(***********************************************************************

                     Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of
the following:

* Save the data starting with the line of stars above into a file
   with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
   clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the
word CacheID, otherwise Mathematica-compatible applications may try to
use invalid cache data.

For more information on notebooks and Mathematica-compatible
applications, contact Wolfram Research:
   web: http://www.wolfram.com
   email: info@wolfram.com
   phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3834723,      82858]*)
(*NotebookOutlinePosition[   3835795,      82892]*)
(*  CellTagsIndexPosition[   3835751,      82888]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Projection reconstruction and the Radon Transform 2", "Title"],

Cell[CellGroupData[{

Cell["The Radon Transform", "Section"],

Cell["\<\
The forward Radon transform is to convert a 2-D object into a set \
of projects within the plane.\
\>", "Text"],

Cell[BoxData[
     \(\(Radon[object_, n_, fov_] :=
         Table[Integrate[
             object\ \ DiracDelta[
                 m\  - \ x\ Cos[\[Theta]]\  - \
                   y\ Sin[\[Theta]]], {x, \(-fov\), fov}, {y, \(-fov\),
               fov}], \[IndentingNewLine]\t\t\t\t\t\t\t{m, \(-2\)\ fov/\((n -
                     1)\), \(+2\)\ fov/\((n - 1)\), 2\ fov/n}, {\[Theta], 0,
             Pi, Pi/\((n - 1)\)}];\)\)], "Input"],

Cell["\<\
The above double integral is very slow to evaluate, and so we \
reduce it to a line integral along the line defined by the delta \
function.\
\>", "Text"],

Cell[BoxData[
     \(Radon2[object_, x_, y_, n_, fov_] :=
       Table[NIntegrate[object[x, y], {yp, \(-fov\), fov},
             \ {PrecisionGoal \[Rule] 4}], {xp, \(-fov\), fov,
             2*fov/\((n - 1)\)}, {\[Theta], 0, Pi, Pi/\((n - 1)\)}]\  // N\)],
   "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define a simple test object", "Section"],

Cell[BoxData[
     \(\(object1[x_, y_] :=
       If[x^2\  + \ y^2\  < 256, 1, 10^\((\(-6\))\)]\  // N; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
     \(Plot3D[
       object1[x, y], {x, \(-64\), 64}, {y, \(-64\), 64}, {
         PlotRange \[Rule] All, PlotPoints \[Rule] {64, 64}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.09164 .22096 -18 -8.88974 ]
[.09164 .22096 0 .11026 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60181 .02034 -10.1961 -9 ]
[.60181 .02034 1.8039 0 ]
[.73809 .05208 0 -6.20582 ]
[.73809 .05208 18 2.79418 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9566 .38669 0 -5.88913 ]
[.9566 .38669 12 3.11087 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10103 .23013 m
.10573 .23471 L
s
[(-50)] .09164 .22096 1 .9755 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60933 .03109 m
.6131 .03647 L
s
[(50)] .60181 .02034 .69935 1 Mshowa
.125 Mabswid
.14766 .21187 m
.15043 .21466 L
s
.19515 .19327 m
.19788 .19611 L
s
.24353 .17433 m
.24621 .17721 L
s
.29283 .15503 m
.29545 .15796 L
s
.39427 .1153 m
.39678 .11833 L
s
.44647 .09487 m
.44892 .09794 L
s
.49969 .07402 m
.50208 .07715 L
s
.55397 .05277 m
.55629 .05595 L
s
.05524 .24806 m
.0581 .25076 L
s
.66582 .00897 m
.668 .01225 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72582 .05673 m
.71969 .05905 L
s
[(-50)] .73809 .05208 -1 .37907 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94406 .39056 m
.93779 .39249 L
s
[(50)] .9566 .38669 -1 .30869 Mshowa
.125 Mabswid
.75117 .0955 m
.74748 .09687 L
s
.77562 .13291 m
.77192 .13425 L
s
.79923 .16902 m
.79552 .17034 L
s
.82203 .2039 m
.81832 .20519 L
s
.86539 .27022 m
.86165 .27146 L
s
.88601 .30176 m
.88227 .30299 L
s
.90598 .33231 m
.90223 .33351 L
s
.92532 .36189 m
.92156 .36307 L
s
.69953 .01651 m
.69586 .01793 L
s
.96223 .41835 m
.95847 .4195 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.40028 .59921 .40512 .60371 .41325 .60127 .40842 .59675 Metetra
.664 .741 .908 r
.40842 .59675 .41325 .60127 .4214 .59883 .41659 .59429 Metetra
.664 .741 .908 r
.41659 .59429 .4214 .59883 .42958 .59638 .42478 .59183 Metetra
.664 .741 .908 r
.42478 .59183 .42958 .59638 .43778 .59392 .433 .58935 Metetra
.664 .741 .908 r
.433 .58935 .43778 .59392 .446 .59145 .44124 .58687 Metetra
.664 .741 .908 r
.44124 .58687 .446 .59145 .45426 .58897 .44951 .58438 Metetra
.664 .741 .908 r
.44951 .58438 .45426 .58897 .46253 .58649 .4578 .58189 Metetra
.664 .741 .908 r
.4578 .58189 .46253 .58649 .47083 .584 .46612 .57938 Metetra
.664 .741 .908 r
.46612 .57938 .47083 .584 .47916 .5815 .47446 .57687 Metetra
.664 .741 .908 r
.47446 .57687 .47916 .5815 .48751 .579 .48283 .57435 Metetra
.664 .741 .908 r
.48283 .57435 .48751 .579 .49589 .57648 .49123 .57182 Metetra
.664 .741 .908 r
.49123 .57182 .49589 .57648 .50429 .57396 .49965 .56929 Metetra
.664 .741 .908 r
.49965 .56929 .50429 .57396 .51272 .57143 .50809 .56674 Metetra
.664 .741 .908 r
.50809 .56674 .51272 .57143 .52118 .5689 .51657 .56419 Metetra
.664 .741 .908 r
.51657 .56419 .52118 .5689 .52966 .56635 .52506 .56163 Metetra
.664 .741 .908 r
.52506 .56163 .52966 .56635 .53817 .5638 .53359 .55907 Metetra
.664 .741 .908 r
.53359 .55907 .53817 .5638 .5467 .56124 .54214 .55649 Metetra
.664 .741 .908 r
.54214 .55649 .5467 .56124 .55526 .55867 .55072 .55391 Metetra
.664 .741 .908 r
.55072 .55391 .55526 .55867 .56385 .55609 .55932 .55132 Metetra
.664 .741 .908 r
.55932 .55132 .56385 .55609 .57247 .55351 .56796 .54872 Metetra
.664 .741 .908 r
.56796 .54872 .57247 .55351 .58111 .55092 .57661 .54611 Metetra
.664 .741 .908 r
.57661 .54611 .58111 .55092 .58977 .54832 .5853 .5435 Metetra
.664 .741 .908 r
.5853 .5435 .58977 .54832 .59847 .54571 .59401 .54087 Metetra
.664 .741 .908 r
.59401 .54087 .59847 .54571 .60719 .54309 .60275 .53824 Metetra
.664 .741 .908 r
.60275 .53824 .60719 .54309 .61594 .54047 .61152 .5356 Metetra
.664 .741 .908 r
.61152 .5356 .61594 .54047 .62472 .53783 .62032 .53295 Metetra
.664 .741 .908 r
.62032 .53295 .62472 .53783 .63352 .53519 .62914 .53029 Metetra
.664 .741 .908 r
.62914 .53029 .63352 .53519 .64235 .53254 .63799 .52763 Metetra
.664 .741 .908 r
.63799 .52763 .64235 .53254 .65121 .52989 .64687 .52496 Metetra
.664 .741 .908 r
.64687 .52496 .65121 .52989 .6601 .52722 .65578 .52227 Metetra
.664 .741 .908 r
.65578 .52227 .6601 .52722 .66902 .52454 .66471 .51958 Metetra
.664 .741 .908 r
.66471 .51958 .66902 .52454 .67796 .52186 .67368 .51688 Metetra
.664 .741 .908 r
.67368 .51688 .67796 .52186 .68694 .51917 .68267 .51418 Metetra
.664 .741 .908 r
.68267 .51418 .68694 .51917 .69594 .51647 .69169 .51146 Metetra
.664 .741 .908 r
.69169 .51146 .69594 .51647 .70497 .51376 .70074 .50874 Metetra
.664 .741 .908 r
.70074 .50874 .70497 .51376 .71403 .51104 .70982 .506 Metetra
.664 .741 .908 r
.70982 .506 .71403 .51104 .72311 .50832 .71893 .50326 Metetra
.664 .741 .908 r
.71893 .50326 .72311 .50832 .73223 .50558 .72806 .50051 Metetra
.664 .741 .908 r
.72806 .50051 .73223 .50558 .74138 .50284 .73723 .49775 Metetra
.664 .741 .908 r
.73723 .49775 .74138 .50284 .75055 .50008 .74643 .49498 Metetra
.664 .741 .908 r
.74643 .49498 .75055 .50008 .75976 .49732 .75565 .4922 Metetra
.664 .741 .908 r
.75565 .4922 .75976 .49732 .76899 .49455 .76491 .48941 Metetra
.664 .741 .908 r
.76491 .48941 .76899 .49455 .77826 .49177 .77419 .48662 Metetra
.664 .741 .908 r
.77419 .48662 .77826 .49177 .78755 .48898 .78351 .48381 Metetra
.664 .741 .908 r
.78351 .48381 .78755 .48898 .79688 .48619 .79286 .481 Metetra
.664 .741 .908 r
.79286 .481 .79688 .48619 .80623 .48338 .80223 .47818 Metetra
.664 .741 .908 r
.80223 .47818 .80623 .48338 .81562 .48057 .81164 .47534 Metetra
.664 .741 .908 r
.81164 .47534 .81562 .48057 .82503 .47774 .82108 .4725 Metetra
.664 .741 .908 r
.82108 .4725 .82503 .47774 .83448 .47491 .83054 .46965 Metetra
.664 .741 .908 r
.83054 .46965 .83448 .47491 .84395 .47206 .84004 .46679 Metetra
.664 .741 .908 r
.84004 .46679 .84395 .47206 .85346 .46921 .84957 .46392 Metetra
.664 .741 .908 r
.84957 .46392 .85346 .46921 .863 .46635 .85914 .46104 Metetra
.664 .741 .908 r
.85914 .46104 .863 .46635 .87257 .46348 .86873 .45815 Metetra
.664 .741 .908 r
.86873 .45815 .87257 .46348 .88217 .4606 .87835 .45526 Metetra
.664 .741 .908 r
.87835 .45526 .88217 .4606 .89181 .45771 .88801 .45235 Metetra
.664 .741 .908 r
.88801 .45235 .89181 .45771 .90147 .45481 .8977 .44943 Metetra
.664 .741 .908 r
.8977 .44943 .90147 .45481 .91117 .4519 .90742 .4465 Metetra
.664 .741 .908 r
.90742 .4465 .91117 .4519 .9209 .44898 .91717 .44357 Metetra
.664 .741 .908 r
.91717 .44357 .9209 .44898 .93066 .44605 .92696 .44062 Metetra
.664 .741 .908 r
.92696 .44062 .93066 .44605 .94045 .44311 .93677 .43766 Metetra
.664 .741 .908 r
.93677 .43766 .94045 .44311 .95028 .44017 .94663 .4347 Metetra
.664 .741 .908 r
.94663 .4347 .95028 .44017 .96014 .43721 .95651 .43172 Metetra
.664 .741 .908 r
.95651 .43172 .96014 .43721 .97003 .43424 .96642 .42874 Metetra
.664 .741 .908 r
.39541 .59467 .40028 .59921 .40842 .59675 .40357 .59221 Metetra
.664 .741 .908 r
.40357 .59221 .40842 .59675 .41659 .59429 .41175 .58974 Metetra
.664 .741 .908 r
.41175 .58974 .41659 .59429 .42478 .59183 .41996 .58725 Metetra
.664 .741 .908 r
.41996 .58725 .42478 .59183 .433 .58935 .4282 .58477 Metetra
.664 .741 .908 r
.4282 .58477 .433 .58935 .44124 .58687 .43645 .58227 Metetra
.664 .741 .908 r
.43645 .58227 .44124 .58687 .44951 .58438 .44474 .57977 Metetra
.664 .741 .908 r
.44474 .57977 .44951 .58438 .4578 .58189 .45304 .57726 Metetra
.664 .741 .908 r
.45304 .57726 .4578 .58189 .46612 .57938 .46138 .57474 Metetra
.664 .741 .908 r
.46138 .57474 .46612 .57938 .47446 .57687 .46974 .57221 Metetra
.664 .741 .908 r
.46974 .57221 .47446 .57687 .48283 .57435 .47812 .56968 Metetra
.664 .741 .908 r
.47812 .56968 .48283 .57435 .49123 .57182 .48653 .56713 Metetra
.664 .741 .908 r
.48653 .56713 .49123 .57182 .49965 .56929 .49497 .56459 Metetra
.664 .741 .908 r
.49497 .56459 .49965 .56929 .50809 .56674 .50344 .56203 Metetra
.664 .741 .908 r
.50344 .56203 .50809 .56674 .51657 .56419 .51193 .55946 Metetra
.664 .741 .908 r
.51193 .55946 .51657 .56419 .52506 .56163 .52044 .55689 Metetra
.664 .741 .908 r
.52044 .55689 .52506 .56163 .53359 .55907 .52898 .55431 Metetra
.664 .741 .908 r
.52898 .55431 .53359 .55907 .54214 .55649 .53755 .55172 Metetra
.664 .741 .908 r
.53755 .55172 .54214 .55649 .55072 .55391 .54615 .54912 Metetra
.664 .741 .908 r
.54615 .54912 .55072 .55391 .55932 .55132 .55477 .54651 Metetra
.664 .741 .908 r
.55477 .54651 .55932 .55132 .56796 .54872 .56342 .5439 Metetra
.664 .741 .908 r
.56342 .5439 .56796 .54872 .57661 .54611 .5721 .54128 Metetra
.664 .741 .908 r
.5721 .54128 .57661 .54611 .5853 .5435 .5808 .53865 Metetra
.664 .741 .908 r
.5808 .53865 .5853 .5435 .59401 .54087 .58953 .53601 Metetra
.664 .741 .908 r
.58953 .53601 .59401 .54087 .60275 .53824 .59829 .53336 Metetra
.664 .741 .908 r
.59829 .53336 .60275 .53824 .61152 .5356 .60708 .5307 Metetra
.664 .741 .908 r
.60708 .5307 .61152 .5356 .62032 .53295 .61589 .52804 Metetra
.664 .741 .908 r
.61589 .52804 .62032 .53295 .62914 .53029 .62473 .52537 Metetra
.664 .741 .908 r
.62473 .52537 .62914 .53029 .63799 .52763 .6336 .52269 Metetra
.664 .741 .908 r
.6336 .52269 .63799 .52763 .64687 .52496 .6425 .52 Metetra
.664 .741 .908 r
.6425 .52 .64687 .52496 .65578 .52227 .65143 .5173 Metetra
.664 .741 .908 r
.65143 .5173 .65578 .52227 .66471 .51958 .66038 .51459 Metetra
.664 .741 .908 r
.66038 .51459 .66471 .51958 .67368 .51688 .66937 .51188 Metetra
.664 .741 .908 r
.66937 .51188 .67368 .51688 .68267 .51418 .67838 .50916 Metetra
.664 .741 .908 r
.67838 .50916 .68267 .51418 .69169 .51146 .68742 .50642 Metetra
.664 .741 .908 r
.68742 .50642 .69169 .51146 .70074 .50874 .69649 .50368 Metetra
.664 .741 .908 r
.69649 .50368 .70074 .50874 .70982 .506 .70559 .50093 Metetra
.664 .741 .908 r
.70559 .50093 .70982 .506 .71893 .50326 .71472 .49817 Metetra
.664 .741 .908 r
.71472 .49817 .71893 .50326 .72806 .50051 .72387 .49541 Metetra
.664 .741 .908 r
.72387 .49541 .72806 .50051 .73723 .49775 .73306 .49263 Metetra
.664 .741 .908 r
.73306 .49263 .73723 .49775 .74643 .49498 .74228 .48984 Metetra
.664 .741 .908 r
.74228 .48984 .74643 .49498 .75565 .4922 .75152 .48705 Metetra
.664 .741 .908 r
.75152 .48705 .75565 .4922 .76491 .48941 .7608 .48425 Metetra
.664 .741 .908 r
.7608 .48425 .76491 .48941 .77419 .48662 .77011 .48143 Metetra
.664 .741 .908 r
.77011 .48143 .77419 .48662 .78351 .48381 .77944 .47861 Metetra
.664 .741 .908 r
.77944 .47861 .78351 .48381 .79286 .481 .78881 .47578 Metetra
.664 .741 .908 r
.78881 .47578 .79286 .481 .80223 .47818 .79821 .47294 Metetra
.664 .741 .908 r
.79821 .47294 .80223 .47818 .81164 .47534 .80764 .47009 Metetra
.664 .741 .908 r
.80764 .47009 .81164 .47534 .82108 .4725 .8171 .46723 Metetra
.664 .741 .908 r
.8171 .46723 .82108 .4725 .83054 .46965 .82659 .46436 Metetra
.664 .741 .908 r
.82659 .46436 .83054 .46965 .84004 .46679 .83611 .46149 Metetra
.664 .741 .908 r
.83611 .46149 .84004 .46679 .84957 .46392 .84566 .4586 Metetra
.664 .741 .908 r
.84566 .4586 .84957 .46392 .85914 .46104 .85525 .4557 Metetra
.664 .741 .908 r
.85525 .4557 .85914 .46104 .86873 .45815 .86486 .4528 Metetra
.664 .741 .908 r
.86486 .4528 .86873 .45815 .87835 .45526 .87451 .44988 Metetra
.664 .741 .908 r
.87451 .44988 .87835 .45526 .88801 .45235 .88419 .44695 Metetra
.664 .741 .908 r
.88419 .44695 .88801 .45235 .8977 .44943 .8939 .44402 Metetra
.664 .741 .908 r
.8939 .44402 .8977 .44943 .90742 .4465 .90365 .44107 Metetra
.664 .741 .908 r
.90365 .44107 .90742 .4465 .91717 .44357 .91342 .43812 Metetra
.664 .741 .908 r
.91342 .43812 .91717 .44357 .92696 .44062 .92323 .43516 Metetra
.664 .741 .908 r
.92323 .43516 .92696 .44062 .93677 .43766 .93307 .43218 Metetra
.664 .741 .908 r
.93307 .43218 .93677 .43766 .94663 .4347 .94295 .4292 Metetra
.664 .741 .908 r
.94295 .4292 .94663 .4347 .95651 .43172 .95285 .4262 Metetra
.664 .741 .908 r
.95285 .4262 .95651 .43172 .96642 .42874 .9628 .4232 Metetra
.664 .741 .908 r
.39052 .59012 .39541 .59467 .40357 .59221 .39869 .58764 Metetra
.664 .741 .908 r
.39869 .58764 .40357 .59221 .41175 .58974 .40689 .58515 Metetra
.664 .741 .908 r
.40689 .58515 .41175 .58974 .41996 .58725 .41511 .58266 Metetra
.664 .741 .908 r
.41511 .58266 .41996 .58725 .4282 .58477 .42336 .58015 Metetra
.664 .741 .908 r
.42336 .58015 .4282 .58477 .43645 .58227 .43164 .57764 Metetra
.664 .741 .908 r
.43164 .57764 .43645 .58227 .44474 .57977 .43994 .57513 Metetra
.664 .741 .908 r
.43994 .57513 .44474 .57977 .45304 .57726 .44826 .5726 Metetra
.664 .741 .908 r
.44826 .5726 .45304 .57726 .46138 .57474 .45661 .57007 Metetra
.664 .741 .908 r
.45661 .57007 .46138 .57474 .46974 .57221 .46499 .56753 Metetra
.664 .741 .908 r
.46499 .56753 .46974 .57221 .47812 .56968 .47339 .56498 Metetra
.664 .741 .908 r
.47339 .56498 .47812 .56968 .48653 .56713 .48182 .56242 Metetra
.664 .741 .908 r
.48182 .56242 .48653 .56713 .49497 .56459 .49027 .55986 Metetra
.664 .741 .908 r
.49027 .55986 .49497 .56459 .50344 .56203 .49875 .55728 Metetra
.664 .741 .908 r
.49875 .55728 .50344 .56203 .51193 .55946 .50726 .5547 Metetra
.664 .741 .908 r
.50726 .5547 .51193 .55946 .52044 .55689 .51579 .55212 Metetra
.664 .741 .908 r
.51579 .55212 .52044 .55689 .52898 .55431 .52435 .54952 Metetra
.664 .741 .908 r
.52435 .54952 .52898 .55431 .53755 .55172 .53294 .54691 Metetra
.664 .741 .908 r
.53294 .54691 .53755 .55172 .54615 .54912 .54155 .5443 Metetra
.664 .741 .908 r
.54155 .5443 .54615 .54912 .55477 .54651 .55019 .54168 Metetra
.664 .741 .908 r
.55019 .54168 .55477 .54651 .56342 .5439 .55886 .53905 Metetra
.664 .741 .908 r
.55886 .53905 .56342 .5439 .5721 .54128 .56755 .53641 Metetra
.664 .741 .908 r
.56755 .53641 .5721 .54128 .5808 .53865 .57628 .53377 Metetra
.664 .741 .908 r
.57628 .53377 .5808 .53865 .58953 .53601 .58502 .53111 Metetra
.664 .741 .908 r
.58502 .53111 .58953 .53601 .59829 .53336 .5938 .52845 Metetra
.664 .741 .908 r
.5938 .52845 .59829 .53336 .60708 .5307 .60261 .52578 Metetra
.664 .741 .908 r
.60261 .52578 .60708 .5307 .61589 .52804 .61144 .5231 Metetra
.664 .741 .908 r
.61144 .5231 .61589 .52804 .62473 .52537 .6203 .52041 Metetra
.664 .741 .908 r
.6203 .52041 .62473 .52537 .6336 .52269 .62919 .51772 Metetra
.664 .741 .908 r
.62919 .51772 .6336 .52269 .6425 .52 .63811 .51501 Metetra
.664 .741 .908 r
.63811 .51501 .6425 .52 .65143 .5173 .64705 .5123 Metetra
.664 .741 .908 r
.64705 .5123 .65143 .5173 .66038 .51459 .65603 .50957 Metetra
.664 .741 .908 r
.65603 .50957 .66038 .51459 .66937 .51188 .66503 .50684 Metetra
.664 .741 .908 r
.66503 .50684 .66937 .51188 .67838 .50916 .67406 .5041 Metetra
.664 .741 .908 r
.67406 .5041 .67838 .50916 .68742 .50642 .68312 .50136 Metetra
.664 .741 .908 r
.68312 .50136 .68742 .50642 .69649 .50368 .69221 .4986 Metetra
.664 .741 .908 r
.69221 .4986 .69649 .50368 .70559 .50093 .70133 .49583 Metetra
.664 .741 .908 r
.70133 .49583 .70559 .50093 .71472 .49817 .71048 .49306 Metetra
.664 .741 .908 r
.71048 .49306 .71472 .49817 .72387 .49541 .71966 .49027 Metetra
.664 .741 .908 r
.71966 .49027 .72387 .49541 .73306 .49263 .72887 .48748 Metetra
.664 .741 .908 r
.72887 .48748 .73306 .49263 .74228 .48984 .7381 .48468 Metetra
.664 .741 .908 r
.7381 .48468 .74228 .48984 .75152 .48705 .74737 .48187 Metetra
.664 .741 .908 r
.74737 .48187 .75152 .48705 .7608 .48425 .75667 .47905 Metetra
.664 .741 .908 r
.75667 .47905 .7608 .48425 .77011 .48143 .766 .47622 Metetra
.664 .741 .908 r
.766 .47622 .77011 .48143 .77944 .47861 .77535 .47338 Metetra
.664 .741 .908 r
.77535 .47338 .77944 .47861 .78881 .47578 .78474 .47053 Metetra
.664 .741 .908 r
.78474 .47053 .78881 .47578 .79821 .47294 .79416 .46767 Metetra
.664 .741 .908 r
.79416 .46767 .79821 .47294 .80764 .47009 .80361 .4648 Metetra
.664 .741 .908 r
.80361 .4648 .80764 .47009 .8171 .46723 .81309 .46193 Metetra
.664 .741 .908 r
.81309 .46193 .8171 .46723 .82659 .46436 .82261 .45904 Metetra
.664 .741 .908 r
.82261 .45904 .82659 .46436 .83611 .46149 .83215 .45615 Metetra
.664 .741 .908 r
.83215 .45615 .83611 .46149 .84566 .4586 .84173 .45324 Metetra
.664 .741 .908 r
.84173 .45324 .84566 .4586 .85525 .4557 .85133 .45033 Metetra
.664 .741 .908 r
.85133 .45033 .85525 .4557 .86486 .4528 .86097 .4474 Metetra
.664 .741 .908 r
.86097 .4474 .86486 .4528 .87451 .44988 .87064 .44447 Metetra
.664 .741 .908 r
.87064 .44447 .87451 .44988 .88419 .44695 .88035 .44153 Metetra
.664 .741 .908 r
.88035 .44153 .88419 .44695 .8939 .44402 .89008 .43857 Metetra
.664 .741 .908 r
.89008 .43857 .8939 .44402 .90365 .44107 .89985 .43561 Metetra
.664 .741 .908 r
.89985 .43561 .90365 .44107 .91342 .43812 .90965 .43264 Metetra
.664 .741 .908 r
.90965 .43264 .91342 .43812 .92323 .43516 .91948 .42966 Metetra
.664 .741 .908 r
.91948 .42966 .92323 .43516 .93307 .43218 .92935 .42666 Metetra
.664 .741 .908 r
.92935 .42666 .93307 .43218 .94295 .4292 .93925 .42366 Metetra
.664 .741 .908 r
.93925 .42366 .94295 .4292 .95285 .4262 .94918 .42065 Metetra
.664 .741 .908 r
.94918 .42065 .95285 .4262 .9628 .4232 .95914 .41762 Metetra
.664 .741 .908 r
.3856 .58553 .39052 .59012 .39869 .58764 .39379 .58304 Metetra
.664 .741 .908 r
.39379 .58304 .39869 .58764 .40689 .58515 .402 .58054 Metetra
.664 .741 .908 r
.402 .58054 .40689 .58515 .41511 .58266 .41024 .57803 Metetra
.664 .741 .908 r
.41024 .57803 .41511 .58266 .42336 .58015 .4185 .57551 Metetra
.664 .741 .908 r
.4185 .57551 .42336 .58015 .43164 .57764 .42679 .57299 Metetra
.664 .741 .908 r
.42679 .57299 .43164 .57764 .43994 .57513 .43511 .57046 Metetra
.664 .741 .908 r
.43511 .57046 .43994 .57513 .44826 .5726 .44345 .56792 Metetra
.664 .741 .908 r
.44345 .56792 .44826 .5726 .45661 .57007 .45182 .56537 Metetra
.664 .741 .908 r
.45182 .56537 .45661 .57007 .46499 .56753 .46021 .56282 Metetra
.664 .741 .908 r
.46021 .56282 .46499 .56753 .47339 .56498 .46863 .56025 Metetra
.664 .741 .908 r
.46863 .56025 .47339 .56498 .48182 .56242 .47707 .55768 Metetra
.664 .741 .908 r
.47707 .55768 .48182 .56242 .49027 .55986 .48554 .5551 Metetra
.664 .741 .908 r
.48554 .5551 .49027 .55986 .49875 .55728 .49404 .55251 Metetra
.664 .741 .908 r
.49404 .55251 .49875 .55728 .50726 .5547 .50256 .54992 Metetra
.664 .741 .908 r
.50256 .54992 .50726 .5547 .51579 .55212 .51111 .54732 Metetra
.664 .741 .908 r
.51111 .54732 .51579 .55212 .52435 .54952 .51969 .5447 Metetra
.664 .741 .908 r
.51969 .5447 .52435 .54952 .53294 .54691 .5283 .54208 Metetra
.664 .741 .908 r
.5283 .54208 .53294 .54691 .54155 .5443 .53693 .53946 Metetra
.664 .741 .908 r
.53693 .53946 .54155 .5443 .55019 .54168 .54558 .53682 Metetra
.664 .741 .908 r
.54558 .53682 .55019 .54168 .55886 .53905 .55427 .53417 Metetra
.664 .741 .908 r
.55427 .53417 .55886 .53905 .56755 .53641 .56298 .53152 Metetra
.664 .741 .908 r
.56298 .53152 .56755 .53641 .57628 .53377 .57172 .52886 Metetra
.664 .741 .908 r
.57172 .52886 .57628 .53377 .58502 .53111 .58049 .52619 Metetra
.664 .741 .908 r
.58049 .52619 .58502 .53111 .5938 .52845 .58929 .52351 Metetra
.664 .741 .908 r
.58929 .52351 .5938 .52845 .60261 .52578 .59811 .52083 Metetra
.664 .741 .908 r
.59811 .52083 .60261 .52578 .61144 .5231 .60696 .51813 Metetra
.664 .741 .908 r
.60696 .51813 .61144 .5231 .6203 .52041 .61584 .51543 Metetra
.664 .741 .908 r
.61584 .51543 .6203 .52041 .62919 .51772 .62475 .51272 Metetra
.664 .741 .908 r
.62475 .51272 .62919 .51772 .63811 .51501 .63369 .50999 Metetra
.664 .741 .908 r
.63369 .50999 .63811 .51501 .64705 .5123 .64265 .50726 Metetra
.664 .741 .908 r
.64265 .50726 .64705 .5123 .65603 .50957 .65164 .50453 Metetra
.664 .741 .908 r
.65164 .50453 .65603 .50957 .66503 .50684 .66067 .50178 Metetra
.664 .741 .908 r
.66067 .50178 .66503 .50684 .67406 .5041 .66972 .49902 Metetra
.664 .741 .908 r
.66972 .49902 .67406 .5041 .68312 .50136 .6788 .49626 Metetra
.664 .741 .908 r
.6788 .49626 .68312 .50136 .69221 .4986 .68791 .49348 Metetra
.664 .741 .908 r
.68791 .49348 .69221 .4986 .70133 .49583 .69705 .4907 Metetra
.664 .741 .908 r
.69705 .4907 .70133 .49583 .71048 .49306 .70622 .48791 Metetra
.664 .741 .908 r
.70622 .48791 .71048 .49306 .71966 .49027 .71542 .48511 Metetra
.664 .741 .908 r
.71542 .48511 .71966 .49027 .72887 .48748 .72464 .4823 Metetra
.664 .741 .908 r
.72464 .4823 .72887 .48748 .7381 .48468 .7339 .47948 Metetra
.664 .741 .908 r
.7339 .47948 .7381 .48468 .74737 .48187 .74319 .47665 Metetra
.664 .741 .908 r
.74319 .47665 .74737 .48187 .75667 .47905 .75251 .47381 Metetra
.664 .741 .908 r
.75251 .47381 .75667 .47905 .766 .47622 .76186 .47097 Metetra
.664 .741 .908 r
.76186 .47097 .766 .47622 .77535 .47338 .77124 .46811 Metetra
.664 .741 .908 r
.77124 .46811 .77535 .47338 .78474 .47053 .78065 .46525 Metetra
.664 .741 .908 r
.78065 .46525 .78474 .47053 .79416 .46767 .79009 .46237 Metetra
.664 .741 .908 r
.79009 .46237 .79416 .46767 .80361 .4648 .79956 .45949 Metetra
.664 .741 .908 r
.79956 .45949 .80361 .4648 .81309 .46193 .80907 .45659 Metetra
.664 .741 .908 r
.80907 .45659 .81309 .46193 .82261 .45904 .8186 .45369 Metetra
.664 .741 .908 r
.8186 .45369 .82261 .45904 .83215 .45615 .82817 .45078 Metetra
.664 .741 .908 r
.82817 .45078 .83215 .45615 .84173 .45324 .83777 .44786 Metetra
.664 .741 .908 r
.83777 .44786 .84173 .45324 .85133 .45033 .8474 .44492 Metetra
.664 .741 .908 r
.8474 .44492 .85133 .45033 .86097 .4474 .85706 .44198 Metetra
.664 .741 .908 r
.85706 .44198 .86097 .4474 .87064 .44447 .86675 .43903 Metetra
.664 .741 .908 r
.86675 .43903 .87064 .44447 .88035 .44153 .87648 .43607 Metetra
.664 .741 .908 r
.87648 .43607 .88035 .44153 .89008 .43857 .88624 .4331 Metetra
.664 .741 .908 r
.88624 .4331 .89008 .43857 .89985 .43561 .89603 .43012 Metetra
.664 .741 .908 r
.89603 .43012 .89985 .43561 .90965 .43264 .90585 .42712 Metetra
.664 .741 .908 r
.90585 .42712 .90965 .43264 .91948 .42966 .91571 .42412 Metetra
.664 .741 .908 r
.91571 .42412 .91948 .42966 .92935 .42666 .9256 .42111 Metetra
.664 .741 .908 r
.9256 .42111 .92935 .42666 .93925 .42366 .93552 .41809 Metetra
.664 .741 .908 r
.93552 .41809 .93925 .42366 .94918 .42065 .94548 .41506 Metetra
.664 .741 .908 r
.94548 .41506 .94918 .42065 .95914 .41762 .95547 .41202 Metetra
.664 .741 .908 r
.38065 .58092 .3856 .58553 .39379 .58304 .38885 .57842 Metetra
.664 .741 .908 r
.38885 .57842 .39379 .58304 .402 .58054 .39708 .5759 Metetra
.664 .741 .908 r
.39708 .5759 .402 .58054 .41024 .57803 .40534 .57338 Metetra
.664 .741 .908 r
.40534 .57338 .41024 .57803 .4185 .57551 .41362 .57085 Metetra
.664 .741 .908 r
.41362 .57085 .4185 .57551 .42679 .57299 .42192 .56831 Metetra
.664 .741 .908 r
.42192 .56831 .42679 .57299 .43511 .57046 .43025 .56576 Metetra
.664 .741 .908 r
.43025 .56576 .43511 .57046 .44345 .56792 .43861 .56321 Metetra
.664 .741 .908 r
.43861 .56321 .44345 .56792 .45182 .56537 .44699 .56065 Metetra
.664 .741 .908 r
.44699 .56065 .45182 .56537 .46021 .56282 .4554 .55808 Metetra
.664 .741 .908 r
.4554 .55808 .46021 .56282 .46863 .56025 .46384 .5555 Metetra
.664 .741 .908 r
.46384 .5555 .46863 .56025 .47707 .55768 .4723 .55291 Metetra
.664 .741 .908 r
.4723 .55291 .47707 .55768 .48554 .5551 .48079 .55032 Metetra
.664 .741 .908 r
.48079 .55032 .48554 .5551 .49404 .55251 .4893 .54772 Metetra
.664 .741 .908 r
.4893 .54772 .49404 .55251 .50256 .54992 .49784 .54511 Metetra
.664 .741 .908 r
.49784 .54511 .50256 .54992 .51111 .54732 .50641 .54249 Metetra
.664 .741 .908 r
.50641 .54249 .51111 .54732 .51969 .5447 .51501 .53986 Metetra
.664 .741 .908 r
.51501 .53986 .51969 .5447 .5283 .54208 .52363 .53723 Metetra
.664 .741 .908 r
.52363 .53723 .5283 .54208 .53693 .53946 .53228 .53458 Metetra
.664 .741 .908 r
.53228 .53458 .53693 .53946 .54558 .53682 .54095 .53193 Metetra
.664 .741 .908 r
.54095 .53193 .54558 .53682 .55427 .53417 .54966 .52927 Metetra
.664 .741 .908 r
.54966 .52927 .55427 .53417 .56298 .53152 .55839 .5266 Metetra
.664 .741 .908 r
.55839 .5266 .56298 .53152 .57172 .52886 .56714 .52393 Metetra
.664 .741 .908 r
.56714 .52393 .57172 .52886 .58049 .52619 .57593 .52124 Metetra
.664 .741 .908 r
.57593 .52124 .58049 .52619 .58929 .52351 .58475 .51855 Metetra
.664 .741 .908 r
.58475 .51855 .58929 .52351 .59811 .52083 .59359 .51584 Metetra
.664 .741 .908 r
.59359 .51584 .59811 .52083 .60696 .51813 .60246 .51313 Metetra
.664 .741 .908 r
.60246 .51313 .60696 .51813 .61584 .51543 .61136 .51041 Metetra
.664 .741 .908 r
.61136 .51041 .61584 .51543 .62475 .51272 .62028 .50769 Metetra
.664 .741 .908 r
.62028 .50769 .62475 .51272 .63369 .50999 .62924 .50495 Metetra
.664 .741 .908 r
.62924 .50495 .63369 .50999 .64265 .50726 .63822 .5022 Metetra
.664 .741 .908 r
.63822 .5022 .64265 .50726 .65164 .50453 .64724 .49945 Metetra
.664 .741 .908 r
.64724 .49945 .65164 .50453 .66067 .50178 .65628 .49668 Metetra
.664 .741 .908 r
.65628 .49668 .66067 .50178 .66972 .49902 .66535 .49391 Metetra
.664 .741 .908 r
.66535 .49391 .66972 .49902 .6788 .49626 .67445 .49113 Metetra
.664 .741 .908 r
.67445 .49113 .6788 .49626 .68791 .49348 .68358 .48834 Metetra
.664 .741 .908 r
.68358 .48834 .68791 .49348 .69705 .4907 .69274 .48554 Metetra
.664 .741 .908 r
.69274 .48554 .69705 .4907 .70622 .48791 .70193 .48273 Metetra
.664 .741 .908 r
.70193 .48273 .70622 .48791 .71542 .48511 .71115 .47991 Metetra
.664 .741 .908 r
.71115 .47991 .71542 .48511 .72464 .4823 .7204 .47709 Metetra
.664 .741 .908 r
.7204 .47709 .72464 .4823 .7339 .47948 .72968 .47425 Metetra
.664 .741 .908 r
.72968 .47425 .7339 .47948 .74319 .47665 .73899 .47141 Metetra
.664 .741 .908 r
.73899 .47141 .74319 .47665 .75251 .47381 .74833 .46855 Metetra
.664 .741 .908 r
.74833 .46855 .75251 .47381 .76186 .47097 .7577 .46569 Metetra
.664 .741 .908 r
.7577 .46569 .76186 .47097 .77124 .46811 .7671 .46281 Metetra
.664 .741 .908 r
.7671 .46281 .77124 .46811 .78065 .46525 .77653 .45993 Metetra
.664 .741 .908 r
.77653 .45993 .78065 .46525 .79009 .46237 .786 .45704 Metetra
.664 .741 .908 r
.786 .45704 .79009 .46237 .79956 .45949 .79549 .45414 Metetra
.664 .741 .908 r
.79549 .45414 .79956 .45949 .80907 .45659 .80502 .45123 Metetra
.664 .741 .908 r
.80502 .45123 .80907 .45659 .8186 .45369 .81457 .44831 Metetra
.664 .741 .908 r
.81457 .44831 .8186 .45369 .82817 .45078 .82416 .44537 Metetra
.664 .741 .908 r
.82416 .44537 .82817 .45078 .83777 .44786 .83378 .44243 Metetra
.664 .741 .908 r
.83378 .44243 .83777 .44786 .8474 .44492 .84344 .43948 Metetra
.664 .741 .908 r
.84344 .43948 .8474 .44492 .85706 .44198 .85312 .43652 Metetra
.664 .741 .908 r
.85312 .43652 .85706 .44198 .86675 .43903 .86284 .43355 Metetra
.664 .741 .908 r
.86284 .43355 .86675 .43903 .87648 .43607 .87259 .43057 Metetra
.664 .741 .908 r
.87259 .43057 .87648 .43607 .88624 .4331 .88237 .42759 Metetra
.664 .741 .908 r
.88237 .42759 .88624 .4331 .89603 .43012 .89218 .42459 Metetra
.664 .741 .908 r
.89218 .42459 .89603 .43012 .90585 .42712 .90203 .42158 Metetra
.664 .741 .908 r
.90203 .42158 .90585 .42712 .91571 .42412 .91191 .41856 Metetra
.664 .741 .908 r
.91191 .41856 .91571 .42412 .9256 .42111 .92183 .41553 Metetra
.664 .741 .908 r
.92183 .41553 .9256 .42111 .93552 .41809 .93178 .41249 Metetra
.664 .741 .908 r
.93178 .41249 .93552 .41809 .94548 .41506 .94176 .40943 Metetra
.664 .741 .908 r
.94176 .40943 .94548 .41506 .95547 .41202 .95177 .40637 Metetra
.664 .741 .908 r
.37567 .57629 .38065 .58092 .38885 .57842 .38389 .57377 Metetra
.664 .741 .908 r
.38389 .57377 .38885 .57842 .39708 .5759 .39213 .57124 Metetra
.664 .741 .908 r
.39213 .57124 .39708 .5759 .40534 .57338 .40041 .5687 Metetra
.664 .741 .908 r
.40041 .5687 .40534 .57338 .41362 .57085 .4087 .56616 Metetra
.664 .741 .908 r
.4087 .56616 .41362 .57085 .42192 .56831 .41702 .5636 Metetra
.664 .741 .908 r
.41702 .5636 .42192 .56831 .43025 .56576 .42537 .56104 Metetra
.664 .741 .908 r
.42537 .56104 .43025 .56576 .43861 .56321 .43374 .55847 Metetra
.664 .741 .908 r
.43374 .55847 .43861 .56321 .44699 .56065 .44214 .5559 Metetra
.664 .741 .908 r
.44214 .5559 .44699 .56065 .4554 .55808 .45057 .55331 Metetra
.664 .741 .908 r
.45057 .55331 .4554 .55808 .46384 .5555 .45902 .55072 Metetra
.664 .741 .908 r
.45902 .55072 .46384 .5555 .4723 .55291 .4675 .54812 Metetra
.664 .741 .908 r
.4675 .54812 .4723 .55291 .48079 .55032 .47601 .54551 Metetra
.664 .741 .908 r
.47601 .54551 .48079 .55032 .4893 .54772 .48454 .54289 Metetra
.664 .741 .908 r
.48454 .54289 .4893 .54772 .49784 .54511 .4931 .54027 Metetra
.664 .741 .908 r
.4931 .54027 .49784 .54511 .50641 .54249 .50168 .53763 Metetra
.664 .741 .908 r
.50168 .53763 .50641 .54249 .51501 .53986 .51029 .53499 Metetra
.664 .741 .908 r
.51029 .53499 .51501 .53986 .52363 .53723 .51893 .53234 Metetra
.664 .741 .908 r
.51893 .53234 .52363 .53723 .53228 .53458 .5276 .52968 Metetra
.664 .741 .908 r
.5276 .52968 .53228 .53458 .54095 .53193 .53629 .52701 Metetra
.664 .741 .908 r
.53629 .52701 .54095 .53193 .54966 .52927 .54501 .52434 Metetra
.664 .741 .908 r
.54501 .52434 .54966 .52927 .55839 .5266 .55376 .52165 Metetra
.664 .741 .908 r
.55376 .52165 .55839 .5266 .56714 .52393 .56254 .51896 Metetra
.664 .741 .908 r
.56254 .51896 .56714 .52393 .57593 .52124 .57134 .51626 Metetra
.664 .741 .908 r
.57134 .51626 .57593 .52124 .58475 .51855 .58018 .51355 Metetra
.664 .741 .908 r
.58018 .51355 .58475 .51855 .59359 .51584 .58904 .51083 Metetra
.664 .741 .908 r
.58904 .51083 .59359 .51584 .60246 .51313 .59793 .50811 Metetra
.664 .741 .908 r
.59793 .50811 .60246 .51313 .61136 .51041 .60684 .50537 Metetra
.664 .741 .908 r
.60684 .50537 .61136 .51041 .62028 .50769 .61579 .50263 Metetra
.664 .741 .908 r
.61579 .50263 .62028 .50769 .62924 .50495 .62477 .49987 Metetra
.664 .741 .908 r
.62477 .49987 .62924 .50495 .63822 .5022 .63377 .49711 Metetra
.664 .741 .908 r
.63377 .49711 .63822 .5022 .64724 .49945 .6428 .49434 Metetra
.664 .741 .908 r
.6428 .49434 .64724 .49945 .65628 .49668 .65186 .49156 Metetra
.664 .741 .908 r
.65186 .49156 .65628 .49668 .66535 .49391 .66096 .48877 Metetra
.664 .741 .908 r
.66096 .48877 .66535 .49391 .67445 .49113 .67008 .48597 Metetra
.664 .741 .908 r
.67008 .48597 .67445 .49113 .68358 .48834 .67923 .48316 Metetra
.664 .741 .908 r
.67923 .48316 .68358 .48834 .69274 .48554 .68841 .48035 Metetra
.664 .741 .908 r
.68841 .48035 .69274 .48554 .70193 .48273 .69762 .47752 Metetra
.664 .741 .908 r
.69762 .47752 .70193 .48273 .71115 .47991 .70686 .47469 Metetra
.664 .741 .908 r
.70686 .47469 .71115 .47991 .7204 .47709 .71613 .47184 Metetra
.664 .741 .908 r
.71613 .47184 .7204 .47709 .72968 .47425 .72543 .46899 Metetra
.664 .741 .908 r
.72543 .46899 .72968 .47425 .73899 .47141 .73476 .46613 Metetra
.664 .741 .908 r
.73476 .46613 .73899 .47141 .74833 .46855 .74412 .46326 Metetra
.664 .741 .908 r
.74412 .46326 .74833 .46855 .7577 .46569 .75351 .46038 Metetra
.664 .741 .908 r
.75351 .46038 .7577 .46569 .7671 .46281 .76293 .45749 Metetra
.664 .741 .908 r
.76293 .45749 .7671 .46281 .77653 .45993 .77239 .45458 Metetra
.664 .741 .908 r
.77239 .45458 .77653 .45993 .786 .45704 .78187 .45168 Metetra
.664 .741 .908 r
.78187 .45168 .786 .45704 .79549 .45414 .79139 .44876 Metetra
.664 .741 .908 r
.79139 .44876 .79549 .45414 .80502 .45123 .80094 .44583 Metetra
.664 .741 .908 r
.80094 .44583 .80502 .45123 .81457 .44831 .81052 .44289 Metetra
.664 .741 .908 r
.81052 .44289 .81457 .44831 .82416 .44537 .82013 .43994 Metetra
.664 .741 .908 r
.82013 .43994 .82416 .44537 .83378 .44243 .82977 .43698 Metetra
.664 .741 .908 r
.82977 .43698 .83378 .44243 .84344 .43948 .83945 .43401 Metetra
.664 .741 .908 r
.83945 .43401 .84344 .43948 .85312 .43652 .84916 .43103 Metetra
.664 .741 .908 r
.84916 .43103 .85312 .43652 .86284 .43355 .8589 .42805 Metetra
.664 .741 .908 r
.8589 .42805 .86284 .43355 .87259 .43057 .86867 .42505 Metetra
.664 .741 .908 r
.86867 .42505 .87259 .43057 .88237 .42759 .87848 .42204 Metetra
.664 .741 .908 r
.87848 .42204 .88237 .42759 .89218 .42459 .88832 .41902 Metetra
.664 .741 .908 r
.88832 .41902 .89218 .42459 .90203 .42158 .89819 .41599 Metetra
.664 .741 .908 r
.89819 .41599 .90203 .42158 .91191 .41856 .90809 .41295 Metetra
.664 .741 .908 r
.90809 .41295 .91191 .41856 .92183 .41553 .91803 .4099 Metetra
.664 .741 .908 r
.91803 .4099 .92183 .41553 .93178 .41249 .92801 .40685 Metetra
.664 .741 .908 r
.92801 .40685 .93178 .41249 .94176 .40943 .93801 .40378 Metetra
.664 .741 .908 r
.93801 .40378 .94176 .40943 .95177 .40637 .94805 .4007 Metetra
.664 .741 .908 r
.37066 .57163 .37567 .57629 .38389 .57377 .3789 .56909 Metetra
.664 .741 .908 r
.3789 .56909 .38389 .57377 .39213 .57124 .38716 .56655 Metetra
.664 .741 .908 r
.38716 .56655 .39213 .57124 .40041 .5687 .39545 .564 Metetra
.664 .741 .908 r
.39545 .564 .40041 .5687 .4087 .56616 .40376 .56144 Metetra
.664 .741 .908 r
.40376 .56144 .4087 .56616 .41702 .5636 .4121 .55887 Metetra
.664 .741 .908 r
.4121 .55887 .41702 .5636 .42537 .56104 .42046 .55629 Metetra
.664 .741 .908 r
.42046 .55629 .42537 .56104 .43374 .55847 .42885 .55371 Metetra
.664 .741 .908 r
.42885 .55371 .43374 .55847 .44214 .5559 .43727 .55112 Metetra
.664 .741 .908 r
.43727 .55112 .44214 .5559 .45057 .55331 .44571 .54852 Metetra
.664 .741 .908 r
.44571 .54852 .45057 .55331 .45902 .55072 .45418 .54591 Metetra
.664 .741 .908 r
.45418 .54591 .45902 .55072 .4675 .54812 .46267 .54329 Metetra
.664 .741 .908 r
.46267 .54329 .4675 .54812 .47601 .54551 .4712 .54067 Metetra
.664 .741 .908 r
.4712 .54067 .47601 .54551 .48454 .54289 .47974 .53804 Metetra
.664 .741 .908 r
.47974 .53804 .48454 .54289 .4931 .54027 .48832 .5354 Metetra
.664 .741 .908 r
.48832 .5354 .4931 .54027 .50168 .53763 .49692 .53275 Metetra
.664 .741 .908 r
.49692 .53275 .50168 .53763 .51029 .53499 .50555 .53009 Metetra
.664 .741 .908 r
.50555 .53009 .51029 .53499 .51893 .53234 .51421 .52742 Metetra
.664 .741 .908 r
.51421 .52742 .51893 .53234 .5276 .52968 .52289 .52475 Metetra
.664 .741 .908 r
.52289 .52475 .5276 .52968 .53629 .52701 .5316 .52207 Metetra
.664 .741 .908 r
.5316 .52207 .53629 .52701 .54501 .52434 .54034 .51938 Metetra
.664 .741 .908 r
.54034 .51938 .54501 .52434 .55376 .52165 .54911 .51668 Metetra
.664 .741 .908 r
.54911 .51668 .55376 .52165 .56254 .51896 .55791 .51397 Metetra
.664 .741 .908 r
.55791 .51397 .56254 .51896 .57134 .51626 .56673 .51125 Metetra
.664 .741 .908 r
.56673 .51125 .57134 .51626 .58018 .51355 .57558 .50853 Metetra
.664 .741 .908 r
.57558 .50853 .58018 .51355 .58904 .51083 .58446 .50579 Metetra
.664 .741 .908 r
.58446 .50579 .58904 .51083 .59793 .50811 .59337 .50305 Metetra
.664 .741 .908 r
.59337 .50305 .59793 .50811 .60684 .50537 .60231 .5003 Metetra
.664 .741 .908 r
.60231 .5003 .60684 .50537 .61579 .50263 .61127 .49754 Metetra
.664 .741 .908 r
.61127 .49754 .61579 .50263 .62477 .49987 .62027 .49477 Metetra
.664 .741 .908 r
.62027 .49477 .62477 .49987 .63377 .49711 .62929 .49199 Metetra
.664 .741 .908 r
.62929 .49199 .63377 .49711 .6428 .49434 .63834 .4892 Metetra
.664 .741 .908 r
.63834 .4892 .6428 .49434 .65186 .49156 .64742 .4864 Metetra
.664 .741 .908 r
.64742 .4864 .65186 .49156 .66096 .48877 .65654 .4836 Metetra
.664 .741 .908 r
.65654 .4836 .66096 .48877 .67008 .48597 .66568 .48078 Metetra
.664 .741 .908 r
.66568 .48078 .67008 .48597 .67923 .48316 .67485 .47796 Metetra
.664 .741 .908 r
.67485 .47796 .67923 .48316 .68841 .48035 .68405 .47513 Metetra
.664 .741 .908 r
.68405 .47513 .68841 .48035 .69762 .47752 .69328 .47228 Metetra
.664 .741 .908 r
.69328 .47228 .69762 .47752 .70686 .47469 .70254 .46943 Metetra
.664 .741 .908 r
.70254 .46943 .70686 .47469 .71613 .47184 .71183 .46657 Metetra
.664 .741 .908 r
.71183 .46657 .71613 .47184 .72543 .46899 .72115 .4637 Metetra
.664 .741 .908 r
.72115 .4637 .72543 .46899 .73476 .46613 .7305 .46082 Metetra
.664 .741 .908 r
.7305 .46082 .73476 .46613 .74412 .46326 .73989 .45793 Metetra
.664 .741 .908 r
.73989 .45793 .74412 .46326 .75351 .46038 .7493 .45503 Metetra
.664 .741 .908 r
.7493 .45503 .75351 .46038 .76293 .45749 .75874 .45212 Metetra
.664 .741 .908 r
.75874 .45212 .76293 .45749 .77239 .45458 .76822 .44921 Metetra
.664 .741 .908 r
.76822 .44921 .77239 .45458 .78187 .45168 .77773 .44628 Metetra
.664 .741 .908 r
.77773 .44628 .78187 .45168 .79139 .44876 .78727 .44334 Metetra
.664 .741 .908 r
.78727 .44334 .79139 .44876 .80094 .44583 .79684 .44039 Metetra
.664 .741 .908 r
.79684 .44039 .80094 .44583 .81052 .44289 .80644 .43744 Metetra
.664 .741 .908 r
.80644 .43744 .81052 .44289 .82013 .43994 .81607 .43447 Metetra
.664 .741 .908 r
.81607 .43447 .82013 .43994 .82977 .43698 .82574 .43149 Metetra
.664 .741 .908 r
.82574 .43149 .82977 .43698 .83945 .43401 .83544 .42851 Metetra
.664 .741 .908 r
.83544 .42851 .83945 .43401 .84916 .43103 .84517 .42551 Metetra
.664 .741 .908 r
.84517 .42551 .84916 .43103 .8589 .42805 .85494 .4225 Metetra
.664 .741 .908 r
.85494 .4225 .8589 .42805 .86867 .42505 .86473 .41949 Metetra
.664 .741 .908 r
.86473 .41949 .86867 .42505 .87848 .42204 .87456 .41646 Metetra
.664 .741 .908 r
.87456 .41646 .87848 .42204 .88832 .41902 .88443 .41342 Metetra
.664 .741 .908 r
.88443 .41342 .88832 .41902 .89819 .41599 .89432 .41037 Metetra
.664 .741 .908 r
.89432 .41037 .89819 .41599 .90809 .41295 .90425 .40732 Metetra
.664 .741 .908 r
.90425 .40732 .90809 .41295 .91803 .4099 .91421 .40425 Metetra
.664 .741 .908 r
.91421 .40425 .91803 .4099 .92801 .40685 .92421 .40117 Metetra
.664 .741 .908 r
.92421 .40117 .92801 .40685 .93801 .40378 .93424 .39808 Metetra
.664 .741 .908 r
.93424 .39808 .93801 .40378 .94805 .4007 .94431 .39498 Metetra
.664 .741 .908 r
.36563 .56694 .37066 .57163 .3789 .56909 .37388 .56439 Metetra
.664 .741 .908 r
.37388 .56439 .3789 .56909 .38716 .56655 .38216 .56183 Metetra
.664 .741 .908 r
.38216 .56183 .38716 .56655 .39545 .564 .39046 .55926 Metetra
.664 .741 .908 r
.39046 .55926 .39545 .564 .40376 .56144 .39879 .55669 Metetra
.664 .741 .908 r
.39879 .55669 .40376 .56144 .4121 .55887 .40714 .55411 Metetra
.664 .741 .908 r
.40714 .55411 .4121 .55887 .42046 .55629 .41552 .55152 Metetra
.664 .741 .908 r
.41552 .55152 .42046 .55629 .42885 .55371 .42393 .54892 Metetra
.664 .741 .908 r
.42393 .54892 .42885 .55371 .43727 .55112 .43236 .54631 Metetra
.664 .741 .908 r
.43236 .54631 .43727 .55112 .44571 .54852 .44082 .5437 Metetra
.664 .741 .908 r
.44082 .5437 .44571 .54852 .45418 .54591 .44931 .54107 Metetra
.664 .741 .908 r
.44931 .54107 .45418 .54591 .46267 .54329 .45782 .53844 Metetra
.664 .741 .908 r
.45782 .53844 .46267 .54329 .4712 .54067 .46636 .5358 Metetra
.664 .741 .908 r
.46636 .5358 .4712 .54067 .47974 .53804 .47492 .53316 Metetra
.664 .741 .908 r
.47492 .53316 .47974 .53804 .48832 .5354 .48352 .5305 Metetra
.664 .741 .908 r
.48352 .5305 .48832 .5354 .49692 .53275 .49214 .52784 Metetra
.664 .741 .908 r
.49214 .52784 .49692 .53275 .50555 .53009 .50078 .52516 Metetra
.664 .741 .908 r
.50078 .52516 .50555 .53009 .51421 .52742 .50946 .52248 Metetra
.664 .741 .908 r
.50946 .52248 .51421 .52742 .52289 .52475 .51816 .51979 Metetra
.664 .741 .908 r
.51816 .51979 .52289 .52475 .5316 .52207 .52689 .51709 Metetra
.664 .741 .908 r
.52689 .51709 .5316 .52207 .54034 .51938 .53565 .51439 Metetra
.664 .741 .908 r
.53565 .51439 .54034 .51938 .54911 .51668 .54443 .51167 Metetra
.664 .741 .908 r
.54443 .51167 .54911 .51668 .55791 .51397 .55325 .50895 Metetra
.664 .741 .908 r
.55325 .50895 .55791 .51397 .56673 .51125 .56209 .50621 Metetra
.664 .741 .908 r
.56209 .50621 .56673 .51125 .57558 .50853 .57096 .50347 Metetra
.664 .741 .908 r
.57096 .50347 .57558 .50853 .58446 .50579 .57986 .50072 Metetra
.664 .741 .908 r
.57986 .50072 .58446 .50579 .59337 .50305 .58878 .49796 Metetra
.664 .741 .908 r
.58878 .49796 .59337 .50305 .60231 .5003 .59774 .49519 Metetra
.664 .741 .908 r
.59774 .49519 .60231 .5003 .61127 .49754 .60673 .49241 Metetra
.664 .741 .908 r
.60673 .49241 .61127 .49754 .62027 .49477 .61574 .48963 Metetra
.664 .741 .908 r
.61574 .48963 .62027 .49477 .62929 .49199 .62478 .48683 Metetra
.664 .741 .908 r
.62478 .48683 .62929 .49199 .63834 .4892 .63386 .48403 Metetra
.664 .741 .908 r
.63386 .48403 .63834 .4892 .64742 .4864 .64296 .48122 Metetra
.664 .741 .908 r
.64296 .48122 .64742 .4864 .65654 .4836 .65209 .47839 Metetra
.664 .741 .908 r
.65209 .47839 .65654 .4836 .66568 .48078 .66125 .47556 Metetra
.664 .741 .908 r
.66125 .47556 .66568 .48078 .67485 .47796 .67044 .47272 Metetra
.664 .741 .908 r
.67044 .47272 .67485 .47796 .68405 .47513 .67966 .46987 Metetra
.664 .741 .908 r
.67966 .46987 .68405 .47513 .69328 .47228 .68891 .46701 Metetra
.664 .741 .908 r
.68891 .46701 .69328 .47228 .70254 .46943 .69819 .46414 Metetra
.664 .741 .908 r
.69819 .46414 .70254 .46943 .71183 .46657 .70751 .46126 Metetra
.664 .741 .908 r
.70751 .46126 .71183 .46657 .72115 .4637 .71685 .45838 Metetra
.664 .741 .908 r
.71685 .45838 .72115 .4637 .7305 .46082 .72622 .45548 Metetra
.664 .741 .908 r
.72622 .45548 .7305 .46082 .73989 .45793 .73563 .45257 Metetra
.664 .741 .908 r
.73563 .45257 .73989 .45793 .7493 .45503 .74506 .44965 Metetra
.664 .741 .908 r
.74506 .44965 .7493 .45503 .75874 .45212 .75453 .44673 Metetra
.664 .741 .908 r
.75453 .44673 .75874 .45212 .76822 .44921 .76403 .44379 Metetra
.664 .741 .908 r
.76403 .44379 .76822 .44921 .77773 .44628 .77356 .44085 Metetra
.664 .741 .908 r
.77356 .44085 .77773 .44628 .78727 .44334 .78312 .43789 Metetra
.664 .741 .908 r
.78312 .43789 .78727 .44334 .79684 .44039 .79271 .43493 Metetra
.664 .741 .908 r
.79271 .43493 .79684 .44039 .80644 .43744 .80234 .43195 Metetra
.664 .741 .908 r
.80234 .43195 .80644 .43744 .81607 .43447 .81199 .42897 Metetra
.664 .741 .908 r
.81199 .42897 .81607 .43447 .82574 .43149 .82168 .42597 Metetra
.664 .741 .908 r
.82168 .42597 .82574 .43149 .83544 .42851 .83141 .42297 Metetra
.664 .741 .908 r
.83141 .42297 .83544 .42851 .84517 .42551 .84116 .41995 Metetra
.664 .741 .908 r
.84116 .41995 .84517 .42551 .85494 .4225 .85095 .41693 Metetra
.664 .741 .908 r
.85095 .41693 .85494 .4225 .86473 .41949 .86077 .41389 Metetra
.664 .741 .908 r
.86077 .41389 .86473 .41949 .87456 .41646 .87062 .41084 Metetra
.664 .741 .908 r
.87062 .41084 .87456 .41646 .88443 .41342 .88051 .40779 Metetra
.664 .741 .908 r
.88051 .40779 .88443 .41342 .89432 .41037 .89043 .40472 Metetra
.664 .741 .908 r
.89043 .40472 .89432 .41037 .90425 .40732 .90038 .40164 Metetra
.664 .741 .908 r
.90038 .40164 .90425 .40732 .91421 .40425 .91037 .39856 Metetra
.664 .741 .908 r
.91037 .39856 .91421 .40425 .92421 .40117 .92039 .39546 Metetra
.664 .741 .908 r
.92039 .39546 .92421 .40117 .93424 .39808 .93045 .39235 Metetra
.664 .741 .908 r
.93045 .39235 .93424 .39808 .94431 .39498 .94054 .38923 Metetra
.664 .741 .908 r
.36056 .56222 .36563 .56694 .37388 .56439 .36883 .55966 Metetra
.664 .741 .908 r
.36883 .55966 .37388 .56439 .38216 .56183 .37712 .55709 Metetra
.664 .741 .908 r
.37712 .55709 .38216 .56183 .39046 .55926 .38544 .5545 Metetra
.664 .741 .908 r
.38544 .5545 .39046 .55926 .39879 .55669 .39379 .55192 Metetra
.664 .741 .908 r
.39379 .55192 .39879 .55669 .40714 .55411 .40216 .54932 Metetra
.664 .741 .908 r
.40216 .54932 .40714 .55411 .41552 .55152 .41055 .54671 Metetra
.664 .741 .908 r
.41055 .54671 .41552 .55152 .42393 .54892 .41898 .5441 Metetra
.664 .741 .908 r
.41898 .5441 .42393 .54892 .43236 .54631 .42743 .54148 Metetra
.664 .741 .908 r
.42743 .54148 .43236 .54631 .44082 .5437 .4359 .53885 Metetra
.664 .741 .908 r
.4359 .53885 .44082 .5437 .44931 .54107 .44441 .53621 Metetra
.664 .741 .908 r
.44441 .53621 .44931 .54107 .45782 .53844 .45293 .53356 Metetra
.664 .741 .908 r
.45293 .53356 .45782 .53844 .46636 .5358 .46149 .53091 Metetra
.664 .741 .908 r
.46149 .53091 .46636 .5358 .47492 .53316 .47007 .52825 Metetra
.664 .741 .908 r
.47007 .52825 .47492 .53316 .48352 .5305 .47868 .52557 Metetra
.664 .741 .908 r
.47868 .52557 .48352 .5305 .49214 .52784 .48732 .52289 Metetra
.664 .741 .908 r
.48732 .52289 .49214 .52784 .50078 .52516 .49599 .52021 Metetra
.664 .741 .908 r
.49599 .52021 .50078 .52516 .50946 .52248 .50468 .51751 Metetra
.664 .741 .908 r
.50468 .51751 .50946 .52248 .51816 .51979 .5134 .5148 Metetra
.664 .741 .908 r
.5134 .5148 .51816 .51979 .52689 .51709 .52215 .51209 Metetra
.664 .741 .908 r
.52215 .51209 .52689 .51709 .53565 .51439 .53092 .50937 Metetra
.664 .741 .908 r
.53092 .50937 .53565 .51439 .54443 .51167 .53973 .50663 Metetra
.664 .741 .908 r
.53973 .50663 .54443 .51167 .55325 .50895 .54856 .50389 Metetra
.664 .741 .908 r
.54856 .50389 .55325 .50895 .56209 .50621 .55742 .50114 Metetra
.664 .741 .908 r
.55742 .50114 .56209 .50621 .57096 .50347 .56631 .49839 Metetra
.664 .741 .908 r
.56631 .49839 .57096 .50347 .57986 .50072 .57523 .49562 Metetra
.664 .741 .908 r
.57523 .49562 .57986 .50072 .58878 .49796 .58417 .49284 Metetra
.664 .741 .908 r
.58417 .49284 .58878 .49796 .59774 .49519 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59774 .49519 .60673 .49241 .60215 .48726 Metetra
.664 .741 .908 r
.60215 .48726 .60673 .49241 .61574 .48963 .61119 .48446 Metetra
.664 .741 .908 r
.61119 .48446 .61574 .48963 .62478 .48683 .62025 .48165 Metetra
.664 .741 .908 r
.62025 .48165 .62478 .48683 .63386 .48403 .62934 .47883 Metetra
.664 .741 .908 r
.62934 .47883 .63386 .48403 .64296 .48122 .63846 .476 Metetra
.664 .741 .908 r
.63846 .476 .64296 .48122 .65209 .47839 .64761 .47316 Metetra
.664 .741 .908 r
.64761 .47316 .65209 .47839 .66125 .47556 .6568 .47031 Metetra
.664 .741 .908 r
.6568 .47031 .66125 .47556 .67044 .47272 .66601 .46745 Metetra
.664 .741 .908 r
.66601 .46745 .67044 .47272 .67966 .46987 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .67966 .46987 .68891 .46701 .68452 .46171 Metetra
.664 .741 .908 r
.68452 .46171 .68891 .46701 .69819 .46414 .69382 .45882 Metetra
.664 .741 .908 r
.69382 .45882 .69819 .46414 .70751 .46126 .70316 .45592 Metetra
.664 .741 .908 r
.70316 .45592 .70751 .46126 .71685 .45838 .71252 .45302 Metetra
.664 .741 .908 r
.71252 .45302 .71685 .45838 .72622 .45548 .72192 .4501 Metetra
.664 .741 .908 r
.72192 .4501 .72622 .45548 .73563 .45257 .73134 .44718 Metetra
.664 .741 .908 r
.73134 .44718 .73563 .45257 .74506 .44965 .7408 .44425 Metetra
.664 .741 .908 r
.7408 .44425 .74506 .44965 .75453 .44673 .75029 .4413 Metetra
.664 .741 .908 r
.75029 .4413 .75453 .44673 .76403 .44379 .75981 .43835 Metetra
.664 .741 .908 r
.75981 .43835 .76403 .44379 .77356 .44085 .76936 .43538 Metetra
.664 .741 .908 r
.76936 .43538 .77356 .44085 .78312 .43789 .77894 .43241 Metetra
.664 .741 .908 r
.77894 .43241 .78312 .43789 .79271 .43493 .78856 .42943 Metetra
.664 .741 .908 r
.78856 .42943 .79271 .43493 .80234 .43195 .79821 .42643 Metetra
.664 .741 .908 r
.79821 .42643 .80234 .43195 .81199 .42897 .80789 .42343 Metetra
.664 .741 .908 r
.80789 .42343 .81199 .42897 .82168 .42597 .8176 .42042 Metetra
.664 .741 .908 r
.8176 .42042 .82168 .42597 .83141 .42297 .82735 .41739 Metetra
.664 .741 .908 r
.82735 .41739 .83141 .42297 .84116 .41995 .83712 .41436 Metetra
.664 .741 .908 r
.83712 .41436 .84116 .41995 .85095 .41693 .84693 .41131 Metetra
.664 .741 .908 r
.84693 .41131 .85095 .41693 .86077 .41389 .85678 .40826 Metetra
.664 .741 .908 r
.85678 .40826 .86077 .41389 .87062 .41084 .86666 .40519 Metetra
.664 .741 .908 r
.86666 .40519 .87062 .41084 .88051 .40779 .87657 .40212 Metetra
.664 .741 .908 r
.87657 .40212 .88051 .40779 .89043 .40472 .88651 .39903 Metetra
.664 .741 .908 r
.88651 .39903 .89043 .40472 .90038 .40164 .89649 .39594 Metetra
.664 .741 .908 r
.89649 .39594 .90038 .40164 .91037 .39856 .90651 .39283 Metetra
.664 .741 .908 r
.90651 .39283 .91037 .39856 .92039 .39546 .91655 .38971 Metetra
.664 .741 .908 r
.91655 .38971 .92039 .39546 .93045 .39235 .92663 .38658 Metetra
.664 .741 .908 r
.92663 .38658 .93045 .39235 .94054 .38923 .93675 .38345 Metetra
.664 .741 .908 r
.35547 .55748 .36056 .56222 .36883 .55966 .36375 .5549 Metetra
.664 .741 .908 r
.36375 .5549 .36883 .55966 .37712 .55709 .37206 .55231 Metetra
.664 .741 .908 r
.37206 .55231 .37712 .55709 .38544 .5545 .3804 .54972 Metetra
.664 .741 .908 r
.3804 .54972 .38544 .5545 .39379 .55192 .38876 .54711 Metetra
.664 .741 .908 r
.38876 .54711 .39379 .55192 .40216 .54932 .39715 .5445 Metetra
.664 .741 .908 r
.39715 .5445 .40216 .54932 .41055 .54671 .40556 .54188 Metetra
.664 .741 .908 r
.40556 .54188 .41055 .54671 .41898 .5441 .414 .53925 Metetra
.664 .741 .908 r
.414 .53925 .41898 .5441 .42743 .54148 .42246 .53662 Metetra
.664 .741 .908 r
.42246 .53662 .42743 .54148 .4359 .53885 .43096 .53397 Metetra
.664 .741 .908 r
.43096 .53397 .4359 .53885 .44441 .53621 .43948 .53132 Metetra
.664 .741 .908 r
.43948 .53132 .44441 .53621 .45293 .53356 .44802 .52866 Metetra
.664 .741 .908 r
.44802 .52866 .45293 .53356 .46149 .53091 .4566 .52599 Metetra
.664 .741 .908 r
.4566 .52599 .46149 .53091 .47007 .52825 .4652 .52331 Metetra
.664 .741 .908 r
.4652 .52331 .47007 .52825 .47868 .52557 .47382 .52062 Metetra
.664 .741 .908 r
.47382 .52062 .47868 .52557 .48732 .52289 .48248 .51792 Metetra
.664 .741 .908 r
.48248 .51792 .48732 .52289 .49599 .52021 .49116 .51522 Metetra
.664 .741 .908 r
.49116 .51522 .49599 .52021 .50468 .51751 .49987 .51251 Metetra
.664 .741 .908 r
.49987 .51251 .50468 .51751 .5134 .5148 .50861 .50978 Metetra
.664 .741 .908 r
.50861 .50978 .5134 .5148 .52215 .51209 .51738 .50705 Metetra
.664 .741 .908 r
.51738 .50705 .52215 .51209 .53092 .50937 .52617 .50432 Metetra
.664 .741 .908 r
.52617 .50432 .53092 .50937 .53973 .50663 .53499 .50157 Metetra
.664 .741 .908 r
.53499 .50157 .53973 .50663 .54856 .50389 .54384 .49881 Metetra
.664 .741 .908 r
.54384 .49881 .54856 .50389 .55742 .50114 .55272 .49604 Metetra
.664 .741 .908 r
.55272 .49604 .55742 .50114 .56631 .49839 .56163 .49327 Metetra
.664 .741 .908 r
.56163 .49327 .56631 .49839 .57523 .49562 .57057 .49049 Metetra
.664 .741 .908 r
.57057 .49049 .57523 .49562 .58417 .49284 .57953 .48769 Metetra
.664 .741 .908 r
.57953 .48769 .58417 .49284 .59315 .49006 .58853 .48489 Metetra
.664 .741 .908 r
.58853 .48489 .59315 .49006 .60215 .48726 .59755 .48208 Metetra
.664 .741 .908 r
.59755 .48208 .60215 .48726 .61119 .48446 .60661 .47926 Metetra
.664 .741 .908 r
.60661 .47926 .61119 .48446 .62025 .48165 .61569 .47643 Metetra
.664 .741 .908 r
.61569 .47643 .62025 .48165 .62934 .47883 .6248 .4736 Metetra
.664 .741 .908 r
.6248 .4736 .62934 .47883 .63846 .476 .63394 .47075 Metetra
.664 .741 .908 r
.63394 .47075 .63846 .476 .64761 .47316 .64311 .46789 Metetra
.664 .741 .908 r
.64311 .46789 .64761 .47316 .6568 .47031 .65232 .46503 Metetra
.664 .741 .908 r
.65232 .46503 .6568 .47031 .66601 .46745 .66155 .46215 Metetra
.664 .741 .908 r
.66155 .46215 .66601 .46745 .67525 .46458 .67081 .45927 Metetra
.664 .741 .908 r
.67081 .45927 .67525 .46458 .68452 .46171 .6801 .45637 Metetra
.664 .741 .908 r
.6801 .45637 .68452 .46171 .69382 .45882 .68943 .45347 Metetra
.664 .741 .908 r
.68943 .45347 .69382 .45882 .70316 .45592 .69878 .45055 Metetra
.664 .741 .908 r
.69878 .45055 .70316 .45592 .71252 .45302 .70817 .44763 Metetra
.664 .741 .908 r
.70817 .44763 .71252 .45302 .72192 .4501 .71758 .4447 Metetra
.664 .741 .908 r
.71758 .4447 .72192 .4501 .73134 .44718 .72703 .44175 Metetra
.664 .741 .908 r
.72703 .44175 .73134 .44718 .7408 .44425 .73651 .4388 Metetra
.664 .741 .908 r
.73651 .4388 .7408 .44425 .75029 .4413 .74602 .43584 Metetra
.664 .741 .908 r
.74602 .43584 .75029 .4413 .75981 .43835 .75556 .43287 Metetra
.664 .741 .908 r
.75556 .43287 .75981 .43835 .76936 .43538 .76514 .42989 Metetra
.664 .741 .908 r
.76514 .42989 .76936 .43538 .77894 .43241 .77474 .42689 Metetra
.664 .741 .908 r
.77474 .42689 .77894 .43241 .78856 .42943 .78438 .42389 Metetra
.664 .741 .908 r
.78438 .42389 .78856 .42943 .79821 .42643 .79405 .42088 Metetra
.664 .741 .908 r
.79405 .42088 .79821 .42643 .80789 .42343 .80375 .41786 Metetra
.664 .741 .908 r
.80375 .41786 .80789 .42343 .8176 .42042 .81349 .41482 Metetra
.664 .741 .908 r
.81349 .41482 .8176 .42042 .82735 .41739 .82326 .41178 Metetra
.664 .741 .908 r
.82326 .41178 .82735 .41739 .83712 .41436 .83306 .40873 Metetra
.664 .741 .908 r
.83306 .40873 .83712 .41436 .84693 .41131 .8429 .40567 Metetra
.664 .741 .908 r
.8429 .40567 .84693 .41131 .85678 .40826 .85277 .40259 Metetra
.664 .741 .908 r
.85277 .40259 .85678 .40826 .86666 .40519 .86267 .39951 Metetra
.664 .741 .908 r
.86267 .39951 .86666 .40519 .87657 .40212 .8726 .39641 Metetra
.664 .741 .908 r
.8726 .39641 .87657 .40212 .88651 .39903 .88257 .39331 Metetra
.664 .741 .908 r
.88257 .39331 .88651 .39903 .89649 .39594 .89258 .39019 Metetra
.664 .741 .908 r
.89258 .39019 .89649 .39594 .90651 .39283 .90261 .38707 Metetra
.664 .741 .908 r
.90261 .38707 .90651 .39283 .91655 .38971 .91269 .38393 Metetra
.664 .741 .908 r
.91269 .38393 .91655 .38971 .92663 .38658 .92279 .38078 Metetra
.664 .741 .908 r
.92279 .38078 .92663 .38658 .93675 .38345 .93294 .37762 Metetra
.664 .741 .908 r
.35035 .55271 .35547 .55748 .36375 .5549 .35865 .55012 Metetra
.664 .741 .908 r
.35865 .55012 .36375 .5549 .37206 .55231 .36697 .54752 Metetra
.664 .741 .908 r
.36697 .54752 .37206 .55231 .3804 .54972 .37532 .5449 Metetra
.664 .741 .908 r
.37532 .5449 .3804 .54972 .38876 .54711 .3837 .54229 Metetra
.664 .741 .908 r
.3837 .54229 .38876 .54711 .39715 .5445 .3921 .53966 Metetra
.664 .741 .908 r
.3921 .53966 .39715 .5445 .40556 .54188 .40053 .53702 Metetra
.664 .741 .908 r
.40053 .53702 .40556 .54188 .414 .53925 .40899 .53438 Metetra
.664 .741 .908 r
.40899 .53438 .414 .53925 .42246 .53662 .41747 .53173 Metetra
.664 .741 .908 r
.41747 .53173 .42246 .53662 .43096 .53397 .42598 .52907 Metetra
.664 .741 .908 r
.42598 .52907 .43096 .53397 .43948 .53132 .43452 .5264 Metetra
.664 .741 .908 r
.43452 .5264 .43948 .53132 .44802 .52866 .44308 .52372 Metetra
.664 .741 .908 r
.44308 .52372 .44802 .52866 .4566 .52599 .45167 .52103 Metetra
.664 .741 .908 r
.45167 .52103 .4566 .52599 .4652 .52331 .46029 .51834 Metetra
.664 .741 .908 r
.46029 .51834 .4652 .52331 .47382 .52062 .46894 .51564 Metetra
.664 .741 .908 r
.46894 .51564 .47382 .52062 .48248 .51792 .47761 .51292 Metetra
.664 .741 .908 r
.47761 .51292 .48248 .51792 .49116 .51522 .48631 .5102 Metetra
.664 .741 .908 r
.48631 .5102 .49116 .51522 .49987 .51251 .49504 .50747 Metetra
.664 .741 .908 r
.49504 .50747 .49987 .51251 .50861 .50978 .50379 .50474 Metetra
.664 .741 .908 r
.50379 .50474 .50861 .50978 .51738 .50705 .51258 .50199 Metetra
.664 .741 .908 r
.51258 .50199 .51738 .50705 .52617 .50432 .52139 .49924 Metetra
.664 .741 .908 r
.52139 .49924 .52617 .50432 .53499 .50157 .53023 .49647 Metetra
.664 .741 .908 r
.53023 .49647 .53499 .50157 .54384 .49881 .5391 .4937 Metetra
.664 .741 .908 r
.5391 .4937 .54384 .49881 .55272 .49604 .548 .49092 Metetra
.664 .741 .908 r
.548 .49092 .55272 .49604 .56163 .49327 .55693 .48812 Metetra
.664 .741 .908 r
.55693 .48812 .56163 .49327 .57057 .49049 .56588 .48532 Metetra
.664 .741 .908 r
.56588 .48532 .57057 .49049 .57953 .48769 .57487 .48252 Metetra
.664 .741 .908 r
.57487 .48252 .57953 .48769 .58853 .48489 .58388 .4797 Metetra
.664 .741 .908 r
.58388 .4797 .58853 .48489 .59755 .48208 .59292 .47687 Metetra
.664 .741 .908 r
.59292 .47687 .59755 .48208 .60661 .47926 .602 .47403 Metetra
.664 .741 .908 r
.602 .47403 .60661 .47926 .61569 .47643 .6111 .47119 Metetra
.664 .741 .908 r
.6111 .47119 .61569 .47643 .6248 .4736 .62023 .46833 Metetra
.664 .741 .908 r
.62023 .46833 .6248 .4736 .63394 .47075 .62939 .46547 Metetra
.664 .741 .908 r
.62939 .46547 .63394 .47075 .64311 .46789 .63859 .46259 Metetra
.664 .741 .908 r
.63859 .46259 .64311 .46789 .65232 .46503 .64781 .45971 Metetra
.664 .741 .908 r
.64781 .45971 .65232 .46503 .66155 .46215 .65706 .45682 Metetra
.664 .741 .908 r
.65706 .45682 .66155 .46215 .67081 .45927 .66634 .45391 Metetra
.664 .741 .908 r
.66634 .45391 .67081 .45927 .6801 .45637 .67566 .451 Metetra
.664 .741 .908 r
.67566 .451 .6801 .45637 .68943 .45347 .685 .44808 Metetra
.664 .741 .908 r
.685 .44808 .68943 .45347 .69878 .45055 .69438 .44515 Metetra
.664 .741 .908 r
.69438 .44515 .69878 .45055 .70817 .44763 .70378 .44221 Metetra
.664 .741 .908 r
.70378 .44221 .70817 .44763 .71758 .4447 .71322 .43926 Metetra
.664 .741 .908 r
.71322 .43926 .71758 .4447 .72703 .44175 .72269 .4363 Metetra
.664 .741 .908 r
.72269 .4363 .72703 .44175 .73651 .4388 .73219 .43333 Metetra
.664 .741 .908 r
.73219 .43333 .73651 .4388 .74602 .43584 .74173 .43035 Metetra
.664 .741 .908 r
.74173 .43035 .74602 .43584 .75556 .43287 .75129 .42735 Metetra
.664 .741 .908 r
.75129 .42735 .75556 .43287 .76514 .42989 .76089 .42435 Metetra
.664 .741 .908 r
.76089 .42435 .76514 .42989 .77474 .42689 .77052 .42134 Metetra
.664 .741 .908 r
.77052 .42134 .77474 .42689 .78438 .42389 .78018 .41832 Metetra
.664 .741 .908 r
.78018 .41832 .78438 .42389 .79405 .42088 .78987 .41529 Metetra
.664 .741 .908 r
.78987 .41529 .79405 .42088 .80375 .41786 .7996 .41225 Metetra
.664 .741 .908 r
.7996 .41225 .80375 .41786 .81349 .41482 .80936 .4092 Metetra
.664 .741 .908 r
.80936 .4092 .81349 .41482 .82326 .41178 .81915 .40614 Metetra
.664 .741 .908 r
.81915 .40614 .82326 .41178 .83306 .40873 .82897 .40307 Metetra
.664 .741 .908 r
.82897 .40307 .83306 .40873 .8429 .40567 .83883 .39998 Metetra
.664 .741 .908 r
.83883 .39998 .8429 .40567 .85277 .40259 .84873 .39689 Metetra
.664 .741 .908 r
.84873 .39689 .85277 .40259 .86267 .39951 .85865 .39379 Metetra
.664 .741 .908 r
.85865 .39379 .86267 .39951 .8726 .39641 .86861 .39067 Metetra
.664 .741 .908 r
.86861 .39067 .8726 .39641 .88257 .39331 .87861 .38755 Metetra
.664 .741 .908 r
.87861 .38755 .88257 .39331 .89258 .39019 .88864 .38441 Metetra
.664 .741 .908 r
.88864 .38441 .89258 .39019 .90261 .38707 .8987 .38127 Metetra
.664 .741 .908 r
.8987 .38127 .90261 .38707 .91269 .38393 .9088 .37811 Metetra
.664 .741 .908 r
.9088 .37811 .91269 .38393 .92279 .38078 .91893 .37494 Metetra
.664 .741 .908 r
.91893 .37494 .92279 .38078 .93294 .37762 .9291 .37176 Metetra
.664 .741 .908 r
.3452 .54792 .35035 .55271 .35865 .55012 .35351 .54531 Metetra
.664 .741 .908 r
.35351 .54531 .35865 .55012 .36697 .54752 .36185 .54269 Metetra
.664 .741 .908 r
.36185 .54269 .36697 .54752 .37532 .5449 .37022 .54006 Metetra
.664 .741 .908 r
.37022 .54006 .37532 .5449 .3837 .54229 .37861 .53743 Metetra
.664 .741 .908 r
.37861 .53743 .3837 .54229 .3921 .53966 .38703 .53479 Metetra
.664 .741 .908 r
.38703 .53479 .3921 .53966 .40053 .53702 .39548 .53214 Metetra
.664 .741 .908 r
.39548 .53214 .40053 .53702 .40899 .53438 .40395 .52948 Metetra
.664 .741 .908 r
.40395 .52948 .40899 .53438 .41747 .53173 .41245 .52681 Metetra
.664 .741 .908 r
.41245 .52681 .41747 .53173 .42598 .52907 .42098 .52413 Metetra
.664 .741 .908 r
.42098 .52413 .42598 .52907 .43452 .5264 .42953 .52145 Metetra
.664 .741 .908 r
.42953 .52145 .43452 .5264 .44308 .52372 .43811 .51875 Metetra
.664 .741 .908 r
.43811 .51875 .44308 .52372 .45167 .52103 .44672 .51605 Metetra
.664 .741 .908 r
.44672 .51605 .45167 .52103 .46029 .51834 .45536 .51334 Metetra
.664 .741 .908 r
.45536 .51334 .46029 .51834 .46894 .51564 .46402 .51062 Metetra
.664 .741 .908 r
.46402 .51062 .46894 .51564 .47761 .51292 .47271 .5079 Metetra
.664 .741 .908 r
.47271 .5079 .47761 .51292 .48631 .5102 .48143 .50516 Metetra
.664 .741 .908 r
.48143 .50516 .48631 .5102 .49504 .50747 .49017 .50241 Metetra
.664 .741 .908 r
.49017 .50241 .49504 .50747 .50379 .50474 .49895 .49966 Metetra
.664 .741 .908 r
.49895 .49966 .50379 .50474 .51258 .50199 .50775 .4969 Metetra
.664 .741 .908 r
.50775 .4969 .51258 .50199 .52139 .49924 .51658 .49413 Metetra
.664 .741 .908 r
.51658 .49413 .52139 .49924 .53023 .49647 .52544 .49134 Metetra
.664 .741 .908 r
.52544 .49134 .53023 .49647 .5391 .4937 .53433 .48855 Metetra
.664 .741 .908 r
.53433 .48855 .5391 .4937 .548 .49092 .54325 .48576 Metetra
.664 .741 .908 r
.54325 .48576 .548 .49092 .55693 .48812 .55219 .48295 Metetra
.664 .741 .908 r
.55219 .48295 .55693 .48812 .56588 .48532 .56117 .48013 Metetra
.664 .741 .908 r
.56117 .48013 .56588 .48532 .57487 .48252 .57017 .47731 Metetra
.664 .741 .908 r
.57017 .47731 .57487 .48252 .58388 .4797 .5792 .47447 Metetra
.664 .741 .908 r
.5792 .47447 .58388 .4797 .59292 .47687 .58827 .47163 Metetra
.664 .741 .908 r
.58827 .47163 .59292 .47687 .602 .47403 .59736 .46877 Metetra
.664 .741 .908 r
.59736 .46877 .602 .47403 .6111 .47119 .60648 .46591 Metetra
.664 .741 .908 r
.60648 .46591 .6111 .47119 .62023 .46833 .61563 .46304 Metetra
.664 .741 .908 r
.61563 .46304 .62023 .46833 .62939 .46547 .62482 .46015 Metetra
.664 .741 .908 r
.62482 .46015 .62939 .46547 .63859 .46259 .63403 .45726 Metetra
.664 .741 .908 r
.63403 .45726 .63859 .46259 .64781 .45971 .64327 .45436 Metetra
.664 .741 .908 r
.64327 .45436 .64781 .45971 .65706 .45682 .65255 .45145 Metetra
.664 .741 .908 r
.65255 .45145 .65706 .45682 .66634 .45391 .66185 .44853 Metetra
.664 .741 .908 r
.66185 .44853 .66634 .45391 .67566 .451 .67118 .4456 Metetra
.664 .741 .908 r
.67118 .4456 .67566 .451 .685 .44808 .68055 .44266 Metetra
.664 .741 .908 r
.68055 .44266 .685 .44808 .69438 .44515 .68995 .43971 Metetra
.664 .741 .908 r
.68995 .43971 .69438 .44515 .70378 .44221 .69938 .43675 Metetra
.664 .741 .908 r
.69938 .43675 .70378 .44221 .71322 .43926 .70884 .43378 Metetra
.664 .741 .908 r
.70884 .43378 .71322 .43926 .72269 .4363 .71833 .4308 Metetra
.664 .741 .908 r
.71833 .4308 .72269 .4363 .73219 .43333 .72785 .42782 Metetra
.664 .741 .908 r
.72785 .42782 .73219 .43333 .74173 .43035 .7374 .42482 Metetra
.664 .741 .908 r
.7374 .42482 .74173 .43035 .75129 .42735 .74699 .42181 Metetra
.664 .741 .908 r
.74699 .42181 .75129 .42735 .76089 .42435 .75661 .41879 Metetra
.664 .741 .908 r
.75661 .41879 .76089 .42435 .77052 .42134 .76626 .41576 Metetra
.664 .741 .908 r
.76626 .41576 .77052 .42134 .78018 .41832 .77595 .41272 Metetra
.664 .741 .908 r
.77595 .41272 .78018 .41832 .78987 .41529 .78566 .40967 Metetra
.664 .741 .908 r
.78566 .40967 .78987 .41529 .7996 .41225 .79541 .40661 Metetra
.664 .741 .908 r
.79541 .40661 .7996 .41225 .80936 .4092 .8052 .40354 Metetra
.664 .741 .908 r
.8052 .40354 .80936 .4092 .81915 .40614 .81501 .40046 Metetra
.664 .741 .908 r
.81501 .40046 .81915 .40614 .82897 .40307 .82486 .39737 Metetra
.664 .741 .908 r
.82486 .39737 .82897 .40307 .83883 .39998 .83474 .39426 Metetra
.664 .741 .908 r
.83474 .39426 .83883 .39998 .84873 .39689 .84466 .39115 Metetra
.664 .741 .908 r
.84466 .39115 .84873 .39689 .85865 .39379 .85461 .38803 Metetra
.664 .741 .908 r
.85461 .38803 .85865 .39379 .86861 .39067 .8646 .3849 Metetra
.664 .741 .908 r
.8646 .3849 .86861 .39067 .87861 .38755 .87462 .38175 Metetra
.664 .741 .908 r
.87462 .38175 .87861 .38755 .88864 .38441 .88467 .3786 Metetra
.664 .741 .908 r
.88467 .3786 .88864 .38441 .8987 .38127 .89476 .37543 Metetra
.664 .741 .908 r
.89476 .37543 .8987 .38127 .9088 .37811 .90488 .37225 Metetra
.664 .741 .908 r
.90488 .37225 .9088 .37811 .91893 .37494 .91504 .36906 Metetra
.664 .741 .908 r
.91504 .36906 .91893 .37494 .9291 .37176 .92523 .36586 Metetra
.664 .741 .908 r
.34002 .54309 .3452 .54792 .35351 .54531 .34835 .54047 Metetra
.664 .741 .908 r
.34835 .54047 .35351 .54531 .36185 .54269 .3567 .53783 Metetra
.664 .741 .908 r
.3567 .53783 .36185 .54269 .37022 .54006 .36509 .53519 Metetra
.664 .741 .908 r
.36509 .53519 .37022 .54006 .37861 .53743 .3735 .53254 Metetra
.664 .741 .908 r
.3735 .53254 .37861 .53743 .38703 .53479 .38193 .52989 Metetra
.664 .741 .908 r
.38193 .52989 .38703 .53479 .39548 .53214 .3904 .52722 Metetra
.664 .741 .908 r
.3904 .52722 .39548 .53214 .40395 .52948 .39888 .52454 Metetra
.664 .741 .908 r
.39888 .52454 .40395 .52948 .41245 .52681 .4074 .52186 Metetra
.664 .741 .908 r
.4074 .52186 .41245 .52681 .42098 .52413 .41594 .51917 Metetra
.664 .741 .908 r
.41594 .51917 .42098 .52413 .42953 .52145 .42452 .51647 Metetra
.664 .741 .908 r
.42452 .51647 .42953 .52145 .43811 .51875 .43311 .51376 Metetra
.664 .741 .908 r
.43311 .51376 .43811 .51875 .44672 .51605 .44174 .51104 Metetra
.664 .741 .908 r
.44174 .51104 .44672 .51605 .45536 .51334 .45039 .50832 Metetra
.664 .741 .908 r
.45039 .50832 .45536 .51334 .46402 .51062 .45907 .50558 Metetra
.664 .741 .908 r
.45907 .50558 .46402 .51062 .47271 .5079 .46778 .50284 Metetra
.664 .741 .908 r
.46778 .50284 .47271 .5079 .48143 .50516 .47652 .50008 Metetra
.664 .741 .908 r
.47652 .50008 .48143 .50516 .49017 .50241 .48528 .49732 Metetra
.664 .741 .908 r
.48528 .49732 .49017 .50241 .49895 .49966 .49407 .49455 Metetra
.664 .741 .908 r
.49407 .49455 .49895 .49966 .50775 .4969 .50289 .49177 Metetra
.664 .741 .908 r
.50289 .49177 .50775 .4969 .51658 .49413 .51174 .48898 Metetra
.664 .741 .908 r
.51174 .48898 .51658 .49413 .52544 .49134 .52062 .48619 Metetra
.664 .741 .908 r
.52062 .48619 .52544 .49134 .53433 .48855 .52953 .48338 Metetra
.664 .741 .908 r
.52953 .48338 .53433 .48855 .54325 .48576 .53847 .48057 Metetra
.664 .741 .908 r
.53847 .48057 .54325 .48576 .55219 .48295 .54743 .47774 Metetra
.664 .741 .908 r
.54743 .47774 .55219 .48295 .56117 .48013 .55642 .47491 Metetra
.664 .741 .908 r
.55642 .47491 .56117 .48013 .57017 .47731 .56545 .47206 Metetra
.664 .741 .908 r
.56545 .47206 .57017 .47731 .5792 .47447 .5745 .46921 Metetra
.664 .741 .908 r
.5745 .46921 .5792 .47447 .58827 .47163 .58358 .46635 Metetra
.664 .741 .908 r
.58358 .46635 .58827 .47163 .59736 .46877 .5927 .46348 Metetra
.664 .741 .908 r
.5927 .46348 .59736 .46877 .60648 .46591 .60184 .4606 Metetra
.664 .741 .908 r
.60184 .4606 .60648 .46591 .61563 .46304 .61101 .45771 Metetra
.664 .741 .908 r
.61101 .45771 .61563 .46304 .62482 .46015 .62021 .45481 Metetra
.664 .741 .908 r
.62021 .45481 .62482 .46015 .63403 .45726 .62945 .4519 Metetra
.664 .741 .908 r
.62945 .4519 .63403 .45726 .64327 .45436 .63871 .44898 Metetra
.664 .741 .908 r
.63871 .44898 .64327 .45436 .65255 .45145 .648 .44605 Metetra
.664 .741 .908 r
.648 .44605 .65255 .45145 .66185 .44853 .65733 .44311 Metetra
.664 .741 .908 r
.65733 .44311 .66185 .44853 .67118 .4456 .66668 .44017 Metetra
.664 .741 .908 r
.66668 .44017 .67118 .4456 .68055 .44266 .67607 .43721 Metetra
.664 .741 .908 r
.67607 .43721 .68055 .44266 .68995 .43971 .68549 .43424 Metetra
.664 .741 .908 r
.68549 .43424 .68995 .43971 .69938 .43675 .69494 .43126 Metetra
.664 .741 .908 r
.69494 .43126 .69938 .43675 .70884 .43378 .70442 .42828 Metetra
.664 .741 .908 r
.70442 .42828 .70884 .43378 .71833 .4308 .71393 .42528 Metetra
.664 .741 .908 r
.71393 .42528 .71833 .4308 .72785 .42782 .72348 .42227 Metetra
.664 .741 .908 r
.72348 .42227 .72785 .42782 .7374 .42482 .73306 .41925 Metetra
.664 .741 .908 r
.73306 .41925 .7374 .42482 .74699 .42181 .74267 .41623 Metetra
.664 .741 .908 r
.74267 .41623 .74699 .42181 .75661 .41879 .75231 .41319 Metetra
.664 .741 .908 r
.75231 .41319 .75661 .41879 .76626 .41576 .76198 .41014 Metetra
.664 .741 .908 r
.76198 .41014 .76626 .41576 .77595 .41272 .77169 .40708 Metetra
.664 .741 .908 r
.77169 .40708 .77595 .41272 .78566 .40967 .78143 .40401 Metetra
.664 .741 .908 r
.78143 .40401 .78566 .40967 .79541 .40661 .7912 .40093 Metetra
.664 .741 .908 r
.7912 .40093 .79541 .40661 .8052 .40354 .80101 .39784 Metetra
.664 .741 .908 r
.80101 .39784 .8052 .40354 .81501 .40046 .81085 .39474 Metetra
.664 .741 .908 r
.81085 .39474 .81501 .40046 .82486 .39737 .82072 .39163 Metetra
.664 .741 .908 r
.82072 .39163 .82486 .39737 .83474 .39426 .83063 .38851 Metetra
.664 .741 .908 r
.83063 .38851 .83474 .39426 .84466 .39115 .84057 .38538 Metetra
.664 .741 .908 r
.84057 .38538 .84466 .39115 .85461 .38803 .85055 .38224 Metetra
.664 .741 .908 r
.85055 .38224 .85461 .38803 .8646 .3849 .86056 .37908 Metetra
.664 .741 .908 r
.86056 .37908 .8646 .3849 .87462 .38175 .8706 .37592 Metetra
.664 .741 .908 r
.8706 .37592 .87462 .38175 .88467 .3786 .88068 .37274 Metetra
.664 .741 .908 r
.88068 .37274 .88467 .3786 .89476 .37543 .89079 .36955 Metetra
.664 .741 .908 r
.89079 .36955 .89476 .37543 .90488 .37225 .90094 .36636 Metetra
.664 .741 .908 r
.90094 .36636 .90488 .37225 .91504 .36906 .91112 .36315 Metetra
.664 .741 .908 r
.91112 .36315 .91504 .36906 .92523 .36586 .92134 .35993 Metetra
.664 .741 .908 r
.33481 .53824 .34002 .54309 .34835 .54047 .34315 .5356 Metetra
.664 .741 .908 r
.34315 .5356 .34835 .54047 .3567 .53783 .35152 .53295 Metetra
.664 .741 .908 r
.35152 .53295 .3567 .53783 .36509 .53519 .35992 .53029 Metetra
.664 .741 .908 r
.35992 .53029 .36509 .53519 .3735 .53254 .36835 .52763 Metetra
.664 .741 .908 r
.36835 .52763 .3735 .53254 .38193 .52989 .3768 .52496 Metetra
.664 .741 .908 r
.3768 .52496 .38193 .52989 .3904 .52722 .38528 .52227 Metetra
.664 .741 .908 r
.38528 .52227 .3904 .52722 .39888 .52454 .39379 .51958 Metetra
.664 .741 .908 r
.39379 .51958 .39888 .52454 .4074 .52186 .40232 .51688 Metetra
.664 .741 .908 r
.40232 .51688 .4074 .52186 .41594 .51917 .41088 .51418 Metetra
.664 .741 .908 r
.41088 .51418 .41594 .51917 .42452 .51647 .41947 .51146 Metetra
.664 .741 .908 r
.41947 .51146 .42452 .51647 .43311 .51376 .42808 .50874 Metetra
.664 .741 .908 r
.42808 .50874 .43311 .51376 .44174 .51104 .43673 .506 Metetra
.664 .741 .908 r
.43673 .506 .44174 .51104 .45039 .50832 .4454 .50326 Metetra
.664 .741 .908 r
.4454 .50326 .45039 .50832 .45907 .50558 .4541 .50051 Metetra
.664 .741 .908 r
.4541 .50051 .45907 .50558 .46778 .50284 .46282 .49775 Metetra
.664 .741 .908 r
.46282 .49775 .46778 .50284 .47652 .50008 .47158 .49498 Metetra
.664 .741 .908 r
.47158 .49498 .47652 .50008 .48528 .49732 .48036 .4922 Metetra
.664 .741 .908 r
.48036 .4922 .48528 .49732 .49407 .49455 .48917 .48941 Metetra
.664 .741 .908 r
.48917 .48941 .49407 .49455 .50289 .49177 .49801 .48662 Metetra
.664 .741 .908 r
.49801 .48662 .50289 .49177 .51174 .48898 .50688 .48381 Metetra
.664 .741 .908 r
.50688 .48381 .51174 .48898 .52062 .48619 .51577 .481 Metetra
.664 .741 .908 r
.51577 .481 .52062 .48619 .52953 .48338 .5247 .47818 Metetra
.664 .741 .908 r
.5247 .47818 .52953 .48338 .53847 .48057 .53366 .47534 Metetra
.664 .741 .908 r
.53366 .47534 .53847 .48057 .54743 .47774 .54264 .4725 Metetra
.664 .741 .908 r
.54264 .4725 .54743 .47774 .55642 .47491 .55165 .46965 Metetra
.664 .741 .908 r
.55165 .46965 .55642 .47491 .56545 .47206 .5607 .46679 Metetra
.664 .741 .908 r
.5607 .46679 .56545 .47206 .5745 .46921 .56977 .46392 Metetra
.664 .741 .908 r
.56977 .46392 .5745 .46921 .58358 .46635 .57887 .46104 Metetra
.664 .741 .908 r
.57887 .46104 .58358 .46635 .5927 .46348 .588 .45815 Metetra
.664 .741 .908 r
.588 .45815 .5927 .46348 .60184 .4606 .59717 .45526 Metetra
.664 .741 .908 r
.59717 .45526 .60184 .4606 .61101 .45771 .60636 .45235 Metetra
.664 .741 .908 r
.60636 .45235 .61101 .45771 .62021 .45481 .61558 .44943 Metetra
.664 .741 .908 r
.61558 .44943 .62021 .45481 .62945 .4519 .62483 .4465 Metetra
.664 .741 .908 r
.62483 .4465 .62945 .4519 .63871 .44898 .63412 .44357 Metetra
.664 .741 .908 r
.63412 .44357 .63871 .44898 .648 .44605 .64343 .44062 Metetra
.664 .741 .908 r
.64343 .44062 .648 .44605 .65733 .44311 .65278 .43766 Metetra
.664 .741 .908 r
.65278 .43766 .65733 .44311 .66668 .44017 .66216 .4347 Metetra
.664 .741 .908 r
.66216 .4347 .66668 .44017 .67607 .43721 .67157 .43172 Metetra
.664 .741 .908 r
.67157 .43172 .67607 .43721 .68549 .43424 .68101 .42874 Metetra
.664 .741 .908 r
.68101 .42874 .68549 .43424 .69494 .43126 .69048 .42574 Metetra
.664 .741 .908 r
.69048 .42574 .69494 .43126 .70442 .42828 .69998 .42273 Metetra
.664 .741 .908 r
.69998 .42273 .70442 .42828 .71393 .42528 .70952 .41972 Metetra
.664 .741 .908 r
.70952 .41972 .71393 .42528 .72348 .42227 .71908 .41669 Metetra
.664 .741 .908 r
.71908 .41669 .72348 .42227 .73306 .41925 .72868 .41366 Metetra
.664 .741 .908 r
.72868 .41366 .73306 .41925 .74267 .41623 .73831 .41061 Metetra
.664 .741 .908 r
.73831 .41061 .74267 .41623 .75231 .41319 .74798 .40755 Metetra
.664 .741 .908 r
.74798 .40755 .75231 .41319 .76198 .41014 .75768 .40449 Metetra
.664 .741 .908 r
.75768 .40449 .76198 .41014 .77169 .40708 .76741 .40141 Metetra
.664 .741 .908 r
.76741 .40141 .77169 .40708 .78143 .40401 .77717 .39832 Metetra
.664 .741 .908 r
.77717 .39832 .78143 .40401 .7912 .40093 .78697 .39522 Metetra
.664 .741 .908 r
.78697 .39522 .7912 .40093 .80101 .39784 .7968 .39211 Metetra
.664 .741 .908 r
.7968 .39211 .80101 .39784 .81085 .39474 .80666 .38899 Metetra
.664 .741 .908 r
.80666 .38899 .81085 .39474 .82072 .39163 .81656 .38586 Metetra
.664 .741 .908 r
.81656 .38586 .82072 .39163 .83063 .38851 .82649 .38272 Metetra
.664 .741 .908 r
.82649 .38272 .83063 .38851 .84057 .38538 .83646 .37957 Metetra
.664 .741 .908 r
.83646 .37957 .84057 .38538 .85055 .38224 .84645 .3764 Metetra
.664 .741 .908 r
.84645 .3764 .85055 .38224 .86056 .37908 .85649 .37323 Metetra
.664 .741 .908 r
.85649 .37323 .86056 .37908 .8706 .37592 .86656 .37005 Metetra
.664 .741 .908 r
.86656 .37005 .8706 .37592 .88068 .37274 .87666 .36685 Metetra
.664 .741 .908 r
.87666 .36685 .88068 .37274 .89079 .36955 .8868 .36364 Metetra
.664 .741 .908 r
.8868 .36364 .89079 .36955 .90094 .36636 .89697 .36042 Metetra
.664 .741 .908 r
.89697 .36042 .90094 .36636 .91112 .36315 .90718 .3572 Metetra
.664 .741 .908 r
.90718 .3572 .91112 .36315 .92134 .35993 .91743 .35396 Metetra
.664 .741 .908 r
.32956 .53336 .33481 .53824 .34315 .5356 .33793 .5307 Metetra
.664 .741 .908 r
.33793 .5307 .34315 .5356 .35152 .53295 .34632 .52804 Metetra
.664 .741 .908 r
.34632 .52804 .35152 .53295 .35992 .53029 .35473 .52537 Metetra
.664 .741 .908 r
.35473 .52537 .35992 .53029 .36835 .52763 .36317 .52269 Metetra
.664 .741 .908 r
.36317 .52269 .36835 .52763 .3768 .52496 .37164 .52 Metetra
.664 .741 .908 r
.37164 .52 .3768 .52496 .38528 .52227 .38014 .5173 Metetra
.664 .741 .908 r
.38014 .5173 .38528 .52227 .39379 .51958 .38866 .51459 Metetra
.664 .741 .908 r
.38866 .51459 .39379 .51958 .40232 .51688 .39721 .51188 Metetra
.664 .741 .908 r
.39721 .51188 .40232 .51688 .41088 .51418 .40579 .50916 Metetra
.664 .741 .908 r
.40579 .50916 .41088 .51418 .41947 .51146 .41439 .50642 Metetra
.664 .741 .908 r
.41439 .50642 .41947 .51146 .42808 .50874 .42303 .50368 Metetra
.664 .741 .908 r
.42303 .50368 .42808 .50874 .43673 .506 .43169 .50093 Metetra
.664 .741 .908 r
.43169 .50093 .43673 .506 .4454 .50326 .44038 .49817 Metetra
.664 .741 .908 r
.44038 .49817 .4454 .50326 .4541 .50051 .44909 .49541 Metetra
.664 .741 .908 r
.44909 .49541 .4541 .50051 .46282 .49775 .45784 .49263 Metetra
.664 .741 .908 r
.45784 .49263 .46282 .49775 .47158 .49498 .46661 .48984 Metetra
.664 .741 .908 r
.46661 .48984 .47158 .49498 .48036 .4922 .47541 .48705 Metetra
.664 .741 .908 r
.47541 .48705 .48036 .4922 .48917 .48941 .48424 .48425 Metetra
.664 .741 .908 r
.48424 .48425 .48917 .48941 .49801 .48662 .4931 .48143 Metetra
.664 .741 .908 r
.4931 .48143 .49801 .48662 .50688 .48381 .50198 .47861 Metetra
.664 .741 .908 r
.50198 .47861 .50688 .48381 .51577 .481 .5109 .47578 Metetra
.664 .741 .908 r
.5109 .47578 .51577 .481 .5247 .47818 .51984 .47294 Metetra
.664 .741 .908 r
.51984 .47294 .5247 .47818 .53366 .47534 .52882 .47009 Metetra
.664 .741 .908 r
.52882 .47009 .53366 .47534 .54264 .4725 .53782 .46723 Metetra
.664 .741 .908 r
.53782 .46723 .54264 .4725 .55165 .46965 .54685 .46436 Metetra
.664 .741 .908 r
.54685 .46436 .55165 .46965 .5607 .46679 .55592 .46149 Metetra
.664 .741 .908 r
.55592 .46149 .5607 .46679 .56977 .46392 .56501 .4586 Metetra
.664 .741 .908 r
.56501 .4586 .56977 .46392 .57887 .46104 .57413 .4557 Metetra
.664 .741 .908 r
.57413 .4557 .57887 .46104 .588 .45815 .58328 .4528 Metetra
.664 .741 .908 r
.58328 .4528 .588 .45815 .59717 .45526 .59246 .44988 Metetra
.664 .741 .908 r
.59246 .44988 .59717 .45526 .60636 .45235 .60168 .44695 Metetra
.664 .741 .908 r
.60168 .44695 .60636 .45235 .61558 .44943 .61092 .44402 Metetra
.664 .741 .908 r
.61092 .44402 .61558 .44943 .62483 .4465 .62019 .44107 Metetra
.664 .741 .908 r
.62019 .44107 .62483 .4465 .63412 .44357 .6295 .43812 Metetra
.664 .741 .908 r
.6295 .43812 .63412 .44357 .64343 .44062 .63884 .43516 Metetra
.664 .741 .908 r
.63884 .43516 .64343 .44062 .65278 .43766 .6482 .43218 Metetra
.664 .741 .908 r
.6482 .43218 .65278 .43766 .66216 .4347 .6576 .4292 Metetra
.664 .741 .908 r
.6576 .4292 .66216 .4347 .67157 .43172 .66703 .4262 Metetra
.664 .741 .908 r
.66703 .4262 .67157 .43172 .68101 .42874 .67649 .4232 Metetra
.664 .741 .908 r
.67649 .4232 .68101 .42874 .69048 .42574 .68599 .42018 Metetra
.664 .741 .908 r
.68599 .42018 .69048 .42574 .69998 .42273 .69551 .41716 Metetra
.664 .741 .908 r
.69551 .41716 .69998 .42273 .70952 .41972 .70507 .41412 Metetra
.664 .741 .908 r
.70507 .41412 .70952 .41972 .71908 .41669 .71466 .41108 Metetra
.664 .741 .908 r
.71466 .41108 .71908 .41669 .72868 .41366 .72428 .40802 Metetra
.664 .741 .908 r
.72428 .40802 .72868 .41366 .73831 .41061 .73394 .40496 Metetra
.664 .741 .908 r
.73394 .40496 .73831 .41061 .74798 .40755 .74362 .40188 Metetra
.664 .741 .908 r
.74362 .40188 .74798 .40755 .75768 .40449 .75334 .39879 Metetra
.664 .741 .908 r
.75334 .39879 .75768 .40449 .76741 .40141 .7631 .3957 Metetra
.664 .741 .908 r
.7631 .3957 .76741 .40141 .77717 .39832 .77288 .39259 Metetra
.664 .741 .908 r
.77288 .39259 .77717 .39832 .78697 .39522 .7827 .38947 Metetra
.664 .741 .908 r
.7827 .38947 .78697 .39522 .7968 .39211 .79256 .38634 Metetra
.664 .741 .908 r
.79256 .38634 .7968 .39211 .80666 .38899 .80245 .3832 Metetra
.664 .741 .908 r
.80245 .3832 .80666 .38899 .81656 .38586 .81237 .38005 Metetra
.664 .741 .908 r
.81237 .38005 .81656 .38586 .82649 .38272 .82232 .37689 Metetra
.664 .741 .908 r
.82232 .37689 .82649 .38272 .83646 .37957 .83231 .37372 Metetra
.664 .741 .908 r
.83231 .37372 .83646 .37957 .84645 .3764 .84234 .37054 Metetra
.664 .741 .908 r
.84234 .37054 .84645 .3764 .85649 .37323 .8524 .36734 Metetra
.664 .741 .908 r
.8524 .36734 .85649 .37323 .86656 .37005 .86249 .36414 Metetra
.664 .741 .908 r
.86249 .36414 .86656 .37005 .87666 .36685 .87262 .36092 Metetra
.664 .741 .908 r
.87262 .36092 .87666 .36685 .8868 .36364 .88278 .35769 Metetra
.664 .741 .908 r
.88278 .35769 .8868 .36364 .89697 .36042 .89298 .35445 Metetra
.664 .741 .908 r
.89298 .35445 .89697 .36042 .90718 .3572 .90322 .3512 Metetra
.664 .741 .908 r
.90322 .3512 .90718 .3572 .91743 .35396 .91349 .34794 Metetra
.664 .741 .908 r
.32429 .52845 .32956 .53336 .33793 .5307 .33267 .52578 Metetra
.664 .741 .908 r
.33267 .52578 .33793 .5307 .34632 .52804 .34108 .5231 Metetra
.664 .741 .908 r
.34108 .5231 .34632 .52804 .35473 .52537 .34951 .52041 Metetra
.664 .741 .908 r
.34951 .52041 .35473 .52537 .36317 .52269 .35797 .51772 Metetra
.664 .741 .908 r
.35797 .51772 .36317 .52269 .37164 .52 .36645 .51501 Metetra
.664 .741 .908 r
.36645 .51501 .37164 .52 .38014 .5173 .37496 .5123 Metetra
.664 .741 .908 r
.37496 .5123 .38014 .5173 .38866 .51459 .3835 .50957 Metetra
.664 .741 .908 r
.3835 .50957 .38866 .51459 .39721 .51188 .39207 .50684 Metetra
.664 .741 .908 r
.39207 .50684 .39721 .51188 .40579 .50916 .40067 .5041 Metetra
.664 .741 .908 r
.40067 .5041 .40579 .50916 .41439 .50642 .40929 .50136 Metetra
.664 .741 .908 r
.40929 .50136 .41439 .50642 .42303 .50368 .41794 .4986 Metetra
.664 .741 .908 r
.41794 .4986 .42303 .50368 .43169 .50093 .42662 .49583 Metetra
.664 .741 .908 r
.42662 .49583 .43169 .50093 .44038 .49817 .43532 .49306 Metetra
.664 .741 .908 r
.43532 .49306 .44038 .49817 .44909 .49541 .44406 .49027 Metetra
.664 .741 .908 r
.44406 .49027 .44909 .49541 .45784 .49263 .45282 .48748 Metetra
.664 .741 .908 r
.45282 .48748 .45784 .49263 .46661 .48984 .46161 .48468 Metetra
.664 .741 .908 r
.46161 .48468 .46661 .48984 .47541 .48705 .47043 .48187 Metetra
.664 .741 .908 r
.47043 .48187 .47541 .48705 .48424 .48425 .47928 .47905 Metetra
.664 .741 .908 r
.47928 .47905 .48424 .48425 .4931 .48143 .48815 .47622 Metetra
.664 .741 .908 r
.48815 .47622 .4931 .48143 .50198 .47861 .49706 .47338 Metetra
.664 .741 .908 r
.49706 .47338 .50198 .47861 .5109 .47578 .50599 .47053 Metetra
.664 .741 .908 r
.50599 .47053 .5109 .47578 .51984 .47294 .51496 .46767 Metetra
.664 .741 .908 r
.51496 .46767 .51984 .47294 .52882 .47009 .52395 .4648 Metetra
.664 .741 .908 r
.52395 .4648 .52882 .47009 .53782 .46723 .53297 .46193 Metetra
.664 .741 .908 r
.53297 .46193 .53782 .46723 .54685 .46436 .54202 .45904 Metetra
.664 .741 .908 r
.54202 .45904 .54685 .46436 .55592 .46149 .55111 .45615 Metetra
.664 .741 .908 r
.55111 .45615 .55592 .46149 .56501 .4586 .56022 .45324 Metetra
.664 .741 .908 r
.56022 .45324 .56501 .4586 .57413 .4557 .56936 .45033 Metetra
.664 .741 .908 r
.56936 .45033 .57413 .4557 .58328 .4528 .57853 .4474 Metetra
.664 .741 .908 r
.57853 .4474 .58328 .4528 .59246 .44988 .58773 .44447 Metetra
.664 .741 .908 r
.58773 .44447 .59246 .44988 .60168 .44695 .59697 .44153 Metetra
.664 .741 .908 r
.59697 .44153 .60168 .44695 .61092 .44402 .60623 .43857 Metetra
.664 .741 .908 r
.60623 .43857 .61092 .44402 .62019 .44107 .61553 .43561 Metetra
.664 .741 .908 r
.61553 .43561 .62019 .44107 .6295 .43812 .62485 .43264 Metetra
.664 .741 .908 r
.62485 .43264 .6295 .43812 .63884 .43516 .63421 .42966 Metetra
.664 .741 .908 r
.63421 .42966 .63884 .43516 .6482 .43218 .6436 .42666 Metetra
.664 .741 .908 r
.6436 .42666 .6482 .43218 .6576 .4292 .65302 .42366 Metetra
.664 .741 .908 r
.65302 .42366 .6576 .4292 .66703 .4262 .66247 .42065 Metetra
.664 .741 .908 r
.66247 .42065 .66703 .4262 .67649 .4232 .67195 .41762 Metetra
.664 .741 .908 r
.67195 .41762 .67649 .4232 .68599 .42018 .68147 .41459 Metetra
.664 .741 .908 r
.68147 .41459 .68599 .42018 .69551 .41716 .69101 .41155 Metetra
.664 .741 .908 r
.69101 .41155 .69551 .41716 .70507 .41412 .70059 .40849 Metetra
.664 .741 .908 r
.70059 .40849 .70507 .41412 .71466 .41108 .71021 .40543 Metetra
.664 .741 .908 r
.71021 .40543 .71466 .41108 .72428 .40802 .71985 .40236 Metetra
.664 .741 .908 r
.71985 .40236 .72428 .40802 .73394 .40496 .72953 .39927 Metetra
.664 .741 .908 r
.72953 .39927 .73394 .40496 .74362 .40188 .73924 .39618 Metetra
.664 .741 .908 r
.73924 .39618 .74362 .40188 .75334 .39879 .74898 .39307 Metetra
.664 .741 .908 r
.74898 .39307 .75334 .39879 .7631 .3957 .75876 .38995 Metetra
.664 .741 .908 r
.75876 .38995 .7631 .3957 .77288 .39259 .76857 .38683 Metetra
.664 .741 .908 r
.76857 .38683 .77288 .39259 .7827 .38947 .77841 .38369 Metetra
.664 .741 .908 r
.77841 .38369 .7827 .38947 .79256 .38634 .78829 .38054 Metetra
.664 .741 .908 r
.78829 .38054 .79256 .38634 .80245 .3832 .7982 .37738 Metetra
.664 .741 .908 r
.7982 .37738 .80245 .3832 .81237 .38005 .80815 .37421 Metetra
.664 .741 .908 r
.80815 .37421 .81237 .38005 .82232 .37689 .81813 .37103 Metetra
.664 .741 .908 r
.81813 .37103 .82232 .37689 .83231 .37372 .82814 .36783 Metetra
.664 .741 .908 r
.82814 .36783 .83231 .37372 .84234 .37054 .83819 .36463 Metetra
.664 .741 .908 r
.83819 .36463 .84234 .37054 .8524 .36734 .84828 .36142 Metetra
.664 .741 .908 r
.84828 .36142 .8524 .36734 .86249 .36414 .8584 .35819 Metetra
.664 .741 .908 r
.8584 .35819 .86249 .36414 .87262 .36092 .86855 .35495 Metetra
.664 .741 .908 r
.86855 .35495 .87262 .36092 .88278 .35769 .87874 .35171 Metetra
.664 .741 .908 r
.87874 .35171 .88278 .35769 .89298 .35445 .88897 .34845 Metetra
.664 .741 .908 r
.88897 .34845 .89298 .35445 .90322 .3512 .89923 .34517 Metetra
.664 .741 .908 r
.89923 .34517 .90322 .3512 .91349 .34794 .90953 .34189 Metetra
.664 .741 .908 r
.31899 .52351 .32429 .52845 .33267 .52578 .32738 .52083 Metetra
.664 .741 .908 r
.32738 .52083 .33267 .52578 .34108 .5231 .3358 .51813 Metetra
.664 .741 .908 r
.3358 .51813 .34108 .5231 .34951 .52041 .34425 .51543 Metetra
.664 .741 .908 r
.34425 .51543 .34951 .52041 .35797 .51772 .35273 .51272 Metetra
.664 .741 .908 r
.35273 .51272 .35797 .51772 .36645 .51501 .36123 .50999 Metetra
.664 .741 .908 r
.36123 .50999 .36645 .51501 .37496 .5123 .36976 .50726 Metetra
.664 .741 .908 r
.36976 .50726 .37496 .5123 .3835 .50957 .37832 .50453 Metetra
.664 .741 .908 r
.37832 .50453 .3835 .50957 .39207 .50684 .3869 .50178 Metetra
.664 .741 .908 r
.3869 .50178 .39207 .50684 .40067 .5041 .39551 .49902 Metetra
.664 .741 .908 r
.39551 .49902 .40067 .5041 .40929 .50136 .40415 .49626 Metetra
.664 .741 .908 r
.40415 .49626 .40929 .50136 .41794 .4986 .41282 .49348 Metetra
.664 .741 .908 r
.41282 .49348 .41794 .4986 .42662 .49583 .42152 .4907 Metetra
.664 .741 .908 r
.42152 .4907 .42662 .49583 .43532 .49306 .43024 .48791 Metetra
.664 .741 .908 r
.43024 .48791 .43532 .49306 .44406 .49027 .43899 .48511 Metetra
.664 .741 .908 r
.43899 .48511 .44406 .49027 .45282 .48748 .44777 .4823 Metetra
.664 .741 .908 r
.44777 .4823 .45282 .48748 .46161 .48468 .45658 .47948 Metetra
.664 .741 .908 r
.45658 .47948 .46161 .48468 .47043 .48187 .46542 .47665 Metetra
.664 .741 .908 r
.46542 .47665 .47043 .48187 .47928 .47905 .47428 .47381 Metetra
.664 .741 .908 r
.47428 .47381 .47928 .47905 .48815 .47622 .48318 .47097 Metetra
.664 .741 .908 r
.48318 .47097 .48815 .47622 .49706 .47338 .4921 .46811 Metetra
.664 .741 .908 r
.4921 .46811 .49706 .47338 .50599 .47053 .50106 .46525 Metetra
.664 .741 .908 r
.50106 .46525 .50599 .47053 .51496 .46767 .51004 .46237 Metetra
.664 .741 .908 r
.51004 .46237 .51496 .46767 .52395 .4648 .51905 .45949 Metetra
.664 .741 .908 r
.51905 .45949 .52395 .4648 .53297 .46193 .52809 .45659 Metetra
.664 .741 .908 r
.52809 .45659 .53297 .46193 .54202 .45904 .53716 .45369 Metetra
.664 .741 .908 r
.53716 .45369 .54202 .45904 .55111 .45615 .54627 .45078 Metetra
.664 .741 .908 r
.54627 .45078 .55111 .45615 .56022 .45324 .5554 .44786 Metetra
.664 .741 .908 r
.5554 .44786 .56022 .45324 .56936 .45033 .56456 .44492 Metetra
.664 .741 .908 r
.56456 .44492 .56936 .45033 .57853 .4474 .57375 .44198 Metetra
.664 .741 .908 r
.57375 .44198 .57853 .4474 .58773 .44447 .58298 .43903 Metetra
.664 .741 .908 r
.58298 .43903 .58773 .44447 .59697 .44153 .59223 .43607 Metetra
.664 .741 .908 r
.59223 .43607 .59697 .44153 .60623 .43857 .60151 .4331 Metetra
.664 .741 .908 r
.60151 .4331 .60623 .43857 .61553 .43561 .61083 .43012 Metetra
.664 .741 .908 r
.61083 .43012 .61553 .43561 .62485 .43264 .62018 .42712 Metetra
.664 .741 .908 r
.62018 .42712 .62485 .43264 .63421 .42966 .62955 .42412 Metetra
.664 .741 .908 r
.62955 .42412 .63421 .42966 .6436 .42666 .63896 .42111 Metetra
.664 .741 .908 r
.63896 .42111 .6436 .42666 .65302 .42366 .64841 .41809 Metetra
.664 .741 .908 r
.64841 .41809 .65302 .42366 .66247 .42065 .65788 .41506 Metetra
.664 .741 .908 r
.65788 .41506 .66247 .42065 .67195 .41762 .66738 .41202 Metetra
.664 .741 .908 r
.66738 .41202 .67195 .41762 .68147 .41459 .67692 .40896 Metetra
.664 .741 .908 r
.67692 .40896 .68147 .41459 .69101 .41155 .68649 .4059 Metetra
.664 .741 .908 r
.68649 .4059 .69101 .41155 .70059 .40849 .69609 .40283 Metetra
.664 .741 .908 r
.69609 .40283 .70059 .40849 .71021 .40543 .70573 .39975 Metetra
.664 .741 .908 r
.70573 .39975 .71021 .40543 .71985 .40236 .71539 .39665 Metetra
.664 .741 .908 r
.71539 .39665 .71985 .40236 .72953 .39927 .72509 .39355 Metetra
.664 .741 .908 r
.72509 .39355 .72953 .39927 .73924 .39618 .73483 .39043 Metetra
.664 .741 .908 r
.73483 .39043 .73924 .39618 .74898 .39307 .74459 .38731 Metetra
.664 .741 .908 r
.74459 .38731 .74898 .39307 .75876 .38995 .75439 .38417 Metetra
.664 .741 .908 r
.75439 .38417 .75876 .38995 .76857 .38683 .76423 .38102 Metetra
.664 .741 .908 r
.76423 .38102 .76857 .38683 .77841 .38369 .7741 .37787 Metetra
.664 .741 .908 r
.7741 .37787 .77841 .38369 .78829 .38054 .784 .3747 Metetra
.664 .741 .908 r
.784 .3747 .78829 .38054 .7982 .37738 .79393 .37152 Metetra
.664 .741 .908 r
.79393 .37152 .7982 .37738 .80815 .37421 .8039 .36833 Metetra
.664 .741 .908 r
.8039 .36833 .80815 .37421 .81813 .37103 .81391 .36512 Metetra
.664 .741 .908 r
.81391 .36512 .81813 .37103 .82814 .36783 .82395 .36191 Metetra
.664 .741 .908 r
.82395 .36191 .82814 .36783 .83819 .36463 .83402 .35869 Metetra
.664 .741 .908 r
.83402 .35869 .83819 .36463 .84828 .36142 .84413 .35545 Metetra
.664 .741 .908 r
.84413 .35545 .84828 .36142 .8584 .35819 .85428 .35221 Metetra
.664 .741 .908 r
.85428 .35221 .8584 .35819 .86855 .35495 .86446 .34895 Metetra
.664 .741 .908 r
.86446 .34895 .86855 .35495 .87874 .35171 .87467 .34568 Metetra
.664 .741 .908 r
.87467 .34568 .87874 .35171 .88897 .34845 .88492 .3424 Metetra
.664 .741 .908 r
.88492 .3424 .88897 .34845 .89923 .34517 .89521 .33911 Metetra
.664 .741 .908 r
.89521 .33911 .89923 .34517 .90953 .34189 .90553 .3358 Metetra
.664 .741 .908 r
.31365 .51855 .31899 .52351 .32738 .52083 .32207 .51584 Metetra
.664 .741 .908 r
.32207 .51584 .32738 .52083 .3358 .51813 .3305 .51313 Metetra
.664 .741 .908 r
.3305 .51313 .3358 .51813 .34425 .51543 .33897 .51041 Metetra
.664 .741 .908 r
.33897 .51041 .34425 .51543 .35273 .51272 .34746 .50769 Metetra
.664 .741 .908 r
.34746 .50769 .35273 .51272 .36123 .50999 .35598 .50495 Metetra
.664 .741 .908 r
.35598 .50495 .36123 .50999 .36976 .50726 .36453 .5022 Metetra
.664 .741 .908 r
.36453 .5022 .36976 .50726 .37832 .50453 .3731 .49945 Metetra
.664 .741 .908 r
.3731 .49945 .37832 .50453 .3869 .50178 .3817 .49668 Metetra
.664 .741 .908 r
.3817 .49668 .3869 .50178 .39551 .49902 .39033 .49391 Metetra
.664 .741 .908 r
.39033 .49391 .39551 .49902 .40415 .49626 .39899 .49113 Metetra
.664 .741 .908 r
.39899 .49113 .40415 .49626 .41282 .49348 .40767 .48834 Metetra
.664 .741 .908 r
.40767 .48834 .41282 .49348 .42152 .4907 .41638 .48554 Metetra
.664 .741 .908 r
.41638 .48554 .42152 .4907 .43024 .48791 .42513 .48273 Metetra
.664 .741 .908 r
.42513 .48273 .43024 .48791 .43899 .48511 .4339 .47991 Metetra
.664 .741 .908 r
.4339 .47991 .43899 .48511 .44777 .4823 .44269 .47709 Metetra
.664 .741 .908 r
.44269 .47709 .44777 .4823 .45658 .47948 .45152 .47425 Metetra
.664 .741 .908 r
.45152 .47425 .45658 .47948 .46542 .47665 .46038 .47141 Metetra
.664 .741 .908 r
.46038 .47141 .46542 .47665 .47428 .47381 .46926 .46855 Metetra
.664 .741 .908 r
.46926 .46855 .47428 .47381 .48318 .47097 .47817 .46569 Metetra
.664 .741 .908 r
.47817 .46569 .48318 .47097 .4921 .46811 .48712 .46281 Metetra
.664 .741 .908 r
.48712 .46281 .4921 .46811 .50106 .46525 .49609 .45993 Metetra
.664 .741 .908 r
.49609 .45993 .50106 .46525 .51004 .46237 .50509 .45704 Metetra
.664 .741 .908 r
.50509 .45704 .51004 .46237 .51905 .45949 .51412 .45414 Metetra
.664 .741 .908 r
.51412 .45414 .51905 .45949 .52809 .45659 .52318 .45123 Metetra
.664 .741 .908 r
.52318 .45123 .52809 .45659 .53716 .45369 .53228 .44831 Metetra
.664 .741 .908 r
.53228 .44831 .53716 .45369 .54627 .45078 .5414 .44537 Metetra
.664 .741 .908 r
.5414 .44537 .54627 .45078 .5554 .44786 .55055 .44243 Metetra
.664 .741 .908 r
.55055 .44243 .5554 .44786 .56456 .44492 .55973 .43948 Metetra
.664 .741 .908 r
.55973 .43948 .56456 .44492 .57375 .44198 .56894 .43652 Metetra
.664 .741 .908 r
.56894 .43652 .57375 .44198 .58298 .43903 .57819 .43355 Metetra
.664 .741 .908 r
.57819 .43355 .58298 .43903 .59223 .43607 .58746 .43057 Metetra
.664 .741 .908 r
.58746 .43057 .59223 .43607 .60151 .4331 .59677 .42759 Metetra
.664 .741 .908 r
.59677 .42759 .60151 .4331 .61083 .43012 .6061 .42459 Metetra
.664 .741 .908 r
.6061 .42459 .61083 .43012 .62018 .42712 .61547 .42158 Metetra
.664 .741 .908 r
.61547 .42158 .62018 .42712 .62955 .42412 .62487 .41856 Metetra
.664 .741 .908 r
.62487 .41856 .62955 .42412 .63896 .42111 .6343 .41553 Metetra
.664 .741 .908 r
.6343 .41553 .63896 .42111 .64841 .41809 .64376 .41249 Metetra
.664 .741 .908 r
.64376 .41249 .64841 .41809 .65788 .41506 .65326 .40943 Metetra
.664 .741 .908 r
.65326 .40943 .65788 .41506 .66738 .41202 .66279 .40637 Metetra
.664 .741 .908 r
.66279 .40637 .66738 .41202 .67692 .40896 .67235 .4033 Metetra
.664 .741 .908 r
.67235 .4033 .67692 .40896 .68649 .4059 .68194 .40022 Metetra
.664 .741 .908 r
.68194 .40022 .68649 .4059 .69609 .40283 .69156 .39713 Metetra
.664 .741 .908 r
.69156 .39713 .69609 .40283 .70573 .39975 .70122 .39403 Metetra
.664 .741 .908 r
.70122 .39403 .70573 .39975 .71539 .39665 .71091 .39091 Metetra
.664 .741 .908 r
.71091 .39091 .71539 .39665 .72509 .39355 .72063 .38779 Metetra
.664 .741 .908 r
.72063 .38779 .72509 .39355 .73483 .39043 .73039 .38465 Metetra
.664 .741 .908 r
.73039 .38465 .73483 .39043 .74459 .38731 .74018 .38151 Metetra
.664 .741 .908 r
.74018 .38151 .74459 .38731 .75439 .38417 .75 .37835 Metetra
.664 .741 .908 r
.75 .37835 .75439 .38417 .76423 .38102 .75986 .37518 Metetra
.664 .741 .908 r
.75986 .37518 .76423 .38102 .7741 .37787 .76975 .37201 Metetra
.664 .741 .908 r
.76975 .37201 .7741 .37787 .784 .3747 .77968 .36882 Metetra
.664 .741 .908 r
.77968 .36882 .784 .3747 .79393 .37152 .78964 .36562 Metetra
.664 .741 .908 r
.78964 .36562 .79393 .37152 .8039 .36833 .79963 .36241 Metetra
.664 .741 .908 r
.79963 .36241 .8039 .36833 .81391 .36512 .80966 .35918 Metetra
.664 .741 .908 r
.80966 .35918 .81391 .36512 .82395 .36191 .81973 .35595 Metetra
.664 .741 .908 r
.81973 .35595 .82395 .36191 .83402 .35869 .82982 .35271 Metetra
.664 .741 .908 r
.82982 .35271 .83402 .35869 .84413 .35545 .83996 .34945 Metetra
.664 .741 .908 r
.83996 .34945 .84413 .35545 .85428 .35221 .85013 .34618 Metetra
.664 .741 .908 r
.85013 .34618 .85428 .35221 .86446 .34895 .86034 .3429 Metetra
.664 .741 .908 r
.86034 .3429 .86446 .34895 .87467 .34568 .87058 .33961 Metetra
.664 .741 .908 r
.87058 .33961 .87467 .34568 .88492 .3424 .88085 .33631 Metetra
.664 .741 .908 r
.88085 .33631 .88492 .3424 .89521 .33911 .89117 .333 Metetra
.664 .741 .908 r
.89117 .333 .89521 .33911 .90553 .3358 .90152 .32967 Metetra
.664 .741 .908 r
.30829 .51355 .31365 .51855 .32207 .51584 .31672 .51083 Metetra
.664 .741 .908 r
.31672 .51083 .32207 .51584 .3305 .51313 .32517 .50811 Metetra
.664 .741 .908 r
.32517 .50811 .3305 .51313 .33897 .51041 .33365 .50537 Metetra
.664 .741 .908 r
.33365 .50537 .33897 .51041 .34746 .50769 .34216 .50263 Metetra
.664 .741 .908 r
.34216 .50263 .34746 .50769 .35598 .50495 .3507 .49987 Metetra
.664 .741 .908 r
.3507 .49987 .35598 .50495 .36453 .5022 .35926 .49711 Metetra
.664 .741 .908 r
.35926 .49711 .36453 .5022 .3731 .49945 .36785 .49434 Metetra
.664 .741 .908 r
.36785 .49434 .3731 .49945 .3817 .49668 .37647 .49156 Metetra
.664 .741 .908 r
.37647 .49156 .3817 .49668 .39033 .49391 .38511 .48877 Metetra
.664 .741 .908 r
.38511 .48877 .39033 .49391 .39899 .49113 .39379 .48597 Metetra
.664 .741 .908 r
.39379 .48597 .39899 .49113 .40767 .48834 .40249 .48316 Metetra
.664 .741 .908 r
.40249 .48316 .40767 .48834 .41638 .48554 .41122 .48035 Metetra
.664 .741 .908 r
.41122 .48035 .41638 .48554 .42513 .48273 .41998 .47752 Metetra
.664 .741 .908 r
.41998 .47752 .42513 .48273 .4339 .47991 .42877 .47469 Metetra
.664 .741 .908 r
.42877 .47469 .4339 .47991 .44269 .47709 .43759 .47184 Metetra
.664 .741 .908 r
.43759 .47184 .44269 .47709 .45152 .47425 .44643 .46899 Metetra
.664 .741 .908 r
.44643 .46899 .45152 .47425 .46038 .47141 .4553 .46613 Metetra
.664 .741 .908 r
.4553 .46613 .46038 .47141 .46926 .46855 .46421 .46326 Metetra
.664 .741 .908 r
.46421 .46326 .46926 .46855 .47817 .46569 .47314 .46038 Metetra
.664 .741 .908 r
.47314 .46038 .47817 .46569 .48712 .46281 .4821 .45749 Metetra
.664 .741 .908 r
.4821 .45749 .48712 .46281 .49609 .45993 .49109 .45458 Metetra
.664 .741 .908 r
.49109 .45458 .49609 .45993 .50509 .45704 .50011 .45168 Metetra
.664 .741 .908 r
.50011 .45168 .50509 .45704 .51412 .45414 .50917 .44876 Metetra
.664 .741 .908 r
.50917 .44876 .51412 .45414 .52318 .45123 .51825 .44583 Metetra
.664 .741 .908 r
.51825 .44583 .52318 .45123 .53228 .44831 .52736 .44289 Metetra
.664 .741 .908 r
.52736 .44289 .53228 .44831 .5414 .44537 .5365 .43994 Metetra
.664 .741 .908 r
.5365 .43994 .5414 .44537 .55055 .44243 .54567 .43698 Metetra
.664 .741 .908 r
.54567 .43698 .55055 .44243 .55973 .43948 .55487 .43401 Metetra
.664 .741 .908 r
.55487 .43401 .55973 .43948 .56894 .43652 .56411 .43103 Metetra
.664 .741 .908 r
.56411 .43103 .56894 .43652 .57819 .43355 .57337 .42805 Metetra
.664 .741 .908 r
.57337 .42805 .57819 .43355 .58746 .43057 .58266 .42505 Metetra
.664 .741 .908 r
.58266 .42505 .58746 .43057 .59677 .42759 .59199 .42204 Metetra
.664 .741 .908 r
.59199 .42204 .59677 .42759 .6061 .42459 .60135 .41902 Metetra
.664 .741 .908 r
.60135 .41902 .6061 .42459 .61547 .42158 .61074 .41599 Metetra
.664 .741 .908 r
.61074 .41599 .61547 .42158 .62487 .41856 .62016 .41295 Metetra
.664 .741 .908 r
.62016 .41295 .62487 .41856 .6343 .41553 .62961 .4099 Metetra
.664 .741 .908 r
.62961 .4099 .6343 .41553 .64376 .41249 .63909 .40685 Metetra
.664 .741 .908 r
.63909 .40685 .64376 .41249 .65326 .40943 .64861 .40378 Metetra
.664 .741 .908 r
.64861 .40378 .65326 .40943 .66279 .40637 .65816 .4007 Metetra
.664 .741 .908 r
.65816 .4007 .66279 .40637 .67235 .4033 .66774 .39761 Metetra
.664 .741 .908 r
.66774 .39761 .67235 .4033 .68194 .40022 .67736 .3945 Metetra
.664 .741 .908 r
.67736 .3945 .68194 .40022 .69156 .39713 .687 .39139 Metetra
.664 .741 .908 r
.687 .39139 .69156 .39713 .70122 .39403 .69668 .38827 Metetra
.664 .741 .908 r
.69668 .38827 .70122 .39403 .71091 .39091 .70639 .38514 Metetra
.664 .741 .908 r
.70639 .38514 .71091 .39091 .72063 .38779 .71614 .38199 Metetra
.664 .741 .908 r
.71614 .38199 .72063 .38779 .73039 .38465 .72592 .37884 Metetra
.664 .741 .908 r
.72592 .37884 .73039 .38465 .74018 .38151 .73573 .37567 Metetra
.664 .741 .908 r
.73573 .37567 .74018 .38151 .75 .37835 .74558 .3725 Metetra
.664 .741 .908 r
.74558 .3725 .75 .37835 .75986 .37518 .75546 .36931 Metetra
.664 .741 .908 r
.75546 .36931 .75986 .37518 .76975 .37201 .76538 .36611 Metetra
.664 .741 .908 r
.76538 .36611 .76975 .37201 .77968 .36882 .77533 .3629 Metetra
.664 .741 .908 r
.77533 .3629 .77968 .36882 .78964 .36562 .78531 .35968 Metetra
.664 .741 .908 r
.78531 .35968 .78964 .36562 .79963 .36241 .79533 .35645 Metetra
.664 .741 .908 r
.79533 .35645 .79963 .36241 .80966 .35918 .80539 .35321 Metetra
.664 .741 .908 r
.80539 .35321 .80966 .35918 .81973 .35595 .81548 .34995 Metetra
.664 .741 .908 r
.81548 .34995 .81973 .35595 .82982 .35271 .8256 .34669 Metetra
.664 .741 .908 r
.8256 .34669 .82982 .35271 .83996 .34945 .83576 .34341 Metetra
.664 .741 .908 r
.83576 .34341 .83996 .34945 .85013 .34618 .84596 .34012 Metetra
.664 .741 .908 r
.84596 .34012 .85013 .34618 .86034 .3429 .85619 .33682 Metetra
.664 .741 .908 r
.85619 .33682 .86034 .3429 .87058 .33961 .86646 .33351 Metetra
.664 .741 .908 r
.86646 .33351 .87058 .33961 .88085 .33631 .87676 .33018 Metetra
.664 .741 .908 r
.87676 .33018 .88085 .33631 .89117 .333 .8871 .32685 Metetra
.664 .741 .908 r
.8871 .32685 .89117 .333 .90152 .32967 .89748 .3235 Metetra
.664 .741 .908 r
.30289 .50853 .30829 .51355 .31672 .51083 .31134 .50579 Metetra
.664 .741 .908 r
.31134 .50579 .31672 .51083 .32517 .50811 .31981 .50305 Metetra
.664 .741 .908 r
.31981 .50305 .32517 .50811 .33365 .50537 .3283 .5003 Metetra
.664 .741 .908 r
.3283 .5003 .33365 .50537 .34216 .50263 .33683 .49754 Metetra
.664 .741 .908 r
.33683 .49754 .34216 .50263 .3507 .49987 .34538 .49477 Metetra
.664 .741 .908 r
.34538 .49477 .3507 .49987 .35926 .49711 .35396 .49199 Metetra
.664 .741 .908 r
.35396 .49199 .35926 .49711 .36785 .49434 .36257 .4892 Metetra
.664 .741 .908 r
.36257 .4892 .36785 .49434 .37647 .49156 .37121 .4864 Metetra
.664 .741 .908 r
.37121 .4864 .37647 .49156 .38511 .48877 .37987 .4836 Metetra
.664 .741 .908 r
.37987 .4836 .38511 .48877 .39379 .48597 .38856 .48078 Metetra
.664 .741 .908 r
.38856 .48078 .39379 .48597 .40249 .48316 .39728 .47796 Metetra
.664 .741 .908 r
.39728 .47796 .40249 .48316 .41122 .48035 .40603 .47513 Metetra
.664 .741 .908 r
.40603 .47513 .41122 .48035 .41998 .47752 .41481 .47228 Metetra
.664 .741 .908 r
.41481 .47228 .41998 .47752 .42877 .47469 .42361 .46943 Metetra
.664 .741 .908 r
.42361 .46943 .42877 .47469 .43759 .47184 .43245 .46657 Metetra
.664 .741 .908 r
.43245 .46657 .43759 .47184 .44643 .46899 .44131 .4637 Metetra
.664 .741 .908 r
.44131 .4637 .44643 .46899 .4553 .46613 .4502 .46082 Metetra
.664 .741 .908 r
.4502 .46082 .4553 .46613 .46421 .46326 .45912 .45793 Metetra
.664 .741 .908 r
.45912 .45793 .46421 .46326 .47314 .46038 .46808 .45503 Metetra
.664 .741 .908 r
.46808 .45503 .47314 .46038 .4821 .45749 .47706 .45212 Metetra
.664 .741 .908 r
.47706 .45212 .4821 .45749 .49109 .45458 .48607 .44921 Metetra
.664 .741 .908 r
.48607 .44921 .49109 .45458 .50011 .45168 .49511 .44628 Metetra
.664 .741 .908 r
.49511 .44628 .50011 .45168 .50917 .44876 .50418 .44334 Metetra
.664 .741 .908 r
.50418 .44334 .50917 .44876 .51825 .44583 .51328 .44039 Metetra
.664 .741 .908 r
.51328 .44039 .51825 .44583 .52736 .44289 .52241 .43744 Metetra
.664 .741 .908 r
.52241 .43744 .52736 .44289 .5365 .43994 .53157 .43447 Metetra
.664 .741 .908 r
.53157 .43447 .5365 .43994 .54567 .43698 .54076 .43149 Metetra
.664 .741 .908 r
.54076 .43149 .54567 .43698 .55487 .43401 .54998 .42851 Metetra
.664 .741 .908 r
.54998 .42851 .55487 .43401 .56411 .43103 .55924 .42551 Metetra
.664 .741 .908 r
.55924 .42551 .56411 .43103 .57337 .42805 .56852 .4225 Metetra
.664 .741 .908 r
.56852 .4225 .57337 .42805 .58266 .42505 .57784 .41949 Metetra
.664 .741 .908 r
.57784 .41949 .58266 .42505 .59199 .42204 .58718 .41646 Metetra
.664 .741 .908 r
.58718 .41646 .59199 .42204 .60135 .41902 .59656 .41342 Metetra
.664 .741 .908 r
.59656 .41342 .60135 .41902 .61074 .41599 .60597 .41037 Metetra
.664 .741 .908 r
.60597 .41037 .61074 .41599 .62016 .41295 .61541 .40732 Metetra
.664 .741 .908 r
.61541 .40732 .62016 .41295 .62961 .4099 .62489 .40425 Metetra
.664 .741 .908 r
.62489 .40425 .62961 .4099 .63909 .40685 .63439 .40117 Metetra
.664 .741 .908 r
.63439 .40117 .63909 .40685 .64861 .40378 .64393 .39808 Metetra
.664 .741 .908 r
.64393 .39808 .64861 .40378 .65816 .4007 .6535 .39498 Metetra
.664 .741 .908 r
.6535 .39498 .65816 .4007 .66774 .39761 .66311 .39187 Metetra
.664 .741 .908 r
.66311 .39187 .66774 .39761 .67736 .3945 .67274 .38875 Metetra
.664 .741 .908 r
.67274 .38875 .67736 .3945 .687 .39139 .68241 .38562 Metetra
.664 .741 .908 r
.68241 .38562 .687 .39139 .69668 .38827 .69212 .38248 Metetra
.664 .741 .908 r
.69212 .38248 .69668 .38827 .70639 .38514 .70185 .37932 Metetra
.664 .741 .908 r
.70185 .37932 .70639 .38514 .71614 .38199 .71162 .37616 Metetra
.664 .741 .908 r
.71162 .37616 .71614 .38199 .72592 .37884 .72143 .37299 Metetra
.664 .741 .908 r
.72143 .37299 .72592 .37884 .73573 .37567 .73126 .3698 Metetra
.664 .741 .908 r
.73126 .3698 .73573 .37567 .74558 .3725 .74113 .3666 Metetra
.664 .741 .908 r
.74113 .3666 .74558 .3725 .75546 .36931 .75104 .3634 Metetra
.664 .741 .908 r
.75104 .3634 .75546 .36931 .76538 .36611 .76098 .36018 Metetra
.664 .741 .908 r
.76098 .36018 .76538 .36611 .77533 .3629 .77095 .35695 Metetra
.664 .741 .908 r
.77095 .35695 .77533 .3629 .78531 .35968 .78096 .35371 Metetra
.664 .741 .908 r
.78096 .35371 .78531 .35968 .79533 .35645 .79101 .35045 Metetra
.664 .741 .908 r
.79101 .35045 .79533 .35645 .80539 .35321 .80108 .34719 Metetra
.664 .741 .908 r
.80108 .34719 .80539 .35321 .81548 .34995 .8112 .34391 Metetra
.664 .741 .908 r
.8112 .34391 .81548 .34995 .8256 .34669 .82135 .34063 Metetra
.664 .741 .908 r
.82135 .34063 .8256 .34669 .83576 .34341 .83153 .33733 Metetra
.664 .741 .908 r
.83153 .33733 .83576 .34341 .84596 .34012 .84176 .33402 Metetra
.664 .741 .908 r
.84176 .33402 .84596 .34012 .85619 .33682 .85201 .3307 Metetra
.664 .741 .908 r
.85201 .3307 .85619 .33682 .86646 .33351 .86231 .32736 Metetra
.664 .741 .908 r
.86231 .32736 .86646 .33351 .87676 .33018 .87264 .32402 Metetra
.664 .741 .908 r
.87264 .32402 .87676 .33018 .8871 .32685 .883 .32066 Metetra
.664 .741 .908 r
.883 .32066 .8871 .32685 .89748 .3235 .89341 .31729 Metetra
.664 .741 .908 r
.29746 .50347 .30289 .50853 .31134 .50579 .30592 .50072 Metetra
.664 .741 .908 r
.30592 .50072 .31134 .50579 .31981 .50305 .31441 .49796 Metetra
.664 .741 .908 r
.31441 .49796 .31981 .50305 .3283 .5003 .32292 .49519 Metetra
.664 .741 .908 r
.32292 .49519 .3283 .5003 .33683 .49754 .33147 .49241 Metetra
.664 .741 .908 r
.33147 .49241 .33683 .49754 .34538 .49477 .34004 .48963 Metetra
.664 .741 .908 r
.34004 .48963 .34538 .49477 .35396 .49199 .34863 .48683 Metetra
.664 .741 .908 r
.34863 .48683 .35396 .49199 .36257 .4892 .35726 .48403 Metetra
.664 .741 .908 r
.35726 .48403 .36257 .4892 .37121 .4864 .36591 .48122 Metetra
.664 .741 .908 r
.36591 .48122 .37121 .4864 .37987 .4836 .37459 .47839 Metetra
.664 .741 .908 r
.37459 .47839 .37987 .4836 .38856 .48078 .3833 .47556 Metetra
.664 .741 .908 r
.3833 .47556 .38856 .48078 .39728 .47796 .39204 .47272 Metetra
.664 .741 .908 r
.39204 .47272 .39728 .47796 .40603 .47513 .40081 .46987 Metetra
.664 .741 .908 r
.40081 .46987 .40603 .47513 .41481 .47228 .4096 .46701 Metetra
.664 .741 .908 r
.4096 .46701 .41481 .47228 .42361 .46943 .41842 .46414 Metetra
.664 .741 .908 r
.41842 .46414 .42361 .46943 .43245 .46657 .42728 .46126 Metetra
.664 .741 .908 r
.42728 .46126 .43245 .46657 .44131 .4637 .43616 .45838 Metetra
.664 .741 .908 r
.43616 .45838 .44131 .4637 .4502 .46082 .44507 .45548 Metetra
.664 .741 .908 r
.44507 .45548 .4502 .46082 .45912 .45793 .45401 .45257 Metetra
.664 .741 .908 r
.45401 .45257 .45912 .45793 .46808 .45503 .46298 .44965 Metetra
.664 .741 .908 r
.46298 .44965 .46808 .45503 .47706 .45212 .47198 .44673 Metetra
.664 .741 .908 r
.47198 .44673 .47706 .45212 .48607 .44921 .48101 .44379 Metetra
.664 .741 .908 r
.48101 .44379 .48607 .44921 .49511 .44628 .49007 .44085 Metetra
.664 .741 .908 r
.49007 .44085 .49511 .44628 .50418 .44334 .49916 .43789 Metetra
.664 .741 .908 r
.49916 .43789 .50418 .44334 .51328 .44039 .50828 .43493 Metetra
.664 .741 .908 r
.50828 .43493 .51328 .44039 .52241 .43744 .51743 .43195 Metetra
.664 .741 .908 r
.51743 .43195 .52241 .43744 .53157 .43447 .52661 .42897 Metetra
.664 .741 .908 r
.52661 .42897 .53157 .43447 .54076 .43149 .53582 .42597 Metetra
.664 .741 .908 r
.53582 .42597 .54076 .43149 .54998 .42851 .54507 .42297 Metetra
.664 .741 .908 r
.54507 .42297 .54998 .42851 .55924 .42551 .55434 .41995 Metetra
.664 .741 .908 r
.55434 .41995 .55924 .42551 .56852 .4225 .56364 .41693 Metetra
.664 .741 .908 r
.56364 .41693 .56852 .4225 .57784 .41949 .57298 .41389 Metetra
.664 .741 .908 r
.57298 .41389 .57784 .41949 .58718 .41646 .58235 .41084 Metetra
.664 .741 .908 r
.58235 .41084 .58718 .41646 .59656 .41342 .59175 .40779 Metetra
.664 .741 .908 r
.59175 .40779 .59656 .41342 .60597 .41037 .60118 .40472 Metetra
.664 .741 .908 r
.60118 .40472 .60597 .41037 .61541 .40732 .61064 .40164 Metetra
.664 .741 .908 r
.61064 .40164 .61541 .40732 .62489 .40425 .62014 .39856 Metetra
.664 .741 .908 r
.62014 .39856 .62489 .40425 .63439 .40117 .62967 .39546 Metetra
.664 .741 .908 r
.62967 .39546 .63439 .40117 .64393 .39808 .63923 .39235 Metetra
.664 .741 .908 r
.63923 .39235 .64393 .39808 .6535 .39498 .64882 .38923 Metetra
.664 .741 .908 r
.64882 .38923 .6535 .39498 .66311 .39187 .65845 .3861 Metetra
.664 .741 .908 r
.65845 .3861 .66311 .39187 .67274 .38875 .6681 .38296 Metetra
.664 .741 .908 r
.6681 .38296 .67274 .38875 .68241 .38562 .6778 .37981 Metetra
.664 .741 .908 r
.6778 .37981 .68241 .38562 .69212 .38248 .68752 .37665 Metetra
.664 .741 .908 r
.68752 .37665 .69212 .38248 .70185 .37932 .69728 .37348 Metetra
.664 .741 .908 r
.69728 .37348 .70185 .37932 .71162 .37616 .70707 .37029 Metetra
.664 .741 .908 r
.70707 .37029 .71162 .37616 .72143 .37299 .7169 .3671 Metetra
.664 .741 .908 r
.7169 .3671 .72143 .37299 .73126 .3698 .72676 .36389 Metetra
.664 .741 .908 r
.72676 .36389 .73126 .3698 .74113 .3666 .73666 .36067 Metetra
.664 .741 .908 r
.73666 .36067 .74113 .3666 .75104 .3634 .74659 .35744 Metetra
.664 .741 .908 r
.74659 .35744 .75104 .3634 .76098 .36018 .75655 .3542 Metetra
.664 .741 .908 r
.75655 .3542 .76098 .36018 .77095 .35695 .76655 .35095 Metetra
.664 .741 .908 r
.76655 .35095 .77095 .35695 .78096 .35371 .77658 .34769 Metetra
.664 .741 .908 r
.77658 .34769 .78096 .35371 .79101 .35045 .78665 .34442 Metetra
.664 .741 .908 r
.78665 .34442 .79101 .35045 .80108 .34719 .79675 .34113 Metetra
.664 .741 .908 r
.79675 .34113 .80108 .34719 .8112 .34391 .80689 .33784 Metetra
.664 .741 .908 r
.80689 .33784 .8112 .34391 .82135 .34063 .81707 .33453 Metetra
.664 .741 .908 r
.81707 .33453 .82135 .34063 .83153 .33733 .82728 .33121 Metetra
.664 .741 .908 r
.82728 .33121 .83153 .33733 .84176 .33402 .83753 .32788 Metetra
.664 .741 .908 r
.83753 .32788 .84176 .33402 .85201 .3307 .84781 .32453 Metetra
.664 .741 .908 r
.84781 .32453 .85201 .3307 .86231 .32736 .85813 .32118 Metetra
.664 .741 .908 r
.85813 .32118 .86231 .32736 .87264 .32402 .86849 .31781 Metetra
.664 .741 .908 r
.86849 .31781 .87264 .32402 .883 .32066 .87888 .31443 Metetra
.664 .741 .908 r
.87888 .31443 .883 .32066 .89341 .31729 .88931 .31104 Metetra
.664 .741 .908 r
.292 .49839 .29746 .50347 .30592 .50072 .30048 .49562 Metetra
.664 .741 .908 r
.30048 .49562 .30592 .50072 .31441 .49796 .30898 .49284 Metetra
.664 .741 .908 r
.30898 .49284 .31441 .49796 .32292 .49519 .31751 .49006 Metetra
.664 .741 .908 r
.31751 .49006 .32292 .49519 .33147 .49241 .32607 .48726 Metetra
.664 .741 .908 r
.32607 .48726 .33147 .49241 .34004 .48963 .33466 .48446 Metetra
.664 .741 .908 r
.33466 .48446 .34004 .48963 .34863 .48683 .34327 .48165 Metetra
.664 .741 .908 r
.34327 .48165 .34863 .48683 .35726 .48403 .35191 .47883 Metetra
.664 .741 .908 r
.35191 .47883 .35726 .48403 .36591 .48122 .36058 .476 Metetra
.664 .741 .908 r
.36058 .476 .36591 .48122 .37459 .47839 .36928 .47316 Metetra
.664 .741 .908 r
.36928 .47316 .37459 .47839 .3833 .47556 .37801 .47031 Metetra
.664 .741 .908 r
.37801 .47031 .3833 .47556 .39204 .47272 .38676 .46745 Metetra
.664 .741 .908 r
.38676 .46745 .39204 .47272 .40081 .46987 .39555 .46458 Metetra
.664 .741 .908 r
.39555 .46458 .40081 .46987 .4096 .46701 .40436 .46171 Metetra
.664 .741 .908 r
.40436 .46171 .4096 .46701 .41842 .46414 .4132 .45882 Metetra
.664 .741 .908 r
.4132 .45882 .41842 .46414 .42728 .46126 .42208 .45592 Metetra
.664 .741 .908 r
.42208 .45592 .42728 .46126 .43616 .45838 .43098 .45302 Metetra
.664 .741 .908 r
.43098 .45302 .43616 .45838 .44507 .45548 .43991 .4501 Metetra
.664 .741 .908 r
.43991 .4501 .44507 .45548 .45401 .45257 .44886 .44718 Metetra
.664 .741 .908 r
.44886 .44718 .45401 .45257 .46298 .44965 .45785 .44425 Metetra
.664 .741 .908 r
.45785 .44425 .46298 .44965 .47198 .44673 .46687 .4413 Metetra
.664 .741 .908 r
.46687 .4413 .47198 .44673 .48101 .44379 .47592 .43835 Metetra
.664 .741 .908 r
.47592 .43835 .48101 .44379 .49007 .44085 .485 .43538 Metetra
.664 .741 .908 r
.485 .43538 .49007 .44085 .49916 .43789 .49411 .43241 Metetra
.664 .741 .908 r
.49411 .43241 .49916 .43789 .50828 .43493 .50325 .42943 Metetra
.664 .741 .908 r
.50325 .42943 .50828 .43493 .51743 .43195 .51242 .42643 Metetra
.664 .741 .908 r
.51242 .42643 .51743 .43195 .52661 .42897 .52162 .42343 Metetra
.664 .741 .908 r
.52162 .42343 .52661 .42897 .53582 .42597 .53085 .42042 Metetra
.664 .741 .908 r
.53085 .42042 .53582 .42597 .54507 .42297 .54012 .41739 Metetra
.664 .741 .908 r
.54012 .41739 .54507 .42297 .55434 .41995 .54941 .41436 Metetra
.664 .741 .908 r
.54941 .41436 .55434 .41995 .56364 .41693 .55874 .41131 Metetra
.664 .741 .908 r
.55874 .41131 .56364 .41693 .57298 .41389 .56809 .40826 Metetra
.664 .741 .908 r
.56809 .40826 .57298 .41389 .58235 .41084 .57748 .40519 Metetra
.664 .741 .908 r
.57748 .40519 .58235 .41084 .59175 .40779 .5869 .40212 Metetra
.664 .741 .908 r
.5869 .40212 .59175 .40779 .60118 .40472 .59636 .39903 Metetra
.664 .741 .908 r
.59636 .39903 .60118 .40472 .61064 .40164 .60584 .39594 Metetra
.664 .741 .908 r
.60584 .39594 .61064 .40164 .62014 .39856 .61536 .39283 Metetra
.664 .741 .908 r
.61536 .39283 .62014 .39856 .62967 .39546 .62491 .38971 Metetra
.664 .741 .908 r
.62491 .38971 .62967 .39546 .63923 .39235 .63449 .38658 Metetra
.664 .741 .908 r
.63449 .38658 .63923 .39235 .64882 .38923 .64411 .38345 Metetra
.664 .741 .908 r
.64411 .38345 .64882 .38923 .65845 .3861 .65375 .3803 Metetra
.664 .741 .908 r
.65375 .3803 .65845 .3861 .6681 .38296 .66344 .37714 Metetra
.664 .741 .908 r
.66344 .37714 .6681 .38296 .6778 .37981 .67315 .37396 Metetra
.664 .741 .908 r
.67315 .37396 .6778 .37981 .68752 .37665 .6829 .37078 Metetra
.664 .741 .908 r
.6829 .37078 .68752 .37665 .69728 .37348 .69268 .36759 Metetra
.664 .741 .908 r
.69268 .36759 .69728 .37348 .70707 .37029 .7025 .36438 Metetra
.664 .741 .908 r
.7025 .36438 .70707 .37029 .7169 .3671 .71235 .36117 Metetra
.664 .741 .908 r
.71235 .36117 .7169 .3671 .72676 .36389 .72223 .35794 Metetra
.664 .741 .908 r
.72223 .35794 .72676 .36389 .73666 .36067 .73215 .3547 Metetra
.664 .741 .908 r
.73215 .3547 .73666 .36067 .74659 .35744 .7421 .35145 Metetra
.664 .741 .908 r
.7421 .35145 .74659 .35744 .75655 .3542 .75209 .34819 Metetra
.664 .741 .908 r
.75209 .34819 .75655 .3542 .76655 .35095 .76211 .34492 Metetra
.664 .741 .908 r
.76211 .34492 .76655 .35095 .77658 .34769 .77217 .34164 Metetra
.664 .741 .908 r
.77217 .34164 .77658 .34769 .78665 .34442 .78227 .33834 Metetra
.664 .741 .908 r
.78227 .33834 .78665 .34442 .79675 .34113 .7924 .33504 Metetra
.664 .741 .908 r
.7924 .33504 .79675 .34113 .80689 .33784 .80256 .33172 Metetra
.664 .741 .908 r
.80256 .33172 .80689 .33784 .81707 .33453 .81276 .32839 Metetra
.664 .741 .908 r
.81276 .32839 .81707 .33453 .82728 .33121 .823 .32505 Metetra
.664 .741 .908 r
.823 .32505 .82728 .33121 .83753 .32788 .83327 .32169 Metetra
.664 .741 .908 r
.83327 .32169 .83753 .32788 .84781 .32453 .84358 .31833 Metetra
.664 .741 .908 r
.84358 .31833 .84781 .32453 .85813 .32118 .85393 .31495 Metetra
.664 .741 .908 r
.85393 .31495 .85813 .32118 .86849 .31781 .86431 .31156 Metetra
.664 .741 .908 r
.86431 .31156 .86849 .31781 .87888 .31443 .87473 .30816 Metetra
.664 .741 .908 r
.87473 .30816 .87888 .31443 .88931 .31104 .88519 .30475 Metetra
.664 .741 .908 r
.28651 .49327 .292 .49839 .30048 .49562 .295 .49049 Metetra
.664 .741 .908 r
.295 .49049 .30048 .49562 .30898 .49284 .30352 .48769 Metetra
.664 .741 .908 r
.30352 .48769 .30898 .49284 .31751 .49006 .31207 .48489 Metetra
.664 .741 .908 r
.31207 .48489 .31751 .49006 .32607 .48726 .32064 .48208 Metetra
.664 .741 .908 r
.32064 .48208 .32607 .48726 .33466 .48446 .32925 .47926 Metetra
.664 .741 .908 r
.32925 .47926 .33466 .48446 .34327 .48165 .33788 .47643 Metetra
.664 .741 .908 r
.33788 .47643 .34327 .48165 .35191 .47883 .34654 .4736 Metetra
.664 .741 .908 r
.34654 .4736 .35191 .47883 .36058 .476 .35523 .47075 Metetra
.664 .741 .908 r
.35523 .47075 .36058 .476 .36928 .47316 .36394 .46789 Metetra
.664 .741 .908 r
.36394 .46789 .36928 .47316 .37801 .47031 .37269 .46503 Metetra
.664 .741 .908 r
.37269 .46503 .37801 .47031 .38676 .46745 .38146 .46215 Metetra
.664 .741 .908 r
.38146 .46215 .38676 .46745 .39555 .46458 .39026 .45927 Metetra
.664 .741 .908 r
.39026 .45927 .39555 .46458 .40436 .46171 .39909 .45637 Metetra
.664 .741 .908 r
.39909 .45637 .40436 .46171 .4132 .45882 .40795 .45347 Metetra
.664 .741 .908 r
.40795 .45347 .4132 .45882 .42208 .45592 .41684 .45055 Metetra
.664 .741 .908 r
.41684 .45055 .42208 .45592 .43098 .45302 .42576 .44763 Metetra
.664 .741 .908 r
.42576 .44763 .43098 .45302 .43991 .4501 .43471 .4447 Metetra
.664 .741 .908 r
.43471 .4447 .43991 .4501 .44886 .44718 .44369 .44175 Metetra
.664 .741 .908 r
.44369 .44175 .44886 .44718 .45785 .44425 .4527 .4388 Metetra
.664 .741 .908 r
.4527 .4388 .45785 .44425 .46687 .4413 .46173 .43584 Metetra
.664 .741 .908 r
.46173 .43584 .46687 .4413 .47592 .43835 .4708 .43287 Metetra
.664 .741 .908 r
.4708 .43287 .47592 .43835 .485 .43538 .4799 .42989 Metetra
.664 .741 .908 r
.4799 .42989 .485 .43538 .49411 .43241 .48903 .42689 Metetra
.664 .741 .908 r
.48903 .42689 .49411 .43241 .50325 .42943 .49819 .42389 Metetra
.664 .741 .908 r
.49819 .42389 .50325 .42943 .51242 .42643 .50738 .42088 Metetra
.664 .741 .908 r
.50738 .42088 .51242 .42643 .52162 .42343 .5166 .41786 Metetra
.664 .741 .908 r
.5166 .41786 .52162 .42343 .53085 .42042 .52585 .41482 Metetra
.664 .741 .908 r
.52585 .41482 .53085 .42042 .54012 .41739 .53514 .41178 Metetra
.664 .741 .908 r
.53514 .41178 .54012 .41739 .54941 .41436 .54445 .40873 Metetra
.664 .741 .908 r
.54445 .40873 .54941 .41436 .55874 .41131 .5538 .40567 Metetra
.664 .741 .908 r
.5538 .40567 .55874 .41131 .56809 .40826 .56317 .40259 Metetra
.664 .741 .908 r
.56317 .40259 .56809 .40826 .57748 .40519 .57258 .39951 Metetra
.664 .741 .908 r
.57258 .39951 .57748 .40519 .5869 .40212 .58203 .39641 Metetra
.664 .741 .908 r
.58203 .39641 .5869 .40212 .59636 .39903 .5915 .39331 Metetra
.664 .741 .908 r
.5915 .39331 .59636 .39903 .60584 .39594 .60101 .39019 Metetra
.664 .741 .908 r
.60101 .39019 .60584 .39594 .61536 .39283 .61055 .38707 Metetra
.664 .741 .908 r
.61055 .38707 .61536 .39283 .62491 .38971 .62012 .38393 Metetra
.664 .741 .908 r
.62012 .38393 .62491 .38971 .63449 .38658 .62972 .38078 Metetra
.664 .741 .908 r
.62972 .38078 .63449 .38658 .64411 .38345 .63936 .37762 Metetra
.664 .741 .908 r
.63936 .37762 .64411 .38345 .65375 .3803 .64903 .37445 Metetra
.664 .741 .908 r
.64903 .37445 .65375 .3803 .66344 .37714 .65874 .37127 Metetra
.664 .741 .908 r
.65874 .37127 .66344 .37714 .67315 .37396 .66847 .36808 Metetra
.664 .741 .908 r
.66847 .36808 .67315 .37396 .6829 .37078 .67825 .36488 Metetra
.664 .741 .908 r
.67825 .36488 .6829 .37078 .69268 .36759 .68805 .36166 Metetra
.664 .741 .908 r
.68805 .36166 .69268 .36759 .7025 .36438 .69789 .35844 Metetra
.664 .741 .908 r
.69789 .35844 .7025 .36438 .71235 .36117 .70776 .3552 Metetra
.664 .741 .908 r
.70776 .3552 .71235 .36117 .72223 .35794 .71767 .35196 Metetra
.664 .741 .908 r
.71767 .35196 .72223 .35794 .73215 .3547 .72762 .3487 Metetra
.664 .741 .908 r
.72762 .3487 .73215 .3547 .7421 .35145 .73759 .34543 Metetra
.664 .741 .908 r
.73759 .34543 .7421 .35145 .75209 .34819 .74761 .34214 Metetra
.664 .741 .908 r
.74761 .34214 .75209 .34819 .76211 .34492 .75765 .33885 Metetra
.664 .741 .908 r
.75765 .33885 .76211 .34492 .77217 .34164 .76774 .33555 Metetra
.664 .741 .908 r
.76774 .33555 .77217 .34164 .78227 .33834 .77785 .33223 Metetra
.664 .741 .908 r
.77785 .33223 .78227 .33834 .7924 .33504 .78801 .3289 Metetra
.664 .741 .908 r
.78801 .3289 .7924 .33504 .80256 .33172 .7982 .32556 Metetra
.664 .741 .908 r
.7982 .32556 .80256 .33172 .81276 .32839 .80843 .32221 Metetra
.664 .741 .908 r
.80843 .32221 .81276 .32839 .823 .32505 .81869 .31885 Metetra
.664 .741 .908 r
.81869 .31885 .823 .32505 .83327 .32169 .82899 .31547 Metetra
.664 .741 .908 r
.82899 .31547 .83327 .32169 .84358 .31833 .83932 .31208 Metetra
.664 .741 .908 r
.83932 .31208 .84358 .31833 .85393 .31495 .8497 .30868 Metetra
.664 .741 .908 r
.8497 .30868 .85393 .31495 .86431 .31156 .86011 .30527 Metetra
.664 .741 .908 r
.86011 .30527 .86431 .31156 .87473 .30816 .87055 .30185 Metetra
.664 .741 .908 r
.87055 .30185 .87473 .30816 .88519 .30475 .88104 .29841 Metetra
.664 .741 .908 r
.28098 .48812 .28651 .49327 .295 .49049 .28949 .48532 Metetra
.664 .741 .908 r
.28949 .48532 .295 .49049 .30352 .48769 .29803 .48252 Metetra
.664 .741 .908 r
.29803 .48252 .30352 .48769 .31207 .48489 .30659 .4797 Metetra
.664 .741 .908 r
.30659 .4797 .31207 .48489 .32064 .48208 .31518 .47687 Metetra
.664 .741 .908 r
.31518 .47687 .32064 .48208 .32925 .47926 .3238 .47403 Metetra
.664 .741 .908 r
.3238 .47403 .32925 .47926 .33788 .47643 .33245 .47119 Metetra
.664 .741 .908 r
.33245 .47119 .33788 .47643 .34654 .4736 .34113 .46833 Metetra
.664 .741 .908 r
.34113 .46833 .34654 .4736 .35523 .47075 .34983 .46547 Metetra
.664 .741 .908 r
.34983 .46547 .35523 .47075 .36394 .46789 .35857 .46259 Metetra
.664 .741 .908 r
.35857 .46259 .36394 .46789 .37269 .46503 .36733 .45971 Metetra
.664 .741 .908 r
.36733 .45971 .37269 .46503 .38146 .46215 .37612 .45682 Metetra
.664 .741 .908 r
.37612 .45682 .38146 .46215 .39026 .45927 .38494 .45391 Metetra
.664 .741 .908 r
.38494 .45391 .39026 .45927 .39909 .45637 .39379 .451 Metetra
.664 .741 .908 r
.39379 .451 .39909 .45637 .40795 .45347 .40267 .44808 Metetra
.664 .741 .908 r
.40267 .44808 .40795 .45347 .41684 .45055 .41158 .44515 Metetra
.664 .741 .908 r
.41158 .44515 .41684 .45055 .42576 .44763 .42051 .44221 Metetra
.664 .741 .908 r
.42051 .44221 .42576 .44763 .43471 .4447 .42948 .43926 Metetra
.664 .741 .908 r
.42948 .43926 .43471 .4447 .44369 .44175 .43848 .4363 Metetra
.664 .741 .908 r
.43848 .4363 .44369 .44175 .4527 .4388 .44751 .43333 Metetra
.664 .741 .908 r
.44751 .43333 .4527 .4388 .46173 .43584 .45656 .43035 Metetra
.664 .741 .908 r
.45656 .43035 .46173 .43584 .4708 .43287 .46565 .42735 Metetra
.664 .741 .908 r
.46565 .42735 .4708 .43287 .4799 .42989 .47477 .42435 Metetra
.664 .741 .908 r
.47477 .42435 .4799 .42989 .48903 .42689 .48392 .42134 Metetra
.664 .741 .908 r
.48392 .42134 .48903 .42689 .49819 .42389 .4931 .41832 Metetra
.664 .741 .908 r
.4931 .41832 .49819 .42389 .50738 .42088 .50231 .41529 Metetra
.664 .741 .908 r
.50231 .41529 .50738 .42088 .5166 .41786 .51155 .41225 Metetra
.664 .741 .908 r
.51155 .41225 .5166 .41786 .52585 .41482 .52082 .4092 Metetra
.664 .741 .908 r
.52082 .4092 .52585 .41482 .53514 .41178 .53012 .40614 Metetra
.664 .741 .908 r
.53012 .40614 .53514 .41178 .54445 .40873 .53946 .40307 Metetra
.965 .671 .423 r
.53946 .40307 .54445 .40873 .5538 .40567 .55043 .61563 Metetra
.545 .32 .524 r
.55043 .61563 .5538 .40567 .56317 .40259 .56046 .61272 Metetra
.545 .32 .524 r
.56046 .61272 .56317 .40259 .57258 .39951 .57053 .6098 Metetra
.545 .32 .524 r
.57053 .6098 .57258 .39951 .58203 .39641 .58064 .60687 Metetra
0 0 .35 r
.58064 .60687 .58203 .39641 .5915 .39331 .58662 .38755 Metetra
.664 .741 .908 r
.58662 .38755 .5915 .39331 .60101 .39019 .59614 .38441 Metetra
.664 .741 .908 r
.59614 .38441 .60101 .39019 .61055 .38707 .60571 .38127 Metetra
.664 .741 .908 r
.60571 .38127 .61055 .38707 .62012 .38393 .6153 .37811 Metetra
.664 .741 .908 r
.6153 .37811 .62012 .38393 .62972 .38078 .62493 .37494 Metetra
.664 .741 .908 r
.62493 .37494 .62972 .38078 .63936 .37762 .63459 .37176 Metetra
.664 .741 .908 r
.63459 .37176 .63936 .37762 .64903 .37445 .64428 .36857 Metetra
.664 .741 .908 r
.64428 .36857 .64903 .37445 .65874 .37127 .65401 .36537 Metetra
.664 .741 .908 r
.65401 .36537 .65874 .37127 .66847 .36808 .66377 .36216 Metetra
.664 .741 .908 r
.66377 .36216 .66847 .36808 .67825 .36488 .67356 .35894 Metetra
.664 .741 .908 r
.67356 .35894 .67825 .36488 .68805 .36166 .68339 .3557 Metetra
.664 .741 .908 r
.68339 .3557 .68805 .36166 .69789 .35844 .69325 .35246 Metetra
.664 .741 .908 r
.69325 .35246 .69789 .35844 .70776 .3552 .70315 .3492 Metetra
.664 .741 .908 r
.70315 .3492 .70776 .3552 .71767 .35196 .71308 .34593 Metetra
.664 .741 .908 r
.71308 .34593 .71767 .35196 .72762 .3487 .72305 .34265 Metetra
.664 .741 .908 r
.72305 .34265 .72762 .3487 .73759 .34543 .73305 .33936 Metetra
.664 .741 .908 r
.73305 .33936 .73759 .34543 .74761 .34214 .74309 .33606 Metetra
.664 .741 .908 r
.74309 .33606 .74761 .34214 .75765 .33885 .75316 .33274 Metetra
.664 .741 .908 r
.75316 .33274 .75765 .33885 .76774 .33555 .76327 .32942 Metetra
.664 .741 .908 r
.76327 .32942 .76774 .33555 .77785 .33223 .77341 .32608 Metetra
.664 .741 .908 r
.77341 .32608 .77785 .33223 .78801 .3289 .78359 .32273 Metetra
.664 .741 .908 r
.78359 .32273 .78801 .3289 .7982 .32556 .79381 .31937 Metetra
.664 .741 .908 r
.79381 .31937 .7982 .32556 .80843 .32221 .80406 .31599 Metetra
.664 .741 .908 r
.80406 .31599 .80843 .32221 .81869 .31885 .81435 .31261 Metetra
.664 .741 .908 r
.81435 .31261 .81869 .31885 .82899 .31547 .82468 .30921 Metetra
.664 .741 .908 r
.82468 .30921 .82899 .31547 .83932 .31208 .83504 .3058 Metetra
.664 .741 .908 r
.83504 .3058 .83932 .31208 .8497 .30868 .84544 .30238 Metetra
.664 .741 .908 r
.84544 .30238 .8497 .30868 .86011 .30527 .85587 .29894 Metetra
.664 .741 .908 r
.85587 .29894 .86011 .30527 .87055 .30185 .86635 .29549 Metetra
.664 .741 .908 r
.86635 .29549 .87055 .30185 .88104 .29841 .87686 .29204 Metetra
.664 .741 .908 r
.27542 .48295 .28098 .48812 .28949 .48532 .28395 .48013 Metetra
.664 .741 .908 r
.28395 .48013 .28949 .48532 .29803 .48252 .2925 .47731 Metetra
.664 .741 .908 r
.2925 .47731 .29803 .48252 .30659 .4797 .30108 .47447 Metetra
.664 .741 .908 r
.30108 .47447 .30659 .4797 .31518 .47687 .30969 .47163 Metetra
.664 .741 .908 r
.30969 .47163 .31518 .47687 .3238 .47403 .31833 .46877 Metetra
.664 .741 .908 r
.31833 .46877 .3238 .47403 .33245 .47119 .32699 .46591 Metetra
.664 .741 .908 r
.32699 .46591 .33245 .47119 .34113 .46833 .33569 .46304 Metetra
.664 .741 .908 r
.33569 .46304 .34113 .46833 .34983 .46547 .34441 .46015 Metetra
.664 .741 .908 r
.34441 .46015 .34983 .46547 .35857 .46259 .35316 .45726 Metetra
.664 .741 .908 r
.35316 .45726 .35857 .46259 .36733 .45971 .36194 .45436 Metetra
.664 .741 .908 r
.36194 .45436 .36733 .45971 .37612 .45682 .37075 .45145 Metetra
.664 .741 .908 r
.37075 .45145 .37612 .45682 .38494 .45391 .37959 .44853 Metetra
.664 .741 .908 r
.37959 .44853 .38494 .45391 .39379 .451 .38846 .4456 Metetra
.664 .741 .908 r
.38846 .4456 .39379 .451 .40267 .44808 .39735 .44266 Metetra
.664 .741 .908 r
.39735 .44266 .40267 .44808 .41158 .44515 .40628 .43971 Metetra
.664 .741 .908 r
.40628 .43971 .41158 .44515 .42051 .44221 .41524 .43675 Metetra
.664 .741 .908 r
.41524 .43675 .42051 .44221 .42948 .43926 .42422 .43378 Metetra
.664 .741 .908 r
.42422 .43378 .42948 .43926 .43848 .4363 .43324 .4308 Metetra
.664 .741 .908 r
.43324 .4308 .43848 .4363 .44751 .43333 .44228 .42782 Metetra
.664 .741 .908 r
.44228 .42782 .44751 .43333 .45656 .43035 .45136 .42482 Metetra
.664 .741 .908 r
.45136 .42482 .45656 .43035 .46565 .42735 .46047 .42181 Metetra
.664 .741 .908 r
.46047 .42181 .46565 .42735 .47477 .42435 .4696 .41879 Metetra
.664 .741 .908 r
.4696 .41879 .47477 .42435 .48392 .42134 .47877 .41576 Metetra
.664 .741 .908 r
.47877 .41576 .48392 .42134 .4931 .41832 .48797 .41272 Metetra
.664 .741 .908 r
.48797 .41272 .4931 .41832 .50231 .41529 .4972 .40967 Metetra
.664 .741 .908 r
.4972 .40967 .50231 .41529 .51155 .41225 .50646 .40661 Metetra
.664 .741 .908 r
.50646 .40661 .51155 .41225 .52082 .4092 .51576 .40354 Metetra
.964 .672 .431 r
.51576 .40354 .52082 .4092 .53012 .40614 .52509 .61608 Metetra
.544 .318 .523 r
.52509 .61608 .53012 .40614 .53946 .40307 .53508 .61317 Metetra
.544 .318 .523 r
.53508 .61317 .53946 .40307 .55043 .61563 .5451 .61025 Metetra
.646 .762 .934 r
.5451 .61025 .55043 .61563 .56046 .61272 .55515 .60732 Metetra
.646 .762 .934 r
.55515 .60732 .56046 .61272 .57053 .6098 .56525 .60438 Metetra
.646 .762 .934 r
.56525 .60438 .57053 .6098 .58064 .60687 .57538 .60143 Metetra
.646 .762 .934 r
.57538 .60143 .58064 .60687 .58662 .38755 .58554 .59847 Metetra
.544 .318 .523 r
.58554 .59847 .58662 .38755 .59614 .38441 .59575 .5955 Metetra
0 0 .354 r
.59575 .5955 .59614 .38441 .60571 .38127 .60083 .37543 Metetra
.664 .741 .908 r
.60083 .37543 .60571 .38127 .6153 .37811 .61045 .37225 Metetra
.664 .741 .908 r
.61045 .37225 .6153 .37811 .62493 .37494 .6201 .36906 Metetra
.664 .741 .908 r
.6201 .36906 .62493 .37494 .63459 .37176 .62978 .36586 Metetra
.664 .741 .908 r
.62978 .36586 .63459 .37176 .64428 .36857 .6395 .36265 Metetra
.664 .741 .908 r
.6395 .36265 .64428 .36857 .65401 .36537 .64925 .35943 Metetra
.664 .741 .908 r
.64925 .35943 .65401 .36537 .66377 .36216 .65903 .3562 Metetra
.664 .741 .908 r
.65903 .3562 .66377 .36216 .67356 .35894 .66885 .35296 Metetra
.664 .741 .908 r
.66885 .35296 .67356 .35894 .68339 .3557 .6787 .3497 Metetra
.664 .741 .908 r
.6787 .3497 .68339 .3557 .69325 .35246 .68859 .34643 Metetra
.664 .741 .908 r
.68859 .34643 .69325 .35246 .70315 .3492 .69851 .34316 Metetra
.664 .741 .908 r
.69851 .34316 .70315 .3492 .71308 .34593 .70847 .33987 Metetra
.664 .741 .908 r
.70847 .33987 .71308 .34593 .72305 .34265 .71846 .33656 Metetra
.664 .741 .908 r
.71846 .33656 .72305 .34265 .73305 .33936 .72848 .33325 Metetra
.664 .741 .908 r
.72848 .33325 .73305 .33936 .74309 .33606 .73855 .32993 Metetra
.664 .741 .908 r
.73855 .32993 .74309 .33606 .75316 .33274 .74864 .32659 Metetra
.664 .741 .908 r
.74864 .32659 .75316 .33274 .76327 .32942 .75878 .32324 Metetra
.664 .741 .908 r
.75878 .32324 .76327 .32942 .77341 .32608 .76894 .31988 Metetra
.664 .741 .908 r
.76894 .31988 .77341 .32608 .78359 .32273 .77915 .31651 Metetra
.664 .741 .908 r
.77915 .31651 .78359 .32273 .79381 .31937 .78939 .31313 Metetra
.664 .741 .908 r
.78939 .31313 .79381 .31937 .80406 .31599 .79967 .30973 Metetra
.664 .741 .908 r
.79967 .30973 .80406 .31599 .81435 .31261 .80998 .30632 Metetra
.664 .741 .908 r
.80998 .30632 .81435 .31261 .82468 .30921 .82034 .3029 Metetra
.664 .741 .908 r
.82034 .3029 .82468 .30921 .83504 .3058 .83072 .29947 Metetra
.664 .741 .908 r
.83072 .29947 .83504 .3058 .84544 .30238 .84115 .29603 Metetra
.664 .741 .908 r
.84115 .29603 .84544 .30238 .85587 .29894 .85161 .29257 Metetra
.664 .741 .908 r
.85161 .29257 .85587 .29894 .86635 .29549 .86211 .2891 Metetra
.664 .741 .908 r
.86211 .2891 .86635 .29549 .87686 .29204 .87265 .28562 Metetra
.664 .741 .908 r
.26983 .47774 .27542 .48295 .28395 .48013 .27837 .47491 Metetra
.664 .741 .908 r
.27837 .47491 .28395 .48013 .2925 .47731 .28694 .47206 Metetra
.664 .741 .908 r
.28694 .47206 .2925 .47731 .30108 .47447 .29554 .46921 Metetra
.664 .741 .908 r
.29554 .46921 .30108 .47447 .30969 .47163 .30417 .46635 Metetra
.664 .741 .908 r
.30417 .46635 .30969 .47163 .31833 .46877 .31282 .46348 Metetra
.664 .741 .908 r
.31282 .46348 .31833 .46877 .32699 .46591 .3215 .4606 Metetra
.664 .741 .908 r
.3215 .4606 .32699 .46591 .33569 .46304 .33021 .45771 Metetra
.664 .741 .908 r
.33021 .45771 .33569 .46304 .34441 .46015 .33895 .45481 Metetra
.664 .741 .908 r
.33895 .45481 .34441 .46015 .35316 .45726 .34772 .4519 Metetra
.664 .741 .908 r
.34772 .4519 .35316 .45726 .36194 .45436 .35652 .44898 Metetra
.664 .741 .908 r
.35652 .44898 .36194 .45436 .37075 .45145 .36535 .44605 Metetra
.664 .741 .908 r
.36535 .44605 .37075 .45145 .37959 .44853 .3742 .44311 Metetra
.664 .741 .908 r
.3742 .44311 .37959 .44853 .38846 .4456 .38309 .44017 Metetra
.664 .741 .908 r
.38309 .44017 .38846 .4456 .39735 .44266 .392 .43721 Metetra
.664 .741 .908 r
.392 .43721 .39735 .44266 .40628 .43971 .40095 .43424 Metetra
.664 .741 .908 r
.40095 .43424 .40628 .43971 .41524 .43675 .40992 .43126 Metetra
.664 .741 .908 r
.40992 .43126 .41524 .43675 .42422 .43378 .41893 .42828 Metetra
.664 .741 .908 r
.41893 .42828 .42422 .43378 .43324 .4308 .42796 .42528 Metetra
.664 .741 .908 r
.42796 .42528 .43324 .4308 .44228 .42782 .43703 .42227 Metetra
.664 .741 .908 r
.43703 .42227 .44228 .42782 .45136 .42482 .44612 .41925 Metetra
.664 .741 .908 r
.44612 .41925 .45136 .42482 .46047 .42181 .45525 .41623 Metetra
.664 .741 .908 r
.45525 .41623 .46047 .42181 .4696 .41879 .46441 .41319 Metetra
.664 .741 .908 r
.46441 .41319 .4696 .41879 .47877 .41576 .4736 .41014 Metetra
.664 .741 .908 r
.4736 .41014 .47877 .41576 .48797 .41272 .48282 .40708 Metetra
.664 .741 .908 r
.48282 .40708 .48797 .41272 .4972 .40967 .49207 .40401 Metetra
.962 .673 .438 r
.49207 .40401 .4972 .40967 .50646 .40661 .49977 .61652 Metetra
.543 .317 .522 r
.49977 .61652 .50646 .40661 .51576 .40354 .50971 .61362 Metetra
.543 .317 .522 r
.50971 .61362 .51576 .40354 .52509 .61608 .51968 .6107 Metetra
.646 .762 .934 r
.51968 .6107 .52509 .61608 .53508 .61317 .52969 .60777 Metetra
.646 .762 .934 r
.52969 .60777 .53508 .61317 .5451 .61025 .53973 .60484 Metetra
.646 .762 .934 r
.53973 .60484 .5451 .61025 .55515 .60732 .54981 .60189 Metetra
.646 .762 .934 r
.54981 .60189 .55515 .60732 .56525 .60438 .55993 .59893 Metetra
.646 .762 .934 r
.55993 .59893 .56525 .60438 .57538 .60143 .57008 .59596 Metetra
.646 .762 .934 r
.57008 .59596 .57538 .60143 .58554 .59847 .58027 .59298 Metetra
.646 .762 .934 r
.58027 .59298 .58554 .59847 .59575 .5955 .5905 .58999 Metetra
.646 .762 .934 r
.5905 .58999 .59575 .5955 .60083 .37543 .60077 .58698 Metetra
.543 .317 .522 r
.60077 .58698 .60083 .37543 .61045 .37225 .61107 .58397 Metetra
0 0 .358 r
.61107 .58397 .61045 .37225 .6201 .36906 .61524 .36315 Metetra
.664 .741 .908 r
.61524 .36315 .6201 .36906 .62978 .36586 .62495 .35993 Metetra
.664 .741 .908 r
.62495 .35993 .62978 .36586 .6395 .36265 .63468 .3567 Metetra
.664 .741 .908 r
.63468 .3567 .6395 .36265 .64925 .35943 .64446 .35346 Metetra
.664 .741 .908 r
.64446 .35346 .64925 .35943 .65903 .3562 .65426 .3502 Metetra
.664 .741 .908 r
.65426 .3502 .65903 .3562 .66885 .35296 .66411 .34694 Metetra
.664 .741 .908 r
.66411 .34694 .66885 .35296 .6787 .3497 .67398 .34366 Metetra
.664 .741 .908 r
.67398 .34366 .6787 .3497 .68859 .34643 .68389 .34037 Metetra
.664 .741 .908 r
.68389 .34037 .68859 .34643 .69851 .34316 .69384 .33707 Metetra
.664 .741 .908 r
.69384 .33707 .69851 .34316 .70847 .33987 .70382 .33376 Metetra
.664 .741 .908 r
.70382 .33376 .70847 .33987 .71846 .33656 .71383 .33044 Metetra
.664 .741 .908 r
.71383 .33044 .71846 .33656 .72848 .33325 .72388 .32711 Metetra
.664 .741 .908 r
.72388 .32711 .72848 .33325 .73855 .32993 .73397 .32376 Metetra
.664 .741 .908 r
.73397 .32376 .73855 .32993 .74864 .32659 .74409 .3204 Metetra
.664 .741 .908 r
.74409 .3204 .74864 .32659 .75878 .32324 .75425 .31703 Metetra
.664 .741 .908 r
.75425 .31703 .75878 .32324 .76894 .31988 .76445 .31365 Metetra
.664 .741 .908 r
.76445 .31365 .76894 .31988 .77915 .31651 .77468 .31025 Metetra
.664 .741 .908 r
.77468 .31025 .77915 .31651 .78939 .31313 .78494 .30685 Metetra
.664 .741 .908 r
.78494 .30685 .78939 .31313 .79967 .30973 .79525 .30343 Metetra
.664 .741 .908 r
.79525 .30343 .79967 .30973 .80998 .30632 .80559 .3 Metetra
.664 .741 .908 r
.80559 .3 .80998 .30632 .82034 .3029 .81597 .29656 Metetra
.664 .741 .908 r
.81597 .29656 .82034 .3029 .83072 .29947 .82638 .2931 Metetra
.664 .741 .908 r
.82638 .2931 .83072 .29947 .84115 .29603 .83683 .28963 Metetra
.664 .741 .908 r
.83683 .28963 .84115 .29603 .85161 .29257 .84732 .28615 Metetra
.664 .741 .908 r
.84732 .28615 .85161 .29257 .86211 .2891 .85785 .28266 Metetra
.664 .741 .908 r
.85785 .28266 .86211 .2891 .87265 .28562 .86842 .27915 Metetra
.664 .741 .908 r
.2642 .4725 .26983 .47774 .27837 .47491 .27276 .46965 Metetra
.664 .741 .908 r
.27276 .46965 .27837 .47491 .28694 .47206 .28135 .46679 Metetra
.664 .741 .908 r
.28135 .46679 .28694 .47206 .29554 .46921 .28996 .46392 Metetra
.664 .741 .908 r
.28996 .46392 .29554 .46921 .30417 .46635 .29861 .46104 Metetra
.664 .741 .908 r
.29861 .46104 .30417 .46635 .31282 .46348 .30728 .45815 Metetra
.664 .741 .908 r
.30728 .45815 .31282 .46348 .3215 .4606 .31598 .45526 Metetra
.664 .741 .908 r
.31598 .45526 .3215 .4606 .33021 .45771 .32471 .45235 Metetra
.664 .741 .908 r
.32471 .45235 .33021 .45771 .33895 .45481 .33346 .44943 Metetra
.664 .741 .908 r
.33346 .44943 .33895 .45481 .34772 .4519 .34225 .4465 Metetra
.664 .741 .908 r
.34225 .4465 .34772 .4519 .35652 .44898 .35107 .44357 Metetra
.664 .741 .908 r
.35107 .44357 .35652 .44898 .36535 .44605 .35991 .44062 Metetra
.664 .741 .908 r
.35991 .44062 .36535 .44605 .3742 .44311 .36878 .43766 Metetra
.664 .741 .908 r
.36878 .43766 .3742 .44311 .38309 .44017 .37769 .4347 Metetra
.664 .741 .908 r
.37769 .4347 .38309 .44017 .392 .43721 .38662 .43172 Metetra
.664 .741 .908 r
.38662 .43172 .392 .43721 .40095 .43424 .39559 .42874 Metetra
.664 .741 .908 r
.39559 .42874 .40095 .43424 .40992 .43126 .40458 .42574 Metetra
.664 .741 .908 r
.40458 .42574 .40992 .43126 .41893 .42828 .4136 .42273 Metetra
.664 .741 .908 r
.4136 .42273 .41893 .42828 .42796 .42528 .42266 .41972 Metetra
.664 .741 .908 r
.42266 .41972 .42796 .42528 .43703 .42227 .43174 .41669 Metetra
.664 .741 .908 r
.43174 .41669 .43703 .42227 .44612 .41925 .44086 .41366 Metetra
.664 .741 .908 r
.44086 .41366 .44612 .41925 .45525 .41623 .45 .41061 Metetra
.664 .741 .908 r
.45 .41061 .45525 .41623 .46441 .41319 .45918 .40755 Metetra
.664 .741 .908 r
.45918 .40755 .46441 .41319 .4736 .41014 .46839 .40449 Metetra
.664 .741 .908 r
.46839 .40449 .4736 .41014 .48282 .40708 .47763 .40141 Metetra
.664 .741 .908 r
.47763 .40141 .48282 .40708 .49207 .40401 .4869 .39832 Metetra
.962 .673 .438 r
.4869 .39832 .49207 .40401 .49977 .61652 .49428 .61115 Metetra
.646 .762 .934 r
.49428 .61115 .49977 .61652 .50971 .61362 .50423 .60822 Metetra
.646 .762 .934 r
.50423 .60822 .50971 .61362 .51968 .6107 .51423 .60529 Metetra
.646 .762 .934 r
.51423 .60529 .51968 .6107 .52969 .60777 .52426 .60234 Metetra
.646 .762 .934 r
.52426 .60234 .52969 .60777 .53973 .60484 .53433 .59938 Metetra
.646 .762 .934 r
.53433 .59938 .53973 .60484 .54981 .60189 .54443 .59642 Metetra
.646 .762 .934 r
.54443 .59642 .54981 .60189 .55993 .59893 .55457 .59344 Metetra
.646 .762 .934 r
.55457 .59344 .55993 .59893 .57008 .59596 .56475 .59045 Metetra
.646 .762 .934 r
.56475 .59045 .57008 .59596 .58027 .59298 .57497 .58745 Metetra
.646 .762 .934 r
.57497 .58745 .58027 .59298 .5905 .58999 .58522 .58443 Metetra
.646 .762 .934 r
.58522 .58443 .5905 .58999 .60077 .58698 .59551 .58141 Metetra
.646 .762 .934 r
.59551 .58141 .60077 .58698 .61107 .58397 .60584 .57838 Metetra
.97 .702 .466 r
.60584 .57838 .61107 .58397 .61524 .36315 .61035 .3572 Metetra
.664 .741 .908 r
.61035 .3572 .61524 .36315 .62495 .35993 .62008 .35396 Metetra
.664 .741 .908 r
.62008 .35396 .62495 .35993 .63468 .3567 .62984 .3507 Metetra
.664 .741 .908 r
.62984 .3507 .63468 .3567 .64446 .35346 .63964 .34744 Metetra
.664 .741 .908 r
.63964 .34744 .64446 .35346 .65426 .3502 .64947 .34417 Metetra
.664 .741 .908 r
.64947 .34417 .65426 .3502 .66411 .34694 .65933 .34088 Metetra
.664 .741 .908 r
.65933 .34088 .66411 .34694 .67398 .34366 .66923 .33758 Metetra
.664 .741 .908 r
.66923 .33758 .67398 .34366 .68389 .34037 .67917 .33427 Metetra
.664 .741 .908 r
.67917 .33427 .68389 .34037 .69384 .33707 .68913 .33095 Metetra
.664 .741 .908 r
.68913 .33095 .69384 .33707 .70382 .33376 .69914 .32762 Metetra
.664 .741 .908 r
.69914 .32762 .70382 .33376 .71383 .33044 .70918 .32427 Metetra
.664 .741 .908 r
.70918 .32427 .71383 .33044 .72388 .32711 .71925 .32092 Metetra
.664 .741 .908 r
.71925 .32092 .72388 .32711 .73397 .32376 .72937 .31755 Metetra
.664 .741 .908 r
.72937 .31755 .73397 .32376 .74409 .3204 .73951 .31417 Metetra
.664 .741 .908 r
.73951 .31417 .74409 .3204 .75425 .31703 .7497 .31078 Metetra
.664 .741 .908 r
.7497 .31078 .75425 .31703 .76445 .31365 .75992 .30737 Metetra
.664 .741 .908 r
.75992 .30737 .76445 .31365 .77468 .31025 .77017 .30396 Metetra
.664 .741 .908 r
.77017 .30396 .77468 .31025 .78494 .30685 .78047 .30053 Metetra
.664 .741 .908 r
.78047 .30053 .78494 .30685 .79525 .30343 .7908 .29709 Metetra
.664 .741 .908 r
.7908 .29709 .79525 .30343 .80559 .3 .80116 .29363 Metetra
.664 .741 .908 r
.80116 .29363 .80559 .3 .81597 .29656 .81157 .29017 Metetra
.664 .741 .908 r
.81157 .29017 .81597 .29656 .82638 .2931 .82201 .28669 Metetra
.664 .741 .908 r
.82201 .28669 .82638 .2931 .83683 .28963 .83249 .2832 Metetra
.664 .741 .908 r
.83249 .2832 .83683 .28963 .84732 .28615 .84301 .27969 Metetra
.664 .741 .908 r
.84301 .27969 .84732 .28615 .85785 .28266 .85356 .27618 Metetra
.664 .741 .908 r
.85356 .27618 .85785 .28266 .86842 .27915 .86416 .27265 Metetra
.664 .741 .908 r
.25854 .46723 .2642 .4725 .27276 .46965 .26712 .46436 Metetra
.664 .741 .908 r
.26712 .46436 .27276 .46965 .28135 .46679 .27572 .46149 Metetra
.664 .741 .908 r
.27572 .46149 .28135 .46679 .28996 .46392 .28435 .4586 Metetra
.664 .741 .908 r
.28435 .4586 .28996 .46392 .29861 .46104 .29301 .4557 Metetra
.664 .741 .908 r
.29301 .4557 .29861 .46104 .30728 .45815 .3017 .4528 Metetra
.664 .741 .908 r
.3017 .4528 .30728 .45815 .31598 .45526 .31042 .44988 Metetra
.664 .741 .908 r
.31042 .44988 .31598 .45526 .32471 .45235 .31916 .44695 Metetra
.664 .741 .908 r
.31916 .44695 .32471 .45235 .33346 .44943 .32794 .44402 Metetra
.664 .741 .908 r
.32794 .44402 .33346 .44943 .34225 .4465 .33674 .44107 Metetra
.664 .741 .908 r
.33674 .44107 .34225 .4465 .35107 .44357 .34558 .43812 Metetra
.664 .741 .908 r
.34558 .43812 .35107 .44357 .35991 .44062 .35444 .43516 Metetra
.664 .741 .908 r
.35444 .43516 .35991 .44062 .36878 .43766 .36333 .43218 Metetra
.664 .741 .908 r
.36333 .43218 .36878 .43766 .37769 .4347 .37226 .4292 Metetra
.664 .741 .908 r
.37226 .4292 .37769 .4347 .38662 .43172 .38121 .4262 Metetra
.664 .741 .908 r
.38121 .4262 .38662 .43172 .39559 .42874 .39019 .4232 Metetra
.664 .741 .908 r
.39019 .4232 .39559 .42874 .40458 .42574 .3992 .42018 Metetra
.664 .741 .908 r
.3992 .42018 .40458 .42574 .4136 .42273 .40825 .41716 Metetra
.664 .741 .908 r
.40825 .41716 .4136 .42273 .42266 .41972 .41732 .41412 Metetra
.664 .741 .908 r
.41732 .41412 .42266 .41972 .43174 .41669 .42642 .41108 Metetra
.664 .741 .908 r
.42642 .41108 .43174 .41669 .44086 .41366 .43556 .40802 Metetra
.664 .741 .908 r
.43556 .40802 .44086 .41366 .45 .41061 .44472 .40496 Metetra
.664 .741 .908 r
.44472 .40496 .45 .41061 .45918 .40755 .45392 .40188 Metetra
.664 .741 .908 r
.45392 .40188 .45918 .40755 .46839 .40449 .46315 .39879 Metetra
.664 .741 .908 r
.46315 .39879 .46839 .40449 .47763 .40141 .47241 .3957 Metetra
.961 .673 .441 r
.47241 .3957 .47763 .40141 .4869 .39832 .47879 .60867 Metetra
.541 .313 .519 r
.47879 .60867 .4869 .39832 .49428 .61115 .48874 .60574 Metetra
.646 .762 .934 r
.48874 .60574 .49428 .61115 .50423 .60822 .49872 .6028 Metetra
.646 .762 .934 r
.49872 .6028 .50423 .60822 .51423 .60529 .50874 .59984 Metetra
.646 .762 .934 r
.50874 .59984 .51423 .60529 .52426 .60234 .51879 .59687 Metetra
.646 .762 .934 r
.51879 .59687 .52426 .60234 .53433 .59938 .52889 .5939 Metetra
.646 .762 .934 r
.52889 .5939 .53433 .59938 .54443 .59642 .53901 .59091 Metetra
.646 .762 .934 r
.53901 .59091 .54443 .59642 .55457 .59344 .54918 .58791 Metetra
.646 .762 .934 r
.54918 .58791 .55457 .59344 .56475 .59045 .55938 .5849 Metetra
.646 .762 .934 r
.55938 .5849 .56475 .59045 .57497 .58745 .56963 .58188 Metetra
.646 .762 .934 r
.56963 .58188 .57497 .58745 .58522 .58443 .57991 .57884 Metetra
.646 .762 .934 r
.57991 .57884 .58522 .58443 .59551 .58141 .59022 .5758 Metetra
.646 .762 .934 r
.59022 .5758 .59551 .58141 .60584 .57838 .60058 .57274 Metetra
.646 .762 .934 r
.60058 .57274 .60584 .57838 .61035 .3572 .61097 .56968 Metetra
0 0 .354 r
.61097 .56968 .61035 .3572 .62008 .35396 .61518 .34794 Metetra
.664 .741 .908 r
.61518 .34794 .62008 .35396 .62984 .3507 .62497 .34467 Metetra
.664 .741 .908 r
.62497 .34467 .62984 .3507 .63964 .34744 .63478 .34139 Metetra
.664 .741 .908 r
.63478 .34139 .63964 .34744 .64947 .34417 .64464 .33809 Metetra
.664 .741 .908 r
.64464 .33809 .64947 .34417 .65933 .34088 .65453 .33478 Metetra
.664 .741 .908 r
.65453 .33478 .65933 .34088 .66923 .33758 .66445 .33146 Metetra
.664 .741 .908 r
.66445 .33146 .66923 .33758 .67917 .33427 .67441 .32813 Metetra
.664 .741 .908 r
.67441 .32813 .67917 .33427 .68913 .33095 .6844 .32479 Metetra
.664 .741 .908 r
.6844 .32479 .68913 .33095 .69914 .32762 .69443 .32144 Metetra
.664 .741 .908 r
.69443 .32144 .69914 .32762 .70918 .32427 .70449 .31807 Metetra
.664 .741 .908 r
.70449 .31807 .70918 .32427 .71925 .32092 .71459 .31469 Metetra
.664 .741 .908 r
.71459 .31469 .71925 .32092 .72937 .31755 .72473 .3113 Metetra
.664 .741 .908 r
.72473 .3113 .72937 .31755 .73951 .31417 .7349 .3079 Metetra
.664 .741 .908 r
.7349 .3079 .73951 .31417 .7497 .31078 .74511 .30448 Metetra
.664 .741 .908 r
.74511 .30448 .7497 .31078 .75992 .30737 .75536 .30106 Metetra
.664 .741 .908 r
.75536 .30106 .75992 .30737 .77017 .30396 .76564 .29762 Metetra
.664 .741 .908 r
.76564 .29762 .77017 .30396 .78047 .30053 .77596 .29417 Metetra
.664 .741 .908 r
.77596 .29417 .78047 .30053 .7908 .29709 .78632 .2907 Metetra
.664 .741 .908 r
.78632 .2907 .7908 .29709 .80116 .29363 .79671 .28723 Metetra
.664 .741 .908 r
.79671 .28723 .80116 .29363 .81157 .29017 .80714 .28374 Metetra
.664 .741 .908 r
.80714 .28374 .81157 .29017 .82201 .28669 .81761 .28023 Metetra
.664 .741 .908 r
.81761 .28023 .82201 .28669 .83249 .2832 .82812 .27672 Metetra
.664 .741 .908 r
.82812 .27672 .83249 .2832 .84301 .27969 .83866 .27319 Metetra
.664 .741 .908 r
.83866 .27319 .84301 .27969 .85356 .27618 .84924 .26965 Metetra
.664 .741 .908 r
.84924 .26965 .85356 .27618 .86416 .27265 .85987 .2661 Metetra
.664 .741 .908 r
.25285 .46193 .25854 .46723 .26712 .46436 .26144 .45904 Metetra
.664 .741 .908 r
.26144 .45904 .26712 .46436 .27572 .46149 .27006 .45615 Metetra
.664 .741 .908 r
.27006 .45615 .27572 .46149 .28435 .4586 .27871 .45324 Metetra
.664 .741 .908 r
.27871 .45324 .28435 .4586 .29301 .4557 .28738 .45033 Metetra
.664 .741 .908 r
.28738 .45033 .29301 .4557 .3017 .4528 .29609 .4474 Metetra
.664 .741 .908 r
.29609 .4474 .3017 .4528 .31042 .44988 .30483 .44447 Metetra
.664 .741 .908 r
.30483 .44447 .31042 .44988 .31916 .44695 .31359 .44153 Metetra
.664 .741 .908 r
.31359 .44153 .31916 .44695 .32794 .44402 .32238 .43857 Metetra
.664 .741 .908 r
.32238 .43857 .32794 .44402 .33674 .44107 .3312 .43561 Metetra
.664 .741 .908 r
.3312 .43561 .33674 .44107 .34558 .43812 .34006 .43264 Metetra
.664 .741 .908 r
.34006 .43264 .34558 .43812 .35444 .43516 .34894 .42966 Metetra
.664 .741 .908 r
.34894 .42966 .35444 .43516 .36333 .43218 .35785 .42666 Metetra
.664 .741 .908 r
.35785 .42666 .36333 .43218 .37226 .4292 .36679 .42366 Metetra
.664 .741 .908 r
.36679 .42366 .37226 .4292 .38121 .4262 .37576 .42065 Metetra
.664 .741 .908 r
.37576 .42065 .38121 .4262 .39019 .4232 .38476 .41762 Metetra
.664 .741 .908 r
.38476 .41762 .39019 .4232 .3992 .42018 .39379 .41459 Metetra
.664 .741 .908 r
.39379 .41459 .3992 .42018 .40825 .41716 .40285 .41155 Metetra
.664 .741 .908 r
.40285 .41155 .40825 .41716 .41732 .41412 .41195 .40849 Metetra
.664 .741 .908 r
.41195 .40849 .41732 .41412 .42642 .41108 .42107 .40543 Metetra
.664 .741 .908 r
.42107 .40543 .42642 .41108 .43556 .40802 .43022 .40236 Metetra
.664 .741 .908 r
.43022 .40236 .43556 .40802 .44472 .40496 .43941 .39927 Metetra
.664 .741 .908 r
.43941 .39927 .44472 .40496 .45392 .40188 .44863 .39618 Metetra
.664 .741 .908 r
.44863 .39618 .45392 .40188 .46315 .39879 .45787 .39307 Metetra
.664 .741 .908 r
.45787 .39307 .46315 .39879 .47241 .3957 .46715 .38995 Metetra
.961 .673 .441 r
.46715 .38995 .47241 .3957 .47879 .60867 .4732 .60325 Metetra
.646 .762 .934 r
.4732 .60325 .47879 .60867 .48874 .60574 .48317 .6003 Metetra
.646 .762 .934 r
.48317 .6003 .48874 .60574 .49872 .6028 .49317 .59733 Metetra
.646 .762 .934 r
.49317 .59733 .49872 .6028 .50874 .59984 .50321 .59435 Metetra
.646 .762 .934 r
.50321 .59435 .50874 .59984 .51879 .59687 .51329 .59137 Metetra
.646 .762 .934 r
.51329 .59137 .51879 .59687 .52889 .5939 .52341 .58837 Metetra
.646 .762 .934 r
.52341 .58837 .52889 .5939 .53901 .59091 .53356 .58536 Metetra
.646 .762 .934 r
.53356 .58536 .53901 .59091 .54918 .58791 .54375 .58234 Metetra
.646 .762 .934 r
.54375 .58234 .54918 .58791 .55938 .5849 .55398 .57931 Metetra
.646 .762 .934 r
.55398 .57931 .55938 .5849 .56963 .58188 .56425 .57627 Metetra
.646 .762 .934 r
.56425 .57627 .56963 .58188 .57991 .57884 .57455 .57321 Metetra
.646 .762 .934 r
.57455 .57321 .57991 .57884 .59022 .5758 .5849 .57015 Metetra
.646 .762 .934 r
.5849 .57015 .59022 .5758 .60058 .57274 .59528 .56707 Metetra
.646 .762 .934 r
.59528 .56707 .60058 .57274 .61097 .56968 .6057 .56399 Metetra
.971 .702 .462 r
.6057 .56399 .61097 .56968 .61518 .34794 .61025 .34189 Metetra
.664 .741 .908 r
.61025 .34189 .61518 .34794 .62497 .34467 .62006 .3386 Metetra
.664 .741 .908 r
.62006 .3386 .62497 .34467 .63478 .34139 .6299 .33529 Metetra
.664 .741 .908 r
.6299 .33529 .63478 .34139 .64464 .33809 .63978 .33197 Metetra
.664 .741 .908 r
.63978 .33197 .64464 .33809 .65453 .33478 .64969 .32865 Metetra
.664 .741 .908 r
.64969 .32865 .65453 .33478 .66445 .33146 .65964 .32531 Metetra
.664 .741 .908 r
.65964 .32531 .66445 .33146 .67441 .32813 .66962 .32195 Metetra
.664 .741 .908 r
.66962 .32195 .67441 .32813 .6844 .32479 .67964 .31859 Metetra
.664 .741 .908 r
.67964 .31859 .6844 .32479 .69443 .32144 .68969 .31521 Metetra
.664 .741 .908 r
.68969 .31521 .69443 .32144 .70449 .31807 .69978 .31182 Metetra
.664 .741 .908 r
.69978 .31182 .70449 .31807 .71459 .31469 .7099 .30842 Metetra
.664 .741 .908 r
.7099 .30842 .71459 .31469 .72473 .3113 .72007 .30501 Metetra
.664 .741 .908 r
.72007 .30501 .72473 .3113 .7349 .3079 .73026 .30158 Metetra
.664 .741 .908 r
.73026 .30158 .7349 .3079 .74511 .30448 .7405 .29815 Metetra
.664 .741 .908 r
.7405 .29815 .74511 .30448 .75536 .30106 .75077 .2947 Metetra
.664 .741 .908 r
.75077 .2947 .75536 .30106 .76564 .29762 .76108 .29124 Metetra
.664 .741 .908 r
.76108 .29124 .76564 .29762 .77596 .29417 .77142 .28776 Metetra
.664 .741 .908 r
.77142 .28776 .77596 .29417 .78632 .2907 .7818 .28427 Metetra
.664 .741 .908 r
.7818 .28427 .78632 .2907 .79671 .28723 .79222 .28077 Metetra
.664 .741 .908 r
.79222 .28077 .79671 .28723 .80714 .28374 .80268 .27726 Metetra
.664 .741 .908 r
.80268 .27726 .80714 .28374 .81761 .28023 .81318 .27374 Metetra
.664 .741 .908 r
.81318 .27374 .81761 .28023 .82812 .27672 .82371 .2702 Metetra
.664 .741 .908 r
.82371 .2702 .82812 .27672 .83866 .27319 .83429 .26665 Metetra
.664 .741 .908 r
.83429 .26665 .83866 .27319 .84924 .26965 .8449 .26308 Metetra
.664 .741 .908 r
.8449 .26308 .84924 .26965 .85987 .2661 .85555 .25951 Metetra
.664 .741 .908 r
.24712 .45659 .25285 .46193 .26144 .45904 .25573 .45369 Metetra
.664 .741 .908 r
.25573 .45369 .26144 .45904 .27006 .45615 .26436 .45078 Metetra
.664 .741 .908 r
.26436 .45078 .27006 .45615 .27871 .45324 .27303 .44786 Metetra
.664 .741 .908 r
.27303 .44786 .27871 .45324 .28738 .45033 .28172 .44492 Metetra
.664 .741 .908 r
.28172 .44492 .28738 .45033 .29609 .4474 .29045 .44198 Metetra
.664 .741 .908 r
.29045 .44198 .29609 .4474 .30483 .44447 .2992 .43903 Metetra
.664 .741 .908 r
.2992 .43903 .30483 .44447 .31359 .44153 .30798 .43607 Metetra
.664 .741 .908 r
.30798 .43607 .31359 .44153 .32238 .43857 .31679 .4331 Metetra
.664 .741 .908 r
.31679 .4331 .32238 .43857 .3312 .43561 .32563 .43012 Metetra
.664 .741 .908 r
.32563 .43012 .3312 .43561 .34006 .43264 .3345 .42712 Metetra
.664 .741 .908 r
.3345 .42712 .34006 .43264 .34894 .42966 .3434 .42412 Metetra
.664 .741 .908 r
.3434 .42412 .34894 .42966 .35785 .42666 .35233 .42111 Metetra
.664 .741 .908 r
.35233 .42111 .35785 .42666 .36679 .42366 .36129 .41809 Metetra
.664 .741 .908 r
.36129 .41809 .36679 .42366 .37576 .42065 .37028 .41506 Metetra
.664 .741 .908 r
.37028 .41506 .37576 .42065 .38476 .41762 .3793 .41202 Metetra
.664 .741 .908 r
.3793 .41202 .38476 .41762 .39379 .41459 .38835 .40896 Metetra
.664 .741 .908 r
.38835 .40896 .39379 .41459 .40285 .41155 .39743 .4059 Metetra
.664 .741 .908 r
.39743 .4059 .40285 .41155 .41195 .40849 .40654 .40283 Metetra
.664 .741 .908 r
.40654 .40283 .41195 .40849 .42107 .40543 .41568 .39975 Metetra
.664 .741 .908 r
.41568 .39975 .42107 .40543 .43022 .40236 .42486 .39665 Metetra
.664 .741 .908 r
.42486 .39665 .43022 .40236 .43941 .39927 .43406 .39355 Metetra
.664 .741 .908 r
.43406 .39355 .43941 .39927 .44863 .39618 .4433 .39043 Metetra
.664 .741 .908 r
.4433 .39043 .44863 .39618 .45787 .39307 .45257 .38731 Metetra
.961 .673 .444 r
.45257 .38731 .45787 .39307 .46715 .38995 .45761 .60075 Metetra
.538 .31 .516 r
.45761 .60075 .46715 .38995 .4732 .60325 .46756 .59779 Metetra
.646 .762 .934 r
.46756 .59779 .4732 .60325 .48317 .6003 .47756 .59481 Metetra
.646 .762 .934 r
.47756 .59481 .48317 .6003 .49317 .59733 .48759 .59183 Metetra
.646 .762 .934 r
.48759 .59183 .49317 .59733 .50321 .59435 .49765 .58883 Metetra
.646 .762 .934 r
.49765 .58883 .50321 .59435 .51329 .59137 .50775 .58583 Metetra
.646 .762 .934 r
.50775 .58583 .51329 .59137 .52341 .58837 .51789 .58281 Metetra
.646 .762 .934 r
.51789 .58281 .52341 .58837 .53356 .58536 .52807 .57978 Metetra
.646 .762 .934 r
.52807 .57978 .53356 .58536 .54375 .58234 .53829 .57674 Metetra
.646 .762 .934 r
.53829 .57674 .54375 .58234 .55398 .57931 .54854 .57369 Metetra
.646 .762 .934 r
.54854 .57369 .55398 .57931 .56425 .57627 .55883 .57062 Metetra
.646 .762 .934 r
.55883 .57062 .56425 .57627 .57455 .57321 .56916 .56755 Metetra
.646 .762 .934 r
.56916 .56755 .57455 .57321 .5849 .57015 .57953 .56446 Metetra
.646 .762 .934 r
.57953 .56446 .5849 .57015 .59528 .56707 .58994 .56136 Metetra
.646 .762 .934 r
.58994 .56136 .59528 .56707 .6057 .56399 .60039 .55825 Metetra
.646 .762 .934 r
.60039 .55825 .6057 .56399 .61025 .34189 .61087 .55513 Metetra
0 0 .35 r
.61087 .55513 .61025 .34189 .62006 .3386 .61512 .33249 Metetra
.664 .741 .908 r
.61512 .33249 .62006 .3386 .6299 .33529 .62499 .32916 Metetra
.664 .741 .908 r
.62499 .32916 .6299 .33529 .63978 .33197 .63489 .32582 Metetra
.664 .741 .908 r
.63489 .32582 .63978 .33197 .64969 .32865 .64482 .32247 Metetra
.664 .741 .908 r
.64482 .32247 .64969 .32865 .65964 .32531 .65479 .31911 Metetra
.664 .741 .908 r
.65479 .31911 .65964 .32531 .66962 .32195 .6648 .31573 Metetra
.664 .741 .908 r
.6648 .31573 .66962 .32195 .67964 .31859 .67484 .31235 Metetra
.664 .741 .908 r
.67484 .31235 .67964 .31859 .68969 .31521 .68492 .30895 Metetra
.664 .741 .908 r
.68492 .30895 .68969 .31521 .69978 .31182 .69503 .30554 Metetra
.664 .741 .908 r
.69503 .30554 .69978 .31182 .7099 .30842 .70518 .30211 Metetra
.664 .741 .908 r
.70518 .30211 .7099 .30842 .72007 .30501 .71537 .29868 Metetra
.664 .741 .908 r
.71537 .29868 .72007 .30501 .73026 .30158 .72559 .29523 Metetra
.664 .741 .908 r
.72559 .29523 .73026 .30158 .7405 .29815 .73585 .29177 Metetra
.664 .741 .908 r
.73585 .29177 .7405 .29815 .75077 .2947 .74615 .2883 Metetra
.664 .741 .908 r
.74615 .2883 .75077 .2947 .76108 .29124 .75648 .28481 Metetra
.664 .741 .908 r
.75648 .28481 .76108 .29124 .77142 .28776 .76685 .28131 Metetra
.664 .741 .908 r
.76685 .28131 .77142 .28776 .7818 .28427 .77726 .2778 Metetra
.664 .741 .908 r
.77726 .2778 .7818 .28427 .79222 .28077 .78771 .27428 Metetra
.664 .741 .908 r
.78771 .27428 .79222 .28077 .80268 .27726 .7982 .27074 Metetra
.664 .741 .908 r
.7982 .27074 .80268 .27726 .81318 .27374 .80872 .2672 Metetra
.664 .741 .908 r
.80872 .2672 .81318 .27374 .82371 .2702 .81928 .26363 Metetra
.664 .741 .908 r
.81928 .26363 .82371 .2702 .83429 .26665 .82988 .26006 Metetra
.664 .741 .908 r
.82988 .26006 .83429 .26665 .8449 .26308 .84052 .25647 Metetra
.664 .741 .908 r
.84052 .25647 .8449 .26308 .85555 .25951 .8512 .25287 Metetra
.664 .741 .908 r
.24135 .45123 .24712 .45659 .25573 .45369 .24998 .44831 Metetra
.664 .741 .908 r
.24998 .44831 .25573 .45369 .26436 .45078 .25863 .44537 Metetra
.664 .741 .908 r
.25863 .44537 .26436 .45078 .27303 .44786 .26732 .44243 Metetra
.664 .741 .908 r
.26732 .44243 .27303 .44786 .28172 .44492 .27603 .43948 Metetra
.664 .741 .908 r
.27603 .43948 .28172 .44492 .29045 .44198 .28477 .43652 Metetra
.664 .741 .908 r
.28477 .43652 .29045 .44198 .2992 .43903 .29354 .43355 Metetra
.664 .741 .908 r
.29354 .43355 .2992 .43903 .30798 .43607 .30234 .43057 Metetra
.664 .741 .908 r
.30234 .43057 .30798 .43607 .31679 .4331 .31116 .42759 Metetra
.664 .741 .908 r
.31116 .42759 .31679 .4331 .32563 .43012 .32002 .42459 Metetra
.664 .741 .908 r
.32002 .42459 .32563 .43012 .3345 .42712 .32891 .42158 Metetra
.664 .741 .908 r
.32891 .42158 .3345 .42712 .3434 .42412 .33783 .41856 Metetra
.664 .741 .908 r
.33783 .41856 .3434 .42412 .35233 .42111 .34677 .41553 Metetra
.664 .741 .908 r
.34677 .41553 .35233 .42111 .36129 .41809 .35575 .41249 Metetra
.664 .741 .908 r
.35575 .41249 .36129 .41809 .37028 .41506 .36476 .40943 Metetra
.664 .741 .908 r
.36476 .40943 .37028 .41506 .3793 .41202 .3738 .40637 Metetra
.664 .741 .908 r
.3738 .40637 .3793 .41202 .38835 .40896 .38287 .4033 Metetra
.664 .741 .908 r
.38287 .4033 .38835 .40896 .39743 .4059 .39197 .40022 Metetra
.664 .741 .908 r
.39197 .40022 .39743 .4059 .40654 .40283 .4011 .39713 Metetra
.664 .741 .908 r
.4011 .39713 .40654 .40283 .41568 .39975 .41026 .39403 Metetra
.664 .741 .908 r
.41026 .39403 .41568 .39975 .42486 .39665 .41945 .39091 Metetra
.664 .741 .908 r
.41945 .39091 .42486 .39665 .43406 .39355 .42868 .38779 Metetra
.664 .741 .908 r
.42868 .38779 .43406 .39355 .4433 .39043 .43794 .38465 Metetra
.664 .741 .908 r
.43794 .38465 .4433 .39043 .45257 .38731 .44722 .38151 Metetra
.961 .673 .444 r
.44722 .38151 .45257 .38731 .45761 .60075 .45191 .59527 Metetra
.646 .762 .934 r
.45191 .59527 .45761 .60075 .46756 .59779 .46189 .59229 Metetra
.646 .762 .934 r
.46189 .59229 .46756 .59779 .47756 .59481 .47191 .58929 Metetra
.646 .762 .934 r
.47191 .58929 .47756 .59481 .48759 .59183 .48196 .58629 Metetra
.646 .762 .934 r
.48196 .58629 .48759 .59183 .49765 .58883 .49205 .58327 Metetra
.646 .762 .934 r
.49205 .58327 .49765 .58883 .50775 .58583 .50218 .58024 Metetra
.646 .762 .934 r
.50218 .58024 .50775 .58583 .51789 .58281 .51234 .57721 Metetra
.646 .762 .934 r
.51234 .57721 .51789 .58281 .52807 .57978 .52254 .57416 Metetra
.646 .762 .934 r
.52254 .57416 .52807 .57978 .53829 .57674 .53278 .57109 Metetra
.646 .762 .934 r
.53278 .57109 .53829 .57674 .54854 .57369 .54306 .56802 Metetra
.646 .762 .934 r
.54306 .56802 .54854 .57369 .55883 .57062 .55338 .56494 Metetra
.646 .762 .934 r
.55338 .56494 .55883 .57062 .56916 .56755 .56374 .56184 Metetra
.646 .762 .934 r
.56374 .56184 .56916 .56755 .57953 .56446 .57413 .55873 Metetra
.646 .762 .934 r
.57413 .55873 .57953 .56446 .58994 .56136 .58456 .55561 Metetra
.646 .762 .934 r
.58456 .55561 .58994 .56136 .60039 .55825 .59504 .55248 Metetra
.646 .762 .934 r
.59504 .55248 .60039 .55825 .61087 .55513 .60555 .54934 Metetra
.972 .702 .459 r
.60555 .54934 .61087 .55513 .61512 .33249 .61015 .32633 Metetra
.664 .741 .908 r
.61015 .32633 .61512 .33249 .62499 .32916 .62004 .32299 Metetra
.664 .741 .908 r
.62004 .32299 .62499 .32916 .63489 .32582 .62996 .31962 Metetra
.664 .741 .908 r
.62996 .31962 .63489 .32582 .64482 .32247 .63992 .31625 Metetra
.664 .741 .908 r
.63992 .31625 .64482 .32247 .65479 .31911 .64992 .31287 Metetra
.664 .741 .908 r
.64992 .31287 .65479 .31911 .6648 .31573 .65995 .30947 Metetra
.664 .741 .908 r
.65995 .30947 .6648 .31573 .67484 .31235 .67001 .30606 Metetra
.664 .741 .908 r
.67001 .30606 .67484 .31235 .68492 .30895 .68012 .30264 Metetra
.664 .741 .908 r
.68012 .30264 .68492 .30895 .69503 .30554 .69025 .29921 Metetra
.664 .741 .908 r
.69025 .29921 .69503 .30554 .70518 .30211 .70043 .29576 Metetra
.664 .741 .908 r
.70043 .29576 .70518 .30211 .71537 .29868 .71064 .2923 Metetra
.664 .741 .908 r
.71064 .2923 .71537 .29868 .72559 .29523 .72089 .28883 Metetra
.664 .741 .908 r
.72089 .28883 .72559 .29523 .73585 .29177 .73118 .28535 Metetra
.664 .741 .908 r
.73118 .28535 .73585 .29177 .74615 .2883 .7415 .28185 Metetra
.664 .741 .908 r
.7415 .28185 .74615 .2883 .75648 .28481 .75186 .27834 Metetra
.664 .741 .908 r
.75186 .27834 .75648 .28481 .76685 .28131 .76226 .27482 Metetra
.664 .741 .908 r
.76226 .27482 .76685 .28131 .77726 .2778 .77269 .27129 Metetra
.664 .741 .908 r
.77269 .27129 .77726 .2778 .78771 .27428 .78317 .26774 Metetra
.664 .741 .908 r
.78317 .26774 .78771 .27428 .7982 .27074 .79368 .26418 Metetra
.664 .741 .908 r
.79368 .26418 .7982 .27074 .80872 .2672 .80423 .26061 Metetra
.664 .741 .908 r
.80423 .26061 .80872 .2672 .81928 .26363 .81482 .25702 Metetra
.664 .741 .908 r
.81482 .25702 .81928 .26363 .82988 .26006 .82545 .25342 Metetra
.664 .741 .908 r
.82545 .25342 .82988 .26006 .84052 .25647 .83611 .24981 Metetra
.664 .741 .908 r
.83611 .24981 .84052 .25647 .8512 .25287 .84682 .24619 Metetra
.664 .741 .908 r
.23555 .44583 .24135 .45123 .24998 .44831 .2442 .44289 Metetra
.664 .741 .908 r
.2442 .44289 .24998 .44831 .25863 .44537 .25287 .43994 Metetra
.664 .741 .908 r
.25287 .43994 .25863 .44537 .26732 .44243 .26157 .43698 Metetra
.664 .741 .908 r
.26157 .43698 .26732 .44243 .27603 .43948 .2703 .43401 Metetra
.664 .741 .908 r
.2703 .43401 .27603 .43948 .28477 .43652 .27905 .43103 Metetra
.664 .741 .908 r
.27905 .43103 .28477 .43652 .29354 .43355 .28784 .42805 Metetra
.664 .741 .908 r
.28784 .42805 .29354 .43355 .30234 .43057 .29666 .42505 Metetra
.664 .741 .908 r
.29666 .42505 .30234 .43057 .31116 .42759 .3055 .42204 Metetra
.664 .741 .908 r
.3055 .42204 .31116 .42759 .32002 .42459 .31438 .41902 Metetra
.664 .741 .908 r
.31438 .41902 .32002 .42459 .32891 .42158 .32328 .41599 Metetra
.664 .741 .908 r
.32328 .41599 .32891 .42158 .33783 .41856 .33222 .41295 Metetra
.664 .741 .908 r
.33222 .41295 .33783 .41856 .34677 .41553 .34119 .4099 Metetra
.664 .741 .908 r
.34119 .4099 .34677 .41553 .35575 .41249 .35018 .40685 Metetra
.664 .741 .908 r
.35018 .40685 .35575 .41249 .36476 .40943 .35921 .40378 Metetra
.664 .741 .908 r
.35921 .40378 .36476 .40943 .3738 .40637 .36827 .4007 Metetra
.664 .741 .908 r
.36827 .4007 .3738 .40637 .38287 .4033 .37736 .39761 Metetra
.664 .741 .908 r
.37736 .39761 .38287 .4033 .39197 .40022 .38647 .3945 Metetra
.664 .741 .908 r
.38647 .3945 .39197 .40022 .4011 .39713 .39562 .39139 Metetra
.664 .741 .908 r
.39562 .39139 .4011 .39713 .41026 .39403 .40481 .38827 Metetra
.664 .741 .908 r
.40481 .38827 .41026 .39403 .41945 .39091 .41402 .38514 Metetra
.664 .741 .908 r
.41402 .38514 .41945 .39091 .42868 .38779 .42326 .38199 Metetra
.664 .741 .908 r
.42326 .38199 .42868 .38779 .43794 .38465 .43254 .37884 Metetra
.664 .741 .908 r
.43254 .37884 .43794 .38465 .44722 .38151 .44185 .37567 Metetra
.961 .673 .444 r
.44185 .37567 .44722 .38151 .45191 .59527 .44618 .58976 Metetra
.646 .762 .934 r
.44618 .58976 .45191 .59527 .46189 .59229 .45618 .58675 Metetra
.646 .762 .934 r
.45618 .58675 .46189 .59229 .47191 .58929 .46622 .58374 Metetra
.646 .762 .934 r
.46622 .58374 .47191 .58929 .48196 .58629 .4763 .58071 Metetra
.646 .762 .934 r
.4763 .58071 .48196 .58629 .49205 .58327 .48641 .57767 Metetra
.646 .762 .934 r
.48641 .57767 .49205 .58327 .50218 .58024 .49656 .57463 Metetra
.646 .762 .934 r
.49656 .57463 .50218 .58024 .51234 .57721 .50675 .57157 Metetra
.646 .762 .934 r
.50675 .57157 .51234 .57721 .52254 .57416 .51698 .56849 Metetra
.646 .762 .934 r
.51698 .56849 .52254 .57416 .53278 .57109 .52724 .56541 Metetra
.646 .762 .934 r
.52724 .56541 .53278 .57109 .54306 .56802 .53755 .56232 Metetra
.646 .762 .934 r
.53755 .56232 .54306 .56802 .55338 .56494 .54789 .55921 Metetra
.646 .762 .934 r
.54789 .55921 .55338 .56494 .56374 .56184 .55827 .55609 Metetra
.646 .762 .934 r
.55827 .55609 .56374 .56184 .57413 .55873 .56869 .55296 Metetra
.646 .762 .934 r
.56869 .55296 .57413 .55873 .58456 .55561 .57915 .54982 Metetra
.646 .762 .934 r
.57915 .54982 .58456 .55561 .59504 .55248 .58965 .54667 Metetra
.646 .762 .934 r
.58965 .54667 .59504 .55248 .60555 .54934 .60019 .54351 Metetra
.972 .702 .459 r
.60019 .54351 .60555 .54934 .61015 .32633 .60514 .32014 Metetra
.664 .741 .908 r
.60514 .32014 .61015 .32633 .62004 .32299 .61506 .31677 Metetra
.664 .741 .908 r
.61506 .31677 .62004 .32299 .62996 .31962 .62501 .31339 Metetra
.664 .741 .908 r
.62501 .31339 .62996 .31962 .63992 .31625 .63499 .30999 Metetra
.664 .741 .908 r
.63499 .30999 .63992 .31625 .64992 .31287 .64501 .30659 Metetra
.664 .741 .908 r
.64501 .30659 .64992 .31287 .65995 .30947 .65506 .30317 Metetra
.664 .741 .908 r
.65506 .30317 .65995 .30947 .67001 .30606 .66515 .29974 Metetra
.664 .741 .908 r
.66515 .29974 .67001 .30606 .68012 .30264 .67528 .29629 Metetra
.664 .741 .908 r
.67528 .29629 .68012 .30264 .69025 .29921 .68545 .29284 Metetra
.664 .741 .908 r
.68545 .29284 .69025 .29921 .70043 .29576 .69565 .28937 Metetra
.664 .741 .908 r
.69565 .28937 .70043 .29576 .71064 .2923 .70588 .28589 Metetra
.664 .741 .908 r
.70588 .28589 .71064 .2923 .72089 .28883 .71616 .28239 Metetra
.664 .741 .908 r
.71616 .28239 .72089 .28883 .73118 .28535 .72647 .27888 Metetra
.664 .741 .908 r
.72647 .27888 .73118 .28535 .7415 .28185 .73682 .27537 Metetra
.664 .741 .908 r
.73682 .27537 .7415 .28185 .75186 .27834 .7472 .27183 Metetra
.664 .741 .908 r
.7472 .27183 .75186 .27834 .76226 .27482 .75763 .26829 Metetra
.664 .741 .908 r
.75763 .26829 .76226 .27482 .77269 .27129 .76809 .26473 Metetra
.664 .741 .908 r
.76809 .26473 .77269 .27129 .78317 .26774 .77859 .26116 Metetra
.664 .741 .908 r
.77859 .26116 .78317 .26774 .79368 .26418 .78913 .25758 Metetra
.664 .741 .908 r
.78913 .25758 .79368 .26418 .80423 .26061 .79971 .25398 Metetra
.664 .741 .908 r
.79971 .25398 .80423 .26061 .81482 .25702 .81032 .25037 Metetra
.664 .741 .908 r
.81032 .25037 .81482 .25702 .82545 .25342 .82098 .24674 Metetra
.664 .741 .908 r
.82098 .24674 .82545 .25342 .83611 .24981 .83168 .24311 Metetra
.664 .741 .908 r
.83168 .24311 .83611 .24981 .84682 .24619 .84241 .23946 Metetra
.664 .741 .908 r
.22972 .44039 .23555 .44583 .2442 .44289 .23838 .43744 Metetra
.664 .741 .908 r
.23838 .43744 .2442 .44289 .25287 .43994 .24707 .43447 Metetra
.664 .741 .908 r
.24707 .43447 .25287 .43994 .26157 .43698 .25578 .43149 Metetra
.664 .741 .908 r
.25578 .43149 .26157 .43698 .2703 .43401 .26453 .42851 Metetra
.664 .741 .908 r
.26453 .42851 .2703 .43401 .27905 .43103 .2733 .42551 Metetra
.664 .741 .908 r
.2733 .42551 .27905 .43103 .28784 .42805 .28211 .4225 Metetra
.664 .741 .908 r
.28211 .4225 .28784 .42805 .29666 .42505 .29094 .41949 Metetra
.664 .741 .908 r
.29094 .41949 .29666 .42505 .3055 .42204 .29981 .41646 Metetra
.664 .741 .908 r
.29981 .41646 .3055 .42204 .31438 .41902 .3087 .41342 Metetra
.664 .741 .908 r
.3087 .41342 .31438 .41902 .32328 .41599 .31762 .41037 Metetra
.664 .741 .908 r
.31762 .41037 .32328 .41599 .33222 .41295 .32658 .40732 Metetra
.664 .741 .908 r
.32658 .40732 .33222 .41295 .34119 .4099 .33556 .40425 Metetra
.664 .741 .908 r
.33556 .40425 .34119 .4099 .35018 .40685 .34458 .40117 Metetra
.664 .741 .908 r
.34458 .40117 .35018 .40685 .35921 .40378 .35362 .39808 Metetra
.664 .741 .908 r
.35362 .39808 .35921 .40378 .36827 .4007 .3627 .39498 Metetra
.664 .741 .908 r
.3627 .39498 .36827 .4007 .37736 .39761 .37181 .39187 Metetra
.664 .741 .908 r
.37181 .39187 .37736 .39761 .38647 .3945 .38095 .38875 Metetra
.664 .741 .908 r
.38095 .38875 .38647 .3945 .39562 .39139 .39012 .38562 Metetra
.664 .741 .908 r
.39012 .38562 .39562 .39139 .40481 .38827 .39932 .38248 Metetra
.664 .741 .908 r
.39932 .38248 .40481 .38827 .41402 .38514 .40855 .37932 Metetra
.664 .741 .908 r
.40855 .37932 .41402 .38514 .42326 .38199 .41781 .37616 Metetra
.664 .741 .908 r
.41781 .37616 .42326 .38199 .43254 .37884 .42711 .37299 Metetra
.664 .741 .908 r
.42711 .37299 .43254 .37884 .44185 .37567 .43644 .3698 Metetra
.961 .673 .444 r
.43644 .3698 .44185 .37567 .44618 .58976 .44041 .5842 Metetra
.646 .762 .934 r
.44041 .5842 .44618 .58976 .45618 .58675 .45043 .58118 Metetra
.646 .762 .934 r
.45043 .58118 .45618 .58675 .46622 .58374 .46049 .57814 Metetra
.646 .762 .934 r
.46049 .57814 .46622 .58374 .4763 .58071 .47059 .5751 Metetra
.646 .762 .934 r
.47059 .5751 .4763 .58071 .48641 .57767 .48073 .57204 Metetra
.646 .762 .934 r
.48073 .57204 .48641 .57767 .49656 .57463 .49091 .56897 Metetra
.646 .762 .934 r
.49091 .56897 .49656 .57463 .50675 .57157 .50112 .56589 Metetra
.646 .762 .934 r
.50112 .56589 .50675 .57157 .51698 .56849 .51137 .56279 Metetra
.646 .762 .934 r
.51137 .56279 .51698 .56849 .52724 .56541 .52166 .55969 Metetra
.646 .762 .934 r
.52166 .55969 .52724 .56541 .53755 .56232 .53199 .55657 Metetra
.646 .762 .934 r
.53199 .55657 .53755 .56232 .54789 .55921 .54236 .55345 Metetra
.646 .762 .934 r
.54236 .55345 .54789 .55921 .55827 .55609 .55277 .55031 Metetra
.646 .762 .934 r
.55277 .55031 .55827 .55609 .56869 .55296 .56321 .54716 Metetra
.646 .762 .934 r
.56321 .54716 .56869 .55296 .57915 .54982 .5737 .54399 Metetra
.646 .762 .934 r
.5737 .54399 .57915 .54982 .58965 .54667 .58423 .54082 Metetra
.646 .762 .934 r
.58423 .54082 .58965 .54667 .60019 .54351 .59479 .53763 Metetra
.972 .702 .459 r
.59479 .53763 .60019 .54351 .60514 .32014 .60011 .31391 Metetra
.664 .741 .908 r
.60011 .31391 .60514 .32014 .61506 .31677 .61004 .31052 Metetra
.664 .741 .908 r
.61004 .31052 .61506 .31677 .62501 .31339 .62002 .30711 Metetra
.664 .741 .908 r
.62002 .30711 .62501 .31339 .63499 .30999 .63002 .30369 Metetra
.664 .741 .908 r
.63002 .30369 .63499 .30999 .64501 .30659 .64007 .30026 Metetra
.664 .741 .908 r
.64007 .30026 .64501 .30659 .65506 .30317 .65015 .29682 Metetra
.664 .741 .908 r
.65015 .29682 .65506 .30317 .66515 .29974 .66026 .29337 Metetra
.664 .741 .908 r
.66026 .29337 .66515 .29974 .67528 .29629 .67041 .2899 Metetra
.664 .741 .908 r
.67041 .2899 .67528 .29629 .68545 .29284 .6806 .28642 Metetra
.664 .741 .908 r
.6806 .28642 .68545 .29284 .69565 .28937 .69083 .28293 Metetra
.664 .741 .908 r
.69083 .28293 .69565 .28937 .70588 .28589 .70109 .27942 Metetra
.664 .741 .908 r
.70109 .27942 .70588 .28589 .71616 .28239 .71139 .27591 Metetra
.664 .741 .908 r
.71139 .27591 .71616 .28239 .72647 .27888 .72173 .27238 Metetra
.664 .741 .908 r
.72173 .27238 .72647 .27888 .73682 .27537 .7321 .26883 Metetra
.664 .741 .908 r
.7321 .26883 .73682 .27537 .7472 .27183 .74252 .26528 Metetra
.664 .741 .908 r
.74252 .26528 .7472 .27183 .75763 .26829 .75297 .26171 Metetra
.664 .741 .908 r
.75297 .26171 .75763 .26829 .76809 .26473 .76346 .25813 Metetra
.664 .741 .908 r
.76346 .25813 .76809 .26473 .77859 .26116 .77399 .25453 Metetra
.664 .741 .908 r
.77399 .25453 .77859 .26116 .78913 .25758 .78455 .25092 Metetra
.664 .741 .908 r
.78455 .25092 .78913 .25758 .79971 .25398 .79516 .2473 Metetra
.664 .741 .908 r
.79516 .2473 .79971 .25398 .81032 .25037 .8058 .24367 Metetra
.664 .741 .908 r
.8058 .24367 .81032 .25037 .82098 .24674 .81649 .24002 Metetra
.664 .741 .908 r
.81649 .24002 .82098 .24674 .83168 .24311 .82721 .23636 Metetra
.664 .741 .908 r
.82721 .23636 .83168 .24311 .84241 .23946 .83797 .23268 Metetra
.664 .741 .908 r
.22385 .43493 .22972 .44039 .23838 .43744 .23252 .43195 Metetra
.664 .741 .908 r
.23252 .43195 .23838 .43744 .24707 .43447 .24123 .42897 Metetra
.664 .741 .908 r
.24123 .42897 .24707 .43447 .25578 .43149 .24996 .42597 Metetra
.664 .741 .908 r
.24996 .42597 .25578 .43149 .26453 .42851 .25873 .42297 Metetra
.664 .741 .908 r
.25873 .42297 .26453 .42851 .2733 .42551 .26752 .41995 Metetra
.664 .741 .908 r
.26752 .41995 .2733 .42551 .28211 .4225 .27634 .41693 Metetra
.664 .741 .908 r
.27634 .41693 .28211 .4225 .29094 .41949 .28519 .41389 Metetra
.664 .741 .908 r
.28519 .41389 .29094 .41949 .29981 .41646 .29407 .41084 Metetra
.664 .741 .908 r
.29407 .41084 .29981 .41646 .3087 .41342 .30299 .40779 Metetra
.664 .741 .908 r
.30299 .40779 .3087 .41342 .31762 .41037 .31193 .40472 Metetra
.664 .741 .908 r
.31193 .40472 .31762 .41037 .32658 .40732 .3209 .40164 Metetra
.664 .741 .908 r
.3209 .40164 .32658 .40732 .33556 .40425 .3299 .39856 Metetra
.664 .741 .908 r
.3299 .39856 .33556 .40425 .34458 .40117 .33894 .39546 Metetra
.664 .741 .908 r
.33894 .39546 .34458 .40117 .35362 .39808 .348 .39235 Metetra
.664 .741 .908 r
.348 .39235 .35362 .39808 .3627 .39498 .3571 .38923 Metetra
.664 .741 .908 r
.3571 .38923 .3627 .39498 .37181 .39187 .36622 .3861 Metetra
.664 .741 .908 r
.36622 .3861 .37181 .39187 .38095 .38875 .37538 .38296 Metetra
.664 .741 .908 r
.37538 .38296 .38095 .38875 .39012 .38562 .38457 .37981 Metetra
.664 .741 .908 r
.38457 .37981 .39012 .38562 .39932 .38248 .39379 .37665 Metetra
.664 .741 .908 r
.39379 .37665 .39932 .38248 .40855 .37932 .40305 .37348 Metetra
.664 .741 .908 r
.40305 .37348 .40855 .37932 .41781 .37616 .41233 .37029 Metetra
.664 .741 .908 r
.41233 .37029 .41781 .37616 .42711 .37299 .42165 .3671 Metetra
.664 .741 .908 r
.42165 .3671 .42711 .37299 .43644 .3698 .431 .36389 Metetra
.664 .741 .908 r
.431 .36389 .43644 .3698 .44041 .5842 .44038 .36067 Metetra
0 0 .341 r
.44038 .36067 .44041 .5842 .45043 .58118 .44464 .57556 Metetra
.646 .762 .934 r
.44464 .57556 .45043 .58118 .46049 .57814 .45473 .57251 Metetra
.646 .762 .934 r
.45473 .57251 .46049 .57814 .47059 .5751 .46485 .56944 Metetra
.646 .762 .934 r
.46485 .56944 .47059 .5751 .48073 .57204 .47501 .56636 Metetra
.646 .762 .934 r
.47501 .56636 .48073 .57204 .49091 .56897 .48521 .56327 Metetra
.646 .762 .934 r
.48521 .56327 .49091 .56897 .50112 .56589 .49545 .56017 Metetra
.646 .762 .934 r
.49545 .56017 .50112 .56589 .51137 .56279 .50573 .55705 Metetra
.646 .762 .934 r
.50573 .55705 .51137 .56279 .52166 .55969 .51604 .55393 Metetra
.646 .762 .934 r
.51604 .55393 .52166 .55969 .53199 .55657 .5264 .55079 Metetra
.646 .762 .934 r
.5264 .55079 .53199 .55657 .54236 .55345 .53679 .54764 Metetra
.646 .762 .934 r
.53679 .54764 .54236 .55345 .55277 .55031 .54723 .54448 Metetra
.646 .762 .934 r
.54723 .54448 .55277 .55031 .56321 .54716 .5577 .54131 Metetra
.646 .762 .934 r
.5577 .54131 .56321 .54716 .5737 .54399 .56821 .53812 Metetra
.646 .762 .934 r
.56821 .53812 .5737 .54399 .58423 .54082 .57876 .53493 Metetra
.971 .702 .462 r
.57876 .53493 .58423 .54082 .59479 .53763 .58511 .31104 Metetra
.549 .338 .546 r
.58511 .31104 .59479 .53763 .60011 .31391 .59504 .30764 Metetra
.664 .741 .908 r
.59504 .30764 .60011 .31391 .61004 .31052 .605 .30422 Metetra
.664 .741 .908 r
.605 .30422 .61004 .31052 .62002 .30711 .61499 .30079 Metetra
.664 .741 .908 r
.61499 .30079 .62002 .30711 .63002 .30369 .62503 .29735 Metetra
.664 .741 .908 r
.62503 .29735 .63002 .30369 .64007 .30026 .63509 .2939 Metetra
.664 .741 .908 r
.63509 .2939 .64007 .30026 .65015 .29682 .6452 .29044 Metetra
.664 .741 .908 r
.6452 .29044 .65015 .29682 .66026 .29337 .65534 .28696 Metetra
.664 .741 .908 r
.65534 .28696 .66026 .29337 .67041 .2899 .66552 .28347 Metetra
.664 .741 .908 r
.66552 .28347 .67041 .2899 .6806 .28642 .67573 .27996 Metetra
.664 .741 .908 r
.67573 .27996 .6806 .28642 .69083 .28293 .68598 .27645 Metetra
.664 .741 .908 r
.68598 .27645 .69083 .28293 .70109 .27942 .69627 .27292 Metetra
.664 .741 .908 r
.69627 .27292 .70109 .27942 .71139 .27591 .70659 .26938 Metetra
.664 .741 .908 r
.70659 .26938 .71139 .27591 .72173 .27238 .71696 .26583 Metetra
.664 .741 .908 r
.71696 .26583 .72173 .27238 .7321 .26883 .72736 .26226 Metetra
.664 .741 .908 r
.72736 .26226 .7321 .26883 .74252 .26528 .7378 .25868 Metetra
.664 .741 .908 r
.7378 .25868 .74252 .26528 .75297 .26171 .74828 .25509 Metetra
.664 .741 .908 r
.74828 .25509 .75297 .26171 .76346 .25813 .75879 .25148 Metetra
.664 .741 .908 r
.75879 .25148 .76346 .25813 .77399 .25453 .76935 .24786 Metetra
.664 .741 .908 r
.76935 .24786 .77399 .25453 .78455 .25092 .77994 .24423 Metetra
.664 .741 .908 r
.77994 .24423 .78455 .25092 .79516 .2473 .79057 .24058 Metetra
.664 .741 .908 r
.79057 .24058 .79516 .2473 .8058 .24367 .80125 .23692 Metetra
.664 .741 .908 r
.80125 .23692 .8058 .24367 .81649 .24002 .81196 .23325 Metetra
.664 .741 .908 r
.81196 .23325 .81649 .24002 .82721 .23636 .82271 .22956 Metetra
.664 .741 .908 r
.82271 .22956 .82721 .23636 .83797 .23268 .8335 .22586 Metetra
.664 .741 .908 r
.21794 .42943 .22385 .43493 .23252 .43195 .22663 .42643 Metetra
.664 .741 .908 r
.22663 .42643 .23252 .43195 .24123 .42897 .23535 .42343 Metetra
.664 .741 .908 r
.23535 .42343 .24123 .42897 .24996 .42597 .24411 .42042 Metetra
.664 .741 .908 r
.24411 .42042 .24996 .42597 .25873 .42297 .25289 .41739 Metetra
.664 .741 .908 r
.25289 .41739 .25873 .42297 .26752 .41995 .2617 .41436 Metetra
.664 .741 .908 r
.2617 .41436 .26752 .41995 .27634 .41693 .27054 .41131 Metetra
.664 .741 .908 r
.27054 .41131 .27634 .41693 .28519 .41389 .27941 .40826 Metetra
.664 .741 .908 r
.27941 .40826 .28519 .41389 .29407 .41084 .28831 .40519 Metetra
.664 .741 .908 r
.28831 .40519 .29407 .41084 .30299 .40779 .29724 .40212 Metetra
.664 .741 .908 r
.29724 .40212 .30299 .40779 .31193 .40472 .3062 .39903 Metetra
.664 .741 .908 r
.3062 .39903 .31193 .40472 .3209 .40164 .31519 .39594 Metetra
.664 .741 .908 r
.31519 .39594 .3209 .40164 .3299 .39856 .32421 .39283 Metetra
.664 .741 .908 r
.32421 .39283 .3299 .39856 .33894 .39546 .33326 .38971 Metetra
.664 .741 .908 r
.33326 .38971 .33894 .39546 .348 .39235 .34235 .38658 Metetra
.664 .741 .908 r
.34235 .38658 .348 .39235 .3571 .38923 .35146 .38345 Metetra
.664 .741 .908 r
.35146 .38345 .3571 .38923 .36622 .3861 .36061 .3803 Metetra
.664 .741 .908 r
.36061 .3803 .36622 .3861 .37538 .38296 .36978 .37714 Metetra
.664 .741 .908 r
.36978 .37714 .37538 .38296 .38457 .37981 .37899 .37396 Metetra
.664 .741 .908 r
.37899 .37396 .38457 .37981 .39379 .37665 .38823 .37078 Metetra
.664 .741 .908 r
.38823 .37078 .39379 .37665 .40305 .37348 .39751 .36759 Metetra
.664 .741 .908 r
.39751 .36759 .40305 .37348 .41233 .37029 .40681 .36438 Metetra
.664 .741 .908 r
.40681 .36438 .41233 .37029 .42165 .3671 .41615 .36117 Metetra
.664 .741 .908 r
.41615 .36117 .42165 .3671 .431 .36389 .42552 .35794 Metetra
.664 .741 .908 r
.42552 .35794 .431 .36389 .44038 .36067 .43492 .3547 Metetra
.961 .673 .441 r
.43492 .3547 .44038 .36067 .44464 .57556 .43881 .56991 Metetra
.646 .762 .934 r
.43881 .56991 .44464 .57556 .45473 .57251 .44892 .56684 Metetra
.646 .762 .934 r
.44892 .56684 .45473 .57251 .46485 .56944 .45907 .56375 Metetra
.646 .762 .934 r
.45907 .56375 .46485 .56944 .47501 .56636 .46926 .56065 Metetra
.646 .762 .934 r
.46926 .56065 .47501 .56636 .48521 .56327 .47948 .55753 Metetra
.646 .762 .934 r
.47948 .55753 .48521 .56327 .49545 .56017 .48974 .55441 Metetra
.646 .762 .934 r
.48974 .55441 .49545 .56017 .50573 .55705 .50005 .55128 Metetra
.646 .762 .934 r
.50005 .55128 .50573 .55705 .51604 .55393 .51039 .54813 Metetra
.646 .762 .934 r
.51039 .54813 .51604 .55393 .5264 .55079 .52077 .54497 Metetra
.646 .762 .934 r
.52077 .54497 .5264 .55079 .53679 .54764 .53119 .5418 Metetra
.646 .762 .934 r
.53119 .5418 .53679 .54764 .54723 .54448 .54165 .53861 Metetra
.646 .762 .934 r
.54165 .53861 .54723 .54448 .5577 .54131 .55214 .53542 Metetra
.646 .762 .934 r
.55214 .53542 .5577 .54131 .56821 .53812 .56268 .53221 Metetra
.646 .762 .934 r
.56268 .53221 .56821 .53812 .57876 .53493 .57326 .52899 Metetra
.971 .702 .462 r
.57326 .52899 .57876 .53493 .58511 .31104 .57999 .30475 Metetra
.664 .741 .908 r
.57999 .30475 .58511 .31104 .59504 .30764 .58994 .30132 Metetra
.664 .741 .908 r
.58994 .30132 .59504 .30764 .605 .30422 .59992 .29788 Metetra
.664 .741 .908 r
.59992 .29788 .605 .30422 .61499 .30079 .60994 .29443 Metetra
.664 .741 .908 r
.60994 .29443 .61499 .30079 .62503 .29735 .61999 .29097 Metetra
.664 .741 .908 r
.61999 .29097 .62503 .29735 .63509 .2939 .63009 .28749 Metetra
.664 .741 .908 r
.63009 .28749 .63509 .2939 .6452 .29044 .64022 .28401 Metetra
.664 .741 .908 r
.64022 .28401 .6452 .29044 .65534 .28696 .65038 .2805 Metetra
.664 .741 .908 r
.65038 .2805 .65534 .28696 .66552 .28347 .66058 .27699 Metetra
.664 .741 .908 r
.66058 .27699 .66552 .28347 .67573 .27996 .67082 .27347 Metetra
.664 .741 .908 r
.67082 .27347 .67573 .27996 .68598 .27645 .6811 .26993 Metetra
.664 .741 .908 r
.6811 .26993 .68598 .27645 .69627 .27292 .69141 .26637 Metetra
.664 .741 .908 r
.69141 .26637 .69627 .27292 .70659 .26938 .70176 .26281 Metetra
.664 .741 .908 r
.70176 .26281 .70659 .26938 .71696 .26583 .71215 .25923 Metetra
.664 .741 .908 r
.71215 .25923 .71696 .26583 .72736 .26226 .72258 .25564 Metetra
.664 .741 .908 r
.72258 .25564 .72736 .26226 .7378 .25868 .73305 .25204 Metetra
.664 .741 .908 r
.73305 .25204 .7378 .25868 .74828 .25509 .74355 .24842 Metetra
.664 .741 .908 r
.74355 .24842 .74828 .25509 .75879 .25148 .7541 .24479 Metetra
.664 .741 .908 r
.7541 .24479 .75879 .25148 .76935 .24786 .76468 .24114 Metetra
.664 .741 .908 r
.76468 .24114 .76935 .24786 .77994 .24423 .7753 .23749 Metetra
.664 .741 .908 r
.7753 .23749 .77994 .24423 .79057 .24058 .78596 .23381 Metetra
.664 .741 .908 r
.78596 .23381 .79057 .24058 .80125 .23692 .79666 .23013 Metetra
.664 .741 .908 r
.79666 .23013 .80125 .23692 .81196 .23325 .8074 .22643 Metetra
.664 .741 .908 r
.8074 .22643 .81196 .23325 .82271 .22956 .81818 .22272 Metetra
.664 .741 .908 r
.81818 .22272 .82271 .22956 .8335 .22586 .829 .21899 Metetra
.664 .741 .908 r
.212 .42389 .21794 .42943 .22663 .42643 .22071 .42088 Metetra
.664 .741 .908 r
.22071 .42088 .22663 .42643 .23535 .42343 .22944 .41786 Metetra
.664 .741 .908 r
.22944 .41786 .23535 .42343 .24411 .42042 .23821 .41482 Metetra
.664 .741 .908 r
.23821 .41482 .24411 .42042 .25289 .41739 .24701 .41178 Metetra
.664 .741 .908 r
.24701 .41178 .25289 .41739 .2617 .41436 .25584 .40873 Metetra
.664 .741 .908 r
.25584 .40873 .2617 .41436 .27054 .41131 .2647 .40567 Metetra
.664 .741 .908 r
.2647 .40567 .27054 .41131 .27941 .40826 .27358 .40259 Metetra
.664 .741 .908 r
.27358 .40259 .27941 .40826 .28831 .40519 .2825 .39951 Metetra
.664 .741 .908 r
.2825 .39951 .28831 .40519 .29724 .40212 .29145 .39641 Metetra
.664 .741 .908 r
.29145 .39641 .29724 .40212 .3062 .39903 .30043 .39331 Metetra
.664 .741 .908 r
.30043 .39331 .3062 .39903 .31519 .39594 .30944 .39019 Metetra
.664 .741 .908 r
.30944 .39019 .31519 .39594 .32421 .39283 .31848 .38707 Metetra
.664 .741 .908 r
.31848 .38707 .32421 .39283 .33326 .38971 .32755 .38393 Metetra
.664 .741 .908 r
.32755 .38393 .33326 .38971 .34235 .38658 .33665 .38078 Metetra
.664 .741 .908 r
.33665 .38078 .34235 .38658 .35146 .38345 .34579 .37762 Metetra
.664 .741 .908 r
.34579 .37762 .35146 .38345 .36061 .3803 .35495 .37445 Metetra
.664 .741 .908 r
.35495 .37445 .36061 .3803 .36978 .37714 .36415 .37127 Metetra
.664 .741 .908 r
.36415 .37127 .36978 .37714 .37899 .37396 .37338 .36808 Metetra
.664 .741 .908 r
.37338 .36808 .37899 .37396 .38823 .37078 .38264 .36488 Metetra
.664 .741 .908 r
.38264 .36488 .38823 .37078 .39751 .36759 .39193 .36166 Metetra
.664 .741 .908 r
.39193 .36166 .39751 .36759 .40681 .36438 .40126 .35844 Metetra
.664 .741 .908 r
.40126 .35844 .40681 .36438 .41615 .36117 .41061 .3552 Metetra
.664 .741 .908 r
.41061 .3552 .41615 .36117 .42552 .35794 .42 .35196 Metetra
.664 .741 .908 r
.42 .35196 .42552 .35794 .43492 .3547 .42943 .3487 Metetra
.664 .741 .908 r
.42943 .3487 .43492 .3547 .43881 .56991 .43888 .34543 Metetra
0 0 .336 r
.43888 .34543 .43881 .56991 .44892 .56684 .44308 .56112 Metetra
.646 .762 .934 r
.44308 .56112 .44892 .56684 .45907 .56375 .45325 .55801 Metetra
.646 .762 .934 r
.45325 .55801 .45907 .56375 .46926 .56065 .46346 .55489 Metetra
.646 .762 .934 r
.46346 .55489 .46926 .56065 .47948 .55753 .47371 .55176 Metetra
.646 .762 .934 r
.47371 .55176 .47948 .55753 .48974 .55441 .484 .54861 Metetra
.646 .762 .934 r
.484 .54861 .48974 .55441 .50005 .55128 .49432 .54546 Metetra
.646 .762 .934 r
.49432 .54546 .50005 .55128 .51039 .54813 .50469 .54229 Metetra
.646 .762 .934 r
.50469 .54229 .51039 .54813 .52077 .54497 .5151 .5391 Metetra
.646 .762 .934 r
.5151 .5391 .52077 .54497 .53119 .5418 .52554 .53591 Metetra
.646 .762 .934 r
.52554 .53591 .53119 .5418 .54165 .53861 .53603 .5327 Metetra
.646 .762 .934 r
.53603 .5327 .54165 .53861 .55214 .53542 .54655 .52949 Metetra
.646 .762 .934 r
.54655 .52949 .55214 .53542 .56268 .53221 .55712 .52626 Metetra
.97 .702 .466 r
.55712 .52626 .56268 .53221 .57326 .52899 .56489 .30185 Metetra
.547 .335 .544 r
.56489 .30185 .57326 .52899 .57999 .30475 .57483 .29841 Metetra
.664 .741 .908 r
.57483 .29841 .57999 .30475 .58994 .30132 .5848 .29496 Metetra
.664 .741 .908 r
.5848 .29496 .58994 .30132 .59992 .29788 .59481 .2915 Metetra
.664 .741 .908 r
.59481 .2915 .59992 .29788 .60994 .29443 .60485 .28803 Metetra
.664 .741 .908 r
.60485 .28803 .60994 .29443 .61999 .29097 .61493 .28454 Metetra
.664 .741 .908 r
.61493 .28454 .61999 .29097 .63009 .28749 .62505 .28104 Metetra
.664 .741 .908 r
.62505 .28104 .63009 .28749 .64022 .28401 .6352 .27753 Metetra
.664 .741 .908 r
.6352 .27753 .64022 .28401 .65038 .2805 .64539 .27401 Metetra
.664 .741 .908 r
.64539 .27401 .65038 .2805 .66058 .27699 .65562 .27047 Metetra
.664 .741 .908 r
.65562 .27047 .66058 .27699 .67082 .27347 .66588 .26692 Metetra
.664 .741 .908 r
.66588 .26692 .67082 .27347 .6811 .26993 .67619 .26336 Metetra
.664 .741 .908 r
.67619 .26336 .6811 .26993 .69141 .26637 .68652 .25978 Metetra
.664 .741 .908 r
.68652 .25978 .69141 .26637 .70176 .26281 .6969 .25619 Metetra
.664 .741 .908 r
.6969 .25619 .70176 .26281 .71215 .25923 .70732 .25259 Metetra
.664 .741 .908 r
.70732 .25259 .71215 .25923 .72258 .25564 .71777 .24898 Metetra
.664 .741 .908 r
.71777 .24898 .72258 .25564 .73305 .25204 .72827 .24535 Metetra
.664 .741 .908 r
.72827 .24535 .73305 .25204 .74355 .24842 .7388 .24171 Metetra
.664 .741 .908 r
.7388 .24171 .74355 .24842 .7541 .24479 .74937 .23805 Metetra
.664 .741 .908 r
.74937 .23805 .7541 .24479 .76468 .24114 .75998 .23438 Metetra
.664 .741 .908 r
.75998 .23438 .76468 .24114 .7753 .23749 .77063 .2307 Metetra
.664 .741 .908 r
.77063 .2307 .7753 .23749 .78596 .23381 .78132 .227 Metetra
.664 .741 .908 r
.78132 .227 .78596 .23381 .79666 .23013 .79204 .22329 Metetra
.664 .741 .908 r
.79204 .22329 .79666 .23013 .8074 .22643 .80281 .21957 Metetra
.664 .741 .908 r
.80281 .21957 .8074 .22643 .81818 .22272 .81362 .21583 Metetra
.664 .741 .908 r
.81362 .21583 .81818 .22272 .829 .21899 .82447 .21208 Metetra
.664 .741 .908 r
.20602 .41832 .212 .42389 .22071 .42088 .21474 .41529 Metetra
.664 .741 .908 r
.21474 .41529 .22071 .42088 .22944 .41786 .2235 .41225 Metetra
.664 .741 .908 r
.2235 .41225 .22944 .41786 .23821 .41482 .23228 .4092 Metetra
.664 .741 .908 r
.23228 .4092 .23821 .41482 .24701 .41178 .2411 .40614 Metetra
.664 .741 .908 r
.2411 .40614 .24701 .41178 .25584 .40873 .24994 .40307 Metetra
.664 .741 .908 r
.24994 .40307 .25584 .40873 .2647 .40567 .25882 .39998 Metetra
.664 .741 .908 r
.25882 .39998 .2647 .40567 .27358 .40259 .26773 .39689 Metetra
.664 .741 .908 r
.26773 .39689 .27358 .40259 .2825 .39951 .27666 .39379 Metetra
.664 .741 .908 r
.27666 .39379 .2825 .39951 .29145 .39641 .28563 .39067 Metetra
.664 .741 .908 r
.28563 .39067 .29145 .39641 .30043 .39331 .29463 .38755 Metetra
.664 .741 .908 r
.29463 .38755 .30043 .39331 .30944 .39019 .30365 .38441 Metetra
.664 .741 .908 r
.30365 .38441 .30944 .39019 .31848 .38707 .31271 .38127 Metetra
.664 .741 .908 r
.31271 .38127 .31848 .38707 .32755 .38393 .3218 .37811 Metetra
.664 .741 .908 r
.3218 .37811 .32755 .38393 .33665 .38078 .33092 .37494 Metetra
.664 .741 .908 r
.33092 .37494 .33665 .38078 .34579 .37762 .34008 .37176 Metetra
.664 .741 .908 r
.34008 .37176 .34579 .37762 .35495 .37445 .34926 .36857 Metetra
.664 .741 .908 r
.34926 .36857 .35495 .37445 .36415 .37127 .35848 .36537 Metetra
.664 .741 .908 r
.35848 .36537 .36415 .37127 .37338 .36808 .36773 .36216 Metetra
.664 .741 .908 r
.36773 .36216 .37338 .36808 .38264 .36488 .37701 .35894 Metetra
.664 .741 .908 r
.37701 .35894 .38264 .36488 .39193 .36166 .38632 .3557 Metetra
.664 .741 .908 r
.38632 .3557 .39193 .36166 .40126 .35844 .39567 .35246 Metetra
.664 .741 .908 r
.39567 .35246 .40126 .35844 .41061 .3552 .40504 .3492 Metetra
.664 .741 .908 r
.40504 .3492 .41061 .3552 .42 .35196 .41445 .34593 Metetra
.664 .741 .908 r
.41445 .34593 .42 .35196 .42943 .3487 .4239 .34265 Metetra
.664 .741 .908 r
.4239 .34265 .42943 .3487 .43888 .34543 .43337 .33936 Metetra
.962 .673 .438 r
.43337 .33936 .43888 .34543 .44308 .56112 .43719 .55537 Metetra
.646 .762 .934 r
.43719 .55537 .44308 .56112 .45325 .55801 .44739 .55224 Metetra
.646 .762 .934 r
.44739 .55224 .45325 .55801 .46346 .55489 .45762 .5491 Metetra
.646 .762 .934 r
.45762 .5491 .46346 .55489 .47371 .55176 .4679 .54594 Metetra
.646 .762 .934 r
.4679 .54594 .47371 .55176 .484 .54861 .47821 .54277 Metetra
.646 .762 .934 r
.47821 .54277 .484 .54861 .49432 .54546 .48856 .53959 Metetra
.646 .762 .934 r
.48856 .53959 .49432 .54546 .50469 .54229 .49895 .5364 Metetra
.646 .762 .934 r
.49895 .5364 .50469 .54229 .5151 .5391 .50938 .5332 Metetra
.646 .762 .934 r
.50938 .5332 .5151 .5391 .52554 .53591 .51986 .52998 Metetra
.646 .762 .934 r
.51986 .52998 .52554 .53591 .53603 .5327 .53037 .52675 Metetra
.646 .762 .934 r
.53037 .52675 .53603 .5327 .54655 .52949 .54092 .52351 Metetra
.646 .762 .934 r
.54092 .52351 .54655 .52949 .55712 .52626 .55151 .52026 Metetra
.97 .702 .466 r
.55151 .52026 .55712 .52626 .56489 .30185 .55967 .29549 Metetra
.664 .741 .908 r
.55967 .29549 .56489 .30185 .57483 .29841 .56963 .29204 Metetra
.664 .741 .908 r
.56963 .29204 .57483 .29841 .5848 .29496 .57963 .28856 Metetra
.664 .741 .908 r
.57963 .28856 .5848 .29496 .59481 .2915 .58966 .28508 Metetra
.664 .741 .908 r
.58966 .28508 .59481 .2915 .60485 .28803 .59973 .28158 Metetra
.664 .741 .908 r
.59973 .28158 .60485 .28803 .61493 .28454 .60983 .27807 Metetra
.664 .741 .908 r
.60983 .27807 .61493 .28454 .62505 .28104 .61997 .27455 Metetra
.664 .741 .908 r
.61997 .27455 .62505 .28104 .6352 .27753 .63015 .27102 Metetra
.664 .741 .908 r
.63015 .27102 .6352 .27753 .64539 .27401 .64037 .26747 Metetra
.664 .741 .908 r
.64037 .26747 .64539 .27401 .65562 .27047 .65062 .26391 Metetra
.664 .741 .908 r
.65062 .26391 .65562 .27047 .66588 .26692 .66091 .26033 Metetra
.664 .741 .908 r
.66091 .26033 .66588 .26692 .67619 .26336 .67124 .25675 Metetra
.664 .741 .908 r
.67124 .25675 .67619 .26336 .68652 .25978 .6816 .25315 Metetra
.664 .741 .908 r
.6816 .25315 .68652 .25978 .6969 .25619 .69201 .24953 Metetra
.664 .741 .908 r
.69201 .24953 .6969 .25619 .70732 .25259 .70245 .24591 Metetra
.664 .741 .908 r
.70245 .24591 .70732 .25259 .71777 .24898 .71293 .24227 Metetra
.664 .741 .908 r
.71293 .24227 .71777 .24898 .72827 .24535 .72345 .23861 Metetra
.664 .741 .908 r
.72345 .23861 .72827 .24535 .7388 .24171 .73401 .23495 Metetra
.664 .741 .908 r
.73401 .23495 .7388 .24171 .74937 .23805 .74461 .23126 Metetra
.664 .741 .908 r
.74461 .23126 .74937 .23805 .75998 .23438 .75524 .22757 Metetra
.664 .741 .908 r
.75524 .22757 .75998 .23438 .77063 .2307 .76592 .22386 Metetra
.664 .741 .908 r
.76592 .22386 .77063 .2307 .78132 .227 .77664 .22014 Metetra
.664 .741 .908 r
.77664 .22014 .78132 .227 .79204 .22329 .78739 .2164 Metetra
.664 .741 .908 r
.78739 .2164 .79204 .22329 .80281 .21957 .79819 .21265 Metetra
.664 .741 .908 r
.79819 .21265 .80281 .21957 .81362 .21583 .80903 .20889 Metetra
.664 .741 .908 r
.80903 .20889 .81362 .21583 .82447 .21208 .81991 .20511 Metetra
.664 .741 .908 r
.2 .41272 .20602 .41832 .21474 .41529 .20874 .40967 Metetra
.664 .741 .908 r
.20874 .40967 .21474 .41529 .2235 .41225 .21751 .40661 Metetra
.664 .741 .908 r
.21751 .40661 .2235 .41225 .23228 .4092 .22632 .40354 Metetra
.664 .741 .908 r
.22632 .40354 .23228 .4092 .2411 .40614 .23515 .40046 Metetra
.664 .741 .908 r
.23515 .40046 .2411 .40614 .24994 .40307 .24401 .39737 Metetra
.664 .741 .908 r
.24401 .39737 .24994 .40307 .25882 .39998 .25291 .39426 Metetra
.664 .741 .908 r
.25291 .39426 .25882 .39998 .26773 .39689 .26183 .39115 Metetra
.664 .741 .908 r
.26183 .39115 .26773 .39689 .27666 .39379 .27078 .38803 Metetra
.664 .741 .908 r
.27078 .38803 .27666 .39379 .28563 .39067 .27977 .3849 Metetra
.664 .741 .908 r
.27977 .3849 .28563 .39067 .29463 .38755 .28879 .38175 Metetra
.664 .741 .908 r
.28879 .38175 .29463 .38755 .30365 .38441 .29783 .3786 Metetra
.664 .741 .908 r
.29783 .3786 .30365 .38441 .31271 .38127 .30691 .37543 Metetra
.664 .741 .908 r
.30691 .37543 .31271 .38127 .3218 .37811 .31602 .37225 Metetra
.664 .741 .908 r
.31602 .37225 .3218 .37811 .33092 .37494 .32516 .36906 Metetra
.664 .741 .908 r
.32516 .36906 .33092 .37494 .34008 .37176 .33433 .36586 Metetra
.664 .741 .908 r
.33433 .36586 .34008 .37176 .34926 .36857 .34354 .36265 Metetra
.664 .741 .908 r
.34354 .36265 .34926 .36857 .35848 .36537 .35277 .35943 Metetra
.664 .741 .908 r
.35277 .35943 .35848 .36537 .36773 .36216 .36204 .3562 Metetra
.664 .741 .908 r
.36204 .3562 .36773 .36216 .37701 .35894 .37134 .35296 Metetra
.664 .741 .908 r
.37134 .35296 .37701 .35894 .38632 .3557 .38067 .3497 Metetra
.664 .741 .908 r
.38067 .3497 .38632 .3557 .39567 .35246 .39004 .34643 Metetra
.664 .741 .908 r
.39004 .34643 .39567 .35246 .40504 .3492 .39944 .34316 Metetra
.664 .741 .908 r
.39944 .34316 .40504 .3492 .41445 .34593 .40887 .33987 Metetra
.664 .741 .908 r
.40887 .33987 .41445 .34593 .4239 .34265 .41833 .33656 Metetra
.664 .741 .908 r
.41833 .33656 .4239 .34265 .43337 .33936 .42783 .33325 Metetra
.664 .741 .908 r
.42783 .33325 .43337 .33936 .43719 .55537 .43736 .32993 Metetra
.544 .331 .542 r
.43736 .32993 .43719 .55537 .44739 .55224 .44693 .32659 Metetra
0 0 .336 r
.44693 .32659 .44739 .55224 .45762 .5491 .45174 .54326 Metetra
.646 .762 .934 r
.45174 .54326 .45762 .5491 .4679 .54594 .46204 .54008 Metetra
.646 .762 .934 r
.46204 .54008 .4679 .54594 .47821 .54277 .47238 .53689 Metetra
.646 .762 .934 r
.47238 .53689 .47821 .54277 .48856 .53959 .48276 .53369 Metetra
.646 .762 .934 r
.48276 .53369 .48856 .53959 .49895 .5364 .49318 .53048 Metetra
.646 .762 .934 r
.49318 .53048 .49895 .5364 .50938 .5332 .50363 .52725 Metetra
.646 .762 .934 r
.50363 .52725 .50938 .5332 .51986 .52998 .51413 .52401 Metetra
.646 .762 .934 r
.51413 .52401 .51986 .52998 .53037 .52675 .52467 .52076 Metetra
.969 .702 .472 r
.52467 .52076 .53037 .52675 .54092 .52351 .53456 .29603 Metetra
.544 .331 .542 r
.53456 .29603 .54092 .52351 .55151 .52026 .54447 .29257 Metetra
.544 .331 .542 r
.54447 .29257 .55151 .52026 .55967 .29549 .55442 .2891 Metetra
.664 .741 .908 r
.55442 .2891 .55967 .29549 .56963 .29204 .5644 .28562 Metetra
.664 .741 .908 r
.5644 .28562 .56963 .29204 .57963 .28856 .57442 .28212 Metetra
.664 .741 .908 r
.57442 .28212 .57963 .28856 .58966 .28508 .58448 .27861 Metetra
.664 .741 .908 r
.58448 .27861 .58966 .28508 .59973 .28158 .59457 .27509 Metetra
.664 .741 .908 r
.59457 .27509 .59973 .28158 .60983 .27807 .6047 .27156 Metetra
.664 .741 .908 r
.6047 .27156 .60983 .27807 .61997 .27455 .61486 .26802 Metetra
.664 .741 .908 r
.61486 .26802 .61997 .27455 .63015 .27102 .62507 .26446 Metetra
.664 .741 .908 r
.62507 .26446 .63015 .27102 .64037 .26747 .63531 .26088 Metetra
.664 .741 .908 r
.63531 .26088 .64037 .26747 .65062 .26391 .64559 .2573 Metetra
.664 .741 .908 r
.64559 .2573 .65062 .26391 .66091 .26033 .6559 .2537 Metetra
.664 .741 .908 r
.6559 .2537 .66091 .26033 .67124 .25675 .66626 .25009 Metetra
.664 .741 .908 r
.66626 .25009 .67124 .25675 .6816 .25315 .67665 .24647 Metetra
.664 .741 .908 r
.67665 .24647 .6816 .25315 .69201 .24953 .68708 .24283 Metetra
.664 .741 .908 r
.68708 .24283 .69201 .24953 .70245 .24591 .69755 .23918 Metetra
.664 .741 .908 r
.69755 .23918 .70245 .24591 .71293 .24227 .70806 .23551 Metetra
.664 .741 .908 r
.70806 .23551 .71293 .24227 .72345 .23861 .7186 .23183 Metetra
.664 .741 .908 r
.7186 .23183 .72345 .23861 .73401 .23495 .72919 .22814 Metetra
.664 .741 .908 r
.72919 .22814 .73401 .23495 .74461 .23126 .73981 .22443 Metetra
.664 .741 .908 r
.73981 .22443 .74461 .23126 .75524 .22757 .75048 .22071 Metetra
.664 .741 .908 r
.75048 .22071 .75524 .22757 .76592 .22386 .76118 .21698 Metetra
.664 .741 .908 r
.76118 .21698 .76592 .22386 .77664 .22014 .77193 .21323 Metetra
.664 .741 .908 r
.77193 .21323 .77664 .22014 .78739 .2164 .78271 .20947 Metetra
.664 .741 .908 r
.78271 .20947 .78739 .2164 .79819 .21265 .79354 .20569 Metetra
.664 .741 .908 r
.79354 .20569 .79819 .21265 .80903 .20889 .80441 .2019 Metetra
.664 .741 .908 r
.80441 .2019 .80903 .20889 .81991 .20511 .81531 .1981 Metetra
.664 .741 .908 r
.19394 .40708 .2 .41272 .20874 .40967 .2027 .40401 Metetra
.664 .741 .908 r
.2027 .40401 .20874 .40967 .21751 .40661 .21149 .40093 Metetra
.664 .741 .908 r
.21149 .40093 .21751 .40661 .22632 .40354 .22031 .39784 Metetra
.664 .741 .908 r
.22031 .39784 .22632 .40354 .23515 .40046 .22916 .39474 Metetra
.664 .741 .908 r
.22916 .39474 .23515 .40046 .24401 .39737 .23805 .39163 Metetra
.664 .741 .908 r
.23805 .39163 .24401 .39737 .25291 .39426 .24696 .38851 Metetra
.664 .741 .908 r
.24696 .38851 .25291 .39426 .26183 .39115 .2559 .38538 Metetra
.664 .741 .908 r
.2559 .38538 .26183 .39115 .27078 .38803 .26487 .38224 Metetra
.664 .741 .908 r
.26487 .38224 .27078 .38803 .27977 .3849 .27387 .37908 Metetra
.664 .741 .908 r
.27387 .37908 .27977 .3849 .28879 .38175 .28291 .37592 Metetra
.664 .741 .908 r
.28291 .37592 .28879 .38175 .29783 .3786 .29197 .37274 Metetra
.664 .741 .908 r
.29197 .37274 .29783 .3786 .30691 .37543 .30107 .36955 Metetra
.664 .741 .908 r
.30107 .36955 .30691 .37543 .31602 .37225 .3102 .36636 Metetra
.664 .741 .908 r
.3102 .36636 .31602 .37225 .32516 .36906 .31936 .36315 Metetra
.664 .741 .908 r
.31936 .36315 .32516 .36906 .33433 .36586 .32855 .35993 Metetra
.664 .741 .908 r
.32855 .35993 .33433 .36586 .34354 .36265 .33777 .3567 Metetra
.664 .741 .908 r
.33777 .3567 .34354 .36265 .35277 .35943 .34703 .35346 Metetra
.664 .741 .908 r
.34703 .35346 .35277 .35943 .36204 .3562 .35632 .3502 Metetra
.664 .741 .908 r
.35632 .3502 .36204 .3562 .37134 .35296 .36564 .34694 Metetra
.664 .741 .908 r
.36564 .34694 .37134 .35296 .38067 .3497 .37499 .34366 Metetra
.664 .741 .908 r
.37499 .34366 .38067 .3497 .39004 .34643 .38438 .34037 Metetra
.664 .741 .908 r
.38438 .34037 .39004 .34643 .39944 .34316 .39379 .33707 Metetra
.664 .741 .908 r
.39379 .33707 .39944 .34316 .40887 .33987 .40325 .33376 Metetra
.664 .741 .908 r
.40325 .33376 .40887 .33987 .41833 .33656 .41273 .33044 Metetra
.664 .741 .908 r
.41273 .33044 .41833 .33656 .42783 .33325 .42225 .32711 Metetra
.664 .741 .908 r
.42225 .32711 .42783 .33325 .43736 .32993 .4318 .32376 Metetra
.664 .741 .908 r
.4318 .32376 .43736 .32993 .44693 .32659 .44139 .3204 Metetra
.664 .741 .908 r
.44139 .3204 .44693 .32659 .45174 .54326 .45101 .31703 Metetra
.543 .33 .54 r
.45101 .31703 .45174 .54326 .46204 .54008 .46066 .31365 Metetra
0 0 .341 r
.46066 .31365 .46204 .54008 .47238 .53689 .46651 .53097 Metetra
.646 .762 .934 r
.46651 .53097 .47238 .53689 .48276 .53369 .47691 .52775 Metetra
.646 .762 .934 r
.47691 .52775 .48276 .53369 .49318 .53048 .48736 .52451 Metetra
.646 .762 .934 r
.48736 .52451 .49318 .53048 .50363 .52725 .49784 .52126 Metetra
.967 .702 .478 r
.49784 .52126 .50363 .52725 .51413 .52401 .50946 .29656 Metetra
.543 .33 .54 r
.50946 .29656 .51413 .52401 .52467 .52076 .51932 .2931 Metetra
.543 .33 .54 r
.51932 .2931 .52467 .52076 .53456 .29603 .52922 .28963 Metetra
.664 .741 .908 r
.52922 .28963 .53456 .29603 .54447 .29257 .53916 .28615 Metetra
.664 .741 .908 r
.53916 .28615 .54447 .29257 .55442 .2891 .54913 .28266 Metetra
.664 .741 .908 r
.54913 .28266 .55442 .2891 .5644 .28562 .55914 .27915 Metetra
.664 .741 .908 r
.55914 .27915 .5644 .28562 .57442 .28212 .56918 .27564 Metetra
.664 .741 .908 r
.56918 .27564 .57442 .28212 .58448 .27861 .57926 .27211 Metetra
.664 .741 .908 r
.57926 .27211 .58448 .27861 .59457 .27509 .58938 .26856 Metetra
.664 .741 .908 r
.58938 .26856 .59457 .27509 .6047 .27156 .59953 .265 Metetra
.664 .741 .908 r
.59953 .265 .6047 .27156 .61486 .26802 .60972 .26143 Metetra
.664 .741 .908 r
.60972 .26143 .61486 .26802 .62507 .26446 .61995 .25785 Metetra
.664 .741 .908 r
.61995 .25785 .62507 .26446 .63531 .26088 .63022 .25426 Metetra
.664 .741 .908 r
.63022 .25426 .63531 .26088 .64559 .2573 .64052 .25065 Metetra
.664 .741 .908 r
.64052 .25065 .64559 .2573 .6559 .2537 .65086 .24702 Metetra
.664 .741 .908 r
.65086 .24702 .6559 .2537 .66626 .25009 .66124 .24339 Metetra
.664 .741 .908 r
.66124 .24339 .66626 .25009 .67665 .24647 .67166 .23974 Metetra
.664 .741 .908 r
.67166 .23974 .67665 .24647 .68708 .24283 .68212 .23608 Metetra
.664 .741 .908 r
.68212 .23608 .68708 .24283 .69755 .23918 .69261 .2324 Metetra
.664 .741 .908 r
.69261 .2324 .69755 .23918 .70806 .23551 .70315 .22871 Metetra
.664 .741 .908 r
.70315 .22871 .70806 .23551 .7186 .23183 .71372 .225 Metetra
.664 .741 .908 r
.71372 .225 .7186 .23183 .72919 .22814 .72433 .22129 Metetra
.664 .741 .908 r
.72433 .22129 .72919 .22814 .73981 .22443 .73499 .21756 Metetra
.664 .741 .908 r
.73499 .21756 .73981 .22443 .75048 .22071 .74568 .21381 Metetra
.664 .741 .908 r
.74568 .21381 .75048 .22071 .76118 .21698 .75641 .21005 Metetra
.664 .741 .908 r
.75641 .21005 .76118 .21698 .77193 .21323 .76719 .20628 Metetra
.664 .741 .908 r
.76719 .20628 .77193 .21323 .78271 .20947 .778 .20249 Metetra
.664 .741 .908 r
.778 .20249 .78271 .20947 .79354 .20569 .78885 .19869 Metetra
.664 .741 .908 r
.78885 .19869 .79354 .20569 .80441 .2019 .79975 .19487 Metetra
.664 .741 .908 r
.79975 .19487 .80441 .2019 .81531 .1981 .81069 .19104 Metetra
.664 .741 .908 r
.18785 .40141 .19394 .40708 .2027 .40401 .19663 .39832 Metetra
.664 .741 .908 r
.19663 .39832 .2027 .40401 .21149 .40093 .20543 .39522 Metetra
.664 .741 .908 r
.20543 .39522 .21149 .40093 .22031 .39784 .21427 .39211 Metetra
.664 .741 .908 r
.21427 .39211 .22031 .39784 .22916 .39474 .22314 .38899 Metetra
.664 .741 .908 r
.22314 .38899 .22916 .39474 .23805 .39163 .23204 .38586 Metetra
.664 .741 .908 r
.23204 .38586 .23805 .39163 .24696 .38851 .24097 .38272 Metetra
.664 .741 .908 r
.24097 .38272 .24696 .38851 .2559 .38538 .24993 .37957 Metetra
.664 .741 .908 r
.24993 .37957 .2559 .38538 .26487 .38224 .25892 .3764 Metetra
.664 .741 .908 r
.25892 .3764 .26487 .38224 .27387 .37908 .26794 .37323 Metetra
.664 .741 .908 r
.26794 .37323 .27387 .37908 .28291 .37592 .27699 .37005 Metetra
.664 .741 .908 r
.27699 .37005 .28291 .37592 .29197 .37274 .28608 .36685 Metetra
.664 .741 .908 r
.28608 .36685 .29197 .37274 .30107 .36955 .29519 .36364 Metetra
.664 .741 .908 r
.29519 .36364 .30107 .36955 .3102 .36636 .30434 .36042 Metetra
.664 .741 .908 r
.30434 .36042 .3102 .36636 .31936 .36315 .31352 .3572 Metetra
.664 .741 .908 r
.31352 .3572 .31936 .36315 .32855 .35993 .32273 .35396 Metetra
.664 .741 .908 r
.32273 .35396 .32855 .35993 .33777 .3567 .33197 .3507 Metetra
.664 .741 .908 r
.33197 .3507 .33777 .3567 .34703 .35346 .34125 .34744 Metetra
.664 .741 .908 r
.34125 .34744 .34703 .35346 .35632 .3502 .35056 .34417 Metetra
.664 .741 .908 r
.35056 .34417 .35632 .3502 .36564 .34694 .3599 .34088 Metetra
.664 .741 .908 r
.3599 .34088 .36564 .34694 .37499 .34366 .36927 .33758 Metetra
.664 .741 .908 r
.36927 .33758 .37499 .34366 .38438 .34037 .37868 .33427 Metetra
.664 .741 .908 r
.37868 .33427 .38438 .34037 .39379 .33707 .38811 .33095 Metetra
.664 .741 .908 r
.38811 .33095 .39379 .33707 .40325 .33376 .39759 .32762 Metetra
.664 .741 .908 r
.39759 .32762 .40325 .33376 .41273 .33044 .40709 .32427 Metetra
.664 .741 .908 r
.40709 .32427 .41273 .33044 .42225 .32711 .41663 .32092 Metetra
.664 .741 .908 r
.41663 .32092 .42225 .32711 .4318 .32376 .42621 .31755 Metetra
.664 .741 .908 r
.42621 .31755 .4318 .32376 .44139 .3204 .43582 .31417 Metetra
.664 .741 .908 r
.43582 .31417 .44139 .3204 .45101 .31703 .44546 .31078 Metetra
.664 .741 .908 r
.44546 .31078 .45101 .31703 .46066 .31365 .45513 .30737 Metetra
.664 .741 .908 r
.45513 .30737 .46066 .31365 .46651 .53097 .46485 .30396 Metetra
.542 .328 .539 r
.46485 .30396 .46651 .53097 .47691 .52775 .47459 .30053 Metetra
.542 .328 .539 r
.47459 .30053 .47691 .52775 .48736 .52451 .48437 .29709 Metetra
.542 .328 .539 r
.48437 .29709 .48736 .52451 .49784 .52126 .49419 .29363 Metetra
.542 .328 .539 r
.49419 .29363 .49784 .52126 .50946 .29656 .50404 .29017 Metetra
.664 .741 .908 r
.50404 .29017 .50946 .29656 .51932 .2931 .51393 .28669 Metetra
.664 .741 .908 r
.51393 .28669 .51932 .2931 .52922 .28963 .52385 .2832 Metetra
.664 .741 .908 r
.52385 .2832 .52922 .28963 .53916 .28615 .53381 .27969 Metetra
.664 .741 .908 r
.53381 .27969 .53916 .28615 .54913 .28266 .54381 .27618 Metetra
.664 .741 .908 r
.54381 .27618 .54913 .28266 .55914 .27915 .55384 .27265 Metetra
.664 .741 .908 r
.55384 .27265 .55914 .27915 .56918 .27564 .5639 .26911 Metetra
.664 .741 .908 r
.5639 .26911 .56918 .27564 .57926 .27211 .57401 .26555 Metetra
.664 .741 .908 r
.57401 .26555 .57926 .27211 .58938 .26856 .58415 .26198 Metetra
.664 .741 .908 r
.58415 .26198 .58938 .26856 .59953 .265 .59433 .2584 Metetra
.664 .741 .908 r
.59433 .2584 .59953 .265 .60972 .26143 .60455 .25481 Metetra
.664 .741 .908 r
.60455 .25481 .60972 .26143 .61995 .25785 .6148 .2512 Metetra
.664 .741 .908 r
.6148 .2512 .61995 .25785 .63022 .25426 .62509 .24758 Metetra
.664 .741 .908 r
.62509 .24758 .63022 .25426 .64052 .25065 .63542 .24395 Metetra
.664 .741 .908 r
.63542 .24395 .64052 .25065 .65086 .24702 .64579 .2403 Metetra
.664 .741 .908 r
.64579 .2403 .65086 .24702 .66124 .24339 .65619 .23664 Metetra
.664 .741 .908 r
.65619 .23664 .66124 .24339 .67166 .23974 .66664 .23297 Metetra
.664 .741 .908 r
.66664 .23297 .67166 .23974 .68212 .23608 .67712 .22928 Metetra
.664 .741 .908 r
.67712 .22928 .68212 .23608 .69261 .2324 .68764 .22558 Metetra
.664 .741 .908 r
.68764 .22558 .69261 .2324 .70315 .22871 .6982 .22186 Metetra
.664 .741 .908 r
.6982 .22186 .70315 .22871 .71372 .225 .7088 .21813 Metetra
.664 .741 .908 r
.7088 .21813 .71372 .225 .72433 .22129 .71945 .21439 Metetra
.664 .741 .908 r
.71945 .21439 .72433 .22129 .73499 .21756 .73013 .21063 Metetra
.664 .741 .908 r
.73013 .21063 .73499 .21756 .74568 .21381 .74085 .20686 Metetra
.664 .741 .908 r
.74085 .20686 .74568 .21381 .75641 .21005 .75161 .20307 Metetra
.664 .741 .908 r
.75161 .20307 .75641 .21005 .76719 .20628 .76241 .19927 Metetra
.664 .741 .908 r
.76241 .19927 .76719 .20628 .778 .20249 .77325 .19546 Metetra
.664 .741 .908 r
.77325 .19546 .778 .20249 .78885 .19869 .78414 .19163 Metetra
.664 .741 .908 r
.78414 .19163 .78885 .19869 .79975 .19487 .79506 .18778 Metetra
.664 .741 .908 r
.79506 .18778 .79975 .19487 .81069 .19104 .80603 .18393 Metetra
.664 .741 .908 r
.18172 .3957 .18785 .40141 .19663 .39832 .19051 .39259 Metetra
.664 .741 .908 r
.19051 .39259 .19663 .39832 .20543 .39522 .19934 .38947 Metetra
.664 .741 .908 r
.19934 .38947 .20543 .39522 .21427 .39211 .20819 .38634 Metetra
.664 .741 .908 r
.20819 .38634 .21427 .39211 .22314 .38899 .21708 .3832 Metetra
.664 .741 .908 r
.21708 .3832 .22314 .38899 .23204 .38586 .22599 .38005 Metetra
.664 .741 .908 r
.22599 .38005 .23204 .38586 .24097 .38272 .23494 .37689 Metetra
.664 .741 .908 r
.23494 .37689 .24097 .38272 .24993 .37957 .24392 .37372 Metetra
.664 .741 .908 r
.24392 .37372 .24993 .37957 .25892 .3764 .25293 .37054 Metetra
.664 .741 .908 r
.25293 .37054 .25892 .3764 .26794 .37323 .26197 .36734 Metetra
.664 .741 .908 r
.26197 .36734 .26794 .37323 .27699 .37005 .27104 .36414 Metetra
.664 .741 .908 r
.27104 .36414 .27699 .37005 .28608 .36685 .28014 .36092 Metetra
.664 .741 .908 r
.28014 .36092 .28608 .36685 .29519 .36364 .28928 .35769 Metetra
.664 .741 .908 r
.28928 .35769 .29519 .36364 .30434 .36042 .29844 .35445 Metetra
.664 .741 .908 r
.29844 .35445 .30434 .36042 .31352 .3572 .30764 .3512 Metetra
.664 .741 .908 r
.30764 .3512 .31352 .3572 .32273 .35396 .31687 .34794 Metetra
.664 .741 .908 r
.31687 .34794 .32273 .35396 .33197 .3507 .32613 .34467 Metetra
.664 .741 .908 r
.32613 .34467 .33197 .3507 .34125 .34744 .33543 .34139 Metetra
.664 .741 .908 r
.33543 .34139 .34125 .34744 .35056 .34417 .34476 .33809 Metetra
.664 .741 .908 r
.34476 .33809 .35056 .34417 .3599 .34088 .35412 .33478 Metetra
.664 .741 .908 r
.35412 .33478 .3599 .34088 .36927 .33758 .36351 .33146 Metetra
.664 .741 .908 r
.36351 .33146 .36927 .33758 .37868 .33427 .37294 .32813 Metetra
.664 .741 .908 r
.37294 .32813 .37868 .33427 .38811 .33095 .3824 .32479 Metetra
.664 .741 .908 r
.3824 .32479 .38811 .33095 .39759 .32762 .39189 .32144 Metetra
.664 .741 .908 r
.39189 .32144 .39759 .32762 .40709 .32427 .40142 .31807 Metetra
.664 .741 .908 r
.40142 .31807 .40709 .32427 .41663 .32092 .41098 .31469 Metetra
.664 .741 .908 r
.41098 .31469 .41663 .32092 .42621 .31755 .42058 .3113 Metetra
.664 .741 .908 r
.42058 .3113 .42621 .31755 .43582 .31417 .43021 .3079 Metetra
.664 .741 .908 r
.43021 .3079 .43582 .31417 .44546 .31078 .43987 .30448 Metetra
.664 .741 .908 r
.43987 .30448 .44546 .31078 .45513 .30737 .44957 .30106 Metetra
.664 .741 .908 r
.44957 .30106 .45513 .30737 .46485 .30396 .4593 .29762 Metetra
.664 .741 .908 r
.4593 .29762 .46485 .30396 .47459 .30053 .46907 .29417 Metetra
.664 .741 .908 r
.46907 .29417 .47459 .30053 .48437 .29709 .47887 .2907 Metetra
.664 .741 .908 r
.47887 .2907 .48437 .29709 .49419 .29363 .48871 .28723 Metetra
.664 .741 .908 r
.48871 .28723 .49419 .29363 .50404 .29017 .49859 .28374 Metetra
.664 .741 .908 r
.49859 .28374 .50404 .29017 .51393 .28669 .5085 .28023 Metetra
.664 .741 .908 r
.5085 .28023 .51393 .28669 .52385 .2832 .51844 .27672 Metetra
.664 .741 .908 r
.51844 .27672 .52385 .2832 .53381 .27969 .52843 .27319 Metetra
.664 .741 .908 r
.52843 .27319 .53381 .27969 .54381 .27618 .53845 .26965 Metetra
.664 .741 .908 r
.53845 .26965 .54381 .27618 .55384 .27265 .5485 .2661 Metetra
.664 .741 .908 r
.5485 .2661 .55384 .27265 .5639 .26911 .55859 .26253 Metetra
.664 .741 .908 r
.55859 .26253 .5639 .26911 .57401 .26555 .56872 .25896 Metetra
.664 .741 .908 r
.56872 .25896 .57401 .26555 .58415 .26198 .57889 .25536 Metetra
.664 .741 .908 r
.57889 .25536 .58415 .26198 .59433 .2584 .58909 .25176 Metetra
.664 .741 .908 r
.58909 .25176 .59433 .2584 .60455 .25481 .59933 .24814 Metetra
.664 .741 .908 r
.59933 .24814 .60455 .25481 .6148 .2512 .60961 .24451 Metetra
.664 .741 .908 r
.60961 .24451 .6148 .2512 .62509 .24758 .61993 .24086 Metetra
.664 .741 .908 r
.61993 .24086 .62509 .24758 .63542 .24395 .63028 .2372 Metetra
.664 .741 .908 r
.63028 .2372 .63542 .24395 .64579 .2403 .64068 .23353 Metetra
.664 .741 .908 r
.64068 .23353 .64579 .2403 .65619 .23664 .65111 .22985 Metetra
.664 .741 .908 r
.65111 .22985 .65619 .23664 .66664 .23297 .66158 .22615 Metetra
.664 .741 .908 r
.66158 .22615 .66664 .23297 .67712 .22928 .67209 .22243 Metetra
.664 .741 .908 r
.67209 .22243 .67712 .22928 .68764 .22558 .68264 .2187 Metetra
.664 .741 .908 r
.68264 .2187 .68764 .22558 .6982 .22186 .69323 .21496 Metetra
.664 .741 .908 r
.69323 .21496 .6982 .22186 .7088 .21813 .70386 .21121 Metetra
.664 .741 .908 r
.70386 .21121 .7088 .21813 .71945 .21439 .71452 .20744 Metetra
.664 .741 .908 r
.71452 .20744 .71945 .21439 .73013 .21063 .72523 .20366 Metetra
.664 .741 .908 r
.72523 .20366 .73013 .21063 .74085 .20686 .73598 .19986 Metetra
.664 .741 .908 r
.73598 .19986 .74085 .20686 .75161 .20307 .74677 .19604 Metetra
.664 .741 .908 r
.74677 .19604 .75161 .20307 .76241 .19927 .7576 .19222 Metetra
.664 .741 .908 r
.7576 .19222 .76241 .19927 .77325 .19546 .76847 .18838 Metetra
.664 .741 .908 r
.76847 .18838 .77325 .19546 .78414 .19163 .77939 .18452 Metetra
.664 .741 .908 r
.77939 .18452 .78414 .19163 .79506 .18778 .79034 .18065 Metetra
.664 .741 .908 r
.79034 .18065 .79506 .18778 .80603 .18393 .80134 .17677 Metetra
.664 .741 .908 r
.17555 .38995 .18172 .3957 .19051 .39259 .18436 .38683 Metetra
.664 .741 .908 r
.18436 .38683 .19051 .39259 .19934 .38947 .1932 .38369 Metetra
.664 .741 .908 r
.1932 .38369 .19934 .38947 .20819 .38634 .20207 .38054 Metetra
.664 .741 .908 r
.20207 .38054 .20819 .38634 .21708 .3832 .21098 .37738 Metetra
.664 .741 .908 r
.21098 .37738 .21708 .3832 .22599 .38005 .21991 .37421 Metetra
.664 .741 .908 r
.21991 .37421 .22599 .38005 .23494 .37689 .22888 .37103 Metetra
.664 .741 .908 r
.22888 .37103 .23494 .37689 .24392 .37372 .23787 .36783 Metetra
.664 .741 .908 r
.23787 .36783 .24392 .37372 .25293 .37054 .2469 .36463 Metetra
.664 .741 .908 r
.2469 .36463 .25293 .37054 .26197 .36734 .25596 .36142 Metetra
.664 .741 .908 r
.25596 .36142 .26197 .36734 .27104 .36414 .26505 .35819 Metetra
.664 .741 .908 r
.26505 .35819 .27104 .36414 .28014 .36092 .27417 .35495 Metetra
.664 .741 .908 r
.27417 .35495 .28014 .36092 .28928 .35769 .28332 .35171 Metetra
.664 .741 .908 r
.28332 .35171 .28928 .35769 .29844 .35445 .29251 .34845 Metetra
.664 .741 .908 r
.29251 .34845 .29844 .35445 .30764 .3512 .30173 .34517 Metetra
.664 .741 .908 r
.30173 .34517 .30764 .3512 .31687 .34794 .31098 .34189 Metetra
.664 .741 .908 r
.31098 .34189 .31687 .34794 .32613 .34467 .32026 .3386 Metetra
.664 .741 .908 r
.32026 .3386 .32613 .34467 .33543 .34139 .32957 .33529 Metetra
.664 .741 .908 r
.32957 .33529 .33543 .34139 .34476 .33809 .33892 .33197 Metetra
.664 .741 .908 r
.33892 .33197 .34476 .33809 .35412 .33478 .3483 .32865 Metetra
.664 .741 .908 r
.3483 .32865 .35412 .33478 .36351 .33146 .35772 .32531 Metetra
.664 .741 .908 r
.35772 .32531 .36351 .33146 .37294 .32813 .36716 .32195 Metetra
.664 .741 .908 r
.36716 .32195 .37294 .32813 .3824 .32479 .37664 .31859 Metetra
.664 .741 .908 r
.37664 .31859 .3824 .32479 .39189 .32144 .38616 .31521 Metetra
.664 .741 .908 r
.38616 .31521 .39189 .32144 .40142 .31807 .39571 .31182 Metetra
.664 .741 .908 r
.39571 .31182 .40142 .31807 .41098 .31469 .40529 .30842 Metetra
.664 .741 .908 r
.40529 .30842 .41098 .31469 .42058 .3113 .41491 .30501 Metetra
.664 .741 .908 r
.41491 .30501 .42058 .3113 .43021 .3079 .42456 .30158 Metetra
.664 .741 .908 r
.42456 .30158 .43021 .3079 .43987 .30448 .43424 .29815 Metetra
.664 .741 .908 r
.43424 .29815 .43987 .30448 .44957 .30106 .44396 .2947 Metetra
.664 .741 .908 r
.44396 .2947 .44957 .30106 .4593 .29762 .45372 .29124 Metetra
.664 .741 .908 r
.45372 .29124 .4593 .29762 .46907 .29417 .46351 .28776 Metetra
.664 .741 .908 r
.46351 .28776 .46907 .29417 .47887 .2907 .47334 .28427 Metetra
.664 .741 .908 r
.47334 .28427 .47887 .2907 .48871 .28723 .4832 .28077 Metetra
.664 .741 .908 r
.4832 .28077 .48871 .28723 .49859 .28374 .4931 .27726 Metetra
.664 .741 .908 r
.4931 .27726 .49859 .28374 .5085 .28023 .50303 .27374 Metetra
.664 .741 .908 r
.50303 .27374 .5085 .28023 .51844 .27672 .513 .2702 Metetra
.664 .741 .908 r
.513 .2702 .51844 .27672 .52843 .27319 .52301 .26665 Metetra
.664 .741 .908 r
.52301 .26665 .52843 .27319 .53845 .26965 .53305 .26308 Metetra
.664 .741 .908 r
.53305 .26308 .53845 .26965 .5485 .2661 .54313 .25951 Metetra
.664 .741 .908 r
.54313 .25951 .5485 .2661 .55859 .26253 .55325 .25592 Metetra
.664 .741 .908 r
.55325 .25592 .55859 .26253 .56872 .25896 .5634 .25231 Metetra
.664 .741 .908 r
.5634 .25231 .56872 .25896 .57889 .25536 .57359 .2487 Metetra
.664 .741 .908 r
.57359 .2487 .57889 .25536 .58909 .25176 .58382 .24507 Metetra
.664 .741 .908 r
.58382 .24507 .58909 .25176 .59933 .24814 .59408 .24142 Metetra
.664 .741 .908 r
.59408 .24142 .59933 .24814 .60961 .24451 .60439 .23777 Metetra
.664 .741 .908 r
.60439 .23777 .60961 .24451 .61993 .24086 .61473 .2341 Metetra
.664 .741 .908 r
.61473 .2341 .61993 .24086 .63028 .2372 .62511 .23041 Metetra
.664 .741 .908 r
.62511 .23041 .63028 .2372 .64068 .23353 .63553 .22672 Metetra
.664 .741 .908 r
.63553 .22672 .64068 .23353 .65111 .22985 .64599 .223 Metetra
.664 .741 .908 r
.64599 .223 .65111 .22985 .66158 .22615 .65649 .21928 Metetra
.664 .741 .908 r
.65649 .21928 .66158 .22615 .67209 .22243 .66702 .21554 Metetra
.664 .741 .908 r
.66702 .21554 .67209 .22243 .68264 .2187 .6776 .21179 Metetra
.664 .741 .908 r
.6776 .21179 .68264 .2187 .69323 .21496 .68822 .20802 Metetra
.664 .741 .908 r
.68822 .20802 .69323 .21496 .70386 .21121 .69887 .20424 Metetra
.664 .741 .908 r
.69887 .20424 .70386 .21121 .71452 .20744 .70957 .20044 Metetra
.664 .741 .908 r
.70957 .20044 .71452 .20744 .72523 .20366 .7203 .19663 Metetra
.664 .741 .908 r
.7203 .19663 .72523 .20366 .73598 .19986 .73108 .19281 Metetra
.664 .741 .908 r
.73108 .19281 .73598 .19986 .74677 .19604 .7419 .18897 Metetra
.664 .741 .908 r
.7419 .18897 .74677 .19604 .7576 .19222 .75276 .18512 Metetra
.664 .741 .908 r
.75276 .18512 .7576 .19222 .76847 .18838 .76366 .18125 Metetra
.664 .741 .908 r
.76366 .18125 .76847 .18838 .77939 .18452 .7746 .17736 Metetra
.664 .741 .908 r
.7746 .17736 .77939 .18452 .79034 .18065 .78558 .17347 Metetra
.664 .741 .908 r
.78558 .17347 .79034 .18065 .80134 .17677 .79661 .16955 Metetra
.664 .741 .908 r
.16934 .38417 .17555 .38995 .18436 .38683 .17817 .38102 Metetra
.664 .741 .908 r
.17817 .38102 .18436 .38683 .1932 .38369 .18703 .37787 Metetra
.664 .741 .908 r
.18703 .37787 .1932 .38369 .20207 .38054 .19592 .3747 Metetra
.664 .741 .908 r
.19592 .3747 .20207 .38054 .21098 .37738 .20484 .37152 Metetra
.664 .741 .908 r
.20484 .37152 .21098 .37738 .21991 .37421 .21379 .36833 Metetra
.664 .741 .908 r
.21379 .36833 .21991 .37421 .22888 .37103 .22277 .36512 Metetra
.664 .741 .908 r
.22277 .36512 .22888 .37103 .23787 .36783 .23179 .36191 Metetra
.664 .741 .908 r
.23179 .36191 .23787 .36783 .2469 .36463 .24083 .35869 Metetra
.664 .741 .908 r
.24083 .35869 .2469 .36463 .25596 .36142 .24991 .35545 Metetra
.664 .741 .908 r
.24991 .35545 .25596 .36142 .26505 .35819 .25902 .35221 Metetra
.664 .741 .908 r
.25902 .35221 .26505 .35819 .27417 .35495 .26816 .34895 Metetra
.664 .741 .908 r
.26816 .34895 .27417 .35495 .28332 .35171 .27733 .34568 Metetra
.664 .741 .908 r
.27733 .34568 .28332 .35171 .29251 .34845 .28654 .3424 Metetra
.664 .741 .908 r
.28654 .3424 .29251 .34845 .30173 .34517 .29577 .33911 Metetra
.664 .741 .908 r
.29577 .33911 .30173 .34517 .31098 .34189 .30504 .3358 Metetra
.664 .741 .908 r
.30504 .3358 .31098 .34189 .32026 .3386 .31434 .33249 Metetra
.664 .741 .908 r
.31434 .33249 .32026 .3386 .32957 .33529 .32368 .32916 Metetra
.664 .741 .908 r
.32368 .32916 .32957 .33529 .33892 .33197 .33305 .32582 Metetra
.664 .741 .908 r
.33305 .32582 .33892 .33197 .3483 .32865 .34245 .32247 Metetra
.664 .741 .908 r
.34245 .32247 .3483 .32865 .35772 .32531 .35188 .31911 Metetra
.664 .741 .908 r
.35188 .31911 .35772 .32531 .36716 .32195 .36135 .31573 Metetra
.664 .741 .908 r
.36135 .31573 .36716 .32195 .37664 .31859 .37085 .31235 Metetra
.664 .741 .908 r
.37085 .31235 .37664 .31859 .38616 .31521 .38039 .30895 Metetra
.664 .741 .908 r
.38039 .30895 .38616 .31521 .39571 .31182 .38996 .30554 Metetra
.664 .741 .908 r
.38996 .30554 .39571 .31182 .40529 .30842 .39956 .30211 Metetra
.664 .741 .908 r
.39956 .30211 .40529 .30842 .41491 .30501 .4092 .29868 Metetra
.664 .741 .908 r
.4092 .29868 .41491 .30501 .42456 .30158 .41887 .29523 Metetra
.664 .741 .908 r
.41887 .29523 .42456 .30158 .43424 .29815 .42858 .29177 Metetra
.664 .741 .908 r
.42858 .29177 .43424 .29815 .44396 .2947 .43832 .2883 Metetra
.664 .741 .908 r
.43832 .2883 .44396 .2947 .45372 .29124 .4481 .28481 Metetra
.664 .741 .908 r
.4481 .28481 .45372 .29124 .46351 .28776 .45792 .28131 Metetra
.664 .741 .908 r
.45792 .28131 .46351 .28776 .47334 .28427 .46776 .2778 Metetra
.664 .741 .908 r
.46776 .2778 .47334 .28427 .4832 .28077 .47765 .27428 Metetra
.664 .741 .908 r
.47765 .27428 .4832 .28077 .4931 .27726 .48757 .27074 Metetra
.664 .741 .908 r
.48757 .27074 .4931 .27726 .50303 .27374 .49753 .2672 Metetra
.664 .741 .908 r
.49753 .2672 .50303 .27374 .513 .2702 .50752 .26363 Metetra
.664 .741 .908 r
.50752 .26363 .513 .2702 .52301 .26665 .51755 .26006 Metetra
.664 .741 .908 r
.51755 .26006 .52301 .26665 .53305 .26308 .52762 .25647 Metetra
.664 .741 .908 r
.52762 .25647 .53305 .26308 .54313 .25951 .53772 .25287 Metetra
.664 .741 .908 r
.53772 .25287 .54313 .25951 .55325 .25592 .54786 .24925 Metetra
.664 .741 .908 r
.54786 .24925 .55325 .25592 .5634 .25231 .55804 .24563 Metetra
.664 .741 .908 r
.55804 .24563 .5634 .25231 .57359 .2487 .56826 .24199 Metetra
.664 .741 .908 r
.56826 .24199 .57359 .2487 .58382 .24507 .57851 .23833 Metetra
.664 .741 .908 r
.57851 .23833 .58382 .24507 .59408 .24142 .5888 .23466 Metetra
.664 .741 .908 r
.5888 .23466 .59408 .24142 .60439 .23777 .59913 .23098 Metetra
.664 .741 .908 r
.59913 .23098 .60439 .23777 .61473 .2341 .6095 .22729 Metetra
.664 .741 .908 r
.6095 .22729 .61473 .2341 .62511 .23041 .61991 .22358 Metetra
.664 .741 .908 r
.61991 .22358 .62511 .23041 .63553 .22672 .63035 .21985 Metetra
.664 .741 .908 r
.63035 .21985 .63553 .22672 .64599 .223 .64084 .21612 Metetra
.664 .741 .908 r
.64084 .21612 .64599 .223 .65649 .21928 .65136 .21237 Metetra
.664 .741 .908 r
.65136 .21237 .65649 .21928 .66702 .21554 .66192 .2086 Metetra
.664 .741 .908 r
.66192 .2086 .66702 .21554 .6776 .21179 .67253 .20482 Metetra
.664 .741 .908 r
.67253 .20482 .6776 .21179 .68822 .20802 .68317 .20103 Metetra
.664 .741 .908 r
.68317 .20103 .68822 .20802 .69887 .20424 .69385 .19722 Metetra
.664 .741 .908 r
.69385 .19722 .69887 .20424 .70957 .20044 .70458 .1934 Metetra
.664 .741 .908 r
.70458 .1934 .70957 .20044 .7203 .19663 .71534 .18956 Metetra
.664 .741 .908 r
.71534 .18956 .7203 .19663 .73108 .19281 .72615 .18571 Metetra
.664 .741 .908 r
.72615 .18571 .73108 .19281 .7419 .18897 .73699 .18184 Metetra
.664 .741 .908 r
.73699 .18184 .7419 .18897 .75276 .18512 .74788 .17796 Metetra
.664 .741 .908 r
.74788 .17796 .75276 .18512 .76366 .18125 .75881 .17407 Metetra
.664 .741 .908 r
.75881 .17407 .76366 .18125 .7746 .17736 .76978 .17016 Metetra
.664 .741 .908 r
.76978 .17016 .7746 .17736 .78558 .17347 .7808 .16623 Metetra
.664 .741 .908 r
.7808 .16623 .78558 .17347 .79661 .16955 .79185 .16229 Metetra
.664 .741 .908 r
.16309 .37835 .16934 .38417 .17817 .38102 .17193 .37518 Metetra
.664 .741 .908 r
.17193 .37518 .17817 .38102 .18703 .37787 .18081 .37201 Metetra
.664 .741 .908 r
.18081 .37201 .18703 .37787 .19592 .3747 .18972 .36882 Metetra
.664 .741 .908 r
.18972 .36882 .19592 .3747 .20484 .37152 .19866 .36562 Metetra
.664 .741 .908 r
.19866 .36562 .20484 .37152 .21379 .36833 .20763 .36241 Metetra
.664 .741 .908 r
.20763 .36241 .21379 .36833 .22277 .36512 .21663 .35918 Metetra
.664 .741 .908 r
.21663 .35918 .22277 .36512 .23179 .36191 .22566 .35595 Metetra
.664 .741 .908 r
.22566 .35595 .23179 .36191 .24083 .35869 .23473 .35271 Metetra
.664 .741 .908 r
.23473 .35271 .24083 .35869 .24991 .35545 .24382 .34945 Metetra
.664 .741 .908 r
.24382 .34945 .24991 .35545 .25902 .35221 .25295 .34618 Metetra
.664 .741 .908 r
.25295 .34618 .25902 .35221 .26816 .34895 .26211 .3429 Metetra
.664 .741 .908 r
.26211 .3429 .26816 .34895 .27733 .34568 .2713 .33961 Metetra
.664 .741 .908 r
.2713 .33961 .27733 .34568 .28654 .3424 .28052 .33631 Metetra
.664 .741 .908 r
.28052 .33631 .28654 .3424 .29577 .33911 .28978 .333 Metetra
.664 .741 .908 r
.28978 .333 .29577 .33911 .30504 .3358 .29907 .32967 Metetra
.664 .741 .908 r
.29907 .32967 .30504 .3358 .31434 .33249 .30839 .32633 Metetra
.664 .741 .908 r
.30839 .32633 .31434 .33249 .32368 .32916 .31775 .32299 Metetra
.664 .741 .908 r
.31775 .32299 .32368 .32916 .33305 .32582 .32713 .31962 Metetra
.664 .741 .908 r
.32713 .31962 .33305 .32582 .34245 .32247 .33656 .31625 Metetra
.664 .741 .908 r
.33656 .31625 .34245 .32247 .35188 .31911 .34601 .31287 Metetra
.664 .741 .908 r
.34601 .31287 .35188 .31911 .36135 .31573 .3555 .30947 Metetra
.664 .741 .908 r
.3555 .30947 .36135 .31573 .37085 .31235 .36502 .30606 Metetra
.664 .741 .908 r
.36502 .30606 .37085 .31235 .38039 .30895 .37458 .30264 Metetra
.664 .741 .908 r
.37458 .30264 .38039 .30895 .38996 .30554 .38417 .29921 Metetra
.664 .741 .908 r
.38417 .29921 .38996 .30554 .39956 .30211 .3938 .29576 Metetra
.664 .741 .908 r
.3938 .29576 .39956 .30211 .4092 .29868 .40346 .2923 Metetra
.664 .741 .908 r
.40346 .2923 .4092 .29868 .41887 .29523 .41315 .28883 Metetra
.664 .741 .908 r
.41315 .28883 .41887 .29523 .42858 .29177 .42288 .28535 Metetra
.664 .741 .908 r
.42288 .28535 .42858 .29177 .43832 .2883 .43265 .28185 Metetra
.664 .741 .908 r
.43265 .28185 .43832 .2883 .4481 .28481 .44245 .27834 Metetra
.664 .741 .908 r
.44245 .27834 .4481 .28481 .45792 .28131 .45228 .27482 Metetra
.664 .741 .908 r
.45228 .27482 .45792 .28131 .46776 .2778 .46215 .27129 Metetra
.664 .741 .908 r
.46215 .27129 .46776 .2778 .47765 .27428 .47206 .26774 Metetra
.664 .741 .908 r
.47206 .26774 .47765 .27428 .48757 .27074 .48201 .26418 Metetra
.664 .741 .908 r
.48201 .26418 .48757 .27074 .49753 .2672 .49199 .26061 Metetra
.664 .741 .908 r
.49199 .26061 .49753 .2672 .50752 .26363 .502 .25702 Metetra
.664 .741 .908 r
.502 .25702 .50752 .26363 .51755 .26006 .51206 .25342 Metetra
.664 .741 .908 r
.51206 .25342 .51755 .26006 .52762 .25647 .52215 .24981 Metetra
.664 .741 .908 r
.52215 .24981 .52762 .25647 .53772 .25287 .53228 .24619 Metetra
.664 .741 .908 r
.53228 .24619 .53772 .25287 .54786 .24925 .54244 .24255 Metetra
.664 .741 .908 r
.54244 .24255 .54786 .24925 .55804 .24563 .55264 .23889 Metetra
.664 .741 .908 r
.55264 .23889 .55804 .24563 .56826 .24199 .56288 .23523 Metetra
.664 .741 .908 r
.56288 .23523 .56826 .24199 .57851 .23833 .57316 .23155 Metetra
.664 .741 .908 r
.57316 .23155 .57851 .23833 .5888 .23466 .58348 .22786 Metetra
.664 .741 .908 r
.58348 .22786 .5888 .23466 .59913 .23098 .59384 .22415 Metetra
.664 .741 .908 r
.59384 .22415 .59913 .23098 .6095 .22729 .60423 .22043 Metetra
.664 .741 .908 r
.60423 .22043 .6095 .22729 .61991 .22358 .61466 .21669 Metetra
.664 .741 .908 r
.61466 .21669 .61991 .22358 .63035 .21985 .62513 .21294 Metetra
.664 .741 .908 r
.62513 .21294 .63035 .21985 .64084 .21612 .63565 .20918 Metetra
.664 .741 .908 r
.63565 .20918 .64084 .21612 .65136 .21237 .6462 .2054 Metetra
.664 .741 .908 r
.6462 .2054 .65136 .21237 .66192 .2086 .65679 .20161 Metetra
.664 .741 .908 r
.65679 .20161 .66192 .2086 .67253 .20482 .66742 .19781 Metetra
.664 .741 .908 r
.66742 .19781 .67253 .20482 .68317 .20103 .67809 .19399 Metetra
.664 .741 .908 r
.67809 .19399 .68317 .20103 .69385 .19722 .6888 .19015 Metetra
.664 .741 .908 r
.6888 .19015 .69385 .19722 .70458 .1934 .69955 .1863 Metetra
.664 .741 .908 r
.69955 .1863 .70458 .1934 .71534 .18956 .71034 .18244 Metetra
.664 .741 .908 r
.71034 .18244 .71534 .18956 .72615 .18571 .72118 .17856 Metetra
.664 .741 .908 r
.72118 .17856 .72615 .18571 .73699 .18184 .73205 .17467 Metetra
.664 .741 .908 r
.73205 .17467 .73699 .18184 .74788 .17796 .74297 .17076 Metetra
.664 .741 .908 r
.74297 .17076 .74788 .17796 .75881 .17407 .75393 .16684 Metetra
.664 .741 .908 r
.75393 .16684 .75881 .17407 .76978 .17016 .76493 .1629 Metetra
.664 .741 .908 r
.76493 .1629 .76978 .17016 .7808 .16623 .77597 .15894 Metetra
.664 .741 .908 r
.77597 .15894 .7808 .16623 .79185 .16229 .78706 .15498 Metetra
.664 .741 .908 r
.1568 .3725 .16309 .37835 .17193 .37518 .16566 .36931 Metetra
.664 .741 .908 r
.16566 .36931 .17193 .37518 .18081 .37201 .17456 .36611 Metetra
.664 .741 .908 r
.17456 .36611 .18081 .37201 .18972 .36882 .18348 .3629 Metetra
.664 .741 .908 r
.18348 .3629 .18972 .36882 .19866 .36562 .19244 .35968 Metetra
.664 .741 .908 r
.19244 .35968 .19866 .36562 .20763 .36241 .20143 .35645 Metetra
.664 .741 .908 r
.20143 .35645 .20763 .36241 .21663 .35918 .21045 .35321 Metetra
.664 .741 .908 r
.21045 .35321 .21663 .35918 .22566 .35595 .2195 .34995 Metetra
.664 .741 .908 r
.2195 .34995 .22566 .35595 .23473 .35271 .22858 .34669 Metetra
.664 .741 .908 r
.22858 .34669 .23473 .35271 .24382 .34945 .2377 .34341 Metetra
.664 .741 .908 r
.2377 .34341 .24382 .34945 .25295 .34618 .24684 .34012 Metetra
.664 .741 .908 r
.24684 .34012 .25295 .34618 .26211 .3429 .25602 .33682 Metetra
.664 .741 .908 r
.25602 .33682 .26211 .3429 .2713 .33961 .26523 .33351 Metetra
.664 .741 .908 r
.26523 .33351 .2713 .33961 .28052 .33631 .27447 .33018 Metetra
.664 .741 .908 r
.27447 .33018 .28052 .33631 .28978 .333 .28375 .32685 Metetra
.664 .741 .908 r
.28375 .32685 .28978 .333 .29907 .32967 .29306 .3235 Metetra
.664 .741 .908 r
.29306 .3235 .29907 .32967 .30839 .32633 .3024 .32014 Metetra
.664 .741 .908 r
.3024 .32014 .30839 .32633 .31775 .32299 .31178 .31677 Metetra
.664 .741 .908 r
.31178 .31677 .31775 .32299 .32713 .31962 .32118 .31339 Metetra
.664 .741 .908 r
.32118 .31339 .32713 .31962 .33656 .31625 .33063 .30999 Metetra
.664 .741 .908 r
.33063 .30999 .33656 .31625 .34601 .31287 .3401 .30659 Metetra
.664 .741 .908 r
.3401 .30659 .34601 .31287 .3555 .30947 .34961 .30317 Metetra
.664 .741 .908 r
.34961 .30317 .3555 .30947 .36502 .30606 .35915 .29974 Metetra
.664 .741 .908 r
.35915 .29974 .36502 .30606 .37458 .30264 .36873 .29629 Metetra
.664 .741 .908 r
.36873 .29629 .37458 .30264 .38417 .29921 .37834 .29284 Metetra
.664 .741 .908 r
.37834 .29284 .38417 .29921 .3938 .29576 .38799 .28937 Metetra
.664 .741 .908 r
.38799 .28937 .3938 .29576 .40346 .2923 .39767 .28589 Metetra
.664 .741 .908 r
.39767 .28589 .40346 .2923 .41315 .28883 .40739 .28239 Metetra
.664 .741 .908 r
.40739 .28239 .41315 .28883 .42288 .28535 .41714 .27888 Metetra
.664 .741 .908 r
.41714 .27888 .42288 .28535 .43265 .28185 .42693 .27537 Metetra
.664 .741 .908 r
.42693 .27537 .43265 .28185 .44245 .27834 .43675 .27183 Metetra
.664 .741 .908 r
.43675 .27183 .44245 .27834 .45228 .27482 .44661 .26829 Metetra
.664 .741 .908 r
.44661 .26829 .45228 .27482 .46215 .27129 .45651 .26473 Metetra
.664 .741 .908 r
.45651 .26473 .46215 .27129 .47206 .26774 .46644 .26116 Metetra
.664 .741 .908 r
.46644 .26116 .47206 .26774 .48201 .26418 .4764 .25758 Metetra
.664 .741 .908 r
.4764 .25758 .48201 .26418 .49199 .26061 .48641 .25398 Metetra
.664 .741 .908 r
.48641 .25398 .49199 .26061 .502 .25702 .49645 .25037 Metetra
.664 .741 .908 r
.49645 .25037 .502 .25702 .51206 .25342 .50653 .24674 Metetra
.664 .741 .908 r
.50653 .24674 .51206 .25342 .52215 .24981 .51664 .24311 Metetra
.664 .741 .908 r
.51664 .24311 .52215 .24981 .53228 .24619 .52679 .23946 Metetra
.664 .741 .908 r
.52679 .23946 .53228 .24619 .54244 .24255 .53698 .23579 Metetra
.664 .741 .908 r
.53698 .23579 .54244 .24255 .55264 .23889 .54721 .23212 Metetra
.664 .741 .908 r
.54721 .23212 .55264 .23889 .56288 .23523 .55748 .22842 Metetra
.664 .741 .908 r
.55748 .22842 .56288 .23523 .57316 .23155 .56778 .22472 Metetra
.664 .741 .908 r
.56778 .22472 .57316 .23155 .58348 .22786 .57812 .221 Metetra
.664 .741 .908 r
.57812 .221 .58348 .22786 .59384 .22415 .5885 .21727 Metetra
.664 .741 .908 r
.5885 .21727 .59384 .22415 .60423 .22043 .59892 .21352 Metetra
.664 .741 .908 r
.59892 .21352 .60423 .22043 .61466 .21669 .60938 .20976 Metetra
.664 .741 .908 r
.60938 .20976 .61466 .21669 .62513 .21294 .61988 .20599 Metetra
.664 .741 .908 r
.61988 .20599 .62513 .21294 .63565 .20918 .63042 .2022 Metetra
.664 .741 .908 r
.63042 .2022 .63565 .20918 .6462 .2054 .641 .19839 Metetra
.664 .741 .908 r
.641 .19839 .6462 .2054 .65679 .20161 .65162 .19457 Metetra
.664 .741 .908 r
.65162 .19457 .65679 .20161 .66742 .19781 .66227 .19074 Metetra
.664 .741 .908 r
.66227 .19074 .66742 .19781 .67809 .19399 .67297 .1869 Metetra
.664 .741 .908 r
.67297 .1869 .67809 .19399 .6888 .19015 .68371 .18303 Metetra
.664 .741 .908 r
.68371 .18303 .6888 .19015 .69955 .1863 .69449 .17916 Metetra
.664 .741 .908 r
.69449 .17916 .69955 .1863 .71034 .18244 .70531 .17527 Metetra
.664 .741 .908 r
.70531 .17527 .71034 .18244 .72118 .17856 .71617 .17136 Metetra
.664 .741 .908 r
.71617 .17136 .72118 .17856 .73205 .17467 .72708 .16744 Metetra
.664 .741 .908 r
.72708 .16744 .73205 .17467 .74297 .17076 .73802 .1635 Metetra
.664 .741 .908 r
.73802 .1635 .74297 .17076 .75393 .16684 .74901 .15955 Metetra
.664 .741 .908 r
.74901 .15955 .75393 .16684 .76493 .1629 .76004 .15559 Metetra
.664 .741 .908 r
.76004 .15559 .76493 .1629 .77597 .15894 .77112 .15161 Metetra
.664 .741 .908 r
.77112 .15161 .77597 .15894 .78706 .15498 .78223 .14761 Metetra
.664 .741 .908 r
.15047 .3666 .1568 .3725 .16566 .36931 .15935 .3634 Metetra
.664 .741 .908 r
.15935 .3634 .16566 .36931 .17456 .36611 .16826 .36018 Metetra
.664 .741 .908 r
.16826 .36018 .17456 .36611 .18348 .3629 .17721 .35695 Metetra
.664 .741 .908 r
.17721 .35695 .18348 .3629 .19244 .35968 .18618 .35371 Metetra
.664 .741 .908 r
.18618 .35371 .19244 .35968 .20143 .35645 .19519 .35045 Metetra
.664 .741 .908 r
.19519 .35045 .20143 .35645 .21045 .35321 .20423 .34719 Metetra
.664 .741 .908 r
.20423 .34719 .21045 .35321 .2195 .34995 .21329 .34391 Metetra
.664 .741 .908 r
.21329 .34391 .2195 .34995 .22858 .34669 .2224 .34063 Metetra
.664 .741 .908 r
.2224 .34063 .22858 .34669 .2377 .34341 .23153 .33733 Metetra
.664 .741 .908 r
.23153 .33733 .2377 .34341 .24684 .34012 .24069 .33402 Metetra
.664 .741 .908 r
.24069 .33402 .24684 .34012 .25602 .33682 .24989 .3307 Metetra
.664 .741 .908 r
.24989 .3307 .25602 .33682 .26523 .33351 .25912 .32736 Metetra
.664 .741 .908 r
.25912 .32736 .26523 .33351 .27447 .33018 .26838 .32402 Metetra
.664 .741 .908 r
.26838 .32402 .27447 .33018 .28375 .32685 .27768 .32066 Metetra
.664 .741 .908 r
.27768 .32066 .28375 .32685 .29306 .3235 .28701 .31729 Metetra
.664 .741 .908 r
.28701 .31729 .29306 .3235 .3024 .32014 .29637 .31391 Metetra
.664 .741 .908 r
.29637 .31391 .3024 .32014 .31178 .31677 .30576 .31052 Metetra
.664 .741 .908 r
.30576 .31052 .31178 .31677 .32118 .31339 .31519 .30711 Metetra
.664 .741 .908 r
.31519 .30711 .32118 .31339 .33063 .30999 .32466 .30369 Metetra
.664 .741 .908 r
.32466 .30369 .33063 .30999 .3401 .30659 .33415 .30026 Metetra
.664 .741 .908 r
.33415 .30026 .3401 .30659 .34961 .30317 .34368 .29682 Metetra
.664 .741 .908 r
.34368 .29682 .34961 .30317 .35915 .29974 .35325 .29337 Metetra
.664 .741 .908 r
.35325 .29337 .35915 .29974 .36873 .29629 .36285 .2899 Metetra
.664 .741 .908 r
.36285 .2899 .36873 .29629 .37834 .29284 .37248 .28642 Metetra
.664 .741 .908 r
.37248 .28642 .37834 .29284 .38799 .28937 .38215 .28293 Metetra
.664 .741 .908 r
.38215 .28293 .38799 .28937 .39767 .28589 .39185 .27942 Metetra
.664 .741 .908 r
.39185 .27942 .39767 .28589 .40739 .28239 .40159 .27591 Metetra
.664 .741 .908 r
.40159 .27591 .40739 .28239 .41714 .27888 .41136 .27238 Metetra
.664 .741 .908 r
.41136 .27238 .41714 .27888 .42693 .27537 .42117 .26883 Metetra
.664 .741 .908 r
.42117 .26883 .42693 .27537 .43675 .27183 .43102 .26528 Metetra
.664 .741 .908 r
.43102 .26528 .43675 .27183 .44661 .26829 .4409 .26171 Metetra
.664 .741 .908 r
.4409 .26171 .44661 .26829 .45651 .26473 .45082 .25813 Metetra
.664 .741 .908 r
.45082 .25813 .45651 .26473 .46644 .26116 .46077 .25453 Metetra
.664 .741 .908 r
.46077 .25453 .46644 .26116 .4764 .25758 .47076 .25092 Metetra
.664 .741 .908 r
.47076 .25092 .4764 .25758 .48641 .25398 .48079 .2473 Metetra
.664 .741 .908 r
.48079 .2473 .48641 .25398 .49645 .25037 .49086 .24367 Metetra
.664 .741 .908 r
.49086 .24367 .49645 .25037 .50653 .24674 .50096 .24002 Metetra
.664 .741 .908 r
.50096 .24002 .50653 .24674 .51664 .24311 .5111 .23636 Metetra
.664 .741 .908 r
.5111 .23636 .51664 .24311 .52679 .23946 .52127 .23268 Metetra
.664 .741 .908 r
.52127 .23268 .52679 .23946 .53698 .23579 .53149 .22899 Metetra
.664 .741 .908 r
.53149 .22899 .53698 .23579 .54721 .23212 .54174 .22529 Metetra
.664 .741 .908 r
.54174 .22529 .54721 .23212 .55748 .22842 .55203 .22157 Metetra
.664 .741 .908 r
.55203 .22157 .55748 .22842 .56778 .22472 .56236 .21784 Metetra
.664 .741 .908 r
.56236 .21784 .56778 .22472 .57812 .221 .57273 .2141 Metetra
.664 .741 .908 r
.57273 .2141 .57812 .221 .5885 .21727 .58314 .21034 Metetra
.664 .741 .908 r
.58314 .21034 .5885 .21727 .59892 .21352 .59358 .20657 Metetra
.664 .741 .908 r
.59358 .20657 .59892 .21352 .60938 .20976 .60407 .20278 Metetra
.664 .741 .908 r
.60407 .20278 .60938 .20976 .61988 .20599 .61459 .19898 Metetra
.664 .741 .908 r
.61459 .19898 .61988 .20599 .63042 .2022 .62516 .19516 Metetra
.664 .741 .908 r
.62516 .19516 .63042 .2022 .641 .19839 .63576 .19133 Metetra
.664 .741 .908 r
.63576 .19133 .641 .19839 .65162 .19457 .64641 .18749 Metetra
.664 .741 .908 r
.64641 .18749 .65162 .19457 .66227 .19074 .65709 .18363 Metetra
.664 .741 .908 r
.65709 .18363 .66227 .19074 .67297 .1869 .66782 .17976 Metetra
.664 .741 .908 r
.66782 .17976 .67297 .1869 .68371 .18303 .67859 .17587 Metetra
.664 .741 .908 r
.67859 .17587 .68371 .18303 .69449 .17916 .68939 .17196 Metetra
.664 .741 .908 r
.68939 .17196 .69449 .17916 .70531 .17527 .70024 .16804 Metetra
.664 .741 .908 r
.70024 .16804 .70531 .17527 .71617 .17136 .71113 .16411 Metetra
.664 .741 .908 r
.71113 .16411 .71617 .17136 .72708 .16744 .72207 .16016 Metetra
.664 .741 .908 r
.72207 .16016 .72708 .16744 .73802 .1635 .73304 .1562 Metetra
.664 .741 .908 r
.73304 .1562 .73802 .1635 .74901 .15955 .74406 .15222 Metetra
.664 .741 .908 r
.74406 .15222 .74901 .15955 .76004 .15559 .75512 .14822 Metetra
.664 .741 .908 r
.75512 .14822 .76004 .15559 .77112 .15161 .76622 .14421 Metetra
.664 .741 .908 r
.76622 .14421 .77112 .15161 .78223 .14761 .77737 .14019 Metetra
.664 .741 .908 r
.1441 .36067 .15047 .3666 .15935 .3634 .153 .35744 Metetra
.664 .741 .908 r
.153 .35744 .15935 .3634 .16826 .36018 .16193 .3542 Metetra
.664 .741 .908 r
.16193 .3542 .16826 .36018 .17721 .35695 .17089 .35095 Metetra
.664 .741 .908 r
.17089 .35095 .17721 .35695 .18618 .35371 .17988 .34769 Metetra
.664 .741 .908 r
.17988 .34769 .18618 .35371 .19519 .35045 .18891 .34442 Metetra
.664 .741 .908 r
.18891 .34442 .19519 .35045 .20423 .34719 .19796 .34113 Metetra
.664 .741 .908 r
.19796 .34113 .20423 .34719 .21329 .34391 .20705 .33784 Metetra
.664 .741 .908 r
.20705 .33784 .21329 .34391 .2224 .34063 .21617 .33453 Metetra
.664 .741 .908 r
.21617 .33453 .2224 .34063 .23153 .33733 .22532 .33121 Metetra
.664 .741 .908 r
.22532 .33121 .23153 .33733 .24069 .33402 .23451 .32788 Metetra
.664 .741 .908 r
.23451 .32788 .24069 .33402 .24989 .3307 .24372 .32453 Metetra
.664 .741 .908 r
.24372 .32453 .24989 .3307 .25912 .32736 .25297 .32118 Metetra
.664 .741 .908 r
.25297 .32118 .25912 .32736 .26838 .32402 .26225 .31781 Metetra
.664 .741 .908 r
.26225 .31781 .26838 .32402 .27768 .32066 .27157 .31443 Metetra
.664 .741 .908 r
.27157 .31443 .27768 .32066 .28701 .31729 .28092 .31104 Metetra
.664 .741 .908 r
.28092 .31104 .28701 .31729 .29637 .31391 .2903 .30764 Metetra
.664 .741 .908 r
.2903 .30764 .29637 .31391 .30576 .31052 .29971 .30422 Metetra
.664 .741 .908 r
.29971 .30422 .30576 .31052 .31519 .30711 .30916 .30079 Metetra
.664 .741 .908 r
.30916 .30079 .31519 .30711 .32466 .30369 .31865 .29735 Metetra
.664 .741 .908 r
.31865 .29735 .32466 .30369 .33415 .30026 .32816 .2939 Metetra
.664 .741 .908 r
.32816 .2939 .33415 .30026 .34368 .29682 .33771 .29044 Metetra
.664 .741 .908 r
.33771 .29044 .34368 .29682 .35325 .29337 .3473 .28696 Metetra
.664 .741 .908 r
.3473 .28696 .35325 .29337 .36285 .2899 .35692 .28347 Metetra
.664 .741 .908 r
.35692 .28347 .36285 .2899 .37248 .28642 .36657 .27996 Metetra
.664 .741 .908 r
.36657 .27996 .37248 .28642 .38215 .28293 .37627 .27645 Metetra
.664 .741 .908 r
.37627 .27645 .38215 .28293 .39185 .27942 .38599 .27292 Metetra
.664 .741 .908 r
.38599 .27292 .39185 .27942 .40159 .27591 .39575 .26938 Metetra
.664 .741 .908 r
.39575 .26938 .40159 .27591 .41136 .27238 .40555 .26583 Metetra
.664 .741 .908 r
.40555 .26583 .41136 .27238 .42117 .26883 .41538 .26226 Metetra
.664 .741 .908 r
.41538 .26226 .42117 .26883 .43102 .26528 .42525 .25868 Metetra
.664 .741 .908 r
.42525 .25868 .43102 .26528 .4409 .26171 .43515 .25509 Metetra
.664 .741 .908 r
.43515 .25509 .4409 .26171 .45082 .25813 .44509 .25148 Metetra
.664 .741 .908 r
.44509 .25148 .45082 .25813 .46077 .25453 .45507 .24786 Metetra
.664 .741 .908 r
.45507 .24786 .46077 .25453 .47076 .25092 .46509 .24423 Metetra
.664 .741 .908 r
.46509 .24423 .47076 .25092 .48079 .2473 .47514 .24058 Metetra
.664 .741 .908 r
.47514 .24058 .48079 .2473 .49086 .24367 .48523 .23692 Metetra
.664 .741 .908 r
.48523 .23692 .49086 .24367 .50096 .24002 .49535 .23325 Metetra
.664 .741 .908 r
.49535 .23325 .50096 .24002 .5111 .23636 .50551 .22956 Metetra
.664 .741 .908 r
.50551 .22956 .5111 .23636 .52127 .23268 .51572 .22586 Metetra
.664 .741 .908 r
.51572 .22586 .52127 .23268 .53149 .22899 .52596 .22215 Metetra
.664 .741 .908 r
.52596 .22215 .53149 .22899 .54174 .22529 .53623 .21842 Metetra
.664 .741 .908 r
.53623 .21842 .54174 .22529 .55203 .22157 .54655 .21468 Metetra
.664 .741 .908 r
.54655 .21468 .55203 .22157 .56236 .21784 .5569 .21092 Metetra
.664 .741 .908 r
.5569 .21092 .56236 .21784 .57273 .2141 .5673 .20715 Metetra
.664 .741 .908 r
.5673 .20715 .57273 .2141 .58314 .21034 .57773 .20336 Metetra
.664 .741 .908 r
.57773 .20336 .58314 .21034 .59358 .20657 .5882 .19956 Metetra
.664 .741 .908 r
.5882 .19956 .59358 .20657 .60407 .20278 .59871 .19575 Metetra
.664 .741 .908 r
.59871 .19575 .60407 .20278 .61459 .19898 .60927 .19192 Metetra
.664 .741 .908 r
.60927 .19192 .61459 .19898 .62516 .19516 .61986 .18808 Metetra
.664 .741 .908 r
.61986 .18808 .62516 .19516 .63576 .19133 .63049 .18422 Metetra
.664 .741 .908 r
.63049 .18422 .63576 .19133 .64641 .18749 .64116 .18035 Metetra
.664 .741 .908 r
.64116 .18035 .64641 .18749 .65709 .18363 .65188 .17647 Metetra
.664 .741 .908 r
.65188 .17647 .65709 .18363 .66782 .17976 .66263 .17256 Metetra
.664 .741 .908 r
.66263 .17256 .66782 .17976 .67859 .17587 .67342 .16865 Metetra
.664 .741 .908 r
.67342 .16865 .67859 .17587 .68939 .17196 .68426 .16472 Metetra
.664 .741 .908 r
.68426 .16472 .68939 .17196 .70024 .16804 .69514 .16077 Metetra
.664 .741 .908 r
.69514 .16077 .70024 .16804 .71113 .16411 .70606 .15681 Metetra
.664 .741 .908 r
.70606 .15681 .71113 .16411 .72207 .16016 .71702 .15283 Metetra
.664 .741 .908 r
.71702 .15283 .72207 .16016 .73304 .1562 .72803 .14884 Metetra
.664 .741 .908 r
.72803 .14884 .73304 .1562 .74406 .15222 .73907 .14483 Metetra
.664 .741 .908 r
.73907 .14483 .74406 .15222 .75512 .14822 .75016 .14081 Metetra
.664 .741 .908 r
.75016 .14081 .75512 .14822 .76622 .14421 .7613 .13677 Metetra
.664 .741 .908 r
.7613 .13677 .76622 .14421 .77737 .14019 .77247 .13272 Metetra
.664 .741 .908 r
.13769 .3547 .1441 .36067 .153 .35744 .14661 .35145 Metetra
.664 .741 .908 r
.14661 .35145 .153 .35744 .16193 .3542 .15555 .34819 Metetra
.664 .741 .908 r
.15555 .34819 .16193 .3542 .17089 .35095 .16453 .34492 Metetra
.664 .741 .908 r
.16453 .34492 .17089 .35095 .17988 .34769 .17354 .34164 Metetra
.664 .741 .908 r
.17354 .34164 .17988 .34769 .18891 .34442 .18259 .33834 Metetra
.664 .741 .908 r
.18259 .33834 .18891 .34442 .19796 .34113 .19166 .33504 Metetra
.664 .741 .908 r
.19166 .33504 .19796 .34113 .20705 .33784 .20077 .33172 Metetra
.664 .741 .908 r
.20077 .33172 .20705 .33784 .21617 .33453 .2099 .32839 Metetra
.664 .741 .908 r
.2099 .32839 .21617 .33453 .22532 .33121 .21907 .32505 Metetra
.664 .741 .908 r
.21907 .32505 .22532 .33121 .23451 .32788 .22828 .32169 Metetra
.664 .741 .908 r
.22828 .32169 .23451 .32788 .24372 .32453 .23751 .31833 Metetra
.664 .741 .908 r
.23751 .31833 .24372 .32453 .25297 .32118 .24678 .31495 Metetra
.664 .741 .908 r
.24678 .31495 .25297 .32118 .26225 .31781 .25608 .31156 Metetra
.664 .741 .908 r
.25608 .31156 .26225 .31781 .27157 .31443 .26542 .30816 Metetra
.664 .741 .908 r
.26542 .30816 .27157 .31443 .28092 .31104 .27479 .30475 Metetra
.664 .741 .908 r
.27479 .30475 .28092 .31104 .2903 .30764 .28419 .30132 Metetra
.664 .741 .908 r
.28419 .30132 .2903 .30764 .29971 .30422 .29362 .29788 Metetra
.664 .741 .908 r
.29362 .29788 .29971 .30422 .30916 .30079 .30309 .29443 Metetra
.664 .741 .908 r
.30309 .29443 .30916 .30079 .31865 .29735 .3126 .29097 Metetra
.664 .741 .908 r
.3126 .29097 .31865 .29735 .32816 .2939 .32213 .28749 Metetra
.664 .741 .908 r
.32213 .28749 .32816 .2939 .33771 .29044 .33171 .28401 Metetra
.664 .741 .908 r
.33171 .28401 .33771 .29044 .3473 .28696 .34131 .2805 Metetra
.664 .741 .908 r
.34131 .2805 .3473 .28696 .35692 .28347 .35095 .27699 Metetra
.664 .741 .908 r
.35095 .27699 .35692 .28347 .36657 .27996 .36063 .27347 Metetra
.664 .741 .908 r
.36063 .27347 .36657 .27996 .37627 .27645 .37034 .26993 Metetra
.664 .741 .908 r
.37034 .26993 .37627 .27645 .38599 .27292 .38009 .26637 Metetra
.664 .741 .908 r
.38009 .26637 .38599 .27292 .39575 .26938 .38987 .26281 Metetra
.664 .741 .908 r
.38987 .26281 .39575 .26938 .40555 .26583 .39969 .25923 Metetra
.664 .741 .908 r
.39969 .25923 .40555 .26583 .41538 .26226 .40955 .25564 Metetra
.664 .741 .908 r
.40955 .25564 .41538 .26226 .42525 .25868 .41944 .25204 Metetra
.664 .741 .908 r
.41944 .25204 .42525 .25868 .43515 .25509 .42937 .24842 Metetra
.664 .741 .908 r
.42937 .24842 .43515 .25509 .44509 .25148 .43933 .24479 Metetra
.664 .741 .908 r
.43933 .24479 .44509 .25148 .45507 .24786 .44933 .24114 Metetra
.664 .741 .908 r
.44933 .24114 .45507 .24786 .46509 .24423 .45937 .23749 Metetra
.664 .741 .908 r
.45937 .23749 .46509 .24423 .47514 .24058 .46944 .23381 Metetra
.664 .741 .908 r
.46944 .23381 .47514 .24058 .48523 .23692 .47956 .23013 Metetra
.664 .741 .908 r
.47956 .23013 .48523 .23692 .49535 .23325 .48971 .22643 Metetra
.664 .741 .908 r
.48971 .22643 .49535 .23325 .50551 .22956 .49989 .22272 Metetra
.664 .741 .908 r
.49989 .22272 .50551 .22956 .51572 .22586 .51012 .21899 Metetra
.664 .741 .908 r
.51012 .21899 .51572 .22586 .52596 .22215 .52038 .21525 Metetra
.664 .741 .908 r
.52038 .21525 .52596 .22215 .53623 .21842 .53069 .2115 Metetra
.664 .741 .908 r
.53069 .2115 .53623 .21842 .54655 .21468 .54103 .20773 Metetra
.664 .741 .908 r
.54103 .20773 .54655 .21468 .5569 .21092 .55141 .20395 Metetra
.664 .741 .908 r
.55141 .20395 .5569 .21092 .5673 .20715 .56183 .20015 Metetra
.664 .741 .908 r
.56183 .20015 .5673 .20715 .57773 .20336 .57229 .19634 Metetra
.664 .741 .908 r
.57229 .19634 .57773 .20336 .5882 .19956 .58279 .19251 Metetra
.664 .741 .908 r
.58279 .19251 .5882 .19956 .59871 .19575 .59332 .18867 Metetra
.664 .741 .908 r
.59332 .18867 .59871 .19575 .60927 .19192 .6039 .18482 Metetra
.664 .741 .908 r
.6039 .18482 .60927 .19192 .61986 .18808 .61452 .18095 Metetra
.664 .741 .908 r
.61452 .18095 .61986 .18808 .63049 .18422 .62518 .17706 Metetra
.664 .741 .908 r
.62518 .17706 .63049 .18422 .64116 .18035 .63588 .17317 Metetra
.664 .741 .908 r
.63588 .17317 .64116 .18035 .65188 .17647 .64662 .16925 Metetra
.664 .741 .908 r
.64662 .16925 .65188 .17647 .66263 .17256 .6574 .16532 Metetra
.664 .741 .908 r
.6574 .16532 .66263 .17256 .67342 .16865 .66823 .16138 Metetra
.664 .741 .908 r
.66823 .16138 .67342 .16865 .68426 .16472 .67909 .15742 Metetra
.664 .741 .908 r
.67909 .15742 .68426 .16472 .69514 .16077 .69 .15345 Metetra
.664 .741 .908 r
.69 .15345 .69514 .16077 .70606 .15681 .70095 .14946 Metetra
.664 .741 .908 r
.70095 .14946 .70606 .15681 .71702 .15283 .71194 .14545 Metetra
.664 .741 .908 r
.71194 .14545 .71702 .15283 .72803 .14884 .72297 .14143 Metetra
.664 .741 .908 r
.72297 .14143 .72803 .14884 .73907 .14483 .73405 .13739 Metetra
.664 .741 .908 r
.73405 .13739 .73907 .14483 .75016 .14081 .74517 .13334 Metetra
.664 .741 .908 r
.74517 .13334 .75016 .14081 .7613 .13677 .75634 .12927 Metetra
.664 .741 .908 r
.75634 .12927 .7613 .13677 .77247 .13272 .76754 .12519 Metetra
.664 .741 .908 r
.13124 .3487 .13769 .3547 .14661 .35145 .14017 .34543 Metetra
.664 .741 .908 r
.14017 .34543 .14661 .35145 .15555 .34819 .14914 .34214 Metetra
.664 .741 .908 r
.14914 .34214 .15555 .34819 .16453 .34492 .15813 .33885 Metetra
.664 .741 .908 r
.15813 .33885 .16453 .34492 .17354 .34164 .16716 .33555 Metetra
.664 .741 .908 r
.16716 .33555 .17354 .34164 .18259 .33834 .17622 .33223 Metetra
.664 .741 .908 r
.17622 .33223 .18259 .33834 .19166 .33504 .18532 .3289 Metetra
.664 .741 .908 r
.18532 .3289 .19166 .33504 .20077 .33172 .19444 .32556 Metetra
.664 .741 .908 r
.19444 .32556 .20077 .33172 .2099 .32839 .2036 .32221 Metetra
.664 .741 .908 r
.2036 .32221 .2099 .32839 .21907 .32505 .21279 .31885 Metetra
.664 .741 .908 r
.21279 .31885 .21907 .32505 .22828 .32169 .22201 .31547 Metetra
.664 .741 .908 r
.22201 .31547 .22828 .32169 .23751 .31833 .23126 .31208 Metetra
.664 .741 .908 r
.23126 .31208 .23751 .31833 .24678 .31495 .24055 .30868 Metetra
.664 .741 .908 r
.24055 .30868 .24678 .31495 .25608 .31156 .24987 .30527 Metetra
.664 .741 .908 r
.24987 .30527 .25608 .31156 .26542 .30816 .25923 .30185 Metetra
.664 .741 .908 r
.25923 .30185 .26542 .30816 .27479 .30475 .26861 .29841 Metetra
.664 .741 .908 r
.26861 .29841 .27479 .30475 .28419 .30132 .27804 .29496 Metetra
.664 .741 .908 r
.27804 .29496 .28419 .30132 .29362 .29788 .28749 .2915 Metetra
.664 .741 .908 r
.28749 .2915 .29362 .29788 .30309 .29443 .29698 .28803 Metetra
.664 .741 .908 r
.29698 .28803 .30309 .29443 .3126 .29097 .30651 .28454 Metetra
.664 .741 .908 r
.30651 .28454 .3126 .29097 .32213 .28749 .31606 .28104 Metetra
.664 .741 .908 r
.31606 .28104 .32213 .28749 .33171 .28401 .32566 .27753 Metetra
.664 .741 .908 r
.32566 .27753 .33171 .28401 .34131 .2805 .33529 .27401 Metetra
.664 .741 .908 r
.33529 .27401 .34131 .2805 .35095 .27699 .34495 .27047 Metetra
.664 .741 .908 r
.34495 .27047 .35095 .27699 .36063 .27347 .35465 .26692 Metetra
.664 .741 .908 r
.35465 .26692 .36063 .27347 .37034 .26993 .36438 .26336 Metetra
.664 .741 .908 r
.36438 .26336 .37034 .26993 .38009 .26637 .37415 .25978 Metetra
.664 .741 .908 r
.37415 .25978 .38009 .26637 .38987 .26281 .38396 .25619 Metetra
.664 .741 .908 r
.38396 .25619 .38987 .26281 .39969 .25923 .3938 .25259 Metetra
.664 .741 .908 r
.3938 .25259 .39969 .25923 .40955 .25564 .40367 .24898 Metetra
.664 .741 .908 r
.40367 .24898 .40955 .25564 .41944 .25204 .41359 .24535 Metetra
.664 .741 .908 r
.41359 .24535 .41944 .25204 .42937 .24842 .42354 .24171 Metetra
.664 .741 .908 r
.42354 .24171 .42937 .24842 .43933 .24479 .43353 .23805 Metetra
.664 .741 .908 r
.43353 .23805 .43933 .24479 .44933 .24114 .44355 .23438 Metetra
.664 .741 .908 r
.44355 .23438 .44933 .24114 .45937 .23749 .45361 .2307 Metetra
.664 .741 .908 r
.45361 .2307 .45937 .23749 .46944 .23381 .46371 .227 Metetra
.664 .741 .908 r
.46371 .227 .46944 .23381 .47956 .23013 .47385 .22329 Metetra
.664 .741 .908 r
.47385 .22329 .47956 .23013 .48971 .22643 .48402 .21957 Metetra
.664 .741 .908 r
.48402 .21957 .48971 .22643 .49989 .22272 .49423 .21583 Metetra
.664 .741 .908 r
.49423 .21583 .49989 .22272 .51012 .21899 .50449 .21208 Metetra
.664 .741 .908 r
.50449 .21208 .51012 .21899 .52038 .21525 .51477 .20831 Metetra
.664 .741 .908 r
.51477 .20831 .52038 .21525 .53069 .2115 .5251 .20453 Metetra
.664 .741 .908 r
.5251 .20453 .53069 .2115 .54103 .20773 .53547 .20073 Metetra
.664 .741 .908 r
.53547 .20073 .54103 .20773 .55141 .20395 .54588 .19693 Metetra
.664 .741 .908 r
.54588 .19693 .55141 .20395 .56183 .20015 .55632 .1931 Metetra
.664 .741 .908 r
.55632 .1931 .56183 .20015 .57229 .19634 .56681 .18926 Metetra
.664 .741 .908 r
.56681 .18926 .57229 .19634 .58279 .19251 .57733 .18541 Metetra
.664 .741 .908 r
.57733 .18541 .58279 .19251 .59332 .18867 .5879 .18155 Metetra
.664 .741 .908 r
.5879 .18155 .59332 .18867 .6039 .18482 .5985 .17766 Metetra
.664 .741 .908 r
.5985 .17766 .6039 .18482 .61452 .18095 .60915 .17377 Metetra
.664 .741 .908 r
.60915 .17377 .61452 .18095 .62518 .17706 .61983 .16985 Metetra
.664 .741 .908 r
.61983 .16985 .62518 .17706 .63588 .17317 .63056 .16593 Metetra
.664 .741 .908 r
.63056 .16593 .63588 .17317 .64662 .16925 .64133 .16199 Metetra
.664 .741 .908 r
.64133 .16199 .64662 .16925 .6574 .16532 .65214 .15803 Metetra
.664 .741 .908 r
.65214 .15803 .6574 .16532 .66823 .16138 .66299 .15406 Metetra
.664 .741 .908 r
.66299 .15406 .66823 .16138 .67909 .15742 .67389 .15007 Metetra
.664 .741 .908 r
.67389 .15007 .67909 .15742 .69 .15345 .68482 .14607 Metetra
.664 .741 .908 r
.68482 .14607 .69 .15345 .70095 .14946 .6958 .14205 Metetra
.664 .741 .908 r
.6958 .14205 .70095 .14946 .71194 .14545 .70682 .13801 Metetra
.664 .741 .908 r
.70682 .13801 .71194 .14545 .72297 .14143 .71788 .13396 Metetra
.664 .741 .908 r
.71788 .13396 .72297 .14143 .73405 .13739 .72899 .1299 Metetra
.664 .741 .908 r
.72899 .1299 .73405 .13739 .74517 .13334 .74014 .12582 Metetra
.664 .741 .908 r
.74014 .12582 .74517 .13334 .75634 .12927 .75134 .12172 Metetra
.664 .741 .908 r
.75134 .12172 .75634 .12927 .76754 .12519 .76258 .11761 Metetra
.664 .741 .908 r
.12474 .34265 .13124 .3487 .14017 .34543 .1337 .33936 Metetra
.664 .741 .908 r
.1337 .33936 .14017 .34543 .14914 .34214 .14268 .33606 Metetra
.664 .741 .908 r
.14268 .33606 .14914 .34214 .15813 .33885 .15169 .33274 Metetra
.664 .741 .908 r
.15169 .33274 .15813 .33885 .16716 .33555 .16074 .32942 Metetra
.664 .741 .908 r
.16074 .32942 .16716 .33555 .17622 .33223 .16982 .32608 Metetra
.664 .741 .908 r
.16982 .32608 .17622 .33223 .18532 .3289 .17893 .32273 Metetra
.664 .741 .908 r
.17893 .32273 .18532 .3289 .19444 .32556 .18807 .31937 Metetra
.664 .741 .908 r
.18807 .31937 .19444 .32556 .2036 .32221 .19725 .31599 Metetra
.664 .741 .908 r
.19725 .31599 .2036 .32221 .21279 .31885 .20646 .31261 Metetra
.664 .741 .908 r
.20646 .31261 .21279 .31885 .22201 .31547 .2157 .30921 Metetra
.664 .741 .908 r
.2157 .30921 .22201 .31547 .23126 .31208 .22497 .3058 Metetra
.664 .741 .908 r
.22497 .3058 .23126 .31208 .24055 .30868 .23428 .30238 Metetra
.664 .741 .908 r
.23428 .30238 .24055 .30868 .24987 .30527 .24362 .29894 Metetra
.664 .741 .908 r
.24362 .29894 .24987 .30527 .25923 .30185 .25299 .29549 Metetra
.664 .741 .908 r
.25299 .29549 .25923 .30185 .26861 .29841 .2624 .29204 Metetra
.664 .741 .908 r
.2624 .29204 .26861 .29841 .27804 .29496 .27184 .28856 Metetra
.664 .741 .908 r
.27184 .28856 .27804 .29496 .28749 .2915 .28132 .28508 Metetra
.664 .741 .908 r
.28132 .28508 .28749 .2915 .29698 .28803 .29083 .28158 Metetra
.664 .741 .908 r
.29083 .28158 .29698 .28803 .30651 .28454 .30038 .27807 Metetra
.664 .741 .908 r
.30038 .27807 .30651 .28454 .31606 .28104 .30995 .27455 Metetra
.664 .741 .908 r
.30995 .27455 .31606 .28104 .32566 .27753 .31957 .27102 Metetra
.664 .741 .908 r
.31957 .27102 .32566 .27753 .33529 .27401 .32922 .26747 Metetra
.664 .741 .908 r
.32922 .26747 .33529 .27401 .34495 .27047 .3389 .26391 Metetra
.664 .741 .908 r
.3389 .26391 .34495 .27047 .35465 .26692 .34862 .26033 Metetra
.664 .741 .908 r
.34862 .26033 .35465 .26692 .36438 .26336 .35838 .25675 Metetra
.664 .741 .908 r
.35838 .25675 .36438 .26336 .37415 .25978 .36817 .25315 Metetra
.664 .741 .908 r
.36817 .25315 .37415 .25978 .38396 .25619 .378 .24953 Metetra
.664 .741 .908 r
.378 .24953 .38396 .25619 .3938 .25259 .38786 .24591 Metetra
.664 .741 .908 r
.38786 .24591 .3938 .25259 .40367 .24898 .39776 .24227 Metetra
.664 .741 .908 r
.39776 .24227 .40367 .24898 .41359 .24535 .4077 .23861 Metetra
.664 .741 .908 r
.4077 .23861 .41359 .24535 .42354 .24171 .41767 .23495 Metetra
.664 .741 .908 r
.41767 .23495 .42354 .24171 .43353 .23805 .42768 .23126 Metetra
.664 .741 .908 r
.42768 .23126 .43353 .23805 .44355 .23438 .43773 .22757 Metetra
.664 .741 .908 r
.43773 .22757 .44355 .23438 .45361 .2307 .44782 .22386 Metetra
.664 .741 .908 r
.44782 .22386 .45361 .2307 .46371 .227 .45794 .22014 Metetra
.664 .741 .908 r
.45794 .22014 .46371 .227 .47385 .22329 .4681 .2164 Metetra
.664 .741 .908 r
.4681 .2164 .47385 .22329 .48402 .21957 .4783 .21265 Metetra
.664 .741 .908 r
.4783 .21265 .48402 .21957 .49423 .21583 .48854 .20889 Metetra
.664 .741 .908 r
.48854 .20889 .49423 .21583 .50449 .21208 .49881 .20511 Metetra
.664 .741 .908 r
.49881 .20511 .50449 .21208 .51477 .20831 .50913 .20132 Metetra
.664 .741 .908 r
.50913 .20132 .51477 .20831 .5251 .20453 .51948 .19751 Metetra
.664 .741 .908 r
.51948 .19751 .5251 .20453 .53547 .20073 .52987 .19369 Metetra
.664 .741 .908 r
.52987 .19369 .53547 .20073 .54588 .19693 .5403 .18986 Metetra
.664 .741 .908 r
.5403 .18986 .54588 .19693 .55632 .1931 .55077 .18601 Metetra
.664 .741 .908 r
.55077 .18601 .55632 .1931 .56681 .18926 .56129 .18214 Metetra
.664 .741 .908 r
.56129 .18214 .56681 .18926 .57733 .18541 .57184 .17826 Metetra
.664 .741 .908 r
.57184 .17826 .57733 .18541 .5879 .18155 .58243 .17437 Metetra
.664 .741 .908 r
.58243 .17437 .5879 .18155 .5985 .17766 .59306 .17046 Metetra
.664 .741 .908 r
.59306 .17046 .5985 .17766 .60915 .17377 .60373 .16653 Metetra
.664 .741 .908 r
.60373 .16653 .60915 .17377 .61983 .16985 .61445 .16259 Metetra
.664 .741 .908 r
.61445 .16259 .61983 .16985 .63056 .16593 .6252 .15864 Metetra
.664 .741 .908 r
.6252 .15864 .63056 .16593 .64133 .16199 .636 .15467 Metetra
.664 .741 .908 r
.636 .15467 .64133 .16199 .65214 .15803 .64684 .15068 Metetra
.664 .741 .908 r
.64684 .15068 .65214 .15803 .66299 .15406 .65772 .14668 Metetra
.664 .741 .908 r
.65772 .14668 .66299 .15406 .67389 .15007 .66864 .14267 Metetra
.664 .741 .908 r
.66864 .14267 .67389 .15007 .68482 .14607 .67961 .13864 Metetra
.664 .741 .908 r
.67961 .13864 .68482 .14607 .6958 .14205 .69061 .13459 Metetra
.664 .741 .908 r
.69061 .13459 .6958 .14205 .70682 .13801 .70167 .13053 Metetra
.664 .741 .908 r
.70167 .13053 .70682 .13801 .71788 .13396 .71276 .12645 Metetra
.664 .741 .908 r
.71276 .12645 .71788 .13396 .72899 .1299 .7239 .12235 Metetra
.664 .741 .908 r
.7239 .12235 .72899 .1299 .74014 .12582 .73508 .11824 Metetra
.664 .741 .908 r
.73508 .11824 .74014 .12582 .75134 .12172 .7463 .11411 Metetra
.664 .741 .908 r
.7463 .11411 .75134 .12172 .76258 .11761 .75757 .10997 Metetra
.664 .741 .908 r
.11821 .33656 .12474 .34265 .1337 .33936 .12718 .33325 Metetra
.664 .741 .908 r
.12718 .33325 .1337 .33936 .14268 .33606 .13618 .32993 Metetra
.664 .741 .908 r
.13618 .32993 .14268 .33606 .15169 .33274 .14521 .32659 Metetra
.664 .741 .908 r
.14521 .32659 .15169 .33274 .16074 .32942 .15428 .32324 Metetra
.664 .741 .908 r
.15428 .32324 .16074 .32942 .16982 .32608 .16337 .31988 Metetra
.664 .741 .908 r
.16337 .31988 .16982 .32608 .17893 .32273 .1725 .31651 Metetra
.664 .741 .908 r
.1725 .31651 .17893 .32273 .18807 .31937 .18166 .31313 Metetra
.664 .741 .908 r
.18166 .31313 .18807 .31937 .19725 .31599 .19086 .30973 Metetra
.664 .741 .908 r
.19086 .30973 .19725 .31599 .20646 .31261 .20009 .30632 Metetra
.664 .741 .908 r
.20009 .30632 .20646 .31261 .2157 .30921 .20935 .3029 Metetra
.664 .741 .908 r
.20935 .3029 .2157 .30921 .22497 .3058 .21864 .29947 Metetra
.664 .741 .908 r
.21864 .29947 .22497 .3058 .23428 .30238 .22797 .29603 Metetra
.664 .741 .908 r
.22797 .29603 .23428 .30238 .24362 .29894 .23733 .29257 Metetra
.664 .741 .908 r
.23733 .29257 .24362 .29894 .25299 .29549 .24672 .2891 Metetra
.664 .741 .908 r
.24672 .2891 .25299 .29549 .2624 .29204 .25615 .28562 Metetra
.664 .741 .908 r
.25615 .28562 .2624 .29204 .27184 .28856 .26561 .28212 Metetra
.664 .741 .908 r
.26561 .28212 .27184 .28856 .28132 .28508 .27511 .27861 Metetra
.664 .741 .908 r
.27511 .27861 .28132 .28508 .29083 .28158 .28464 .27509 Metetra
.664 .741 .908 r
.28464 .27509 .29083 .28158 .30038 .27807 .2942 .27156 Metetra
.664 .741 .908 r
.2942 .27156 .30038 .27807 .30995 .27455 .3038 .26802 Metetra
.664 .741 .908 r
.3038 .26802 .30995 .27455 .31957 .27102 .31344 .26446 Metetra
.664 .741 .908 r
.31344 .26446 .31957 .27102 .32922 .26747 .32311 .26088 Metetra
.664 .741 .908 r
.32311 .26088 .32922 .26747 .3389 .26391 .33282 .2573 Metetra
.664 .741 .908 r
.33282 .2573 .3389 .26391 .34862 .26033 .34256 .2537 Metetra
.664 .741 .908 r
.34256 .2537 .34862 .26033 .35838 .25675 .35234 .25009 Metetra
.664 .741 .908 r
.35234 .25009 .35838 .25675 .36817 .25315 .36215 .24647 Metetra
.664 .741 .908 r
.36215 .24647 .36817 .25315 .378 .24953 .372 .24283 Metetra
.664 .741 .908 r
.372 .24283 .378 .24953 .38786 .24591 .38189 .23918 Metetra
.664 .741 .908 r
.38189 .23918 .38786 .24591 .39776 .24227 .39181 .23551 Metetra
.664 .741 .908 r
.39181 .23551 .39776 .24227 .4077 .23861 .40177 .23183 Metetra
.664 .741 .908 r
.40177 .23183 .4077 .23861 .41767 .23495 .41177 .22814 Metetra
.664 .741 .908 r
.41177 .22814 .41767 .23495 .42768 .23126 .4218 .22443 Metetra
.664 .741 .908 r
.4218 .22443 .42768 .23126 .43773 .22757 .43187 .22071 Metetra
.664 .741 .908 r
.43187 .22071 .43773 .22757 .44782 .22386 .44198 .21698 Metetra
.664 .741 .908 r
.44198 .21698 .44782 .22386 .45794 .22014 .45213 .21323 Metetra
.664 .741 .908 r
.45213 .21323 .45794 .22014 .4681 .2164 .46231 .20947 Metetra
.664 .741 .908 r
.46231 .20947 .4681 .2164 .4783 .21265 .47254 .20569 Metetra
.664 .741 .908 r
.47254 .20569 .4783 .21265 .48854 .20889 .4828 .2019 Metetra
.664 .741 .908 r
.4828 .2019 .48854 .20889 .49881 .20511 .4931 .1981 Metetra
.664 .741 .908 r
.4931 .1981 .49881 .20511 .50913 .20132 .50344 .19428 Metetra
.664 .741 .908 r
.50344 .19428 .50913 .20132 .51948 .19751 .51382 .19045 Metetra
.664 .741 .908 r
.51382 .19045 .51948 .19751 .52987 .19369 .52423 .1866 Metetra
.664 .741 .908 r
.52423 .1866 .52987 .19369 .5403 .18986 .53469 .18274 Metetra
.664 .741 .908 r
.53469 .18274 .5403 .18986 .55077 .18601 .54519 .17886 Metetra
.664 .741 .908 r
.54519 .17886 .55077 .18601 .56129 .18214 .55573 .17497 Metetra
.664 .741 .908 r
.55573 .17497 .56129 .18214 .57184 .17826 .56631 .17106 Metetra
.664 .741 .908 r
.56631 .17106 .57184 .17826 .58243 .17437 .57692 .16714 Metetra
.664 .741 .908 r
.57692 .16714 .58243 .17437 .59306 .17046 .58758 .1632 Metetra
.664 .741 .908 r
.58758 .1632 .59306 .17046 .60373 .16653 .59828 .15925 Metetra
.664 .741 .908 r
.59828 .15925 .60373 .16653 .61445 .16259 .60903 .15528 Metetra
.664 .741 .908 r
.60903 .15528 .61445 .16259 .6252 .15864 .61981 .1513 Metetra
.664 .741 .908 r
.61981 .1513 .6252 .15864 .636 .15467 .63063 .1473 Metetra
.664 .741 .908 r
.63063 .1473 .636 .15467 .64684 .15068 .6415 .14329 Metetra
.664 .741 .908 r
.6415 .14329 .64684 .15068 .65772 .14668 .65241 .13926 Metetra
.664 .741 .908 r
.65241 .13926 .65772 .14668 .66864 .14267 .66336 .13521 Metetra
.664 .741 .908 r
.66336 .13521 .66864 .14267 .67961 .13864 .67436 .13115 Metetra
.664 .741 .908 r
.67436 .13115 .67961 .13864 .69061 .13459 .68539 .12708 Metetra
.664 .741 .908 r
.68539 .12708 .69061 .13459 .70167 .13053 .69647 .12298 Metetra
.664 .741 .908 r
.69647 .12298 .70167 .13053 .71276 .12645 .7076 .11887 Metetra
.664 .741 .908 r
.7076 .11887 .71276 .12645 .7239 .12235 .71876 .11475 Metetra
.664 .741 .908 r
.71876 .11475 .7239 .12235 .73508 .11824 .72998 .11061 Metetra
.664 .741 .908 r
.72998 .11061 .73508 .11824 .7463 .11411 .74123 .10645 Metetra
.664 .741 .908 r
.74123 .10645 .7463 .11411 .75757 .10997 .75253 .10228 Metetra
.664 .741 .908 r
.11163 .33044 .11821 .33656 .12718 .33325 .12062 .32711 Metetra
.664 .741 .908 r
.12062 .32711 .12718 .33325 .13618 .32993 .12964 .32376 Metetra
.664 .741 .908 r
.12964 .32376 .13618 .32993 .14521 .32659 .13869 .3204 Metetra
.664 .741 .908 r
.13869 .3204 .14521 .32659 .15428 .32324 .14777 .31703 Metetra
.664 .741 .908 r
.14777 .31703 .15428 .32324 .16337 .31988 .15688 .31365 Metetra
.664 .741 .908 r
.15688 .31365 .16337 .31988 .1725 .31651 .16603 .31025 Metetra
.664 .741 .908 r
.16603 .31025 .1725 .31651 .18166 .31313 .17521 .30685 Metetra
.664 .741 .908 r
.17521 .30685 .18166 .31313 .19086 .30973 .18443 .30343 Metetra
.664 .741 .908 r
.18443 .30343 .19086 .30973 .20009 .30632 .19367 .3 Metetra
.664 .741 .908 r
.19367 .3 .20009 .30632 .20935 .3029 .20295 .29656 Metetra
.664 .741 .908 r
.20295 .29656 .20935 .3029 .21864 .29947 .21226 .2931 Metetra
.664 .741 .908 r
.21226 .2931 .21864 .29947 .22797 .29603 .22161 .28963 Metetra
.664 .741 .908 r
.22161 .28963 .22797 .29603 .23733 .29257 .23099 .28615 Metetra
.664 .741 .908 r
.23099 .28615 .23733 .29257 .24672 .2891 .2404 .28266 Metetra
.664 .741 .908 r
.2404 .28266 .24672 .2891 .25615 .28562 .24985 .27915 Metetra
.664 .741 .908 r
.24985 .27915 .25615 .28562 .26561 .28212 .25934 .27564 Metetra
.664 .741 .908 r
.25934 .27564 .26561 .28212 .27511 .27861 .26885 .27211 Metetra
.664 .741 .908 r
.26885 .27211 .27511 .27861 .28464 .27509 .2784 .26856 Metetra
.664 .741 .908 r
.2784 .26856 .28464 .27509 .2942 .27156 .28799 .265 Metetra
.664 .741 .908 r
.28799 .265 .2942 .27156 .3038 .26802 .29761 .26143 Metetra
.664 .741 .908 r
.29761 .26143 .3038 .26802 .31344 .26446 .30727 .25785 Metetra
.664 .741 .908 r
.30727 .25785 .31344 .26446 .32311 .26088 .31696 .25426 Metetra
.664 .741 .908 r
.31696 .25426 .32311 .26088 .33282 .2573 .32669 .25065 Metetra
.664 .741 .908 r
.32669 .25065 .33282 .2573 .34256 .2537 .33645 .24702 Metetra
.664 .741 .908 r
.33645 .24702 .34256 .2537 .35234 .25009 .34625 .24339 Metetra
.664 .741 .908 r
.34625 .24339 .35234 .25009 .36215 .24647 .35609 .23974 Metetra
.664 .741 .908 r
.35609 .23974 .36215 .24647 .372 .24283 .36596 .23608 Metetra
.664 .741 .908 r
.36596 .23608 .372 .24283 .38189 .23918 .37587 .2324 Metetra
.664 .741 .908 r
.37587 .2324 .38189 .23918 .39181 .23551 .38581 .22871 Metetra
.664 .741 .908 r
.38581 .22871 .39181 .23551 .40177 .23183 .3958 .225 Metetra
.664 .741 .908 r
.3958 .225 .40177 .23183 .41177 .22814 .40582 .22129 Metetra
.664 .741 .908 r
.40582 .22129 .41177 .22814 .4218 .22443 .41587 .21756 Metetra
.664 .741 .908 r
.41587 .21756 .4218 .22443 .43187 .22071 .42597 .21381 Metetra
.664 .741 .908 r
.42597 .21381 .43187 .22071 .44198 .21698 .4361 .21005 Metetra
.664 .741 .908 r
.4361 .21005 .44198 .21698 .45213 .21323 .44627 .20628 Metetra
.664 .741 .908 r
.44627 .20628 .45213 .21323 .46231 .20947 .45648 .20249 Metetra
.664 .741 .908 r
.45648 .20249 .46231 .20947 .47254 .20569 .46673 .19869 Metetra
.664 .741 .908 r
.46673 .19869 .47254 .20569 .4828 .2019 .47702 .19487 Metetra
.664 .741 .908 r
.47702 .19487 .4828 .2019 .4931 .1981 .48734 .19104 Metetra
.664 .741 .908 r
.48734 .19104 .4931 .1981 .50344 .19428 .49771 .18719 Metetra
.664 .741 .908 r
.49771 .18719 .50344 .19428 .51382 .19045 .50811 .18333 Metetra
.664 .741 .908 r
.50811 .18333 .51382 .19045 .52423 .1866 .51856 .17946 Metetra
.664 .741 .908 r
.51856 .17946 .52423 .1866 .53469 .18274 .52904 .17557 Metetra
.664 .741 .908 r
.52904 .17557 .53469 .18274 .54519 .17886 .53957 .17166 Metetra
.664 .741 .908 r
.53957 .17166 .54519 .17886 .55573 .17497 .55013 .16774 Metetra
.664 .741 .908 r
.55013 .16774 .55573 .17497 .56631 .17106 .56073 .16381 Metetra
.664 .741 .908 r
.56073 .16381 .56631 .17106 .57692 .16714 .57138 .15986 Metetra
.664 .741 .908 r
.57138 .15986 .57692 .16714 .58758 .1632 .58207 .15589 Metetra
.664 .741 .908 r
.58207 .15589 .58758 .1632 .59828 .15925 .59279 .15191 Metetra
.664 .741 .908 r
.59279 .15191 .59828 .15925 .60903 .15528 .60356 .14792 Metetra
.664 .741 .908 r
.60356 .14792 .60903 .15528 .61981 .1513 .61437 .14391 Metetra
.664 .741 .908 r
.61437 .14391 .61981 .1513 .63063 .1473 .62523 .13988 Metetra
.664 .741 .908 r
.62523 .13988 .63063 .1473 .6415 .14329 .63612 .13584 Metetra
.664 .741 .908 r
.63612 .13584 .6415 .14329 .65241 .13926 .64706 .13178 Metetra
.664 .741 .908 r
.64706 .13178 .65241 .13926 .66336 .13521 .65804 .1277 Metetra
.664 .741 .908 r
.65804 .1277 .66336 .13521 .67436 .13115 .66907 .12361 Metetra
.664 .741 .908 r
.66907 .12361 .67436 .13115 .68539 .12708 .68013 .11951 Metetra
.664 .741 .908 r
.68013 .11951 .68539 .12708 .69647 .12298 .69124 .11539 Metetra
.664 .741 .908 r
.69124 .11539 .69647 .12298 .7076 .11887 .7024 .11125 Metetra
.664 .741 .908 r
.7024 .11125 .7076 .11887 .71876 .11475 .71359 .10709 Metetra
.664 .741 .908 r
.71359 .10709 .71876 .11475 .72998 .11061 .72484 .10292 Metetra
.664 .741 .908 r
.72484 .10292 .72998 .11061 .74123 .10645 .73612 .09873 Metetra
.664 .741 .908 r
.73612 .09873 .74123 .10645 .75253 .10228 .74745 .09453 Metetra
.664 .741 .908 r
.10501 .32427 .11163 .33044 .12062 .32711 .11401 .32092 Metetra
.664 .741 .908 r
.11401 .32092 .12062 .32711 .12964 .32376 .12305 .31755 Metetra
.664 .741 .908 r
.12305 .31755 .12964 .32376 .13869 .3204 .13212 .31417 Metetra
.664 .741 .908 r
.13212 .31417 .13869 .3204 .14777 .31703 .14122 .31078 Metetra
.664 .741 .908 r
.14122 .31078 .14777 .31703 .15688 .31365 .15035 .30737 Metetra
.664 .741 .908 r
.15035 .30737 .15688 .31365 .16603 .31025 .15952 .30396 Metetra
.664 .741 .908 r
.15952 .30396 .16603 .31025 .17521 .30685 .16872 .30053 Metetra
.664 .741 .908 r
.16872 .30053 .17521 .30685 .18443 .30343 .17795 .29709 Metetra
.664 .741 .908 r
.17795 .29709 .18443 .30343 .19367 .3 .18722 .29363 Metetra
.664 .741 .908 r
.18722 .29363 .19367 .3 .20295 .29656 .19651 .29017 Metetra
.664 .741 .908 r
.19651 .29017 .20295 .29656 .21226 .2931 .20585 .28669 Metetra
.664 .741 .908 r
.20585 .28669 .21226 .2931 .22161 .28963 .21521 .2832 Metetra
.664 .741 .908 r
.21521 .2832 .22161 .28963 .23099 .28615 .22461 .27969 Metetra
.664 .741 .908 r
.22461 .27969 .23099 .28615 .2404 .28266 .23405 .27618 Metetra
.664 .741 .908 r
.23405 .27618 .2404 .28266 .24985 .27915 .24351 .27265 Metetra
.664 .741 .908 r
.24351 .27265 .24985 .27915 .25934 .27564 .25302 .26911 Metetra
.664 .741 .908 r
.25302 .26911 .25934 .27564 .26885 .27211 .26255 .26555 Metetra
.664 .741 .908 r
.26255 .26555 .26885 .27211 .2784 .26856 .27213 .26198 Metetra
.664 .741 .908 r
.27213 .26198 .2784 .26856 .28799 .265 .28173 .2584 Metetra
.664 .741 .908 r
.28173 .2584 .28799 .265 .29761 .26143 .29138 .25481 Metetra
.664 .741 .908 r
.29138 .25481 .29761 .26143 .30727 .25785 .30106 .2512 Metetra
.664 .741 .908 r
.30106 .2512 .30727 .25785 .31696 .25426 .31077 .24758 Metetra
.664 .741 .908 r
.31077 .24758 .31696 .25426 .32669 .25065 .32052 .24395 Metetra
.664 .741 .908 r
.32052 .24395 .32669 .25065 .33645 .24702 .3303 .2403 Metetra
.664 .741 .908 r
.3303 .2403 .33645 .24702 .34625 .24339 .34013 .23664 Metetra
.664 .741 .908 r
.34013 .23664 .34625 .24339 .35609 .23974 .34998 .23297 Metetra
.664 .741 .908 r
.34998 .23297 .35609 .23974 .36596 .23608 .35988 .22928 Metetra
.664 .741 .908 r
.35988 .22928 .36596 .23608 .37587 .2324 .36981 .22558 Metetra
.664 .741 .908 r
.36981 .22558 .37587 .2324 .38581 .22871 .37978 .22186 Metetra
.664 .741 .908 r
.37978 .22186 .38581 .22871 .3958 .225 .38979 .21813 Metetra
.664 .741 .908 r
.38979 .21813 .3958 .225 .40582 .22129 .39983 .21439 Metetra
.664 .741 .908 r
.39983 .21439 .40582 .22129 .41587 .21756 .40991 .21063 Metetra
.664 .741 .908 r
.40991 .21063 .41587 .21756 .42597 .21381 .42003 .20686 Metetra
.664 .741 .908 r
.42003 .20686 .42597 .21381 .4361 .21005 .43019 .20307 Metetra
.664 .741 .908 r
.43019 .20307 .4361 .21005 .44627 .20628 .44038 .19927 Metetra
.664 .741 .908 r
.44038 .19927 .44627 .20628 .45648 .20249 .45062 .19546 Metetra
.664 .741 .908 r
.45062 .19546 .45648 .20249 .46673 .19869 .46089 .19163 Metetra
.664 .741 .908 r
.46089 .19163 .46673 .19869 .47702 .19487 .4712 .18778 Metetra
.664 .741 .908 r
.4712 .18778 .47702 .19487 .48734 .19104 .48155 .18393 Metetra
.664 .741 .908 r
.48155 .18393 .48734 .19104 .49771 .18719 .49194 .18005 Metetra
.664 .741 .908 r
.49194 .18005 .49771 .18719 .50811 .18333 .50237 .17617 Metetra
.664 .741 .908 r
.50237 .17617 .50811 .18333 .51856 .17946 .51284 .17226 Metetra
.664 .741 .908 r
.51284 .17226 .51856 .17946 .52904 .17557 .52335 .16835 Metetra
.664 .741 .908 r
.52335 .16835 .52904 .17557 .53957 .17166 .5339 .16441 Metetra
.664 .741 .908 r
.5339 .16441 .53957 .17166 .55013 .16774 .54449 .16047 Metetra
.664 .741 .908 r
.54449 .16047 .55013 .16774 .56073 .16381 .55512 .1565 Metetra
.664 .741 .908 r
.55512 .1565 .56073 .16381 .57138 .15986 .5658 .15253 Metetra
.664 .741 .908 r
.5658 .15253 .57138 .15986 .58207 .15589 .57651 .14853 Metetra
.664 .741 .908 r
.57651 .14853 .58207 .15589 .59279 .15191 .58727 .14452 Metetra
.664 .741 .908 r
.58727 .14452 .59279 .15191 .60356 .14792 .59806 .1405 Metetra
.664 .741 .908 r
.59806 .1405 .60356 .14792 .61437 .14391 .6089 .13646 Metetra
.664 .741 .908 r
.6089 .13646 .61437 .14391 .62523 .13988 .61978 .1324 Metetra
.664 .741 .908 r
.61978 .1324 .62523 .13988 .63612 .13584 .63071 .12833 Metetra
.664 .741 .908 r
.63071 .12833 .63612 .13584 .64706 .13178 .64167 .12424 Metetra
.664 .741 .908 r
.64167 .12424 .64706 .13178 .65804 .1277 .65268 .12014 Metetra
.664 .741 .908 r
.65268 .12014 .65804 .1277 .66907 .12361 .66374 .11602 Metetra
.664 .741 .908 r
.66374 .11602 .66907 .12361 .68013 .11951 .67483 .11188 Metetra
.664 .741 .908 r
.67483 .11188 .68013 .11951 .69124 .11539 .68597 .10773 Metetra
.664 .741 .908 r
.68597 .10773 .69124 .11539 .7024 .11125 .69716 .10356 Metetra
.664 .741 .908 r
.69716 .10356 .7024 .11125 .71359 .10709 .70839 .09938 Metetra
.664 .741 .908 r
.70839 .09938 .71359 .10709 .72484 .10292 .71966 .09518 Metetra
.664 .741 .908 r
.71966 .09518 .72484 .10292 .73612 .09873 .73098 .09096 Metetra
.664 .741 .908 r
.73098 .09096 .73612 .09873 .74745 .09453 .74234 .08672 Metetra
.664 .741 .908 r
.09834 .31807 .10501 .32427 .11401 .32092 .10737 .31469 Metetra
.664 .741 .908 r
.10737 .31469 .11401 .32092 .12305 .31755 .11642 .3113 Metetra
.664 .741 .908 r
.11642 .3113 .12305 .31755 .13212 .31417 .12551 .3079 Metetra
.664 .741 .908 r
.12551 .3079 .13212 .31417 .14122 .31078 .13463 .30448 Metetra
.664 .741 .908 r
.13463 .30448 .14122 .31078 .15035 .30737 .14378 .30106 Metetra
.664 .741 .908 r
.14378 .30106 .15035 .30737 .15952 .30396 .15296 .29762 Metetra
.664 .741 .908 r
.15296 .29762 .15952 .30396 .16872 .30053 .16218 .29417 Metetra
.664 .741 .908 r
.16218 .29417 .16872 .30053 .17795 .29709 .17143 .2907 Metetra
.664 .741 .908 r
.17143 .2907 .17795 .29709 .18722 .29363 .18072 .28723 Metetra
.664 .741 .908 r
.18072 .28723 .18722 .29363 .19651 .29017 .19003 .28374 Metetra
.664 .741 .908 r
.19003 .28374 .19651 .29017 .20585 .28669 .19939 .28023 Metetra
.664 .741 .908 r
.19939 .28023 .20585 .28669 .21521 .2832 .20877 .27672 Metetra
.664 .741 .908 r
.20877 .27672 .21521 .2832 .22461 .27969 .21819 .27319 Metetra
.664 .741 .908 r
.21819 .27319 .22461 .27969 .23405 .27618 .22765 .26965 Metetra
.664 .741 .908 r
.22765 .26965 .23405 .27618 .24351 .27265 .23713 .2661 Metetra
.664 .741 .908 r
.23713 .2661 .24351 .27265 .25302 .26911 .24666 .26253 Metetra
.664 .741 .908 r
.24666 .26253 .25302 .26911 .26255 .26555 .25622 .25896 Metetra
.664 .741 .908 r
.25622 .25896 .26255 .26555 .27213 .26198 .26581 .25536 Metetra
.664 .741 .908 r
.26581 .25536 .27213 .26198 .28173 .2584 .27544 .25176 Metetra
.664 .741 .908 r
.27544 .25176 .28173 .2584 .29138 .25481 .2851 .24814 Metetra
.664 .741 .908 r
.2851 .24814 .29138 .25481 .30106 .2512 .2948 .24451 Metetra
.664 .741 .908 r
.2948 .24451 .30106 .2512 .31077 .24758 .30454 .24086 Metetra
.664 .741 .908 r
.30454 .24086 .31077 .24758 .32052 .24395 .31431 .2372 Metetra
.664 .741 .908 r
.31431 .2372 .32052 .24395 .3303 .2403 .32411 .23353 Metetra
.664 .741 .908 r
.32411 .23353 .3303 .2403 .34013 .23664 .33396 .22985 Metetra
.664 .741 .908 r
.33396 .22985 .34013 .23664 .34998 .23297 .34384 .22615 Metetra
.664 .741 .908 r
.34384 .22615 .34998 .23297 .35988 .22928 .35376 .22243 Metetra
.664 .741 .908 r
.35376 .22243 .35988 .22928 .36981 .22558 .36371 .2187 Metetra
.664 .741 .908 r
.36371 .2187 .36981 .22558 .37978 .22186 .3737 .21496 Metetra
.664 .741 .908 r
.3737 .21496 .37978 .22186 .38979 .21813 .38373 .21121 Metetra
.664 .741 .908 r
.38373 .21121 .38979 .21813 .39983 .21439 .3938 .20744 Metetra
.664 .741 .908 r
.3938 .20744 .39983 .21439 .40991 .21063 .4039 .20366 Metetra
.664 .741 .908 r
.4039 .20366 .40991 .21063 .42003 .20686 .41405 .19986 Metetra
.664 .741 .908 r
.41405 .19986 .42003 .20686 .43019 .20307 .42423 .19604 Metetra
.664 .741 .908 r
.42423 .19604 .43019 .20307 .44038 .19927 .43445 .19222 Metetra
.664 .741 .908 r
.43445 .19222 .44038 .19927 .45062 .19546 .44471 .18838 Metetra
.664 .741 .908 r
.44471 .18838 .45062 .19546 .46089 .19163 .455 .18452 Metetra
.664 .741 .908 r
.455 .18452 .46089 .19163 .4712 .18778 .46534 .18065 Metetra
.664 .741 .908 r
.46534 .18065 .4712 .18778 .48155 .18393 .47572 .17677 Metetra
.664 .741 .908 r
.47572 .17677 .48155 .18393 .49194 .18005 .48613 .17287 Metetra
.664 .741 .908 r
.48613 .17287 .49194 .18005 .50237 .17617 .49659 .16895 Metetra
.664 .741 .908 r
.49659 .16895 .50237 .17617 .51284 .17226 .50708 .16502 Metetra
.664 .741 .908 r
.50708 .16502 .51284 .17226 .52335 .16835 .51762 .16107 Metetra
.664 .741 .908 r
.51762 .16107 .52335 .16835 .5339 .16441 .5282 .15711 Metetra
.664 .741 .908 r
.5282 .15711 .5339 .16441 .54449 .16047 .53881 .15314 Metetra
.664 .741 .908 r
.53881 .15314 .54449 .16047 .55512 .1565 .54947 .14915 Metetra
.664 .741 .908 r
.54947 .14915 .55512 .1565 .5658 .15253 .56017 .14514 Metetra
.664 .741 .908 r
.56017 .14514 .5658 .15253 .57651 .14853 .57091 .14112 Metetra
.664 .741 .908 r
.57091 .14112 .57651 .14853 .58727 .14452 .5817 .13708 Metetra
.664 .741 .908 r
.5817 .13708 .58727 .14452 .59806 .1405 .59252 .13303 Metetra
.664 .741 .908 r
.59252 .13303 .59806 .1405 .6089 .13646 .60339 .12896 Metetra
.664 .741 .908 r
.60339 .12896 .6089 .13646 .61978 .1324 .6143 .12487 Metetra
.664 .741 .908 r
.6143 .12487 .61978 .1324 .63071 .12833 .62525 .12077 Metetra
.664 .741 .908 r
.62525 .12077 .63071 .12833 .64167 .12424 .63625 .11666 Metetra
.664 .741 .908 r
.63625 .11666 .64167 .12424 .65268 .12014 .64729 .11252 Metetra
.664 .741 .908 r
.64729 .11252 .65268 .12014 .66374 .11602 .65837 .10837 Metetra
.664 .741 .908 r
.65837 .10837 .66374 .11602 .67483 .11188 .6695 .10421 Metetra
.664 .741 .908 r
.6695 .10421 .67483 .11188 .68597 .10773 .68067 .10002 Metetra
.664 .741 .908 r
.68067 .10002 .68597 .10773 .69716 .10356 .69188 .09582 Metetra
.664 .741 .908 r
.69188 .09582 .69716 .10356 .70839 .09938 .70314 .09161 Metetra
.664 .741 .908 r
.70314 .09161 .70839 .09938 .71966 .09518 .71444 .08738 Metetra
.664 .741 .908 r
.71444 .08738 .71966 .09518 .73098 .09096 .72579 .08313 Metetra
.664 .741 .908 r
.72579 .08313 .73098 .09096 .74234 .08672 .73719 .07886 Metetra
.664 .741 .908 r
.09164 .31182 .09834 .31807 .10737 .31469 .10068 .30842 Metetra
.664 .741 .908 r
.10068 .30842 .10737 .31469 .11642 .3113 .10975 .30501 Metetra
.664 .741 .908 r
.10975 .30501 .11642 .3113 .12551 .3079 .11885 .30158 Metetra
.664 .741 .908 r
.11885 .30158 .12551 .3079 .13463 .30448 .12799 .29815 Metetra
.664 .741 .908 r
.12799 .29815 .13463 .30448 .14378 .30106 .13716 .2947 Metetra
.664 .741 .908 r
.13716 .2947 .14378 .30106 .15296 .29762 .14636 .29124 Metetra
.664 .741 .908 r
.14636 .29124 .15296 .29762 .16218 .29417 .1556 .28776 Metetra
.664 .741 .908 r
.1556 .28776 .16218 .29417 .17143 .2907 .16487 .28427 Metetra
.664 .741 .908 r
.16487 .28427 .17143 .2907 .18072 .28723 .17417 .28077 Metetra
.664 .741 .908 r
.17417 .28077 .18072 .28723 .19003 .28374 .18351 .27726 Metetra
.664 .741 .908 r
.18351 .27726 .19003 .28374 .19939 .28023 .19288 .27374 Metetra
.664 .741 .908 r
.19288 .27374 .19939 .28023 .20877 .27672 .20229 .2702 Metetra
.664 .741 .908 r
.20229 .2702 .20877 .27672 .21819 .27319 .21173 .26665 Metetra
.664 .741 .908 r
.21173 .26665 .21819 .27319 .22765 .26965 .2212 .26308 Metetra
.664 .741 .908 r
.2212 .26308 .22765 .26965 .23713 .2661 .23071 .25951 Metetra
.664 .741 .908 r
.23071 .25951 .23713 .2661 .24666 .26253 .24025 .25592 Metetra
.664 .741 .908 r
.24025 .25592 .24666 .26253 .25622 .25896 .24983 .25231 Metetra
.664 .741 .908 r
.24983 .25231 .25622 .25896 .26581 .25536 .25945 .2487 Metetra
.664 .741 .908 r
.25945 .2487 .26581 .25536 .27544 .25176 .2691 .24507 Metetra
.664 .741 .908 r
.2691 .24507 .27544 .25176 .2851 .24814 .27878 .24142 Metetra
.664 .741 .908 r
.27878 .24142 .2851 .24814 .2948 .24451 .2885 .23777 Metetra
.664 .741 .908 r
.2885 .23777 .2948 .24451 .30454 .24086 .29826 .2341 Metetra
.664 .741 .908 r
.29826 .2341 .30454 .24086 .31431 .2372 .30805 .23041 Metetra
.664 .741 .908 r
.30805 .23041 .31431 .2372 .32411 .23353 .31788 .22672 Metetra
.664 .741 .908 r
.31788 .22672 .32411 .23353 .33396 .22985 .32775 .223 Metetra
.664 .741 .908 r
.32775 .223 .33396 .22985 .34384 .22615 .33765 .21928 Metetra
.664 .741 .908 r
.33765 .21928 .34384 .22615 .35376 .22243 .34759 .21554 Metetra
.664 .741 .908 r
.34759 .21554 .35376 .22243 .36371 .2187 .35757 .21179 Metetra
.664 .741 .908 r
.35757 .21179 .36371 .2187 .3737 .21496 .36758 .20802 Metetra
.664 .741 .908 r
.36758 .20802 .3737 .21496 .38373 .21121 .37764 .20424 Metetra
.664 .741 .908 r
.37764 .20424 .38373 .21121 .3938 .20744 .38773 .20044 Metetra
.664 .741 .908 r
.38773 .20044 .3938 .20744 .4039 .20366 .39785 .19663 Metetra
.664 .741 .908 r
.39785 .19663 .4039 .20366 .41405 .19986 .40802 .19281 Metetra
.664 .741 .908 r
.40802 .19281 .41405 .19986 .42423 .19604 .41823 .18897 Metetra
.664 .741 .908 r
.41823 .18897 .42423 .19604 .43445 .19222 .42847 .18512 Metetra
.664 .741 .908 r
.42847 .18512 .43445 .19222 .44471 .18838 .43875 .18125 Metetra
.664 .741 .908 r
.43875 .18125 .44471 .18838 .455 .18452 .44908 .17736 Metetra
.664 .741 .908 r
.44908 .17736 .455 .18452 .46534 .18065 .45944 .17347 Metetra
.664 .741 .908 r
.45944 .17347 .46534 .18065 .47572 .17677 .46984 .16955 Metetra
.664 .741 .908 r
.46984 .16955 .47572 .17677 .48613 .17287 .48028 .16563 Metetra
.664 .741 .908 r
.48028 .16563 .48613 .17287 .49659 .16895 .49076 .16168 Metetra
.664 .741 .908 r
.49076 .16168 .49659 .16895 .50708 .16502 .50129 .15772 Metetra
.664 .741 .908 r
.50129 .15772 .50708 .16502 .51762 .16107 .51185 .15375 Metetra
.664 .741 .908 r
.51185 .15375 .51762 .16107 .5282 .15711 .52245 .14976 Metetra
.664 .741 .908 r
.52245 .14976 .5282 .15711 .53881 .15314 .5331 .14576 Metetra
.664 .741 .908 r
.5331 .14576 .53881 .15314 .54947 .14915 .54378 .14174 Metetra
.664 .741 .908 r
.54378 .14174 .54947 .14915 .56017 .14514 .55451 .1377 Metetra
.664 .741 .908 r
.55451 .1377 .56017 .14514 .57091 .14112 .56528 .13365 Metetra
.664 .741 .908 r
.56528 .13365 .57091 .14112 .5817 .13708 .57609 .12959 Metetra
.664 .741 .908 r
.57609 .12959 .5817 .13708 .59252 .13303 .58694 .1255 Metetra
.664 .741 .908 r
.58694 .1255 .59252 .13303 .60339 .12896 .59784 .1214 Metetra
.664 .741 .908 r
.59784 .1214 .60339 .12896 .6143 .12487 .60878 .11729 Metetra
.664 .741 .908 r
.60878 .11729 .6143 .12487 .62525 .12077 .61976 .11316 Metetra
.664 .741 .908 r
.61976 .11316 .62525 .12077 .63625 .11666 .63078 .10901 Metetra
.664 .741 .908 r
.63078 .10901 .63625 .11666 .64729 .11252 .64185 .10485 Metetra
.664 .741 .908 r
.64185 .10485 .64729 .11252 .65837 .10837 .65296 .10067 Metetra
.664 .741 .908 r
.65296 .10067 .65837 .10837 .6695 .10421 .66412 .09647 Metetra
.664 .741 .908 r
.66412 .09647 .6695 .10421 .68067 .10002 .67532 .09226 Metetra
.664 .741 .908 r
.67532 .09226 .68067 .10002 .69188 .09582 .68657 .08803 Metetra
.664 .741 .908 r
.68657 .08803 .69188 .09582 .70314 .09161 .69786 .08378 Metetra
.664 .741 .908 r
.69786 .08378 .70314 .09161 .71444 .08738 .70919 .07952 Metetra
.664 .741 .908 r
.70919 .07952 .71444 .08738 .72579 .08313 .72057 .07524 Metetra
.664 .741 .908 r
.72057 .07524 .72579 .08313 .73719 .07886 .732 .07094 Metetra
.664 .741 .908 r
.08488 .30554 .09164 .31182 .10068 .30842 .09394 .30211 Metetra
.664 .741 .908 r
.09394 .30211 .10068 .30842 .10975 .30501 .10303 .29868 Metetra
.664 .741 .908 r
.10303 .29868 .10975 .30501 .11885 .30158 .11215 .29523 Metetra
.664 .741 .908 r
.11215 .29523 .11885 .30158 .12799 .29815 .12131 .29177 Metetra
.664 .741 .908 r
.12131 .29177 .12799 .29815 .13716 .2947 .1305 .2883 Metetra
.664 .741 .908 r
.1305 .2883 .13716 .2947 .14636 .29124 .13972 .28481 Metetra
.664 .741 .908 r
.13972 .28481 .14636 .29124 .1556 .28776 .14898 .28131 Metetra
.664 .741 .908 r
.14898 .28131 .1556 .28776 .16487 .28427 .15827 .2778 Metetra
.664 .741 .908 r
.15827 .2778 .16487 .28427 .17417 .28077 .16759 .27428 Metetra
.664 .741 .908 r
.16759 .27428 .17417 .28077 .18351 .27726 .17694 .27074 Metetra
.664 .741 .908 r
.17694 .27074 .18351 .27726 .19288 .27374 .18634 .2672 Metetra
.664 .741 .908 r
.18634 .2672 .19288 .27374 .20229 .2702 .19576 .26363 Metetra
.664 .741 .908 r
.19576 .26363 .20229 .2702 .21173 .26665 .20522 .26006 Metetra
.664 .741 .908 r
.20522 .26006 .21173 .26665 .2212 .26308 .21471 .25647 Metetra
.664 .741 .908 r
.21471 .25647 .2212 .26308 .23071 .25951 .22424 .25287 Metetra
.664 .741 .908 r
.22424 .25287 .23071 .25951 .24025 .25592 .23381 .24925 Metetra
.664 .741 .908 r
.23381 .24925 .24025 .25592 .24983 .25231 .24341 .24563 Metetra
.664 .741 .908 r
.24341 .24563 .24983 .25231 .25945 .2487 .25304 .24199 Metetra
.664 .741 .908 r
.25304 .24199 .25945 .2487 .2691 .24507 .26271 .23833 Metetra
.664 .741 .908 r
.26271 .23833 .2691 .24507 .27878 .24142 .27242 .23466 Metetra
.664 .741 .908 r
.27242 .23466 .27878 .24142 .2885 .23777 .28216 .23098 Metetra
.664 .741 .908 r
.28216 .23098 .2885 .23777 .29826 .2341 .29194 .22729 Metetra
.664 .741 .908 r
.29194 .22729 .29826 .2341 .30805 .23041 .30175 .22358 Metetra
.664 .741 .908 r
.30175 .22358 .30805 .23041 .31788 .22672 .31161 .21985 Metetra
.664 .741 .908 r
.31161 .21985 .31788 .22672 .32775 .223 .32149 .21612 Metetra
.664 .741 .908 r
.32149 .21612 .32775 .223 .33765 .21928 .33142 .21237 Metetra
.664 .741 .908 r
.33142 .21237 .33765 .21928 .34759 .21554 .34138 .2086 Metetra
.664 .741 .908 r
.34138 .2086 .34759 .21554 .35757 .21179 .35138 .20482 Metetra
.664 .741 .908 r
.35138 .20482 .35757 .21179 .36758 .20802 .36142 .20103 Metetra
.664 .741 .908 r
.36142 .20103 .36758 .20802 .37764 .20424 .3715 .19722 Metetra
.664 .741 .908 r
.3715 .19722 .37764 .20424 .38773 .20044 .38161 .1934 Metetra
.664 .741 .908 r
.38161 .1934 .38773 .20044 .39785 .19663 .39176 .18956 Metetra
.664 .741 .908 r
.39176 .18956 .39785 .19663 .40802 .19281 .40195 .18571 Metetra
.664 .741 .908 r
.40195 .18571 .40802 .19281 .41823 .18897 .41218 .18184 Metetra
.664 .741 .908 r
.41218 .18184 .41823 .18897 .42847 .18512 .42245 .17796 Metetra
.664 .741 .908 r
.42245 .17796 .42847 .18512 .43875 .18125 .43276 .17407 Metetra
.664 .741 .908 r
.43276 .17407 .43875 .18125 .44908 .17736 .44311 .17016 Metetra
.664 .741 .908 r
.44311 .17016 .44908 .17736 .45944 .17347 .4535 .16623 Metetra
.664 .741 .908 r
.4535 .16623 .45944 .17347 .46984 .16955 .46392 .16229 Metetra
.664 .741 .908 r
.46392 .16229 .46984 .16955 .48028 .16563 .47439 .15833 Metetra
.664 .741 .908 r
.47439 .15833 .48028 .16563 .49076 .16168 .4849 .15436 Metetra
.664 .741 .908 r
.4849 .15436 .49076 .16168 .50129 .15772 .49545 .15038 Metetra
.664 .741 .908 r
.49545 .15038 .50129 .15772 .51185 .15375 .50603 .14638 Metetra
.664 .741 .908 r
.50603 .14638 .51185 .15375 .52245 .14976 .51666 .14236 Metetra
.664 .741 .908 r
.51666 .14236 .52245 .14976 .5331 .14576 .52734 .13833 Metetra
.664 .741 .908 r
.52734 .13833 .5331 .14576 .54378 .14174 .53805 .13428 Metetra
.664 .741 .908 r
.53805 .13428 .54378 .14174 .55451 .1377 .5488 .13021 Metetra
.664 .741 .908 r
.5488 .13021 .55451 .1377 .56528 .13365 .5596 .12613 Metetra
.664 .741 .908 r
.5596 .12613 .56528 .13365 .57609 .12959 .57044 .12204 Metetra
.664 .741 .908 r
.57044 .12204 .57609 .12959 .58694 .1255 .58132 .11792 Metetra
.664 .741 .908 r
.58132 .11792 .58694 .1255 .59784 .1214 .59225 .1138 Metetra
.664 .741 .908 r
.59225 .1138 .59784 .1214 .60878 .11729 .60321 .10965 Metetra
.664 .741 .908 r
.60321 .10965 .60878 .11729 .61976 .11316 .61422 .10549 Metetra
.664 .741 .908 r
.61422 .10549 .61976 .11316 .63078 .10901 .62528 .10131 Metetra
.664 .741 .908 r
.62528 .10131 .63078 .10901 .64185 .10485 .63638 .09712 Metetra
.664 .741 .908 r
.63638 .09712 .64185 .10485 .65296 .10067 .64752 .09291 Metetra
.664 .741 .908 r
.64752 .09291 .65296 .10067 .66412 .09647 .6587 .08868 Metetra
.664 .741 .908 r
.6587 .08868 .66412 .09647 .67532 .09226 .66994 .08444 Metetra
.664 .741 .908 r
.66994 .08444 .67532 .09226 .68657 .08803 .68121 .08017 Metetra
.664 .741 .908 r
.68121 .08017 .68657 .08803 .69786 .08378 .69253 .0759 Metetra
.664 .741 .908 r
.69253 .0759 .69786 .08378 .70919 .07952 .7039 .0716 Metetra
.664 .741 .908 r
.7039 .0716 .70919 .07952 .72057 .07524 .71531 .06729 Metetra
.664 .741 .908 r
.71531 .06729 .72057 .07524 .732 .07094 .72677 .06296 Metetra
.664 .741 .908 r
.07809 .29921 .08488 .30554 .09394 .30211 .08716 .29576 Metetra
.664 .741 .908 r
.08716 .29576 .09394 .30211 .10303 .29868 .09627 .2923 Metetra
.664 .741 .908 r
.09627 .2923 .10303 .29868 .11215 .29523 .10541 .28883 Metetra
.664 .741 .908 r
.10541 .28883 .11215 .29523 .12131 .29177 .11458 .28535 Metetra
.664 .741 .908 r
.11458 .28535 .12131 .29177 .1305 .2883 .12379 .28185 Metetra
.664 .741 .908 r
.12379 .28185 .1305 .2883 .13972 .28481 .13303 .27834 Metetra
.664 .741 .908 r
.13303 .27834 .13972 .28481 .14898 .28131 .14231 .27482 Metetra
.664 .741 .908 r
.14231 .27482 .14898 .28131 .15827 .2778 .15162 .27129 Metetra
.664 .741 .908 r
.15162 .27129 .15827 .2778 .16759 .27428 .16096 .26774 Metetra
.664 .741 .908 r
.16096 .26774 .16759 .27428 .17694 .27074 .17033 .26418 Metetra
.664 .741 .908 r
.17033 .26418 .17694 .27074 .18634 .2672 .17974 .26061 Metetra
.664 .741 .908 r
.17974 .26061 .18634 .2672 .19576 .26363 .18919 .25702 Metetra
.664 .741 .908 r
.18919 .25702 .19576 .26363 .20522 .26006 .19867 .25342 Metetra
.664 .741 .908 r
.19867 .25342 .20522 .26006 .21471 .25647 .20818 .24981 Metetra
.664 .741 .908 r
.20818 .24981 .21471 .25647 .22424 .25287 .21773 .24619 Metetra
.664 .741 .908 r
.21773 .24619 .22424 .25287 .23381 .24925 .22732 .24255 Metetra
.664 .741 .908 r
.22732 .24255 .23381 .24925 .24341 .24563 .23694 .23889 Metetra
.664 .741 .908 r
.23694 .23889 .24341 .24563 .25304 .24199 .24659 .23523 Metetra
.664 .741 .908 r
.24659 .23523 .25304 .24199 .26271 .23833 .25628 .23155 Metetra
.664 .741 .908 r
.25628 .23155 .26271 .23833 .27242 .23466 .26601 .22786 Metetra
.664 .741 .908 r
.26601 .22786 .27242 .23466 .28216 .23098 .27578 .22415 Metetra
.664 .741 .908 r
.27578 .22415 .28216 .23098 .29194 .22729 .28558 .22043 Metetra
.664 .741 .908 r
.28558 .22043 .29194 .22729 .30175 .22358 .29541 .21669 Metetra
.664 .741 .908 r
.29541 .21669 .30175 .22358 .31161 .21985 .30529 .21294 Metetra
.664 .741 .908 r
.30529 .21294 .31161 .21985 .32149 .21612 .3152 .20918 Metetra
.664 .741 .908 r
.3152 .20918 .32149 .21612 .33142 .21237 .32515 .2054 Metetra
.664 .741 .908 r
.32515 .2054 .33142 .21237 .34138 .2086 .33513 .20161 Metetra
.664 .741 .908 r
.33513 .20161 .34138 .2086 .35138 .20482 .34516 .19781 Metetra
.664 .741 .908 r
.34516 .19781 .35138 .20482 .36142 .20103 .35522 .19399 Metetra
.664 .741 .908 r
.35522 .19399 .36142 .20103 .3715 .19722 .36532 .19015 Metetra
.664 .741 .908 r
.36532 .19015 .3715 .19722 .38161 .1934 .37545 .1863 Metetra
.664 .741 .908 r
.37545 .1863 .38161 .1934 .39176 .18956 .38563 .18244 Metetra
.664 .741 .908 r
.38563 .18244 .39176 .18956 .40195 .18571 .39585 .17856 Metetra
.664 .741 .908 r
.39585 .17856 .40195 .18571 .41218 .18184 .4061 .17467 Metetra
.664 .741 .908 r
.4061 .17467 .41218 .18184 .42245 .17796 .41639 .17076 Metetra
.664 .741 .908 r
.41639 .17076 .42245 .17796 .43276 .17407 .42673 .16684 Metetra
.664 .741 .908 r
.42673 .16684 .43276 .17407 .44311 .17016 .4371 .1629 Metetra
.664 .741 .908 r
.4371 .1629 .44311 .17016 .4535 .16623 .44751 .15894 Metetra
.664 .741 .908 r
.44751 .15894 .4535 .16623 .46392 .16229 .45796 .15498 Metetra
.664 .741 .908 r
.45796 .15498 .46392 .16229 .47439 .15833 .46846 .15099 Metetra
.664 .741 .908 r
.46846 .15099 .47439 .15833 .4849 .15436 .47899 .14699 Metetra
.664 .741 .908 r
.47899 .14699 .4849 .15436 .49545 .15038 .48956 .14298 Metetra
.664 .741 .908 r
.48956 .14298 .49545 .15038 .50603 .14638 .50018 .13895 Metetra
.664 .741 .908 r
.50018 .13895 .50603 .14638 .51666 .14236 .51084 .1349 Metetra
.664 .741 .908 r
.51084 .1349 .51666 .14236 .52734 .13833 .52154 .13084 Metetra
.664 .741 .908 r
.52154 .13084 .52734 .13833 .53805 .13428 .53228 .12676 Metetra
.664 .741 .908 r
.53228 .12676 .53805 .13428 .5488 .13021 .54306 .12267 Metetra
.664 .741 .908 r
.54306 .12267 .5488 .13021 .5596 .12613 .55388 .11856 Metetra
.664 .741 .908 r
.55388 .11856 .5596 .12613 .57044 .12204 .56475 .11443 Metetra
.664 .741 .908 r
.56475 .11443 .57044 .12204 .58132 .11792 .57566 .11029 Metetra
.664 .741 .908 r
.57566 .11029 .58132 .11792 .59225 .1138 .58661 .10613 Metetra
.664 .741 .908 r
.58661 .10613 .59225 .1138 .60321 .10965 .59761 .10196 Metetra
.664 .741 .908 r
.59761 .10196 .60321 .10965 .61422 .10549 .60865 .09776 Metetra
.664 .741 .908 r
.60865 .09776 .61422 .10549 .62528 .10131 .61973 .09356 Metetra
.664 .741 .908 r
.61973 .09356 .62528 .10131 .63638 .09712 .63086 .08933 Metetra
.664 .741 .908 r
.63086 .08933 .63638 .09712 .64752 .09291 .64203 .08509 Metetra
.664 .741 .908 r
.64203 .08509 .64752 .09291 .6587 .08868 .65325 .08083 Metetra
.664 .741 .908 r
.65325 .08083 .6587 .08868 .66994 .08444 .66451 .07655 Metetra
.664 .741 .908 r
.66451 .07655 .66994 .08444 .68121 .08017 .67582 .07226 Metetra
.664 .741 .908 r
.67582 .07226 .68121 .08017 .69253 .0759 .68717 .06795 Metetra
.664 .741 .908 r
.68717 .06795 .69253 .0759 .7039 .0716 .69857 .06362 Metetra
.664 .741 .908 r
.69857 .06362 .7039 .0716 .71531 .06729 .71001 .05928 Metetra
.664 .741 .908 r
.71001 .05928 .71531 .06729 .72677 .06296 .7215 .05492 Metetra
.664 .741 .908 r
.07124 .29284 .07809 .29921 .08716 .29576 .08034 .28937 Metetra
.664 .741 .908 r
.08034 .28937 .08716 .29576 .09627 .2923 .08946 .28589 Metetra
.664 .741 .908 r
.08946 .28589 .09627 .2923 .10541 .28883 .09862 .28239 Metetra
.664 .741 .908 r
.09862 .28239 .10541 .28883 .11458 .28535 .10781 .27888 Metetra
.664 .741 .908 r
.10781 .27888 .11458 .28535 .12379 .28185 .11704 .27537 Metetra
.664 .741 .908 r
.11704 .27537 .12379 .28185 .13303 .27834 .1263 .27183 Metetra
.664 .741 .908 r
.1263 .27183 .13303 .27834 .14231 .27482 .13559 .26829 Metetra
.664 .741 .908 r
.13559 .26829 .14231 .27482 .15162 .27129 .14492 .26473 Metetra
.664 .741 .908 r
.14492 .26473 .15162 .27129 .16096 .26774 .15428 .26116 Metetra
.664 .741 .908 r
.15428 .26116 .16096 .26774 .17033 .26418 .16368 .25758 Metetra
.664 .741 .908 r
.16368 .25758 .17033 .26418 .17974 .26061 .17311 .25398 Metetra
.664 .741 .908 r
.17311 .25398 .17974 .26061 .18919 .25702 .18257 .25037 Metetra
.664 .741 .908 r
.18257 .25037 .18919 .25702 .19867 .25342 .19207 .24674 Metetra
.664 .741 .908 r
.19207 .24674 .19867 .25342 .20818 .24981 .20161 .24311 Metetra
.664 .741 .908 r
.20161 .24311 .20818 .24981 .21773 .24619 .21118 .23946 Metetra
.664 .741 .908 r
.21118 .23946 .21773 .24619 .22732 .24255 .22078 .23579 Metetra
.664 .741 .908 r
.22078 .23579 .22732 .24255 .23694 .23889 .23042 .23212 Metetra
.664 .741 .908 r
.23042 .23212 .23694 .23889 .24659 .23523 .2401 .22842 Metetra
.664 .741 .908 r
.2401 .22842 .24659 .23523 .25628 .23155 .24981 .22472 Metetra
.664 .741 .908 r
.24981 .22472 .25628 .23155 .26601 .22786 .25956 .221 Metetra
.664 .741 .908 r
.25956 .221 .26601 .22786 .27578 .22415 .26935 .21727 Metetra
.664 .741 .908 r
.26935 .21727 .27578 .22415 .28558 .22043 .27917 .21352 Metetra
.664 .741 .908 r
.27917 .21352 .28558 .22043 .29541 .21669 .28903 .20976 Metetra
.664 .741 .908 r
.28903 .20976 .29541 .21669 .30529 .21294 .29892 .20599 Metetra
.664 .741 .908 r
.29892 .20599 .30529 .21294 .3152 .20918 .30886 .2022 Metetra
.664 .741 .908 r
.30886 .2022 .3152 .20918 .32515 .2054 .31883 .19839 Metetra
.664 .741 .908 r
.31883 .19839 .32515 .2054 .33513 .20161 .32884 .19457 Metetra
.664 .741 .908 r
.32884 .19457 .33513 .20161 .34516 .19781 .33888 .19074 Metetra
.664 .741 .908 r
.33888 .19074 .34516 .19781 .35522 .19399 .34897 .1869 Metetra
.664 .741 .908 r
.34897 .1869 .35522 .19399 .36532 .19015 .35909 .18303 Metetra
.664 .741 .908 r
.35909 .18303 .36532 .19015 .37545 .1863 .36925 .17916 Metetra
.664 .741 .908 r
.36925 .17916 .37545 .1863 .38563 .18244 .37945 .17527 Metetra
.664 .741 .908 r
.37945 .17527 .38563 .18244 .39585 .17856 .38969 .17136 Metetra
.664 .741 .908 r
.38969 .17136 .39585 .17856 .4061 .17467 .39997 .16744 Metetra
.664 .741 .908 r
.39997 .16744 .4061 .17467 .41639 .17076 .41029 .1635 Metetra
.664 .741 .908 r
.41029 .1635 .41639 .17076 .42673 .16684 .42065 .15955 Metetra
.664 .741 .908 r
.42065 .15955 .42673 .16684 .4371 .1629 .43105 .15559 Metetra
.664 .741 .908 r
.43105 .15559 .4371 .1629 .44751 .15894 .44148 .15161 Metetra
.664 .741 .908 r
.44148 .15161 .44751 .15894 .45796 .15498 .45196 .14761 Metetra
.664 .741 .908 r
.45196 .14761 .45796 .15498 .46846 .15099 .46248 .1436 Metetra
.664 .741 .908 r
.46248 .1436 .46846 .15099 .47899 .14699 .47304 .13957 Metetra
.664 .741 .908 r
.47304 .13957 .47899 .14699 .48956 .14298 .48364 .13552 Metetra
.664 .741 .908 r
.48364 .13552 .48956 .14298 .50018 .13895 .49428 .13146 Metetra
.664 .741 .908 r
.49428 .13146 .50018 .13895 .51084 .1349 .50497 .12739 Metetra
.664 .741 .908 r
.50497 .12739 .51084 .1349 .52154 .13084 .51569 .1233 Metetra
.664 .741 .908 r
.51569 .1233 .52154 .13084 .53228 .12676 .52646 .11919 Metetra
.664 .741 .908 r
.52646 .11919 .53228 .12676 .54306 .12267 .53727 .11507 Metetra
.664 .741 .908 r
.53727 .11507 .54306 .12267 .55388 .11856 .54812 .11093 Metetra
.664 .741 .908 r
.54812 .11093 .55388 .11856 .56475 .11443 .55902 .10677 Metetra
.664 .741 .908 r
.55902 .10677 .56475 .11443 .57566 .11029 .56996 .1026 Metetra
.664 .741 .908 r
.56996 .1026 .57566 .11029 .58661 .10613 .58094 .09841 Metetra
.664 .741 .908 r
.58094 .09841 .58661 .10613 .59761 .10196 .59196 .0942 Metetra
.664 .741 .908 r
.59196 .0942 .59761 .10196 .60865 .09776 .60303 .08998 Metetra
.664 .741 .908 r
.60303 .08998 .60865 .09776 .61973 .09356 .61415 .08574 Metetra
.664 .741 .908 r
.61415 .08574 .61973 .09356 .63086 .08933 .6253 .08149 Metetra
.664 .741 .908 r
.6253 .08149 .63086 .08933 .64203 .08509 .63651 .07721 Metetra
.664 .741 .908 r
.63651 .07721 .64203 .08509 .65325 .08083 .64775 .07292 Metetra
.664 .741 .908 r
.64775 .07292 .65325 .08083 .66451 .07655 .65904 .06862 Metetra
.664 .741 .908 r
.65904 .06862 .66451 .07655 .67582 .07226 .67038 .06429 Metetra
.664 .741 .908 r
.67038 .06429 .67582 .07226 .68717 .06795 .68177 .05995 Metetra
.664 .741 .908 r
.68177 .05995 .68717 .06795 .69857 .06362 .6932 .05559 Metetra
.664 .741 .908 r
.6932 .05559 .69857 .06362 .71001 .05928 .70467 .05121 Metetra
.664 .741 .908 r
.70467 .05121 .71001 .05928 .7215 .05492 .71619 .04682 Metetra
.664 .741 .908 r
.06435 .28642 .07124 .29284 .08034 .28937 .07347 .28293 Metetra
.664 .741 .908 r
.07347 .28293 .08034 .28937 .08946 .28589 .08261 .27942 Metetra
.664 .741 .908 r
.08261 .27942 .08946 .28589 .09862 .28239 .09179 .27591 Metetra
.664 .741 .908 r
.09179 .27591 .09862 .28239 .10781 .27888 .101 .27238 Metetra
.664 .741 .908 r
.101 .27238 .10781 .27888 .11704 .27537 .11024 .26883 Metetra
.664 .741 .908 r
.11024 .26883 .11704 .27537 .1263 .27183 .11952 .26528 Metetra
.664 .741 .908 r
.11952 .26528 .1263 .27183 .13559 .26829 .12883 .26171 Metetra
.664 .741 .908 r
.12883 .26171 .13559 .26829 .14492 .26473 .13818 .25813 Metetra
.664 .741 .908 r
.13818 .25813 .14492 .26473 .15428 .26116 .14756 .25453 Metetra
.664 .741 .908 r
.14756 .25453 .15428 .26116 .16368 .25758 .15698 .25092 Metetra
.664 .741 .908 r
.15698 .25092 .16368 .25758 .17311 .25398 .16643 .2473 Metetra
.664 .741 .908 r
.16643 .2473 .17311 .25398 .18257 .25037 .17591 .24367 Metetra
.664 .741 .908 r
.17591 .24367 .18257 .25037 .19207 .24674 .18543 .24002 Metetra
.664 .741 .908 r
.18543 .24002 .19207 .24674 .20161 .24311 .19499 .23636 Metetra
.664 .741 .908 r
.19499 .23636 .20161 .24311 .21118 .23946 .20458 .23268 Metetra
.664 .741 .908 r
.20458 .23268 .21118 .23946 .22078 .23579 .2142 .22899 Metetra
.664 .741 .908 r
.2142 .22899 .22078 .23579 .23042 .23212 .22386 .22529 Metetra
.664 .741 .908 r
.22386 .22529 .23042 .23212 .2401 .22842 .23356 .22157 Metetra
.664 .741 .908 r
.23356 .22157 .2401 .22842 .24981 .22472 .2433 .21784 Metetra
.664 .741 .908 r
.2433 .21784 .24981 .22472 .25956 .221 .25307 .2141 Metetra
.664 .741 .908 r
.25307 .2141 .25956 .221 .26935 .21727 .26287 .21034 Metetra
.664 .741 .908 r
.26287 .21034 .26935 .21727 .27917 .21352 .27272 .20657 Metetra
.664 .741 .908 r
.27272 .20657 .27917 .21352 .28903 .20976 .2826 .20278 Metetra
.664 .741 .908 r
.2826 .20278 .28903 .20976 .29892 .20599 .29252 .19898 Metetra
.664 .741 .908 r
.29252 .19898 .29892 .20599 .30886 .2022 .30247 .19516 Metetra
.664 .741 .908 r
.30247 .19516 .30886 .2022 .31883 .19839 .31247 .19133 Metetra
.664 .741 .908 r
.31247 .19133 .31883 .19839 .32884 .19457 .3225 .18749 Metetra
.664 .741 .908 r
.3225 .18749 .32884 .19457 .33888 .19074 .33257 .18363 Metetra
.664 .741 .908 r
.33257 .18363 .33888 .19074 .34897 .1869 .34268 .17976 Metetra
.664 .741 .908 r
.34268 .17976 .34897 .1869 .35909 .18303 .35282 .17587 Metetra
.664 .741 .908 r
.35282 .17587 .35909 .18303 .36925 .17916 .36301 .17196 Metetra
.664 .741 .908 r
.36301 .17196 .36925 .17916 .37945 .17527 .37323 .16804 Metetra
.664 .741 .908 r
.37323 .16804 .37945 .17527 .38969 .17136 .3835 .16411 Metetra
.664 .741 .908 r
.3835 .16411 .38969 .17136 .39997 .16744 .3938 .16016 Metetra
.664 .741 .908 r
.3938 .16016 .39997 .16744 .41029 .1635 .40414 .1562 Metetra
.664 .741 .908 r
.40414 .1562 .41029 .1635 .42065 .15955 .41453 .15222 Metetra
.664 .741 .908 r
.41453 .15222 .42065 .15955 .43105 .15559 .42495 .14822 Metetra
.664 .741 .908 r
.42495 .14822 .43105 .15559 .44148 .15161 .43541 .14421 Metetra
.664 .741 .908 r
.43541 .14421 .44148 .15161 .45196 .14761 .44592 .14019 Metetra
.664 .741 .908 r
.44592 .14019 .45196 .14761 .46248 .1436 .45646 .13615 Metetra
.664 .741 .908 r
.45646 .13615 .46248 .1436 .47304 .13957 .46705 .13209 Metetra
.664 .741 .908 r
.46705 .13209 .47304 .13957 .48364 .13552 .47767 .12802 Metetra
.664 .741 .908 r
.47767 .12802 .48364 .13552 .49428 .13146 .48834 .12393 Metetra
.664 .741 .908 r
.48834 .12393 .49428 .13146 .50497 .12739 .49905 .11982 Metetra
.664 .741 .908 r
.49905 .11982 .50497 .12739 .51569 .1233 .50981 .1157 Metetra
.664 .741 .908 r
.50981 .1157 .51569 .1233 .52646 .11919 .5206 .11157 Metetra
.664 .741 .908 r
.5206 .11157 .52646 .11919 .53727 .11507 .53144 .10741 Metetra
.664 .741 .908 r
.53144 .10741 .53727 .11507 .54812 .11093 .54232 .10324 Metetra
.664 .741 .908 r
.54232 .10324 .54812 .11093 .55902 .10677 .55324 .09906 Metetra
.664 .741 .908 r
.55324 .09906 .55902 .10677 .56996 .1026 .56421 .09485 Metetra
.664 .741 .908 r
.56421 .09485 .56996 .1026 .58094 .09841 .57522 .09063 Metetra
.664 .741 .908 r
.57522 .09063 .58094 .09841 .59196 .0942 .58628 .0864 Metetra
.664 .741 .908 r
.58628 .0864 .59196 .0942 .60303 .08998 .59737 .08214 Metetra
.664 .741 .908 r
.59737 .08214 .60303 .08998 .61415 .08574 .60852 .07787 Metetra
.664 .741 .908 r
.60852 .07787 .61415 .08574 .6253 .08149 .61971 .07358 Metetra
.664 .741 .908 r
.61971 .07358 .6253 .08149 .63651 .07721 .63094 .06928 Metetra
.664 .741 .908 r
.63094 .06928 .63651 .07721 .64775 .07292 .64222 .06496 Metetra
.664 .741 .908 r
.64222 .06496 .64775 .07292 .65904 .06862 .65354 .06062 Metetra
.664 .741 .908 r
.65354 .06062 .65904 .06862 .67038 .06429 .66491 .05626 Metetra
.664 .741 .908 r
.66491 .05626 .67038 .06429 .68177 .05995 .67632 .05189 Metetra
.664 .741 .908 r
.67632 .05189 .68177 .05995 .6932 .05559 .68778 .04749 Metetra
.664 .741 .908 r
.68778 .04749 .6932 .05559 .70467 .05121 .69929 .04308 Metetra
.664 .741 .908 r
.69929 .04308 .70467 .05121 .71619 .04682 .71085 .03865 Metetra
.664 .741 .908 r
.05742 .27996 .06435 .28642 .07347 .28293 .06655 .27645 Metetra
.664 .741 .908 r
.06655 .27645 .07347 .28293 .08261 .27942 .07571 .27292 Metetra
.664 .741 .908 r
.07571 .27292 .08261 .27942 .09179 .27591 .08491 .26938 Metetra
.664 .741 .908 r
.08491 .26938 .09179 .27591 .101 .27238 .09414 .26583 Metetra
.664 .741 .908 r
.09414 .26583 .101 .27238 .11024 .26883 .1034 .26226 Metetra
.664 .741 .908 r
.1034 .26226 .11024 .26883 .11952 .26528 .1127 .25868 Metetra
.664 .741 .908 r
.1127 .25868 .11952 .26528 .12883 .26171 .12203 .25509 Metetra
.664 .741 .908 r
.12203 .25509 .12883 .26171 .13818 .25813 .13139 .25148 Metetra
.664 .741 .908 r
.13139 .25148 .13818 .25813 .14756 .25453 .14079 .24786 Metetra
.664 .741 .908 r
.14079 .24786 .14756 .25453 .15698 .25092 .15023 .24423 Metetra
.664 .741 .908 r
.15023 .24423 .15698 .25092 .16643 .2473 .1597 .24058 Metetra
.664 .741 .908 r
.1597 .24058 .16643 .2473 .17591 .24367 .1692 .23692 Metetra
.664 .741 .908 r
.1692 .23692 .17591 .24367 .18543 .24002 .17874 .23325 Metetra
.664 .741 .908 r
.17874 .23325 .18543 .24002 .19499 .23636 .18832 .22956 Metetra
.664 .741 .908 r
.18832 .22956 .19499 .23636 .20458 .23268 .19793 .22586 Metetra
.664 .741 .908 r
.19793 .22586 .20458 .23268 .2142 .22899 .20758 .22215 Metetra
.664 .741 .908 r
.20758 .22215 .2142 .22899 .22386 .22529 .21726 .21842 Metetra
.664 .741 .908 r
.21726 .21842 .22386 .22529 .23356 .22157 .22698 .21468 Metetra
.664 .741 .908 r
.22698 .21468 .23356 .22157 .2433 .21784 .23673 .21092 Metetra
.664 .741 .908 r
.23673 .21092 .2433 .21784 .25307 .2141 .24653 .20715 Metetra
.664 .741 .908 r
.24653 .20715 .25307 .2141 .26287 .21034 .25635 .20336 Metetra
.664 .741 .908 r
.25635 .20336 .26287 .21034 .27272 .20657 .26622 .19956 Metetra
.664 .741 .908 r
.26622 .19956 .27272 .20657 .2826 .20278 .27612 .19575 Metetra
.664 .741 .908 r
.27612 .19575 .2826 .20278 .29252 .19898 .28607 .19192 Metetra
.664 .741 .908 r
.28607 .19192 .29252 .19898 .30247 .19516 .29604 .18808 Metetra
.664 .741 .908 r
.29604 .18808 .30247 .19516 .31247 .19133 .30606 .18422 Metetra
.664 .741 .908 r
.30606 .18422 .31247 .19133 .3225 .18749 .31612 .18035 Metetra
.664 .741 .908 r
.31612 .18035 .3225 .18749 .33257 .18363 .32621 .17647 Metetra
.664 .741 .908 r
.32621 .17647 .33257 .18363 .34268 .17976 .33634 .17256 Metetra
.664 .741 .908 r
.33634 .17256 .34268 .17976 .35282 .17587 .34651 .16865 Metetra
.664 .741 .908 r
.34651 .16865 .35282 .17587 .36301 .17196 .35672 .16472 Metetra
.664 .741 .908 r
.35672 .16472 .36301 .17196 .37323 .16804 .36697 .16077 Metetra
.664 .741 .908 r
.36697 .16077 .37323 .16804 .3835 .16411 .37726 .15681 Metetra
.664 .741 .908 r
.37726 .15681 .3835 .16411 .3938 .16016 .38758 .15283 Metetra
.664 .741 .908 r
.38758 .15283 .3938 .16016 .40414 .1562 .39795 .14884 Metetra
.664 .741 .908 r
.39795 .14884 .40414 .1562 .41453 .15222 .40836 .14483 Metetra
.664 .741 .908 r
.40836 .14483 .41453 .15222 .42495 .14822 .41881 .14081 Metetra
.664 .741 .908 r
.41881 .14081 .42495 .14822 .43541 .14421 .4293 .13677 Metetra
.664 .741 .908 r
.4293 .13677 .43541 .14421 .44592 .14019 .43983 .13272 Metetra
.664 .741 .908 r
.43983 .13272 .44592 .14019 .45646 .13615 .4504 .12865 Metetra
.664 .741 .908 r
.4504 .12865 .45646 .13615 .46705 .13209 .46101 .12456 Metetra
.664 .741 .908 r
.46101 .12456 .46705 .13209 .47767 .12802 .47166 .12046 Metetra
.664 .741 .908 r
.47166 .12046 .47767 .12802 .48834 .12393 .48236 .11634 Metetra
.664 .741 .908 r
.48236 .11634 .48834 .12393 .49905 .11982 .4931 .1122 Metetra
.664 .741 .908 r
.4931 .1122 .49905 .11982 .50981 .1157 .50388 .10805 Metetra
.664 .741 .908 r
.50388 .10805 .50981 .1157 .5206 .11157 .5147 .10388 Metetra
.664 .741 .908 r
.5147 .10388 .5206 .11157 .53144 .10741 .52557 .0997 Metetra
.664 .741 .908 r
.52557 .0997 .53144 .10741 .54232 .10324 .53648 .0955 Metetra
.664 .741 .908 r
.53648 .0955 .54232 .10324 .55324 .09906 .54743 .09128 Metetra
.664 .741 .908 r
.54743 .09128 .55324 .09906 .56421 .09485 .55842 .08705 Metetra
.664 .741 .908 r
.55842 .08705 .56421 .09485 .57522 .09063 .56946 .0828 Metetra
.664 .741 .908 r
.56946 .0828 .57522 .09063 .58628 .0864 .58055 .07853 Metetra
.664 .741 .908 r
.58055 .07853 .58628 .0864 .59737 .08214 .59168 .07425 Metetra
.664 .741 .908 r
.59168 .07425 .59737 .08214 .60852 .07787 .60285 .06994 Metetra
.664 .741 .908 r
.60285 .06994 .60852 .07787 .61971 .07358 .61407 .06562 Metetra
.664 .741 .908 r
.61407 .06562 .61971 .07358 .63094 .06928 .62533 .06129 Metetra
.664 .741 .908 r
.62533 .06129 .63094 .06928 .64222 .06496 .63664 .05693 Metetra
.664 .741 .908 r
.63664 .05693 .64222 .06496 .65354 .06062 .64799 .05256 Metetra
.664 .741 .908 r
.64799 .05256 .65354 .06062 .66491 .05626 .65939 .04817 Metetra
.664 .741 .908 r
.65939 .04817 .66491 .05626 .67632 .05189 .67084 .04376 Metetra
.664 .741 .908 r
.67084 .04376 .67632 .05189 .68778 .04749 .68233 .03934 Metetra
.664 .741 .908 r
.68233 .03934 .68778 .04749 .69929 .04308 .69387 .03489 Metetra
.664 .741 .908 r
.69387 .03489 .69929 .04308 .71085 .03865 .70546 .03043 Metetra
.664 .741 .908 r
.05044 .27347 .05742 .27996 .06655 .27645 .05959 .26993 Metetra
.664 .741 .908 r
.05959 .26993 .06655 .27645 .07571 .27292 .06877 .26637 Metetra
.664 .741 .908 r
.06877 .26637 .07571 .27292 .08491 .26938 .07798 .26281 Metetra
.664 .741 .908 r
.07798 .26281 .08491 .26938 .09414 .26583 .08723 .25923 Metetra
.664 .741 .908 r
.08723 .25923 .09414 .26583 .1034 .26226 .09651 .25564 Metetra
.664 .741 .908 r
.09651 .25564 .1034 .26226 .1127 .25868 .10583 .25204 Metetra
.664 .741 .908 r
.10583 .25204 .1127 .25868 .12203 .25509 .11518 .24842 Metetra
.664 .741 .908 r
.11518 .24842 .12203 .25509 .13139 .25148 .12456 .24479 Metetra
.664 .741 .908 r
.12456 .24479 .13139 .25148 .14079 .24786 .13398 .24114 Metetra
.664 .741 .908 r
.13398 .24114 .14079 .24786 .15023 .24423 .14344 .23749 Metetra
.664 .741 .908 r
.14344 .23749 .15023 .24423 .1597 .24058 .15293 .23381 Metetra
.664 .741 .908 r
.15293 .23381 .1597 .24058 .1692 .23692 .16245 .23013 Metetra
.664 .741 .908 r
.16245 .23013 .1692 .23692 .17874 .23325 .17201 .22643 Metetra
.664 .741 .908 r
.17201 .22643 .17874 .23325 .18832 .22956 .18161 .22272 Metetra
.664 .741 .908 r
.18161 .22272 .18832 .22956 .19793 .22586 .19124 .21899 Metetra
.664 .741 .908 r
.19124 .21899 .19793 .22586 .20758 .22215 .20091 .21525 Metetra
.664 .741 .908 r
.20091 .21525 .20758 .22215 .21726 .21842 .21061 .2115 Metetra
.664 .741 .908 r
.21061 .2115 .21726 .21842 .22698 .21468 .22035 .20773 Metetra
.664 .741 .908 r
.22035 .20773 .22698 .21468 .23673 .21092 .23013 .20395 Metetra
.664 .741 .908 r
.23013 .20395 .23673 .21092 .24653 .20715 .23994 .20015 Metetra
.664 .741 .908 r
.23994 .20015 .24653 .20715 .25635 .20336 .24979 .19634 Metetra
.664 .741 .908 r
.24979 .19634 .25635 .20336 .26622 .19956 .25968 .19251 Metetra
.664 .741 .908 r
.25968 .19251 .26622 .19956 .27612 .19575 .2696 .18867 Metetra
.664 .741 .908 r
.2696 .18867 .27612 .19575 .28607 .19192 .27957 .18482 Metetra
.664 .741 .908 r
.27957 .18482 .28607 .19192 .29604 .18808 .28957 .18095 Metetra
.664 .741 .908 r
.28957 .18095 .29604 .18808 .30606 .18422 .29961 .17706 Metetra
.664 .741 .908 r
.29961 .17706 .30606 .18422 .31612 .18035 .30969 .17317 Metetra
.664 .741 .908 r
.30969 .17317 .31612 .18035 .32621 .17647 .3198 .16925 Metetra
.664 .741 .908 r
.3198 .16925 .32621 .17647 .33634 .17256 .32996 .16532 Metetra
.664 .741 .908 r
.32996 .16532 .33634 .17256 .34651 .16865 .34015 .16138 Metetra
.664 .741 .908 r
.34015 .16138 .34651 .16865 .35672 .16472 .35039 .15742 Metetra
.664 .741 .908 r
.35039 .15742 .35672 .16472 .36697 .16077 .36066 .15345 Metetra
.664 .741 .908 r
.36066 .15345 .36697 .16077 .37726 .15681 .37097 .14946 Metetra
.664 .741 .908 r
.37097 .14946 .37726 .15681 .38758 .15283 .38132 .14545 Metetra
.664 .741 .908 r
.38132 .14545 .38758 .15283 .39795 .14884 .39172 .14143 Metetra
.664 .741 .908 r
.39172 .14143 .39795 .14884 .40836 .14483 .40215 .13739 Metetra
.664 .741 .908 r
.40215 .13739 .40836 .14483 .41881 .14081 .41262 .13334 Metetra
.664 .741 .908 r
.41262 .13334 .41881 .14081 .4293 .13677 .42314 .12927 Metetra
.664 .741 .908 r
.42314 .12927 .4293 .13677 .43983 .13272 .43369 .12519 Metetra
.664 .741 .908 r
.43369 .12519 .43983 .13272 .4504 .12865 .44429 .12109 Metetra
.664 .741 .908 r
.44429 .12109 .4504 .12865 .46101 .12456 .45493 .11697 Metetra
.664 .741 .908 r
.45493 .11697 .46101 .12456 .47166 .12046 .46561 .11284 Metetra
.664 .741 .908 r
.46561 .11284 .47166 .12046 .48236 .11634 .47633 .10869 Metetra
.664 .741 .908 r
.47633 .10869 .48236 .11634 .4931 .1122 .4871 .10453 Metetra
.664 .741 .908 r
.4871 .10453 .4931 .1122 .50388 .10805 .49791 .10035 Metetra
.664 .741 .908 r
.49791 .10035 .50388 .10805 .5147 .10388 .50876 .09615 Metetra
.664 .741 .908 r
.50876 .09615 .5147 .10388 .52557 .0997 .51965 .09193 Metetra
.664 .741 .908 r
.51965 .09193 .52557 .0997 .53648 .0955 .53059 .0877 Metetra
.664 .741 .908 r
.53059 .0877 .53648 .0955 .54743 .09128 .54157 .08345 Metetra
.664 .741 .908 r
.54157 .08345 .54743 .09128 .55842 .08705 .55259 .07919 Metetra
.664 .741 .908 r
.55259 .07919 .55842 .08705 .56946 .0828 .56366 .07491 Metetra
.664 .741 .908 r
.56366 .07491 .56946 .0828 .58055 .07853 .57478 .07061 Metetra
.664 .741 .908 r
.57478 .07061 .58055 .07853 .59168 .07425 .58593 .06629 Metetra
.664 .741 .908 r
.58593 .06629 .59168 .07425 .60285 .06994 .59714 .06196 Metetra
.664 .741 .908 r
.59714 .06196 .60285 .06994 .61407 .06562 .60838 .0576 Metetra
.664 .741 .908 r
.60838 .0576 .61407 .06562 .62533 .06129 .61968 .05323 Metetra
.664 .741 .908 r
.61968 .05323 .62533 .06129 .63664 .05693 .63102 .04885 Metetra
.664 .741 .908 r
.63102 .04885 .63664 .05693 .64799 .05256 .6424 .04444 Metetra
.664 .741 .908 r
.6424 .04444 .64799 .05256 .65939 .04817 .65383 .04002 Metetra
.664 .741 .908 r
.65383 .04002 .65939 .04817 .67084 .04376 .66531 .03558 Metetra
.664 .741 .908 r
.66531 .03558 .67084 .04376 .68233 .03934 .67684 .03112 Metetra
.664 .741 .908 r
.67684 .03112 .68233 .03934 .69387 .03489 .68841 .02664 Metetra
.664 .741 .908 r
.68841 .02664 .69387 .03489 .70546 .03043 .70003 .02215 Metetra
.664 .741 .908 r
.04341 .26692 .05044 .27347 .05959 .26993 .05258 .26336 Metetra
.664 .741 .908 r
.05258 .26336 .05959 .26993 .06877 .26637 .06178 .25978 Metetra
.664 .741 .908 r
.06178 .25978 .06877 .26637 .07798 .26281 .07101 .25619 Metetra
.664 .741 .908 r
.07101 .25619 .07798 .26281 .08723 .25923 .08028 .25259 Metetra
.664 .741 .908 r
.08028 .25259 .08723 .25923 .09651 .25564 .08958 .24898 Metetra
.664 .741 .908 r
.08958 .24898 .09651 .25564 .10583 .25204 .09891 .24535 Metetra
.664 .741 .908 r
.09891 .24535 .10583 .25204 .11518 .24842 .10828 .24171 Metetra
.664 .741 .908 r
.10828 .24171 .11518 .24842 .12456 .24479 .11768 .23805 Metetra
.664 .741 .908 r
.11768 .23805 .12456 .24479 .13398 .24114 .12712 .23438 Metetra
.664 .741 .908 r
.12712 .23438 .13398 .24114 .14344 .23749 .1366 .2307 Metetra
.664 .741 .908 r
.1366 .2307 .14344 .23749 .15293 .23381 .14611 .227 Metetra
.664 .741 .908 r
.14611 .227 .15293 .23381 .16245 .23013 .15565 .22329 Metetra
.664 .741 .908 r
.15565 .22329 .16245 .23013 .17201 .22643 .16523 .21957 Metetra
.664 .741 .908 r
.16523 .21957 .17201 .22643 .18161 .22272 .17485 .21583 Metetra
.664 .741 .908 r
.17485 .21583 .18161 .22272 .19124 .21899 .1845 .21208 Metetra
.664 .741 .908 r
.1845 .21208 .19124 .21899 .20091 .21525 .19419 .20831 Metetra
.664 .741 .908 r
.19419 .20831 .20091 .21525 .21061 .2115 .20391 .20453 Metetra
.664 .741 .908 r
.20391 .20453 .21061 .2115 .22035 .20773 .21367 .20073 Metetra
.664 .741 .908 r
.21367 .20073 .22035 .20773 .23013 .20395 .22347 .19693 Metetra
.664 .741 .908 r
.22347 .19693 .23013 .20395 .23994 .20015 .23331 .1931 Metetra
.664 .741 .908 r
.23331 .1931 .23994 .20015 .24979 .19634 .24318 .18926 Metetra
.664 .741 .908 r
.24318 .18926 .24979 .19634 .25968 .19251 .25309 .18541 Metetra
.664 .741 .908 r
.25309 .18541 .25968 .19251 .2696 .18867 .26304 .18155 Metetra
.664 .741 .908 r
.26304 .18155 .2696 .18867 .27957 .18482 .27303 .17766 Metetra
.664 .741 .908 r
.27303 .17766 .27957 .18482 .28957 .18095 .28305 .17377 Metetra
.664 .741 .908 r
.28305 .17377 .28957 .18095 .29961 .17706 .29311 .16985 Metetra
.664 .741 .908 r
.29311 .16985 .29961 .17706 .30969 .17317 .30321 .16593 Metetra
.664 .741 .908 r
.30321 .16593 .30969 .17317 .3198 .16925 .31335 .16199 Metetra
.664 .741 .908 r
.31335 .16199 .3198 .16925 .32996 .16532 .32353 .15803 Metetra
.664 .741 .908 r
.32353 .15803 .32996 .16532 .34015 .16138 .33375 .15406 Metetra
.664 .741 .908 r
.33375 .15406 .34015 .16138 .35039 .15742 .34401 .15007 Metetra
.664 .741 .908 r
.34401 .15007 .35039 .15742 .36066 .15345 .3543 .14607 Metetra
.664 .741 .908 r
.3543 .14607 .36066 .15345 .37097 .14946 .36464 .14205 Metetra
.664 .741 .908 r
.36464 .14205 .37097 .14946 .38132 .14545 .37502 .13801 Metetra
.664 .741 .908 r
.37502 .13801 .38132 .14545 .39172 .14143 .38544 .13396 Metetra
.664 .741 .908 r
.38544 .13396 .39172 .14143 .40215 .13739 .3959 .1299 Metetra
.664 .741 .908 r
.3959 .1299 .40215 .13739 .41262 .13334 .4064 .12582 Metetra
.664 .741 .908 r
.4064 .12582 .41262 .13334 .42314 .12927 .41694 .12172 Metetra
.664 .741 .908 r
.41694 .12172 .42314 .12927 .43369 .12519 .42752 .11761 Metetra
.664 .741 .908 r
.42752 .11761 .43369 .12519 .44429 .12109 .43814 .11348 Metetra
.664 .741 .908 r
.43814 .11348 .44429 .12109 .45493 .11697 .44881 .10933 Metetra
.664 .741 .908 r
.44881 .10933 .45493 .11697 .46561 .11284 .45951 .10517 Metetra
.664 .741 .908 r
.45951 .10517 .46561 .11284 .47633 .10869 .47026 .10099 Metetra
.664 .741 .908 r
.47026 .10099 .47633 .10869 .4871 .10453 .48106 .09679 Metetra
.664 .741 .908 r
.48106 .09679 .4871 .10453 .49791 .10035 .49189 .09258 Metetra
.664 .741 .908 r
.49189 .09258 .49791 .10035 .50876 .09615 .50277 .08835 Metetra
.664 .741 .908 r
.50277 .08835 .50876 .09615 .51965 .09193 .51369 .08411 Metetra
.664 .741 .908 r
.51369 .08411 .51965 .09193 .53059 .0877 .52466 .07985 Metetra
.664 .741 .908 r
.52466 .07985 .53059 .0877 .54157 .08345 .53567 .07557 Metetra
.664 .741 .908 r
.53567 .07557 .54157 .08345 .55259 .07919 .54672 .07127 Metetra
.664 .741 .908 r
.54672 .07127 .55259 .07919 .56366 .07491 .55782 .06695 Metetra
.664 .741 .908 r
.55782 .06695 .56366 .07491 .57478 .07061 .56896 .06262 Metetra
.664 .741 .908 r
.56896 .06262 .57478 .07061 .58593 .06629 .58015 .05827 Metetra
.664 .741 .908 r
.58015 .05827 .58593 .06629 .59714 .06196 .59138 .05391 Metetra
.664 .741 .908 r
.59138 .05391 .59714 .06196 .60838 .0576 .60266 .04952 Metetra
.664 .741 .908 r
.60266 .04952 .60838 .0576 .61968 .05323 .61399 .04512 Metetra
.664 .741 .908 r
.61399 .04512 .61968 .05323 .63102 .04885 .62536 .0407 Metetra
.664 .741 .908 r
.62536 .0407 .63102 .04885 .6424 .04444 .63677 .03626 Metetra
.664 .741 .908 r
.63677 .03626 .6424 .04444 .65383 .04002 .64824 .03181 Metetra
.664 .741 .908 r
.64824 .03181 .65383 .04002 .66531 .03558 .65975 .02733 Metetra
.664 .741 .908 r
.65975 .02733 .66531 .03558 .67684 .03112 .6713 .02284 Metetra
.664 .741 .908 r
.6713 .02284 .67684 .03112 .68841 .02664 .68291 .01833 Metetra
.664 .741 .908 r
.68291 .01833 .68841 .02664 .70003 .02215 .69456 .0138 Metetra
.664 .741 .908 r
.03634 .26033 .04341 .26692 .05258 .26336 .04552 .25675 Metetra
.664 .741 .908 r
.04552 .25675 .05258 .26336 .06178 .25978 .05474 .25315 Metetra
.664 .741 .908 r
.05474 .25315 .06178 .25978 .07101 .25619 .06399 .24953 Metetra
.664 .741 .908 r
.06399 .24953 .07101 .25619 .08028 .25259 .07327 .24591 Metetra
.664 .741 .908 r
.07327 .24591 .08028 .25259 .08958 .24898 .08259 .24227 Metetra
.664 .741 .908 r
.08259 .24227 .08958 .24898 .09891 .24535 .09195 .23861 Metetra
.664 .741 .908 r
.09195 .23861 .09891 .24535 .10828 .24171 .10134 .23495 Metetra
.664 .741 .908 r
.10134 .23495 .10828 .24171 .11768 .23805 .11076 .23126 Metetra
.664 .741 .908 r
.11076 .23126 .11768 .23805 .12712 .23438 .12022 .22757 Metetra
.664 .741 .908 r
.12022 .22757 .12712 .23438 .1366 .2307 .12971 .22386 Metetra
.664 .741 .908 r
.12971 .22386 .1366 .2307 .14611 .227 .13924 .22014 Metetra
.664 .741 .908 r
.13924 .22014 .14611 .227 .15565 .22329 .1488 .2164 Metetra
.664 .741 .908 r
.1488 .2164 .15565 .22329 .16523 .21957 .1584 .21265 Metetra
.664 .741 .908 r
.1584 .21265 .16523 .21957 .17485 .21583 .16804 .20889 Metetra
.664 .741 .908 r
.16804 .20889 .17485 .21583 .1845 .21208 .17771 .20511 Metetra
.664 .741 .908 r
.17771 .20511 .1845 .21208 .19419 .20831 .18742 .20132 Metetra
.664 .741 .908 r
.18742 .20132 .19419 .20831 .20391 .20453 .19717 .19751 Metetra
.664 .741 .908 r
.19717 .19751 .20391 .20453 .21367 .20073 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21367 .20073 .22347 .19693 .21677 .18986 Metetra
.664 .741 .908 r
.21677 .18986 .22347 .19693 .23331 .1931 .22663 .18601 Metetra
.664 .741 .908 r
.22663 .18601 .23331 .1931 .24318 .18926 .23652 .18214 Metetra
.664 .741 .908 r
.23652 .18214 .24318 .18926 .25309 .18541 .24646 .17826 Metetra
.664 .741 .908 r
.24646 .17826 .25309 .18541 .26304 .18155 .25643 .17437 Metetra
.664 .741 .908 r
.25643 .17437 .26304 .18155 .27303 .17766 .26644 .17046 Metetra
.664 .741 .908 r
.26644 .17046 .27303 .17766 .28305 .17377 .27648 .16653 Metetra
.664 .741 .908 r
.27648 .16653 .28305 .17377 .29311 .16985 .28657 .16259 Metetra
.664 .741 .908 r
.28657 .16259 .29311 .16985 .30321 .16593 .29669 .15864 Metetra
.664 .741 .908 r
.29669 .15864 .30321 .16593 .31335 .16199 .30686 .15467 Metetra
.664 .741 .908 r
.30686 .15467 .31335 .16199 .32353 .15803 .31706 .15068 Metetra
.664 .741 .908 r
.31706 .15068 .32353 .15803 .33375 .15406 .3273 .14668 Metetra
.664 .741 .908 r
.3273 .14668 .33375 .15406 .34401 .15007 .33758 .14267 Metetra
.664 .741 .908 r
.33758 .14267 .34401 .15007 .3543 .14607 .3479 .13864 Metetra
.664 .741 .908 r
.3479 .13864 .3543 .14607 .36464 .14205 .35827 .13459 Metetra
.664 .741 .908 r
.35827 .13459 .36464 .14205 .37502 .13801 .36867 .13053 Metetra
.664 .741 .908 r
.36867 .13053 .37502 .13801 .38544 .13396 .37911 .12645 Metetra
.664 .741 .908 r
.37911 .12645 .38544 .13396 .3959 .1299 .3896 .12235 Metetra
.664 .741 .908 r
.3896 .12235 .3959 .1299 .4064 .12582 .40012 .11824 Metetra
.664 .741 .908 r
.40012 .11824 .4064 .12582 .41694 .12172 .41069 .11411 Metetra
.664 .741 .908 r
.41069 .11411 .41694 .12172 .42752 .11761 .4213 .10997 Metetra
.664 .741 .908 r
.4213 .10997 .42752 .11761 .43814 .11348 .43195 .10581 Metetra
.664 .741 .908 r
.43195 .10581 .43814 .11348 .44881 .10933 .44264 .10163 Metetra
.664 .741 .908 r
.44264 .10163 .44881 .10933 .45951 .10517 .45337 .09744 Metetra
.664 .741 .908 r
.45337 .09744 .45951 .10517 .47026 .10099 .46415 .09323 Metetra
.664 .741 .908 r
.46415 .09323 .47026 .10099 .48106 .09679 .47497 .08901 Metetra
.664 .741 .908 r
.47497 .08901 .48106 .09679 .49189 .09258 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49189 .09258 .50277 .08835 .49674 .0805 Metetra
.664 .741 .908 r
.49674 .0805 .50277 .08835 .51369 .08411 .50769 .07623 Metetra
.664 .741 .908 r
.50769 .07623 .51369 .08411 .52466 .07985 .51868 .07193 Metetra
.664 .741 .908 r
.51868 .07193 .52466 .07985 .53567 .07557 .52972 .06762 Metetra
.664 .741 .908 r
.52972 .06762 .53567 .07557 .54672 .07127 .5408 .06329 Metetra
.664 .741 .908 r
.5408 .06329 .54672 .07127 .55782 .06695 .55193 .05894 Metetra
.664 .741 .908 r
.55193 .05894 .55782 .06695 .56896 .06262 .5631 .05458 Metetra
.664 .741 .908 r
.5631 .05458 .56896 .06262 .58015 .05827 .57432 .0502 Metetra
.664 .741 .908 r
.57432 .0502 .58015 .05827 .59138 .05391 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .59138 .05391 .60266 .04952 .59689 .04138 Metetra
.664 .741 .908 r
.59689 .04138 .60266 .04952 .61399 .04512 .60825 .03695 Metetra
.664 .741 .908 r
.60825 .03695 .61399 .04512 .62536 .0407 .61965 .03249 Metetra
.664 .741 .908 r
.61965 .03249 .62536 .0407 .63677 .03626 .6311 .02802 Metetra
.664 .741 .908 r
.6311 .02802 .63677 .03626 .64824 .03181 .64259 .02353 Metetra
.664 .741 .908 r
.64259 .02353 .64824 .03181 .65975 .02733 .65414 .01902 Metetra
.664 .741 .908 r
.65414 .01902 .65975 .02733 .6713 .02284 .66573 .0145 Metetra
.664 .741 .908 r
.66573 .0145 .6713 .02284 .68291 .01833 .67736 .00995 Metetra
.664 .741 .908 r
.67736 .00995 .68291 .01833 .69456 .0138 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10103 .23013 m
.10573 .23471 L
s
[(-50)] .09164 .22096 1 .9755 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60933 .03109 m
.6131 .03647 L
s
[(50)] .60181 .02034 .69935 1 Mshowa
.125 Mabswid
.14766 .21187 m
.15043 .21466 L
s
.19515 .19327 m
.19788 .19611 L
s
.24353 .17433 m
.24621 .17721 L
s
.29283 .15503 m
.29545 .15796 L
s
.39427 .1153 m
.39678 .11833 L
s
.44647 .09487 m
.44892 .09794 L
s
.49969 .07402 m
.50208 .07715 L
s
.55397 .05277 m
.55629 .05595 L
s
.05524 .24806 m
.0581 .25076 L
s
.66582 .00897 m
.668 .01225 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{492.5, 399.5},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;R0002Ea000`40O003h00Oogooogooi7oo003o
OoooOooTOol00?mooomoonAoo`00ogooogooi7oo003oOoooOooTOol00?mooomoonAoo`00ogooogoo
i7oo003oOoooOooTOol00?mooomoonAoo`00ogooogooi7oo003oOoooOooTOol00?mooomoonAoo`00
ogooogooi7oo003oOoooOooTOol00?mooomoonAoo`00ogooogoo27oo0P00fWoo003oOoooOol5Ool3
00000goo001oo`3IOol00?mooomoo`=oo`8000Aoo`800=Uoo`00ogooogoo0`001Woo00<007oo0000
f7oo003oOoomOol20008Ool200000goo001oo`3GOol00?mookeoo`06BU88@P00000Q27>L17oo00AJ
ePQ2000icRmoo`<000Moo`<00005E_d007ooOol0003GOol00?mookeoo`06249247ooOolicR480goo
00IS61S6LiacW124DY@[Ool30007Ool30004E_d20002Ool00`00Oomoo`3DOol00?mool9oo`06001o
ogooOolQ25:D0Woo00=BU1S6Ool0:7oo0P0000=oo`00Ool01Goo0P001eKm00D005Km001oo`000=Io
o`00ogoo`Goo00=cW000Ool00Woo00<007ooOol00Woo00<007ooOol097oo0`0017oo00@007ooOomo
o`800003E_d005Km00IFo@03001Fo@00009oo`03001oogoo0==oo`00ogoo_Goo00H8@TYBOomoocW>
<H`3Ool00`00Oomoo`02Ool00`00Oomoo`0ROol20008Ool30004E_d00`00E_eFo@04E_d01000E_eF
o@000Woo00<007ooOol0dWoo003oOonmOol01@0048@00000<H`017oo00<007ooOol00Woo00<007oo
Ool07goo0`002Goo0P001eKm00<005KmE_d015Km00H005Km000007oo003DOol00?mookeoo`03001o
ogoo00Ioo`068@QBU7ooOomBU2487goo0P002Woo0P002EKm00<005KmE_d00eKm0`0000EFo@00Oomo
o`000==oo`00ogoo_Goo00<007ooOol01Woo00IS61S6LiacW1S6HaPLOol30009Ool300000eKm001F
o@09E_d00`00E_d0000200000eKm001Fo@02E_d01000Ool00000dWoo003oOonmOol50005Ool015[F
2488@V<H6goo0P002Goo0`001EKm00<005KmE_d01eKm0P0015Km00<005KmE_d00UKm00<007oo0000
dWoo003oOooSOol30009Ool20009E_d00`00E_eFo@03E_d300000eKm001Fo@03E_d00`00E_eFo@02
E_d01000Oomoo`00dGoo003oOooQOol20009Ool300000eKm001Fo@09E_d00`00E_d000020005E_d0
1@00E_eFoEKm00001EKm00<007oo0000dGoo003oOooNOol30008Ool30005E_d00`00E_eFo@07E_d2
0009E_d01000E_eFo@001EKm0P0000=oo`00Ool0cgoo003oOooKOol30009Ool20009E_d00`00E_eF
o@03E_d300000eKm001Fo@08E_d01000E_eFo@000UKm0`0000EFo@00Oomoo`000<moo`00ogoofGoo
0P002Goo0`0000=Fo@00E_d02EKm00<005Km00000P001EKm00<005KmE_d01eKm00<005Km00000P00
1EKm00<007oo0000cgoo003oOooFOol30008Ool30005E_d00`00E_eFo@07E_d20009E_d00`00E_eF
o@06E_d30008E_d00`00Ool0003>Ool00?moomAoo`8000Uoo`8000UFo@03001FoEKm00AFo@800003
E_d005Km00QFo@03001FoEKm00=Fo@<00003E_d0000000QFo@04001oogoo003=Ool00?moom5oo`<0
00Qoo`<00003E_d005Km00QFo@03001FoEKm009Fo@8000AFo@03001FoEKm00MFo@03001Fo@000080
00EFo@03001FoEKm00MFo@03001oo`000<eoo`00ogoocgoo0`001goo0`001EKm00<005KmE_d01eKm
00@005Km000000MFo@03001FoEKm00IFo@8000QFo@8000QFo@800003Ool007oo0<]oo`00ogooc7oo
0`000Woo00<007ooOol00goo0P002EKm00<005KmE_d01UKm0P002EKm00<005KmE_d00eKm0`0000=F
o@00E_d01eKm0P001EKm0`0000EFo@00Oomoo`000<]oo`00ogoobWoo0P001Woo00<007oo00000P00
00=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d02EKm00<005Km00000P001EKm00<005Km
E_d01EKm00@005Km001Fo@<000EFo@03001oo`000<]oo`00ogooagoo0`001goo0`001EKm00<005Km
E_d01eKm00<005Km00000P001EKm00<005KmE_d01eKm0P002EKm00<005KmE_d015Km00@005Km0000
00UFo@03001oo`000<Yoo`00ogooa7oo0`0027oo0P000UKm00<005KmE_d015Km00<005KmE_d01UKm
0P002EKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d02EKm
00<007oo0000bGoo003oOoo2Ool20008Ool300000eKm001Fo@08E_d00`00E_eFo@03E_d300000eKm
001Fo@09E_d00`00E_d000020005E_d00`00E_eFo@07E_d00`00E_d000020002E_d01000E_eFo@00
2EKm0`00bGoo003oOonoOol30007Ool30005E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00
E_eFo@07E_d20009E_d00`00E_eFo@06E_d20005E_d01@00E_eFoEKm00001UKm0P0000AFo@00Ool0
0<Qoo`00ogoo_Goo0P0027oo0P002EKm00<005KmE_d01UKm0P002EKm00<005KmE_d00eKm0`0000=F
o@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d015Km00D005KmE_eFo@0000AFo@8000AFo@03
001oo`000<Moo`00ogoo^Woo0`001goo0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00
E_d02EKm00<005Km00000P001EKm00<005KmE_d01eKm00<005Km00000P001EKm00<005KmE_d00UKm
00<005KmE_d00UKm00@005Km000000MFo@800<Moo`00ogoo^7oo0P001goo0`001EKm00<005KmE_d0
1eKm00<005Km00000P001EKm00<005KmE_d01eKm0P002EKm00<005KmE_d01UKm0P002EKm00D005Km
E_eFo@0000AFo@8000UFo@03001oo`000<Ioo`00ogoo]Goo0`001goo0P002EKm00<005KmE_d01UKm
0P002EKm00<005KmE_d015Km0P0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d025Km
00H005KmE_eFo@00E_d300000eKm001Fo@09E_d00`00Ool0000GOol01TYB248000008@QcW0Aoo`04
F]H8@P00>LjPOol00?mook=oo`8000Qoo`800003E_d005Km00QFo@03001FoEKm00=Fo@<00003E_d0
05Km00QFo@03001FoEKm009Fo@8000AFo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm
00MFo@03001Fo@00008000EFo@03001FoEKm00MFo@<001Moo`06249247ooOolicR480goo00IS61S6
LiacW124DYBOOol00?mook1oo`<000Qoo`8000AFo@03001FoEKm00MFo@03001Fo@00008000EFo@03
001FoEKm00MFo@04001Fo@000007E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@06E_d200000eKm
001Fo@06E_d00`00E_eFo@03E_d3000015Km001oo`006goo00H007ooOomoob48DY@2Ool00e:D6<Io
o`2NOol00?moojioo`8000Uoo`8000MFo@03001FoEKm00IFo@8000UFo@03001FoEKm00IFo@8000UF
o@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm00=Fo@<00004E_d005Km0007E_d00`00
E_eFo@030005E_d00`00Ool0000<Ool70006Ool00g>L001oo`02Ool00`00Oomoo`02Ool00`00Oomo
o`2MOol00?mooj]oo`<000Uoo`8000UFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm
00=Fo@<00003E_d005Km00UFo@03001Fo@00008000EFo@03001FoEKm00MFo@03001Fo@00008000EF
o@8000MFo@<000QFo@03001oo`0001Eoo`06249:DWooOolicS6<0goo00<007ooOol00Woo00<007oo
Ool0WGoo003oOonXOol30009Ool300000eKm001Fo@09E_d00`00E_d000020005E_d00`00E_eFo@07
E_d00`00E_d000020005E_d00`00E_eFo@07E_d20009E_d00`00E_eFo@06E_d20009E_d00`00E_eF
o@02E_d300000eKm001Fo@09E_d00`00Ool0000DOol01@0048@00000<H`017oo00<007ooOol00Woo
00<007ooOol0WGoo003oOonVOol20002Ool00`00Oomoo`04Ool30005E_d00`00E_eFo@07E_d20009
E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_eFo@03E_d3
00000eKm001Fo@08E_d00`00E_d000020005E_d00`00E_eFo@07E_d01000Oomoo`004goo00<007oo
Ool01Woo00HQ25:DOomooe:D8@ROOol00?mooj=oo`<000Eoo`04001oogooOol20009E_d00`00E_eF
o@03E_d300000eKm001Fo@08E_d00`00E_eFo@03E_d300000eKm001Fo@09E_d00`00E_d000020005
E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@06E_d2
00000goo001oo`0BOol00`00Oomoo`06Ool01V<H6<IcW7>L6<IS69moo`00ogooXGoo0P002Goo0`00
00=Fo@00E_d02EKm00<005Km00000P001EKm00<005KmE_d01eKm00<005Km00000P001EKm00<005Km
E_d01eKm0P002EKm00<005KmE_d01UKm0P002EKm00<005KmE_d00UKm1@002EKm00<005KmE_d00eKm
0`0000=Fo@00Ool00P004Woo1@001Goo00AJePQ2249S6:1oo`00ogooWWoo0`0027oo0`001EKm00<0
05KmE_d01eKm0P002EKm00<005KmE_d01UKm0P002EKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km
00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005Km00000P000eKm00<005Km00002EKm00<005Km
00000P001EKm00@007ooOol00;moo`00ogooW7oo0P002Goo0P002EKm00<005KmE_d00eKm0`0000=F
o@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d02EKm00<005Km00000P001EKm00<005KmE_d0
1eKm00<005Km00000P001EKm00<005KmE_d01UKm0P001UKm00@005KmE_d000QFo@8000UFo@03001o
o`000;moo`00ogooVGoo0`0027oo0`000UKm00<005KmE_d01eKm00<005Km00000P001EKm00<005Km
E_d01eKm00<005Km00000P001EKm00<005KmE_d01eKm0P002EKm00<005KmE_d01UKm0P002EKm00<0
05KmE_d00UKm0`0000=Fo@00E_d01EKm00@005KmE_d000EFo@<00003E_d005Km00UFo@03001oo`00
0;ioo`00ogooUgoo0P002Goo0P001UKm00<005KmE_d01UKm0P002EKm00<005KmE_d01UKm0P002EKm
00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005Km
00000P001EKm00<005KmE_d015Km00D005KmE_d005Km00<000EFo@03001FoEKm00MFo@<00;ioo`00
ogooU7oo0`002Goo0P002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`00
00=Fo@00E_d02EKm00<005Km00000P001EKm00<005KmE_d01eKm00<005Km00000P001EKm00<005Km
E_d01UKm0P002EKm00<005KmE_d00eKm00<005KmE_d00P002EKm00<005KmE_d00eKm0`0000AFo@00
Ool00;eoo`00ogooTWoo0P002Goo0`0000=Fo@00E_d02EKm00@005Km000000EFo@03001FoEKm00MF
o@03001Fo@00008000EFo@03001FoEKm00MFo@8000UFo@03001FoEKm00IFo@8000UFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm00=Fo@<00003E_d005Km00UFo@03001Fo@00008000EF
o@03001oo`000;aoo`00ogooSgoo0`0027oo0`001EKm00<005KmE_d01eKm0P0025Km00<005KmE_d0
1UKm0P002EKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d0
25Km00<005Km00000P001EKm00<005KmE_d01eKm00<005Km00000`0015Km00<005KmE_d01eKm0P00
2EKm0P00_7oo003oOon<Ool30009Ool20009E_d00`00E_eFo@03E_d300000eKm001Fo@07E_d00`00
E_eFo@03E_d300000eKm001Fo@09E_d00`00E_d000020005E_d00`00E_eFo@07E_d00`00E_d00002
0005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@06E_d20003E_d00`00E_eFo@03E_d00`00E_eF
o@03E_d300000eKm001Fo@08E_d00`00Ool0002kOol00?moohYoo`8000Uoo`<00003E_d005Km00UF
o@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00MFo@8000UF
o@03001FoEKm00IFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00=Fo@<0
0003E_d005Km009Fo@03001FoEKm00AFo@03001Fo@00008000EFo@03001FoEKm00MFo@03001oo`00
0;Yoo`00ogooQgoo0`0027oo0`001EKm00<005KmE_d01eKm0P002EKm00<005KmE_d01EKm0P002EKm
00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d02EKm00@005Km
000000EFo@03001FoEKm00MFo@03001Fo@00008000EFo@04001FoEKm0006E_d20009E_d00`00E_eF
o@06E_d3002jOol00?moohEoo`8000Uoo`8000UFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03
001FoEKm009Fo@<0009Fo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00MFo@03001F
o@00008000EFo@03001FoEKm00MFo@8000QFo@03001FoEKm00IFo@8000UFo@03001Fo@0000AFo@80
0003E_d005Km00QFo@03001FoEKm00=Fo@<00004E_d007oo002iOol00?mooh9oo`<000Qoo`<00003
E_d005Km00UFo@03001Fo@00008000EFo@03001FoEKm00MFo@04001Fo@000006E_d00`00E_eFo@06
E_d20009E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@03E_d300000eKm001Fo@07E_d00`00E_eF
o@03E_d300000eKm001Fo@08E_d00`00E_d00002E_d20004E_d00`00E_eFo@07E_d00`00E_d00002
0005E_d00`00Ool0002hOol00?mooh1oo`8000=oo`03001oogoo009oo`<000EFo@03001FoEKm00MF
o@8000UFo@03001FoEKm00IFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm
00=Fo@<00003E_d005Km00UFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EF
o@03001FoEKm00MFo@@000MFo@03001FoEKm00IFo@8000QFo@03001oo`000;Qoo`00ogooOGoo0`00
1Woo00@007oo000000UFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm00=Fo@<00003
E_d005Km00UFo@04001Fo@000005E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@07
E_d20008E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@05E_d30009E_d00`00E_eFo@03E_d30000
0eKm001Fo@08E_d00`00Ool0002gOol00?moog]oo`8000Qoo`<0009Fo@03001FoEKm00MFo@03001F
o@00008000EFo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00MFo@8000QFo@03001F
oEKm00IFo@8000UFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d0
05Km00UFo@03001FoEKm00@0009Fo@03001FoEKm00QFo@03001Fo@00008000EFo@03001FoEKm00IF
o@04001oogoo002fOol00?moogQoo`<000Qoo`8000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm
00IFo@8000UFo@03001FoEKm00=Fo@<00003E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km
00UFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00MFo@<0
00IFo@8000UFo@8000QFo@03001FoEKm00IFo@800003Ool007oo0;Eoo`00ogooMWoo0P002Goo0P00
2EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d02EKm00<0
05Km00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01eKm0P002EKm00<0
05KmE_d01EKm0P002EKm00<005KmE_d00eKm0`0000=Fo@00E_d01UKm00<005Km00001EKm0`0000=F
o@00E_d025Km00<005KmE_d00UKm0`0000EFo@00Oomoo`000;Eoo`00ogooLgoo0`0027oo0`0000=F
o@00E_d02EKm00@005Km000000EFo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00MF
o@8000UFo@03001FoEKm00EFo@8000UFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm
009Fo@<00003E_d005Km00UFo@03001Fo@00008000EFo@03001FoEKm00AFo@05001FoEKm001Fo@03
0005E_d00`00E_eFo@06E_d00`00E_d000020005E_d01000Oomoo`00]7oo003oOom`Ool30008Ool3
0005E_d00`00E_eFo@07E_d20008E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@03E_d300000eKm
001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d00`00E_d000020005E_d00`00E_eFo@07
E_d01000E_d000001EKm00<005KmE_d01eKm0P002EKm00<005KmE_d00eKm00<005KmE_d00P0025Km
00<005KmE_d01UKm0P002EKm00<007oo0000]7oo003oOom^Ool20009Ool20009E_d00`00E_eFo@03
E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d00`00E_d000020005E_d0
0`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0P002EKm00<005KmE_d01UKm0P0025Km
00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005Km
E_d00UKm0`0000=Fo@00E_d02EKm00<007oo0000/goo003oOom[Ool30008Ool300000eKm001Fo@09
E_d00`00E_d000020005E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0P002EKm
00<005KmE_d01UKm0P0025Km00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`00
00=Fo@00E_d025Km00<005Km00000P001EKm00<005KmE_d01eKm00<005Km00000P0000=Fo@00E_d0
0UKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01eKm0P0000=oo`00Ool0/Goo003o
OomYOol20009Ool20005E_d00`00E_eFo@07E_d20009E_d00`00E_eFo@06E_d20008E_d00`00E_eF
o@03E_d300000eKm001Fo@08E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_d000020005
E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@06E_d2
0004E_d01@00E_eFoEKm000025Km0P002EKm00<005KmE_d00eKm0`0000AFo@00Ool00;9oo`00ogoo
IWoo0`002Goo0P0025Km00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=F
o@00E_d025Km00<005Km00000P001EKm00<005KmE_d01eKm00<005Km00000P001EKm00<005KmE_d0
1UKm0P002EKm00<005KmE_d01UKm0P002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005Km
E_d00eKm0`0000=Fo@00E_d00eKm00<005KmE_d00UKm00<005KmE_d00UKm0`0000=Fo@00E_d02EKm
00<005Km00000P001EKm00<007oo0000/Goo003oOomTOol20009Ool300000eKm001Fo@08E_d00`00
E_d000020005E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d20009E_d00`00
E_eFo@06E_d20009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@03E_d300000eKm
001Fo@08E_d00`00E_d000020005E_d00`00E_eFo@07E_d00`00E_d000020005E_d01@00E_eFoEKm
000015Km00<005Km00000P001EKm00<005KmE_d01eKm0P0025Km00@007ooOol00;1oo`00ogooHGoo
0`0027oo0`001EKm00<005KmE_d01UKm0P002EKm00<005KmE_d01UKm0P002EKm00<005KmE_d00UKm
0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d02EKm00@005Km000000EFo@03001F
oEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00IFo@8000UFo@04
001FoEKm0003E_d30009E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00Ool0002`Ool00?mo
oemoo`8000Uoo`8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00=Fo@<00003
E_d005Km00UFo@04001Fo@000005E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@07
E_d20008E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eF
o@03E_d300000eKm001Fo@08E_d00`00E_eFo@040002E_d00`00E_eFo@08E_d00`00E_d000020005
E_d00`00E_eFo@06E_d01000Oomoo`00[goo003oOomLOol40007Ool300000eKm001Fo@09E_d01000
E_d000001EKm00<005KmE_d01eKm00<005Km00000P001EKm00<005KmE_d01eKm0P0025Km00<005Km
E_d01UKm0P002EKm00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00
E_d02EKm00@005Km000000EFo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@@0
00IFo@03001FoEKm00MFo@8000UFo@03001FoEKm00AFo@<00003Ool000000:ioo`00ogooFGoo0`00
0goo00<007ooOol00Woo0`001EKm00<005KmE_d01eKm0P0025Km00<005KmE_d01UKm0P002EKm00<0
05KmE_d00eKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00E_d02EKm00<005Km0000
0P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01eKm0P0025Km00<005KmE_d0
1UKm0P002EKm00<005KmE_d00UKm0`0000AFo@00E_d000MFo@03001FoEKm00=Fo@<00003E_d005Km
00QFo@03001FoEKm00@0009Fo@800003Ool007oo0:eoo`00ogooEgoo0P001goo00@007oo000000UF
o@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00UFo@03001F
o@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00MFo@8000QFo@03001F
oEKm00IFo@8000UFo@03001FoEKm00=Fo@<00003E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d0
05Km00UFo@04001Fo@000005E_d20008E_d00`00E_d000020005E_d00`00E_eFo@06E_d30007E_d0
1000Oomoo`00[Goo003oOomDOol30008Ool30002E_d00`00E_eFo@07E_d00`00E_d000020005E_d0
0`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0P002EKm00<005KmE_d01EKm0P002EKm
00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00<005Km
00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01eKm0P0025Km00<005Km
E_d01UKm0P002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<007oo0000[Goo003oOomBOol2
0009Ool20006E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@03E_d3
00000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d00`00E_d000020005E_d00`00
E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@07E_d20008E_d00`00E_eFo@06E_d20009E_d0
0`00E_eFo@03E_d300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@09E_d01000E_d0
00001EKm00<005KmE_d01eKm00<007oo0000[7oo003oOom?Ool30008Ool30009E_d00`00E_eFo@02
E_d30002E_d00`00E_eFo@06E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_d000020005
E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0P002EKm00<005KmE_d01EKm0P00
2EKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00<0
05Km00000P001EKm00<005KmE_d01EKm0P0000AFo@00000000EFo@03001FoEKm00MFo@8000QFo@03
001FoEKm00IFo@800003Ool007oo0:Yoo`00ogooCGoo0P001goo10000UKm00<005KmE_d025Km00@0
05Km000000IFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@8000UFo@03001F
oEKm00IFo@8000QFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d0
05Km00UFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00MF
o@8000QFo@03001FoEKm00EFo@<000UFo@03001FoEKm00=Fo@<00003E_d005Km00MFo@03001FoEKm
00=Fo@<00004E_d007oo002[Ool00?moodYoo`<000Ioo`<000MFo@03001FoEKm00MFo@8000UFo@03
001FoEKm00AFo@<000UFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00IFo@03001FoEKm00=Fo@<0
0003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eF
o@07E_d20009E_d00`00E_eFo@05E_d20009E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00
E_eFo@02E_d300000eKm001Fo@09E_d00`00E_d000020005E_d00`00E_eFo@06E_d00`00E_d00002
0005E_d00`00Ool0002ZOol00?moodQoo`8000Ioo`<00003E_d005Km00QFo@03001FoEKm00=Fo@<0
0003E_d005Km00UFo@03001FoEKm00<0009Fo@03001FoEKm00QFo@04001Fo@000006E_d00`00E_eF
o@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@06E_d20008E_d00`00
E_eFo@03E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d00`00E_d00002
0005E_d00`00E_eFo@06E_d00`00E_d000020002E_d01000E_eFo@002EKm0P0025Km00<005KmE_d0
1UKm0P002EKm00<007oo0000ZGoo003oOom5Ool30006Ool20005E_d00`00E_eFo@07E_d00`00E_d0
00020005E_d00`00E_eFo@07E_d30006E_d00`00E_eFo@07E_d20009E_d00`00E_eFo@04E_d30009
E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00
E_d000020005E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0P002EKm00<005Km
E_d01EKm0P001EKm00D005KmE_eFo@0000EFo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@03001oo`000:Uoo`00ogoo@goo0P001goo0P0025Km00<005KmE_d01UKm0P002EKm
00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00E_d02EKm00<005Km
E_d00`000UKm00<005KmE_d025Km00@005Km000000EFo@03001FoEKm00MFo@03001Fo@00008000EF
o@03001FoEKm00IFo@8000UFo@03001FoEKm00IFo@8000QFo@03001FoEKm00=Fo@<00003E_d005Km
00QFo@03001FoEKm009Fo@<00003E_d005Km00AFo@03001FoEKm009Fo@03001Fo@00008000EFo@03
001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@800003Ool007oo0:Moo`00ogoo2Woo
00AJePQ2000icS9oo`<000Ioo`<00003E_d005Km00QFo@03001FoEKm009Fo@<0009Fo@03001FoEKm
00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00MFo@<0
00IFo@03001FoEKm00MFo@8000QFo@03001FoEKm00EFo@<000UFo@03001FoEKm009Fo@<00003E_d0
05Km00QFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00MF
o@04001Fo@000005E_d00`00E_eFo@03E_d01000E_eFoEKm0P0025Km00<005KmE_d01UKm0P002EKm
00<005KmE_d00UKm0`0000EFo@00Oomoo`000:Moo`00ogoo2Goo00IS61S6LiacW124DY@^Ool30007
Ool20005E_d00`00E_eFo@07E_d01000E_d000001UKm00<005KmE_d01UKm0P002EKm00<005KmE_d0
1EKm0P002EKm00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00E_d0
25Km00<005KmE_d010000UKm00<005KmE_d025Km00@005Km000000EFo@03001FoEKm00MFo@03001F
o@00008000EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00IFo@8000QFo@03001FoEKm009Fo@@0
0003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00UFo@04001Fo@000005E_d00`00Ool0
002WOol00?moo`Uoo`068@QBU7ooOomBU1S6;7oo0P0027oo0P0025Km00<005KmE_d01UKm0P002EKm
00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00<005Km
00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0`001eKm00<005Km
E_d01eKm0P0025Km00<005KmE_d01EKm0`002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<0
05KmE_d00eKm0`0000=Fo@00E_d025Km00<005Km00000P001EKm00<005KmE_d01UKm00<005Km0000
0P001EKm00<005KmE_d01eKm0P0025Km00<007oo0000YWoo003oOol9Ool00`00Oomoo`02Ool00`00
Oomoo`0WOol30007Ool300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@09E_d01000
E_d000001EKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00MFo@8000UFo@03001FoEKm
00EFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00=Fo@<00003E_d005Km
00QFo@03001FoEKm00@0009Fo@03001FoEKm00QFo@04001Fo@000005E_d00`00E_eFo@07E_d00`00
E_d000020005E_d00`00E_eFo@06E_d20002E_d00`00E_eFo@03E_d00`00E_eFo@06E_d20009E_d0
0`00E_eFo@03E_d300000eKm001Fo@07E_d01000Oomoo`00YGoo003oOol9Ool00`00Oomoo`02Ool0
0`00Oomoo`0UOol20003Ool01000Oomoogoo0`001EKm00<005KmE_d01UKm00<005Km00000P001EKm
00<005KmE_d01eKm0P0025Km00<005KmE_d01UKm0P0025Km00<005KmE_d00eKm0`0000=Fo@00E_d0
25Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00@005Km000000EFo@03001FoEKm00MFo@03001F
o@00008000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00MFo@8000QFo@03001FoEKm00EFo@<0
00UFo@03001FoEKm009Fo@<00005E_d005KmE_d00006E_d00`00E_eFo@02E_d300000eKm001Fo@09
E_d00`00E_d000020005E_d00`00E_eFo@06E_d00`00Ool0002UOol00?moo`Uoo`03001oogoo009o
o`03001oogoo029oo`<000Ioo`<000UFo@03001FoEKm00EFo@8000UFo@03001FoEKm00=Fo@<00003
E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm
00MFo@04001Fo@000005E_d00`00E_eFo@07E_d20008E_d00`00E_eFo@06E_d20009E_d00`00E_eF
o@02E_d300000eKm001Fo@08E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_eFo@040002
E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_d00006E_d00`00E_d000020005E_d00`00
E_eFo@07E_d20008E_d00`00E_eFo@06E_d200000goo001oo`2SOol00?moo`Uoo`068@QBU7ooOomB
U2488Woo0P001goo0`000UKm00<005KmE_d01UKm00<005KmE_d00UKm0`000UKm00<005KmE_d01eKm
00<005Km00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0P002EKm
00<005KmE_d01UKm0P0025Km00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`00
00=Fo@00E_d02EKm00@005Km000000EFo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm
00IFo@<000MFo@03001FoEKm00IFo@8000UFo@8000EFo@<000UFo@03001FoEKm00=Fo@<00003E_d0
05Km00QFo@03001FoEKm009Fo@<00005E_d007ooOol0002SOol00?moo`Uoo`06HaPHaW>LLi`HaV<H
7goo0`001goo0P001UKm00<005KmE_d01UKm00@005Km000000IFo@03001FoEKm00IFo@8000UFo@03
001FoEKm00EFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00=Fo@<00003
E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm
00MFo@8000QFo@03001FoEKm00IFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001F
oEKm009Fo@<00003E_d005Km00UFo@03001FoEKm00<0009Fo@03001FoEKm00QFo@03001Fo@000080
00EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001oo`000:=oo`00ogoo2Woo00AJePQ2249S
61ioo`8000Qoo`8000UFo@03001FoEKm00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QF
o@03001FoEKm009Fo@<00003E_d005Km00UFo@04001Fo@000005E_d00`00E_eFo@07E_d00`00E_d0
00020005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@05E_d20009E_d00`00E_eFo@03E_d30000
0eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_d000020005E_d00`00E_eF
o@07E_d01000E_d000001EKm00<005KmE_d01eKm0`001UKm00<005KmE_d01eKm0P002EKm00<005Km
E_d015Km0`002EKm00<007oo0000XWoo003oOolYOol30007Ool300000eKm001Fo@09E_d00`00E_eF
o@030002E_d00`00E_eFo@08E_d01000E_d000001EKm00<005KmE_d01eKm00@005Km000000EFo@03
001FoEKm00MFo@8000QFo@03001FoEKm00IFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QF
o@03001FoEKm009Fo@<00003E_d005Km00UFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001F
o@00008000EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00IFo@8000QFo@03001FoEKm00=Fo@D0
00QFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@04
001oogoo002QOol00?moobMoo`8000Moo`<000EFo@03001FoEKm00MFo@<000IFo@03001FoEKm00MF
o@8000QFo@03001FoEKm00EFo@<000QFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm
009Fo@<00003E_d005Km00UFo@04001Fo@000005E_d00`00E_eFo@07E_d01000E_d000001EKm00<0
05KmE_d01eKm0P002EKm00<005KmE_d01EKm0P002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km
00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005Km00000P000eKm00<005Km000025Km00<005Km
00000P001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0000=oo`00Ool0X7oo003oOolT
Ool30007Ool20009E_d00`00E_eFo@03E_d300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm
001Fo@08E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@07
E_d01000E_d000001EKm00<005KmE_d01eKm0P0025Km00<005KmE_d01UKm0P0025Km00<005KmE_d0
0eKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00@005Km000000EFo@03
001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@8000IFo@03001Fo@0000QFo@8000UF
o@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00005E_d007ooOol0002POol0
0?moob5oo`<000Moo`<0009Fo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@03
001Fo@00008000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000UFo@03001FoEKm00EF
o@<000QFo@03001FoEKm00=Fo@<00003E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QF
o@03001Fo@00008000EFo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07E_d20008E_d0
0`00E_eFo@06E_d20009E_d00`00E_eFo@02E_d300000eKm001Fo@05E_d01000E_eFo@0015Km0`00
00=Fo@00E_d025Km00<005Km00000P001EKm00<005KmE_d01eKm00@005Km000000EFo@04001oogoo
002OOol00?mooamoo`8000Qoo`8000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm00EFo@8000UF
o@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00MFo@03
001FoEKm00@0009Fo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00
008000EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00IFo@8000QFo@03001FoEKm00=Fo@<00003
E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm
00=Fo@05001FoEKm001Fo@030005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@06E_d20008E_d0
0`00Ool0002OOol00?mooaaoo`<000Qoo`8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03
001FoEKm009Fo@<0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07E_d01000E_d0
00001UKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P002EKm00<005KmE_d015Km0`002EKm
00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005Km
00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0P002EKm00<005Km
E_d00UKm00<005KmE_d00P002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00eKm
0`0000=Fo@00E_d025Km00<007oo0000WWoo003oOolJOol20008Ool30002E_d00`00E_eFo@07E_d0
1000E_d000001EKm00<005KmE_d01eKm00@005Km000000IFo@03001FoEKm00IFo@8000QFo@03001F
oEKm00IFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d0
05Km00UFo@03001FoEKm00<0009Fo@03001FoEKm00QFo@04001Fo@000005E_d00`00E_eFo@07E_d0
0`00E_d000020005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02
E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d01000E_d000001EKm00<0
05KmE_d01eKm00<005Km00000P001EKm00<005KmE_d01UKm1000WGoo003oOolGOol30008Ool20006
E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@02E_d300000eKm001F
o@08E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d01000E_d000001EKm00<005KmE_d01eKm00@0
05Km000000EFo@03001FoEKm00MFo@<000IFo@03001FoEKm00MFo@8000QFo@03001FoEKm00EFo@<0
00UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00QFo@04
001Fo@000005E_d00`00E_eFo@07E_d00`00E_d000020004E_d00`00E_eFo@07E_d20008E_d00`00
E_eFo@06E_d20009E_d00`00E_eFo@02E_d3000015Km001oo`00WGoo003oOolEOol20008Ool30009
E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d01000
E_d000001EKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00MFo@8000QFo@03001FoEKm
00IFo@8000QFo@03001FoEKm00=Fo@<00003E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km
00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@<0
00MFo@03001FoEKm00MFo@8000QFo@03001FoEKm00EFo@<0009Fo@03001FoEKm00=Fo@03001FoEKm
00=Fo@<00003E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001Fo@00008000EF
o@03001oo`0009aoo`00ogoo4Woo0`0000=oo`00Ool017oo0`000UKm00<005KmE_d025Km00@005Km
000000EFo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07E_d20008E_d00`00E_eFo@06
E_d20008E_d00`00E_eFo@03E_d300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@08
E_d00`00E_d000020005E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d30007
E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@03E_d3
00000eKm001Fo@08E_d00`00E_eFo@040002E_d01@00E_eFoEKm00001EKm00<005Km00000P001EKm
00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0P0025Km00@007ooOol009]oo`00
ogoo47oo0P001Goo00<007oo00000P001UKm00<005KmE_d01eKm0P0025Km00<005KmE_d01EKm0`00
25Km00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<0
05Km00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0P002EKm00<0
05KmE_d01EKm0P002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=F
o@00E_d02EKm00@005Km000000EFo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IF
o@<000MFo@04001FoEKm0005E_d20009E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d30000
0eKm001Fo@08E_d00`00Ool0002KOol00?moo`eoo`<000Ioo`<00003E_d005Km00MFo@03001FoEKm
00=Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@03001Fo@00008000EF
o@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<0
00UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00UFo@04
001Fo@000005E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0P0025Km00<005Km
E_d01UKm0P002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005Km00000UKm0`0000=Fo@00
E_d025Km00<005KmE_d010000UKm00<005KmE_d01eKm00<005Km00000P001EKm00<005KmE_d01UKm
00@007ooOol009Yoo`00ogoo2goo0P001Woo0`000eKm00<005Km000025Km00<005Km00000P001EKm
00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P002EKm00<005KmE_d015Km0`002EKm00<005Km
E_d00UKm0`0000=Fo@00E_d02EKm00<005KmE_d00`000UKm00<005KmE_d025Km00@005Km000000EF
o@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07E_d20008E_d00`00E_eFo@06E_d20008
E_d00`00E_eFo@03E_d300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00
E_d000020005E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d30007E_d00`00
E_eFo@06E_d20009E_d00`00E_eFo@04E_d300000goo001oo`2IOol00?moo`Qoo`<000Ioo`8000UF
o@03001FoEKm00EFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<0
009Fo@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm00QFo@04001Fo@000005E_d00`00
E_eFo@07E_d30006E_d00`00E_eFo@07E_d20008E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@03
E_d300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_d000020005E_d0
0`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@05E_d30008
E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d00`00
E_eFo@030002E_d01000Oomoo`00VGoo003oOol5Ool30006Ool30002E_d00`00E_eFo@06E_d00`00
E_eFo@02E_d30002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm00@005Km0000
00IFo@03001FoEKm00IFo@<000IFo@03001FoEKm00MFo@8000QFo@03001FoEKm00=Fo@<00003E_d0
05Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MF
o@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@8000UF
o@03001FoEKm00EFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<0
0003E_d0000000UFo@04001Fo@000005E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d0
1eKm0`001UKm00@007ooOol009Qoo`00ogoo0goo0P001goo0P001UKm00<005KmE_d01UKm00@005Km
000000IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00IFo@8000UFo@03001FoEKm009Fo@<00003
E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm
00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000UFo@03001F
oEKm00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d0
05Km00UFo@04001Fo@000005E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0P00
25Km00<005KmE_d01UKm0P0025Km00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<007oo0000V7oo
003oOol30007Ool20009E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@08
E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d01000E_d000001EKm00<005KmE_d01UKm00<005Km
00000P001EKm00<005KmE_d01UKm0P002EKm00<005KmE_d01EKm0P002EKm00<005KmE_d00UKm0`00
00=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00<005KmE_d00`000UKm00<005Km
E_d025Km00@005Km000000EFo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07E_d20008
E_d00`00E_eFo@05E_d30007E_d20005E_d300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm
001Fo@08E_d00`00E_d000020005E_d00`00E_eFo@06E_d00`00Ool0002GOol00?eoo`8000Moo`<0
009Fo@03001FoEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00
E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0P0025Km00<005KmE_d01EKm0P002EKm00<0
05KmE_d00UKm0`000UKm00<005KmE_d01UKm00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00@005Km
000000EFo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07E_d30006E_d00`00E_eFo@07
E_d20008E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_eF
o@040002E_d00`00E_eFo@05E_d01000E_d005Km0`001EKm00<005KmE_d01UKm00<005Km00000P00
1EKm00<005KmE_d01UKm0P0025Km00<005KmE_d01UKm0P0000=oo`00Ool0UGoo003jOol30007Ool2
0006E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@05E_d30008E_d0
0`00E_eFo@03E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@07E_d01000
E_d000001UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00MFo@8000QFo@03001FoEKm
00IFo@8000QFo@03001FoEKm00=Fo@<00003E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km
00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@<0
00MFo@03001FoEKm00AFo@04001Fo@000009E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d3
00000eKm001Fo@08E_d00`00E_eFo@02E_d3000015Km001oo`00UWoo003hOol20008Ool20009E_d0
0`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eF
o@040002E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d01000E_d000001UKm
00<005KmE_d01UKm0P002EKm00<005KmE_d015Km0`0025Km00<005KmE_d00eKm0`0000=Fo@00E_d0
1eKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005Km00000P001EKm00<005KmE_d01UKm00<0
05Km00000P001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P002EKm00<005KmE_d00UKm
0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d010000UKm00<0
05KmE_d01eKm00<005Km00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<007oo0000
UGoo003eOol30007Ool30002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm00@0
05Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<0
00UFo@03001FoEKm009Fo@<00003E_d005Km00UFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03
001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@8000UFo@03
001FoEKm00EFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@0000800003E_d005Km009F
o@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<000UFo@03001o
o`0009Aoo`00lgoo0P0027oo0P001UKm00<005KmE_d01UKm0P0025Km00<005KmE_d01UKm0P0025Km
00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`000UKm00<005KmE_d01eKm00<0
05KmE_d00`000UKm00<005KmE_d025Km00@005Km000000EFo@03001FoEKm00MFo@<000IFo@03001F
oEKm00IFo@8000UFo@03001FoEKm00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03
001FoEKm009Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00
008000EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00EFo@8000AFo@03001FoEKm009Fo@03001F
oEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0
009Fo@03001FoEKm00MFo@03001oo`0009Aoo`00l7oo0`001goo0`002EKm00<005KmE_d00UKm0`00
00=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00@005Km000000EFo@03001FoEKm
00MFo@04001Fo@000006E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@07E_d20008E_d00`00E_eF
o@03E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d00`00E_eFo@030002
E_d00`00E_eFo@08E_d01000E_d000001EKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm
00IFo@8000UFo@03001FoEKm00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001F
oEKm009Fo@<00003E_d005Km00=Fo@03001FoEKm009Fo@03001Fo@00008000EFo@03001FoEKm00IF
o@03001Fo@00008000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@800003Ool007oo099o
o`00kWoo0P000goo00@007ooOomoo`<0009Fo@03001FoEKm00QFo@04001Fo@000005E_d00`00E_eF
o@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@06E_d20009E_d00`00
E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_d00002
0005E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01eKm0`001UKm00<005KmE_d01eKm
0P0025Km00<005KmE_d01EKm0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00<005KmE_d0
0`000UKm00<005KmE_d025Km00@005Km000000EFo@03001FoEKm00MFo@04001Fo@000005E_d01@00
E_eFoEKm000015Km0P002EKm00<005KmE_d01EKm0P002EKm00<005KmE_d00UKm0`0000=Fo@00E_d0
25Km00<005KmE_d00UKm0`0000EFo@00Oomoo`00099oo`00jgoo0`001Woo0`001UKm00<005KmE_d0
1eKm0P0025Km00<005KmE_d015Km0`002EKm00<005KmE_d00UKm0`000UKm00<005KmE_d01UKm00<0
05KmE_d00UKm0`0000=Fo@00E_d02EKm00@005Km000000EFo@03001FoEKm00IFo@03001Fo@000080
00EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00EFo@8000QFo@03001FoEKm00=Fo@<00003E_d0
05Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MF
o@04001Fo@000005E_d00`00E_eFo@07E_d30006E_d00`00E_eFo@07E_d20008E_d00`00E_eFo@05
E_d30008E_d01@00E_eFo@00E_d00`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d0
25Km00<005Km00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<007oo0000TWoo003X
Ool30006Ool300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_eFo@03
0003E_d00`00E_eFo@07E_d01000E_d000001UKm00<005KmE_d01UKm00@005Km000000EFo@03001F
oEKm00MFo@8000QFo@03001FoEKm00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03
001FoEKm009Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00
008000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm00=Fo@<00003
E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm
00MFo@04001Fo@000005E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm0P002EKm
00<005KmE_d015Km0`002EKm00<007oo0000TGoo003VOol20007Ool20005E_d00`00E_eFo@06E_d0
0`00E_d000020005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@04
E_d30008E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@07
E_d01000E_d000001EKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@8000UFo@03
001FoEKm00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm
00IFo@<000MFo@03001FoEKm00IFo@800003E_d005Km00EFo@03001FoEKm00EFo@<000QFo@03001F
oEKm009Fo@<00003E_d005Km00UFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001oogoo002@
Ool00>=oo`<000Moo`8000QFo@03001FoEKm00EFo@8000UFo@03001FoEKm009Fo@<0009Fo@03001F
oEKm00IFo@03001FoEKm009Fo@<00003E_d005Km00UFo@03001FoEKm00<0009Fo@03001FoEKm00MF
o@03001Fo@00008000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm
00EFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00UFo@03001FoEKm00<0009Fo@03001FoEKm
00QFo@04001Fo@000005E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d20009
E_d00`00E_eFo@05E_d20009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d3
000015Km001Fo@001eKm00<005KmE_d010000UKm00<005KmE_d01eKm00@005Km000000EFo@03001F
oEKm00MFo@<000IFo@03001FoEKm00IFo@800003Ool007oo08moo`00hGoo0P001goo0`0000=Fo@00
E_d01eKm00<005KmE_d00UKm0`000UKm00<005KmE_d01eKm00@005Km000000IFo@03001FoEKm00IF
o@04001Fo@000005E_d00`00E_eFo@07E_d30006E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@02
E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@040002E_d0
0`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm0`001UKm00<005KmE_d01eKm0P0025Km
00<005KmE_d015Km0`002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`00
00=Fo@00E_d025Km00<005Km00000P001EKm00<005KmE_d01UKm00<005Km00000P001EKm0P001eKm
0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<005KmE_d0
0UKm0`0000EFo@00Oomoo`0008moo`00gWoo0`001goo0P001EKm00<005KmE_d01UKm00@005Km0000
00IFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm00=Fo@<00003E_d0
05Km00MFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07
E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d0
0eKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm
00<005KmE_d025Km00@005Km000000EFo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06
E_d20009E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eF
o@02E_d300000eKm001Fo@08E_d00`00E_d000020005E_d00`00E_eFo@06E_d01000E_d000001EKm
00@007ooOol008ioo`00g7oo0P0027oo0P0025Km00<005KmE_d015Km0`002EKm00<005KmE_d00UKm
0`0000=Fo@00E_d02EKm00<005KmE_d00`000UKm00<005KmE_d01eKm00<005Km00000P001EKm00<0
05KmE_d01UKm00@005Km000000IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00IFo@8000QFo@03
001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001Fo@00
008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm
00MFo@8000QFo@03001FoEKm00EFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00UFo@03001F
oEKm00<0009Fo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@000080
00EFo@03001FoEKm00IFo@8000QFo@03001FoEKm00IFo@8000QFo@03001oo`0008ioo`00fGoo0`00
1goo0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01eKm00@005Km000000EFo@03
001FoEKm00MFo@<000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<000UFo@03001FoEKm
009Fo@<00003E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@04001Fo@000005E_d0
0`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm0P002EKm00<005KmE_d01EKm0P002EKm
00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<005Km
E_d010000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00MFo@<000IFo@03001FoEKm
00IFo@8000UFo@03001FoEKm00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001F
oEKm009Fo@<00003E_d005Km00QFo@03001oo`0008eoo`00egoo0P0027oo0P001EKm00<005KmE_d0
1UKm0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<005Km
E_d00UKm0`000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<005KmE_d025Km00@005Km0000
00EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@8000QFo@03001FoEKm00EF
o@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00UF
o@04001Fo@000005E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d30007E_d0
0`00E_eFo@06E_d20008E_d00`00E_eFo@03E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d50009
E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d00`00
E_d000020005E_d00`00E_eFo@06E_d4002<Ool00=Aoo`<000Moo`<000QFo@03001FoEKm009Fo@<0
009Fo@03001FoEKm00IFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03
001FoEKm00IFo@04001Fo@000006E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@07E_d20008E_d0
0`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@040002E_d0
0`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00MF
o@8000QFo@03001FoEKm00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00IFo@04001Fo@000003E_d0
0`00E_d00008E_d30007E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@04E_d30009E_d00`00E_eF
o@02E_d3000015Km001oo`00S7oo003AOol30007Ool30002E_d00`00E_eFo@07E_d01000E_d00000
1UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00EFo@80
00UFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00=Fo@<00003E_d005Km00QFo@03
001FoEKm00<0009Fo@03001FoEKm00QFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00
E_eFo@06E_d20008E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d0
0`00E_eFo@030002E_d00`00E_eFo@08E_d01000E_d000001EKm00<005KmE_d01UKm00<005Km0000
0P001EKm00<005KmE_d01UKm0P0025Km00<005KmE_d01UKm0P001EKm00@005KmE_d000AFo@<00003
E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm
00MFo@03001Fo@00008000EFo@03001oo`0008]oo`00cgoo0P001goo0`001UKm00<005KmE_d01UKm
0P002EKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`000UKm00<005KmE_d01UKm00<005Km
E_d00UKm0`000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@03001Fo@000080
00EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00MFo@8000QFo@03001FoEKm009Fo@<00003E_d0
05Km00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MF
o@03001Fo@00008000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00MFo@8000QFo@03001FoEKm
00AFo@<000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km
00AFo@06001FoEKmE_d005Km0P001EKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IF
o@<000MFo@03001FoEKm00IFo@8000UFo@03001oo`0008Yoo`00c7oo0`0000=oo`00Ool00goo0`00
00=Fo@00E_d01eKm00<005KmE_d00UKm0`000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<0
05KmE_d01eKm00@005Km000000IFo@03001FoEKm00IFo@04001Fo@000006E_d00`00E_eFo@06E_d2
0008E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@03
E_d300000eKm001Fo@08E_d01000E_d000001EKm00<005KmE_d01eKm00@005Km000000EFo@03001F
oEKm00IFo@<000MFo@03001FoEKm00IFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03
001FoEKm00=Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001Fo@00
008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm009Fo@04001FoEKmE_d20008
E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d3
00000eKm001Fo@08E_d00`00Ool0002:Ool00<Yoo`8000Eoo`04001oo`000005E_d00`00E_eFo@06
E_d01000E_d000001UKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0P002EKm00<005KmE_d0
15Km0`002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d0
1eKm00@005Km000000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@8000QF
o@03001FoEKm00EFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<0
0003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001F
oEKm00IFo@<000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<000UFo@04001FoEKmE_d4
00000eKm001Fo@08E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005Km
E_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0P0000=oo`00Ool0R7oo0037Ool30007Ool2
0008E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02
E_d30002E_d00`00E_eFo@07E_d00`00E_eFo@030002E_d00`00E_eFo@08E_d01000E_d000001EKm
00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d015Km0`002EKm00<005Km
E_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d010000UKm00<005KmE_d01eKm00@005Km000000EF
o@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@04E_d30009
E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d00`00
E_eFo@030002E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d30007E_d00`00
E_eFo@06E_d20008E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d3000015Km001oo`00RGoo
0035Ool20007Ool300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@07E_d01000E_d0
00001EKm00<005KmE_d01UKm00@005Km000000IFo@03001FoEKm00IFo@<000IFo@03001FoEKm00MF
o@8000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00QF
o@03001FoEKm00<000=Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d0
0`00E_eFo@06E_d20008E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@09
E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d01000
E_d000001EKm00<005KmE_d01eKm0`001UKm00<005KmE_d01UKm0P000UKm00<005KmE_d015Km00<0
05KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`000UKm00<005KmE_d01eKm00<005Km00000P001EKm00<007oo0000R7oo0032Ool30007Ool20005
E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@04E_d30009E_d00`00
E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@03E_d300000eKm001Fo@08E_d01000E_d00000
1EKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@80
00QFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00IFo@03001FoEKm009Fo@<00003E_d005Km00QF
o@03001FoEKm00@0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07E_d30006E_d0
0`00E_eFo@06E_d20009E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@03E_d300000eKm001Fo@07
E_d00`00E_eFo@02E_d300001EKm001FoEKm00001UKm00<005Km00000P001EKm00<005KmE_d01UKm
00<005Km00000P001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0P002EKm00<007oo0000
Qgoo0030Ool20008Ool20008E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@06E_d00`00E_eFo@02
E_d300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@07E_d01000E_d000001EKm00<0
05KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0P0025Km00<005KmE_d01EKm0`0025Km
00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00@005Km
000000IFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06
E_d20008E_d00`00E_eFo@03E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@08
E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d01000
E_d000001EKm00<005Km00001UKm0P002EKm00<005KmE_d015Km0`002EKm00<005KmE_d00UKm0`00
00=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<007oo0000Qgoo002mOol30007
Ool300000eKm001Fo@08E_d01000E_d000001UKm00<005KmE_d01UKm00@005Km000000EFo@03001F
oEKm00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@<000UFo@03001FoEKm009F
o@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00
E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm0P002EKm00<005KmE_d015Km0`0025Km00<0
05KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005Km0000
0P001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IF
o@8000UFo@03001FoEKm00AFo@<000QFo@8000=Fo@<00003E_d005Km00QFo@03001FoEKm00@0009F
o@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eF
o@06E_d200000goo001oo`25Ool00;]oo`8000Qoo`8000EFo@03001FoEKm00IFo@8000UFo@03001F
oEKm00AFo@<000QFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00IFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02E_d30000
0eKm001Fo@09E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d0
1eKm00@005Km000000EFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0009F
o@03001FoEKm00MFo@@000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000UFo@03001F
oEKm00AFo@<000QFo@03001FoEKm009Fo@<00005E_d007ooOol00025Ool00;Qoo`<000Moo`<000QF
o@03001FoEKm009Fo@<0009Fo@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04
001Fo@000006E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005Km
E_d01UKm0P0025Km00<005KmE_d00UKm0`000UKm00<005KmE_d01UKm00<005KmE_d00UKm0`0000=F
o@00E_d025Km00<005KmE_d010000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00MF
o@<000IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00EFo@<000QFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@07
E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d0
0UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d010000UKm
00<005KmE_d01eKm00@005Km000000EFo@03001oo`0008Eoo`00]Goo0`001goo0`000UKm00<005Km
E_d01eKm00@005Km000000IFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@8000UFo@03001F
oEKm00AFo@<000QFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00IFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@04001Fo@000006E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm
0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d00eKm0`0000=Fo@00E_d01eKm00<005KmE_d0
0UKm0`0000=Fo@00E_d025Km00<005KmE_d010000UKm00<005KmE_d01eKm00@005Km000000EFo@03
001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm00EFo@<000QFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@04001Fo@000005E_d0
0`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0025Km
00<007oo0000Q7oo002cOol20007Ool30006E_d00`00E_eFo@06E_d20009E_d00`00E_eFo@02E_d3
00000eKm001Fo@07E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@07E_d00`00E_eFo@030002E_d0
0`00E_eFo@07E_d01000E_d000001UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IF
o@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00IFo@03001F
oEKm009Fo@<00003E_d005Km00QFo@03001Fo@00008000EFo@03001FoEKm00IFo@04001Fo@000005
E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@02E_d300000eKm001F
o@08E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d0
1000E_d000001EKm00<005KmE_d01UKm00<005Km00000P0015Km0P0025Km0P0025Km00<005KmE_d0
1EKm0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d0
25Km00<007oo0000Pgoo002`Ool30006Ool300000eKm001Fo@07E_d00`00E_eFo@02E_d30002E_d0
0`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000IFo@03001FoEKm00IF
o@<000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<0009F
o@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000006E_d00`00E_eF
o@06E_d01000E_d000001EKm00<005KmE_d01UKm0P002EKm00<005KmE_d015Km0`0025Km00<005Km
E_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00@005Km000000EF
o@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d20008
E_d00`00E_eFo@04E_d30007E_d00`00E_d00004E_d300000eKm001Fo@08E_d00`00E_eFo@040002
E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00
E_eFo@06E_d30023Ool00:ioo`8000Moo`8000EFo@03001FoEKm00IFo@04001Fo@000006E_d00`00
E_eFo@06E_d20008E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d0
0`00E_eFo@02E_d30002E_d00`00E_eFo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000
E_d000001UKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0P002EKm00<005KmE_d015Km0`00
25Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00<005KmE_d00`000UKm00<005KmE_d01eKm00@0
05Km000000EFo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d20008E_d00`00E_eF
o@05E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001F
o@08E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d01000E_d005Km0`001EKm00<005KmE_d01UKm
0`001eKm00<005KmE_d01EKm0P002EKm00<005KmE_d015Km0`002EKm00<005KmE_d00UKm0`0000AF
o@00Ool0089oo`00Zgoo10001Woo0P0025Km00<005KmE_d015Km0`002EKm00<005KmE_d00UKm0`00
00=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm
00IFo@04001Fo@000006E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30009E_d00`00E_eF
o@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@09E_d00`00E_eFo@030003
E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01eKm0`001UKm00<005KmE_d01UKm0P00
25Km00<005KmE_d01EKm0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d01000
0UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001F
oEKm00IFo@<000MFo@03001FoEKm00=Fo@@000UFo@03001FoEKm009Fo@<00003E_d005Km00QFo@04
001FoEKmE_d300000eKm001Fo@08E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d00`00E_d00002
0005E_d00`00Ool00021Ool00:Uoo`8000Aoo`03001oogoo00<0009Fo@03001FoEKm00IFo@03001F
oEKm00<000=Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eF
o@06E_d20008E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00
E_eFo@030002E_d00`00E_eFo@08E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EF
o@03001FoEKm00MFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm00=Fo@<00003E_d005Km
00MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@04
001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@04E_d3
0009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d0
0`00E_d000020005E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<0
05KmE_d01EKm0`002EKm0P00PGoo002VOol30007Ool20006E_d00`00E_eFo@05E_d30007E_d00`00
E_eFo@06E_d20008E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@06E_d00`00E_eFo@02E_d30000
0eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d0
1UKm0`001UKm00<005KmE_d01eKm0P0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00eKm0`00
00=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00<005Km00000P001EKm00<005Km
E_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03001F
oEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0
009Fo@03001FoEKm00MFo@03001Fo@00008000EFo@03001FoEKm00IFo@<0009Fo@05001FoEKmE_d0
0008E_d20009E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00
E_eFo@040002E_d00`00E_eFo@07E_d00`00Ool00020Ool00:Aoo`8000Moo`<000UFo@03001FoEKm
009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm009Fo@<00003E_d005Km00QFo@04001Fo@000006
E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P00
25Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00eKm0`0000=Fo@00E_d025Km00<0
05KmE_d00`000UKm00<005KmE_d01eKm00<005Km00000P001EKm00<005KmE_d01UKm0`001UKm00<0
05KmE_d01UKm0P002EKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km
00<005KmE_d00UKm0`0000=Fo@00E_d025Km00@005Km000000EFo@03001FoEKm00IFo@03001Fo@00
008000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm009Fo@<00003
E_d005Km009Fo@03001FoEKm009Fo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0
009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d2
00000goo001oo`1nOol00:5oo`<000Ioo`<000=Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0P002EKm00<005KmE_d015Km0`0025Km00<0
05KmE_d00UKm0`000UKm00<005KmE_d01UKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00@005Km
000000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm
00IFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@<00003E_d005Km
00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d00`00
E_d000020005E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d3
00000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_d000020005E_d01000
E_eFo@001EKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03
001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00004E_d007oo001oOol009moo`80
00Ioo`<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@@000MFo@03001FoEKm009Fo@<0
009Fo@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000006E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0P0025Km00<005KmE_d015Km0`002EKm00<0
05KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00@005Km0000
00EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d2
0008E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@03
0002E_d00`00E_eFo@07E_d00`00E_d000020005E_d00`00E_eFo@06E_d01000E_d000001EKm00<0
05KmE_d01UKm0P002EKm00<005Km000015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km
00<005KmE_d00UKm0`0000=Fo@00E_d025Km00@005Km000000EFo@03001FoEKm00IFo@03001Fo@00
008000EFo@03001oo`0007ioo`00W7oo0`001Goo0`000UKm00<005KmE_d01UKm00<005KmE_d00UKm
0`0000=Fo@00E_d025Km00<005KmE_d00`0015Km00<005KmE_d01EKm00@005Km000000IFo@03001F
oEKm00IFo@<000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01eKm0P0025Km00<005KmE_d015Km0`0025Km00<0
05KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`000eKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IF
o@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001Fo@00
00@0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d00`00E_d000020005E_d0
0`00E_eFo@06E_d20008E_d00`00E_eFo@04E_d30009E_d00`00Ool0001mOol009Uoo`<000Ioo`80
00IFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30008E_d00`00E_eFo@04E_d2
0009E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@07
E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm
00<005KmE_d01UKm0P0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00eKm0`0000=Fo@00E_d0
25Km00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00MFo@04001F
o@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02E_d30000
0eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@040002E_d00`00E_eF
o@07E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0025Km00<005Km
E_d015Km0`002EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005Km
E_d01eKm00@007oo000007aoo`00Ugoo0P001goo0P002EKm00<005KmE_d015Km0`0025Km00<005Km
E_d00UKm0`000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km0000
00EFo@03001FoEKm00IFo@04001Fo@000006E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d3
0008E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@06E_d00`00E_eFo@02E_d300000eKm001Fo@08
E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06E_d30006
E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02E_d300000eKm001F
o@08E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@0
05Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00EFo@<000QFo@03001FoEKm009Fo@<0
0003E_d0000000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001F
oEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@800003Ool0
07oo07]oo`00E7oo00I:DPQ200000248Li`4Ool015[F248003W><Woo0`001goo0P000UKm00<005Km
E_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000IFo@03001FoEKm00IFo@<0
00IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@@000QFo@03001FoEKm009Fo@<00003E_d0
05Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000006E_d00`00E_eFo@06E_d0
1000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`002EKm00<005KmE_d00UKm
0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d010000eKm00<0
05KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03
001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03
001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eF
o@02E_d300001EKm001oogoo0000Ngoo001DOol01PQ2@Q1oogoo>LhQ20=oo`06HaPHaW>LLi`@Q5:D
;goo0P0027oo0P001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`002EKm00<005KmE_d0
0UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`0015Km
00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@8000UF
o@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=F
o@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d0
1UKm0`0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005Km
E_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EF
o@03001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000MFo@8000IFo@<000UFo@03001FoEKm009F
o@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001Fo@00008000EFo@03
001FoEKm00IFo@04001Fo@000005E_d00`00Ool0001kOol005Uoo`06001oogooOolQ25:D0Woo00=B
U1S6Ool0:goo0`001goo0`0025Km00<005KmE_d00UKm0`000UKm00<005KmE_d01UKm00<005KmE_d0
0`000eKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@06E_d30008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d0
0`00E_eFo@02E_d30002E_d00`00E_eFo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000
E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d015Km0`00
25Km00<005KmE_d00UKm0`0000=Fo@00E_d02EKm00<005KmE_d00`000UKm00<005KmE_d01eKm00@0
05Km000000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@<000MFo@03001F
oEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm009Fo@<00003E_d0
05Km00MFo@80009Fo@<000=Fo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@<0
00IFo@03001FoEKm00IFo@8000UFo@03001FoEKm00AFo@<000QFo@03001oo`0007Yoo`00Bgoo1`00
1Woo00=cW000Ool00Woo00<007ooOol00Woo00<007ooOol0:7oo0P001goo0`000UKm00<005KmE_d0
1eKm00@005Km000000IFo@03001FoEKm00EFo@<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm
00AFo@<000QFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001F
oEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d000001UKm00<005KmE_d01UKm0`00
1eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm
0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EFo@03001F
oEKm00MFo@<000IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@<000UFo@03001FoEKm009F
o@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00
E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@05E_d40007E_d00`00E_eFo@04E_d30009E_d0
0`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eF
o@040002E_d00`00E_eFo@06E_d01000Oomoo`00NGoo001DOol01PQ2BU9oogoo>LhaS0=oo`03001o
ogoo009oo`03001oogoo02Eoo`<000Ioo`<000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm009F
o@80009Fo@03001FoEKm00IFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=F
o@03001FoEKm00IFo@04001Fo@000006E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06E_d20008
E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002
E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm
00IFo@<000IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00=Fo@<00003E_d005Km00MFo@03001F
oEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001Fo@000080
00EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@<000UFo@03
001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001Fo@00
008000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@05
E_d200000goo001oo`1hOol005Aoo`05000@Q000000aS004Ool00`00Oomoo`02Ool00`00Oomoo`0S
Ool20003Ool00`00Oomoo`030002E_d00`00E_eFo@05E_d00`00E_eFo@02E_d30002E_d00`00E_eF
o@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MF
o@03001FoEKm00EFo@8000UFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@<0
0003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eF
o@06E_d30006E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02E_d3
00000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_d000020005E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0P002EKm00<0
05KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`000UKm00<005KmE_d01eKm00<005Km00000P000UKm00@005KmE_d000QFo@<000IFo@03001FoEKm
00IFo@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@04001F
oEKmE_d300001EKm001oogoo0000N7oo001DOol00`00Oomoo`06Ool01R48DYAoogooDY@Q229oo`<0
00Ioo`8000IFo@03001FoEKm00EFo@04001Fo@000006E_d00`00E_eFo@06E_d20008E_d00`00E_eF
o@04E_d30008E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@06E_d00`00E_eFo@02E_d20002E_d0
0`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IF
o@<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@04001Fo@000005E_d0
0`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0P002EKm00<005KmE_d015Km0`0025Km
00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005Km
00000P001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm
00IFo@8000EFo@05001FoEKmE_d00004E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm
001Fo@08E_d00`00E_eFo@040002E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@06
E_d01000E_d000001EKm00@007ooOol007Moo`00E7oo00<007ooOol01Woo00IS61S6LiacW1S6HaPP
Ool20007Ool20009E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d0
0`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001UKm00<005KmE_d01UKm00@005Km0000
00EFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<0009Fo@03
001FoEKm00IFo@03001FoEKm009Fo@<00003E_d005Km00QFo@04001Fo@000005E_d00`00E_eFo@06
E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d0
15Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d010000UKm00<005KmE_d0
1eKm00@005Km000000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d20009E_d0
0`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d30000
0eKm001Fo@04E_d01P00E_eFoEKm001Fo@<000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@06E_d30007E_d00`00E_eFo@05E_d20009E_d00`00E_eFo@04E_d30008E_d00`00Ool0001g
Ool005Aoo`D000Eoo`04F]H8@PQ2HaPNOol30006Ool30002E_d00`00E_eFo@07E_d00`00E_eFo@03
0003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01EKm
0P002EKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`000UKm00<005KmE_d01eKm00@005Km000000IFo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@06E_d20008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@06
E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000
E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01UKm0P0025Km00<005KmE_d015Km0`00
25Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d010000UKm00<005KmE_d01eKm00@0
05Km000000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@02E_d01000E_eFoEKm0P00
2EKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00@005KmE_eFo@<0
0003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00IFo@04001oogoo001fOol007eoo`<0
00Moo`8000IFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<0
009Fo@03001FoEKm00IFo@03001FoEKm009Fo@80009Fo@03001FoEKm00MFo@03001FoEKm00<000=F
o@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06E_d20009
E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002
E_d00`00E_eFo@07E_d01000E_d000001UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm
00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001F
oEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005
E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@04E_d30008E_d01000
E_eFoEKm100000=Fo@00E_d025Km00<005KmE_d010000UKm00<005KmE_d01eKm00@005Km000000EF
o@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30000
0goo001oo`1eOol007]oo`8000Qoo`<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001F
oEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000006E_d00`00E_eFo@06E_d01000E_d000001EKm
00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`000UKm00<005Km
E_d01EKm00<005KmE_d00UKm0`000UKm00<005KmE_d01eKm00<005KmE_d00`000eKm00<005KmE_d0
1UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@8000UFo@03001FoEKm
00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm
00MFo@04001Fo@000005E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm
00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`00
00=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm
00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<0
0003E_d005Km00QFo@03001FoEKm00<0009Fo@04001oogoo001eOol007Qoo`<000Moo`<000=Fo@03
001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@05E_d20009E_d0
0`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d0
0`00E_eFo@07E_d01000E_d000001UKm00<005KmE_d01EKm00@005Km000000IFo@03001FoEKm00IF
o@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm
009Fo@<00003E_d005Km00UFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d0
0`00E_eFo@06E_d30006E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@05E_d30008E_d00`00E_eF
o@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm
00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`00
00=Fo@00E_d01EKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00UKm0`0000=Fo@00
E_d01eKm00<005KmE_d010000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@<0
00IFo@04001oogoo001dOol007Ioo`8000Moo`<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm
009Fo@<0009Fo@03001FoEKm00IFo@03001FoEKm009Fo@80009Fo@03001FoEKm00MFo@03001FoEKm
00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06
E_d20009E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eF
o@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03
001FoEKm00MFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MF
o@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00MFo@04001F
o@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@04E_d30009
E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_d00007E_d01000
E_d000001EKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01EKm0`001eKm00<005Km
E_d01EKm0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<007oo0000M7oo001cOol30006
Ool30002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001UKm
00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QF
o@03001FoEKm009Fo@<0009Fo@03001FoEKm00EFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00MF
o@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d0
0`00E_eFo@06E_d20008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@03E_d300000eKm001Fo@08
E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km
000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00EFo@<000QFo@03001FoEKm009Fo@<00003
E_d005Km00MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm
00IFo@03001Fo@00008000EFo@03001FoEKm00IFo@<000IFo@8000MFo@8000QFo@03001FoEKm00AF
o@<000UFo@04001FoEKmE_d300000eKm001Fo@08E_d00`00E_eFo@040002E_d00`00E_eFo@06E_d0
0`00E_d000020005E_d00`00E_eFo@06E_d00`00Ool0001cOol0075oo`8000Moo`8000IFo@03001F
oEKm00EFo@<000MFo@03001FoEKm00EFo@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000006E_d00`00
E_eFo@05E_d01000E_d000001UKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<0
05KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`000eKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d0
1UKm0P0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005Km
E_d010000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@04001Fo@000005E_d0
0`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@07
E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000
E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d01EKm0P002EKm00<005KmE_d015Km0`00
00=oo`00Ool03Woo00AJePQ2000icUmoo`00KWoo0`001goo0`0025Km00<005KmE_d00UKm0P000UKm
00<005KmE_d01UKm00<005KmE_d00UKm0P000UKm00<005KmE_d01eKm00<005KmE_d00`000eKm00<0
05KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@8000UFo@03
001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03
001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm
0`001eKm00<005KmE_d015Km100025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d0
0UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03
001FoEKm00IFo@<000MFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001Fo@00008000EF
o@03001FoEKm00EFo@03001Fo@00008000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00EFo@<0
00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@04001FoEKmE_d300000eKm001Fo@08E_d00`00
E_eFo@040002E_d00`00Ool0000>Ool01V<H6<IcW7>L48ABU5ioo`00K7oo0P001goo0`000eKm00<0
05KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d3
0007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@05E_d00`00E_eF
o@02E_d30002E_d00`00E_eFo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d00000
1EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0P0025Km00<005KmE_d015Km0`0025Km00<0
05KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`0015Km00<005KmE_d01UKm00@005Km0000
00EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d3
0008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d0
0`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<0
05KmE_d01UKm0P002EKm00<005KmE_d00eKm0`002EKm00<005KmE_d00UKm0`0000=Fo@00E_d01eKm
00<005KmE_d010000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@04001Fo@00
0005E_d00`00E_eFo@06E_d30007E_d00`00Ool0000=Ool01R48DYAoogooDY@HaUioo`00JGoo1000
1Goo0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`00
0UKm00<005KmE_d01UKm00<005KmE_d00`0015Km00<005KmE_d01EKm00@005Km000000IFo@03001F
oEKm00EFo@04001Fo@000006E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@03
0003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`0025Km00<005KmE_d015Km
0`0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@03001Fo@00008000EFo@03
001FoEKm00IFo@<000IFo@03001FoEKm00EFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MF
o@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<00004E_d005Km0008E_d00`00E_d0
00020005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@04E_d30008
E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00Ool0000<Ool00`00Oomoo`02Ool00`00Oomo
o`1LOol006Ioo`<000Aoo`03001oo`0000800003E_d005Km00QFo@03001FoEKm00<0009Fo@03001F
oEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000006E_d00`00E_eFo@05E_d3
0008E_d00`00E_eFo@04E_d20009E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm
001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<0009Fo@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001FoEKm00<000=F
o@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008
E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@040002
E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm
00IFo@<000AFo@04001FoEKm0006E_d30009E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005Km
E_d010000UKm00<005KmE_d01UKm00<005KmE_d010000UKm00<005KmE_d01eKm00@005Km000000EF
o@03001FoEKm00IFo@<000aoo`03001oogoo009oo`03001oogoo05aoo`00I7oo0P001goo0P001EKm
00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km100025Km00<005Km
E_d00UKm0P000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d0
0`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AF
o@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm
00<000=Fo@03001FoEKm00IFo@04001Fo@000006E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eF
o@030002E_d00`00E_eFo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_d000020005
E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@02E_d300000eKm001Fo@05E_d01000E_eFo@000UKm0`000eKm00<005KmE_d01UKm00@005Km
000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00EFo@<000MFo@03001FoEKm00EFo@<000QF
o@03001FoEKm009Fo@<00004E_d007oo000;Ool00`00Oomoo`02Ool00`00Oomoo`1LOol0065oo`<0
00Ioo`<0009Fo@03001FoEKm00=Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm00EFo@03001FoEKm
009Fo@<0009Fo@03001FoEKm00IFo@03001FoEKm00<000AFo@03001FoEKm00IFo@04001Fo@000005
E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d00`00E_eFo@03
0003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km
0`002EKm00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km
00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03
001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000UFo@04001FoEKmE_d300000eKm001Fo@08E_d0
0`00E_eFo@040002E_d00`00E_eFo@06E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d01000E_d0
00001EKm00<005KmE_d00eKm00<005KmE_d00`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d0
0UKm0`0000=Fo@00E_d025Km00@005KmE_eFo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03
001FoEKm00IFo@03001Fo@00008000EFo@03001oo`0000Yoo`068@QBU7ooOomBU248GWoo001OOol2
0006Ool30003E_d00`00E_eFo@06E_d01000E_d000001UKm00<005KmE_d01EKm00@005Km000000IF
o@03001FoEKm00EFo@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km
00MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04
001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d3
0008E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@07
E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03
001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02E_d30000
0eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d0
1UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000UFo@8000Yoo`06
HaPHaW>LLi`HaV<HGWoo001LOol30005Ool30007E_d00`00E_eFo@05E_d20009E_d00`00E_eFo@04
E_d30008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@07E_d00`00E_eFo@030002E_d00`00E_eF
o@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MF
o@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@<0
0003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000006E_d00`00E_eF
o@05E_d30007E_d00`00E_eFo@06E_d20008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d3
00000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005Km
E_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001F
oEKm009Fo@<00003E_d005Km00QFo@04001FoEKmE_d300000eKm001Fo@08E_d00`00E_eFo@040002
E_d00`00E_eFo@06E_d00`00E_d000030004E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06E_d2
0008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@03
0002E_d00`00E_eFo@07E_d3000:Ool015[F2488@V<HGgoo001JOol20006Ool20002E_d00`00E_eF
o@06E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06
E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0P0025Km00<005KmE_d0
15Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d0
1eKm00@005Km000000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d0
0`00E_eFo@04E_d30009E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@02E_d3
00000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005Km
E_d01UKm0`001UKm00<005KmE_d01UKm0P0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm
0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EFo@03001F
oEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30003E_d00`00
E_eFo@03E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@07
E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm
00<005KmE_d01UKm0P0000=oo`00Ool0Jgoo001GOol30006Ool20005E_d00`00E_eFo@06E_d01000
E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`00
00=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005Km
E_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@8000QFo@03001F
oEKm00AFo@@000MFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03
001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm
0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d0
0UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03
001FoEKm00IFo@<000IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@05001FoEKmE_d00005E_d00`00E_d00002
0005E_d00`00E_eFo@05E_d00`00E_d000020005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@05
E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d3000015Km001oo`00
K7oo001EOol20007Ool20008E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@02E_d30002E_d00`00
E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<0009Fo@03001FoEKm00EFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00IFo@03001FoEKm00<0
00AFo@03001FoEKm00EFo@04001Fo@000006E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@06E_d2
0008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@03
0002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001F
oEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03
001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@00
0005E_d00`00E_eFo@06E_d30006E_d01000E_eFo@001EKm0P002EKm00<005KmE_d00eKm0`002EKm
00@005KmE_eFo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00IFo@03001Fo@00
008000EFo@03001FoEKm00EFo@03001Fo@00008000EFo@03001oo`0006]oo`00DWoo0`001Woo0`00
0UKm00<005KmE_d01UKm00<005KmE_d00`0015Km00<005KmE_d01EKm00@005Km000000IFo@03001F
oEKm00EFo@<000MFo@03001FoEKm00EFo@8000QFo@03001FoEKm00AFo@@000MFo@03001FoEKm009F
o@<0009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000006E_d0
0`00E_eFo@05E_d01000E_d000001UKm00<005KmE_d01EKm0`0025Km00<005KmE_d015Km0`0025Km
00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<0
05KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001F
oEKm00IFo@8000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03
001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d00000
1EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00
E_d01eKm00<005Km00000UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00EFo@8000UFo@03001FoEKm00=F
o@<000UFo@03001oo`0006Yoo`00D7oo0P001goo0P001UKm00<005KmE_d01EKm0`0025Km00<005Km
E_d015Km0`0025Km00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00UKm0P000UKm
00<005KmE_d01UKm00<005KmE_d00`0015Km00<005KmE_d01EKm00@005Km000000IFo@03001FoEKm
00EFo@<000MFo@03001FoEKm00EFo@8000UFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80
009Fo@03001FoEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<0
05KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IF
o@8000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm
00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d40005E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d01000E_eF
oEKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00<007oo0000JWoo001=
Ool30007Ool30008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@07E_d00`00E_eFo@030003E_d0
0`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EF
o@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001F
oEKm009Fo@80009Fo@03001FoEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@00
0005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@04E_d30008E_d0
0`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d0
00001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AF
o@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@<00003E_d005Km00QF
o@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d0
0`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d50008E_d00`00E_eFo@02E_d300000eKm001Fo@08
E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km
000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00EFo@<00003Ool007oo06Qoo`00BWoo0`00
1goo0`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm
00AFo@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00MFo@03
001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d00000
1EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00
E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm00AF
o@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IF
o@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<0
05KmE_d01EKm0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<0
05KmE_d01eKm1P000UKm0P0025Km00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm
00EFo@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001F
oEKm00@0009Fo@04001oogoo001XOol004Qoo`8000=oo`04001oogooOol30007E_d00`00E_eFo@04
E_d40007E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@07
E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm
00<005KmE_d015Km0`0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d0
25Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IF
o@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km
00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04
001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@04E_d3
0008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@040002E_d00`00E_eFo@07E_d0
1000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km1@001UKm0P001UKm0`0025Km
00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d010000UKm00<005KmE_d01UKm00<005Km
E_d010000UKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01EKm0`001eKm00<007oo
0000J7oo0015Ool30006Ool30002E_d00`00E_eFo@06E_d00`00E_eFo@030004E_d00`00E_eFo@05
E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0`001eKm00<005KmE_d0
15Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d0
1eKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MF
o@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@<0
0003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eF
o@06E_d30006E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d3
00000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d00`00E_eFo@030002E_d00`00
E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@05E_d30008E_d0
0`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@0500000eKm001Fo@07E_d200000eKm0000
00020002E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@05E_d30007E_d00`00E_eF
o@05E_d30007E_d00`00E_eFo@04E_d30009E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<007oo
0000Igoo0013Ool20007Ool20006E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@04E_d20008E_d0
0`00E_eFo@02E_d30002E_d00`00E_eFo@05E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@06E_d0
0`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<0
05KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km
00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IFo@04001Fo@00
0005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm
001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06
E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0`001UKm00<005KmE_d0
15Km0`002EKm00@005KmE_eFo@<00003E_d005Km00QFo@03001FoEKm00@0009Fo@03001FoEKm00IF
o@03001Fo@00008000EFo@03001FoEKm00EFo@D000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm
00AFo@<000UFo@04001FoEKmE_d300000eKm001Fo@08E_d01000E_eFoEKm0`0000=Fo@00E_d025Km
00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@800003Ool0
07oo06Eoo`00@7oo0`001goo0`0025Km00<005KmE_d00UKm0P000UKm00<005KmE_d01eKm00<005Km
E_d00`000UKm00<005KmE_d01UKm00@005Km000000IFo@03001FoEKm00EFo@04001Fo@000006E_d0
0`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@02E_d30002E_d00`00E_eF
o@05E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d0
1000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0P0025Km00<005KmE_d015Km
0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm
00@005Km000000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00
E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm
001Fo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm
0`001eKm00<005KmE_d01EKm0P002EKm00@005KmE_eFo@D000UFo@04001FoEKmE_d300000eKm0000
0008E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm00@0
05Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<0
0004E_d007oo001VOol003moo`8000Ioo`<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@06E_d30006E_d00`00E_eFo@05E_d20009E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02
E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030004E_d00`00E_eFo@05E_d01000E_d000001UKm
00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QF
o@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001F
oEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eF
o@06E_d20008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00
E_eFo@030002E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@05E_d00`00E_d00002
0005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm
001Fo@08E_d01000E_eFoEKm0`0000=Fo@00E_d025Km1P000eKm00<005KmE_d01UKm00@005Km0000
00EFo@8000MFo@<000IFo@03001FoEKm00IFo@8000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000005E_d0
0`00Ool0001UOol003moo`03001oo`00009oo`<000MFo@03001FoEKm00AFo@@000MFo@03001FoEKm
009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@80009Fo@03001FoEKm00MFo@03001FoEKm00<0
00=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@04E_d2
0009E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@06E_d00`00E_eF
o@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03
001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MF
o@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001F
o@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@03E_d30009
E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km
000000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d40007E_d00`00E_eFo@04
E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001Fo@08
E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm
00<005KmE_d01EKm0`0025Km0P00IGoo000oOol00`00Ool000020002E_d00`00E_eFo@06E_d00`00
E_eFo@030004E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EF
o@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001F
oEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm00EF
o@04001Fo@000006E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@04
E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06
E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03
001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03
001FoEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm100000=F
o@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00IF
o@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02
E_d300000eKm001Fo@07E_d00`00E_eFo@040002E_d00`00E_eFo@06E_d00`00Ool0001TOol003mo
o`8000IFo@03001FoEKm00EFo@<000QFo@03001FoEKm00AFo@8000QFo@03001FoEKm00AFo@@000MF
o@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001F
o@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008
E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d0
0`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<0
05KmE_d015Km0`0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km
00<005KmE_d00`000eKm00<005KmE_d01EKm00<005Km00000P001EKm00<005KmE_d01EKm0`001UKm
00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d0
25Km00<005KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm1000
1EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01EKm0`0025Km00<005KmE_d015Km0`0025Km00<0
05KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d010000UKm00<005KmE_d01UKm00<005Km0000
0P001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d01EKm0P0000=oo`00Ool0HWoo000nOol20008
E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d0
0`00E_eFo@030004E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<0
05KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=F
o@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EF
o@<000IFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm
00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d20009E_d01000E_eF
oEKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm
00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@<000MF
o@03001FoEKm009Fo@D000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00@0009F
o@8000MFo@03001FoEKm00@0009Fo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00EF
o@<000MFo@03001FoEKm00AFo@<000UFo@04001FoEKmE_d300000eKm001Fo@08E_d01000E_eFoEKm
0`0000AFo@00Ool006=oo`00?Woo00<007oo000025Km00@005Km000000EFo@03001FoEKm00IFo@<0
00IFo@03001FoEKm00EFo@<000QFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@<0009Fo@03
001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06
E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d0
0UKm0P000UKm00<005KmE_d01EKm00<005KmE_d00UKm0`000UKm00<005KmE_d01UKm00<005KmE_d0
0`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IF
o@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm
00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d000001EKm00<0
05KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm
00<005KmE_d00UKm0`0000=Fo@00E_d025Km1P000UKm00<005KmE_d01UKm00<005Km00000P001EKm
00<005KmE_d01EKm0`001eKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`002EKm00@005Km
E_eFo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@04001Fo@000005E_d0
0`00E_eFo@06E_d01000E_d000001EKm00<007oo0000HWoo000nOol01000Oomoo`001UKm10001eKm
00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0P000UKm00<005KmE_d01eKm00<0
05KmE_d00`000eKm00<005KmE_d01EKm00@005Km000000IFo@03001FoEKm00EFo@<000MFo@03001F
oEKm00AFo@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03
001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d01000E_d00000
1UKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00
E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm00AF
o@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IF
o@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d015Km1@001UKm00<0
05KmE_d015Km0`002EKm00@005KmE_eFo@<00003E_d005Km00QFo@04001FoEKmE_d300000eKm001F
o@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`00
1UKm00<005KmE_d01EKm0`0025Km00<005KmE_d015Km0`0025Km00<007oo0000HGoo000_Ool015[F
248003W>2goo00D007ooOomoo`00009Fo@<000AFo@03001FoEKm00EFo@04001Fo@000005E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<0
05KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00<005Km
E_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm
00AFo@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03
001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d00000
1EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00
E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm00AF
o@<000QFo@03001FoEKm00D00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04
001Fo@000005E_d00`00E_eFo@06E_d40005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d3
0008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@040002E_d00`00E_eFo@06E_d0
0`00E_eFo@040002E_d00`00E_eFo@06E_d00`00Ool0001QOol002ioo`06HaPHaW>LLi`@Q5:D2Woo
00<007ooOol00Woo0P0025Km00<005KmE_d015Km0`001eKm00<005KmE_d015Km10001eKm00<005Km
E_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EF
o@03001FoEKm00EFo@<000MFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000QFo@03001F
oEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001FoEKm00<0
00=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d3
0008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@03
0003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d01UKm
0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm1@001EKm00<005KmE_d0
1EKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d015Km10001eKm00<005KmE_d00UKm0`00
00=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<005Km00000P001EKm00<005Km
E_d01EKm0`001eKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`0000=oo`00Ool0Ggoo000^
Ool01R48DYAoogooDY@HaPYoo`03001oogoo00=oo`03001FoEKm00MFo@03001FoEKm00<000=Fo@03
001FoEKm00EFo@03001FoEKm00<000AFo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00
E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d0
00001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km
00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00<0
05KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001F
oEKm00AFo@<000QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@02E_d300000eKm001F
o@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`00
1UKm00<005KmE_d01UKm0`001UKm00<005KmE_d00eKm10002EKm00@005KmE_eFo@<00003E_d005Km
00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@8000QFo@04001Fo@00
0005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d30009E_d01000E_eFoEKm0`0000=Fo@00
E_d025Km00@005KmE_eFo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@04001oogoo001OOol0
02ioo`03001oogoo009oo`03001oogoo00Moo`04001oo`000004Ool00`00E_eFo@06E_d30007E_d0
0`00E_eFo@04E_d30008E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d30002E_d00`00E_eF
o@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm00@0
05Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@@000MFo@03001FoEKm009Fo@<0
0003E_d005Km00MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001F
oEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00
E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<0
00MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009F
o@<00003E_d005Km00MFo@03001Fo@0000<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@06E_d30007E_d00`00E_eFo@04E_d40006E_d20006E_d30008E_d00`00E_eFo@02E_d30000
0eKm001Fo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d0
1UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001oo`0005moo`00;Woo00<007ooOol0
0Woo00<007ooOol01goo0P001goo00<005KmE_d00UKm0`000UKm00<005KmE_d01UKm00<005KmE_d0
0`000UKm00<005KmE_d01eKm00<005KmE_d00`000eKm00<005KmE_d01EKm00@005Km000000IFo@03
001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm
009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<000AFo@03001FoEKm00EFo@04001Fo@000005
E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`00
25Km00<005KmE_d00UKm0P0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00<0
05KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001F
oEKm00AFo@<000QFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03
001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d00`00E_d00002
0005E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm
001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d200000eKm000000020002E_d00`00E_eF
o@06E_d00`00E_d000020005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d3001NOol002ioo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo00Moo`04001Fo@000006E_d00`00E_eFo@05E_d30006E_d0
0`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d20002E_d00`00E_eF
o@06E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d0
1000E_d000001EKm00<005KmE_d01EKm0`0025Km00<005KmE_d015Km0`001eKm00<005KmE_d015Km
0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm
00@005Km000000AFo@03001FoEKm00IFo@<000IFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AF
o@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00MF
o@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d0
0`00E_eFo@04E_d30008E_d00`00E_eFo@03E_d30009E_d00`00E_eFo@0400000eKm001Fo@08E_d0
0`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<0
05KmE_d01EKm0`001eKm00<005KmE_d015Km0`002EKm00@005KmE_eFo@<00003E_d005Km00QFo@03
001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00@0009Fo@03001FoEKm00IFo@03001Fo@00
008000EFo@03001FoEKm00EFo@800003Ool007oo05aoo`00;Woo00HQ25:DOomooe:D8@P9Ool00`00
Oomoo`08Ool20008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@05E_d00`00E_eFo@02E_d30000
0eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d0
1EKm0`001UKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0P00
0UKm00<005KmE_d01eKm00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<0
05KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000MFo@03
001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm
00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d40005E_d00`00E_eF
o@06E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d01000
E_eFoEKm0`0000=Fo@00000025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EF
o@03001FoEKm00IFo@<000IFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000UFo@04001F
oEKmE_d3000015Km001oo`00GGoo000^Ool01V<H6<IcW7>L6<IS60Uoo`03001oogoo00Yoo`03001F
oEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm0`00
1eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0P000UKm00<005KmE_d01EKm00<005KmE_d0
0UKm0`000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EF
o@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000QFo@03001F
oEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005
E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`00
25Km00<005KmE_d00UKm0P0000=Fo@00E_d01eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<0
05KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001F
oEKm00AFo@@000MFo@03001FoEKm009Fo@D000QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03
001FoEKm00<0009Fo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00EFo@04001Fo@00
0005E_d20007E_d30006E_d00`00E_eFo@05E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07
E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km
000000EFo@03001oo`0005aoo`00;goo00AJePQ2249S60Yoo`03001oogoo00]oo`03001FoEKm00AF
o@<000QFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@<0009Fo@03001FoEKm00IFo@03001F
oEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d01000E_d000001UKm
00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d0
25Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@0
05Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<0
00QFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04
001Fo@000004E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005Km
E_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005Km
E_d01eKm1P000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001F
oEKm00AFo@<000UFo@03001FoEKm00=Fo@<000QFo@8000=Fo@<00003E_d005Km00MFo@03001FoEKm
00@0009Fo@03001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00EFo@04001Fo@000005E_d0
0`00E_eFo@06E_d30006E_d00`00E_eFo@05E_d30008E_d00`00Ool0001KOol003eoo`03001oogoo
00aoo`03001FoEKm00<000=Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04
001Fo@000006E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@04E_d3
0008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06
E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01EKm0`001eKm00<005KmE_d0
15Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d0
1EKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000MF
o@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km
00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30006
E_d00`00E_eFo@04E_d50007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001F
o@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@07E_d0
1000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`002EKm00<005KmE_d00eKm
0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d010000UKm00<005KmE_d01UKm
00<007oo0000Fgoo000lOol01000Ool000003Goo0P001eKm00<005KmE_d015Km10001eKm00<005Km
E_d015Km0`0025Km00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<0
05KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EF
o@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm
009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005
E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@03
0003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km
0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@04001FoEKmE_d400000eKm001Fo@08E_d00`00
E_eFo@030002E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@05E_d30007E_d00`00
E_eFo@04E_d40006E_d00`00E_eFo@05E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<0
05KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km0000
00EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<00003Ool007oo05Uoo`00?7oo0P0047oo
00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005Km
E_d01UKm00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@@000MFo@03001F
oEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03
001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm
0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d0
0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001F
oEKm00IFo@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@06E_d40005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d30009E_d01000E_eFoEKm
0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d010000UKm0P00
1eKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00EFo@@000IFo@03001FoEKm
00EFo@<000QFo@04001FoEKmE_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d01000Oomoo`00
FGoo000lOol00`00Oomoo`0@Ool00`00E_eFo@05E_d30007E_d00`00E_eFo@05E_d30007E_d00`00
E_eFo@04E_d30008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d0
0`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d0
1EKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0P00
0UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001F
oEKm00IFo@<000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001FoEKm00<000=Fo@03
001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d30008E_d0
0`00E_eFo@02E_d50008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030003E_d0
0`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01EKm0`001eKm
0P001EKm0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d010000UKm00<005Km
E_d01UKm00<005KmE_d010000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<0
00IFo@03001oo`0005Uoo`00?7oo00<007ooOol04Goo00<005KmE_d00UKm0P000UKm00<005KmE_d0
1UKm00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AF
o@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm
00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007
E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@06E_d00`00E_eFo@02E_d3
00000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005Km
E_d01EKm0`001UKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm
0`0000=Fo@00E_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm1P000eKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<00003E_d005Km00MFo@04001FoEKmE_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00
E_eFo@07E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d01EKm0`001eKm00<0
05KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<007oo0000F7oo000lOol0
0`00Oomoo`0BOol01000E_d000001EKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EF
o@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001F
oEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@00
0005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30008E_d0
0`00E_eFo@02E_d200000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d0
00001EKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AF
o@<000QFo@03001FoEKm009Fo@800003E_d005Km00MFo@03001FoEKm009Fo@<00003E_d005Km00QF
o@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d0
0`00E_eFo@03E_d50007E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km
00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm00EFo@04001Fo@00
0005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@05E_d30008E_d01000E_eFoEKm0`0000=Fo@00
E_d025Km00@005KmE_eFo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03
001Fo@00008000EFo@03001FoEKm00EFo@800003Ool007oo05Ioo`00?7oo00<007ooOol04goo0P00
1eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d0
0`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@05E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06
E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000
E_d0000015Km00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d015Km0P00
25Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@0
05Km000000AFo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eF
o@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005Km00000`000UKm00<005KmE_d0
1eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IF
o@03001FoEKm00EFo@<000QFo@03001FoEKm00=Fo@<000QFo@03001FoEKm009Fo@<00003E_d00000
00MFo@03001FoEKm00@0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d01000
E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km0`002EKm00@005KmE_eFo@<00004
E_d007oo001GOol003]oo`03001oogoo01Ioo`03001FoEKm00EFo@03001FoEKm00<000=Fo@03001F
oEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00
E_eFo@04E_d30008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d0
0`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km10001eKm
00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm
00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm
00IFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<0
0003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eF
o@05E_d40006E_d00`00E_eFo@05E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d3
00000eKm001Fo@07E_d00`00E_eFo@040002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`0025Km00<0
05KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<0
05KmE_d01eKm00@005Km000000EFo@03001oo`0005Ioo`00>goo00<007ooOol05goo00<005KmE_d0
15Km0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<0
05KmE_d00`0015Km00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km0000
00EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03
001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00MFo@03001FoEKm00<000=Fo@03001FoEKm
00EFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d40006E_d00`00E_eF
o@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eF
o@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`00
1UKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@@00003E_d005Km00MFo@03001FoEKm00@0009F
o@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eF
o@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`00
00=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<005Km
E_d01UKm00<005Km00000P001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d01EKm0`0025Km00<0
07oo0000EGoo000kOol3000HOol00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003
E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`0025Km00<005KmE_d015Km0`00
1eKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d0
0`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00IF
o@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm
00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d0
0`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30008E_d00`00E_eF
o@02E_d300000dEA001Fo@07E_d00`00E_eFo@030003AE400`00E_eFo@06E_d40005E_d00`00E_eF
o@05E_d30007E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`00
00=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<005Km
E_d01UKm10001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d01EKm10001UKm00<005KmE_d015Km
0`002EKm00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00@0009Fo@03001FoEKm00IFo@03
001oo`0005Eoo`00>goo00<007ooOol06Goo0P001eKm00<005KmE_d015Km0`001eKm00<005KmE_d0
15Km10001eKm00<005KmE_d00UKm0P000UKm00<005KmE_d01eKm00<005KmE_d00`000eKm00<005Km
E_d01EKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EFo@<0
00MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00EFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d0
0`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d30008E_d00`00E_eF
o@02E_d300000eKm001Fo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030003
AE400`00E_eFo@06E_d01000E_d000001DEA00<005KmE_d01EKm0`001dEA00<005KmE_d00eKm1000
25Km00@005KmE_eFo@<00003E_d005Km00QFo@04001FoEKmE_d300000eKm001Fo@08E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d0
1EKm10001UKm00<005KmE_d015Km10001eKm00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005Km
E_d010000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EF
o@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<00003Ool007oo05=oo`00>goo00<007ooOol0
6Woo00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`0015Km00<0
05KmE_d01EKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000MFo@03
001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<000=F
o@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d0
1UKm0`001eKm00<005KmE_d015Km0P0025Km00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005Km
E_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EF
o@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@@000M5D@03001FoEKm00AFo@<000Q5D@04001F
oEKmE_d300000dEA0015D@08AE400`00E_d000030003E_d00`00E_eFo@05E_d01000E_d000001EKm
00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@<000QF
o@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00@0009Fo@03001FoEKm00IFo@03001F
oEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@05E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005Km
E_d00`000UKm00<007oo0000E7oo000kOol00`00Oomoo`0KOol00`00E_eFo@05E_d30006E_d00`00
E_eFo@05E_d30008E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d0
0`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d0
00001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`0025Km00<005KmE_d015Km0P0025Km
00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km
000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000QF
o@03001FoEKm009Fo@800003E_d005Km00QFo@03001FoEKm00<00095D@030015DDEA00M5D@03001F
oEKm00<00095D@030015DDEA00I5D@04001Fo@000004AE400`00AE55D@06AE440007E_d00`00E_eF
o@04E_d20008E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00
E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005Km
E_d01EKm0`001eKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km00QFo@03001F
oEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00@0009Fo@03001FoEKm00IFo@04001Fo@000005
E_d00`00E_eFo@06E_d30006E_d00`00Ool0001COol003Yoo`03001oogoo01eoo`03001FoEKm009F
o@80009Fo@03001FoEKm00EFo@03001FoEKm009Fo@80009Fo@03001FoEKm00MFo@03001FoEKm00<0
00=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d3
0007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d200000eKm001Fo@08E_d00`00E_eFo@03
0003E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<0
05KmE_d01UKm0`001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`0000=Fo@00E_d01eKm
00<005KmE_d00UKm0P0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km
000000AFo@03001FoEKm00IFo@<000E5D@030015DDEA00Q5D@8000E5D@030015DDEA00M5D@030015
DDEA00A5D@030015DDEA00=5D@<00095D@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm
00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007
E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00@005KmE_eFo@<00003
E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06
E_d30006E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d30000
0eKm001Fo@07E_d00`00Ool0001BOol003Yoo`03001oogoo01ioo`04001Fo@000005E_d00`00E_eF
o@05E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`001eKm00<005Km
E_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`00
0eKm00<005KmE_d01UKm00@005Km000000AFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@@0
00IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<0
00=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d0000015Km00<005Km
E_d01UKm0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=5D@00AE401DEA00<0
04EAAE4024EA00<004EAAE4014EA00<004EAAE401dEA00<004EAAE4014EA00<004EAAE400`001DEA
0P0025Km0`001UKm00<005KmE_d015Km10001eKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<0
0003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eF
o@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km0`0025Km00<005Km
E_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d00`00
0UKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01EKm0`00DWoo000jOol00`00Oomo
o`0OOol00`00E_eFo@06E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d300000eKm001Fo@08
E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm
00<005KmE_d015Km0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=Fo@00E_d0
25Km00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@0
05Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm00AFo@<0
00MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04
001Fo@000004AE400`00AE55D@04AE400`00AE55D@08AE400`00AE55D@04AE400`00AE55D@07AE40
0`00AE55D@04AE430008AE400`00O/h00004E_d300000dEA001Fo@07E_d00`00E_eFo@030003E_d0
0`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d0
1UKm0`001UKm00<005KmE_d015Km0`0025Km00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0`00
00=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km000000EFo@03001FoEKm
00EFo@<000IFo@03001FoEKm00EFo@@000IFo@03001FoEKm00AFo@<000UFo@04001FoEKmE_d30000
15Km001oo`00DGoo000jOol3000POol00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@05
E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d0
0UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm
00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000MF
o@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<0
00=Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00
E_eFo@06E_d30006E_d00`00E_eFo@04E_d30006AE400`00AE55D@04AE400`00AE55D@08AE400`00
AE55D@04AE400`00AE55D@07AE401000AE55DDEA10002TEA00D007k>O/h005Km008000E5D@03001F
oEKm00EFo@<000MFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03
001FoEKm00IFo@03001Fo@00008000EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00EFo@<000QF
o@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@040002E_d00`00E_eFo@06E_d00`00E_eF
o@030002E_d00`00E_eFo@07E_d01000E_d000001EKm00<007oo0000D7oo000jOol00`00Oomoo`0Q
Ool00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d300000eKm001F
o@08E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm0`00
1UKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=Fo@00
E_d025Km00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@@000MFo@03001FoEKm00AF
o@8000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<00095D@030015DDEA00A5
D@030015DDEA00A5D@030015DDEA00Q5D@030015DDEA00A5D@030015DDEA00M5D@@000=5D@030015
DDEA00Q5D@05001ncWk>O/h00008AE401000E_eFoEKm0`0000=Fo@00E_d025Km00<005KmE_d00`00
0UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001F
oEKm00EFo@<000MFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000UFo@04001FoEKmE_d3
00000eKm001Fo@07E_d00`00E_eFo@040002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005Km
E_d01EKm0`001eKm00<005KmE_d01EKm0`001UKm00<005KmE_d01EKm0`0025Km0P00D7oo000jOol0
0`00Oomoo`0ROol00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eF
o@05E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`001eKm00<005Km
E_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00UKm0P0000=Fo@00E_d025Km00<005KmE_d00`00
0eKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<0
00MFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@800003E_d005Km00QFo@03001FoEKm00<0
00=Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@05E_d30005AE400`00AE55D@04AE400`00AE55D@04AE400`00AE55D@08AE400`00AE55D@04
AE400`00AE55D@06AE420006AE400`00AE55D@08AE401@00O/incWk>000024EA00@005Km000000EF
o@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm00AFo@<000QFo@04001F
oEKmE_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030003
E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`00
25Km00@005KmE_eFo@<00003E_d005Km00QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eF
o@040002E_d00`00E_eFo@06E_d00`00Ool0001?Ool003Yoo`03001oogoo02=oo`8000MFo@03001F
oEKm00AFo@@000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03
001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@06E_d01000E_d00000
15Km00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=Fo@00
E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm
00@005Km000000AFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AF
o@<000QFo@03001FoEKm009Fo@800003E_d004EA00E5D@030015DDEA00A5D@030015DDEA00A5D@03
0015DDEA00Q5D@030015DDEA00A5D@030015DDEA00=5D@<00003AE4004EA00E5D@030015DDEA00Q5
D@05001ncWk>O/h00009AE400`00E_eFo@06E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00
E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d00000
1EKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km10001eKm00<005KmE_d015Km0`0025Km00@0
05KmE_eFo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005
E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`00
00=oo`00Ool0CGoo000iOol00`00Oomoo`0UOol00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00
E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm
0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=F
o@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00IF
o@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@<00003
E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm
00IFo@04001Fo@000003E_d00`00AE55D@04AE400`00AE55D@04AE400`00AE55D@04AE400`00AE55
D@08AE400`00AE55D@04AE400`00AE55D@030004AE400`00AE55D@04AE400`00AE55D@08AE401@00
O/incWk>00002DEA0P0025Km00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AF
o@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm
00<0009Fo@03001FoEKm00MFo@03001FoEKm00<0009Fo@8000MFo@04001Fo@000005E_d00`00E_eF
o@06E_d30006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`00
00=Fo@00E_d025Km00<005KmE_d00`000UKm00<007oo0000CWoo000iOol00`00Oomoo`0VOol00`00
E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02
E_d300000eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d0
0`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005KmE_d015Km0`001eKm
00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm00<005Km
E_d00`000eKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm
00AFo@@000MFo@03001FoEKm00AFo@<000EFo@030015DDEA00A5D@030015DDEA00A5D@030015DDEA
00A5D@030015DDEA00Q5D@030015DDEA00A5D@<000M5D@030015DDEA00A5D@030015DDEA00Q5D@05
001ncWk>O/h00009AE400`00O/h00006E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<0
05KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km0000
00EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00EFo@@000IFo@8000EFo@<000QFo@03001FoEKm
009Fo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00@0009F
o@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00Ool0001=Ool003Uo
o`03001oogoo02Moo`03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03
001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@06
E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d30000
0eKm001Fo@08E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d0
1EKm0`001eKm00<005KmE_d015Km10001eKm00<005KmE_d015Km0P0025Km00<005KmE_d00UKm0`00
00=Fo@00E_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005Km
E_d00UKm00<004EAAE4014EA00<004EAAE4014EA00<004EAAE4014EA00<004EAAE4024EA00@004EA
AE55D@@000U5D@030015DDEA00A5D@030015DDEA00Q5D@05001ncWk>O/h00009AE401000O/incP00
0UKm0`000TEA00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm
00AFo@@000MFo@03001FoEKm00AFo@<000QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eF
o@040002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_d000020005
E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@02E_d300000eKm001Fo@07E_d00`00Ool0001<Ool003Uoo`03001oogoo008002Ioo`04001F
o@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30007
E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00
E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm0`001eKm00<005Km
E_d015Km0P0025Km00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<0
05KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EF
o@<000MFo@03001FoEKm00AFo@@000MFo@05001FoEKmE_d00006AE400`00AE55D@04AE400`00AE55
D@04AE400`00AE55D@08AE440003AE400`00AE55D@07AE400`00AE55D@04AE400`00AE55D@08AE40
1@00O/incWk>00002DEA00@007k>O/incP8000I5D@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03
001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40006E_d0
0`00E_eFo@04E_d30009E_d01000E_eFoEKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<0
05KmE_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d0
1EKm0`00C7oo000iOol3000YOol20007E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00
E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d00000
1EKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km10001eKm00<005KmE_d015Km0`001eKm00<0
05KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km0000
00EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03
001FoEKm009Fo@800003E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001FoEKm
0006AE400`00AE55D@04AE400`00AE55D@04AE400`00AE55D@06AE430006AE400`00AE55D@07AE40
0`00AE55D@04AE400`00AE55D@08AE401@00O/incWk>00002DEA00D007k>O/incP0000Q5D@03001F
oEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005Km
E_d00`000UKm0P001eKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03001F
oEKm00EFo@<000IFo@03001FoEKm00EFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009F
o@<00004E_d007oo001;Ool003Uoo`03001oogoo02]oo`03001FoEKm00EFo@04001Fo@000005E_d0
0`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30007E_d00`00E_eF
o@02E_d300000eKm001Fo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030003
E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km0`00
25Km00<005KmE_d00UKm0P0000=Fo@00E_d025Km00<005KmE_d00`000eKm00<005KmE_d01EKm00<0
05KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000AFo@03001FoEKm00IFo@<000MFo@03001F
oEKm00AFo@<00003E_d004EA00E5D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00=5D@<0
0003AE40000000I5D@030015DDEA00I5D@8000I5D@030015DDEA00Q5D@05001ncWk>O/h00009AE40
1@00O/incWk>00002DEA0P001eKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km
00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04
001Fo@000005E_d00`00E_eFo@06E_d30006E_d20005E_d40007E_d00`00E_eFo@04E_d30008E_d0
1000E_eFoEKm0`0000=Fo@00E_d01eKm00<005KmE_d010000UKm00<005KmE_d01UKm00<005KmE_d0
0`000UKm00<005KmE_d01UKm00<005Km00000P001EKm00<007oo0000BWoo000hOol00`00Oomoo`0]
Ool00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@03
0003E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<0
05KmE_d01EKm0`001eKm00<005KmE_d015Km10001eKm00<005KmE_d015Km0P0025Km00<005KmE_d0
0UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000AFo@03
001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm
009Fo@<00003E_d005Km00QFo@03001FoEKm00<00095D@03001Fo@0000I5D@030015DDEA00A5D@03
0015DDEA00A5D@040015DDEAAE420004AE420006AE400`00AE55D@06AE420006AE400`00AE55D@07
AE400`00O/incP02O/h00`00AE55D@07AE401@00O/incWk>00002DEA00<005KmE_d01eKm00<005Km
E_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm
00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001F
oEKm00<0009Fo@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005
E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30009E_d2001:
Ool003Qoo`03001oogoo02ioo`03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d0
0`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30007E_d00`00E_eF
o@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@03
0002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km
0`001eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm
00<005KmE_d00`000eKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00IFo@<000E5D@03
001Fo@0000I5D@030015DDEA00A5D@030015DDEA00A5D@@000I5D@8000I5D@030015DDEA00I5D@80
00M5D@030015DDEA00I5D@03001ncWk>009ncP030015DDEA00M5D@05001ncWk>O/h00009AE420008
E_d30006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm
00<005KmE_d01EKm0`001UKm00<005KmE_d01EKm10001UKm00<005KmE_d015Km0`0025Km00@005Km
E_eFo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009F
o@03001FoEKm00MFo@03001oo`0004Uoo`003Woo00AJePQ2000icPIoo`03:DX002U:00Aoo`H000=o
o`06BU88@P00000Q27>L2Woo00<007ooOol0;goo0P001eKm00<005KmE_d015Km0`001eKm00<005Km
E_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01UKm00<005KmE_d0
0`000eKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AF
o@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@800003E_d005Km00QFo@03001FoEKm
00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04
E_d40007E_d00`00E_eFo@04E_d20008E_d00`00E_eFo@02E_d300000eKm0015D@05AE400`00E_d0
0006AE400`00AE55D@04AE400`00AE55D@02AE430009AE420006AE400`00AE55D@06AE420007AE40
0`00AE55D@06AE400`00O/incP02O/h00`00AE55D@07AE401@00O/incWk>00002DEA00<007k>0000
15Km0`0000=Fo@00E_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000EFo@03
001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm00AFo@<000QFo@04001FoEKm
E_d300000eKm00000007E_d00`00E_eFo@040002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d0
0`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km10001UKm
00<005KmE_d01EKm0`0000=oo`00Ool0Agoo000=Ool01V<H6<IcW7>L48ABU0Eoo`<000Aoo`03BU80
06<H009oo`06249oogooOol8@T8@0Woo00<icR48Ool02Goo00<007ooOol0<7oo00<005KmE_d01UKm
00<005KmE_d00`000eKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03
001FoEKm00AFo@@000MFo@03001FoEKm00AFo@8000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm
00IFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04
001Fo@000004E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d20008E_d00`00E_eFo@02E_d3
00000eKm001Fo@07E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00
E_eFo@06E_d01000E_d0000015Km00<004EAAE4014EA00<005Km00001TEA00<004EAAE4014EA00<0
04EA00000P000TEA00<004EAAE401dEA0P001TEA00<004EAAE401TEA0P001dEA00<004EAAE401TEA
00<007k>O/h00Wk>00<004EAAE401dEA00D007k>O/incP0000U5D@05001ncWk>001Fo@020005E_d0
0`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d01eKm
00<005KmE_d00`000eKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km
000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QF
o@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001F
oEKm00@0009Fo@03001oo`0004Qoo`003Goo00HQ25:DOomooe:D6<H5Ool00bU:000YBP05Ool00dYB
001S600:Ool00`00Oomoo`08Ool00`00Oomoo`0aOol00`00E_eFo@04E_d40007E_d00`00E_eFo@04
E_d30007E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eF
o@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`00
1eKm00<005KmE_d015Km0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=Fo@00
E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EFo@<0
00MFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000IFo@030015DDEA00A5D@03001Fo@00
00I5D@030015DDEA00=5D@<000E5D@030015DDEA00M5D@8000I5D@030015DDEA00I5D@03001nc`00
00I5D@030015DDEA00I5D@03001ncWk>009ncP030015DDEA00M5D@05001ncWk>O/h00009AE401@00
O/incWk>000025Km00@005KmE_eFo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm
00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40006E_d00`00E_eF
o@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d0
1UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005Km00000P001EKm00<005KmE_d01EKm0`00
1UKm00<005KmE_d015Km10001eKm00<007oo0000Agoo000=Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00e:D249S6008Ool00g>L001oo`09Ool3000bOol00`00E_eFo@030003E_d00`00E_eFo@06E_d0
0`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<0
05KmE_d015Km10001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm0P0000=Fo@00E_d025Km
00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01EKm00@005Km
000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@800003
E_d005Km00QFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm
00=Fo@030015DDEA00A5D@03001Fo@0000I5D@030015DDEA00<00003AE4004EA00E5D@030015DDEA
00M5D@8000I5D@030015DDEA00I5D@03001nc`0000I5D@030015DDEA00I5D@04001ncWk>O/h20009
AE401@00O/incWk>00002DEA00D007k>O/incP0000QFo@04001Fo@000005E_d00`00E_eFo@06E_d3
0006E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005KmE_d00`00
0UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm10001EKm00<005KmE_d01UKm
0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`002EKm00@005KmE_eFo@<00003E_d0
05Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001oogoo0016Ool000eoo`03001oogoo
009oo`03001oogoo00eoo`03HaP8@V<H00=oo`06249:DWooOolicS6<2Goo0P00=Goo0P001eKm00<0
05KmE_d015Km10001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0P000UKm00<005KmE_d0
1UKm00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@0
05Km000000AFo@03001FoEKm00IFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<0
00MFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04
001Fo@000004E_d00`00E_eFo@06E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d0
0`00AE55D@04AE400`00E_d00006AE430004AE400`00AE55D@04AE400`00AE55D@07AE420006AE40
0`00AE55D@06AE400`00O/l00006AE400`00AE55D@06AE401000O/incWk>0P002DEA00D007k>O/in
cP0000U5D@04001ncWk>O/h20006E_d30008E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00
E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005Km
E_d015Km10001UKm00<005KmE_d015Km10001eKm00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<0
05KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01eKm00@005Km0000
00EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@<00003Ool007oo04Eoo`003Goo00<007oo
Ool00Woo00<007ooOol03Woo00=BU1S6Ool00Woo00D001240000036<00Yoo`03001oogoo03Eoo`03
001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm
00EFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eF
o@04E_d30007E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eF
o@06E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01EKm0`00
1eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=Fo@00E_d025Km00<005KmE_d00`00
0UKm00<005KmE_d01UKm00D005KmE_eFo@0000I5D@03001Fo@0000=5D@@000I5D@030015DDEA00A5
D@030015DDEA00M5D@8000I5D@030015DDEA00I5D@03001nc`0000I5D@030015DDEA00I5D@04001n
cWk>O/h20009AE401@00O/incWk>00002DEA00L007k>O/incP00O/h00002E_d30003E_d00`00E_eF
o@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km0`0025Km00<005Km
E_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`00
0UKm0P0025Km00@005Km000000EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000IFo@03
001FoEKm00EFo@<000QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d01000
Oomoo`00AGoo000=Ool01R48DYAoogooDY@Q215oo`05001oogooOol0000>Ool00`00Oomoo`0fOol0
0`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d20008E_d00`00E_eF
o@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eFo@03
0003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km
10001eKm00<005KmE_d015Km0P0025Km00<005KmE_d00UKm0P000eKm00<005KmE_d01EKm00<005Km
E_d00`000eKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm
00AFo@<0009Fo@030015DDEA00A5D@04001Fo@00AE420003AE400`00AE55D@04AE400`00AE55D@04
AE400`00AE55D@07AE420006AE400`00AE55D@06AE400`00O/l00006AE400`00AE55D@06AE401`00
O/incWk>001ncP0000Q5D@05001ncWk>O/h00009AE401@00O/incWk>00000Wk>0P001eKm00<005Km
E_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm
00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40006E_d20006E_d3
0008E_d01000E_eFoEKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<0
05KmE_d010000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EFo@<000IFo@04001o
ogoo0014Ool000eoo`06HaPHaW>LLi`HaV<H37oo00H0048@LiaoocW>6<H3Ool00`00Oomoo`0<Ool0
0`00Oomoo`0gOol00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00
E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm
0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0`0000=F
o@00E_d01eKm00<005KmE_d00`000eKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d0
1UKm00@005Km000000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@8000QFo@03001FoEKm
009Fo@<00003E_d005Km00MFo@03001FoEKm00<00095D@04001FoEKm0006AE440005AE400`00AE55
D@04AE400`00AE55D@04AE400`00AE55D@07AE420006AE400`00AE55D@06AE400`00O/l00006AE40
0`00AE55D@06AE401`00O/incWk>001ncP0000Q5D@05001ncWk>O/h00009AE401@00O/incWk>0000
0Wk>0P0025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00AF
o@@000MFo@03001FoEKm00AFo@<000QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@03
0002E_d00`00E_eFo@06E_d200000eKm000000020002E_d00`00E_eFo@06E_d01000E_d000001EKm
00<005KmE_d01EKm0`001UKm00<005KmE_d015Km10001eKm00<005KmE_d015Km0`0025Km00@005Km
E_eFo@<00003E_d005Km00MFo@03001oo`0004Aoo`003Woo00AJePQ2249S60eoo`06DY@HaP00000Y
BW>L0goo1@002Woo00<007ooOol0>7oo00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03001F
oEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@800003E_d005Km00QFo@03
001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@00
0005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30009E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d0
00001EKm00<005KmE_d01EKm0`001DEA00@005KmE_d000A5D@<00003E_d004EA00E5D@030015DDEA
00A5D@030015DDEA00A5D@030015DDEA00M5D@8000I5D@030015DDEA00I5D@03001nc`0000I5D@03
0015DDEA00I5D@07001ncWk>O/h007k>00001dEA00<007k>O/h00Wk>00<004EAAE401dEA00D007k>
O/incP00009ncP03001ncP0000IFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm00<000=F
o@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eF
o@05E_d30006E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`00
00=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01eKm00<005KmE_d00`000UKm00<005Km
E_d01UKm00@005Km000000EFo@03001FoEKm00EFo@800003Ool007oo049oo`00=goo00<007ooOol0
>Goo0P001eKm00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005Km
E_d01EKm00<005KmE_d00`000eKm00<005KmE_d01UKm00@005Km000000AFo@03001FoEKm00IFo@<0
00MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@8000QFo@03001FoEKm009Fo@80009Fo@03
001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm
00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm009Fo@80
0003E_d004EA00E5D@05001FoEKm0015D@030002AE400`00E_d00006AE400`00AE55D@04AE400`00
AE55D@04AE400`00AE55D@07AE420006AE400`00AE55D@06AE400`00O/l00006AE400`00AE55D@06
AE401`00O/incWk>001ncP0000M5D@03001ncWk>009ncP8000Q5D@05001ncWk>O/h00002O/h01000
O/incP000UKm0`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm0`001eKm
00<005KmE_d015Km10001UKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MF
o@03001FoEKm00<000=Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001F
o@000005E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@05E_d40006E_d00`00E_eFo@04E_d30008
E_d01000E_eFoEKm0`0000EFo@00Oomoo`00049oo`00=goo00<007ooOol0>goo00<005KmE_d01EKm
00@005Km000000EFo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AF
o@<000MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d0
0`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030003E_d0
0`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000000eKm00<004EAAE40
14EA00<005Km00000P001DEA00<005Km00001TEA00<004EAAE4014EA00<004EAAE401DEA00<004EA
AE401TEA0P001dEA00<004EAAE401DEA00<007k?00001TEA00<004EAAE401TEA00L007k>O/incP00
O/h00007AE400`00O/incP02O/h20008AE401@00O/incWk>00000Wk>00@007k>O/incP8000IFo@03
001FoEKm00AFo@@000IFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009Fo@03
001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05
E_d30007E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=F
o@00E_d01eKm00<005KmE_d010000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d0
1UKm00@005Km000000EFo@<0049oo`00=Woo00@007oo000003aoo`03001FoEKm00AFo@<000MFo@03
001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001F
oEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<0
05KmE_d015Km0`001eKm00<005KmE_d015Km0`001EKm00<004EAAE400dEA0`0000=Fo@00AE401DEA
00<005Km00001TEA00<004EAAE4014EA00<004EAAE401DEA00<004EAAE401TEA0P001dEA00<004EA
AE401DEA00<007k?00001TEA00<004EAAE401TEA00L007k>O/incP00O/h00007AE400`00O/incP02
O/h20008AE401@00O/incWk>00000Wk>00D007k>O/incP0000QFo@03001FoEKm00<0009Fo@03001F
oEKm00IFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d40006E_d00`00
E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005Km
E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EFo@<0
00MFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03001oo`00045oo`00=Woo0P00
?goo00<005KmE_d00`000eKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00EFo@<000MF
o@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@<00003E_d005Km
00MFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04
001Fo@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d2
00000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00
E_eFo@03E_d00`00AE55D@0300001DEA001FoEKm00001TEA00<005Km00001TEA00<004EAAE4014EA
00<004EAAE401DEA00<004EAAE401TEA00<007[?00001TEA00<004EAAE401DEA00<007k?00001TEA
00<004EAAE401TEA00L007k>O/incP00O/h00007AE401`00O/incWk>001ncP0000Q5D@05001ncWk>
O/h00002O/h01000O/incWk>0P001UKm10001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00UKm
0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<0
05KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03
001FoEKm00AFo@<000QFo@04001FoEKmE_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00
E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00Ool00011Ool003Ioo`03001oogoo
03moo`8000MFo@03001FoEKm00AFo@8000QFo@03001FoEKm009Fo@800003E_d005Km00QFo@03001F
oEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005
E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d00000
15Km00<005KmE_d01UKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm0`0014EA00@0
05KmE_d000I5D@03001Fo@0000I5D@030015DDEA00A5D@030015DDEA00E5D@030015DDEA00I5D@03
001jc`0000I5D@030015DDEA00E5D@03001nc`0000I5D@030015DDEA00I5D@07001ncWk>O/h007k>
00001dEA00L007k>O/incP00O/h00008AE401@00O/incWk>00000Wk>00L007k>O/incP0000/00002
E_d30002E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm
00<005KmE_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`0025Km00<005Km
E_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`00
0UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@0
00IFo@03001FoEKm00AFo@<00003Ool007oo03moo`00=Woo00<007ooOol0@7oo00<005KmE_d01UKm
00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000AFo@03001FoEKm00IFo@<000MFo@03
001FoEKm00AFo@<000MFo@03001FoEKm00AFo@8000QFo@03001FoEKm009Fo@8000=Fo@03001FoEKm
00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@<0
00MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@<00003E_d0
05Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001Fo@00008000I5D@04001FoEKm0006
AE400`00E_d00006AE400`00AE55D@04AE400`00AE55D@05AE400`00AE55D@06AE400`00N/l00006
AE400`00AE55D@05AE400`00O/l00006AE400`00AE55D@06AE401`00O/incWk>001ncP0000M5D@07
001ncWk>O/h007k>000024EA00D007k>O/incP00009ncP06001ncWk>O/h0000;0`001UKm00<005Km
E_d015Km10001eKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@03001F
oEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@04001Fo@000005
E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@03
0002E_d01000Oomoo`00?goo000fOol00`00Oomoo`11Ool00`00E_eFo@04E_d40006E_d00`00E_eF
o@04E_d30007E_d00`00E_eFo@02E_d300000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eF
o@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001UKm00<005KmE_d015Km0`00
1eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0P0000=Fo@00E_d025Km00<005KmE_d00`00
0UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01EKm00@005Km000000EFo@03001F
oEKm00EFo@<000MFo@03001FoEKm00=Fo@<0009Fo@030015DDEA00A5D@04001FoEKm0006AE400`00
E_d00006AE400`00AE55D@04AE400`00AE55D@05AE400`00AE55D@05AE401000N/mjc`001TEA00<0
04EAAE401DEA00<007k?00001TEA00<004EAAE401TEA00L007k>O/incP00O/h00007AE401`00O/in
cWk>001ncP0000Q5D@05001ncWk>O/h00002O/h01000O/incWk>0P0000=Fo@00E_d01eKm00<005Km
E_d00`000eKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EF
o@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm00AFo@<000QFo@04001F
oEKmE_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002
E_d00`00E_eFo@06E_d00`00E_d000020005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d4
0006E_d00`00Ool0000oOol003Ioo`03001oogoo049oo`03001FoEKm00<000=Fo@03001FoEKm00EF
o@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d0
0`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30009E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d0000015Km00<005KmE_d01UKm0`001UKm
00<005KmE_d015Km10001eKm00<005KmE_d015Km0P0025Km00<005KmE_d00UKm0P0000=Fo@00E_d0
25Km00<005Km00000`0000EFo@00E_eFo@0000I5D@04001FoEKm0006AE400`00E_d00006AE400`00
AE55D@04AE400`00AE55D@05AE400`00AE55D@05AE401000N/mjc`001TEA00<004EAAE401DEA00<0
07k?00001TEA00<004EAAE401TEA00L007k>O/incP00O/h00007AE401`00O/incWk>001ncP0000Q5
D@05001ncWk>O/h00002O/h01@00O/incWk>00000eKm00<005KmE_d01EKm0`001eKm00<005KmE_d0
15Km10001UKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm
00<0009Fo@03001FoEKm00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d0
0`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eF
o@040002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00Ool0000nOol0
03Eoo`03001oogoo04Aoo`8000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03
001FoEKm009Fo@<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001F
oEKm00<000=Fo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<0
00MFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00IFo@03
001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000004E_d00`00E_eFo@05E_d40004E_d01000
E_eFo@001TEA00@005KmE_d000I5D@<000I5D@030015DDEA00A5D@030015DDEA00E5D@030015DDEA
00E5D@04001jcg[?0006AE400`00AE55D@05AE400`00O/l00006AE400`00AE55D@06AE401`00O/in
cWk>001ncP0000M5D@07001ncWk>O/h007k>000024EA00D007k>O/incP00009ncP05001ncWk>O/h0
0004E_d00`00E_eFo@02E_d200000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<0
05KmE_d01EKm10001UKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@03
001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@<000MFo@03
001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<00003Ool007oo03aoo`00=Goo00<007ooOol0AGoo
00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005Km
E_d01EKm00@005Km000000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03001F
oEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0
00=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d4
0006E_d00`00E_eFo@04E_d30007E_d01000E_eFoEKm100000=Fo@00E_d015Km00@005KmE_d000I5
D@04001FoEKm0006AE430006AE400`00AE55D@04AE400`00AE55D@05AE400`00AE55D@05AE401000
N/mjc`001TEA00<004EAAE401DEA00<007k?00001TEA00<004EAAE401TEA00L007k>O/incP00O/h0
0007AE401`00O/incWk>001ncP0000M5D@03001ncWk>009ncP04001ncWk>0003O/h00`00E_eFo@03
E_d01000E_d0000015Km00<005KmE_d01UKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d0
15Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00@0009Fo@03001FoEKm00IF
o@03001FoEKm00<0009Fo@8000MFo@04001Fo@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@040002E_d00`00E_eF
o@06E_d00`00E_eFo@030002E_d00`00Ool0000mOol003Eoo`<004Ioo`03001FoEKm00EFo@<000MF
o@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000QFo@03001FoEKm00<000=Fo@03001FoEKm
00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@05E_d30007
E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d20008E_d00`00E_eFo@02E_d200000eKm001F
o@08E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d4
0005E_d00`00E_eFo@02E_d01000E_eFo@001TEA00@005KmE_d000I5D@<000I5D@030015DDEA00A5
D@030015DDEA00E5D@030015DDEA00E5D@04001jcg[?0006AE400`00AE55D@05AE400`00O/l00006
AE400`00AE55D@06AE401`00O/incWk>001ncP0000M5D@07001ncWk>O/h007k>00001dEA00<007k>
O/h00Wk>00@007k>O/h000=ncP03001FoEKm009Fo@<000MFo@03001FoEKm009Fo@<00003E_d005Km
00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04
001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40006E_d20005E_d30008E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d0
00001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km10001UKm00<007oo0000?7oo000eOol0
0`00Oomoo`17Ool00`00E_eFo@02E_d20003E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00
E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30007E_d0
0`00E_eFo@04E_d20008E_d00`00E_eFo@02E_d200000eKm001Fo@08E_d00`00E_eFo@030002E_d0
0`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d0000015Km00<005KmE_d0
1UKm0`001eKm00<005KmE_d015Km0`001eKm00@005KmE_eFo@D000QFo@05001FoEKmE_d00002E_d0
0`00AE55D@04AE401000E_eFo@001TEA0`001TEA00<004EAAE4014EA00<004EAAE401DEA00<004EA
AE401DEA00@007[?N/l000I5D@030015DDEA00A5D@04001ncgk?0006AE400`00AE55D@06AE401`00
O/incWk>001ncP0000M5D@07001ncWk>O/h007k>00001dEA00<007k>O/h00Wk>00@007k>O/h000=n
cP03001Fo@000080009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d30006E_d0
0`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@02E_d20002E_d00`00E_eF
o@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d3
0006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00
E_d01eKm00<005KmE_d010000UKm00<005KmE_d01UKm00<007oo0000>goo000eOol00`00Oomoo`18
Ool01000E_d000001UKm00<005KmE_d015Km0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d0
0UKm0P0000=Fo@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm
00<005KmE_d01UKm00@005Km000000AFo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IF
o@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@<00003E_d005Km00QFo@03001FoEKm00<0009F
o@03001FoEKm00IFo@H0009Fo@03001FoEKm00IFo@04001Fo@000002E_d00`00AE55D@04AE401000
E_eFo@001TEA0`001TEA00<004EAAE4014EA00<004EAAE401DEA00<004EAAE401DEA00@007[?N/l0
00I5D@030015DDEA00A5D@04001ncgk?0006AE400`00AE55D@06AE401`00O/incWk>001ncP0000M5
D@07001ncWk>O/h007k>00001dEA00<007k>O/h00Wk>00@007k>O/h000=ncP8000IFo@03001FoEKm
00AFo@<000QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d015Km10001UKm
00<005KmE_d015Km10001UKm00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm
00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm
00EFo@<000MFo@03001FoEKm00AFo@@003]oo`00=Goo00<007ooOol0BGoo00<005KmE_d01eKm00<0
05KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km0000
00AFo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000MFo@03
001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm
00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@03
E_d50006E_d00`00E_eFo@04E_d300001EKm001FoEKm00001TEA00@005KmE_d000I5D@<000I5D@03
0015DDEA00A5D@030015DDEA00E5D@030015DDEA00E5D@04001jcg[?0006AE400`00AE55D@04AE40
1000O/mnc`001TEA00<004EAAE401TEA00L007k>O/incP00O/h00007AE401`00O/incWk>001ncP00
00M5D@05001ncWk>O/h00003O/h01@00O/incWk>000025Km00<005KmE_d00`000UKm00<005KmE_d0
1UKm00@005Km000000EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm
00AFo@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@8000MFo@04
001Fo@000005E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d3
0008E_d01000E_eFoEKm0`0000=Fo@00E_d01eKm00<005KmE_d010000UKm00<007oo0000>Woo000d
Ool00`00Oomoo`1;Ool00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04
E_d30007E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030003E_d00`00E_eFo@05
E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm
00<005KmE_d015Km0`001eKm00<005KmE_d015Km0P0025Km00<005KmE_d00UKm0`0000=Fo@00E_d0
1eKm00<005Km00000`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm0P000UKm00<004EAAE40
14EA00@005KmE_d000I5D@<000I5D@030015DDEA00A5D@030015DDEA00E5D@030015DDEA00E5D@04
001jcg[?0006AE400`00AE55D@04AE401000O/mnc`001TEA00<004EAAE401TEA00L007k>O/incP00
O/h00007AE401`00O/incWk>001ncP0000M5D@05001ncWk>O/h00003O/h01000O/incWk>0P001UKm
10001UKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<0009Fo@03001FoEKm00EFo@03001FoEKm
00<000=Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@<000IFo@03001FoEKm
00AFo@@000IFo@03001FoEKm00AFo@<000QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm
00<005KmE_d01EKm0`001eKm00<007oo0000>Goo000dOol00`00Oomoo`1<Ool00`00E_eFo@02E_d3
00000eKm001Fo@07E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00
E_eFo@05E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`001eKm00<0
05KmE_d015Km0`001eKm00<005KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm
00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm
00AFo@@000MFo@03001FoEKm00AFo@<000MFo@04001FoEKm0006AE401000E_eFo@001TEA0`001TEA
00<004EAAE4014EA00<004EAAE401DEA00<004EAAE401DEA00@007[?N/l000I5D@030015DDEA00A5
D@04001ncgk?0006AE400`00AE55D@05AE400`00O/incP02O/h00`00O/h00007AE401`00O/incWk>
001ncP0000M5D@05001ncWk>O/h00003O/h01`00O/incWk>00002`00009Fo@<0009Fo@03001FoEKm
00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000006E_d00`00E_eFo@04E_d30007
E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030002
E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005Km
E_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<0
0003E_d005Km00MFo@03001oo`0003Uoo`00=7oo00<007ooOol0CGoo00@005Km000000EFo@03001F
oEKm00EFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm009F
o@80009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=F
o@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40006
E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@030003E_d00`00E_eFo@06E_d00`00E_eFo@030002
E_d00`00E_eFo@05E_d01000E_eFo@001TEA00@005KmE_d000I5D@<000I5D@030015DDEA00A5D@03
0015DDEA00E5D@030015DDEA00E5D@04001jcg[?0006AE400`00AE55D@04AE401000O/mnc`001TEA
00<004EAAE401DEA00<007k>O/h00Wk>00<007k>00001dEA00L007k>O/incP00O/h00007AE401@00
O/incWk>00000gk>00H007k>O/incP0000/30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04
E_d30009E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d0
15Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d200000goo
001oo`0gOol003Aoo`<004ioo`8000MFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001F
oEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005
E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d20008E_d00`00
E_eFo@02E_d20002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eF
o@030003E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d01000
E_eFo@001TEA00@005KmE_d000I5D@<000I5D@030015DDEA00E5D@030015DDEA00A5D@030015DDEA
00E5D@04001jcg[?0006AE400`00AE55D@04AE401000O/mnc`001TEA00<004EAAE401DEA00<007k>
O/h00Wk>00<007k>00001dEA00L007k>O/incP00O/h00007AE401@00O/incWk>00000gk>00@007k>
O/incP80009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0
00=Fo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@04
001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d20007E_d00`00E_eFo@030002E_d0
0`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km10001UKm
00<005KmE_d015Km0`0025Km00@005KmE_eFo@<00005E_d007ooOol0000gOol003Aoo`03001oogoo
051oo`03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d3
0007E_d00`00E_eFo@04E_d20008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm
00<005KmE_d015Km0`001eKm00<005KmE_d015Km0`001eKm00@005KmE_eFo@<00003E_d005Km00QF
o@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00@0009Fo@030015DDEA00A5D@04001F
oEKm0006AE430006AE400`00AE55D@05AE400`00AE55D@04AE400`00AE55D@05AE401000N/mjc`00
1TEA00<004EAAE4014EA00@007k?O/l000I5D@030015DDEA00E5D@03001ncWk>009ncP03001ncP00
00M5D@07001ncWk>O/h007k>00001dEA00D007k>O/incP0000=ncP05001ncWk>O/h00004E_d00`00
E_eFo@04E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d0
00001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`0025Km
00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm
00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00Ool0000gOol003Aoo`03001oogoo055o
o`03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00<0
009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@04E_d40006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@03
0003E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d40004E_d00`00E_eFo@06
E_d30006E_d00`00E_eFo@04E_d40003E_d01000E_eFo@001TEA00@005KmE_d000I5D@<000I5D@03
0015DDEA00E5D@030015DDEA00A5D@030015DDEA00E5D@04001jcg[?0006AE400`00AE55D@04AE40
1000O/mnc`001TEA00<004EAAE401DEA00<007k>O/h00Wk>00<007k>00001dEA00L007k>O/incP00
O/h00007AE401@00O/incWk>00000gk>00D007k>O/incP0000EFo@03001FoEKm00<0009Fo@03001F
oEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@05E_d3
0006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00
E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm
00@005Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AF
o@<000QFo@03001oo`0003Ioo`00=7oo00<007ooOol0DWoo00<005KmE_d00`000eKm00<005KmE_d0
1EKm00@005Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm
00AFo@<000QFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm
00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@<000IFo@03001F
oEKm009Fo@D000MFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<000=Fo@05001F
oEKmE_d00002E_d00`00AE55D@04AE401000E_eFo@001TEA0`001dEA00<004EAAE4014EA00<004EA
AE4014EA00<004EAAE401DEA00@007[?N/l000I5D@030015DDEA00A5D@04001ncgk?0006AE400`00
AE55D@05AE401@00O/incWk>00000Wk>00<004EAAE401DEA00L007k>O/incP00O/h00007AE401@00
O/incWk>00000gk>00D007k>O/incP0000EFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm
00AFo@<000QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d015Km10001UKm
00<005KmE_d015Km10001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`000UKm00<005KmE_d0
1UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm0P00
00=oo`00Ool0=7oo000cOol00`00Oomoo`1DOol20007E_d00`00E_eFo@04E_d20008E_d00`00E_eF
o@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003
E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d30007E_d00`00
E_eFo@02E_d200000eKm001Fo@08E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_d00003
0003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d01EKm0`001eKm00@005KmE_d0009F
o@030015DDEA00A5D@04001FoEKm0006AE430007AE400`00AE55D@04AE400`00AE55D@04AE400`00
AE55D@05AE401000N/mjc`001TEA00<004EAAE4014EA00@007k?O/l000I5D@030015DDEA00E5D@05
001ncWk>O/h00002O/h00`00AE55D@05AE401`00O/incWk>001ncP0000M5D@05001ncWk>O/h00003
O/h01@00O/incWk>00000UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm
00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00EFo@<000IFo@03
001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm00<0009Fo@8000MFo@03001F
oEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@<000IFo@03001F
oEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm009Fo@<00004E_d007oo000eOol0
03=oo`03001oogoo05Eoo`03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@<000MF
o@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@800003E_d005Km
00QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04
001Fo@000004E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@03E_d40007E_d00`00E_eFo@04E_d2
0008E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_d00002E_d00`00AE55D@04AE40
1000E_eFo@001TEA0P0000=Fo@00AE401DEA00<004EAAE4014EA00<004EAAE4014EA00<004EAAE40
1DEA00@007[?N/l000I5D@030015DDEA00A5D@04001ncgk?0007AE400`00AE55D@04AE401@00O/in
cWk>00000Wk>00<004EAAE401DEA00L007k>O/incP00O/h00007AE401@00O/incWk>00000gk>00@0
07k>O/incP<000EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AF
o@<000QFo@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04
E_d40006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm0`00=7oo000cOol00`00Oomo
o`1FOol00`00E_eFo@04E_d40006E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eF
o@030003E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d0000015Km
00<005KmE_d01UKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001eKm00<005Km
E_d00UKm0`000UKm00<005KmE_d01EKm00<005Km00000`000UKm00<005KmE_d01UKm00<005KmE_d0
0`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00AFo@@0009Fo@030015DDEA00A5
D@800003E_d004EA00E5D@800003E_d004EA00E5D@030015DDEA00A5D@030015DDEA00A5D@030015
DDEA00E5D@04001jcg[?0006AE400`00AE55D@04AE401000O/mnc`001dEA00<004EAAE4014EA00D0
07k>O/incP00009ncP030015DDEA00E5D@07001ncWk>O/h007k>00001dEA00D007k>O/incP0000=n
cP05001ncWk>O/h00008E_d01000E_eFoEKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<0
05KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00AF
o@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm
00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d0
0`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00Ool0
000cOol003=oo`03001oogoo05Moo`03001FoEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005
E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d20007E_d00`00
E_eFo@02E_d30002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00E_eF
o@030003E_d00`00E_eFo@05E_d01000E_d000001UKm00<005KmE_d00eKm10001UKm00<005KmE_d0
15Km10001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`000eKm00@005KmE_d000I5D@800003
E_d004EA00E5D@800003E_d004EA00E5D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00E5
D@04001jcg[?0006AE400`00AE55D@04AE401000O/mnc`001dEA00<004EAAE4014EA00D007k>O/in
cP00009ncP030015DDEA00E5D@07001ncWk>O/h007k>00001dEA00D007k>O/incP00009ncP03001n
cWk>009ncP03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04
E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d0
15Km10001UKm00<005KmE_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm
00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001oo`0003=oo`00
<goo00<007oo00000P00EWoo0P001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0P0000=F
o@00E_d025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d0
1EKm00@005Km000000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03001FoEKm
00AFo@8000UFo@03001Fo@0000<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm
00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@<000IFo@04001FoEKm0006AE4200000eKm0015
D@05AE4200000eKm0015D@05AE400`00AE55D@04AE400`00AE55D@04AE400`00AE55D@05AE401000
N/mjc`001TEA00<004EAAE4014EA00D007k?O/mnc`0000I5D@030015DDEA00A5D@05001ncWk>O/h0
0002O/h00`00AE55D@05AE401`00O/incWk>001ncP0000M5D@05001ncWk>O/h00002O/h00`00O/in
cP02O/h20006E_d30008E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d0
0`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d40006
E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm
00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm
00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<00003Ool007oo035oo`00<Woo
0`00Fgoo00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01EKm00@005Km000000AFo@03
001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm
00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009F
o@03001FoEKm00EFo@@000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000MFo@03001F
oEKm009Fo@800003E_d005Km00IFo@04001FoEKm0006AE4200000eKm0015D@05AE4200000eKm0015
D@05AE400`00AE55D@04AE400`00AE55D@04AE400`00AE55D@04AE401@00N/mjcg[?00001TEA00<0
04EAAE4014EA00D007k?O/mnc`0000I5D@030015DDEA00A5D@05001ncWk>O/h00002O/h00`00AE55
D@05AE401`00O/incWk>001ncP0000M5D@05001ncWk>O/h00002O/h00`00O/incP02O/h00`0000/0
0002E_d30002E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d4
0006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<0
05KmE_d015Km10001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`000UKm00<005KmE_d01UKm
00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00@007ooOol0035oo`00<Woo
00<007ooOol0G7oo00<005KmE_d015Km0`001eKm00<005KmE_d015Km0P001eKm00<005KmE_d00UKm
0`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm
00<005KmE_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km10001UKm00@005Km
E_eFo@@00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009F
o@03001FoEKm00IFo@04001Fo@000004E_d00`00E_eFo@04E_d01000E_eFo@001TEA0P0000=Fo@00
AE401DEA0P0000=Fo@00AE401DEA00<004EAAE4014EA00<004EAAE4014EA00<004EAAE4014EA00D0
07[?N/mjc`0000I5D@030015DDEA00A5D@05001ncgk?O/l00006AE400`00AE55D@04AE401@00O/in
cWk>00000Wk>00<004EAAE401DEA00D007k>O/incP00009ncP030015DDEA00A5D@05001ncWk>O/h0
0002O/h00`00O/incP02O/h50006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@03
0002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<0
05KmE_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`0025Km00@005KmE_eF
o@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03
001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001oo`00
035oo`00<Woo00<007ooOol0GGoo00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`00
0UKm00<005KmE_d01EKm00@005Km000000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<0
00MFo@03001FoEKm009Fo@800003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03
001FoEKm00<000=Fo@03001FoEKm00EFo@@000EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00AF
o@@000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@80009Fo@030015DDEA00A5D@800003
E_d004EA00E5D@800003E_d004EA00E5D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00A5
D@05001jcg[?N/l00006AE400`00AE55D@04AE401@00O/mncgk?00001TEA00<004EAAE4014EA00D0
07k>O/incP00009ncP030015DDEA00E5D@05001ncWk>O/h00002O/h00`00AE55D@04AE401@00O/in
cWk>00000Wk>00@007k>O/incP8000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@05
E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`0000=F
o@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d0
1UKm10001EKm00<005KmE_d015Km10001UKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm0`00
00=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005Km
E_d01UKm00<007oo0000<7oo000bOol00`00Oomoo`1NOol20006E_d00`00E_eFo@04E_d40006E_d0
0`00E_eFo@04E_d30008E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d0
0`00E_eFo@06E_d01000E_d0000015Km00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`001eKm
00@005KmE_eFo@D000QFo@03001FoEKm009Fo@80009Fo@03001FoEKm00EFo@03001FoEKm00<000=F
o@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@06001Fo@00001Fo@000UKm00<0
04EAAE4014EA0P0000=Fo@00AE401DEA0P0000=Fo@00AE401DEA00<004EAAE4014EA00<004EAAE40
14EA00<004EAAE4014EA00D007[?N/mjc`0000I5D@030015DDEA00A5D@05001ncgk?O/l00006AE40
0`00AE55D@04AE401@00O/incWk>00000gk>00<004EAAE4014EA00D007k>O/incP00009ncP030015
DDEA00A5D@05001ncWk>O/h00002O/h01000O/incWk>0P0015Km00<005KmE_d015Km0P0025Km00@0
05KmE_eFo@<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm
00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04
E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d0
15Km10001UKm00<005KmE_d015Km1000<7oo000AOol015[F248003W>1Woo00<YBP00:DX017oo00I:
DPQ200000248Li`:Ool00`00Oomoo`1OOol00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eF
o@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40006E_d00`00
E_eFo@04E_d30007E_d00`00E_eFo@02E_d20003E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d0
0`00E_eFo@06E_d60002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d015Km0`001eKm
00<005KmE_d015Km0`001eKm00<005KmE_d015Km0P000eKm00@005KmE_d000I5D@800003E_d004EA
00E5D@800003E_d004EA00E5D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00A5D@05001j
cg[?N/l00006AE400`00AE55D@04AE401@00O/mncgk?00001TEA00<004EAAE4014EA00D007k>O/in
cP0000=ncP030015DDEA00=5D@03001ncWk>009ncP04001ncWk>0006AE401@00O/incWk>00000Wk>
00@007k>O/incP8000EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000006E_d00`00
E_eFo@04E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@03
0002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d2
0007E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30008E_d01000E_eFoEKm0`00
00=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d010000UKm00<007oo
0000;goo000@Ool01V<H6<IcW7>L48ABU0Eoo`<000Aoo`06249247ooOolicR482Woo00<007ooOol0
H7oo00<005KmE_d015Km0`001eKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0P0000=Fo@00
E_d01eKm00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01EKm
00@005Km000000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00=Fo@D000IFo@03001FoEKm00AF
o@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@03001FoEKm00<0009Fo@04001FoEKm0002E_d00`00AE55D@04AE4200000eKm0015D@05AE420000
0eKm0015D@05AE400`00AE55D@04AE400`00AE55D@04AE400`00AE55D@04AE401@00N/mjcg[?0000
1TEA00<004EAAE4014EA00D007k?O/mnc`0000I5D@030015DDEA00A5D@05001ncWk>O/h00003O/h0
0`00AE55D@03AE400`00O/incP02O/h01000O/incP001TEA00D007k>O/incP00009ncP04001ncWk>
O/h20004E_d40006E_d00`00E_eFo@04E_d20009E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d0
0`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d40006E_d20003E_d300000eKm001Fo@07E_d00`00
E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d00000
1EKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm10001eKm00<007oo0000;Woo000@Ool01R48
DYAoogooDY@HaPEoo`03:DX002U:00Uoo`03001oogoo00Qoo`03001oogoo065oo`03001FoEKm00<0
00=Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000004E_d00`00
E_eFo@05E_d30007E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d20009E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_d000030003E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d0
0`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d40006E_d01P00E_eF
o@00E_d000I5D@800003E_d004EA00E5D@800003E_d004EA00E5D@030015DDEA00A5D@030015DDEA
00A5D@030015DDEA00A5D@05001jcg[?N/l00006AE400`00AE55D@04AE401@00O/mncgk?00001TEA
00<004EAAE4014EA00D007k>O/incP0000=ncP030015DDEA00=5D@03001ncWk>009ncP04001ncWk>
0006AE401@00O/incWk>00000Wk>00@007k>O/incP800004E_d000000002E_d00`00E_eFo@06E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d40006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d40005E_d00`00E_eFo@05E_d30006E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@040002E_d00`00E_eFo@05E_d00`00
E_eFo@030002E_d00`00E_eFo@06E_d00`00Ool0000^Ool0011oo`03001oogoo009oo`03001oogoo
00ioo`03Li`007oo00Qoo`04001oo`00001ROol20007E_d00`00E_eFo@04E_d30006E_d00`00E_eF
o@04E_d30007E_d00`00E_eFo@02E_d20003E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00
E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@03E_d40007E_d0
0`00E_eFo@04E_d30006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030003E_d0
0`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01@00E_d005Km00001TEA0P0000=F
o@00AE401DEA0P0000=Fo@00AE401DEA00<004EAAE4014EA00<004EAAE4014EA00<004EAAE4014EA
00D007[?N/mjc`0000I5D@030015DDEA00=5D@03001ncgk?009nc`030015DDEA00A5D@030015DDEA
00A5D@05001ncWk>O/h00003O/h00`00AE55D@03AE400`00O/incP02O/h01000O/incP001TEA00D0
07k>O/incP00009ncP04001ncWk>O/h30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@02E_d3
00000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00
E_eFo@06E_d01000E_d000001EKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<0
05KmE_d015Km0`0025Km00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001F
oEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@<000MFo@03001FoEKm00=Fo@@000IFo@03
001FoEKm00AFo@<00003Ool007oo02aoo`0047oo00<007ooOol00Woo00<007ooOol02Woo00H8@TYB
OomoocW><H`9Ool2001VOol00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00
E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001UKm00<005KmE_d015Km0`001UKm00<005Km
E_d015Km10001UKm00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005Km00000`000UKm00<005Km
E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00EFo@<0
00MFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@00003E_d004EA00E5D@800003E_d004EA
00E5D@800003E_d004EA00E5D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00A5D@05001j
cg[?N/l00006AE400`00AE55D@03AE400`00O/mnc`02O/l00`00AE55D@04AE400`00AE55D@04AE40
1@00O/incWk>00000gk>00<004EAAE400dEA00D007k>O/incP0000=ncP030015DDEA00A5D@05001n
cWk>O/h00002O/h01000O/incWk>0P0025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km
000000EFo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000QF
o@04001FoEKmE_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eF
o@030002E_d20007E_d01000E_d000001EKm00<005KmE_d015Km10001UKm00<005KmE_d015Km1000
1UKm00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001F
oEKm00<0009Fo@04001oogoo000>Ool01TYB248000008@QcW0Aoo`04F]H8@P00>Lh@Ool0011oo`03
001oogoo009oo`03001oogoo00Yoo`05000@Q000000aS00:Ool00`00Oomoo`1VOol00`00E_eFo@04
E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d20009E_d00`00E_eFo@030002E_d0
0`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d0
15Km10001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0P0025Km00<005KmE_d00UKm0P00
0UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<0
05Km00001TEA0P0000=Fo@00AE401DEA0P0000=Fo@00AE401DEA00<004EAAE4014EA00<004EAAE40
14EA00<004EAAE4014EA00D007[?N/mjc`0000I5D@030015DDEA00=5D@03001ncgk?009nc`030015
DDEA00A5D@030015DDEA00A5D@05001ncWk>O/h00003O/h00`00AE55D@03AE401@00O/incWk>0000
0gk>00<004EAAE4014EA00D007k>O/incP00009ncP04001ncWk>O/h30006E_d40006E_d00`00E_eF
o@04E_d30008E_d01000E_eFoEKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d0
1EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00AFo@@000IF
o@03001FoEKm00AFo@@000IFo@8000EFo@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03
001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@05E_d30006E_d00`00
E_eFo@04E_d40006E_d00`00Ool0000>Ool01PQ2@Q1oogoo>LhQ20=oo`06HaPHaW>LLi`@Q5:D3goo
000@Ool01R48DYAoogooDY@Q20aoo`03001oogoo00aoo`03001oogoo06Moo`03001FoEKm00<0009F
o@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001F
oEKm00IFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@8000QFo@03001FoEKm00@0
009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03
001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30006E_d0
0`00E_d00006AE4200000eKm0015D@05AE4200000eKm0015D@05AE400`00AE55D@04AE400`00AE55
D@04AE400`00AE55D@04AE401@00N/mjcg[?00001TEA00<004EAAE400dEA00<007k?O/l00Wk?00<0
04EAAE4014EA00<004EAAE4014EA00D007k>O/incP0000=ncP030015DDEA00=5D@05001ncWk>O/h0
0003O/h00`00AE55D@04AE401@00O/incWk>00000Wk>00@007k>O/incP800004E_d005KmE_d30002
E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005Km
E_d015Km10001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`00
0UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<0
05KmE_d01UKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm0`0025Km00@005KmE_eF
o@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001oo`00019oo`06001o
ogooOolQ25:D0Woo00=BU1S6Ool03Woo000@Ool01V<H6<IcW7>L6<IS60aoo`03001oogoo00aoo`03
001oogoo06Qoo`8000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000IFo@03001FoEKm
009Fo@<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0
009Fo@03001FoEKm00EFo@D000EFo@03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000IFo@03
001FoEKm00AFo@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03
001FoEKm00AFo@03001Fo@0000I5D@800003E_d004EA00E5D@800003E_d004EA00E5D@030015DDEA
00A5D@030015DDEA00A5D@030015DDEA00A5D@05001jcg[?N/l00006AE400`00AE55D@03AE400`00
O/mnc`02O/l00`00AE55D@04AE400`00AE55D@04AE401@00O/incWk>00000gk>00<004EAAE400dEA
00D007k>O/incP0000=ncP030015DDEA00A5D@05001ncWk>O/h00002O/h01000O/incWk>0P0000AF
o@00000000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm00<0009F
o@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001F
oEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm009F
o@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03
001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d300000goo
001oo`0?Ool00g>L001oo`02Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool0015oo`04F]H8@PQ2HaP=
Ool5000:Ool00`00Oomoo`1YOol00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d0
0`00E_eFo@030002E_d00`00E_eFo@05E_d01000E_d000001UKm00<005KmE_d015Km0`001eKm00<0
05KmE_d015Km0`001UKm00<005KmE_d00UKm1@0025Km00<005KmE_d00`000UKm00<005KmE_d01UKm
00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01EKm0`001UKm
00<005KmE_d015Km10001UKm00<005KmE_d00eKm00<005Km00001TEA0P0000=Fo@00AE401DEA0P00
00=Fo@00AE401DEA00<004EAAE4014EA00<004EAAE4014EA00<004EAAE4014EA00D007[?N/mjc`00
00I5D@030015DDEA00=5D@03001ncgk?009nc`030015DDEA00A5D@030015DDEA00A5D@05001ncWk>
O/h00003O/h00`00AE55D@03AE401@00O/incWk>00000gk>00<004EAAE4014EA00D007k>O/incP00
009ncP04001ncWk>O/h30002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d0
0`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04
E_d30006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d00`00E_eFo@030002E_d20007E_d01000E_d000001EKm00<005KmE_d015Km10001UKm00<005Km
E_d00eKm10001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<0
05KmE_d00`000UKm00<007oo000037oo00H8@TYBOomoocW><H`3Ool00`00Oomoo`02Ool00`00Oomo
o`0=Ool0031oo`03001oogoo06]oo`03001FoEKm00AFo@<000MFo@03001FoEKm00AFo@<000IFo@03
001FoEKm00AFo@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03
001FoEKm00EFo@H000=Fo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm
00AFo@<000MFo@03001FoEKm009Fo@80009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001F
oEKm00EFo@03001FoEKm00<00003E_d004EA00E5D@800003E_d004EA00E5D@800003E_d004EA00E5
D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00A5D@05001jcg[?N/l00006AE400`00AE55
D@03AE400`00O/mnc`02O/l00`00AE55D@04AE400`00AE55D@04AE401@00O/incWk>00000gk>00<0
04EAAE400dEA00D007k>O/incP0000=ncP030015DDEA00A5D@05001ncWk>O/h00002O/h01000O/in
cWk>0P0015Km00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm0`00
00=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005Km
E_d01EKm00@005Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@8000EF
o@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@03001FoEKm00<0009Fo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001oo`00
00]oo`05000@Q000000aS004Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool0031oo`03001oogoo06ao
o`03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001F
oEKm00<000=Fo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm009Fo@D0
00MFo@03001FoEKm009Fo@80009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EF
o@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d30007E_d0
0`00E_eFo@04E_d30002E_d00`00E_d00006AE4200000eKm0015D@05AE4200000eKm0015D@05AE40
0`00AE55D@04AE400`00AE55D@04AE400`00AE55D@04AE401@00N/mjcg[?00001TEA00<004EAAE40
0dEA00<007k?O/l00Wk?00<004EAAE4014EA00<004EAAE4014EA00D007k>O/incP0000=ncP030015
DDEA00=5D@05001ncWk>O/h00003O/h00`00AE55D@04AE401@00O/incWk>00000Wk>00@007k>O/in
cP8000EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@04001Fo@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04
E_d20008E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@03E_d40006E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eF
o@06E_d00`00Ool0000:Ool00`00Oomoo`06Ool01R48DYAoogooDY@Q20moo`00<7oo00@007oo0000
06aoo`8000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@80
009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@H0009Fo@03001FoEKm00IF
o@04001Fo@000005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d30008E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d01P00E_eFo@00
E_d000I5D@800003E_d004EA00E5D@800003E_d004EA00E5D@030015DDEA00A5D@030015DDEA00A5
D@030015DDEA00A5D@05001jcg[?N/l00006AE400`00AE55D@03AE400`00O/mnc`02O/l00`00AE55
D@04AE400`00AE55D@04AE401@00O/incWk>00000gk>00<004EAAE400dEA00D007k>O/incP0000=n
cP030015DDEA00A5D@05001ncWk>O/h00002O/h01000O/incWk>0P0015Km10001UKm00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<005Km
E_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm0`001UKm00<005KmE_d0
15Km10001UKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm0`0000=Fo@00E_d01UKm00<005Km
E_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EF
o@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000Yoo`03001oogoo00Ioo`06HaPHaW>LLi`H
aV<H3goo000`Ool2001_Ool00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d00`00
E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005KmE_d015Km0`001eKm00<005Km
E_d00UKm1@001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`000UKm00<005KmE_d01UKm00<0
05KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01EKm0`001UKm00<0
05KmE_d015Km10001UKm00D005Km001Fo@0000I5D@800003E_d004EA00E5D@800003E_d004EA00E5
D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00A5D@05001jcg[?N/l00006AE400`00AE55
D@03AE400`00O/mnc`02O/l00`00AE55D@04AE400`00AE55D@03AE400`00O/incP02O/h01@00O/in
cWk>00001DEA00D007k>O/incP0000=ncP030015DDEA00A5D@05001ncWk>O/h00002O/h01000O/in
cWk>0P0000AFo@000000009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03
001FoEKm00<0009Fo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AF
o@@000EFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@03001FoEKm00<0009Fo@8000MFo@04001Fo@000005E_d00`00E_eFo@04E_d30006E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00
E_eFo@030002E_d30009Ool50005Ool015[F2488@V<H47oo000`Ool00`00Oomoo`1_Ool00`00E_eF
o@04E_d30007E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@030002
E_d00`00E_eFo@06E_d60002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@05E_d3
0006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@02E_d20002E_d0
0`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d200000eKm0015D@05AE4200000eKm
0015D@05AE4200000eKm0015D@05AE400`00AE55D@04AE400`00AE55D@04AE400`00AE55D@04AE40
1@00N/mjcg[?00001TEA00<004EAAE400dEA00<007k?O/l00Wk?00<004EAAE4014EA00<004EAAE40
0dEA00<007k>O/h00Wk>00D007k>O/incP0000E5D@05001ncWk>O/h00003O/h00`00AE55D@04AE40
1@00O/incWk>00000Wk>00@007k>O/incP<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AF
o@<000IFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@04E_d40006E_d0
0`00E_eFo@04E_d40006E_d20005E_d30008E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d00`00E_eF
o@04E_d40006E_d00`00Ool0000VOol0031oo`03001oogoo071oo`03001FoEKm00<000=Fo@03001F
oEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EF
o@<000IFo@03001FoEKm00=Fo@D000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@80009F
o@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001F
oEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d300000eKm0015
D@05AE4200000eKm0015D@05AE4200000eKm0015D@05AE400`00AE55D@04AE400`00AE55D@04AE40
0`00AE55D@04AE401@00N/mjcg[?00001TEA00<004EAAE400dEA00<007k?O/l00Wk?00<004EAAE40
14EA00<004EAAE400dEA00<007k>O/h00Wk>00D007k>O/incP0000E5D@05001ncWk>O/h00003O/h0
0`00AE55D@04AE401@00O/incWk>00000Wk>00@007k>O/incP8000QFo@03001FoEKm00<0009Fo@03
001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@04
E_d40006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d20008E_d00`00E_eFo@030002E_d0
0`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eF
o@06E_d30005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@02E_d3
00000eKm001Fo@06E_d00`00E_eFo@040002E_d00`00E_eFo@05E_d00`00Ool0000VOol0031oo`03
001oogoo075oo`8000MFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm
009Fo@80009Fo@03001FoEKm00EFo@03001Fo@0000<000=Fo@03001FoEKm00EFo@03001FoEKm00<0
009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d3
0006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03
0002E_d00`00E_d00006AE4200000eKm0015D@05AE4200000eKm0015D@05AE400`00AE55D@04AE40
0`00AE55D@04AE400`00AE55D@04AE401@00N/mjcg[?00001TEA00<004EAAE400dEA00<007k?O/l0
0Wk?00<004EAAE4014EA00<004EAAE400dEA00<007k>O/h00Wk>00D007k>O/incP0000E5D@05001n
cWk>O/h00003O/h00`00AE55D@04AE401@00O/incWk>00000Wk>00@007k>O/incP<000IFo@@000IF
o@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@8000QFo@03001FoEKm00<0009Fo@03001FoEKm
00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@<0
00IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm009Fo@<00003E_d0
05Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@04001Fo@000005E_d00`00E_eFo@03E_d40007E_d00`00E_eFo@03E_d300000goo001oo`0TOol0
02moo`03001oogoo07Aoo`03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001F
oEKm00<000=Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@04E_d30007E_d00`00E_eF
o@04E_d30006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00
E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d30006E_d00`00
E_eFo@04E_d30005E_d00`00E_d00006AE4200000eKm0015D@05AE40100000X000001TEA00<004EA
AE4014EA00<004EAAE4014EA00<004EAAE400dEA00<007[?N/l00W[?00<004EAAE4014EA00<004EA
AE400dEA00<007k?O/l00Wk?00<004EAAE4014EA00<004EAAE400dEA00D007k>O/incP0000AncP03
0015DDEA00=5D@05001ncWk>O/h00003O/h00`00AE55D@04AE401@00O/incWk>00000Wk>00@007k>
O/incP800004E_d005KmE_d30002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@02E_d200000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eF
o@06E_d00`00E_eFo@030002E_d20007E_d01000E_d000001EKm00<005KmE_d00eKm10001UKm00<0
05KmE_d015Km10001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01UKm
00<005KmE_d00`000UKm00@007ooOol002Aoo`00;goo00<007ooOol0MGoo00<005KmE_d015Km0`00
1UKm00<005KmE_d015Km0`001eKm00<005KmE_d015Km0P0025Km00<005KmE_d00`000eKm00<005Km
E_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d01EKm
0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001UKm00<005KmE_d00UKm0`000UKm
00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d00eKm00<005Km00001TEA0P0000=Fo@00
AE401DEA00@0000:000000I5D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00=5D@03001j
cg[?009jc`030015DDEA00A5D@030015DDEA00=5D@03001ncgk?009nc`030015DDEA00A5D@030015
DDEA00=5D@05001ncWk>O/h00004O/h00`00AE55D@03AE401@00O/incWk>00000gk>00<004EAAE40
14EA00D007k>O/incP00009ncP04001ncWk>O/h2000015Km000000001UKm00<005KmE_d015Km1000
1UKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm0P0000=Fo@00E_d01eKm00<005KmE_d00`00
0UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000AFo@03001F
oEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0
009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03
001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000IFo@03001oo`0002Aoo`00;goo00<007ooOol0
MWoo00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<0
05KmE_d00`000UKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km
0`001eKm00<005KmE_d00UKm0P000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d0
1EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@005Km000000IFo@03001FoEKm00AFo@<000IF
o@03001FoEKm009Fo@03001Fo@0000I5D@800003E_d004EA00E5D@0400002P000006AE400`00AE55
D@04AE400`00AE55D@04AE400`00AE55D@03AE400`00N/mjc`02N/l00`00AE55D@04AE400`00AE55
D@03AE400`00O/mnc`02O/l00`00AE55D@04AE400`00AE55D@03AE401@00O/incWk>000017k>00<0
04EAAE400dEA00D007k>O/incP0000=ncP030015DDEA00=5D@03001ncWk>009ncP04001ncWk>0003
O/h30002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002
E_d00`00E_eFo@06E_d01000E_d0000015Km00<005KmE_d015Km10001UKm00<005KmE_d015Km1000
1UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`00
0UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km
10001UKm00<005KmE_d015Km10001UKm00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<0
009Fo@03001FoEKm00IFo@03001oo`0002=oo`00;goo0`00Mgoo0P001UKm00<005KmE_d015Km0`00
1UKm00<005KmE_d015Km10001UKm00@005KmE_eFo@<0009Fo@03001FoEKm00IFo@03001FoEKm00<0
009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00
E_eFo@04E_d30007E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d20009E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_eFo@0200000eKm0015D@05AE4200000eKm0015D@05AE401000
00X000001TEA00<004EAAE4014EA00<004EAAE4014EA00<004EAAE400dEA00<007[?N/l00W[?00<0
04EAAE4014EA00<004EAAE400dEA00<007k?O/l00Wk?00<004EAAE4014EA00<004EAAE400dEA00D0
07k>O/incP0000AncP030015DDEA00=5D@05001ncWk>O/h00003O/h00`00AE55D@03AE400`00O/in
cP02O/h01000O/incP000gk>0P0015Km00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm
00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm
00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km1000
1UKm00<005KmE_d015Km10001UKm00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<0009F
o@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eF
o@04E_d40006E_d00`00E_eFo@04E_d300000goo001oo`0QOol002moo`03001oogoo07Qoo`03001F
oEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EF
o@@000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000QF
o@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001F
oEKm00<0009Fo@03001FoEKm00IFo@<000IFo@03001FoEKm00AFo@<00004E_d005Km0006AE420000
0eKm0015D@05AE40100000X000001TEA00<004EAAE4014EA00<004EAAE4014EA00<004EAAE400dEA
00<007[?N/l00W[?00<004EAAE4014EA00<004EAAE400dEA00<007k?O/l00Wk?00<004EAAE4014EA
00<004EAAE400dEA00D007k>O/incP0000AncP030015DDEA00=5D@05001ncWk>O/h00003O/h00`00
AE55D@03AE400`00O/incP02O/h01000O/incP000gk>00<005KmE_d015Km00<005KmE_d00`000UKm
00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005Km
E_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm
0P0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm0P00
1UKm00@005Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm
00AFo@8000QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001oo`00
029oo`00;goo00<007ooOol0NGoo00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00@0
05KmE_eFo@D000QFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001F
oEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000IFo@03
001FoEKm00AFo@<000IFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@05
001Fo@00E_d00006AE4200000eKm0015D@05AE40100000X000001TEA00<004EAAE4014EA00<004EA
AE4014EA00<004EAAE400dEA00<007[?N/l00W[?00<004EAAE4014EA00<004EAAE400dEA00<007k?
O/l00Wk?00<004EAAE4014EA00<004EAAE400dEA00D007k>O/incP0000AncP030015DDEA00=5D@05
001ncWk>O/h00003O/h00`00AE55D@03AE400`00O/incP02O/h01000O/incP000gk>00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm0P00
0UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<0
05KmE_d01UKm00@005Km000000AFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03
001FoEKm00AFo@8000QFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03
001FoEKm00IFo@03001FoEKm00<00003E_d005Km00MFo@<000IFo@03001FoEKm00AFo@@000IFo@03
001oo`00025oo`00;Woo00<007ooOol0Ngoo00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`000eKm00<005KmE_d01EKm1P000UKm00<005KmE_d01EKm0`001eKm00<005KmE_d015Km0`00
1UKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0P000UKm00<005KmE_d01EKm00<005KmE_d0
0`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@005Km000000EFo@03
001FoEKm00AFo@@000IFo@800003E_d004EA00E5D@800003E_d004EA00E5D@0400002P000006AE40
0`00AE55D@04AE400`00AE55D@04AE400`00AE55D@03AE400`00N/mjc`02N/l00`00AE55D@04AE40
0`00AE55D@03AE400`00O/mnc`02O/l00`00AE55D@04AE400`00AE55D@03AE401@00O/incWk>0000
17k>00<004EAAE400dEA00D007k>O/incP0000=ncP030015DDEA00=5D@05001ncWk>O/h00003O/h0
1@00O/incWk>00000eKm0`0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005Km
E_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00AFo@<000IFo@03001FoEKm
00AFo@@000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001F
oEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<00003E_d005Km00MFo@<000IFo@03001FoEKm
00AFo@@000IFo@03001FoEKm00AFo@@000EFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001F
oEKm00<0009Fo@03001FoEKm00EFo@04001oogoo000POol002ioo`03001oogoo07aoo`8000IFo@03
001FoEKm00AFo@<000MFo@04001FoEKmE_d60006E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000
E_d000001EKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0P00
25Km00<005KmE_d00`000eKm00<005KmE_d01EKm00<005Km00001TEA0P0000=Fo@00AE401DEA00@0
000:000000I5D@030015DDEA00A5D@030015DDEA00A5D@030015DDEA00=5D@03001jcg[?009jc`03
0015DDEA00A5D@030015DDEA00=5D@03001ncgk?009nc`030015DDEA00A5D@030015DDEA00=5D@05
001ncWk>O/h00004O/h00`00AE55D@03AE401@00O/incWk>000017k>00<004EAAE400TEA00D007k>
O/incP0000=ncP06001ncWk>O/h005Km0P001EKm00<005KmE_d015Km10001EKm00<005KmE_d015Km
10001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`00
0UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km
10001UKm00<005KmE_d015Km10001EKm00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d0
0`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@005Km000000EFo@03
001FoEKm00AFo@@000IFo@03001FoEKm00=Fo@<00003Ool007oo01moo`00;Woo00<007ooOol0OGoo
00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm1P000UKm00<005KmE_d01EKm00@0
05Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<0
00QFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03
001FoEKm00<0009Fo@03001FoEKm00EFo@<000MFo@03001FoEKm00AFo@03001Fo@0000I5D@800003
E_d004EA00E5D@0400002P000006AE400`00AE55D@04AE400`00AE55D@05AE400`00AE55D@02AE40
0`00N/mjc`02N/l00`00AE55D@05AE400`00AE55D@02AE400`00O/mnc`02O/l00`00AE55D@05AE40
0`00AE55D@02AE401@00O/incWk>000017k>00<004EAAE400dEA00D007k>O/incP0000AncP030015
DDEA0095D@05001ncWk>O/h00003O/h01000O/incWk>0P0025Km00<005KmE_d00`000UKm00<005Km
E_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01UKm
0`001EKm00<005KmE_d015Km10001UKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm0P0000=F
o@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm0P001UKm00@0
05Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00=Fo@<0
00QFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@04001oogoo000OOol0
02ioo`03001oogoo07ioo`03001FoEKm00AFo@<000IFo@03001FoEKm00=Fo@D000IFo@03001FoEKm
00AFo@8000QFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm
00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@<000MFo@03001F
oEKm00AFo@<000IFo@03001FoEKm009Fo@80009Fo@03001FoEKm00IFo@03001FoEKm00@00003E_d0
04EA00E5D@800003E_d004EA00E5D@0400002P000006AE400`00AE55D@04AE400`00AE55D@05AE40
0`00AE55D@02AE400`00N/mjc`02N/l00`00AE55D@05AE401@00AE55DDEA00001Gk?00<004EAAE40
1DEA00<004EAAE400TEA00D007k>O/incP0000AncP030015DDEA00=5D@05001ncWk>O/h00004O/h0
0`00AE55D@02AE401@00O/incWk>00000gk>00@007k>O/incP8000QFo@<000IFo@03001FoEKm00AF
o@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm009Fo@<00003E_d005Km00IFo@03001FoEKm
00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000004E_d0
0`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@03E_d30008E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002
E_d00`00E_eFo@06E_d30006E_d00`00E_eFo@03E_d40006E_d01000Oomoo`007Woo000^Ool00`00
Oomoo`1oOol00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_d000030003E_d00`00E_eFo@05
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d30007E_d00`00E_eFo@04E_d30006E_d00`00E_eF
o@04E_d30007E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00
E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d015Km
10000eKm00<005Km00001TEA0P0000=Fo@00AE401DEA00@0000:000000I5D@030015DDEA00A5D@03
0015DDEA00E5D@030015DDEA0095D@03001jcg[?00=jc`030015DDEA00A5D@050015DDEAAE400006
O/l00`00AE55D@04AE400`00AE55D@02AE401@00O/incWk>000017k>00<004EAAE400dEA00D007k>
O/incP0000AncP030015DDEA0095D@05001ncWk>O/h00003O/h01`00O/incWk>001Fo@0000AFo@<0
0003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001F
oEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d40006E_d00`00
E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00
E_eFo@05E_d2000015Km000000000UKm00<005KmE_d01UKm0`001UKm00<005KmE_d015Km10001UKm
00<005KmE_d00eKm10001UKm00<005KmE_d00UKm0`0000=Fo@00E_d01UKm00<005KmE_d00`000UKm
00<005KmE_d01UKm00<007oo00007Woo000^Ool30020Ool20006E_d00`00E_eFo@03E_d40007E_d0
0`00E_eFo@04E_d30006E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@06E_d00`00E_eFo@030002
E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm00<005Km
E_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`00
0UKm00<005KmE_d00UKm00<005Km00001TEA0P0000=Fo@00AE401DEA00@0000:000000I5D@030015
DDEA00A5D@030015DDEA00E5D@030015DDEA0095D@03001jcg[?00=jc`030015DDEA00A5D@050015
DDEAAE400006O/l00`00AE55D@04AE400`00AE55D@02AE401@00O/incWk>000017k>00<004EAAE40
0dEA00D007k>O/incP0000AncP030015DDEA0095D@05001ncWk>O/h00003O/h01@00O/incWk>0000
0UKm00@005Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm
00AFo@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm
00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@<000IFo@03001FoEKm00AFo@@000IFo@03001F
oEKm00AFo@<000IFo@03001FoEKm009Fo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001F
oEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d3
0006E_d00`00E_eFo@04E_d300000goo001oo`0LOol002eoo`8008=oo`03001FoEKm00EFo@03001F
o@0000<000=Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000005
E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d40007E_d00`00
E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@03
0003E_d00`00E_eFo@04E_d30006E_d01`00E_eFoEKm001Fo@0000I5D@800003E_d004EA00E5D@04
00002P000006AE400`00AE55D@04AE400`00AE55D@05AE400`00AE55D@02AE400`00N/mjc`03N/l0
0`00AE55D@04AE401@00AE55DDEA00001Wk?00<004EAAE4014EA00<004EAAE400TEA00D007k>O/in
cP0000AncP030015DDEA00=5D@05001ncWk>O/h00004O/h00`00AE55D@02AE401@00O/incWk>0000
0gk>00D007k>O/incP00009Fo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@@000IFo@03001FoEKm
00AFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm009Fo@800003E_d005Km00MFo@03001F
oEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<00003E_d0000000MFo@04001Fo@000005E_d0
0`00E_eFo@04E_d40006E_d00`00E_eFo@03E_d40006E_d00`00E_eFo@04E_d30008E_d00`00E_eF
o@0300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00Ool0000MOol002eoo`03001oogoo08=o
o`03001FoEKm00=Fo@@000MFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001F
oEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0
00AFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@000MFo@03
001FoEKm00<0009Fo@03001FoEKm00EFo@06001FoEKm001Fo@001TEA0P0000=Fo@00AE401DEA00@0
000:000000I5D@030015DDEA00A5D@030015DDEA00E5D@030015DDEA0095D@03001jcg[?00=jc`03
0015DDEA00A5D@050015DDEAAE400006O/l00`00AE55D@04AE400`00AE55D@02AE401@00O/incWk>
000017k>00<004EAAE400dEA00D007k>O/incP0000AncP030015DDEA0095D@05001ncWk>O/h00003
O/h01000O/incWk>0`000eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005Km
E_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`0000=Fo@00E_d0
1eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000AFo@03001FoEKm00AFo@@000IF
o@03001FoEKm00AFo@@000EFo@8000EFo@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03
001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@@000EFo@03
001FoEKm00AFo@@000IFo@03001oo`0001aoo`00;Goo00<007ooOol0Q7oo00<005Km00000`000eKm
00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005Km
E_d015Km0`001eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`0025Km00<005KmE_d00`00
0UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<0
05KmE_d01EKm0`001UKm00<005KmE_d015Km100000=Fo@00AE401DEA0P0000=Fo@00AE401DEA00@0
000:000000I5D@030015DDEA00A5D@030015DDEA00E5D@030015DDEA0095D@03001jcg[?00=jc`03
0015DDEA00A5D@050015DDEAAE400006O/l00`00AE55D@04AE400`00AE55D@02AE401@00O/incWk>
00001Gk>00<004EAAE400TEA00D007k>O/incP0000AncP030015DDEA0095D@05001ncWk>O/h00003
O/h01@00O/incWk>00001UKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<0
05KmE_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm0`001UKm00<005KmE_d015Km10001EKm00<0
05KmE_d015Km10001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01UKm
00<005KmE_d00`000UKm00<005KmE_d01EKm0P0000AFo@00000000=Fo@03001FoEKm00AFo@@000IF
o@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm00<0009Fo@03001FoEKm
00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001oo`0001]oo`00;Goo00<007ooOol0Pgoo
10001eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000eKm00<0
05KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d0
1UKm0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00UKm0P00
0UKm00<005KmE_d01EKm00<005KmE_d00`000UKm0P0000=Fo@00AE401DEA0P0000=Fo@00AE401DEA
00@0000:000000I5D@030015DDEA00A5D@030015DDEA00E5D@030015DDEA0095D@03001jcg[?00=j
c`030015DDEA00A5D@050015DDEAAE400006O/l00`00AE55D@04AE400`00AE55D@02AE401@00O/in
cWk>00001Gk>00D004EAAE55D@0000AncP03001ncWk>009ncP030015DDEA0095D@05001ncWk>O/h0
0003O/h01@00O/incWk>00001UKm0`001EKm00<005KmE_d015Km10001UKm00<005KmE_d015Km1000
1EKm00<005KmE_d00UKm0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<0
05KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000eKm00<005KmE_d015Km0`001UKm00<0
05KmE_d015Km10001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01UKm
00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01UKm0`001UKm00<0
05KmE_d00eKm10001UKm00<005KmE_d015Km1@006Woo000]Ool00`00Oomoo`21Ool20003Ool00`00
E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d30007E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@02E_d30000
0eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eF
o@06E_d01000E_d000001EKm00<005KmE_d015Km0`001UKm00<005Km00001TEA0P0000=Fo@00AE40
1DEA00@0000:000000I5D@030015DDEA00A5D@030015DDEA00E5D@030015DDEA0095D@03001jcg[?
00=jc`030015DDEA00A5D@050015DDEAAE400006O/l00`00AE55D@04AE400`00AE55D@02AE401@00
O/incWk>00001Gk>00D004EAAE55D@0000AncP03001ncWk>009ncP030015DDEA0095D@05001ncWk>
O/h00003O/h01@00O/incWk>00000eKm0`0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005Km
E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00AFo@@0
00IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm00<00003E_d005Km
00MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<00003E_d0000000MFo@<000IF
o@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm009Fo@<00003E_d005Km
00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001oo`0001Yoo`00
;Goo00<007ooOol0OWoo0`001Woo00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001UKm00<0
05KmE_d00UKm0P000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`000UKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm
00AFo@<000IFo@03001FoEKm00AFo@<000QFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@03001F
o@0000I5D@800003E_d004EA00E5D@0400002P000006AE400`00AE55D@04AE400`00AE55D@05AE40
0`00AE55D@02AE400`00N/mjc`03N/l00`00AE55D@04AE401@00AE55DDEA00001Wk?00<004EAAE40
14EA00<004EAAE400TEA00D007k>O/incP0000EncP050015DDEAAE400004O/h00`00O/incP02O/h0
0`00AE55D@02AE401@00O/incWk>00000gk>00H007k>O/incP00E_d20005E_d00`00E_eFo@04E_d3
0006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d20008E_d00`00E_eFo@030002E_d00`00
E_eFo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d3
0005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d40005E_d20003E_d300000eKm001Fo@07
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000
E_d000001EKm00<005KmE_d00eKm10001UKm00<005KmE_d015Km10001UKm00<007oo00006Goo000]
Ool01000Ool00000NWoo0`002Woo00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`00
0UKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<0
00IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@03001FoEKm00<0
009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@@000IFo@03001FoEKm00=F
o@03001Fo@0000I5D@800003E_d004EA00E5D@0400002P000006AE400`00AE55D@04AE400`00AE55
D@05AE400`00AE55D@02AE400`00N/mjc`03N/l00`00AE55D@04AE401@00AE55DDEA00001Wk?00<0
04EAAE4014EA00<004EAAE400TEA00D007k>O/incP0000EncP050015DDEAAE400004O/h00`00O/in
cP02O/h00`00AE55D@02AE401@00O/incWk>00000gk>00@007k>O/incP8000QFo@03001FoEKm00<0
009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03
001FoEKm00AFo@@000IFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm
009Fo@<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009F
o@03001FoEKm00EFo@@000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00=Fo@@000IFo@03001F
oEKm00AFo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0009Fo@03001F
oEKm00EFo@03001oo`0001Uoo`00;7oo0`00NGoo0`003Woo0P001eKm00<005KmE_d015Km0`001UKm
00<005KmE_d015Km0`001eKm00<005KmE_d00`000eKm00<005KmE_d01EKm00<005KmE_d00`000UKm
00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km0`001eKm00<005KmE_d015Km0`00
1UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`00
00=Fo@00AE401DEA0P0000=Fo@00AE401DEA00@0000:000000I5D@030015DDEA00A5D@030015DDEA
00E5D@050015DDEAAE400006N/l00`00AE55D@04AE401@00AE55DDEA00001Wk?00<004EAAE4014EA
00<004EAAE400TEA00D007k>O/incP0000EncP050015DDEAAE400003O/h00`00O/incP03O/h00`00
AE55D@02AE401@00O/incWk>00000gk>00L007k>O/incP00E_d00006E_d40006E_d00`00E_eFo@04
E_d30006E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eF
o@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d01000E_d000001EKm
00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm10001eKm00<005Km
E_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`00
0UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm0`0000=oo`00
Ool05goo000/Ool00`00Oomoo`1fOol3000COol00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00
E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d30006E_d0
0`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d0
0`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d40002
E_d00`00E_d00006AE4200000eKm0015D@05AE40100000X000001TEA00<004EAAE4014EA00<004EA
AE401DEA00D004EAAE55D@0000Ijc`030015DDEA00A5D@050015DDEAAE400006O/l00`00AE55D@04
AE400`00AE55D@02AE401@00O/incWk>00001Gk>00D004EAAE55D@0000=ncP03001ncWk>00=ncP03
0015DDEA0095D@05001ncWk>O/h00003O/h01@00O/incWk>00000UKm00<005KmE_d00`000UKm00<0
05KmE_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm
0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`0025Km
00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d0
0`000eKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm10001UKm00<005KmE_d015Km10001UKm
00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`000UKm00@007ooOol001Moo`00;7oo00<007ooOol0Lgoo0`005goo00<005KmE_d015Km0`00
1UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`00
0UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km
10001UKm00<005KmE_d015Km0`001UKm00<005KmE_d00UKm0P000UKm00<005KmE_d01EKm00<005Km
E_d00`000UKm00L005KmE_eFo@00E_d00006AE4200000eKm0015D@05AE40100000X000001TEA00<0
04EAAE4014EA00<004EAAE401DEA00D004EAAE55D@0000Ijc`030015DDEA00A5D@050015DDEAAE40
0006O/l00`00AE55D@04AE400`00AE55D@02AE401@00O/incWk>00001Gk>00D004EAAE55D@0000=n
cP03001ncWk>00=ncP030015DDEA0095D@05001ncWk>O/h00003O/h01@00O/incWk>00000UKm0`00
1UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001UKm00<005KmE_d00UKm0P000UKm00<0
05KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm
00<005KmE_d00`000eKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001UKm00<005KmE_d0
15Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d0
1UKm00<005KmE_d00`000UKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km10001UKm00<005Km
E_d00eKm10001UKm00<007oo00005goo000/Ool00`00Oomoo`1`Ool3000KOol00`00E_eFo@030002
E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d30006E_d00`00E_eFo@04E_d4
0006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@05E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d01000E_d000001EKm
00<005KmE_d015Km0`001UKm00H005KmE_d005Km0006AE4200000eKm0015D@06AE430006AE400`00
AE55D@04AE400`00AE55D@05AE401@00AE55DDEA00001W[?00<004EAAE4014EA00D004EAAE55D@00
00Inc`030015DDEA00A5D@050015DDEAAE400004O/h00`00O/incP03O/h01@00AE55DDEA00000gk>
00<007k>O/h00gk>00<004EAAE400TEA00D007k>O/incP0000=ncP04001ncWk>O/h30002E_d00`00
E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06
E_d01000E_d000001EKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001EKm00<005KmE_d0
15Km10001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d0
1UKm00<005KmE_d00`0000=Fo@00E_d01eKm0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d0
15Km10001UKm00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00EF
o@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001oo`0001Ioo`000Woo00AJePQ2000icPIoo`03
:DX002U:00Ioo`036<I:DWoo00Aoo`06BU88@P00000Q27>L2Woo00<007ooOol0KGoo0`007goo0P00
1UKm00<005KmE_d015Km0`001UKm00<005KmE_d00UKm0P000UKm00<005KmE_d01EKm00<005KmE_d0
0`000eKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@005Km000000EFo@03
001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@05001Fo@00E_d00006AE4200000eKm0015D@06AE430006AE400`00
AE55D@04AE400`00AE55D@05AE401@00AE55DDEA00001W[?00<004EAAE4014EA00D004EAAE55D@00
00Inc`030015DDEA00A5D@050015DDEAAE400004O/h00`00O/incP03O/h01@00AE55DDEA00000gk>
00<007k>O/h00gk>00<004EAAE400TEA00D007k>O/incP0000=ncP05001ncWk>O/h00005E_d00`00
E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30008E_d00`00E_eFo@03
00000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00
E_eFo@04E_d40006E_d00`00E_eFo@03E_d40006E_d00`00E_eFo@04E_d40005E_d00`00E_eFo@02
E_d300000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00
E_eFo@05E_d01000E_d000001EKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm10001UKm00<0
05KmE_d015Km1@005Goo00000gooHaPHaP02Li`00a24DYAoo`04Ool30006Ool00e:D8@Qoo`04Ool0
1PQ2@Q1oogoo>LhQ20Yoo`03001oogoo06]oo`8002=oo`03001FoEKm00EFo@03001FoEKm00<0009F
o@03001FoEKm00EFo@04001Fo@000005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@04E_d30006
E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002
E_d00`00E_eFo@06E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d3
00000eKm0015D@05AE4200000eKm0015D@06AE430006AE400`00AE55D@04AE400`00AE55D@05AE40
1@00AE55DDEA00001W[?00<004EAAE4014EA00D004EAAE55D@0000Inc`030015DDEA00A5D@050015
DDEAAE400004O/h00`00O/incP03O/h01@00AE55DDEA00000gk>00<007k>O/h00gk>00<004EAAE40
0TEA00D007k>O/incP0000=ncP05001ncWk>O/h00006E_d00`00E_eFo@0300000eKm001Fo@07E_d0
0`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d40005E_d0
0`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d01000
E_d000001EKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0P00
25Km00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<0
05KmE_d00`000UKm00<007oo00005Goo00000goo8@QBU002Ool00e:D6<Ioo`04Ool00bU:000YBP07
Ool00`00Liaoo`08Ool00`00Oomoo`07Ool00`00Oomoo`1YOol3000VOol00`00E_eFo@04E_d30006
E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002
E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d3
0006E_d00`00E_eFo@04E_d40007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03
0002E_d00`00E_d00006AE4200000eKm0015D@06AE430006AE400`00AE55D@04AE400`00AE55D@05
AE401@00AE55DDEA00001W[?00<004EAAE4014EA00D004EAAE55D@0000Inc`030015DDEA00A5D@05
0015DDEAAE400004O/h00`00O/incP03O/h01@00AE55DDEA00000gk>00<007k>O/h00gk>00<004EA
AE400TEA00D007k>O/incP0000=ncP05001ncWk>O/h00005E_d40005E_d00`00E_eFo@04E_d40006
E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002
E_d00`00E_eFo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d30006E_d00`00E_eFo@04E_d30006
E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@03E_d30008E_d00`00E_eFo@030002E_d00`00E_eF
o@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d4
0006E_d00`00E_eFo@03E_d40006E_d00`00E_eFo@04E_d40006E_d2000EOol00003Ool007oo00=o
o`03001oogoo00eoo`03:DY:DWoo00Moo`03Li`007oo00Qoo`03001oogoo06Ioo`<002Yoo`03001F
oEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@<000IFo@03001F
oEKm00AFo@@000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03
001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@<000IFo@03
001FoEKm00AFo@<000EFo@03001Fo@0000I5D@800003E_d004EA00I5D@<000I5D@030015DDEA00A5
D@030015DDEA00E5D@050015DDEAAE400006N/l00`00AE55D@04AE401@00AE55DDEA00001Wk?00<0
04EAAE4014EA00D004EAAE55D@0000AncP03001ncWk>00=ncP050015DDEAAE400003O/h00`00O/in
cP03O/h00`00AE55D@02AE401@00O/incWk>00000gk>00D007k>O/incP00009Fo@<0009Fo@03001F
oEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<00003E_d005Km00MFo@<0
00IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@000EFo@03001FoEKm009Fo@<00003E_d0
05Km00MFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03
001FoEKm00<000=Fo@03001FoEKm00AFo@@000IFo@03001FoEKm00=Fo@@000IFo@03001FoEKm00AF
o@@000IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IF
o@03001FoEKm00<0009Fo@03001FoEKm00EFo@8001Eoo`0000=oo`00Ool00goo00<007ooOol03Goo
00=BU248Ool00goo00H8@TYBOomoocW><H`9Ool3001SOol3000^Ool20006E_d00`00E_eFo@04E_d3
0007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d0
0`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d30006E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@03
E_d00`00E_d00006AE4200000eKm0015D@06AE430006AE400`00AE55D@04AE400`00AE55D@05AE40
1@00AE55DDEA00001W[?00<004EAAE4014EA00D004EAAE55D@0000Inc`030015DDEA00A5D@050015
DDEAAE400003O/h00`00O/incP04O/h01@00AE55DDEA00000gk>00<007k>O/h00gk>00<004EAAE40
0TEA00D007k>O/incP0000=ncP04001ncWk>O/h30006E_d00`00E_eFo@04E_d30006E_d00`00E_eF
o@04E_d40005E_d00`00E_eFo@02E_d300000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@07
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d015Km10001EKm
00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d0
1EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d015Km1000
1UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00@005KmE_eFo@<00003Ool007oo
01Aoo`0000=oo`00Ool00goo00<007ooOol03Woo00<007>LOol00Woo00D001240000036<00Yoo`03
001oogoo061oo`<0039oo`03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@<000IF
o@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@000MFo@03001FoEKm00<0009Fo@03001FoEKm
00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04
001Fo@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@02E_d00`00E_d00006AE40100000X0
00001dEA0`001TEA00<004EAAE4014EA00<004EAAE401DEA00D004EAAE55D@0000Ijc`030015DDEA
00A5D@050015DDEAAE400006O/l00`00AE55D@04AE401@00AE55DDEA00000gk>00<007k>O/h017k>
00D004EAAE55D@0000=ncP03001ncWk>00=ncP030015DDEA0095D@05001ncWk>O/h00003O/h01000
O/incWk>0P0025Km00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005Km
E_d01EKm00@005Km000000EFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000IFo@03001F
oEKm00AFo@8000QFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001F
oEKm00IFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000IFo@03
001FoEKm00AFo@@000IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<00003E_d0
05Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000005Ool00`00Oomoo`0BOol0
0003OolQ25:D009oo`03DY@Q27oo00moo`03:DY:DWoo009oo`03001oogoo00aoo`03001oogoo05eo
o`<003Ioo`03001FoEKm00AFo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00EFo@<000IFo@03001FoEKm
00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0009F
o@03001FoEKm00IFo@03001FoEKm00800003E_d004EA00E5D@0400002P000007AE430006AE400`00
AE55D@04AE400`00AE55D@05AE401@00AE55DDEA00001W[?00<004EAAE4014EA00D004EAAE55D@00
00Inc`030015DDEA00A5D@050015DDEAAE400003O/h00`00O/incP04O/h01@00AE55DDEA00000gk>
00<007k>O/h00gk>00<004EAAE400TEA00D007k>O/incP0000=ncP07001ncWk>O/h005Km00001UKm
10001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<0
05KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d0
15Km10001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d00`000UKm
00<005KmE_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d0
1EKm0`001UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm0`00
1goo00<007ooOol04Woo00000gooHaPHaP02Li`00aS6HaQoo`0;Ool01PQ2OomoogooF]HQ20=oo`03
001oogoo00aoo`03001oogoo05Yoo`<003Yoo`03001FoEKm00<0009Fo@03001FoEKm00EFo@<000IF
o@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm009Fo@80009Fo@03001F
oEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EF
o@03001FoEKm00<000=Fo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@00004E_d005Km0006
AE40100000X000001dEA0`001TEA00<004EAAE4014EA00<004EAAE401DEA00D004EAAE55D@0000Ij
c`030015DDEA00A5D@050015DDEAAE400006O/l00`00AE55D@04AE401@00AE55DDEA00000gk>00<0
07k>O/h017k>00D004EAAE55D@0000=ncP03001ncWk>00=ncP030015DDEA0095D@05001ncWk>O/h0
0002O/h00`00O/incP02O/h01000E_eFo@000UKm0`000UKm00<005KmE_d01UKm00<005KmE_d00`00
00=Fo@00E_d01eKm00<005KmE_d00`000eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`00
1UKm00<005KmE_d015Km10001UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`00
00=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km1000
1EKm00<005KmE_d015Km10001UKm00@005KmE_eFo@<00003E_d005Km00MFo@03001FoEKm00<0009F
o@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000Yoo`03001o
ogoo019oo`000Woo00AJePQ2249S60eoo`H000=oo`D000Uoo`03001oogoo05Qoo`<003ioo`8000IF
o@03001FoEKm009Fo@80009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03
001FoEKm00<0009Fo@03001FoEKm00IFo@04001Fo@000005E_d00`00E_eFo@04E_d30006E_d00`00
E_eFo@04E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d0
0`00E_eFo@030002E_d01P00E_eFo@00E_d000I5D@0400002P000007AE430006AE400`00AE55D@04
AE400`00AE55D@05AE401@00AE55DDEA00001W[?00<004EAAE4014EA00D004EAAE55D@0000Inc`03
0015DDEA00A5D@050015DDEAAE400003O/h00`00O/incP04O/h01@00AE55DDEA00000gk>00<007k>
O/h00gk>00<004EAAE400TEA00D007k>O/incP00009ncP03001ncWk>009ncP03001FoEKm00<000IF
o@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000MFo@03001FoEKm00<00003E_d005Km00MF
o@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@<000IFo@03
001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm009Fo@800003E_d005Km00MF
o@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001F
o@000005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@03E_d40006E_d00`00E_eFo@04E_d3000=
Ool00`00Oomoo`0BOol002Yoo`03001oogoo05Ioo`80049oo`03001FoEKm00EFo@04001Fo@000005
E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30008E_d00`00
E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03
0003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d01@00E_d005Km00001TEA00@0
000:000000M5D@<000I5D@030015DDEA00A5D@030015DDEA00E5D@050015DDEAAE400006N/l00`00
AE55D@04AE401000AE55D@001gk?00<004EAAE4014EA00D004EAAE55D@0000=ncP03001ncWk>00An
cP050015DDEAAE400003O/h00`00O/incP03O/h00`00AE55D@02AE401@00O/incWk>00000Wk>00<0
07k>O/h00Wk>0`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`000eKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001EKm00<005KmE_d015Km1000
1eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`000UKm00<005KmE_d01UKm00@005Km000000AFo@03001FoEKm00AFo@@000IFo@03001FoEKm
00=Fo@@000IFo@03001FoEKm00AFo@8000QFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001F
oEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<0011oo`03001oogoo019oo`00:Woo00<007oo
Ool0Dgoo0`00AGoo00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<0
05KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km10001UKm00<0
05KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm
00<005KmE_d00`000UKm00<005KmE_d01EKm0P0000=Fo@00AE401DEA00@0000:000000M5D@<000I5
D@030015DDEA00A5D@030015DDEA00E5D@050015DDEAAE400006N/l00`00AE55D@04AE401000AE55
D@001gk?00<004EAAE4014EA00D004EAAE55D@0000=ncP03001ncWk>00AncP050015DDEAAE400003
O/h00`00O/incP03O/h00`00AE55D@02AE401@00O/incWk>00000Wk>00<007k>O/h00Wk>00<005Km
E_d00eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<0
05KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d0
1UKm0`001EKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`00
1eKm00<005KmE_d00`000UKm00<005KmE_d01EKm0P0000AFo@000000009Fo@03001FoEKm00IFo@03
001FoEKm00<0009Fo@03001FoEKm00AFo@@000IFo@03001FoEKm00=Fo@@000IFo@03001FoEKm00AF
o@@001=oo`03001oogoo019oo`00:Woo00<007ooOol0D7oo0`00BGoo00<005KmE_d00`000eKm00<0
05KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d0
0`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm
00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0P0000=Fo@00AE40
1DEA00@0000:000000M5D@<000I5D@030015DDEA00A5D@030015DDEA00E5D@050015DDEAAE400006
N/l00`00AE55D@04AE401000AE55D@001gk?00<004EAAE4014EA00D004EAAE55D@0000=ncP03001n
cWk>00AncP050015DDEAAE400003O/h00`00O/incP04O/h01@00AE55DDEA00000gk>00@007k>O/h0
00=ncP8000IFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00AF
o@@000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm009Fo@<00003
E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<00003E_d005Km00MF
o@03001FoEKm00<0009Fo@03001FoEKm00AFo@@000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm
00AFo@@000IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm
00IFo@03001FoEKm00<001Moo`03001oogoo019oo`00:Woo0`00CGoo0`00CGoo0P001eKm00<005Km
E_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`00
0eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001eKm00<0
05KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d0
0`0000AFo@00E_d000I5D@0400002P000007AE430006AE400`00AE55D@04AE400`00AE55D@05AE40
1@00AE55DDEA00001W[?00<004EAAE4014EA00@004EAAE4000Mnc`030015DDEA00A5D@050015DDEA
AE400003O/h00`00O/incP04O/h01@00AE55DDEA00000gk>00<007k>O/h017k>00D004EAAE55D@00
00=ncP04001ncWk>0003O/h20005E_d40005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@030002
E_d00`00E_eFo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eF
o@05E_d01000E_d000001EKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001EKm00<005Km
E_d015Km10001UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`0000=Fo@000000
1eKm00<005KmE_d00`000UKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0`001UKm00<005Km
E_d015Km10006goo00<007ooOol04Goo000ZOol00`00Oomoo`1:Ool3001BOol00`00E_eFo@04E_d3
0006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00
E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30005E_d20006AE40100000X00000
1dEA0`001TEA00<004EAAE4014EA00<004EAAE401DEA00D004EAAE55D@0000Ijc`030015DDEA00A5
D@040015DDEA0007O/l00`00AE55D@04AE401@00AE55DDEA00000gk>00<007k>O/h017k>00D004EA
AE55D@0000=ncP03001ncWk>00AncP050015DDEAAE400003O/h01000O/incP000gk>0P000UKm0`00
0UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm0`001UKm00<005KmE_d015Km
10001EKm00<005KmE_d015Km10001UKm00<005KmE_d015Km0P0025Km00<005KmE_d00`0000=Fo@00
E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km
0`001UKm00<005KmE_d015Km10001EKm0P001EKm10001UKm00<005KmE_d00`000UKm00<005KmE_d0
1UKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`007goo00<007ooOol04Goo000ZOol0
0`00Oomoo`17Ool3001FOol00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d0
0`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006
E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@02E_d20002E_d00`00E_eFo@05E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d20006AE40100000X00000
1dEA0`001TEA00<004EAAE4014EA00<004EAAE401DEA00D004EAAE55D@0000Ijc`030015DDEA00A5
D@040015DDEA0007O/l00`00AE55D@04AE401@00AE55DDEA00000gk>00<007k>O/h017k>00D004EA
AE55D@0000=ncP03001ncWk>00AncP050015DDEAAE400003O/h01000O/incP000gk>10001UKm00<0
05KmE_d015Km0`001UKm00<005KmE_d00UKm0P000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm
00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`000UKm00<005Km
E_d015Km10001EKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm10001eKm00<005KmE_d00`00
00=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm0P0000AFo@00000000=Fo@03001F
oEKm00AFo@<000IFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@0029oo`03001oogoo015o
o`00:Goo00<007ooOol0AGoo0`00FWoo0P001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km
0`001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm
00<005KmE_d00`000UKm00<005KmE_d01UKm00@005Km000000EFo@03001FoEKm00AFo@<000IFo@03
001FoEKm00AFo@<000IFo@03001FoEKm009Fo@8000I5D@0400002P000007AE400`0000X00006AE40
0`00AE55D@04AE400`00AE55D@05AE401@00AE55DDEA00001W[?00<004EAAE4014EA00@004EAAE40
00Mnc`030015DDEA00A5D@050015DDEAAE400003O/h00`00O/incP04O/h01@00AE55DDEA00000gk>
00<007k>O/h017k>00D004EAAE55D@0000=ncP04001ncWk>0003O/h30008E_d00`00E_eFo@030000
0eKm001Fo@07E_d01000E_d000001EKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm
00<005KmE_d015Km10001UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm
00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km10001EKm00<005KmE_d015Km1000
1UKm00<005KmE_d00eKm10001eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm
00<005KmE_d01EKm00<005KmE_d00`009Woo00<007ooOol04Goo000YOol00`00Oomoo`12Ool3001N
Ool00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00
E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d30008E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d0
0`00E_eFo@030006AE40100000X000001dEA00<0000:00001TEA00<004EAAE4014EA00<004EAAE40
1DEA00@004EAAE4000Mjc`030015DDEA00A5D@040015DDEA0007O/l00`00AE55D@04AE401@00AE55
DDEA00000gk>00<007k>O/h017k>00D004EAAE55D@0000=ncP03001ncWk>00AncP050015DDEAAE40
0003O/h01000O/incP000gk>0P0000=Fo@00E_d01EKm10001EKm00<005KmE_d015Km0`0025Km00<0
05KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000eKm
00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005Km
E_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`00
0eKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm1000:Goo00<0
07ooOol04Goo000YOol00`00Oomoo`0oOol3001ROol00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d40005
E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d300000eKm00000006AE40100000X000001dEA
00<0000:00001TEA00<004EAAE4014EA00<004EAAE401DEA00@004EAAE4000Mjc`030015DDEA00A5
D@040015DDEA0007O/l00`00AE55D@05AE401000AE55D@000gk>00<007k>O/h017k>00D004EAAE55
D@0000=ncP03001ncWk>00AncP050015DDEAAE400003O/h01000O/incP000gk>0P000UKm00<005Km
E_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km10001EKm00<005Km
E_d015Km10001EKm00<005KmE_d015Km10001eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005Km
E_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d015Km10001UKm00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`00;Goo00<007ooOol04Goo000YOol00`00Oomo
o`0mOol2001VOol00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eF
o@05E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d3
0007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@06E_d0
0`00E_eFo@030002E_d01000E_d000001TEA00@0000:000000M5D@0300002P0000I5D@030015DDEA
00A5D@030015DDEA00E5D@040015DDEA0007N/l00`00AE55D@04AE401000AE55D@001gk?00<004EA
AE401DEA00@004EAAE4000=ncP03001ncWk>00AncP050015DDEAAE400003O/h00`00O/incP04O/h0
1000AE55D@0017k>00@007k>O/h000=ncP80009Fo@<000IFo@03001FoEKm00AFo@<000MFo@03001F
oEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0
00=Fo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000IFo@03
001FoEKm00<0009Fo@03001FoEKm00IFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm00<0
0003E_d005Km00MFo@<000IFo@03001FoEKm00=Fo@@000IFo@03001FoEKm00=Fo@@0031oo`03001o
ogoo015oo`00:Goo00<007ooOol0>Woo0`00JGoo0P001UKm00<005KmE_d015Km0`001UKm00<005Km
E_d00UKm0P000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d0
0`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km0`001UKm00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km10001UKm0`001TEA00@0000:000000M5D@0300002P0000I5D@03
0015DDEA00A5D@030015DDEA00E5D@040015DDEA0007N/l00`00AE55D@04AE401000AE55D@0027k?
00<004EAAE4014EA00@004EAAE4000=ncP03001ncWk>00AncP050015DDEAAE400003O/h00`00O/in
cP04O/h01000AE55D@0017k>00@007k>O/h000=ncP@0009Fo@03001FoEKm00EFo@03001FoEKm00<0
00=Fo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03
001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm
00<000=Fo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000EF
o@03001FoEKm009Fo@<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001F
oEKm00<003Aoo`03001oogoo015oo`00:Goo0`00=goo0`00KGoo00<005KmE_d01EKm00<005KmE_d0
0`000UKm00<005KmE_d01EKm00@005Km000000EFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AF
o@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@<000I5D@0400002P00
0007AE400`0000X00006AE400`00AE55D@04AE400`00AE55D@05AE401000AE55D@001g[?00<004EA
AE4014EA00@004EAAE4000Qnc`030015DDEA00A5D@040015DDEA0003O/h00`00O/incP04O/h01@00
AE55DDEA00000gk>00<007k>O/h017k>00@004EAAE4000AncP04001ncWk>0003O/h20005E_d00`00
E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@07
E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@04E_d30006E_d00`00E_eF
o@04E_d30007E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d01000E_d000001EKm00<005KmE_d015Km0`001UKm
00<005KmE_d015Km0`00>7oo00<007ooOol047oo000XOol2000fOol3001aOol00`00E_eFo@04E_d3
0006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm00000006AE40100000X00000
1dEA00<0000:00001TEA00<004EAAE4014EA00<004EAAE401DEA00@004EAAE4000Mjc`030015DDEA
00A5D@040015DDEA0008O/l00`00AE55D@04AE401000AE55D@000gk>00<007k>O/h017k>00D004EA
AE55D@0000=ncP03001ncWk>00AncP040015DDEA0004O/h01000O/incP000gk>0P001UKm00<005Km
E_d00`000UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001EKm00<005KmE_d015Km1000
1UKm00<005KmE_d00`000UKm00<005KmE_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005Km
E_d00`000UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001UKm00<005KmE_d00eKm1000
1UKm00<005KmE_d00eKm0`0025Km00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`00>goo
00<007ooOol047oo000XOol00`00Oomoo`0bOol3001eOol00`00E_eFo@030002E_d00`00E_eFo@05
E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eF
o@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eF
o@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30004E_d20006AE40100000X000001dEA00<0
000:00001TEA00<004EAAE4014EA00<004EAAE401DEA00@004EAAE4000Mjc`030015DDEA00A5D@04
0015DDEA0008O/l00`00AE55D@04AE401000AE55D@000gk>00<007k>O/h017k>00D004EAAE55D@00
00=ncP03001ncWk>00AncP040015DDEA0003O/h01@00O/incWk>00000gk>0P001EKm10001UKm00<0
05KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d0
0`000eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001UKm
00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km10001EKm00<005Km
E_d015Km1000?Woo00<007ooOol047oo000XOol00`00Oomoo`0_Ool3001iOol20006E_d00`00E_eF
o@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eF
o@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00
E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@02E_d20006AE40100000X000001dEA
00<0000:00001TEA00<004EAAE4014EA00<004EAAE401DEA00@004EAAE4000Mjc`030015DDEA00A5
D@040015DDEA0008O/l00`00AE55D@04AE401000AE55D@000gk>00<007k>O/h01Gk>00@004EAAE40
00=ncP03001ncWk>00AncP040015DDEA0003O/h01@00O/incWk>00000gk>0P000UKm0`000eKm00<0
05KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d0
0`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<0
05KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d0
15Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`00@Woo00<007ooOol0
47oo000XOol00`00Oomoo`0/Ool3001mOol00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eF
o@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002
E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00
E_eFo@04E_d30006E_d01000E_eFoEKm0P001TEA00@0000:000000M5D@0300002P0000I5D@030015
DDEA00A5D@030015DDEA00E5D@040015DDEA0007N/l00`00AE55D@04AE401000AE55D@0027k?00<0
04EAAE4014EA00@004EAAE4000=ncP03001ncWk>00EncP030015D@0000AncP03001ncWk>00AncP04
0015DDEA0003O/h01@00O/incWk>00000gk>10001eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<0
05KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d015Km10001EKm00<005Km
E_d015Km10001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005Km
E_d00`0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<0
05KmE_d015Km10001UKm00<005KmE_d00eKm1000AGoo00<007ooOol047oo000XOol00`00Oomoo`0Y
Ool30021Ool00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eF
o@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eF
o@04E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00
E_eFo@020006AE40100000X000001dEA00<0000:00001TEA00<004EAAE4014EA00<004EAAE401DEA
00@004EAAE4000Mjc`030015DDEA00A5D@040015DDEA0008O/l00`00AE55D@04AE400`00AE400004
O/h00`00O/incP05O/h00`00AE400004O/h00`00O/incP04O/h01000AE55D@000gk>00D007k>O/in
cP0000=ncP800003E_d005Km00EFo@@000EFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@0
00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00IFo@03
001FoEKm00<0009Fo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AF
o@@000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@800004E_d0
00000019Ool00`00Oomoo`0@Ool002Qoo`03001oogoo02Moo`8008Eoo`03001FoEKm00<000=Fo@03
001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=F
o@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@D000I5D@0400002P000007AE400`0000X00006
AE400`00AE55D@04AE400`00AE55D@05AE401000AE55D@001g[?00<004EAAE4014EA00@004EAAE40
00Qnc`030015DDEA00A5D@030015D@0000AncP03001ncWk>00EncP030015D@0000AncP03001ncWk>
00AncP040015DDEA0003O/h01@00O/incWk>00000gk>0P000UKm00<005KmE_d00`000UKm00<005Km
E_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km
0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km10001UKm00<005KmE_d00`000UKm00<0
05KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d0
1EKm00<005KmE_d00`000eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`00C7oo00<007oo
Ool047oo000WOol00`00Oomoo`0UOol30028Ool20007E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006
E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm001Fo@07
E_d00`00E_eFo@0300000eKm001Fo@020006AE40100000X000001dEA00<0000:00001TEA00<004EA
AE4014EA00<004EAAE401DEA00@004EAAE4000Mjc`030015DDEA00A5D@040015DDEA0008O/l00`00
AE55D@04AE400`00AE400004O/h00`00O/incP05O/h00`00AE400004O/h00`00O/incP04O/h01000
AE55D@000gk>00D007k>O/incP0000=ncP80009Fo@<000IFo@03001FoEKm00AFo@<000IFo@03001F
oEKm00AFo@<000MFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm00<00003E_d005Km00MF
o@03001FoEKm00<0009Fo@03001FoEKm00AFo@@000IFo@03001FoEKm00=Fo@@000IFo@03001FoEKm
00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm
00<0009oo`03001oogoo04]oo`03001oogoo00moo`009goo00<007ooOol08Woo0`00SGoo00<005Km
E_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`00
0UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<0
05KmE_d015Km0`001EKm00<005KmE_d015Km10001EKm0`001TEA00@0000:000000M5D@0300002P00
00I5D@030015DDEA00E5D@030015DDEA00A5D@040015DDEA0007N/l00`00AE55D@04AE401000AE55
D@0027k?00<004EAAE4014EA00<004EA000017k>00<007k>O/h01Gk>00<004EA00000gk>00<007k>
O/h01Gk>00@004EAAE4000=ncP05001ncWk>O/h00003O/h40002E_d00`00E_eFo@05E_d00`00E_eF
o@0300000eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d40005E_d00`00E_eFo@04
E_d40005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eF
o@030002E_d00`00E_eFo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@030002E_d0
0`00E_eFo@04E_d40005E_d00`00E_eFo@04E_d40006Ool00`00Oomoo`1:Ool00`00Oomoo`0?Ool0
02Moo`04001oo`00000NOol3002AOol00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d20006AE40100000X000001dEA00<0000:00001TEA00<004EAAE401DEA
00<004EAAE4014EA00@004EAAE4000Mjc`030015DDEA00A5D@040015DDEA0008O/l00`00AE55D@04
AE400`00AE400004O/h00`00O/incP05O/h00`00AE400003O/h00`00O/incP05O/h01000AE55D@00
0gk>00D007k>O/incP0000=ncP8000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@@000IF
o@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001F
oEKm00<000=Fo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@@0
00EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0
00]oo`03001oogoo04Uoo`03001oogoo00moo`009goo0P007Goo0`00UGoo0P001UKm00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d015Km10001EKm00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km0P001TEA00@0000:000000M5D@0300002P0000M5D@030015DDEA
00A5D@030015DDEA00A5D@040015DDEA0007N/l00`00AE55D@04AE401000AE55D@0027k?00<004EA
AE4014EA00<004EA00000gk>00<007k>O/h01Wk>00<004EA00000gk>00<007k>O/h01Gk>00@004EA
AE4000=ncP05001ncWk>O/h00003O/h20006E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30007
E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@03
E_d4000>Ool00`00Oomoo`19Ool00`00Oomoo`0?Ool002Moo`03001oogoo01Uoo`<009Uoo`03001F
oEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001FoEKm00AF
o@<000IFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00<0009Fo@03
001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00D000I5D@0400002P00
0007AE400`0000X00007AE400`00AE55D@04AE400`00AE55D@04AE401000AE55D@001g[?00<004EA
AE4014EA00<004EA00002Gk?00<004EAAE4014EA00<004EA00000gk>00<007k>O/h01Wk>00<004EA
00000gk>00<007k>O/h01Gk>00@004EAAE4000=ncP05001ncWk>O/h00003O/h20005E_d40005E_d0
0`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@0300000eKm
001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d40005E_d00`00E_eFo@04E_d40005E_d0
0`00E_eFo@04E_d40006E_d00`00E_eFo@03E_d40006E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d00`00E_eFo@03000COol00`00Oomoo`18Ool00`00Oomoo`0?Ool002Moo`03001oogoo01Ioo`<0
09eoo`03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0009Fo@03001F
oEKm00EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@<0
00IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000=Fo@8000I5D@0400002P000007AE40
100000X000001TEA00<004EAAE4014EA00<004EAAE4014EA00@004EAAE4000Mjc`030015DDEA00A5
D@030015D@0000Unc`030015DDEA00A5D@030015D@0000=ncP03001ncWk>00IncP030015D@0000=n
cP03001ncWk>00EncP040015DDEA0003O/h01@00O/incWk>00000gk>0P000UKm0`000UKm00<005Km
E_d01EKm00<005KmE_d00`000eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km10001UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<0
05KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km0`005goo00<007ooOol0Agoo00<007ooOol03goo000WOol00`00
Oomoo`0COol3002QOol00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00
E_eFo@04E_d30006E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d0
0`00E_eFo@020006AE40100000X000001dEA00@0000:000000I5D@030015DDEA00A5D@030015DDEA
00A5D@040015DDEA0007N/l00`00AE55D@04AE400`00AE400009O/l00`00AE55D@04AE400`00AE40
0003O/h00`00O/incP06O/h00`00AE400003O/h00`00O/incP05O/h01000AE55D@000gk>00D007k>
O/incP0000=ncP@000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<00003E_d005Km00MFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@<000IFo@03001F
oEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0
0003E_d005Km00MFo@03001FoEKm00<001Yoo`03001oogoo04Moo`03001oogoo00moo`009Woo00<0
07ooOol04Woo0P00YGoo0P001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`000UKm00<005Km
E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000eKm00<005KmE_d015Km0`00
1UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00@005Km000000I5D@0400002P00
0007AE40100000X000001TEA00<004EAAE4014EA00<004EAAE4014EA00@004EAAE4000Mjc`030015
DDEA00A5D@030015D@0000Unc`030015DDEA00A5D@030015D@0000=ncP03001ncWk>00IncP030015
D@0000=ncP03001ncWk>00EncP040015DDEA0003O/h01@00O/incWk>00000gk>00<005Km000025Km
00<005KmE_d00`000UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001EKm00<005KmE_d0
15Km0`001eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01eKm00<0
05KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d015Km10001EKm00<0
05KmE_d015Km10007Woo00<007ooOol0AWoo00<007ooOol03goo000VOol00`00Oomoo`0?Ool3002X
Ool00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d40006AE40100000X00000
1dEA00@0000:000000I5D@030015DDEA00A5D@030015DDEA00A5D@040015DDEA0007N/l00`00AE55
D@04AE400`00AE400009O/l00`00AE55D@04AE400`00AE400003O/h00`00O/incP06O/h00`00AE40
0003O/h00`00O/incP05O/h01000AE55D@000gk>00D007k>O/incP0000=ncP04001FoEKm0006E_d4
0006E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d0
0`00E_eFo@030003E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d40005E_d00`00E_eFo@04
E_d40006E_d00`00E_eFo@02E_d50006E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eF
o@03000SOol00`00Oomoo`16Ool00`00Oomoo`0>Ool002Ioo`03001oogoo00aoo`<00:aoo`03001F
oEKm00AFo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d005Km
00IFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001F
oEKm00AFo@<000MFo@03001FoEKm00<00004E_d000000006AE40100000X000001dEA00@0000:0000
00I5D@030015DDEA00A5D@030015DDEA00A5D@030015D@0000Qjc`030015DDEA00A5D@030015D@00
00Unc`030015DDEA00A5D@030015D@0000=ncP03001ncWk>00IncP030015D@0000=ncP03001ncWk>
00EncP040015DDEA0003O/h01@00O/incWk>00000gk>00D005KmE_eFo@00009Fo@<000=Fo@03001F
oEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0
0003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<000=Fo@03001F
oEKm00AFo@D000AFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<002Moo`03001oogoo04Eo
o`03001oogoo00ioo`009Woo00<007oo00000P001goo0`00/7oo00<005KmE_d00`000eKm00<005Km
E_d015Km0`001UKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001eKm00<005KmE_d00`00
0UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<0
05KmE_d015Km0`001EKm0P001TEA00@0000:000000M5D@0400002P000006AE400`00AE55D@04AE40
0`00AE55D@04AE400`00AE400008N/l00`00AE55D@04AE400`00AE400009O/l00`00AE55D@04AE40
0`00AE400003O/h00`00O/incP06O/h00`00AE400003O/h00`00O/incP06O/h00`00AE400003O/h0
1@00O/incWk>00000gk>00@005KmE_eFo@<000MFo@03001FoEKm00<00003E_d005Km00MFo@03001F
oEKm00<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@@000EFo@03001FoEKm
00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm
00<00003E_d005Km00MFo@03001FoEKm00<002Yoo`03001oogoo04Eoo`03001oogoo00ioo`009Woo
0P001goo0`00]7oo0P001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`000eKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm
00<005KmE_d015Km0`001eKm00<005KmE_d00`0000=Fo@00E_d01EKm0P001TEA00@0000:000000M5
D@0400002P000006AE400`00AE55D@04AE400`00AE55D@05AE420008N/l00`00AE55D@05AE420009
O/l00`00AE55D@04AE400`00AE400003O/h00`00O/incP06O/h00`00AE400003O/h00`00O/incP06
O/h00`00AE400003O/h01@00O/incWk>00000gk>10000UKm00<005KmE_d015Km10001EKm00<005Km
E_d015Km10001EKm00<005KmE_d015Km10001UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<0
05KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<005KmE_d015Km10001EKm00<005Km
E_d015Km10001EKm00<005KmE_d015Km1000;Woo00<007ooOol0A7oo00<007ooOol03Woo000VOol0
0`00Oomoo`03Ool3002iOol00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30005E_d00`00E_eF
o@04E_d30007E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eF
o@05E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d40005E_d00`00E_eFo@03E_d20006AE401000
00X000001dEA00@0000:000000I5D@030015DDEA00A5D@030015DDEA00E5D@8000Qjc`030015DDEA
00E5D@8000Unc`030015DDEA00A5D@030015D@0000=ncP03001ncWk>00IncP030015D@0000=ncP03
001ncWk>00IncP030015D@0000=ncP05001ncWk>O/h00003O/h00`00E_eFo@04E_d00`00E_eFo@03
0002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d0
0`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d40006E_d00`00E_eF
o@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03000c
Ool00`00Oomoo`13Ool00`00Oomoo`0>Ool002Eoo`04001oogooOol3002mOol00`00E_eFo@030002
E_d00`00E_eFo@05E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030003E_d00`00E_eF
o@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@030002
E_d00`00E_eFo@05E_d00`00E_eFo@040006AE40100000X000001dEA00@0000:000000I5D@030015
DDEA00A5D@030015DDEA00E5D@8000Ujc`030015DDEA00A5D@8000Unc`030015DDEA00A5D@030015
D@0000=ncP03001ncWk>00IncP030015D@0000=ncP03001ncWk>00IncP030015D@0000=ncP05001n
cWk>O/h00003O/h00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d3
0007E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@030003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@03E_d4000g
Ool00`00Oomoo`12Ool00`00Oomoo`0>Ool001Ioo`@00003249oogoo00Qoo`@00<5oo`8000IFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00EF
o@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@<000IF
o@03001FoEKm00AFo@<0009Fo@8000I5D@0400002P000007AE40100000X000001TEA00<004EAAE40
14EA00<004EAAE401DEA0P002G[?00<004EAAE4014EA0P002Gk?00<004EAAE4014EA00<004EA0000
0gk>00<007k>O/h01Wk>00<004EA00000gk>00<007k>O/h01Wk>00<004EA00000gk>00D007k>O/in
cP0000=ncP80009Fo@<0009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d005Km00MFo@03001F
oEKm00<0009Fo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@<0
00MFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm
00<003]oo`03001oogoo049oo`03001oogoo00ioo`0067oo00<007ooOol02Woo0P00a7oo00<005Km
E_d01EKm00<005KmE_d00`000UKm00<005KmE_d015Km00<005KmE_d00`000eKm00<005KmE_d015Km
0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d00`000UKm00<0
05KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d00P001TEA00@0000:000000M5D@0400002P00
0006AE400`00AE55D@04AE400`00AE55D@05AE420009N/l00`00AE55D@04AE420009O/l00`00AE55
D@04AE400`00AE400003O/h00`00O/incP06O/h00`00AE400003O/h00`00O/incP06O/h00`00AE40
0003O/h01@00O/incWk>00000gk>10001UKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km1000
1UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<0
05KmE_d00`000UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001EKm00<005KmE_d015Km
0`00?goo00<007ooOol0@Woo00<007ooOol03Goo000HOol00`00Oomoo`0<Ool00`00Oomoo`32Ool0
0`00E_eFo@04E_d30006E_d01000E_eFoEKm1@001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm
00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d015Km0`001UKm
00<005KmE_d015Km0`001UKm00@005Km000000I5D@0400002P000007AE40100000X000001TEA00<0
04EAAE4014EA00<004EAAE401DEA0P002G[?00<004EAAE4014EA0P002Gk?00<004EAAE4014EA00<0
04EA00000gk>00<007k>O/h01Wk>00<004EA00000gk>00<007k>O/h01Wk>00<004EA00000gk>00D0
07k>O/incP0000=ncP03001Fo@0000QFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
00=Fo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03
001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm
00<004=oo`03001oogoo045oo`03001oogoo00eoo`0067oo00<007ooOol03Goo00<007ooOol0`Woo
00<005KmE_d00`000UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km0`001UKm00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km0`001UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km
E_d00`000UKm00<005KmE_d01EKm0`001TEA00@0000:000000M5D@0400002P000006AE400`00AE55
D@04AE400`00AE55D@05AE420009N/l00`00AE55D@04AE420009O/l00`00AE55D@04AE400`00AE40
0003O/h00`00O/incP06O/h00`00AE400003O/h00`00O/incP06O/h00`00AE400003O/h01@00O/in
cWk>00000gk>00@005KmE_d000IFo@@000EFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<00003
E_d005Km00MFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm00<0009Fo@03001FoEKm00AF
o@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm00=Fo@@004Ioo`03001oogoo045oo`03001o
ogoo00eoo`0067oo00<007ooOol03Woo00<007ooOol0`Woo0P001UKm00<005KmE_d00`000UKm00<0
05KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d0
15Km00<005KmE_d00`000UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005Km
E_d015Km0`001TEA00@0000:000000M5D@0400002P000006AE400`00AE55D@04AE400`00AE55D@05
AE420009N/l00`00AE55D@04AE420009O/l00`00AE55D@04AE400`00AE400003O/h00`00O/incP06
O/h00`00AE400003O/h00`00O/incP06O/h00`00AE400003O/h01@00O/incWk>00000gk>00D005Km
E_eFo@00009Fo@<000=Fo@03001FoEKm00AFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@<000EF
o@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@@000IFo@03001FoEKm00<00003E_d005Km00MF
o@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<004]oo`03001oogoo041oo`03001oogoo
00eoo`0067oo00<007ooOol03goo0P00`goo00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`00
1UKm00<005KmE_d015Km0`001eKm00@005KmE_eFo@D000IFo@03001FoEKm00<0009Fo@03001FoEKm
00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d0000000I5D@040000
2P000007AE40100000X000001TEA00<004EAAE4014EA00<004EAAE401DEA0P002G[?00<004EAAE40
14EA0P002Gk?00<004EAAE4014EA00<004EA00000gk>00<007k>O/h01Wk>00<004EA00000gk>00<0
07k>O/h01Wk>00<004EA00000gk>00D007k>O/incP0000=ncP04001FoEKmE_d30007E_d01000E_eF
oEKm1@001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm
00<005KmE_d00`000UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km10001EKm00<005KmE_d0
15Km0`00Cgoo00<007ooOol0?goo00<007ooOol03Goo000HOol00`00Oomoo`0AOol00`00Oomoo`31
Ool00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00
E_eFo@030003E_d00`00E_eFo@04E_d40004E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d3
0006E_d00`00E_eFo@04E_d30004E_d20006AE40100000X000001dEA00@0000:000000I5D@030015
DDEA00A5D@030015DDEA00E5D@8000Ujc`030015DDEA00A5D@8000Unc`030015DDEA00A5D@030015
D@0000=ncP03001ncWk>00IncP030015D@0000=ncP03001ncWk>00IncP030015D@0000=ncP05001n
cWk>O/h00003O/h40002E_d00`00E_eFo@04E_d50004E_d00`00E_eFo@04E_d40005E_d00`00E_eF
o@04E_d30006E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00
E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03001COol00`00Oomoo`0nOol00`00Oomoo`0=
Ool001Ioo`03000Q200001Aoo`03001oogoo0<5oo`8000IFo@03001FoEKm00AFo@<000IFo@03001F
oEKm00AFo@<000MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm
00EFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@03001FoEKm00<0009Fo@03001FoEKm009Fo@80
00I5D@0400002P000007AE40100000X000001TEA00<004EAAE4014EA00<004EAAE401DEA0P002G[?
00<004EAAE4014EA0P002Gk?00<004EAAE4014EA00<004EA00000gk>00<007k>O/h01Wk>00<004EA
00000gk>00<007k>O/h01Wk>00<004EA00000gk>00D007k>O/incP0000=ncP03001FoEKm00AFo@03
001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@<000IFo@03001FoEKm
00AFo@<000IFo@03001FoEKm00AFo@<005Ioo`03001oogoo03ioo`03001oogoo00eoo`005Woo00=S
62U:00005Goo00<007ooOol0`Goo00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d01EKm
00<005KmE_d00`000eKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001UKm00<005KmE_d0
15Km0`001eKm00@005KmE_eFo@D000IFo@03001FoEKm00<000I5D@0400002P000007AE40100000X0
00001TEA00<004EAAE4014EA00<004EAAE401DEA0P002G[?00<004EAAE4014EA0P002Gk?00<004EA
AE401DEA0P000gk>00<007k>O/h01Wk>00<004EA00000gk>00<007k>O/h01Wk>00<004EA00000gk>
00D007k>O/incP0000=ncP03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000IFo@03001FoEKm
00AFo@<000IFo@03001FoEKm009Fo@D000IFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@03001FoEKm00<005Yoo`03001oogoo03eoo`03001oogoo00eoo`00
;goo0P00`Woo00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001eKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`000eKm00<005KmE_d0
15Km100015Km00<005KmE_d015Km0`0000=Fo@0000001TEA00@0000:000000M5D@0400002P000006
AE400`00AE55D@04AE400`00AE55D@05AE420009N/l00`00AE55D@04AE420009O/l00`00AE55D@05
AE420003O/h00`00O/incP06O/h00`00AE400003O/h00`00O/incP06O/h00`00AE400003O/h01@00
O/incWk>00000gk>0P000UKm0`000UKm00<005KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01eKm
00<005KmE_d00`000UKm00<005KmE_d015Km1@0015Km00<005KmE_d015Km0`001EKm00<005KmE_d0
15Km10001UKm00<005KmE_d00UKm1@00GWoo00<007ooOol0?Goo00<007ooOol037oo000aOol00`00
Oomoo`30Ool00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@030002E_d01000E_d000001TEA00@0000:000000M5D@0400002P000006
AE400`00AE55D@04AE400`00AE55D@05AE420009N/l00`00AE55D@04AE42000:O/l00`00AE55D@04
AE420003O/h00`00O/incP06O/h00`00AE400003O/h00`00O/incP06O/h00`00AE400003O/h01@00
O/incWk>00000gk>10001UKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km10001UKm00<005Km
E_d00`0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000eKm00<0
05KmE_d015Km1@00I7oo00<007ooOol0?7oo00<007ooOol037oo000bOol00`00Oomoo`30Ool20006
E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030002E_d0
0`00E_eFo@05E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30006
E_d30006AE40100000X000001dEA00@0000:000000I5D@030015DDEA00A5D@030015DDEA00E5D@80
00Ujc`030015DDEA00A5D@8000Ync`030015DDEA00A5D@03001ncWk>009ncP03001ncWk>00IncP03
0015D@0000=ncP03001ncWk>00IncP030015D@0000=ncP05001ncWk>O/h00003O/h00`00E_d00008
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30005E_d0
0`00E_eFo@04E_d40005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@03001YOol00`00Oomoo`0l
Ool00`00Oomoo`0<Ool003=oo`03001oogoo0<5oo`03001FoEKm00AFo@03001FoEKm00<000=Fo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000MFo@03001FoEKm
00<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@8000I5D@0400002P000007
AE40100000X02P001TEA00<004EAAE4014EA00<004EAAE401DEA0P002G[?00<004EAAE4014EA0P00
2Wk?00<004EAAE4014EA00<007k>O/h00Wk>00<007k>O/h01Wk>00<004EA00000gk>00<007k>O/h0
1Wk>00<004EA00000gk>00D007k>O/incP0000=ncP04001FoEKm0006E_d40005E_d00`00E_eFo@04
E_d30007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d0
0`00E_eFo@030002E_d00`00E_eFo@04E_d4001]Ool00`00Oomoo`0kOol00`00Oomoo`0<Ool003Ao
o`800<9oo`04001FoEKmE_d50007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030003
E_d00`00E_eFo@04E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d3
0006E_d00`00E_eFo@04E_d20006AE40100000X000001dEA00@0000:00X000I5D@030015DDEA00A5
D@030015DDEA00E5D@8000Ujc`030015DDEA00A5D@03001ncgk?00Unc`030015DDEA00A5D@03001n
cWk>009ncP03001ncWk>00IncP030015D@0000=ncP03001ncWk>00IncP030015D@0000=ncP05001n
cWk>O/h00003O/h01@00E_eFoEKm00000UKm0`000eKm00<005KmE_d015Km00<005KmE_d00`000UKm
00<005KmE_d015Km10001EKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001UKm00<005Km
E_d00`00LWoo00<007ooOol0>Woo00<007ooOol037oo000fOol00`00Oomoo`30Ool30005E_d00`00
E_eFo@04E_d30005E_d00`00E_eFo@04E_d30007E_d01000E_eFoEKm1@001eKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d01@001TEA00@0000:
000000M5D@0400002P0:0006AE400`00AE55D@04AE400`00AE55D@05AE400`00N/mjc`08N/l00`00
AE55D@04AE400`00O/mnc`09O/l00`00AE55D@04AE400`00O/incP02O/h00`00O/incP07O/h00`00
O/incP02O/h00`00O/incP06O/h00`00AE400003O/h01@00O/incWk>00000gk>00@005KmE_eFo@<0
00MFo@04001FoEKmE_d50006E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@030000
0eKm001Fo@07E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d3001eOol00`00Oomoo`0jOol00`00
Oomoo`0<Ool003Moo`03001oogoo0<1oo`03001FoEKm00EFo@03001FoEKm00<00003E_d005Km00IF
o@03001FoEKm00<000=Fo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@<000IFo@03001FoEKm00AFo@<000=Fo@8000I5D@0400002P0:0007AE40100000X02P001TEA
00<004EAAE4014EA00<004EAAE401DEA00<007[?N/l027[?00<004EAAE4014EA00<007k?O/l02Gk?
00<004EAAE4014EA00D007k>O/incP0000YncP03001ncWk>009ncP03001ncWk>00IncP030015D@00
00=ncP05001ncWk>O/h00003O/h40002E_d00`00E_eFo@04E_d50004E_d00`00E_eFo@04E_d30006
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d40006E_d00`00E_eFo@03001iOol00`00Oomo
o`0iOol00`00Oomoo`0<Ool003Qoo`03001oogoo0<1oo`03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d005Km00IF
o@03001FoEKm00<000=Fo@03001FoEKm00AFo@03001FoEKm00<0009Fo@04001FoEKmE_d20006AE40
100000X02P001dEA00@0000:00X000I5D@030015DDEA00A5D@030015DDEA00E5D@03001jcg[?00Qj
c`030015DDEA00A5D@03001ncgk?00Unc`030015DDEA00A5D@05001ncWk>O/h0000:O/h00`00O/in
cP02O/h00`00O/incP06O/h20004O/h01@00O/incWk>00000gk>00<005KmE_d015Km00<005KmE_d0
0`000UKm00<005KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`000UKm00<0
05KmE_d015Km00<005KmE_d00`000eKm00<005KmE_d015Km0`00OGoo00<007ooOol0>Goo00<007oo
Ool02goo000iOol00`00Oomoo`30Ool00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eFo@03
0003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30007E_d0
1000E_eFoEKm1@001UKm00<005KmE_d00P001TEA00@0000:00X000M5D@0400002P0:0006AE400`00
AE55D@04AE400`00AE55D@05AE400`00N/mjc`08N/l00`00AE55D@04AE400`00O/mnc`09O/l00`00
AE55D@04AE401@00O/incWk>00002Wk>00<007k>O/h00Wk>00<007k>O/h01Wk>0P0017k>00D007k>
O/incP0000=ncP03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@@0
00IFo@04001FoEKmE_d50007E_d00`00E_eFo@030021Ool00`00Oomoo`0hOol00`00Oomoo`0;Ool0
03Yoo`800<5oo`8000IFo@03001FoEKm00=Fo@<000MFo@03001FoEKm00<0009Fo@03001FoEKm00EF
o@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@@000AFo@03
001FoEKm00AFo@D000I5D@0400002P0:0007AE40100000X02P001TEA00<004EAAE4014EA00<004EA
AE401DEA00<007[?N/l027[?00<004EAAE4014EA00<007k?O/l02Gk?00<004EAAE4014EA00D007k>
O/incP0000YncP05001ncWk>O/h00009O/h20004O/h01000O/incP0017k>0P000UKm0`000UKm00<0
05KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000eKm00<005KmE_d015Km
100015Km00<005KmE_d015Km1000Q7oo00<007ooOol0>7oo00<007ooOol02goo000lOol00`00Oomo
o`30Ool00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
0002E_d30006AE40100000X02P001dEA00@0000:00X000I5D@030015DDEA00A5D@030015DDEA00E5
D@03001jcg[?00Qjc`030015DDEA00A5D@03001ncgk?00Unc`030015DDEA00A5D@05001ncWk>O/h0
000:O/h01@00O/incWk>00002Gk>0P0017k>00@007k>O/h000AncP@000IFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<008Uo
o`03001oogoo03Moo`03001oogoo00]oo`00?Goo00<007ooOol0`7oo00@005KmE_eFo@@000MFo@03
001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
00=Fo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000IFo@8000I5D@0400002P0:0007AE40
100000X02P001TEA00<004EAAE4014EA00<004EAAE401DEA00<007[?N/l027[?00<004EAAE4014EA
00<007k?O/l02Gk?00<004EAAE4014EA00D007k>O/incP0000YncP05001ncWk>O/h00009O/h20003
O/h01@00O/incWk>000017k>00<005Km000025Km00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km
E_d00`000UKm00<005KmE_d015Km10001EKm00<005KmE_d015Km0`00SGoo00<007ooOol0=Woo00<0
07ooOol02goo000nOol00`00Oomoo`30Ool30004E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
0002E_d00`00E_eFo@04E_d20006AE40100000X02P001dEA00@0000:00X000I5D@030015DDEA00A5
D@030015DDEA00E5D@03001jcg[?00Qjc`030015DDEA00A5D@03001ncgk?00Unc`030015DDEA00A5
D@05001ncWk>O/h0000:O/h01@00O/incWk>00002Gk>0P000gk>00D007k>O/incP0000AncP04001F
oEKm0006E_d40005E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d0
0`00E_eFo@03002AOol00`00Oomoo`0eOol00`00Oomoo`0;Ool003moo`800<1oo`03001FoEKm00EF
o@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@03001F
oEKm00<000=Fo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000IFo@03001FoEKm00=Fo@80
00I5D@0400002P0:0007AE40100000X02P001TEA00<004EAAE4014EA00<004EAAE401DEA00<007[?
N/l027[?00<004EAAE4014EA00<007k?O/l02Gk?00<004EAAE4014EA00D007k>O/incP0000YncP05
001ncWk>O/h00009O/h20003O/h01@00O/incWk>00000gk>0P000eKm00<005KmE_d00`000eKm00<0
05KmE_d015Km00<005KmE_d00`000UKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`00U7oo
00<007ooOol0=Goo00<007ooOol02goo0011Ool00`00Oomoo`2nOol00`00E_eFo@04E_d30006E_d0
0`00E_eFo@04E_d30006E_d01000E_eFoEKm1@001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<0
05KmE_d00`000eKm00<005KmE_d015Km00<005KmE_d010001TEA00@0000:00X000M5D@0400002P0:
0006AE400`00AE55D@04AE400`00AE55D@04AE42000:N/l00`00AE55D@02AE43000;O/l00`00AE55
D@02AE430003O/h00`00O/incP08O/h01@00O/incWk>00002Wk>00D007k>O/incP0000=ncP04001n
cWk>O/h20003E_d30007E_d01000E_eFoEKm1@001UKm00<005KmE_d00`0000=Fo@00E_d01eKm00<0
05KmE_d00`00V7oo00<007ooOol0=7oo00<007ooOol02goo0012Ool00`00Oomoo`2nOol00`00E_eF
o@030002E_d00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d40005E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d30007E_d01000E_eFoEKm1@000eKm00<004EAAE4014EA00@0
000:00X000M5D@0400002P0:0006AE400`00AE55D@04AE401000AE55DDEA0`0000=C7@00N/l02G[?
00<004EA00000P000e<M00<007k?O/l027k?00<004EA00000P000e<M00@007k>O/h000YncP05001n
cWk>O/h0000:O/h01@00O/incWk>00000gk>00@007k>O/incPD0009Fo@03001FoEKm00AFo@D000AF
o@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@@009aoo`03001oogoo03Aoo`03001oogoo00Yo
o`00@goo00<007ooOol0_Woo0P001UKm00<005KmE_d015Km0`001UKm00<005KmE_d00`000UKm00<0
05KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000eKm00<005KmE_d015Km
100015Km00D005KmE_eFo@0000I5D@0400002P0:0007AE40100000X02P001TEA00<004EAAE4014EA
10001E<M00<007[?N/l01W[?0`001e<M00<007k?O/l01Gk?10001e<M00<007k>00002Wk>00D007k>
O/incP0000YncP05001ncWk>O/h00003O/h01000O/incWk>0P001UKm00<005KmE_d00`000UKm00<0
05KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`00X7oo00<007ooOol0=7oo
00<007ooOol02Woo0014Ool20030Ool00`00E_eFo@04E_d00`00E_eFo@030002E_d00`00E_eFo@04
E_d30006E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30007E_d00`00E_eFo@0300000eKm
001Fo@06E_d01000E_eFo@001TEA00@0000:00X000M5D@0400002P0:0006AE400`00AE55D@02AE43
0009Dad00`00N/mjc`02N/l30002Dad00`00DaeC7@06Dad00`00O/mnc`040003Dad00`00DaeC7@06
Dad2000:O/h01@00O/incWk>00002Wk>00D007k>O/incP0000=ncP04001ncWk>O/h20006E_d30006
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d3002TOol00`00Oomoo`0cOol00`00Oomoo`0:
Ool004Ioo`03001oogoo0;ioo`04001FoEKmE_d50006E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eFo@030003E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d40006AE40100000X02P001dEA00@0000:00X000I5D@030015D@00008000=C
7@03001C7E<M00MC7@04001jc`000006Dad00`00DaeC7@04Dad40008Dad00`00DaeC7@04Dad3000:
O/h01@00O/incWk>00002Wk>00D007k>O/incP0000=ncP04001ncWk>O/h30002E_d30002E_d00`00
E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eFo@03002XOol00`00Oomoo`0b
Ool00`00Oomoo`0:Ool004Moo`03001oogoo0;ioo`<000EFo@03001FoEKm00=Fo@<000IFo@03001F
oEKm00AFo@<000IFo@04001FoEKmE_d50007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@030003E_d00`00AE55D@04AE40100000X02P001dEA00@0000:00X000A5D@@000MC7@03001C7E<M
00EC7@<000UC7@03001C7E<M00<000=C7@03001C7E<M00MC7@03001C7E<M00<000=C7@03001ncWk>
00MncP05001ncWk>O/h0000:O/h01@00O/incWk>00000gk>00@007k>O/incPD000IFo@03001FoEKm
00AFo@<000IFo@04001FoEKmE_d5002/Ool00`00Oomoo`0aOol00`00Oomoo`0:Ool004Qoo`03001o
ogoo0;ioo`03001FoEKm00EFo@03001Fo@000080009Fo@03001FoEKm00EFo@03001FoEKm00<000=F
o@03001FoEKm00=Fo@@000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000IFo@030015
DDEA00A5D@0400002P0:0007AE401@0000X02P00AE400`000e<M00<005<MDad01U<M00<005<MDad0
10000e<M00<005<MDad01U<M0`001e<M00<005<MDad01E<M10001e<M00<007k>O/h017k>0`000gk>
00<007k>O/h027k>00D007k>O/incP0000=ncP04001ncWk>O/h200000eKm001Fo@07E_d00`00E_eF
o@030002E_d00`00E_eFo@04E_d4002aOol00`00Oomoo`0aOol00`00Oomoo`0:Ool004Uoo`800;mo
o`03001FoEKm00AFo@8000IFo@03001FoEKm00AFo@<000MFo@03001Fo@000080009Fo@03001FoEKm
00EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<000=Fo@03001FoEKm00=Fo@030015
DDEA00A5D@0400002P0:0007AE400`0000X02P020007Dad00`00DaeC7@04Dad40008Dad00`00DaeC
7@02Dad300000e<M001C7@08Dad00`00DaeC7@040003Dad00`00DaeC7@06Dad00`00O/incP030003
Dad01000O/incP002Wk>00D007k>O/incP0000=ncP04001ncWk>O/h20002E_d00`00E_eFo@04E_d4
0006E_d00`00E_eFo@03002fOol00`00Oomoo`0`Ool00`00Oomoo`0:Ool004]oo`03001oogoo0;eo
o`03001FoEKm00<0009Fo@03001FoEKm00AFo@03001FoEKm00<000=Fo@03001FoEKm00AFo@8000IF
o@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000MFo@03001FoEKm00<000I5D@0400002P0:
0007AE401@0000X02P0:000025<M00<005<MDad00`000e<M00<005<MDad01e<M00@005<M000000EC
7@03001C7E<M00IC7@<000QC7@03001C7E<M00AC7@@000MC7@03001ncP0000YncP05001ncWk>O/h0
0003O/h01000O/incWk>0P000eKm00<005KmE_d00`000eKm00<005KmE_d015Km0`00^Woo00<007oo
Ool0<7oo00<007ooOol02Goo001<Ool00`00Oomoo`2mOol20006E_d01000E_eFoEKm1@001eKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d015Km00<005KmE_d00`00
0eKm00<005KmE_d015Km0`000UKm00<004EAAE4014EA00@0000:00X000M5D@0300002P0:00802P03
001C7E<M00AC7@@000MC7@03001C7E<M00EC7@<000QC7@03001C7E<M009C7@<00003Dad005<M00UC
7@03001C7E<M00<000=C7@03001C7E<M00IC7@8000YncP05001ncWk>O/h00003O/h01000O/incWk>
0P0000=Fo@0000000`001eKm00<005KmE_d00`00_Woo00<007ooOol0;goo00<007ooOol02Goo001=
Ool00`00Oomoo`2mOol00`00E_eFo@04E_d40005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04
E_d30006E_d01000E_eFoEKm1@001eKm00<005KmE_d00`0000=Fo@00E_d00UKm00<004EAAE4014EA
00@0000:00X000M5D@0300002P0:00<02P03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M
00@000=C7@03001C7E<M00IC7@04001C7@000005Dad00`00DaeC7@07Dad30007Dad00`00DaeC7@04
Dad3000:O/h01@00O/incWk>00000gk>00@007k>O/incP<000AFo@03001FoEKm00AFo@@00<5oo`03
001oogoo02moo`03001oogoo00Uoo`00CWoo0P00_Woo00<005KmE_d00`000UKm00<005KmE_d01EKm
00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000eKm00<005KmE_d00eKm10001EKm00<0
05KmE_d015Km0`001EKm00@005KmE_d000I5D@0400002P0:0007AE400`0000X02P0300X30007Dad0
0`00DaeC7@04Dad40008Dad00`00DaeC7@04Dad30008Dad00`00DaeC7@03Dad30002Dad00`00DaeC
7@06Dad00`00DaeC7@030003Dad00`00O/incP07O/h01@00O/incWk>00000gk>00@007k>O/incP80
00IFo@03001FoEKm00<00<Ioo`03001oogoo02ioo`03001oogoo00Uoo`00D7oo00<007ooOol0_7oo
0P001UKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001eKm00<005Km00000P000UKm00<0
05KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00001TEA00@0000:00X000M5D@03
00002P0:00<0009C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00MC7@03001C7E<M
00<000=C7@03001C7E<M00IC7@03001C7@00008000IC7@03001C7E<M00AC7@@000MC7@03001ncWk>
00AncP<000=ncP05001ncWk>O/h00003O/h20006E_d3003:Ool00`00Oomoo`0]Ool00`00Oomoo`09
Ool0055oo`03001oogoo0;aoo`03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@03
001FoEKm00<000=Fo@03001FoEKm00AFo@8000IFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AF
o@<000I5D@0400002P0:0007AE430006Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@05Dad40007
Dad00`00DaeC7@04Dad3000:Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad00`00O/incP030003
Dad01000O/incP000gk>00@007k>O/incP<0009Fo@<00<eoo`03001oogoo02eoo`03001oogoo00Uo
o`00DWoo00<007ooOol0_7oo00<005KmE_d015Km0`001UKm00@005KmE_eFo@D000MFo@03001FoEKm
00<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@03001FoEKm00<0009Fo@03
0015DDEA00A5D@0400002P0:0005AE430009Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad00`00
DaeC7@040003Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@07Dad30007Dad00`00
DaeC7@04Dad40007Dad00`00O/h00003O/h01000O/incWk>1@00dGoo00<007ooOol0;7oo00<007oo
Ool02Goo001COol2002mOol00`00E_eFo@030003E_d00`00E_eFo@03E_d40005E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d30006E_d01000E_eFoEKm1@001EKm00<004EAAE4014EA00D0000:
00X004EA00@000=C7@03001C7E<M00IC7@<000MC7@03001C7E<M00AC7@@000QC7@03001C7E<M00AC
7@@000MC7@03001C7E<M00=C7@<00003Dad005<M00QC7@03001C7E<M00<000=C7@03001C7E<M00IC
7@8000=ncP04001ncWk>O/h2003EOol00`00Oomoo`0/Ool00`00Oomoo`08Ool005Eoo`03001oogoo
0;]oo`8000MFo@03001Fo@000080009Fo@03001FoEKm00EFo@03001FoEKm00<0009Fo@03001FoEKm
00AFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@@000EFo@03001FoEKm009Fo@030015DDEA00A5
D@0300002P0:008000QC7@03001C7E<M009C7@<00003Dad005<M00QC7@03001C7E<M00<000=C7@03
001C7E<M00MC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7@00008000EC7@03001C7E<M
00IC7@<000MC7@03001C7E<M00AC7@<000=ncP04001ncWk>O/h2003FOol00`00Oomoo`0[Ool00`00
Oomoo`08Ool005Ioo`03001oogoo0;aoo`03001FoEKm00AFo@8000IFo@03001FoEKm00AFo@<000IF
o@04001FoEKmE_d50006E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@020006AE40
1@0000X02P0:00002E<M00@005<M000000EC7@03001C7E<M00IC7@<000MC7@03001C7E<M00EC7@@0
00MC7@03001C7E<M00AC7@<000UC7@03001C7E<M009C7@<0009C7@03001C7E<M00IC7@03001C7E<M
00<000=C7@04001ncWk>0003O/h2003FOol00`00Oomoo`0[Ool00`00Oomoo`08Ool005Moo`03001o
ogoo0;aoo`03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@@0
00EFo@03001FoEKm00=Fo@<000IFo@03001FoEKm00AFo@<00003E_d004EA00E5D@0300002P0:0080
2P03001C7E<M00EC7@<000QC7@03001C7E<M009C7@<0009C7@03001C7E<M00IC7@03001C7E<M00@0
00=C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7@00008000IC7@03
001C7E<M00AC7@@000MC7@03001ncP0000=ncP800=Moo`03001oogoo02Yoo`03001oogoo00Qoo`00
F7oo00<007ooOol0_7oo0P001EKm00<005KmE_d015Km0`001UKm00<005KmE_d00`000UKm00<005Km
E_d01EKm00<005Km00000P000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005Km00001TEA
00<0000:00X00`0:00<005<MDad010000e<M00<005<MDad01U<M00@005<M000000IC7@03001C7E<M
00AC7@@000QC7@03001C7E<M00AC7@@000MC7@03001C7E<M00AC7@<000YC7@03001C7E<M00<000=C
7@03001C7E<M00IC7@8000=ncP03001oogoo0=Moo`03001oogoo02Uoo`03001oogoo00Qoo`00FGoo
0P00_Goo00<005KmE_d015Km00<005KmE_d00`000eKm00<005KmE_d00eKm0`001UKm00<005KmE_d0
15Km0P001UKm00<005KmE_d015Km0`001UKm0P001TEA00<0000:00X00P0:100025<M00<005<MDad0
15<M0`002E<M00<005<MDad00`000e<M00<005<MDad01e<M00<005<MDad00`000e<M00<005<MDad0
1U<M00<005<MDad00`000e<M00<005<MDad01e<M0`001e<M00<005<MDad015<M0`000gk>00<007oo
Ool0f7oo00<007ooOol0:7oo00<007ooOol027oo001KOol00`00Oomoo`2kOol01000E_eFoEKm1@00
1eKm00<005Km00000P000UKm00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d015Km00<0
05KmE_d00`000UKm00<005KmE_d015Km0P001TEA00<0000:00000P0015<M00<005<MDad01U<M00<0
05<MDad00`000e<M00<005<MDad01U<M0`001e<M00<005<MDad01E<M10001e<M00<005<MDad015<M
10001e<M00<005<MDad00e<M0`0000=C7@00Dad025<M00<005<MDad00`000e<M00@007k>O/h00=Yo
o`03001oogoo02Qoo`03001oogoo00Qoo`00G7oo00<007ooOol0^goo0`001EKm00<005KmE_d015Km
0P001UKm00<005KmE_d015Km0`001UKm00@005KmE_eFo@D000IFo@03001FoEKm00<00003E_d004EA
00=5D@@000QC7@03001C7E<M00AC7@@000MC7@03001C7E<M009C7@<0009C7@03001C7E<M00IC7@03
001C7E<M00@000=C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7@00
008000EC7@03001C7E<M00EC7@@000MC7@03001ncP000=]oo`03001oogoo02Moo`03001oogoo00Qo
o`00GGoo00<007ooOol0^goo00<005KmE_d01EKm00<005KmE_d00`000UKm00<005KmE_d015Km00<0
05KmE_d00`000UKm00<005KmE_d015Km100015Km00<005KmE_d015Km0`0015Km00<004EA00000P00
0e<M00<005<MDad01e<M00<005<MDad00`000e<M00<005<MDad01U<M00@005<M000000IC7@03001C
7E<M00AC7@@000QC7@03001C7E<M00AC7@@000MC7@03001C7E<M00AC7@<000UC7@03001C7E<M00@0
009C7@03001C7E<M00MC7@800=aoo`03001oogoo02Moo`03001oogoo00Moo`00GWoo0P00_7oo00<0
05KmE_d015Km0`001UKm00@005KmE_eFo@D000IFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@03
001FoEKm00<000=Fo@04001FoEKmE_d20007Dad00`00DaeC7@05Dad40007Dad00`00DaeC7@04Dad3
0009Dad00`00DaeC7@030003Dad00`00DaeC7@07Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad0
0`00DaeC7@030003Dad00`00DaeC7@06Dad30007Dad00`00DaeC7@05Dad3003LOol00`00Oomoo`0W
Ool00`00Oomoo`07Ool0061oo`03001oogoo0;Yoo`03001FoEKm00<0009Fo@03001FoEKm00AFo@@0
00AFo@03001FoEKm00AFo@<000IFo@03001FoEKm00=Fo@<000MFo@05001FoEKmE_d00008Dad00`00
DaeC7@040003Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad30007Dad00`00
DaeC7@05Dad40007Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@06
Dad00`00DaeC7@040002O/h00`00Oomoo`3KOol00`00Oomoo`0VOol00`00Oomoo`07Ool0065oo`03
001oogoo0;Yoo`8000IFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@03001FoEKm00<0009Fo@03
001FoEKm00EFo@03001Fo@00008000=Fo@03001FoEKm00AFo@H000IC7@@000QC7@03001C7E<M00AC
7@@000MC7@03001C7E<M009C7@<0009C7@03001C7E<M00IC7@03001C7E<M00@0009C7@03001C7E<M
00MC7@03001C7E<M00<000=C7@03001C7E<M00IC7@04001C7@000006Dad00`00DaeC7@04Dad40002
Dad01@00O/incWk>0000gWoo00<007ooOol09Goo00<007ooOol01goo001ROol00`00Oomoo`2jOol0
0`00E_eFo@04E_d30006E_d00`00E_eFo@03E_d30006E_d00`00E_eFo@04E_d20007E_d00`00E_eF
o@0300001eKm001FoEKm00002P00009C7@<000=C7@03001C7E<M00MC7@03001C7E<M00<000=C7@03
001C7E<M00IC7@04001C7@000006Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@05Dad40007Dad0
0`00DaeC7@04Dad30009Dad00`00DaeC7@030003Dad01000DaeC7@000gk>00<007ooOol0gGoo00<0
07ooOol097oo00<007ooOol01goo001SOol2002kOol00`00E_eFo@030002E_d00`00E_eFo@05E_d0
0`00E_d000020003E_d00`00E_eFo@04E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d30005E_d0
0`00E_d0000200X20007Dad00`00DaeC7@05Dad40007Dad00`00DaeC7@04Dad30009Dad00`00DaeC
7@030003Dad00`00DaeC7@06Dad00`00DaeC7@040002Dad00`00DaeC7@07Dad00`00DaeC7@030003
Dad00`00DaeC7@06Dad30007Dad00`00Dad00003O/h00`00Oomoo`3MOol00`00Oomoo`0TOol00`00
Oomoo`07Ool006Eoo`03001oogoo0;Uoo`8000IFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d5
0006E_d00`00E_eFo@0300000eKm001Fo@06E_d2000300X00`00DaeC7@06Dad00`00DaeC7@040003
Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad30007Dad00`00DaeC7@04Dad4
0007Dad00`00DaeC7@05Dad40007Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@06Dad20003O/h0
0`00Oomoo`3NOol00`00Oomoo`0SOol00`00Oomoo`07Ool006Ioo`03001oogoo0;Yoo`03001FoEKm
00AFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@@000AFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00AFo@8000@02P03001C7E<M00AC7@@000QC7@03001C7E<M00AC7@@000MC7@03001C7E<M009C
7@<0009C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M00@000=C
7@03001C7E<M00IC7@04001C7@000006Dad00`00DaeC7@04Dad30003O/h00`00Oomoo`3OOol00`00
Oomoo`0SOol00`00Oomoo`06Ool006Moo`03001oogoo0;Yoo`04001FoEKmE_d50006E_d00`00E_eF
o@0300000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm
00002P0400X00`00DaeC7@030003Dad00`00DaeC7@07Dad00`00DaeC7@030003Dad00`00DaeC7@06
Dad01000Dad000001U<M00<005<MDad015<M10001e<M00<005<MDad015<M100025<M00<005<MDad0
15<M0`002E<M00<005<MDad00`000e<M00@007k>O/h00>9oo`03001oogoo029oo`03001oogoo00Io
o`00J7oo0P00^goo0`0015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001UKm00@005Km
E_eFo@D000AFo@0300002P0:00802P@000MC7@03001C7E<M00EC7@@000MC7@03001C7E<M00AC7@<0
00UC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00MC7@03
001C7E<M00<000=C7@03001C7E<M00IC7@<000MC7@03001ncP000>9oo`03001oogoo029oo`03001o
ogoo00Ioo`00JWoo00<007ooOol0^Goo00<005KmE_d015Km00<005KmE_d00`000eKm00<005KmE_d0
0eKm00<005KmE_d00`000eKm00<005KmE_d00eKm10001EKm00H005KmE_eFo@0000X30003Dad00`00
DaeC7@06Dad00`00DaeC7@040003Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06
Dad30007Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@05Dad40007Dad00`00DaeC7@02Dad30002
Dad00`00DaeC7@06Dad2003SOol00`00Oomoo`0QOol00`00Oomoo`06Ool006]oo`03001oogoo0;Uo
o`03001FoEKm00=Fo@<000MFo@04001FoEKmE_d40007E_d00`00E_d000020002E_d00`00E_eFo@05
E_d00`00E_eFo@020007Dad00`00DaeC7@04Dad40008Dad00`00DaeC7@04Dad40007Dad00`00DaeC
7@02Dad30002Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC7@04
0002Dad00`00DaeC7@07Dad01000Dad000001U<M00<005<MDad015<M0`00i7oo00<007ooOol087oo
00<007ooOol01Woo001/Ool00`00Oomoo`2iOol00`00E_d000020003E_d00`00E_eFo@04E_d40004
E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@04E_d300000eKm001C7@07Dad00`00DaeC7@030004
Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad01000Dad000001U<M00<005<M
Dad015<M10001e<M00<005<MDad015<M10001e<M00<005<MDad01E<M0`002E<M00<005<MDad00`00
0Wk>00<007ooOol0hWoo00<007ooOol087oo00<007ooOol01Woo001]Ool2002jOol00`00E_eFo@05
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eF
o@030002E_d01000E_d000001U<M100025<M00<005<MDad015<M10001e<M00<005<MDad015<M0`00
2E<M00<005<MDad00`000e<M00<005<MDad01U<M00<005<MDad00`000e<M00<005<MDad01U<M00<0
05<MDad010000U<M00<005<MDad01e<M0`0000=C7@00O/h00Wk>00<007ooOol0hgoo00<007ooOol0
7goo00<007ooOol01Woo001_Ool00`00Oomoo`2hOol00`00E_eFo@04E_d30005E_d00`00E_eFo@04
E_d30006E_d01000E_eFoEKm1@001UKm0P0000@02P00DaeC7@<000=C7@03001C7E<M00MC7@03001C
7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@<000MC7@03001C
7E<M00AC7@@000MC7@03001C7E<M00AC7@@000MC7@03001C7E<M00=C7@<00005Dad005<MDad00003
O/h00`00Oomoo`3TOol00`00Oomoo`0NOol00`00Oomoo`06Ool0071oo`03001oogoo0;Qoo`03001F
oEKm00<0009Fo@03001FoEKm00AFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@@000AFo@03001F
oEKm00AFo@8000802P8000MC7@03001C7E<M00EC7@@000MC7@03001C7E<M00AC7@@000MC7@03001C
7E<M009C7@<0009C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M
00<000=C7@03001C7E<M00IC7@03001C7@00008000EC7@03001C7@0000=ncP03001oogoo0>Eoo`03
001oogoo01ioo`03001oogoo00Eoo`00LGoo00<007ooOol0^7oo0P001UKm00@005KmE_eFo@D000IF
o@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d0000:00802P03001C7E<M00IC
7@03001C7E<M00@000=C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@04001C
7@000006Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@04Dad30009
Dad20003O/h00`00Oomoo`3UOol00`00Oomoo`0NOol00`00Oomoo`05Ool0079oo`800;Yoo`03001F
oEKm00=Fo@@000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000AFo@0300002P0:0080
2P03001C7E<M00AC7@@000QC7@03001C7E<M00AC7@@000MC7@03001C7E<M00AC7@@000QC7@03001C
7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M00<0
00=C7@03001C7E<M00IC7@8000=ncP03001oogoo0>Ioo`03001oogoo01eoo`03001oogoo00Eoo`00
M7oo00<007ooOol0^7oo00<005Km00000P000UKm00<005KmE_d015Km00<005KmE_d00`000eKm00<0
05KmE_d00eKm00<005KmE_d00`000eKm00D005KmE_eFo@0000D02P03001C7E<M00<000=C7@03001C
7E<M00MC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M00<000AC7@03001C7E<M00AC
7@@000MC7@03001C7E<M00AC7@@000MC7@03001C7E<M00AC7@@000MC7@03001C7E<M009C7@<0009C
7@04001ncWk>003YOol00`00Oomoo`0LOol00`00Oomoo`05Ool007Eoo`03001oogoo0;Qoo`03001F
oEKm00AFo@03001FoEKm00=Fo@<000MFo@04001FoEKmE_d40007E_d01000E_d00000100:10001e<M
00<005<MDad01E<M10001e<M00<005<MDad015<M100025<M00<005<MDad00`000e<M00<005<MDad0
1U<M00<005<MDad00`000e<M00<005<MDad01U<M00<005<MDad00`000e<M00<005<MDad01U<M00@0
05<M000000IC7@03001ncP000>Yoo`03001oogoo01]oo`03001oogoo00Eoo`00MWoo00<007ooOol0
^7oo00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d015Km100015Km00<005KmE_d015Km
0P0000=Fo@0000X00`000e<M00<005<MDad01U<M00<005<MDad010000U<M00<005<MDad01e<M00<0
05<MDad00`000e<M00<005<MDad01U<M0`001e<M00<005<MDad015<M10001e<M00<005<MDad015<M
10001e<M00<005<MDad015<M100025<M0P00jWoo00<007ooOol06goo00<007ooOol01Goo001gOol0
0`00Oomoo`2hOol01000E_eFoEKm10001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`000UKm0`001e<M00<005<MDad015<M10001e<M00<005<MDad01E<M10001e<M00<005<MDad00U<M
0`0000=C7@00Dad025<M00<005<MDad00`000e<M00<005<MDad01U<M00<005<MDad00`000e<M00<0
05<MDad01U<M00<005<MDad00`0015<M00<005<MDad015<M0`00jgoo00<007ooOol06Woo00<007oo
Ool01Goo001hOol2002iOol30004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30006E_d2
0008Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC7@040002Dad00`00DaeC7@07Dad0
1000Dad000001E<M00<005<MDad01E<M10001e<M00<005<MDad015<M10001e<M00<005<MDad015<M
100025<M00<005<MDad00`00kgoo00<007ooOol06Woo00<007ooOol017oo001jOol00`00Oomoo`2f
Ool00`00E_eFo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eFo@030002E_d00`00
E_eFo@04E_d30006Dad40007Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@05Dad30008Dad00`00
DaeC7@040002Dad00`00DaeC7@07Dad00`00DaeC7@030002Dad00`00DaeC7@07Dad00`00DaeC7@03
0002Dad00`00DaeC7@07Dad3003bOol00`00Oomoo`0JOol00`00Oomoo`04Ool007]oo`03001oogoo
0;Ioo`03001FoEKm00AFo@<000IFo@04001FoEKmE_d50006E_d00`00E_eFo@03000015Km001Fo@00
0U<M0`000e<M00<005<MDad01U<M00<005<MDad00`000e<M00<005<MDad01U<M00<005<MDad01000
0e<M00<005<MDad015<M10001e<M00<005<MDad01E<M10001U<M00<005<MDad01E<M10001U<M00<0
05<MDad00e<M0`00mWoo00<007ooOol06Goo00<007ooOol017oo001lOol00`00Oomoo`2fOol00`00
E_eFo@030003E_d00`00E_eFo@03E_d40004E_d00`00E_eFo@04E_d30005E_d01000E_d000001e<M
00<005<MDad015<M10001e<M00<005<MDad015<M100025<M00<005<MDad00`000e<M00<005<MDad0
1U<M00<005<MDad010000U<M00<005<MDad01U<M00<005<MDad010000U<M00<005<MDad01U<M00<0
05<M00000`00nGoo00<007ooOol067oo00<007ooOol017oo001mOol2002gOol20007E_d00`00E_d0
00020002E_d00`00E_eFo@04E_d00`00E_eFo@030003E_d00`00E_eFo@03E_d00`00E_d00008Dad0
0`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad30007Dad0
0`00DaeC7@04Dad40007Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@04Dad40002Dad00`00Oomo
o`3hOol00`00Oomoo`0GOol00`00Oomoo`04Ool007moo`03001oogoo0;Ioo`03001FoEKm00AFo@80
00IFo@03001FoEKm00=Fo@<000MFo@04001FoEKmE_d50006Dad40007Dad00`00DaeC7@04Dad40007
Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad0
0`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC7@030004Dad00`00Dad0003jOol00`00Oomo
o`0GOol00`00Oomoo`04Ool0081oo`03001oogoo0;Ioo`03001FoEKm00<0009Fo@03001FoEKm00AF
o@03001Fo@00008000=Fo@03001FoEKm00AFo@@000Eoo`03001C7E<M00<000=C7@03001C7E<M00IC
7@03001C7E<M00<000=C7@03001C7E<M00IC7@04001C7@000006Dad00`00DaeC7@04Dad40007Dad0
0`00DaeC7@04Dad40007Dad00`00DaeC7@04Dad40008Dad2003kOol00`00Oomoo`0FOol00`00Oomo
o`04Ool0085oo`03001oogoo0;Ioo`8000IFo@04001FoEKmE_d40007E_d00`00E_eFo@03000:Ool2
0007Dad00`00DaeC7@04Dad40007Dad00`00DaeC7@04Dad40008Dad00`00DaeC7@030003Dad00`00
DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC7@030004Dad00`00DaeC7@04
Dad3003lOol00`00Oomoo`0EOol00`00Oomoo`04Ool0089oo`800;Moo`03001FoEKm00AFo@@000AF
o@03001FoEKm00AFo@<000ioo`03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03
001C7E<M00<000AC7@03001C7E<M00AC7@@000MC7@03001C7E<M00AC7@@000MC7@03001C7E<M00AC
7@@000QC7@03001C7E<M00<00?moo`5oo`03001oogoo01Eoo`03001oogoo00=oo`00Q7oo00<007oo
Ool0]Goo00<005KmE_d00`000UKm00<005KmE_d015Km00<005KmE_d00`004Woo00<005<MDad015<M
10001e<M00<005<MDad015<M100025<M00<005<MDad00`000e<M00<005<MDad01U<M00<005<MDad0
0`000e<M00<005<MDad01U<M00<005<MDad00`000e<M00<005<MDad01U<M0`00ogoo17oo00<007oo
Ool05Goo00<007ooOol00goo0025Ool00`00Oomoo`2eOol20006E_d01000E_eFoEKm1@005Woo00<0
05<MDad00`000goo00<005<MDad01U<M00<005<MDad00`0015<M00<005<MDad015<M10001e<M00<0
05<MDad015<M10001e<M00<005<MDad015<M10001e<M00<005<MDad00U<M0`00ogoo27oo00<007oo
Ool057oo00<007ooOol00goo0026Ool00`00Oomoo`2fOol00`00E_eFo@03E_d4000LOol20007Ool0
0`00DaeC7@04Dad40008Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad0
0`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad01P00Dad00000Dad00?moo`Yoo`03
001oogoo01=oo`03001oogoo00=oo`00Qgoo0P00]goo00<005Km00000P00:Woo00<005<MDad00`00
0e<M00<005<MDad01U<M0`001e<M00<005<MDad015<M10001e<M00<005<MDad015<M10001e<M00<0
05<MDad015<M10000U<M00<007ooOol0ogoo27oo00<007ooOol04goo00<007ooOol00goo0029Ool0
0`00Oomoo`2eOol00`00Oomoo`0/Ool20007Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@06Dad0
0`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC
7@030004Dad00`00Dad0003oOol;Ool00`00Oomoo`0BOol00`00Oomoo`03Ool008Yoo`03001oogoo
0;Aoo`03001oogoo02eoo`03001C7E<M00IC7@04001C7@000006Dad00`00DaeC7@04Dad40007Dad0
0`00DaeC7@04Dad40007Dad00`00DaeC7@04Dad40008Dad2003oOol<Ool00`00Oomoo`0AOol00`00
Oomoo`03Ool008]oo`03001oogoo0;=oo`03001oogoo02ioo`03001C7E<M00AC7@@000QC7@03001C
7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M00<000=C7@03001C7E<M00IC7@03001C7E<M00<0
00=C7@03001C7E<M00EC7@<00?moo`eoo`03001oogoo015oo`03001oogoo009oo`00S7oo0P00/goo
00<007ooOol0;goo00<005<MDad00`0017oo00<005<MDad015<M10001e<M00<005<MDad015<M1000
1e<M00<005<MDad015<M10001e<M00<005<MDad01000ogoo47oo00<007ooOol04Goo00<007ooOol0
0Woo002>Ool00`00Oomoo`2`Ool00`00Oomoo`0`Ool20008Ool00`00DaeC7@030003Dad00`00DaeC
7@06Dad00`00DaeC7@030003Dad00`00DaeC7@06Dad00`00DaeC7@030003Dad00`00DaeC7@04Dad4
003oOolEOol00`00Oomoo`0@Ool00`00Oomoo`02Ool008moo`03001oogoo0:moo`03001oogoo03]o
o`8000MC7@03001C7E<M00AC7@@000MC7@03001C7E<M00AC7@@000MC7@03001C7E<M00<00?mooaYo
o`03001oogoo00moo`03001oogoo009oo`00T7oo00<007ooOol0[Woo00<007ooOol0?7oo00<005<M
Dad01U<M00<005<MDad00`000goo00<005<MDad01U<M00<005<MDad00`000goo00<005<MDad015<M
1000ogoo7Woo00<007ooOol03Woo00<007ooOol00Woo002AOol2002^Ool00`00Oomoo`0mOol00`00
DaeC7@04Dad40007Ool00`00DaeC7@04Dad40007Ool00`00DaeC7@03003oOolROol00`00Oomoo`0>
Ool00`00Oomoo`02Ool009=oo`03001oogoo0:]oo`03001oogoo03ioo`03001C7E<M00<000aoo`03
001C7E<M00<000aoo`800?moobIoo`03001oogoo00eoo`03001oogoo009oo`00U7oo00<007ooOol0
ZWoo00<007ooOol0?goo0P0047oo0P00ogoo>7oo00<007ooOol037oo00<007ooOol00Woo002EOol0
0`00Oomoo`2YOol00`00Oomoo`3oOon;Ool00`00Oomoo`0=Ool00`00Oomoo`01Ool009Ioo`03001o
ogoo0:Qoo`03001oogoo0?moohaoo`03001oogoo00aoo`03001oogoo005oo`00Ugoo0P00Z7oo00<0
07ooOol0ogooSGoo00<007ooOol02goo00<007ooOol00Goo002IOol00`00Oomoo`2TOol00`00Oomo
o`3oOon?Ool00`00Oomoo`0:Ool00`00Oomoo`01Ool009Yoo`03001oogoo0:=oo`03001oogoo0?mo
ohmoo`03001oogoo00Yoo`03001oogoo005oo`00Vgoo00<007ooOol0XWoo00<007ooOol0ogooT7oo
00<007ooOol02Goo00<007ooOol00Goo002LOol2002ROol00`00Oomoo`3oOonAOol00`00Oomoo`08
Ool00`00Oomoo`01Ool009ioo`03001oogoo09moo`03001oogoo0?mooi9oo`03001oogoo00Qoo`40
005oo`5oo`00Wgoo00<007ooOol0WWoo00<007ooOol0ogooTWoo00<007ooOol027oo0@000Goo0Goo
002POol00`00Oomoo`2MOol00`00Oomoo`3oOonCOol00`00Oomoo`07Ool10001Ool1Ool00:5oo`80
09eoo`03001oogoo0?mooiAoo`03001oogoo00Ioo`40005oo`5oo`00Xgoo00<007ooOol0VWoo00<0
07ooOol0ogooU7oo00<007ooOol01Woo0@000Goo0Goo002TOol00`00Oomoo`2IOol00`00Oomoo`3o
OonEOol00`00Oomoo`05Ool10001Ool1Ool00:Eoo`03001oogoo09Qoo`03001oogoo0?mooiIoo`03
001oogoo00Aoo`40005oo`5oo`00YWoo0P00V7oo00<007ooOol0ogooUgoo00<007ooOol00goo0@00
0Goo0Goo002XOol00`00Oomoo`2EOol00`00Oomoo`3oOonGOol00`00Oomoo`04Ool10001Ool00:Uo
o`03001oogoo09Aoo`03001oogoo0?mooiQoo`03001oogoo00=oo`40005oo`00ZWoo00<007ooOol0
Tgoo00<007ooOol0ogooVGoo00<007ooOol00Woo0@000Goo002[Ool2002COol00`00Oomoo`3oOonJ
Ool01@00Oomoogoo00000Goo002]Ool00`00Oomoo`2@Ool00`00Oomoo`3oOonJOol01@00Oomoogoo
00000Goo002^Ool00`00Oomoo`2?Ool00`00Oomoo`3oOonKOol01000Oomoo`000Goo002_Ool00`00
Oomoo`2>Ool00`00Oomoo`3oOonLOol00`00Ool00001Ool00;1oo`8008ioo`03001oogoo0?mooiao
o`03001oogoo00400000/Woo00<007ooOol0Rgoo00<007ooOol0ogooWGoo0@000Goo0@00002cOol0
0`00Oomoo`2:Ool00`00Oomoo`3oOonNOol200000;Aoo`03001oogoo08Uoo`03001oogoo0?mooieo
o`<00000]Goo00<007ooOol0R7oo00<007ooOol0ogooVGoo10000goo002fOol20028Ool00`00Oomo
o`3oOonEOol40007Ool00;Qoo`03001oogoo08Eoo`03001oogoo0?mooi9oo`<000]oo`00^Goo00<0
07ooOol0Q7oo00<007ooOol0ogooSWoo10003Woo002jOol00`00Oomoo`23Ool00`00Oomoo`3oOon:
Ool4000BOol00;]oo`8008=oo`03001oogoo0?moohIoo`@001Ioo`00_Goo00<007ooOol0Ogoo00<0
07ooOol0ogooPgoo10006Woo002nOol00`00Oomoo`1nOol00`00Oomoo`3oOomoOol4000NOol00;mo
o`03001oogoo07eoo`03001oogoo0?moogaoo`<0029oo`00`7oo0P00OGoo00<007ooOol0ogooN7oo
10009Goo0032Ool00`00Oomoo`1jOol00`00Oomoo`3oOomdOol4000YOol00<=oo`03001oogoo07Uo
o`03001oogoo0?moog1oo`@002eoo`00a7oo00<007ooOol0N7oo00<007ooOol0ogooK7oo1000<Goo
0035Ool2001hOol00`00Oomoo`3oOomYOol3000eOol00<Moo`03001oogoo07Eoo`03001oogoo0?mo
ofEoo`@003Qoo`00b7oo00<007ooOol0M7oo00<007ooOol0ogooHGoo1000?7oo0039Ool00`00Oomo
o`1cOol00`00Oomoo`3oOomMOol40010Ool00<Yoo`8007=oo`03001oogoo0?mooeUoo`@004Aoo`00
c7oo00<007ooOol0L7oo00<007ooOol0ogooEGoo1000B7oo003=Ool00`00Oomoo`1_Ool00`00Oomo
o`3oOomBOol3001<Ool00<ioo`03001oogoo06ioo`03001oogoo0?moodioo`@004moo`00cgoo0P00
KWoo00<007ooOol0ogooBWoo1000Dgoo003AOol00`00Oomoo`1[Ool00`00Oomoo`3oOom6Ool4001G
Ool00=9oo`03001oogoo06Yoo`03001oogoo0?mood9oo`@005]oo`00dgoo00<007ooOol0JGoo00<0
07ooOol0ogoo?Woo1000Ggoo003DOol00`00Oomoo`1XOol00`00Oomoo`3oOolkOol3001SOol00=Eo
o`8006Qoo`03001oogoo0?moocMoo`@006Ioo`00egoo00<007ooOol0IGoo00<007ooOol0ogoo<goo
1000JWoo003HOol00`00Oomoo`1TOol00`00Oomoo`3oOol_Ool4001^Ool00=Uoo`03001oogoo06=o
o`03001oogoo0?moob]oo`@0079oo`00fWoo0P00Hgoo00<007ooOol0ogoo9goo1000MWoo003LOol0
0`00Oomoo`1POol00`00Oomoo`3oOolTOol3001jOol00=eoo`03001oogoo05moo`03001oogoo0?mo
ob1oo`@007eoo`00gWoo00<007ooOol0GWoo00<007ooOol0ogoo77oo1000PGoo003OOol2001NOol0
0`00Oomoo`3oOolHOol40025Ool00>5oo`03001oogoo05]oo`03001oogoo0?mooaAoo`@008Uoo`00
hWoo00<007ooOol0FGoo00<007ooOol0ogoo4Goo1000SGoo003SOol00`00Oomoo`1HOol00`00Oomo
o`3oOol>Ool3002AOol00>Aoo`8005Qoo`03001oogoo0?moo`Yoo`@009Aoo`00iWoo00<007ooOol0
EGoo00<007ooOol0ogoo1Woo1000V7oo003WOol00`00Oomoo`1DOol00`00Oomoo`3oOol2Ool4002L
Ool00>Qoo`03001oogoo05=oo`03001oogoo0?eoo`@00:1oo`00jGoo0P00Dgoo00<007ooOol0nWoo
0`00Y7oo003[Ool00`00Oomoo`1@Ool00`00Oomoo`3fOol4002WOol00>aoo`03001oogoo04moo`03
001oogoo0?9oo`@00:]oo`00kGoo00<007ooOol0CWoo00<007ooOol0kWoo1000[goo003^Ool2001>
Ool00`00Oomoo`3ZOol4002cOol00?1oo`03001oogoo04]oo`03001oogoo0>Ioo`@00;Moo`00lGoo
00<007ooOol0BWoo00<007ooOol0hgoo0`00^goo003bOol00`00Oomoo`19Ool00`00Oomoo`3OOol4
002nOol00?=oo`03001oogoo04Qoo`03001oogoo0=]oo`@00<9oo`00m7oo0P00B7oo00<007ooOol0
egoo1000aWoo003fOol00`00Oomoo`15Ool00`00Oomoo`3COol4003:Ool00?Moo`03001oogoo04Ao
o`03001oogoo0<moo`@00<ioo`00n7oo00<007ooOol0@goo00<007ooOol0c7oo0`00dWoo003iOol2
0013Ool00`00Oomoo`38Ool4003EOol00?]oo`03001oogoo041oo`03001oogoo0<Aoo`@00=Uoo`00
o7oo00<007ooOol0?goo00<007ooOol0`7oo1000gGoo003mOol00`00Oomoo`0nOol00`00Oomoo`2l
Ool4003QOol00?ioo`8003ioo`03001oogoo0;Qoo`@00>Eoo`00ogoo0Goo00<007ooOol0>goo00<0
07ooOol0]Goo0`00jGoo003oOol2Ool00`00Oomoo`0jOol00`00Oomoo`2aOol4003/Ool00?moo`=o
o`03001oogoo03Uoo`03001oogoo0:eoo`@00?1oo`00ogoo17oo0P00>Goo00<007ooOol0ZGoo1000
m7oo003oOol6Ool00`00Oomoo`0fOol00`00Oomoo`2UOol4003hOol00?moo`Moo`03001oogoo03Eo
o`03001oogoo0:5oo`@00?aoo`00ogoo27oo00<007ooOol0<goo00<007ooOol0Wgoo0`00ogoo0Goo
003oOol9Ool2000cOol00`00Oomoo`2KOol4003oOol4Ool00?moo`]oo`03001oogoo031oo`03001o
ogoo09Moo`@00?moo`Qoo`00ogoo37oo00<007ooOol0;goo00<007ooOol0Tgoo1000ogoo37oo003o
Ool=Ool00`00Oomoo`0^Ool00`00Oomoo`2?Ool4003oOol@Ool00?moo`ioo`8002ioo`03001oogoo
08aoo`<00?mooaAoo`00ogoo47oo00<007ooOol0:goo00<007ooOol0R7oo1000ogoo5goo003oOolA
Ool00`00Oomoo`0ZOol00`00Oomoo`24Ool4003oOolKOol00?mooa9oo`03001oogoo02Uoo`03001o
ogoo081oo`@00?mooamoo`00ogoo4goo00<007ooOol0:7oo00<007ooOol0O7oo1000ogoo8goo003o
OolDOol2000XOol00`00Oomoo`1hOol4003oOolWOol00?mooaIoo`03001oogoo02Eoo`03001oogoo
07Eoo`<00?moob]oo`00ogoo5goo00<007ooOol097oo00<007ooOol0LGoo1000ogoo;Woo003oOolH
Ool00`00Oomoo`0SOol00`00Oomoo`1]Ool4003oOolbOol00?mooaUoo`8002=oo`03001oogoo06Uo
o`@00?moocIoo`00ogoo6goo00<007ooOol087oo00<007ooOol0IGoo1000ogoo>Woo003oOolLOol0
0`00Oomoo`0OOol00`00Oomoo`1QOol4003oOolnOol00?mooaeoo`03001oogoo01ioo`03001oogoo
05ioo`<00?mood9oo`00ogoo7Woo0P007Woo00<007ooOol0FWoo1000ogooAGoo003oOolPOol00`00
Oomoo`0KOol00`00Oomoo`1FOol4003oOom9Ool00?moob5oo`03001oogoo01Yoo`03001oogoo059o
o`@00?moodeoo`00ogoo8Woo00<007ooOol06Goo00<007ooOol0CWoo1000ogooDGoo003oOolSOol2
000IOol00`00Oomoo`1:Ool4003oOomEOol00?moobEoo`03001oogoo01Ioo`03001oogoo04Moo`<0
0?mooeUoo`00ogoo9Woo00<007ooOol05Goo00<007ooOol0@goo1000ogooG7oo003oOolWOol00`00
Oomoo`0DOol00`00Oomoo`0oOol4003oOomPOol00?moobQoo`8001Aoo`03001oogoo03]oo`@00?mo
ofAoo`00ogoo:Woo00<007ooOol04Goo00<007ooOol0=goo1000ogooJ7oo003oOol[Ool00`00Oomo
o`0@Ool00`00Oomoo`0cOol4003oOom/Ool00?moobaoo`03001oogoo00ioo`03001oogoo035oo`<0
0?moog1oo`00ogoo;Goo0P003Woo00<007ooOol0;Goo1000ogooLgoo003oOol_Ool00`00Oomoo`0;
Ool00`00Oomoo`0YOol4003oOomgOol00?mooc1oo`03001oogoo00Yoo`03001oogoo02Eoo`@00?mo
og]oo`00ogoo<Goo00<007ooOol02Goo00<007ooOol08Goo1000ogooOgoo003oOolbOol00`00Oomo
o`08Ool00`00Oomoo`0NOol3003oOon3Ool00?mooc=oo`8000Qoo`03001oogoo01Yoo`@00?moohIo
o`00ogoo=Goo00<007ooOol01Goo00<007ooOol05Woo1000ogooRWoo003oOolfOol00`00Oomoo`04
Ool00`00Oomoo`0BOol4003oOon>Ool00?moocMoo`03001oogoo00=oo`03001oogoo00ioo`@00?mo
oi9oo`00ogoo>7oo0P000goo00<007ooOol02Woo1000ogooUWoo003oOoljOol01000Oomoo`002Goo
0`00ogooVWoo003oOolkOol00`00Ool00005Ool4003oOonMOol00?moocaoo`800003Ool000000080
0?mooj5oo`00ogoo?Goo0P00ogooYGoo003oOoooOooTOol00?mooomoonAoo`00ogooogooi7oo003o
OoooOooTOol00?mooomoonAoo`00ogooogooi7oo003oOoooOooTOol00?mooomoonAoo`00ogooogoo
i7oo003oOoooOooTOol00?mooomoonAoo`00ogooogooi7oo003oOoooOooTOol00?mooomoonAoo`00
ogooogooi7oo0000\
\>"],
   ImageRangeCache->{{{0, 737.75}, {598.25, 0}} -> {-0.0509564, 0.044183,
   0.00204043, 0.00204043}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
     \(\(Robject1 =
       Radon2[object1, xp\ Cos[\[Theta]] - yp\ Sin[\[Theta]],
         yp\ Cos[\[Theta]]\  + \ xp\ Sin[\[Theta]], 64, 64]; \)\)], "Input"],

Cell[BoxData[
     \(NIntegrate::"slwcon" \( : \ \)
       "Numerical integration converging too slowly; suspect singularity, \
value of the integration is 0, oscillatory integrand, or insufficient \
WorkingPrecision. If your integrand is oscillatory try using the option \
Method->Oscillatory in NIntegrate."\)], "Message"],

Cell[BoxData[
     \(NIntegrate::"slwcon" \( : \ \)
       "Numerical integration converging too slowly; suspect singularity, \
value of the integration is 0, oscillatory integrand, or insufficient \
WorkingPrecision. If your integrand is oscillatory try using the option \
Method->Oscillatory in NIntegrate."\)], "Message"],

Cell[BoxData[
     \(NIntegrate::"ncvb" \( : \ \)
       "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(yp\) near \!\(yp\) = \!\(-4.5`\)."\)], "Message"],

Cell[BoxData[
     \(NIntegrate::"slwcon" \( : \ \)
       "Numerical integration converging too slowly; suspect singularity, \
value of the integration is 0, oscillatory integrand, or insufficient \
WorkingPrecision. If your integrand is oscillatory try using the option \
Method->Oscillatory in NIntegrate."\)], "Message"],

Cell[BoxData[
     \(General::"stop" \( : \ \)
       "Further output of \!\(NIntegrate :: \"slwcon\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[BoxData[
     \(NIntegrate::"ncvb" \( : \ \)
       "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(yp\) near \!\(yp\) = \!\(-4.5`\)."\)], "Message"],

Cell[BoxData[
     \(NIntegrate::"ncvb" \( : \ \)
       "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(yp\) near \!\(yp\) = \!\(-4.5`\)."\)], "Message"],

Cell[BoxData[
     \(General::"stop" \( : \ \)
       "Further output of \!\(NIntegrate :: \"ncvb\"\) will be suppressed \
during this calculation."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
     \(ListPlot3D[Robject1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.2083 .17506 -11.6698 -9 ]
[.2083 .17506 .33019 0 ]
[.41321 .09446 -10.8756 -9 ]
[.41321 .09446 1.12444 0 ]
[.63499 .00731 -10.0813 -9 ]
[.63499 .00731 1.9187 0 ]
[.79894 .14525 0 -6.11522 ]
[.79894 .14525 12 2.88478 ]
[.88874 .28276 0 -5.98496 ]
[.88874 .28276 12 3.01504 ]
[.96735 .40315 0 -5.87414 ]
[.96735 .40315 12 3.12586 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01353 .33145 -12 -2.79843 ]
[.01353 .33145 0 6.20157 ]
[.00248 .4007 -12 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.00907 .47308 -12 -2.91903 ]
[-0.00907 .47308 0 6.08097 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78659 .14969 m
.78042 .1519 L
s
[(20)] .79894 .14525 -1 .35894 Mshowa
.87628 .28687 m
.87005 .28893 L
s
[(40)] .88874 .28276 -1 .32999 Mshowa
.9548 .40699 m
.94853 .4089 L
s
[(60)] .96735 .40315 -1 .30537 Mshowa
.125 Mabswid
.7105 .03329 m
.70682 .0347 L
s
.7368 .07352 m
.73311 .0749 L
s
.76215 .11229 m
.75845 .11365 L
s
.81019 .18578 m
.80647 .18708 L
s
.83297 .22063 m
.82925 .22191 L
s
.85499 .25431 m
.85126 .25557 L
s
.89687 .31837 m
.89312 .31958 L
s
.9168 .34886 m
.91305 .35005 L
s
.9361 .37838 m
.93234 .37955 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.0258 .3268 m
.03194 .32448 L
s
[(10)] .01353 .33145 1 -0.37813 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(20)] .00248 .4007 1 -0.36505 Mshowa
.00331 .46873 m
.0095 .46656 L
s
[(30)] -0.00907 .47308 1 -0.35133 Mshowa
.125 Mabswid
.03427 .2734 m
.03794 .27198 L
s
.03218 .28658 m
.03585 .28517 L
s
.03007 .29987 m
.03375 .29847 L
s
.02795 .31328 m
.03163 .31188 L
s
.02364 .34044 m
.02733 .33906 L
s
.02146 .3542 m
.02515 .35283 L
s
.01926 .36808 m
.02295 .36671 L
s
.01704 .38208 m
.02074 .38072 L
s
.01255 .41045 m
.01625 .40911 L
s
.01027 .42483 m
.01397 .4235 L
s
.00797 .43933 m
.01168 .43801 L
s
.00565 .45397 m
.00936 .45265 L
s
.00095 .48363 m
.00467 .48233 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.40028 .59921 .40512 .60371 .41325 .60128 .40842 .59675 Metetra
.664 .741 .908 r
.40842 .59675 .41325 .60128 .4214 .59883 .41659 .5943 Metetra
.664 .741 .908 r
.41659 .5943 .4214 .59883 .42958 .59638 .42478 .59183 Metetra
.664 .741 .908 r
.42478 .59183 .42958 .59638 .43778 .59392 .433 .58935 Metetra
.664 .741 .908 r
.433 .58935 .43778 .59392 .446 .59145 .44124 .58687 Metetra
.664 .741 .908 r
.44124 .58687 .446 .59145 .45426 .58897 .44951 .58438 Metetra
.664 .741 .908 r
.44951 .58438 .45426 .58897 .46253 .58649 .4578 .58189 Metetra
.664 .741 .908 r
.4578 .58189 .46253 .58649 .47083 .584 .46612 .57938 Metetra
.664 .741 .908 r
.46612 .57938 .47083 .584 .47916 .5815 .47446 .57687 Metetra
.664 .741 .908 r
.47446 .57687 .47916 .5815 .48751 .579 .48283 .57435 Metetra
.664 .741 .908 r
.48283 .57435 .48751 .579 .49589 .57648 .49123 .57182 Metetra
.664 .741 .908 r
.49123 .57182 .49589 .57648 .50429 .57396 .49965 .56929 Metetra
.664 .741 .908 r
.49965 .56929 .50429 .57396 .51272 .57143 .50809 .56674 Metetra
.664 .741 .908 r
.50809 .56674 .51272 .57143 .52118 .5689 .51657 .56419 Metetra
.664 .741 .908 r
.51657 .56419 .52118 .5689 .52966 .56635 .52506 .56163 Metetra
.664 .741 .908 r
.52506 .56163 .52966 .56635 .53817 .5638 .53359 .55907 Metetra
.664 .741 .908 r
.53359 .55907 .53817 .5638 .5467 .56124 .54214 .55649 Metetra
.664 .741 .908 r
.54214 .55649 .5467 .56124 .55526 .55867 .55072 .55391 Metetra
.664 .741 .908 r
.55072 .55391 .55526 .55867 .56385 .55609 .55932 .55132 Metetra
.664 .741 .908 r
.55932 .55132 .56385 .55609 .57247 .55351 .56796 .54872 Metetra
.664 .741 .908 r
.56796 .54872 .57247 .55351 .58111 .55092 .57661 .54611 Metetra
.664 .741 .908 r
.57661 .54611 .58111 .55092 .58977 .54832 .5853 .5435 Metetra
.664 .741 .908 r
.5853 .5435 .58977 .54832 .59847 .54571 .59401 .54087 Metetra
.664 .741 .908 r
.59401 .54087 .59847 .54571 .60719 .54309 .60275 .53824 Metetra
.664 .741 .908 r
.60275 .53824 .60719 .54309 .61594 .54047 .61152 .5356 Metetra
.664 .741 .908 r
.61152 .5356 .61594 .54047 .62472 .53784 .62032 .53295 Metetra
.664 .741 .908 r
.62032 .53295 .62472 .53784 .63352 .53519 .62914 .5303 Metetra
.664 .741 .908 r
.62914 .5303 .63352 .53519 .64235 .53254 .63799 .52763 Metetra
.664 .741 .908 r
.63799 .52763 .64235 .53254 .65121 .52989 .64687 .52496 Metetra
.664 .741 .908 r
.64687 .52496 .65121 .52989 .6601 .52722 .65578 .52227 Metetra
.664 .741 .908 r
.65578 .52227 .6601 .52722 .66902 .52454 .66471 .51958 Metetra
.664 .741 .908 r
.66471 .51958 .66902 .52454 .67796 .52186 .67368 .51689 Metetra
.664 .741 .908 r
.67368 .51689 .67796 .52186 .68694 .51917 .68267 .51418 Metetra
.664 .741 .908 r
.68267 .51418 .68694 .51917 .69594 .51647 .69169 .51146 Metetra
.664 .741 .908 r
.69169 .51146 .69594 .51647 .70497 .51376 .70074 .50874 Metetra
.664 .741 .908 r
.70074 .50874 .70497 .51376 .71403 .51104 .70982 .506 Metetra
.664 .741 .908 r
.70982 .506 .71403 .51104 .72311 .50832 .71893 .50326 Metetra
.664 .741 .908 r
.71893 .50326 .72311 .50832 .73223 .50558 .72807 .50051 Metetra
.664 .741 .908 r
.72807 .50051 .73223 .50558 .74138 .50284 .73723 .49775 Metetra
.664 .741 .908 r
.73723 .49775 .74138 .50284 .75055 .50008 .74643 .49498 Metetra
.664 .741 .908 r
.74643 .49498 .75055 .50008 .75976 .49732 .75565 .4922 Metetra
.664 .741 .908 r
.75565 .4922 .75976 .49732 .76899 .49455 .76491 .48941 Metetra
.664 .741 .908 r
.76491 .48941 .76899 .49455 .77826 .49177 .77419 .48662 Metetra
.664 .741 .908 r
.77419 .48662 .77826 .49177 .78755 .48899 .78351 .48381 Metetra
.664 .741 .908 r
.78351 .48381 .78755 .48899 .79688 .48619 .79286 .481 Metetra
.664 .741 .908 r
.79286 .481 .79688 .48619 .80623 .48338 .80223 .47818 Metetra
.664 .741 .908 r
.80223 .47818 .80623 .48338 .81562 .48057 .81164 .47534 Metetra
.664 .741 .908 r
.81164 .47534 .81562 .48057 .82503 .47774 .82108 .4725 Metetra
.664 .741 .908 r
.82108 .4725 .82503 .47774 .83448 .47491 .83054 .46965 Metetra
.664 .741 .908 r
.83054 .46965 .83448 .47491 .84395 .47206 .84004 .46679 Metetra
.664 .741 .908 r
.84004 .46679 .84395 .47206 .85346 .46921 .84957 .46392 Metetra
.664 .741 .908 r
.84957 .46392 .85346 .46921 .863 .46635 .85914 .46104 Metetra
.664 .741 .908 r
.85914 .46104 .863 .46635 .87257 .46348 .86873 .45815 Metetra
.664 .741 .908 r
.86873 .45815 .87257 .46348 .88217 .4606 .87835 .45526 Metetra
.664 .741 .908 r
.87835 .45526 .88217 .4606 .89181 .45771 .88801 .45235 Metetra
.664 .741 .908 r
.88801 .45235 .89181 .45771 .90147 .45481 .8977 .44943 Metetra
.664 .741 .908 r
.8977 .44943 .90147 .45481 .91117 .4519 .90742 .4465 Metetra
.664 .741 .908 r
.90742 .4465 .91117 .4519 .9209 .44898 .91717 .44357 Metetra
.664 .741 .908 r
.91717 .44357 .9209 .44898 .93066 .44605 .92696 .44062 Metetra
.664 .741 .908 r
.92696 .44062 .93066 .44605 .94045 .44311 .93677 .43766 Metetra
.664 .741 .908 r
.93677 .43766 .94045 .44311 .95028 .44017 .94663 .4347 Metetra
.664 .741 .908 r
.94663 .4347 .95028 .44017 .96014 .43721 .95651 .43172 Metetra
.664 .741 .908 r
.95651 .43172 .96014 .43721 .97003 .43424 .96642 .42874 Metetra
.664 .741 .908 r
.39541 .59467 .40028 .59921 .40842 .59675 .40357 .59221 Metetra
.664 .741 .908 r
.40357 .59221 .40842 .59675 .41659 .5943 .41175 .58974 Metetra
.664 .741 .908 r
.41175 .58974 .41659 .5943 .42478 .59183 .41996 .58726 Metetra
.664 .741 .908 r
.41996 .58726 .42478 .59183 .433 .58935 .4282 .58477 Metetra
.664 .741 .908 r
.4282 .58477 .433 .58935 .44124 .58687 .43645 .58227 Metetra
.664 .741 .908 r
.43645 .58227 .44124 .58687 .44951 .58438 .44474 .57977 Metetra
.664 .741 .908 r
.44474 .57977 .44951 .58438 .4578 .58189 .45304 .57726 Metetra
.664 .741 .908 r
.45304 .57726 .4578 .58189 .46612 .57938 .46138 .57474 Metetra
.664 .741 .908 r
.46138 .57474 .46612 .57938 .47446 .57687 .46974 .57221 Metetra
.664 .741 .908 r
.46974 .57221 .47446 .57687 .48283 .57435 .47812 .56968 Metetra
.664 .741 .908 r
.47812 .56968 .48283 .57435 .49123 .57182 .48653 .56714 Metetra
.664 .741 .908 r
.48653 .56714 .49123 .57182 .49965 .56929 .49497 .56459 Metetra
.664 .741 .908 r
.49497 .56459 .49965 .56929 .50809 .56674 .50344 .56203 Metetra
.664 .741 .908 r
.50344 .56203 .50809 .56674 .51657 .56419 .51193 .55946 Metetra
.664 .741 .908 r
.51193 .55946 .51657 .56419 .52506 .56163 .52044 .55689 Metetra
.664 .741 .908 r
.52044 .55689 .52506 .56163 .53359 .55907 .52898 .55431 Metetra
.664 .741 .908 r
.52898 .55431 .53359 .55907 .54214 .55649 .53755 .55172 Metetra
.664 .741 .908 r
.53755 .55172 .54214 .55649 .55072 .55391 .54615 .54912 Metetra
.664 .741 .908 r
.54615 .54912 .55072 .55391 .55932 .55132 .55477 .54651 Metetra
.664 .741 .908 r
.55477 .54651 .55932 .55132 .56796 .54872 .56342 .5439 Metetra
.664 .741 .908 r
.56342 .5439 .56796 .54872 .57661 .54611 .5721 .54128 Metetra
.664 .741 .908 r
.5721 .54128 .57661 .54611 .5853 .5435 .5808 .53865 Metetra
.664 .741 .908 r
.5808 .53865 .5853 .5435 .59401 .54087 .58953 .53601 Metetra
.664 .741 .908 r
.58953 .53601 .59401 .54087 .60275 .53824 .59829 .53336 Metetra
.664 .741 .908 r
.59829 .53336 .60275 .53824 .61152 .5356 .60708 .5307 Metetra
.664 .741 .908 r
.60708 .5307 .61152 .5356 .62032 .53295 .61589 .52804 Metetra
.664 .741 .908 r
.61589 .52804 .62032 .53295 .62914 .5303 .62473 .52537 Metetra
.664 .741 .908 r
.62473 .52537 .62914 .5303 .63799 .52763 .6336 .52269 Metetra
.664 .741 .908 r
.6336 .52269 .63799 .52763 .64687 .52496 .6425 .52 Metetra
.664 .741 .908 r
.6425 .52 .64687 .52496 .65578 .52227 .65143 .5173 Metetra
.664 .741 .908 r
.65143 .5173 .65578 .52227 .66471 .51958 .66038 .51459 Metetra
.664 .741 .908 r
.66038 .51459 .66471 .51958 .67368 .51689 .66937 .51188 Metetra
.664 .741 .908 r
.66937 .51188 .67368 .51689 .68267 .51418 .67838 .50916 Metetra
.664 .741 .908 r
.67838 .50916 .68267 .51418 .69169 .51146 .68742 .50642 Metetra
.664 .741 .908 r
.68742 .50642 .69169 .51146 .70074 .50874 .69649 .50368 Metetra
.664 .741 .908 r
.69649 .50368 .70074 .50874 .70982 .506 .70559 .50093 Metetra
.664 .741 .908 r
.70559 .50093 .70982 .506 .71893 .50326 .71472 .49817 Metetra
.664 .741 .908 r
.71472 .49817 .71893 .50326 .72807 .50051 .72387 .49541 Metetra
.664 .741 .908 r
.72387 .49541 .72807 .50051 .73723 .49775 .73306 .49263 Metetra
.664 .741 .908 r
.73306 .49263 .73723 .49775 .74643 .49498 .74228 .48984 Metetra
.664 .741 .908 r
.74228 .48984 .74643 .49498 .75565 .4922 .75152 .48705 Metetra
.664 .741 .908 r
.75152 .48705 .75565 .4922 .76491 .48941 .7608 .48425 Metetra
.664 .741 .908 r
.7608 .48425 .76491 .48941 .77419 .48662 .77011 .48143 Metetra
.664 .741 .908 r
.77011 .48143 .77419 .48662 .78351 .48381 .77944 .47861 Metetra
.664 .741 .908 r
.77944 .47861 .78351 .48381 .79286 .481 .78881 .47578 Metetra
.664 .741 .908 r
.78881 .47578 .79286 .481 .80223 .47818 .79821 .47294 Metetra
.664 .741 .908 r
.79821 .47294 .80223 .47818 .81164 .47534 .80764 .47009 Metetra
.664 .741 .908 r
.80764 .47009 .81164 .47534 .82108 .4725 .8171 .46723 Metetra
.664 .741 .908 r
.8171 .46723 .82108 .4725 .83054 .46965 .82659 .46436 Metetra
.664 .741 .908 r
.82659 .46436 .83054 .46965 .84004 .46679 .83611 .46149 Metetra
.664 .741 .908 r
.83611 .46149 .84004 .46679 .84957 .46392 .84566 .4586 Metetra
.664 .741 .908 r
.84566 .4586 .84957 .46392 .85914 .46104 .85525 .4557 Metetra
.664 .741 .908 r
.85525 .4557 .85914 .46104 .86873 .45815 .86486 .4528 Metetra
.664 .741 .908 r
.86486 .4528 .86873 .45815 .87835 .45526 .87451 .44988 Metetra
.664 .741 .908 r
.87451 .44988 .87835 .45526 .88801 .45235 .88419 .44695 Metetra
.664 .741 .908 r
.88419 .44695 .88801 .45235 .8977 .44943 .8939 .44402 Metetra
.664 .741 .908 r
.8939 .44402 .8977 .44943 .90742 .4465 .90365 .44107 Metetra
.664 .741 .908 r
.90365 .44107 .90742 .4465 .91717 .44357 .91342 .43812 Metetra
.664 .741 .908 r
.91342 .43812 .91717 .44357 .92696 .44062 .92323 .43516 Metetra
.664 .741 .908 r
.92323 .43516 .92696 .44062 .93677 .43766 .93307 .43218 Metetra
.664 .741 .908 r
.93307 .43218 .93677 .43766 .94663 .4347 .94295 .4292 Metetra
.664 .741 .908 r
.94295 .4292 .94663 .4347 .95651 .43172 .95286 .4262 Metetra
.664 .741 .908 r
.95286 .4262 .95651 .43172 .96642 .42874 .9628 .4232 Metetra
.664 .741 .908 r
.39052 .59012 .39541 .59467 .40357 .59221 .39869 .58764 Metetra
.664 .741 .908 r
.39869 .58764 .40357 .59221 .41175 .58974 .40689 .58515 Metetra
.664 .741 .908 r
.40689 .58515 .41175 .58974 .41996 .58726 .41511 .58266 Metetra
.664 .741 .908 r
.41511 .58266 .41996 .58726 .4282 .58477 .42336 .58015 Metetra
.664 .741 .908 r
.42336 .58015 .4282 .58477 .43645 .58227 .43164 .57764 Metetra
.664 .741 .908 r
.43164 .57764 .43645 .58227 .44474 .57977 .43994 .57513 Metetra
.664 .741 .908 r
.43994 .57513 .44474 .57977 .45304 .57726 .44826 .5726 Metetra
.664 .741 .908 r
.44826 .5726 .45304 .57726 .46138 .57474 .45661 .57007 Metetra
.664 .741 .908 r
.45661 .57007 .46138 .57474 .46974 .57221 .46499 .56753 Metetra
.664 .741 .908 r
.46499 .56753 .46974 .57221 .47812 .56968 .47339 .56498 Metetra
.664 .741 .908 r
.47339 .56498 .47812 .56968 .48653 .56714 .48182 .56242 Metetra
.664 .741 .908 r
.48182 .56242 .48653 .56714 .49497 .56459 .49027 .55986 Metetra
.664 .741 .908 r
.49027 .55986 .49497 .56459 .50344 .56203 .49875 .55728 Metetra
.664 .741 .908 r
.49875 .55728 .50344 .56203 .51193 .55946 .50726 .5547 Metetra
.664 .741 .908 r
.50726 .5547 .51193 .55946 .52044 .55689 .51579 .55212 Metetra
.664 .741 .908 r
.51579 .55212 .52044 .55689 .52898 .55431 .52435 .54952 Metetra
.664 .741 .908 r
.52435 .54952 .52898 .55431 .53755 .55172 .53294 .54691 Metetra
.664 .741 .908 r
.53294 .54691 .53755 .55172 .54615 .54912 .54155 .5443 Metetra
.664 .741 .908 r
.54155 .5443 .54615 .54912 .55477 .54651 .55019 .54168 Metetra
.664 .741 .908 r
.55019 .54168 .55477 .54651 .56342 .5439 .55886 .53905 Metetra
.664 .741 .908 r
.55886 .53905 .56342 .5439 .5721 .54128 .56755 .53641 Metetra
.664 .741 .908 r
.56755 .53641 .5721 .54128 .5808 .53865 .57628 .53377 Metetra
.664 .741 .908 r
.57628 .53377 .5808 .53865 .58953 .53601 .58502 .53111 Metetra
.664 .741 .908 r
.58502 .53111 .58953 .53601 .59829 .53336 .5938 .52845 Metetra
.664 .741 .908 r
.5938 .52845 .59829 .53336 .60708 .5307 .60261 .52578 Metetra
.664 .741 .908 r
.60261 .52578 .60708 .5307 .61589 .52804 .61144 .5231 Metetra
.664 .741 .908 r
.61144 .5231 .61589 .52804 .62473 .52537 .6203 .52041 Metetra
.664 .741 .908 r
.6203 .52041 .62473 .52537 .6336 .52269 .62919 .51772 Metetra
.664 .741 .908 r
.62919 .51772 .6336 .52269 .6425 .52 .63811 .51501 Metetra
.664 .741 .908 r
.63811 .51501 .6425 .52 .65143 .5173 .64705 .5123 Metetra
.664 .741 .908 r
.64705 .5123 .65143 .5173 .66038 .51459 .65603 .50958 Metetra
.664 .741 .908 r
.65603 .50958 .66038 .51459 .66937 .51188 .66503 .50684 Metetra
.664 .741 .908 r
.66503 .50684 .66937 .51188 .67838 .50916 .67406 .5041 Metetra
.664 .741 .908 r
.67406 .5041 .67838 .50916 .68742 .50642 .68312 .50136 Metetra
.664 .741 .908 r
.68312 .50136 .68742 .50642 .69649 .50368 .69221 .4986 Metetra
.664 .741 .908 r
.69221 .4986 .69649 .50368 .70559 .50093 .70133 .49583 Metetra
.664 .741 .908 r
.70133 .49583 .70559 .50093 .71472 .49817 .71048 .49306 Metetra
.664 .741 .908 r
.71048 .49306 .71472 .49817 .72387 .49541 .71966 .49027 Metetra
.664 .741 .908 r
.71966 .49027 .72387 .49541 .73306 .49263 .72887 .48748 Metetra
.664 .741 .908 r
.72887 .48748 .73306 .49263 .74228 .48984 .7381 .48468 Metetra
.664 .741 .908 r
.7381 .48468 .74228 .48984 .75152 .48705 .74737 .48187 Metetra
.664 .741 .908 r
.74737 .48187 .75152 .48705 .7608 .48425 .75667 .47905 Metetra
.664 .741 .908 r
.75667 .47905 .7608 .48425 .77011 .48143 .766 .47622 Metetra
.664 .741 .908 r
.766 .47622 .77011 .48143 .77944 .47861 .77535 .47338 Metetra
.664 .741 .908 r
.77535 .47338 .77944 .47861 .78881 .47578 .78474 .47053 Metetra
.664 .741 .908 r
.78474 .47053 .78881 .47578 .79821 .47294 .79416 .46767 Metetra
.664 .741 .908 r
.79416 .46767 .79821 .47294 .80764 .47009 .80361 .46481 Metetra
.664 .741 .908 r
.80361 .46481 .80764 .47009 .8171 .46723 .81309 .46193 Metetra
.664 .741 .908 r
.81309 .46193 .8171 .46723 .82659 .46436 .82261 .45904 Metetra
.664 .741 .908 r
.82261 .45904 .82659 .46436 .83611 .46149 .83215 .45615 Metetra
.664 .741 .908 r
.83215 .45615 .83611 .46149 .84566 .4586 .84173 .45324 Metetra
.664 .741 .908 r
.84173 .45324 .84566 .4586 .85525 .4557 .85133 .45033 Metetra
.664 .741 .908 r
.85133 .45033 .85525 .4557 .86486 .4528 .86097 .44741 Metetra
.664 .741 .908 r
.86097 .44741 .86486 .4528 .87451 .44988 .87064 .44447 Metetra
.664 .741 .908 r
.87064 .44447 .87451 .44988 .88419 .44695 .88035 .44153 Metetra
.664 .741 .908 r
.88035 .44153 .88419 .44695 .8939 .44402 .89008 .43858 Metetra
.664 .741 .908 r
.89008 .43858 .8939 .44402 .90365 .44107 .89985 .43561 Metetra
.664 .741 .908 r
.89985 .43561 .90365 .44107 .91342 .43812 .90965 .43264 Metetra
.664 .741 .908 r
.90965 .43264 .91342 .43812 .92323 .43516 .91948 .42966 Metetra
.664 .741 .908 r
.91948 .42966 .92323 .43516 .93307 .43218 .92935 .42666 Metetra
.664 .741 .908 r
.92935 .42666 .93307 .43218 .94295 .4292 .93925 .42366 Metetra
.664 .741 .908 r
.93925 .42366 .94295 .4292 .95286 .4262 .94918 .42065 Metetra
.664 .741 .908 r
.94918 .42065 .95286 .4262 .9628 .4232 .95914 .41763 Metetra
.664 .741 .908 r
.3856 .58553 .39052 .59012 .39869 .58764 .39379 .58304 Metetra
.664 .741 .908 r
.39379 .58304 .39869 .58764 .40689 .58515 .402 .58054 Metetra
.664 .741 .908 r
.402 .58054 .40689 .58515 .41511 .58266 .41024 .57803 Metetra
.664 .741 .908 r
.41024 .57803 .41511 .58266 .42336 .58015 .4185 .57551 Metetra
.664 .741 .908 r
.4185 .57551 .42336 .58015 .43164 .57764 .42679 .57299 Metetra
.664 .741 .908 r
.42679 .57299 .43164 .57764 .43994 .57513 .43511 .57046 Metetra
.664 .741 .908 r
.43511 .57046 .43994 .57513 .44826 .5726 .44345 .56792 Metetra
.664 .741 .908 r
.44345 .56792 .44826 .5726 .45661 .57007 .45182 .56537 Metetra
.664 .741 .908 r
.45182 .56537 .45661 .57007 .46499 .56753 .46021 .56282 Metetra
.664 .741 .908 r
.46021 .56282 .46499 .56753 .47339 .56498 .46863 .56025 Metetra
.664 .741 .908 r
.46863 .56025 .47339 .56498 .48182 .56242 .47707 .55768 Metetra
.664 .741 .908 r
.47707 .55768 .48182 .56242 .49027 .55986 .48554 .5551 Metetra
.664 .741 .908 r
.48554 .5551 .49027 .55986 .49875 .55728 .49404 .55251 Metetra
.664 .741 .908 r
.49404 .55251 .49875 .55728 .50726 .5547 .50256 .54992 Metetra
.664 .741 .908 r
.50256 .54992 .50726 .5547 .51579 .55212 .51111 .54732 Metetra
.664 .741 .908 r
.51111 .54732 .51579 .55212 .52435 .54952 .51969 .5447 Metetra
.664 .741 .908 r
.51969 .5447 .52435 .54952 .53294 .54691 .5283 .54208 Metetra
.664 .741 .908 r
.5283 .54208 .53294 .54691 .54155 .5443 .53693 .53946 Metetra
.664 .741 .908 r
.53693 .53946 .54155 .5443 .55019 .54168 .54558 .53682 Metetra
.664 .741 .908 r
.54558 .53682 .55019 .54168 .55886 .53905 .55427 .53418 Metetra
.664 .741 .908 r
.55427 .53418 .55886 .53905 .56755 .53641 .56298 .53152 Metetra
.664 .741 .908 r
.56298 .53152 .56755 .53641 .57628 .53377 .57172 .52886 Metetra
.664 .741 .908 r
.57172 .52886 .57628 .53377 .58502 .53111 .58049 .52619 Metetra
.664 .741 .908 r
.58049 .52619 .58502 .53111 .5938 .52845 .58929 .52351 Metetra
.664 .741 .908 r
.58929 .52351 .5938 .52845 .60261 .52578 .59811 .52083 Metetra
.664 .741 .908 r
.59811 .52083 .60261 .52578 .61144 .5231 .60696 .51813 Metetra
.664 .741 .908 r
.60696 .51813 .61144 .5231 .6203 .52041 .61584 .51543 Metetra
.664 .741 .908 r
.61584 .51543 .6203 .52041 .62919 .51772 .62475 .51272 Metetra
.664 .741 .908 r
.62475 .51272 .62919 .51772 .63811 .51501 .63369 .51 Metetra
.664 .741 .908 r
.63369 .51 .63811 .51501 .64705 .5123 .64265 .50727 Metetra
.664 .741 .908 r
.64265 .50727 .64705 .5123 .65603 .50958 .65164 .50453 Metetra
.664 .741 .908 r
.65164 .50453 .65603 .50958 .66503 .50684 .66067 .50178 Metetra
.664 .741 .908 r
.66067 .50178 .66503 .50684 .67406 .5041 .66972 .49902 Metetra
.664 .741 .908 r
.66972 .49902 .67406 .5041 .68312 .50136 .6788 .49626 Metetra
.664 .741 .908 r
.6788 .49626 .68312 .50136 .69221 .4986 .68791 .49348 Metetra
.664 .741 .908 r
.68791 .49348 .69221 .4986 .70133 .49583 .69705 .4907 Metetra
.664 .741 .908 r
.69705 .4907 .70133 .49583 .71048 .49306 .70622 .48791 Metetra
.664 .741 .908 r
.70622 .48791 .71048 .49306 .71966 .49027 .71542 .48511 Metetra
.664 .741 .908 r
.71542 .48511 .71966 .49027 .72887 .48748 .72464 .4823 Metetra
.664 .741 .908 r
.72464 .4823 .72887 .48748 .7381 .48468 .7339 .47948 Metetra
.664 .741 .908 r
.7339 .47948 .7381 .48468 .74737 .48187 .74319 .47665 Metetra
.664 .741 .908 r
.74319 .47665 .74737 .48187 .75667 .47905 .75251 .47382 Metetra
.664 .741 .908 r
.75251 .47382 .75667 .47905 .766 .47622 .76186 .47097 Metetra
.664 .741 .908 r
.76186 .47097 .766 .47622 .77535 .47338 .77124 .46811 Metetra
.664 .741 .908 r
.77124 .46811 .77535 .47338 .78474 .47053 .78065 .46525 Metetra
.664 .741 .908 r
.78065 .46525 .78474 .47053 .79416 .46767 .79009 .46237 Metetra
.664 .741 .908 r
.79009 .46237 .79416 .46767 .80361 .46481 .79956 .45949 Metetra
.664 .741 .908 r
.79956 .45949 .80361 .46481 .81309 .46193 .80907 .45659 Metetra
.664 .741 .908 r
.80907 .45659 .81309 .46193 .82261 .45904 .8186 .45369 Metetra
.664 .741 .908 r
.8186 .45369 .82261 .45904 .83215 .45615 .82817 .45078 Metetra
.664 .741 .908 r
.82817 .45078 .83215 .45615 .84173 .45324 .83777 .44786 Metetra
.664 .741 .908 r
.83777 .44786 .84173 .45324 .85133 .45033 .8474 .44492 Metetra
.664 .741 .908 r
.8474 .44492 .85133 .45033 .86097 .44741 .85706 .44198 Metetra
.664 .741 .908 r
.85706 .44198 .86097 .44741 .87064 .44447 .86675 .43903 Metetra
.664 .741 .908 r
.86675 .43903 .87064 .44447 .88035 .44153 .87648 .43607 Metetra
.664 .741 .908 r
.87648 .43607 .88035 .44153 .89008 .43858 .88624 .4331 Metetra
.664 .741 .908 r
.88624 .4331 .89008 .43858 .89985 .43561 .89603 .43012 Metetra
.664 .741 .908 r
.89603 .43012 .89985 .43561 .90965 .43264 .90585 .42713 Metetra
.664 .741 .908 r
.90585 .42713 .90965 .43264 .91948 .42966 .91571 .42412 Metetra
.664 .741 .908 r
.91571 .42412 .91948 .42966 .92935 .42666 .9256 .42111 Metetra
.664 .741 .908 r
.9256 .42111 .92935 .42666 .93925 .42366 .93552 .41809 Metetra
.664 .741 .908 r
.93552 .41809 .93925 .42366 .94918 .42065 .94548 .41506 Metetra
.664 .741 .908 r
.94548 .41506 .94918 .42065 .95914 .41763 .95547 .41202 Metetra
.664 .741 .908 r
.38065 .58092 .3856 .58553 .39379 .58304 .38885 .57842 Metetra
.664 .741 .908 r
.38885 .57842 .39379 .58304 .402 .58054 .39708 .5759 Metetra
.664 .741 .908 r
.39708 .5759 .402 .58054 .41024 .57803 .40534 .57338 Metetra
.664 .741 .908 r
.40534 .57338 .41024 .57803 .4185 .57551 .41362 .57085 Metetra
.664 .741 .908 r
.41362 .57085 .4185 .57551 .42679 .57299 .42192 .56831 Metetra
.664 .741 .908 r
.42192 .56831 .42679 .57299 .43511 .57046 .43025 .56576 Metetra
.664 .741 .908 r
.43025 .56576 .43511 .57046 .44345 .56792 .43861 .56321 Metetra
.664 .741 .908 r
.43861 .56321 .44345 .56792 .45182 .56537 .44699 .56065 Metetra
.664 .741 .908 r
.44699 .56065 .45182 .56537 .46021 .56282 .4554 .55808 Metetra
.664 .741 .908 r
.4554 .55808 .46021 .56282 .46863 .56025 .46384 .5555 Metetra
.664 .741 .908 r
.46384 .5555 .46863 .56025 .47707 .55768 .4723 .55291 Metetra
.664 .741 .908 r
.4723 .55291 .47707 .55768 .48554 .5551 .48079 .55032 Metetra
.664 .741 .908 r
.48079 .55032 .48554 .5551 .49404 .55251 .4893 .54772 Metetra
.664 .741 .908 r
.4893 .54772 .49404 .55251 .50256 .54992 .49784 .54511 Metetra
.664 .741 .908 r
.49784 .54511 .50256 .54992 .51111 .54732 .50641 .54249 Metetra
.664 .741 .908 r
.50641 .54249 .51111 .54732 .51969 .5447 .51501 .53986 Metetra
.664 .741 .908 r
.51501 .53986 .51969 .5447 .5283 .54208 .52363 .53723 Metetra
.664 .741 .908 r
.52363 .53723 .5283 .54208 .53693 .53946 .53228 .53458 Metetra
.664 .741 .908 r
.53228 .53458 .53693 .53946 .54558 .53682 .54095 .53193 Metetra
.664 .741 .908 r
.54095 .53193 .54558 .53682 .55427 .53418 .54966 .52927 Metetra
.664 .741 .908 r
.54966 .52927 .55427 .53418 .56298 .53152 .55839 .5266 Metetra
.664 .741 .908 r
.55839 .5266 .56298 .53152 .57172 .52886 .56714 .52393 Metetra
.664 .741 .908 r
.56714 .52393 .57172 .52886 .58049 .52619 .57593 .52124 Metetra
.664 .741 .908 r
.57593 .52124 .58049 .52619 .58929 .52351 .58475 .51855 Metetra
.664 .741 .908 r
.58475 .51855 .58929 .52351 .59811 .52083 .59359 .51584 Metetra
.664 .741 .908 r
.59359 .51584 .59811 .52083 .60696 .51813 .60246 .51313 Metetra
.664 .741 .908 r
.60246 .51313 .60696 .51813 .61584 .51543 .61136 .51041 Metetra
.664 .741 .908 r
.61136 .51041 .61584 .51543 .62475 .51272 .62028 .50769 Metetra
.664 .741 .908 r
.62028 .50769 .62475 .51272 .63369 .51 .62924 .50495 Metetra
.664 .741 .908 r
.62924 .50495 .63369 .51 .64265 .50727 .63822 .5022 Metetra
.664 .741 .908 r
.63822 .5022 .64265 .50727 .65164 .50453 .64724 .49945 Metetra
.664 .741 .908 r
.64724 .49945 .65164 .50453 .66067 .50178 .65628 .49668 Metetra
.664 .741 .908 r
.65628 .49668 .66067 .50178 .66972 .49902 .66535 .49391 Metetra
.664 .741 .908 r
.66535 .49391 .66972 .49902 .6788 .49626 .67445 .49113 Metetra
.664 .741 .908 r
.67445 .49113 .6788 .49626 .68791 .49348 .68358 .48834 Metetra
.664 .741 .908 r
.68358 .48834 .68791 .49348 .69705 .4907 .69274 .48554 Metetra
.664 .741 .908 r
.69274 .48554 .69705 .4907 .70622 .48791 .70193 .48273 Metetra
.664 .741 .908 r
.70193 .48273 .70622 .48791 .71542 .48511 .71115 .47992 Metetra
.664 .741 .908 r
.71115 .47992 .71542 .48511 .72464 .4823 .7204 .47709 Metetra
.664 .741 .908 r
.7204 .47709 .72464 .4823 .7339 .47948 .72968 .47425 Metetra
.664 .741 .908 r
.72968 .47425 .7339 .47948 .74319 .47665 .73899 .47141 Metetra
.664 .741 .908 r
.73899 .47141 .74319 .47665 .75251 .47382 .74833 .46855 Metetra
.664 .741 .908 r
.74833 .46855 .75251 .47382 .76186 .47097 .7577 .46569 Metetra
.664 .741 .908 r
.7577 .46569 .76186 .47097 .77124 .46811 .7671 .46282 Metetra
.664 .741 .908 r
.7671 .46282 .77124 .46811 .78065 .46525 .77653 .45993 Metetra
.664 .741 .908 r
.77653 .45993 .78065 .46525 .79009 .46237 .786 .45704 Metetra
.664 .741 .908 r
.786 .45704 .79009 .46237 .79956 .45949 .79549 .45414 Metetra
.664 .741 .908 r
.79549 .45414 .79956 .45949 .80907 .45659 .80502 .45123 Metetra
.664 .741 .908 r
.80502 .45123 .80907 .45659 .8186 .45369 .81457 .44831 Metetra
.664 .741 .908 r
.81457 .44831 .8186 .45369 .82817 .45078 .82416 .44538 Metetra
.664 .741 .908 r
.82416 .44538 .82817 .45078 .83777 .44786 .83378 .44244 Metetra
.664 .741 .908 r
.83378 .44244 .83777 .44786 .8474 .44492 .84344 .43949 Metetra
.664 .741 .908 r
.84344 .43949 .8474 .44492 .85706 .44198 .85312 .43653 Metetra
.664 .741 .908 r
.85312 .43653 .85706 .44198 .86675 .43903 .86284 .43356 Metetra
.664 .741 .908 r
.86284 .43356 .86675 .43903 .87648 .43607 .87259 .43058 Metetra
.664 .741 .908 r
.87259 .43058 .87648 .43607 .88624 .4331 .88237 .42759 Metetra
.664 .741 .908 r
.88237 .42759 .88624 .4331 .89603 .43012 .89218 .42459 Metetra
.664 .741 .908 r
.89218 .42459 .89603 .43012 .90585 .42713 .90203 .42158 Metetra
.664 .741 .908 r
.90203 .42158 .90585 .42713 .91571 .42412 .91191 .41856 Metetra
.664 .741 .908 r
.91191 .41856 .91571 .42412 .9256 .42111 .92183 .41553 Metetra
.664 .741 .908 r
.92183 .41553 .9256 .42111 .93552 .41809 .93178 .41249 Metetra
.664 .741 .908 r
.93178 .41249 .93552 .41809 .94548 .41506 .94176 .40944 Metetra
.664 .741 .908 r
.94176 .40944 .94548 .41506 .95547 .41202 .95177 .40637 Metetra
.664 .741 .908 r
.37567 .57629 .38065 .58092 .38885 .57842 .38389 .57377 Metetra
.664 .741 .908 r
.38389 .57377 .38885 .57842 .39708 .5759 .39213 .57124 Metetra
.664 .741 .908 r
.39213 .57124 .39708 .5759 .40534 .57338 .40041 .5687 Metetra
.664 .741 .908 r
.40041 .5687 .40534 .57338 .41362 .57085 .4087 .56616 Metetra
.664 .741 .908 r
.4087 .56616 .41362 .57085 .42192 .56831 .41702 .5636 Metetra
.664 .741 .908 r
.41702 .5636 .42192 .56831 .43025 .56576 .42537 .56104 Metetra
.664 .741 .908 r
.42537 .56104 .43025 .56576 .43861 .56321 .43374 .55847 Metetra
.664 .741 .908 r
.43374 .55847 .43861 .56321 .44699 .56065 .44214 .5559 Metetra
.664 .741 .908 r
.44214 .5559 .44699 .56065 .4554 .55808 .45057 .55331 Metetra
.664 .741 .908 r
.45057 .55331 .4554 .55808 .46384 .5555 .45902 .55072 Metetra
.664 .741 .908 r
.45902 .55072 .46384 .5555 .4723 .55291 .4675 .54812 Metetra
.664 .741 .908 r
.4675 .54812 .4723 .55291 .48079 .55032 .47601 .54551 Metetra
.664 .741 .908 r
.47601 .54551 .48079 .55032 .4893 .54772 .48454 .54289 Metetra
.664 .741 .908 r
.48454 .54289 .4893 .54772 .49784 .54511 .4931 .54027 Metetra
.664 .741 .908 r
.4931 .54027 .49784 .54511 .50641 .54249 .50168 .53763 Metetra
.664 .741 .908 r
.50168 .53763 .50641 .54249 .51501 .53986 .51029 .53499 Metetra
.664 .741 .908 r
.51029 .53499 .51501 .53986 .52363 .53723 .51893 .53234 Metetra
.664 .741 .908 r
.51893 .53234 .52363 .53723 .53228 .53458 .5276 .52968 Metetra
.664 .741 .908 r
.5276 .52968 .53228 .53458 .54095 .53193 .53629 .52701 Metetra
.664 .741 .908 r
.53629 .52701 .54095 .53193 .54966 .52927 .54501 .52434 Metetra
.664 .741 .908 r
.54501 .52434 .54966 .52927 .55839 .5266 .55376 .52165 Metetra
.664 .741 .908 r
.55376 .52165 .55839 .5266 .56714 .52393 .56254 .51896 Metetra
.664 .741 .908 r
.56254 .51896 .56714 .52393 .57593 .52124 .57134 .51626 Metetra
.664 .741 .908 r
.57134 .51626 .57593 .52124 .58475 .51855 .58018 .51355 Metetra
.664 .741 .908 r
.58018 .51355 .58475 .51855 .59359 .51584 .58904 .51083 Metetra
.664 .741 .908 r
.58904 .51083 .59359 .51584 .60246 .51313 .59793 .50811 Metetra
.664 .741 .908 r
.59793 .50811 .60246 .51313 .61136 .51041 .60684 .50537 Metetra
.664 .741 .908 r
.60684 .50537 .61136 .51041 .62028 .50769 .61579 .50263 Metetra
.664 .741 .908 r
.61579 .50263 .62028 .50769 .62924 .50495 .62477 .49987 Metetra
.664 .741 .908 r
.62477 .49987 .62924 .50495 .63822 .5022 .63377 .49711 Metetra
.664 .741 .908 r
.63377 .49711 .63822 .5022 .64724 .49945 .6428 .49434 Metetra
.664 .741 .908 r
.6428 .49434 .64724 .49945 .65628 .49668 .65187 .49156 Metetra
.664 .741 .908 r
.65187 .49156 .65628 .49668 .66535 .49391 .66096 .48877 Metetra
.664 .741 .908 r
.66096 .48877 .66535 .49391 .67445 .49113 .67008 .48597 Metetra
.664 .741 .908 r
.67008 .48597 .67445 .49113 .68358 .48834 .67923 .48317 Metetra
.664 .741 .908 r
.67923 .48317 .68358 .48834 .69274 .48554 .68841 .48035 Metetra
.664 .741 .908 r
.68841 .48035 .69274 .48554 .70193 .48273 .69762 .47752 Metetra
.664 .741 .908 r
.69762 .47752 .70193 .48273 .71115 .47992 .70686 .47469 Metetra
.664 .741 .908 r
.70686 .47469 .71115 .47992 .7204 .47709 .71613 .47185 Metetra
.664 .741 .908 r
.71613 .47185 .7204 .47709 .72968 .47425 .72543 .46899 Metetra
.664 .741 .908 r
.72543 .46899 .72968 .47425 .73899 .47141 .73476 .46613 Metetra
.664 .741 .908 r
.73476 .46613 .73899 .47141 .74833 .46855 .74412 .46326 Metetra
.664 .741 .908 r
.74412 .46326 .74833 .46855 .7577 .46569 .75351 .46038 Metetra
.664 .741 .908 r
.75351 .46038 .7577 .46569 .7671 .46282 .76294 .45749 Metetra
.664 .741 .908 r
.76294 .45749 .7671 .46282 .77653 .45993 .77239 .45459 Metetra
.664 .741 .908 r
.77239 .45459 .77653 .45993 .786 .45704 .78187 .45168 Metetra
.664 .741 .908 r
.78187 .45168 .786 .45704 .79549 .45414 .79139 .44876 Metetra
.664 .741 .908 r
.79139 .44876 .79549 .45414 .80502 .45123 .80094 .44583 Metetra
.664 .741 .908 r
.80094 .44583 .80502 .45123 .81457 .44831 .81052 .44289 Metetra
.664 .741 .908 r
.81052 .44289 .81457 .44831 .82416 .44538 .82013 .43994 Metetra
.664 .741 .908 r
.82013 .43994 .82416 .44538 .83378 .44244 .82977 .43698 Metetra
.664 .741 .908 r
.82977 .43698 .83378 .44244 .84344 .43949 .83945 .43401 Metetra
.664 .741 .908 r
.83945 .43401 .84344 .43949 .85312 .43653 .84916 .43103 Metetra
.664 .741 .908 r
.84916 .43103 .85312 .43653 .86284 .43356 .8589 .42805 Metetra
.664 .741 .908 r
.8589 .42805 .86284 .43356 .87259 .43058 .86867 .42505 Metetra
.664 .741 .908 r
.86867 .42505 .87259 .43058 .88237 .42759 .87848 .42204 Metetra
.664 .741 .908 r
.87848 .42204 .88237 .42759 .89218 .42459 .88832 .41902 Metetra
.664 .741 .908 r
.88832 .41902 .89218 .42459 .90203 .42158 .89819 .41599 Metetra
.664 .741 .908 r
.89819 .41599 .90203 .42158 .91191 .41856 .90809 .41295 Metetra
.664 .741 .908 r
.90809 .41295 .91191 .41856 .92183 .41553 .91803 .40991 Metetra
.664 .741 .908 r
.91803 .40991 .92183 .41553 .93178 .41249 .92801 .40685 Metetra
.664 .741 .908 r
.92801 .40685 .93178 .41249 .94176 .40944 .93801 .40378 Metetra
.664 .741 .908 r
.93801 .40378 .94176 .40944 .95177 .40637 .94805 .4007 Metetra
.664 .741 .908 r
.37066 .57163 .37567 .57629 .38389 .57377 .3789 .56909 Metetra
.664 .741 .908 r
.3789 .56909 .38389 .57377 .39213 .57124 .38716 .56655 Metetra
.664 .741 .908 r
.38716 .56655 .39213 .57124 .40041 .5687 .39545 .564 Metetra
.664 .741 .908 r
.39545 .564 .40041 .5687 .4087 .56616 .40376 .56144 Metetra
.664 .741 .908 r
.40376 .56144 .4087 .56616 .41702 .5636 .4121 .55887 Metetra
.664 .741 .908 r
.4121 .55887 .41702 .5636 .42537 .56104 .42046 .55629 Metetra
.664 .741 .908 r
.42046 .55629 .42537 .56104 .43374 .55847 .42885 .55371 Metetra
.664 .741 .908 r
.42885 .55371 .43374 .55847 .44214 .5559 .43727 .55112 Metetra
.664 .741 .908 r
.43727 .55112 .44214 .5559 .45057 .55331 .44571 .54852 Metetra
.664 .741 .908 r
.44571 .54852 .45057 .55331 .45902 .55072 .45418 .54591 Metetra
.664 .741 .908 r
.45418 .54591 .45902 .55072 .4675 .54812 .46267 .54329 Metetra
.664 .741 .908 r
.46267 .54329 .4675 .54812 .47601 .54551 .4712 .54067 Metetra
.664 .741 .908 r
.4712 .54067 .47601 .54551 .48454 .54289 .47974 .53804 Metetra
.664 .741 .908 r
.47974 .53804 .48454 .54289 .4931 .54027 .48832 .5354 Metetra
.664 .741 .908 r
.48832 .5354 .4931 .54027 .50168 .53763 .49692 .53275 Metetra
.664 .741 .908 r
.49692 .53275 .50168 .53763 .51029 .53499 .50555 .53009 Metetra
.664 .741 .908 r
.50555 .53009 .51029 .53499 .51893 .53234 .51421 .52743 Metetra
.664 .741 .908 r
.51421 .52743 .51893 .53234 .5276 .52968 .52289 .52475 Metetra
.664 .741 .908 r
.52289 .52475 .5276 .52968 .53629 .52701 .5316 .52207 Metetra
.664 .741 .908 r
.5316 .52207 .53629 .52701 .54501 .52434 .54034 .51938 Metetra
.664 .741 .908 r
.54034 .51938 .54501 .52434 .55376 .52165 .54911 .51668 Metetra
.664 .741 .908 r
.54911 .51668 .55376 .52165 .56254 .51896 .55791 .51397 Metetra
.664 .741 .908 r
.55791 .51397 .56254 .51896 .57134 .51626 .56673 .51125 Metetra
.664 .741 .908 r
.56673 .51125 .57134 .51626 .58018 .51355 .57558 .50853 Metetra
.664 .741 .908 r
.57558 .50853 .58018 .51355 .58904 .51083 .58446 .50579 Metetra
.664 .741 .908 r
.58446 .50579 .58904 .51083 .59793 .50811 .59337 .50305 Metetra
.664 .741 .908 r
.59337 .50305 .59793 .50811 .60684 .50537 .60231 .5003 Metetra
.664 .741 .908 r
.60231 .5003 .60684 .50537 .61579 .50263 .61127 .49754 Metetra
.664 .741 .908 r
.61127 .49754 .61579 .50263 .62477 .49987 .62027 .49477 Metetra
.664 .741 .908 r
.62027 .49477 .62477 .49987 .63377 .49711 .62929 .49199 Metetra
.664 .741 .908 r
.62929 .49199 .63377 .49711 .6428 .49434 .63834 .4892 Metetra
.664 .741 .908 r
.63834 .4892 .6428 .49434 .65187 .49156 .64742 .4864 Metetra
.664 .741 .908 r
.64742 .4864 .65187 .49156 .66096 .48877 .65654 .4836 Metetra
.664 .741 .908 r
.65654 .4836 .66096 .48877 .67008 .48597 .66568 .48078 Metetra
.664 .741 .908 r
.66568 .48078 .67008 .48597 .67923 .48317 .67485 .47796 Metetra
.664 .741 .908 r
.67485 .47796 .67923 .48317 .68841 .48035 .68405 .47513 Metetra
.664 .741 .908 r
.68405 .47513 .68841 .48035 .69762 .47752 .69328 .47228 Metetra
.664 .741 .908 r
.69328 .47228 .69762 .47752 .70686 .47469 .70254 .46943 Metetra
.664 .741 .908 r
.70254 .46943 .70686 .47469 .71613 .47185 .71183 .46657 Metetra
.664 .741 .908 r
.71183 .46657 .71613 .47185 .72543 .46899 .72115 .4637 Metetra
.664 .741 .908 r
.72115 .4637 .72543 .46899 .73476 .46613 .7305 .46082 Metetra
.664 .741 .908 r
.7305 .46082 .73476 .46613 .74412 .46326 .73989 .45793 Metetra
.664 .741 .908 r
.73989 .45793 .74412 .46326 .75351 .46038 .7493 .45503 Metetra
.664 .741 .908 r
.7493 .45503 .75351 .46038 .76294 .45749 .75874 .45212 Metetra
.664 .741 .908 r
.75874 .45212 .76294 .45749 .77239 .45459 .76822 .44921 Metetra
.664 .741 .908 r
.76822 .44921 .77239 .45459 .78187 .45168 .77773 .44628 Metetra
.664 .741 .908 r
.77773 .44628 .78187 .45168 .79139 .44876 .78727 .44334 Metetra
.664 .741 .908 r
.78727 .44334 .79139 .44876 .80094 .44583 .79684 .44039 Metetra
.664 .741 .908 r
.79684 .44039 .80094 .44583 .81052 .44289 .80644 .43744 Metetra
.664 .741 .908 r
.80644 .43744 .81052 .44289 .82013 .43994 .81607 .43447 Metetra
.664 .741 .908 r
.81607 .43447 .82013 .43994 .82977 .43698 .82574 .43149 Metetra
.664 .741 .908 r
.82574 .43149 .82977 .43698 .83945 .43401 .83544 .42851 Metetra
.664 .741 .908 r
.83544 .42851 .83945 .43401 .84916 .43103 .84517 .42551 Metetra
.664 .741 .908 r
.84517 .42551 .84916 .43103 .8589 .42805 .85494 .4225 Metetra
.664 .741 .908 r
.85494 .4225 .8589 .42805 .86867 .42505 .86473 .41949 Metetra
.664 .741 .908 r
.86473 .41949 .86867 .42505 .87848 .42204 .87456 .41646 Metetra
.664 .741 .908 r
.87456 .41646 .87848 .42204 .88832 .41902 .88443 .41342 Metetra
.664 .741 .908 r
.88443 .41342 .88832 .41902 .89819 .41599 .89432 .41038 Metetra
.664 .741 .908 r
.89432 .41038 .89819 .41599 .90809 .41295 .90425 .40732 Metetra
.664 .741 .908 r
.90425 .40732 .90809 .41295 .91803 .40991 .91422 .40425 Metetra
.664 .741 .908 r
.91422 .40425 .91803 .40991 .92801 .40685 .92421 .40117 Metetra
.664 .741 .908 r
.92421 .40117 .92801 .40685 .93801 .40378 .93424 .39808 Metetra
.664 .741 .908 r
.93424 .39808 .93801 .40378 .94805 .4007 .94431 .39498 Metetra
.664 .741 .908 r
.36563 .56694 .37066 .57163 .3789 .56909 .37388 .56439 Metetra
.664 .741 .908 r
.37388 .56439 .3789 .56909 .38716 .56655 .38216 .56183 Metetra
.664 .741 .908 r
.38216 .56183 .38716 .56655 .39545 .564 .39046 .55926 Metetra
.664 .741 .908 r
.39046 .55926 .39545 .564 .40376 .56144 .39879 .55669 Metetra
.664 .741 .908 r
.39879 .55669 .40376 .56144 .4121 .55887 .40714 .55411 Metetra
.664 .741 .908 r
.40714 .55411 .4121 .55887 .42046 .55629 .41552 .55152 Metetra
.664 .741 .908 r
.41552 .55152 .42046 .55629 .42885 .55371 .42393 .54892 Metetra
.664 .741 .908 r
.42393 .54892 .42885 .55371 .43727 .55112 .43236 .54631 Metetra
.664 .741 .908 r
.43236 .54631 .43727 .55112 .44571 .54852 .44082 .5437 Metetra
.664 .741 .908 r
.44082 .5437 .44571 .54852 .45418 .54591 .44931 .54107 Metetra
.664 .741 .908 r
.44931 .54107 .45418 .54591 .46267 .54329 .45782 .53844 Metetra
.664 .741 .908 r
.45782 .53844 .46267 .54329 .4712 .54067 .46636 .5358 Metetra
.664 .741 .908 r
.46636 .5358 .4712 .54067 .47974 .53804 .47492 .53316 Metetra
.664 .741 .908 r
.47492 .53316 .47974 .53804 .48832 .5354 .48352 .5305 Metetra
.664 .741 .908 r
.48352 .5305 .48832 .5354 .49692 .53275 .49214 .52784 Metetra
.664 .741 .908 r
.49214 .52784 .49692 .53275 .50555 .53009 .50078 .52516 Metetra
.664 .741 .908 r
.50078 .52516 .50555 .53009 .51421 .52743 .50946 .52248 Metetra
.664 .741 .908 r
.50946 .52248 .51421 .52743 .52289 .52475 .51816 .51979 Metetra
.664 .741 .908 r
.51816 .51979 .52289 .52475 .5316 .52207 .52689 .51709 Metetra
.664 .741 .908 r
.52689 .51709 .5316 .52207 .54034 .51938 .53565 .51439 Metetra
.664 .741 .908 r
.53565 .51439 .54034 .51938 .54911 .51668 .54443 .51167 Metetra
.664 .741 .908 r
.54443 .51167 .54911 .51668 .55791 .51397 .55325 .50895 Metetra
.664 .741 .908 r
.55325 .50895 .55791 .51397 .56673 .51125 .56209 .50621 Metetra
.664 .741 .908 r
.56209 .50621 .56673 .51125 .57558 .50853 .57096 .50347 Metetra
.664 .741 .908 r
.57096 .50347 .57558 .50853 .58446 .50579 .57986 .50072 Metetra
.664 .741 .908 r
.57986 .50072 .58446 .50579 .59337 .50305 .58878 .49796 Metetra
.664 .741 .908 r
.58878 .49796 .59337 .50305 .60231 .5003 .59774 .49519 Metetra
.664 .741 .908 r
.59774 .49519 .60231 .5003 .61127 .49754 .60673 .49242 Metetra
.664 .741 .908 r
.60673 .49242 .61127 .49754 .62027 .49477 .61574 .48963 Metetra
.664 .741 .908 r
.61574 .48963 .62027 .49477 .62929 .49199 .62478 .48683 Metetra
.664 .741 .908 r
.62478 .48683 .62929 .49199 .63834 .4892 .63386 .48403 Metetra
.664 .741 .908 r
.63386 .48403 .63834 .4892 .64742 .4864 .64296 .48122 Metetra
.664 .741 .908 r
.64296 .48122 .64742 .4864 .65654 .4836 .65209 .47839 Metetra
.664 .741 .908 r
.65209 .47839 .65654 .4836 .66568 .48078 .66125 .47556 Metetra
.664 .741 .908 r
.66125 .47556 .66568 .48078 .67485 .47796 .67044 .47272 Metetra
.664 .741 .908 r
.67044 .47272 .67485 .47796 .68405 .47513 .67966 .46987 Metetra
.664 .741 .908 r
.67966 .46987 .68405 .47513 .69328 .47228 .68891 .46701 Metetra
.664 .741 .908 r
.68891 .46701 .69328 .47228 .70254 .46943 .69819 .46414 Metetra
.664 .741 .908 r
.69819 .46414 .70254 .46943 .71183 .46657 .70751 .46126 Metetra
.664 .741 .908 r
.70751 .46126 .71183 .46657 .72115 .4637 .71685 .45838 Metetra
.664 .741 .908 r
.71685 .45838 .72115 .4637 .7305 .46082 .72622 .45548 Metetra
.664 .741 .908 r
.72622 .45548 .7305 .46082 .73989 .45793 .73563 .45257 Metetra
.664 .741 .908 r
.73563 .45257 .73989 .45793 .7493 .45503 .74506 .44966 Metetra
.664 .741 .908 r
.74506 .44966 .7493 .45503 .75874 .45212 .75453 .44673 Metetra
.664 .741 .908 r
.75453 .44673 .75874 .45212 .76822 .44921 .76403 .44379 Metetra
.664 .741 .908 r
.76403 .44379 .76822 .44921 .77773 .44628 .77356 .44085 Metetra
.664 .741 .908 r
.77356 .44085 .77773 .44628 .78727 .44334 .78312 .43789 Metetra
.664 .741 .908 r
.78312 .43789 .78727 .44334 .79684 .44039 .79271 .43493 Metetra
.664 .741 .908 r
.79271 .43493 .79684 .44039 .80644 .43744 .80234 .43195 Metetra
.664 .741 .908 r
.80234 .43195 .80644 .43744 .81607 .43447 .81199 .42897 Metetra
.664 .741 .908 r
.81199 .42897 .81607 .43447 .82574 .43149 .82168 .42597 Metetra
.664 .741 .908 r
.82168 .42597 .82574 .43149 .83544 .42851 .83141 .42297 Metetra
.664 .741 .908 r
.83141 .42297 .83544 .42851 .84517 .42551 .84116 .41995 Metetra
.664 .741 .908 r
.84116 .41995 .84517 .42551 .85494 .4225 .85095 .41693 Metetra
.664 .741 .908 r
.85095 .41693 .85494 .4225 .86473 .41949 .86077 .41389 Metetra
.664 .741 .908 r
.86077 .41389 .86473 .41949 .87456 .41646 .87062 .41084 Metetra
.664 .741 .908 r
.87062 .41084 .87456 .41646 .88443 .41342 .88051 .40779 Metetra
.664 .741 .908 r
.88051 .40779 .88443 .41342 .89432 .41038 .89043 .40472 Metetra
.664 .741 .908 r
.89043 .40472 .89432 .41038 .90425 .40732 .90038 .40165 Metetra
.664 .741 .908 r
.90038 .40165 .90425 .40732 .91422 .40425 .91037 .39856 Metetra
.664 .741 .908 r
.91037 .39856 .91422 .40425 .92421 .40117 .92039 .39546 Metetra
.664 .741 .908 r
.92039 .39546 .92421 .40117 .93424 .39808 .93045 .39235 Metetra
.664 .741 .908 r
.93045 .39235 .93424 .39808 .94431 .39498 .94054 .38923 Metetra
.664 .741 .908 r
.36056 .56222 .36563 .56694 .37388 .56439 .36883 .55966 Metetra
.664 .741 .908 r
.36883 .55966 .37388 .56439 .38216 .56183 .37712 .55709 Metetra
.664 .741 .908 r
.37712 .55709 .38216 .56183 .39046 .55926 .38544 .55451 Metetra
.664 .741 .908 r
.38544 .55451 .39046 .55926 .39879 .55669 .39379 .55192 Metetra
.664 .741 .908 r
.39379 .55192 .39879 .55669 .40714 .55411 .40216 .54932 Metetra
.664 .741 .908 r
.40216 .54932 .40714 .55411 .41552 .55152 .41055 .54671 Metetra
.664 .741 .908 r
.41055 .54671 .41552 .55152 .42393 .54892 .41898 .5441 Metetra
.664 .741 .908 r
.41898 .5441 .42393 .54892 .43236 .54631 .42743 .54148 Metetra
.664 .741 .908 r
.42743 .54148 .43236 .54631 .44082 .5437 .4359 .53885 Metetra
.664 .741 .908 r
.4359 .53885 .44082 .5437 .44931 .54107 .44441 .53621 Metetra
.664 .741 .908 r
.44441 .53621 .44931 .54107 .45782 .53844 .45293 .53356 Metetra
.664 .741 .908 r
.45293 .53356 .45782 .53844 .46636 .5358 .46149 .53091 Metetra
.664 .741 .908 r
.46149 .53091 .46636 .5358 .47492 .53316 .47007 .52825 Metetra
.664 .741 .908 r
.47007 .52825 .47492 .53316 .48352 .5305 .47868 .52557 Metetra
.664 .741 .908 r
.47868 .52557 .48352 .5305 .49214 .52784 .48732 .52289 Metetra
.664 .741 .908 r
.48732 .52289 .49214 .52784 .50078 .52516 .49599 .52021 Metetra
.664 .741 .908 r
.49599 .52021 .50078 .52516 .50946 .52248 .50468 .51751 Metetra
.664 .741 .908 r
.50468 .51751 .50946 .52248 .51816 .51979 .5134 .5148 Metetra
.664 .741 .908 r
.5134 .5148 .51816 .51979 .52689 .51709 .52215 .51209 Metetra
.664 .741 .908 r
.52215 .51209 .52689 .51709 .53565 .51439 .53092 .50937 Metetra
.664 .741 .908 r
.53092 .50937 .53565 .51439 .54443 .51167 .53973 .50663 Metetra
.664 .741 .908 r
.53973 .50663 .54443 .51167 .55325 .50895 .54856 .50389 Metetra
.664 .741 .908 r
.54856 .50389 .55325 .50895 .56209 .50621 .55742 .50114 Metetra
.664 .741 .908 r
.55742 .50114 .56209 .50621 .57096 .50347 .56631 .49839 Metetra
.664 .741 .908 r
.56631 .49839 .57096 .50347 .57986 .50072 .57523 .49562 Metetra
.664 .741 .908 r
.57523 .49562 .57986 .50072 .58878 .49796 .58417 .49284 Metetra
.664 .741 .908 r
.58417 .49284 .58878 .49796 .59774 .49519 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59774 .49519 .60673 .49242 .60215 .48726 Metetra
.664 .741 .908 r
.60215 .48726 .60673 .49242 .61574 .48963 .61119 .48446 Metetra
.664 .741 .908 r
.61119 .48446 .61574 .48963 .62478 .48683 .62025 .48165 Metetra
.664 .741 .908 r
.62025 .48165 .62478 .48683 .63386 .48403 .62934 .47883 Metetra
.664 .741 .908 r
.62934 .47883 .63386 .48403 .64296 .48122 .63846 .476 Metetra
.664 .741 .908 r
.63846 .476 .64296 .48122 .65209 .47839 .64761 .47316 Metetra
.664 .741 .908 r
.64761 .47316 .65209 .47839 .66125 .47556 .6568 .47031 Metetra
.664 .741 .908 r
.6568 .47031 .66125 .47556 .67044 .47272 .66601 .46745 Metetra
.664 .741 .908 r
.66601 .46745 .67044 .47272 .67966 .46987 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .67966 .46987 .68891 .46701 .68452 .46171 Metetra
.664 .741 .908 r
.68452 .46171 .68891 .46701 .69819 .46414 .69382 .45882 Metetra
.664 .741 .908 r
.69382 .45882 .69819 .46414 .70751 .46126 .70316 .45593 Metetra
.664 .741 .908 r
.70316 .45593 .70751 .46126 .71685 .45838 .71252 .45302 Metetra
.664 .741 .908 r
.71252 .45302 .71685 .45838 .72622 .45548 .72192 .4501 Metetra
.664 .741 .908 r
.72192 .4501 .72622 .45548 .73563 .45257 .73134 .44718 Metetra
.664 .741 .908 r
.73134 .44718 .73563 .45257 .74506 .44966 .7408 .44425 Metetra
.664 .741 .908 r
.7408 .44425 .74506 .44966 .75453 .44673 .75029 .4413 Metetra
.664 .741 .908 r
.75029 .4413 .75453 .44673 .76403 .44379 .75981 .43835 Metetra
.664 .741 .908 r
.75981 .43835 .76403 .44379 .77356 .44085 .76936 .43538 Metetra
.664 .741 .908 r
.76936 .43538 .77356 .44085 .78312 .43789 .77894 .43241 Metetra
.664 .741 .908 r
.77894 .43241 .78312 .43789 .79271 .43493 .78856 .42943 Metetra
.664 .741 .908 r
.78856 .42943 .79271 .43493 .80234 .43195 .79821 .42643 Metetra
.664 .741 .908 r
.79821 .42643 .80234 .43195 .81199 .42897 .80789 .42343 Metetra
.664 .741 .908 r
.80789 .42343 .81199 .42897 .82168 .42597 .8176 .42042 Metetra
.664 .741 .908 r
.8176 .42042 .82168 .42597 .83141 .42297 .82735 .41739 Metetra
.664 .741 .908 r
.82735 .41739 .83141 .42297 .84116 .41995 .83712 .41436 Metetra
.664 .741 .908 r
.83712 .41436 .84116 .41995 .85095 .41693 .84693 .41131 Metetra
.664 .741 .908 r
.84693 .41131 .85095 .41693 .86077 .41389 .85678 .40826 Metetra
.664 .741 .908 r
.85678 .40826 .86077 .41389 .87062 .41084 .86666 .40519 Metetra
.664 .741 .908 r
.86666 .40519 .87062 .41084 .88051 .40779 .87657 .40212 Metetra
.664 .741 .908 r
.87657 .40212 .88051 .40779 .89043 .40472 .88651 .39903 Metetra
.664 .741 .908 r
.88651 .39903 .89043 .40472 .90038 .40165 .89649 .39594 Metetra
.664 .741 .908 r
.89649 .39594 .90038 .40165 .91037 .39856 .90651 .39283 Metetra
.664 .741 .908 r
.90651 .39283 .91037 .39856 .92039 .39546 .91655 .38971 Metetra
.664 .741 .908 r
.91655 .38971 .92039 .39546 .93045 .39235 .92663 .38658 Metetra
.664 .741 .908 r
.92663 .38658 .93045 .39235 .94054 .38923 .93675 .38345 Metetra
.664 .741 .908 r
.35547 .55748 .36056 .56222 .36883 .55966 .36375 .5549 Metetra
.664 .741 .908 r
.36375 .5549 .36883 .55966 .37712 .55709 .37206 .55232 Metetra
.664 .741 .908 r
.37206 .55232 .37712 .55709 .38544 .55451 .3804 .54972 Metetra
.664 .741 .908 r
.3804 .54972 .38544 .55451 .39379 .55192 .38876 .54712 Metetra
.664 .741 .908 r
.38876 .54712 .39379 .55192 .40216 .54932 .39715 .5445 Metetra
.664 .741 .908 r
.39715 .5445 .40216 .54932 .41055 .54671 .40556 .54188 Metetra
.664 .741 .908 r
.40556 .54188 .41055 .54671 .41898 .5441 .414 .53925 Metetra
.664 .741 .908 r
.414 .53925 .41898 .5441 .42743 .54148 .42246 .53662 Metetra
.664 .741 .908 r
.42246 .53662 .42743 .54148 .4359 .53885 .43096 .53397 Metetra
.664 .741 .908 r
.43096 .53397 .4359 .53885 .44441 .53621 .43948 .53132 Metetra
.664 .741 .908 r
.43948 .53132 .44441 .53621 .45293 .53356 .44802 .52866 Metetra
.664 .741 .908 r
.44802 .52866 .45293 .53356 .46149 .53091 .4566 .52599 Metetra
.664 .741 .908 r
.4566 .52599 .46149 .53091 .47007 .52825 .4652 .52331 Metetra
.664 .741 .908 r
.4652 .52331 .47007 .52825 .47868 .52557 .47382 .52062 Metetra
.664 .741 .908 r
.47382 .52062 .47868 .52557 .48732 .52289 .48248 .51792 Metetra
.664 .741 .908 r
.48248 .51792 .48732 .52289 .49599 .52021 .49116 .51522 Metetra
.664 .741 .908 r
.49116 .51522 .49599 .52021 .50468 .51751 .49987 .51251 Metetra
.664 .741 .908 r
.49987 .51251 .50468 .51751 .5134 .5148 .50861 .50979 Metetra
.664 .741 .908 r
.50861 .50979 .5134 .5148 .52215 .51209 .51738 .50706 Metetra
.664 .741 .908 r
.51738 .50706 .52215 .51209 .53092 .50937 .52617 .50432 Metetra
.664 .741 .908 r
.52617 .50432 .53092 .50937 .53973 .50663 .53499 .50157 Metetra
.664 .741 .908 r
.53499 .50157 .53973 .50663 .54856 .50389 .54384 .49881 Metetra
.664 .741 .908 r
.54384 .49881 .54856 .50389 .55742 .50114 .55272 .49605 Metetra
.664 .741 .908 r
.55272 .49605 .55742 .50114 .56631 .49839 .56163 .49327 Metetra
.664 .741 .908 r
.56163 .49327 .56631 .49839 .57523 .49562 .57057 .49049 Metetra
.664 .741 .908 r
.57057 .49049 .57523 .49562 .58417 .49284 .57953 .4877 Metetra
.664 .741 .908 r
.57953 .4877 .58417 .49284 .59315 .49006 .58853 .48489 Metetra
.664 .741 .908 r
.58853 .48489 .59315 .49006 .60215 .48726 .59755 .48208 Metetra
.664 .741 .908 r
.59755 .48208 .60215 .48726 .61119 .48446 .60661 .47926 Metetra
.664 .741 .908 r
.60661 .47926 .61119 .48446 .62025 .48165 .61569 .47643 Metetra
.664 .741 .908 r
.61569 .47643 .62025 .48165 .62934 .47883 .6248 .4736 Metetra
.664 .741 .908 r
.6248 .4736 .62934 .47883 .63846 .476 .63394 .47075 Metetra
.664 .741 .908 r
.63394 .47075 .63846 .476 .64761 .47316 .64311 .46789 Metetra
.664 .741 .908 r
.64311 .46789 .64761 .47316 .6568 .47031 .65232 .46503 Metetra
.664 .741 .908 r
.65232 .46503 .6568 .47031 .66601 .46745 .66155 .46215 Metetra
.664 .741 .908 r
.66155 .46215 .66601 .46745 .67525 .46458 .67081 .45927 Metetra
.664 .741 .908 r
.67081 .45927 .67525 .46458 .68452 .46171 .6801 .45637 Metetra
.664 .741 .908 r
.6801 .45637 .68452 .46171 .69382 .45882 .68943 .45347 Metetra
.664 .741 .908 r
.68943 .45347 .69382 .45882 .70316 .45593 .69878 .45055 Metetra
.664 .741 .908 r
.69878 .45055 .70316 .45593 .71252 .45302 .70817 .44763 Metetra
.664 .741 .908 r
.70817 .44763 .71252 .45302 .72192 .4501 .71758 .4447 Metetra
.664 .741 .908 r
.71758 .4447 .72192 .4501 .73134 .44718 .72703 .44176 Metetra
.664 .741 .908 r
.72703 .44176 .73134 .44718 .7408 .44425 .73651 .4388 Metetra
.664 .741 .908 r
.73651 .4388 .7408 .44425 .75029 .4413 .74602 .43584 Metetra
.664 .741 .908 r
.74602 .43584 .75029 .4413 .75981 .43835 .75556 .43287 Metetra
.664 .741 .908 r
.75556 .43287 .75981 .43835 .76936 .43538 .76514 .42989 Metetra
.664 .741 .908 r
.76514 .42989 .76936 .43538 .77894 .43241 .77474 .42689 Metetra
.664 .741 .908 r
.77474 .42689 .77894 .43241 .78856 .42943 .78438 .42389 Metetra
.664 .741 .908 r
.78438 .42389 .78856 .42943 .79821 .42643 .79405 .42088 Metetra
.664 .741 .908 r
.79405 .42088 .79821 .42643 .80789 .42343 .80375 .41786 Metetra
.664 .741 .908 r
.80375 .41786 .80789 .42343 .8176 .42042 .81349 .41483 Metetra
.664 .741 .908 r
.81349 .41483 .8176 .42042 .82735 .41739 .82326 .41178 Metetra
.664 .741 .908 r
.82326 .41178 .82735 .41739 .83712 .41436 .83306 .40873 Metetra
.664 .741 .908 r
.83306 .40873 .83712 .41436 .84693 .41131 .8429 .40567 Metetra
.664 .741 .908 r
.8429 .40567 .84693 .41131 .85678 .40826 .85277 .40259 Metetra
.664 .741 .908 r
.85277 .40259 .85678 .40826 .86666 .40519 .86267 .39951 Metetra
.664 .741 .908 r
.86267 .39951 .86666 .40519 .87657 .40212 .8726 .39641 Metetra
.664 .741 .908 r
.8726 .39641 .87657 .40212 .88651 .39903 .88257 .39331 Metetra
.664 .741 .908 r
.88257 .39331 .88651 .39903 .89649 .39594 .89258 .39019 Metetra
.664 .741 .908 r
.89258 .39019 .89649 .39594 .90651 .39283 .90261 .38707 Metetra
.664 .741 .908 r
.90261 .38707 .90651 .39283 .91655 .38971 .91269 .38393 Metetra
.664 .741 .908 r
.91269 .38393 .91655 .38971 .92663 .38658 .92279 .38078 Metetra
.664 .741 .908 r
.92279 .38078 .92663 .38658 .93675 .38345 .93294 .37762 Metetra
.664 .741 .908 r
.35035 .55271 .35547 .55748 .36375 .5549 .35865 .55012 Metetra
.664 .741 .908 r
.35865 .55012 .36375 .5549 .37206 .55232 .36697 .54752 Metetra
.664 .741 .908 r
.36697 .54752 .37206 .55232 .3804 .54972 .37532 .54491 Metetra
.664 .741 .908 r
.37532 .54491 .3804 .54972 .38876 .54712 .3837 .54229 Metetra
.664 .741 .908 r
.3837 .54229 .38876 .54712 .39715 .5445 .3921 .53966 Metetra
.664 .741 .908 r
.3921 .53966 .39715 .5445 .40556 .54188 .40053 .53702 Metetra
.664 .741 .908 r
.40053 .53702 .40556 .54188 .414 .53925 .40899 .53438 Metetra
.664 .741 .908 r
.40899 .53438 .414 .53925 .42246 .53662 .41747 .53173 Metetra
.664 .741 .908 r
.41747 .53173 .42246 .53662 .43096 .53397 .42598 .52907 Metetra
.664 .741 .908 r
.42598 .52907 .43096 .53397 .43948 .53132 .43452 .5264 Metetra
.664 .741 .908 r
.43452 .5264 .43948 .53132 .44802 .52866 .44308 .52372 Metetra
.664 .741 .908 r
.44308 .52372 .44802 .52866 .4566 .52599 .45167 .52103 Metetra
.664 .741 .908 r
.45167 .52103 .4566 .52599 .4652 .52331 .46029 .51834 Metetra
.664 .741 .908 r
.46029 .51834 .4652 .52331 .47382 .52062 .46894 .51564 Metetra
.664 .741 .908 r
.46894 .51564 .47382 .52062 .48248 .51792 .47761 .51293 Metetra
.664 .741 .908 r
.47761 .51293 .48248 .51792 .49116 .51522 .48631 .5102 Metetra
.664 .741 .908 r
.48631 .5102 .49116 .51522 .49987 .51251 .49504 .50748 Metetra
.664 .741 .908 r
.49504 .50748 .49987 .51251 .50861 .50979 .50379 .50474 Metetra
.664 .741 .908 r
.50379 .50474 .50861 .50979 .51738 .50706 .51258 .50199 Metetra
.664 .741 .908 r
.51258 .50199 .51738 .50706 .52617 .50432 .52139 .49924 Metetra
.664 .741 .908 r
.52139 .49924 .52617 .50432 .53499 .50157 .53023 .49647 Metetra
.664 .741 .908 r
.53023 .49647 .53499 .50157 .54384 .49881 .5391 .4937 Metetra
.664 .741 .908 r
.5391 .4937 .54384 .49881 .55272 .49605 .548 .49092 Metetra
.664 .741 .908 r
.548 .49092 .55272 .49605 .56163 .49327 .55693 .48813 Metetra
.664 .741 .908 r
.55693 .48813 .56163 .49327 .57057 .49049 .56588 .48533 Metetra
.664 .741 .908 r
.56588 .48533 .57057 .49049 .57953 .4877 .57487 .48252 Metetra
.664 .741 .908 r
.57487 .48252 .57953 .4877 .58853 .48489 .58388 .4797 Metetra
.664 .741 .908 r
.58388 .4797 .58853 .48489 .59755 .48208 .59292 .47687 Metetra
.664 .741 .908 r
.59292 .47687 .59755 .48208 .60661 .47926 .602 .47403 Metetra
.664 .741 .908 r
.602 .47403 .60661 .47926 .61569 .47643 .6111 .47119 Metetra
.664 .741 .908 r
.6111 .47119 .61569 .47643 .6248 .4736 .62023 .46833 Metetra
.664 .741 .908 r
.62023 .46833 .6248 .4736 .63394 .47075 .62939 .46547 Metetra
.664 .741 .908 r
.62939 .46547 .63394 .47075 .64311 .46789 .63859 .46259 Metetra
.664 .741 .908 r
.63859 .46259 .64311 .46789 .65232 .46503 .64781 .45971 Metetra
.664 .741 .908 r
.64781 .45971 .65232 .46503 .66155 .46215 .65706 .45682 Metetra
.664 .741 .908 r
.65706 .45682 .66155 .46215 .67081 .45927 .66634 .45392 Metetra
.664 .741 .908 r
.66634 .45392 .67081 .45927 .6801 .45637 .67566 .451 Metetra
.664 .741 .908 r
.67566 .451 .6801 .45637 .68943 .45347 .685 .44808 Metetra
.664 .741 .908 r
.685 .44808 .68943 .45347 .69878 .45055 .69438 .44515 Metetra
.664 .741 .908 r
.69438 .44515 .69878 .45055 .70817 .44763 .70378 .44221 Metetra
.664 .741 .908 r
.70378 .44221 .70817 .44763 .71758 .4447 .71322 .43926 Metetra
.664 .741 .908 r
.71322 .43926 .71758 .4447 .72703 .44176 .72269 .4363 Metetra
.664 .741 .908 r
.72269 .4363 .72703 .44176 .73651 .4388 .73219 .43333 Metetra
.664 .741 .908 r
.73219 .43333 .73651 .4388 .74602 .43584 .74173 .43035 Metetra
.664 .741 .908 r
.74173 .43035 .74602 .43584 .75556 .43287 .75129 .42736 Metetra
.664 .741 .908 r
.75129 .42736 .75556 .43287 .76514 .42989 .76089 .42436 Metetra
.664 .741 .908 r
.76089 .42436 .76514 .42989 .77474 .42689 .77052 .42134 Metetra
.664 .741 .908 r
.77052 .42134 .77474 .42689 .78438 .42389 .78018 .41832 Metetra
.664 .741 .908 r
.78018 .41832 .78438 .42389 .79405 .42088 .78987 .41529 Metetra
.664 .741 .908 r
.78987 .41529 .79405 .42088 .80375 .41786 .7996 .41225 Metetra
.664 .741 .908 r
.7996 .41225 .80375 .41786 .81349 .41483 .80936 .4092 Metetra
.664 .741 .908 r
.80936 .4092 .81349 .41483 .82326 .41178 .81915 .40614 Metetra
.664 .741 .908 r
.81915 .40614 .82326 .41178 .83306 .40873 .82897 .40307 Metetra
.664 .741 .908 r
.82897 .40307 .83306 .40873 .8429 .40567 .83883 .39998 Metetra
.664 .741 .908 r
.83883 .39998 .8429 .40567 .85277 .40259 .84873 .39689 Metetra
.664 .741 .908 r
.84873 .39689 .85277 .40259 .86267 .39951 .85865 .39379 Metetra
.664 .741 .908 r
.85865 .39379 .86267 .39951 .8726 .39641 .86861 .39067 Metetra
.664 .741 .908 r
.86861 .39067 .8726 .39641 .88257 .39331 .87861 .38755 Metetra
.664 .741 .908 r
.87861 .38755 .88257 .39331 .89258 .39019 .88864 .38441 Metetra
.664 .741 .908 r
.88864 .38441 .89258 .39019 .90261 .38707 .8987 .38127 Metetra
.664 .741 .908 r
.8987 .38127 .90261 .38707 .91269 .38393 .9088 .37811 Metetra
.664 .741 .908 r
.9088 .37811 .91269 .38393 .92279 .38078 .91893 .37494 Metetra
.664 .741 .908 r
.91893 .37494 .92279 .38078 .93294 .37762 .9291 .37176 Metetra
.664 .741 .908 r
.3452 .54792 .35035 .55271 .35865 .55012 .35351 .54531 Metetra
.664 .741 .908 r
.35351 .54531 .35865 .55012 .36697 .54752 .36185 .54269 Metetra
.664 .741 .908 r
.36185 .54269 .36697 .54752 .37532 .54491 .37022 .54006 Metetra
.664 .741 .908 r
.37022 .54006 .37532 .54491 .3837 .54229 .37861 .53743 Metetra
.664 .741 .908 r
.37861 .53743 .3837 .54229 .3921 .53966 .38703 .53479 Metetra
.664 .741 .908 r
.38703 .53479 .3921 .53966 .40053 .53702 .39548 .53214 Metetra
.664 .741 .908 r
.39548 .53214 .40053 .53702 .40899 .53438 .40395 .52948 Metetra
.664 .741 .908 r
.40395 .52948 .40899 .53438 .41747 .53173 .41245 .52681 Metetra
.664 .741 .908 r
.41245 .52681 .41747 .53173 .42598 .52907 .42098 .52413 Metetra
.664 .741 .908 r
.42098 .52413 .42598 .52907 .43452 .5264 .42953 .52145 Metetra
.664 .741 .908 r
.42953 .52145 .43452 .5264 .44308 .52372 .43811 .51875 Metetra
.664 .741 .908 r
.43811 .51875 .44308 .52372 .45167 .52103 .44672 .51605 Metetra
.664 .741 .908 r
.44672 .51605 .45167 .52103 .46029 .51834 .45536 .51334 Metetra
.664 .741 .908 r
.45536 .51334 .46029 .51834 .46894 .51564 .46402 .51062 Metetra
.664 .741 .908 r
.46402 .51062 .46894 .51564 .47761 .51293 .47271 .5079 Metetra
.664 .741 .908 r
.47271 .5079 .47761 .51293 .48631 .5102 .48143 .50516 Metetra
.664 .741 .908 r
.48143 .50516 .48631 .5102 .49504 .50748 .49017 .50241 Metetra
.664 .741 .908 r
.49017 .50241 .49504 .50748 .50379 .50474 .49895 .49966 Metetra
.664 .741 .908 r
.49895 .49966 .50379 .50474 .51258 .50199 .50775 .4969 Metetra
.664 .741 .908 r
.50775 .4969 .51258 .50199 .52139 .49924 .51658 .49413 Metetra
.664 .741 .908 r
.51658 .49413 .52139 .49924 .53023 .49647 .52544 .49135 Metetra
.664 .741 .908 r
.52544 .49135 .53023 .49647 .5391 .4937 .53433 .48856 Metetra
.664 .741 .908 r
.53433 .48856 .5391 .4937 .548 .49092 .54325 .48576 Metetra
.664 .741 .908 r
.54325 .48576 .548 .49092 .55693 .48813 .55219 .48295 Metetra
.664 .741 .908 r
.55219 .48295 .55693 .48813 .56588 .48533 .56117 .48013 Metetra
.664 .741 .908 r
.56117 .48013 .56588 .48533 .57487 .48252 .57017 .47731 Metetra
.664 .741 .908 r
.57017 .47731 .57487 .48252 .58388 .4797 .5792 .47447 Metetra
.664 .741 .908 r
.5792 .47447 .58388 .4797 .59292 .47687 .58827 .47163 Metetra
.664 .741 .908 r
.58827 .47163 .59292 .47687 .602 .47403 .59736 .46877 Metetra
.664 .741 .908 r
.59736 .46877 .602 .47403 .6111 .47119 .60648 .46591 Metetra
.664 .741 .908 r
.60648 .46591 .6111 .47119 .62023 .46833 .61563 .46304 Metetra
.664 .741 .908 r
.61563 .46304 .62023 .46833 .62939 .46547 .62482 .46015 Metetra
.664 .741 .908 r
.62482 .46015 .62939 .46547 .63859 .46259 .63403 .45726 Metetra
.664 .741 .908 r
.63403 .45726 .63859 .46259 .64781 .45971 .64327 .45436 Metetra
.664 .741 .908 r
.64327 .45436 .64781 .45971 .65706 .45682 .65255 .45145 Metetra
.664 .741 .908 r
.65255 .45145 .65706 .45682 .66634 .45392 .66185 .44853 Metetra
.664 .741 .908 r
.66185 .44853 .66634 .45392 .67566 .451 .67118 .4456 Metetra
.664 .741 .908 r
.67118 .4456 .67566 .451 .685 .44808 .68055 .44266 Metetra
.664 .741 .908 r
.68055 .44266 .685 .44808 .69438 .44515 .68995 .43971 Metetra
.664 .741 .908 r
.68995 .43971 .69438 .44515 .70378 .44221 .69938 .43675 Metetra
.664 .741 .908 r
.69938 .43675 .70378 .44221 .71322 .43926 .70884 .43378 Metetra
.664 .741 .908 r
.70884 .43378 .71322 .43926 .72269 .4363 .71833 .43081 Metetra
.664 .741 .908 r
.71833 .43081 .72269 .4363 .73219 .43333 .72785 .42782 Metetra
.664 .741 .908 r
.72785 .42782 .73219 .43333 .74173 .43035 .7374 .42482 Metetra
.664 .741 .908 r
.7374 .42482 .74173 .43035 .75129 .42736 .74699 .42181 Metetra
.664 .741 .908 r
.74699 .42181 .75129 .42736 .76089 .42436 .75661 .41879 Metetra
.664 .741 .908 r
.75661 .41879 .76089 .42436 .77052 .42134 .76626 .41576 Metetra
.664 .741 .908 r
.76626 .41576 .77052 .42134 .78018 .41832 .77595 .41272 Metetra
.664 .741 .908 r
.77595 .41272 .78018 .41832 .78987 .41529 .78566 .40967 Metetra
.664 .741 .908 r
.78566 .40967 .78987 .41529 .7996 .41225 .79541 .40661 Metetra
.664 .741 .908 r
.79541 .40661 .7996 .41225 .80936 .4092 .8052 .40354 Metetra
.664 .741 .908 r
.8052 .40354 .80936 .4092 .81915 .40614 .81501 .40046 Metetra
.664 .741 .908 r
.81501 .40046 .81915 .40614 .82897 .40307 .82486 .39737 Metetra
.664 .741 .908 r
.82486 .39737 .82897 .40307 .83883 .39998 .83474 .39427 Metetra
.664 .741 .908 r
.83474 .39427 .83883 .39998 .84873 .39689 .84466 .39115 Metetra
.664 .741 .908 r
.84466 .39115 .84873 .39689 .85865 .39379 .85461 .38803 Metetra
.664 .741 .908 r
.85461 .38803 .85865 .39379 .86861 .39067 .8646 .3849 Metetra
.664 .741 .908 r
.8646 .3849 .86861 .39067 .87861 .38755 .87462 .38175 Metetra
.664 .741 .908 r
.87462 .38175 .87861 .38755 .88864 .38441 .88467 .3786 Metetra
.664 .741 .908 r
.88467 .3786 .88864 .38441 .8987 .38127 .89476 .37543 Metetra
.664 .741 .908 r
.89476 .37543 .8987 .38127 .9088 .37811 .90488 .37225 Metetra
.664 .741 .908 r
.90488 .37225 .9088 .37811 .91893 .37494 .91504 .36906 Metetra
.664 .741 .908 r
.91504 .36906 .91893 .37494 .9291 .37176 .92523 .36587 Metetra
.664 .741 .908 r
.34002 .54309 .3452 .54792 .35351 .54531 .34835 .54047 Metetra
.664 .741 .908 r
.34835 .54047 .35351 .54531 .36185 .54269 .3567 .53784 Metetra
.664 .741 .908 r
.3567 .53784 .36185 .54269 .37022 .54006 .36509 .53519 Metetra
.664 .741 .908 r
.36509 .53519 .37022 .54006 .37861 .53743 .3735 .53254 Metetra
.664 .741 .908 r
.3735 .53254 .37861 .53743 .38703 .53479 .38193 .52989 Metetra
.664 .741 .908 r
.38193 .52989 .38703 .53479 .39548 .53214 .3904 .52722 Metetra
.664 .741 .908 r
.3904 .52722 .39548 .53214 .40395 .52948 .39888 .52454 Metetra
.664 .741 .908 r
.39888 .52454 .40395 .52948 .41245 .52681 .4074 .52186 Metetra
.664 .741 .908 r
.4074 .52186 .41245 .52681 .42098 .52413 .41594 .51917 Metetra
.664 .741 .908 r
.41594 .51917 .42098 .52413 .42953 .52145 .42452 .51647 Metetra
.664 .741 .908 r
.42452 .51647 .42953 .52145 .43811 .51875 .43311 .51376 Metetra
.664 .741 .908 r
.43311 .51376 .43811 .51875 .44672 .51605 .44174 .51104 Metetra
.664 .741 .908 r
.44174 .51104 .44672 .51605 .45536 .51334 .45039 .50832 Metetra
.664 .741 .908 r
.45039 .50832 .45536 .51334 .46402 .51062 .45907 .50558 Metetra
.664 .741 .908 r
.45907 .50558 .46402 .51062 .47271 .5079 .46778 .50284 Metetra
.664 .741 .908 r
.46778 .50284 .47271 .5079 .48143 .50516 .47652 .50008 Metetra
.664 .741 .908 r
.47652 .50008 .48143 .50516 .49017 .50241 .48528 .49732 Metetra
.664 .741 .908 r
.48528 .49732 .49017 .50241 .49895 .49966 .49407 .49455 Metetra
.664 .741 .908 r
.49407 .49455 .49895 .49966 .50775 .4969 .50289 .49177 Metetra
.664 .741 .908 r
.50289 .49177 .50775 .4969 .51658 .49413 .51174 .48899 Metetra
.664 .741 .908 r
.51174 .48899 .51658 .49413 .52544 .49135 .52062 .48619 Metetra
.664 .741 .908 r
.52062 .48619 .52544 .49135 .53433 .48856 .52953 .48338 Metetra
.664 .741 .908 r
.52953 .48338 .53433 .48856 .54325 .48576 .53847 .48057 Metetra
.664 .741 .908 r
.53847 .48057 .54325 .48576 .55219 .48295 .54743 .47774 Metetra
.664 .741 .908 r
.54743 .47774 .55219 .48295 .56117 .48013 .55642 .47491 Metetra
.664 .741 .908 r
.55642 .47491 .56117 .48013 .57017 .47731 .56545 .47206 Metetra
.664 .741 .908 r
.56545 .47206 .57017 .47731 .5792 .47447 .5745 .46921 Metetra
.664 .741 .908 r
.5745 .46921 .5792 .47447 .58827 .47163 .58358 .46635 Metetra
.664 .741 .908 r
.58358 .46635 .58827 .47163 .59736 .46877 .5927 .46348 Metetra
.664 .741 .908 r
.5927 .46348 .59736 .46877 .60648 .46591 .60184 .4606 Metetra
.664 .741 .908 r
.60184 .4606 .60648 .46591 .61563 .46304 .61101 .45771 Metetra
.664 .741 .908 r
.61101 .45771 .61563 .46304 .62482 .46015 .62021 .45481 Metetra
.664 .741 .908 r
.62021 .45481 .62482 .46015 .63403 .45726 .62945 .4519 Metetra
.664 .741 .908 r
.62945 .4519 .63403 .45726 .64327 .45436 .63871 .44898 Metetra
.664 .741 .908 r
.63871 .44898 .64327 .45436 .65255 .45145 .648 .44605 Metetra
.664 .741 .908 r
.648 .44605 .65255 .45145 .66185 .44853 .65733 .44311 Metetra
.664 .741 .908 r
.65733 .44311 .66185 .44853 .67118 .4456 .66668 .44017 Metetra
.664 .741 .908 r
.66668 .44017 .67118 .4456 .68055 .44266 .67607 .43721 Metetra
.664 .741 .908 r
.67607 .43721 .68055 .44266 .68995 .43971 .68549 .43424 Metetra
.664 .741 .908 r
.68549 .43424 .68995 .43971 .69938 .43675 .69494 .43126 Metetra
.664 .741 .908 r
.69494 .43126 .69938 .43675 .70884 .43378 .70442 .42828 Metetra
.664 .741 .908 r
.70442 .42828 .70884 .43378 .71833 .43081 .71393 .42528 Metetra
.664 .741 .908 r
.71393 .42528 .71833 .43081 .72785 .42782 .72348 .42227 Metetra
.664 .741 .908 r
.72348 .42227 .72785 .42782 .7374 .42482 .73306 .41925 Metetra
.664 .741 .908 r
.73306 .41925 .7374 .42482 .74699 .42181 .74267 .41623 Metetra
.664 .741 .908 r
.74267 .41623 .74699 .42181 .75661 .41879 .75231 .41319 Metetra
.664 .741 .908 r
.75231 .41319 .75661 .41879 .76626 .41576 .76198 .41014 Metetra
.664 .741 .908 r
.76198 .41014 .76626 .41576 .77595 .41272 .77169 .40708 Metetra
.664 .741 .908 r
.77169 .40708 .77595 .41272 .78566 .40967 .78143 .40401 Metetra
.664 .741 .908 r
.78143 .40401 .78566 .40967 .79541 .40661 .7912 .40093 Metetra
.664 .741 .908 r
.7912 .40093 .79541 .40661 .8052 .40354 .80101 .39784 Metetra
.664 .741 .908 r
.80101 .39784 .8052 .40354 .81501 .40046 .81085 .39474 Metetra
.664 .741 .908 r
.81085 .39474 .81501 .40046 .82486 .39737 .82072 .39163 Metetra
.664 .741 .908 r
.82072 .39163 .82486 .39737 .83474 .39427 .83063 .38851 Metetra
.664 .741 .908 r
.83063 .38851 .83474 .39427 .84466 .39115 .84057 .38538 Metetra
.664 .741 .908 r
.84057 .38538 .84466 .39115 .85461 .38803 .85055 .38224 Metetra
.664 .741 .908 r
.85055 .38224 .85461 .38803 .8646 .3849 .86056 .37908 Metetra
.664 .741 .908 r
.86056 .37908 .8646 .3849 .87462 .38175 .8706 .37592 Metetra
.664 .741 .908 r
.8706 .37592 .87462 .38175 .88467 .3786 .88068 .37274 Metetra
.664 .741 .908 r
.88068 .37274 .88467 .3786 .89476 .37543 .89079 .36956 Metetra
.664 .741 .908 r
.89079 .36956 .89476 .37543 .90488 .37225 .90094 .36636 Metetra
.664 .741 .908 r
.90094 .36636 .90488 .37225 .91504 .36906 .91112 .36315 Metetra
.664 .741 .908 r
.91112 .36315 .91504 .36906 .92523 .36587 .92134 .35993 Metetra
.664 .741 .908 r
.3348 .53824 .34002 .54309 .34835 .54047 .34315 .5356 Metetra
.664 .741 .908 r
.34315 .5356 .34835 .54047 .3567 .53784 .35152 .53295 Metetra
.664 .741 .908 r
.35152 .53295 .3567 .53784 .36509 .53519 .35992 .5303 Metetra
.664 .741 .908 r
.35992 .5303 .36509 .53519 .3735 .53254 .36835 .52763 Metetra
.664 .741 .908 r
.36835 .52763 .3735 .53254 .38193 .52989 .3768 .52496 Metetra
.664 .741 .908 r
.3768 .52496 .38193 .52989 .3904 .52722 .38528 .52227 Metetra
.664 .741 .908 r
.38528 .52227 .3904 .52722 .39888 .52454 .39379 .51958 Metetra
.664 .741 .908 r
.39379 .51958 .39888 .52454 .4074 .52186 .40232 .51689 Metetra
.664 .741 .908 r
.40232 .51689 .4074 .52186 .41594 .51917 .41088 .51418 Metetra
.664 .741 .908 r
.41088 .51418 .41594 .51917 .42452 .51647 .41947 .51146 Metetra
.664 .741 .908 r
.41947 .51146 .42452 .51647 .43311 .51376 .42808 .50874 Metetra
.664 .741 .908 r
.42808 .50874 .43311 .51376 .44174 .51104 .43673 .506 Metetra
.664 .741 .908 r
.43673 .506 .44174 .51104 .45039 .50832 .4454 .50326 Metetra
.664 .741 .908 r
.4454 .50326 .45039 .50832 .45907 .50558 .4541 .50051 Metetra
.664 .741 .908 r
.4541 .50051 .45907 .50558 .46778 .50284 .46282 .49775 Metetra
.664 .741 .908 r
.46282 .49775 .46778 .50284 .47652 .50008 .47158 .49498 Metetra
.664 .741 .908 r
.47158 .49498 .47652 .50008 .48528 .49732 .48036 .4922 Metetra
.664 .741 .908 r
.48036 .4922 .48528 .49732 .49407 .49455 .48917 .48941 Metetra
.664 .741 .908 r
.48917 .48941 .49407 .49455 .50289 .49177 .49801 .48662 Metetra
.664 .741 .908 r
.49801 .48662 .50289 .49177 .51174 .48899 .50688 .48381 Metetra
.664 .741 .908 r
.50688 .48381 .51174 .48899 .52062 .48619 .51577 .481 Metetra
.664 .741 .908 r
.51577 .481 .52062 .48619 .52953 .48338 .5247 .47818 Metetra
.664 .741 .908 r
.5247 .47818 .52953 .48338 .53847 .48057 .53366 .47534 Metetra
.664 .741 .908 r
.53366 .47534 .53847 .48057 .54743 .47774 .54264 .4725 Metetra
.664 .741 .908 r
.54264 .4725 .54743 .47774 .55642 .47491 .55165 .46965 Metetra
.664 .741 .908 r
.55165 .46965 .55642 .47491 .56545 .47206 .5607 .46679 Metetra
.664 .741 .908 r
.5607 .46679 .56545 .47206 .5745 .46921 .56977 .46392 Metetra
.664 .741 .908 r
.56977 .46392 .5745 .46921 .58358 .46635 .57887 .46104 Metetra
.664 .741 .908 r
.57887 .46104 .58358 .46635 .5927 .46348 .588 .45815 Metetra
.664 .741 .908 r
.588 .45815 .5927 .46348 .60184 .4606 .59717 .45526 Metetra
.664 .741 .908 r
.59717 .45526 .60184 .4606 .61101 .45771 .60636 .45235 Metetra
.664 .741 .908 r
.60636 .45235 .61101 .45771 .62021 .45481 .61558 .44943 Metetra
.664 .741 .908 r
.61558 .44943 .62021 .45481 .62945 .4519 .62483 .4465 Metetra
.664 .741 .908 r
.62483 .4465 .62945 .4519 .63871 .44898 .63412 .44357 Metetra
.664 .741 .908 r
.63412 .44357 .63871 .44898 .648 .44605 .64343 .44062 Metetra
.664 .741 .908 r
.64343 .44062 .648 .44605 .65733 .44311 .65278 .43766 Metetra
.664 .741 .908 r
.65278 .43766 .65733 .44311 .66668 .44017 .66216 .4347 Metetra
.664 .741 .908 r
.66216 .4347 .66668 .44017 .67607 .43721 .67157 .43172 Metetra
.664 .741 .908 r
.67157 .43172 .67607 .43721 .68549 .43424 .68101 .42874 Metetra
.664 .741 .908 r
.68101 .42874 .68549 .43424 .69494 .43126 .69048 .42574 Metetra
.664 .741 .908 r
.69048 .42574 .69494 .43126 .70442 .42828 .69998 .42274 Metetra
.664 .741 .908 r
.69998 .42274 .70442 .42828 .71393 .42528 .70952 .41972 Metetra
.664 .741 .908 r
.70952 .41972 .71393 .42528 .72348 .42227 .71908 .41669 Metetra
.664 .741 .908 r
.71908 .41669 .72348 .42227 .73306 .41925 .72868 .41366 Metetra
.664 .741 .908 r
.72868 .41366 .73306 .41925 .74267 .41623 .73831 .41061 Metetra
.664 .741 .908 r
.73831 .41061 .74267 .41623 .75231 .41319 .74798 .40755 Metetra
.664 .741 .908 r
.74798 .40755 .75231 .41319 .76198 .41014 .75768 .40449 Metetra
.664 .741 .908 r
.75768 .40449 .76198 .41014 .77169 .40708 .76741 .40141 Metetra
.664 .741 .908 r
.76741 .40141 .77169 .40708 .78143 .40401 .77717 .39832 Metetra
.664 .741 .908 r
.77717 .39832 .78143 .40401 .7912 .40093 .78697 .39522 Metetra
.664 .741 .908 r
.78697 .39522 .7912 .40093 .80101 .39784 .7968 .39211 Metetra
.664 .741 .908 r
.7968 .39211 .80101 .39784 .81085 .39474 .80666 .38899 Metetra
.664 .741 .908 r
.80666 .38899 .81085 .39474 .82072 .39163 .81656 .38586 Metetra
.664 .741 .908 r
.81656 .38586 .82072 .39163 .83063 .38851 .82649 .38272 Metetra
.664 .741 .908 r
.82649 .38272 .83063 .38851 .84057 .38538 .83646 .37957 Metetra
.664 .741 .908 r
.83646 .37957 .84057 .38538 .85055 .38224 .84645 .37641 Metetra
.664 .741 .908 r
.84645 .37641 .85055 .38224 .86056 .37908 .85649 .37323 Metetra
.664 .741 .908 r
.85649 .37323 .86056 .37908 .8706 .37592 .86656 .37005 Metetra
.664 .741 .908 r
.86656 .37005 .8706 .37592 .88068 .37274 .87666 .36685 Metetra
.664 .741 .908 r
.87666 .36685 .88068 .37274 .89079 .36956 .8868 .36364 Metetra
.664 .741 .908 r
.8868 .36364 .89079 .36956 .90094 .36636 .89697 .36043 Metetra
.664 .741 .908 r
.89697 .36043 .90094 .36636 .91112 .36315 .90718 .3572 Metetra
.664 .741 .908 r
.90718 .3572 .91112 .36315 .92134 .35993 .91743 .35396 Metetra
.664 .741 .908 r
.32956 .53336 .3348 .53824 .34315 .5356 .33793 .5307 Metetra
.664 .741 .908 r
.33793 .5307 .34315 .5356 .35152 .53295 .34632 .52804 Metetra
.664 .741 .908 r
.34632 .52804 .35152 .53295 .35992 .5303 .35473 .52537 Metetra
.664 .741 .908 r
.35473 .52537 .35992 .5303 .36835 .52763 .36317 .52269 Metetra
.664 .741 .908 r
.36317 .52269 .36835 .52763 .3768 .52496 .37164 .52 Metetra
.664 .741 .908 r
.37164 .52 .3768 .52496 .38528 .52227 .38014 .5173 Metetra
.664 .741 .908 r
.38014 .5173 .38528 .52227 .39379 .51958 .38866 .51459 Metetra
.664 .741 .908 r
.38866 .51459 .39379 .51958 .40232 .51689 .39721 .51188 Metetra
.664 .741 .908 r
.39721 .51188 .40232 .51689 .41088 .51418 .40579 .50916 Metetra
.664 .741 .908 r
.40579 .50916 .41088 .51418 .41947 .51146 .41439 .50642 Metetra
.664 .741 .908 r
.41439 .50642 .41947 .51146 .42808 .50874 .42303 .50368 Metetra
.664 .741 .908 r
.42303 .50368 .42808 .50874 .43673 .506 .43169 .50093 Metetra
.664 .741 .908 r
.43169 .50093 .43673 .506 .4454 .50326 .44038 .49817 Metetra
.664 .741 .908 r
.44038 .49817 .4454 .50326 .4541 .50051 .44909 .49541 Metetra
.664 .741 .908 r
.44909 .49541 .4541 .50051 .46282 .49775 .45784 .49263 Metetra
.664 .741 .908 r
.45784 .49263 .46282 .49775 .47158 .49498 .46661 .48984 Metetra
.664 .741 .908 r
.46661 .48984 .47158 .49498 .48036 .4922 .47541 .48705 Metetra
.664 .741 .908 r
.47541 .48705 .48036 .4922 .48917 .48941 .48424 .48425 Metetra
.664 .741 .908 r
.48424 .48425 .48917 .48941 .49801 .48662 .4931 .48143 Metetra
.664 .741 .908 r
.4931 .48143 .49801 .48662 .50688 .48381 .50198 .47861 Metetra
.664 .741 .908 r
.50198 .47861 .50688 .48381 .51577 .481 .5109 .47578 Metetra
.664 .741 .908 r
.5109 .47578 .51577 .481 .5247 .47818 .51984 .47294 Metetra
.664 .741 .908 r
.51984 .47294 .5247 .47818 .53366 .47534 .52882 .47009 Metetra
.664 .741 .908 r
.52882 .47009 .53366 .47534 .54264 .4725 .53782 .46723 Metetra
.664 .741 .908 r
.53782 .46723 .54264 .4725 .55165 .46965 .54685 .46436 Metetra
.664 .741 .908 r
.54685 .46436 .55165 .46965 .5607 .46679 .55592 .46149 Metetra
.664 .741 .908 r
.55592 .46149 .5607 .46679 .56977 .46392 .56501 .4586 Metetra
.664 .741 .908 r
.56501 .4586 .56977 .46392 .57887 .46104 .57413 .4557 Metetra
.664 .741 .908 r
.57413 .4557 .57887 .46104 .588 .45815 .58328 .4528 Metetra
.664 .741 .908 r
.58328 .4528 .588 .45815 .59717 .45526 .59246 .44988 Metetra
.664 .741 .908 r
.59246 .44988 .59717 .45526 .60636 .45235 .60168 .44695 Metetra
.664 .741 .908 r
.60168 .44695 .60636 .45235 .61558 .44943 .61092 .44402 Metetra
.664 .741 .908 r
.61092 .44402 .61558 .44943 .62483 .4465 .62019 .44107 Metetra
.664 .741 .908 r
.62019 .44107 .62483 .4465 .63412 .44357 .6295 .43812 Metetra
.664 .741 .908 r
.6295 .43812 .63412 .44357 .64343 .44062 .63884 .43516 Metetra
.664 .741 .908 r
.63884 .43516 .64343 .44062 .65278 .43766 .6482 .43218 Metetra
.664 .741 .908 r
.6482 .43218 .65278 .43766 .66216 .4347 .6576 .4292 Metetra
.664 .741 .908 r
.6576 .4292 .66216 .4347 .67157 .43172 .66703 .4262 Metetra
.664 .741 .908 r
.66703 .4262 .67157 .43172 .68101 .42874 .67649 .4232 Metetra
.664 .741 .908 r
.67649 .4232 .68101 .42874 .69048 .42574 .68599 .42018 Metetra
.664 .741 .908 r
.68599 .42018 .69048 .42574 .69998 .42274 .69551 .41716 Metetra
.664 .741 .908 r
.69551 .41716 .69998 .42274 .70952 .41972 .70507 .41412 Metetra
.664 .741 .908 r
.70507 .41412 .70952 .41972 .71908 .41669 .71466 .41108 Metetra
.664 .741 .908 r
.71466 .41108 .71908 .41669 .72868 .41366 .72428 .40802 Metetra
.664 .741 .908 r
.72428 .40802 .72868 .41366 .73831 .41061 .73394 .40496 Metetra
.664 .741 .908 r
.73394 .40496 .73831 .41061 .74798 .40755 .74362 .40188 Metetra
.664 .741 .908 r
.74362 .40188 .74798 .40755 .75768 .40449 .75334 .3988 Metetra
.664 .741 .908 r
.75334 .3988 .75768 .40449 .76741 .40141 .7631 .3957 Metetra
.664 .741 .908 r
.7631 .3957 .76741 .40141 .77717 .39832 .77288 .39259 Metetra
.664 .741 .908 r
.77288 .39259 .77717 .39832 .78697 .39522 .7827 .38947 Metetra
.664 .741 .908 r
.7827 .38947 .78697 .39522 .7968 .39211 .79256 .38634 Metetra
.664 .741 .908 r
.79256 .38634 .7968 .39211 .80666 .38899 .80245 .3832 Metetra
.664 .741 .908 r
.80245 .3832 .80666 .38899 .81656 .38586 .81237 .38005 Metetra
.664 .741 .908 r
.81237 .38005 .81656 .38586 .82649 .38272 .82232 .37689 Metetra
.664 .741 .908 r
.82232 .37689 .82649 .38272 .83646 .37957 .83231 .37372 Metetra
.664 .741 .908 r
.83231 .37372 .83646 .37957 .84645 .37641 .84234 .37054 Metetra
.664 .741 .908 r
.84234 .37054 .84645 .37641 .85649 .37323 .8524 .36734 Metetra
.664 .741 .908 r
.8524 .36734 .85649 .37323 .86656 .37005 .86249 .36414 Metetra
.664 .741 .908 r
.86249 .36414 .86656 .37005 .87666 .36685 .87262 .36092 Metetra
.664 .741 .908 r
.87262 .36092 .87666 .36685 .8868 .36364 .88278 .35769 Metetra
.664 .741 .908 r
.88278 .35769 .8868 .36364 .89697 .36043 .89298 .35446 Metetra
.664 .741 .908 r
.89298 .35446 .89697 .36043 .90718 .3572 .90322 .35121 Metetra
.664 .741 .908 r
.90322 .35121 .90718 .3572 .91743 .35396 .91349 .34794 Metetra
.664 .741 .908 r
.32429 .52845 .32956 .53336 .33793 .5307 .33267 .52578 Metetra
.664 .741 .908 r
.33267 .52578 .33793 .5307 .34632 .52804 .34108 .5231 Metetra
.664 .741 .908 r
.34108 .5231 .34632 .52804 .35473 .52537 .34951 .52041 Metetra
.664 .741 .908 r
.34951 .52041 .35473 .52537 .36317 .52269 .35797 .51772 Metetra
.664 .741 .908 r
.35797 .51772 .36317 .52269 .37164 .52 .36645 .51501 Metetra
.664 .741 .908 r
.36645 .51501 .37164 .52 .38014 .5173 .37496 .5123 Metetra
.664 .741 .908 r
.37496 .5123 .38014 .5173 .38866 .51459 .3835 .50958 Metetra
.664 .741 .908 r
.3835 .50958 .38866 .51459 .39721 .51188 .39207 .50684 Metetra
.664 .741 .908 r
.39207 .50684 .39721 .51188 .40579 .50916 .40067 .5041 Metetra
.664 .741 .908 r
.40067 .5041 .40579 .50916 .41439 .50642 .40929 .50136 Metetra
.664 .741 .908 r
.40929 .50136 .41439 .50642 .42303 .50368 .41794 .4986 Metetra
.664 .741 .908 r
.41794 .4986 .42303 .50368 .43169 .50093 .42662 .49583 Metetra
.664 .741 .908 r
.42662 .49583 .43169 .50093 .44038 .49817 .43532 .49306 Metetra
.664 .741 .908 r
.43532 .49306 .44038 .49817 .44909 .49541 .44406 .49027 Metetra
.664 .741 .908 r
.44406 .49027 .44909 .49541 .45784 .49263 .45282 .48748 Metetra
.664 .741 .908 r
.45282 .48748 .45784 .49263 .46661 .48984 .46161 .48468 Metetra
.664 .741 .908 r
.46161 .48468 .46661 .48984 .47541 .48705 .47043 .48187 Metetra
.664 .741 .908 r
.47043 .48187 .47541 .48705 .48424 .48425 .47928 .47905 Metetra
.664 .741 .908 r
.47928 .47905 .48424 .48425 .4931 .48143 .48815 .47622 Metetra
.664 .741 .908 r
.48815 .47622 .4931 .48143 .50198 .47861 .49706 .47338 Metetra
.664 .741 .908 r
.49706 .47338 .50198 .47861 .5109 .47578 .50599 .47053 Metetra
.664 .741 .908 r
.50599 .47053 .5109 .47578 .51984 .47294 .51496 .46767 Metetra
.664 .741 .908 r
.51496 .46767 .51984 .47294 .52882 .47009 .52395 .46481 Metetra
.664 .741 .908 r
.52395 .46481 .52882 .47009 .53782 .46723 .53297 .46193 Metetra
.664 .741 .908 r
.53297 .46193 .53782 .46723 .54685 .46436 .54202 .45904 Metetra
.664 .741 .908 r
.54202 .45904 .54685 .46436 .55592 .46149 .55111 .45615 Metetra
.664 .741 .908 r
.55111 .45615 .55592 .46149 .56501 .4586 .56022 .45324 Metetra
.664 .741 .908 r
.56022 .45324 .56501 .4586 .57413 .4557 .56936 .45033 Metetra
.664 .741 .908 r
.56936 .45033 .57413 .4557 .58328 .4528 .57853 .44741 Metetra
.664 .741 .908 r
.57853 .44741 .58328 .4528 .59246 .44988 .58773 .44447 Metetra
.664 .741 .908 r
.58773 .44447 .59246 .44988 .60168 .44695 .59697 .44153 Metetra
.664 .741 .908 r
.59697 .44153 .60168 .44695 .61092 .44402 .60623 .43858 Metetra
.664 .741 .908 r
.60623 .43858 .61092 .44402 .62019 .44107 .61553 .43561 Metetra
.664 .741 .908 r
.61553 .43561 .62019 .44107 .6295 .43812 .62485 .43264 Metetra
.664 .741 .908 r
.62485 .43264 .6295 .43812 .63884 .43516 .63421 .42966 Metetra
.664 .741 .908 r
.63421 .42966 .63884 .43516 .6482 .43218 .6436 .42666 Metetra
.664 .741 .908 r
.6436 .42666 .6482 .43218 .6576 .4292 .65302 .42366 Metetra
.664 .741 .908 r
.65302 .42366 .6576 .4292 .66703 .4262 .66247 .42065 Metetra
.664 .741 .908 r
.66247 .42065 .66703 .4262 .67649 .4232 .67195 .41763 Metetra
.664 .741 .908 r
.67195 .41763 .67649 .4232 .68599 .42018 .68147 .41459 Metetra
.664 .741 .908 r
.68147 .41459 .68599 .42018 .69551 .41716 .69101 .41155 Metetra
.664 .741 .908 r
.69101 .41155 .69551 .41716 .70507 .41412 .70059 .40849 Metetra
.664 .741 .908 r
.70059 .40849 .70507 .41412 .71466 .41108 .71021 .40543 Metetra
.664 .741 .908 r
.71021 .40543 .71466 .41108 .72428 .40802 .71985 .40236 Metetra
.664 .741 .908 r
.71985 .40236 .72428 .40802 .73394 .40496 .72953 .39927 Metetra
.664 .741 .908 r
.72953 .39927 .73394 .40496 .74362 .40188 .73924 .39618 Metetra
.664 .741 .908 r
.73924 .39618 .74362 .40188 .75334 .3988 .74898 .39307 Metetra
.664 .741 .908 r
.74898 .39307 .75334 .3988 .7631 .3957 .75876 .38995 Metetra
.664 .741 .908 r
.75876 .38995 .7631 .3957 .77288 .39259 .76857 .38683 Metetra
.664 .741 .908 r
.76857 .38683 .77288 .39259 .7827 .38947 .77841 .38369 Metetra
.664 .741 .908 r
.77841 .38369 .7827 .38947 .79256 .38634 .78829 .38054 Metetra
.664 .741 .908 r
.78829 .38054 .79256 .38634 .80245 .3832 .7982 .37738 Metetra
.664 .741 .908 r
.7982 .37738 .80245 .3832 .81237 .38005 .80815 .37421 Metetra
.664 .741 .908 r
.80815 .37421 .81237 .38005 .82232 .37689 .81813 .37103 Metetra
.664 .741 .908 r
.81813 .37103 .82232 .37689 .83231 .37372 .82814 .36784 Metetra
.664 .741 .908 r
.82814 .36784 .83231 .37372 .84234 .37054 .83819 .36463 Metetra
.664 .741 .908 r
.83819 .36463 .84234 .37054 .8524 .36734 .84828 .36142 Metetra
.664 .741 .908 r
.84828 .36142 .8524 .36734 .86249 .36414 .8584 .35819 Metetra
.664 .741 .908 r
.8584 .35819 .86249 .36414 .87262 .36092 .86855 .35495 Metetra
.664 .741 .908 r
.86855 .35495 .87262 .36092 .88278 .35769 .87874 .35171 Metetra
.664 .741 .908 r
.87874 .35171 .88278 .35769 .89298 .35446 .88897 .34845 Metetra
.664 .741 .908 r
.88897 .34845 .89298 .35446 .90322 .35121 .89923 .34518 Metetra
.664 .741 .908 r
.89923 .34518 .90322 .35121 .91349 .34794 .90953 .34189 Metetra
.664 .741 .908 r
.31899 .52351 .32429 .52845 .33267 .52578 .32738 .52083 Metetra
.664 .741 .908 r
.32738 .52083 .33267 .52578 .34108 .5231 .3358 .51813 Metetra
.664 .741 .908 r
.3358 .51813 .34108 .5231 .34951 .52041 .34425 .51543 Metetra
.664 .741 .908 r
.34425 .51543 .34951 .52041 .35797 .51772 .35273 .51272 Metetra
.664 .741 .908 r
.35273 .51272 .35797 .51772 .36645 .51501 .36123 .51 Metetra
.664 .741 .908 r
.36123 .51 .36645 .51501 .37496 .5123 .36976 .50727 Metetra
.664 .741 .908 r
.36976 .50727 .37496 .5123 .3835 .50958 .37832 .50453 Metetra
.664 .741 .908 r
.37832 .50453 .3835 .50958 .39207 .50684 .3869 .50178 Metetra
.664 .741 .908 r
.3869 .50178 .39207 .50684 .40067 .5041 .39551 .49902 Metetra
.664 .741 .908 r
.39551 .49902 .40067 .5041 .40929 .50136 .40415 .49626 Metetra
.664 .741 .908 r
.40415 .49626 .40929 .50136 .41794 .4986 .41282 .49348 Metetra
.664 .741 .908 r
.41282 .49348 .41794 .4986 .42662 .49583 .42152 .4907 Metetra
.664 .741 .908 r
.42152 .4907 .42662 .49583 .43532 .49306 .43024 .48791 Metetra
.664 .741 .908 r
.43024 .48791 .43532 .49306 .44406 .49027 .43899 .48511 Metetra
.664 .741 .908 r
.43899 .48511 .44406 .49027 .45282 .48748 .44777 .4823 Metetra
.664 .741 .908 r
.44777 .4823 .45282 .48748 .46161 .48468 .45658 .47948 Metetra
.664 .741 .908 r
.45658 .47948 .46161 .48468 .47043 .48187 .46542 .47665 Metetra
.664 .741 .908 r
.46542 .47665 .47043 .48187 .47928 .47905 .47428 .47382 Metetra
.664 .741 .908 r
.47428 .47382 .47928 .47905 .48815 .47622 .48318 .47097 Metetra
.664 .741 .908 r
.48318 .47097 .48815 .47622 .49706 .47338 .4921 .46811 Metetra
.664 .741 .908 r
.4921 .46811 .49706 .47338 .50599 .47053 .50106 .46525 Metetra
.664 .741 .908 r
.50106 .46525 .50599 .47053 .51496 .46767 .51004 .46237 Metetra
.664 .741 .908 r
.51004 .46237 .51496 .46767 .52395 .46481 .51905 .45949 Metetra
.664 .741 .908 r
.51905 .45949 .52395 .46481 .53297 .46193 .52809 .45659 Metetra
.664 .741 .908 r
.52809 .45659 .53297 .46193 .54202 .45904 .53716 .45369 Metetra
.664 .741 .908 r
.53716 .45369 .54202 .45904 .55111 .45615 .54627 .45078 Metetra
.664 .741 .908 r
.54627 .45078 .55111 .45615 .56022 .45324 .5554 .44786 Metetra
.664 .741 .908 r
.5554 .44786 .56022 .45324 .56936 .45033 .56456 .44492 Metetra
.664 .741 .908 r
.56456 .44492 .56936 .45033 .57853 .44741 .57375 .44198 Metetra
.664 .741 .908 r
.57375 .44198 .57853 .44741 .58773 .44447 .58298 .43903 Metetra
.664 .741 .908 r
.58298 .43903 .58773 .44447 .59697 .44153 .59223 .43607 Metetra
.664 .741 .908 r
.59223 .43607 .59697 .44153 .60623 .43858 .60151 .4331 Metetra
.664 .741 .908 r
.60151 .4331 .60623 .43858 .61553 .43561 .61083 .43012 Metetra
.664 .741 .908 r
.61083 .43012 .61553 .43561 .62485 .43264 .62018 .42713 Metetra
.664 .741 .908 r
.62018 .42713 .62485 .43264 .63421 .42966 .62955 .42412 Metetra
.664 .741 .908 r
.62955 .42412 .63421 .42966 .6436 .42666 .63896 .42111 Metetra
.664 .741 .908 r
.63896 .42111 .6436 .42666 .65302 .42366 .64841 .41809 Metetra
.664 .741 .908 r
.64841 .41809 .65302 .42366 .66247 .42065 .65788 .41506 Metetra
.664 .741 .908 r
.65788 .41506 .66247 .42065 .67195 .41763 .66738 .41202 Metetra
.664 .741 .908 r
.66738 .41202 .67195 .41763 .68147 .41459 .67692 .40897 Metetra
.664 .741 .908 r
.67692 .40897 .68147 .41459 .69101 .41155 .68649 .4059 Metetra
.664 .741 .908 r
.68649 .4059 .69101 .41155 .70059 .40849 .69609 .40283 Metetra
.664 .741 .908 r
.69609 .40283 .70059 .40849 .71021 .40543 .70573 .39975 Metetra
.664 .741 .908 r
.70573 .39975 .71021 .40543 .71985 .40236 .71539 .39665 Metetra
.664 .741 .908 r
.71539 .39665 .71985 .40236 .72953 .39927 .72509 .39355 Metetra
.664 .741 .908 r
.72509 .39355 .72953 .39927 .73924 .39618 .73483 .39043 Metetra
.664 .741 .908 r
.73483 .39043 .73924 .39618 .74898 .39307 .74459 .38731 Metetra
.664 .741 .908 r
.74459 .38731 .74898 .39307 .75876 .38995 .75439 .38417 Metetra
.664 .741 .908 r
.75439 .38417 .75876 .38995 .76857 .38683 .76423 .38102 Metetra
.664 .741 .908 r
.76423 .38102 .76857 .38683 .77841 .38369 .7741 .37787 Metetra
.664 .741 .908 r
.7741 .37787 .77841 .38369 .78829 .38054 .784 .3747 Metetra
.664 .741 .908 r
.784 .3747 .78829 .38054 .7982 .37738 .79393 .37152 Metetra
.664 .741 .908 r
.79393 .37152 .7982 .37738 .80815 .37421 .8039 .36833 Metetra
.664 .741 .908 r
.8039 .36833 .80815 .37421 .81813 .37103 .81391 .36513 Metetra
.664 .741 .908 r
.81391 .36513 .81813 .37103 .82814 .36784 .82395 .36191 Metetra
.664 .741 .908 r
.82395 .36191 .82814 .36784 .83819 .36463 .83402 .35869 Metetra
.664 .741 .908 r
.83402 .35869 .83819 .36463 .84828 .36142 .84413 .35545 Metetra
.664 .741 .908 r
.84413 .35545 .84828 .36142 .8584 .35819 .85428 .35221 Metetra
.664 .741 .908 r
.85428 .35221 .8584 .35819 .86855 .35495 .86446 .34895 Metetra
.664 .741 .908 r
.86446 .34895 .86855 .35495 .87874 .35171 .87467 .34568 Metetra
.664 .741 .908 r
.87467 .34568 .87874 .35171 .88897 .34845 .88492 .3424 Metetra
.664 .741 .908 r
.88492 .3424 .88897 .34845 .89923 .34518 .89521 .33911 Metetra
.664 .741 .908 r
.89521 .33911 .89923 .34518 .90953 .34189 .90553 .3358 Metetra
.664 .741 .908 r
.31365 .51855 .31899 .52351 .32738 .52083 .32207 .51584 Metetra
.664 .741 .908 r
.32207 .51584 .32738 .52083 .3358 .51813 .3305 .51313 Metetra
.664 .741 .908 r
.3305 .51313 .3358 .51813 .34425 .51543 .33897 .51041 Metetra
.664 .741 .908 r
.33897 .51041 .34425 .51543 .35273 .51272 .34746 .50769 Metetra
.664 .741 .908 r
.34746 .50769 .35273 .51272 .36123 .51 .35598 .50495 Metetra
.664 .741 .908 r
.35598 .50495 .36123 .51 .36976 .50727 .36453 .5022 Metetra
.664 .741 .908 r
.36453 .5022 .36976 .50727 .37832 .50453 .3731 .49945 Metetra
.664 .741 .908 r
.3731 .49945 .37832 .50453 .3869 .50178 .3817 .49668 Metetra
.664 .741 .908 r
.3817 .49668 .3869 .50178 .39551 .49902 .39033 .49391 Metetra
.664 .741 .908 r
.39033 .49391 .39551 .49902 .40415 .49626 .39899 .49113 Metetra
.664 .741 .908 r
.39899 .49113 .40415 .49626 .41282 .49348 .40767 .48834 Metetra
.664 .741 .908 r
.40767 .48834 .41282 .49348 .42152 .4907 .41638 .48554 Metetra
.664 .741 .908 r
.41638 .48554 .42152 .4907 .43024 .48791 .42513 .48273 Metetra
.664 .741 .908 r
.42513 .48273 .43024 .48791 .43899 .48511 .4339 .47992 Metetra
.664 .741 .908 r
.4339 .47992 .43899 .48511 .44777 .4823 .44269 .47709 Metetra
.664 .741 .908 r
.44269 .47709 .44777 .4823 .45658 .47948 .45152 .47425 Metetra
.664 .741 .908 r
.45152 .47425 .45658 .47948 .46542 .47665 .46038 .47141 Metetra
.664 .741 .908 r
.46038 .47141 .46542 .47665 .47428 .47382 .46926 .46855 Metetra
.664 .741 .908 r
.46926 .46855 .47428 .47382 .48318 .47097 .47817 .46569 Metetra
.664 .741 .908 r
.47817 .46569 .48318 .47097 .4921 .46811 .48712 .46282 Metetra
.664 .741 .908 r
.48712 .46282 .4921 .46811 .50106 .46525 .49609 .45993 Metetra
.664 .741 .908 r
.49609 .45993 .50106 .46525 .51004 .46237 .50509 .45704 Metetra
.664 .741 .908 r
.50509 .45704 .51004 .46237 .51905 .45949 .51412 .45414 Metetra
.664 .741 .908 r
.51412 .45414 .51905 .45949 .52809 .45659 .52318 .45123 Metetra
.664 .741 .908 r
.52318 .45123 .52809 .45659 .53716 .45369 .53228 .44831 Metetra
.664 .741 .908 r
.53228 .44831 .53716 .45369 .54627 .45078 .5414 .44538 Metetra
.664 .741 .908 r
.5414 .44538 .54627 .45078 .5554 .44786 .55055 .44244 Metetra
.664 .741 .908 r
.55055 .44244 .5554 .44786 .56456 .44492 .55973 .43949 Metetra
.664 .741 .908 r
.55973 .43949 .56456 .44492 .57375 .44198 .56894 .43653 Metetra
.664 .741 .908 r
.56894 .43653 .57375 .44198 .58298 .43903 .57819 .43356 Metetra
.664 .741 .908 r
.57819 .43356 .58298 .43903 .59223 .43607 .58746 .43058 Metetra
.664 .741 .908 r
.58746 .43058 .59223 .43607 .60151 .4331 .59677 .42759 Metetra
.664 .741 .908 r
.59677 .42759 .60151 .4331 .61083 .43012 .6061 .42459 Metetra
.664 .741 .908 r
.6061 .42459 .61083 .43012 .62018 .42713 .61547 .42158 Metetra
.664 .741 .908 r
.61547 .42158 .62018 .42713 .62955 .42412 .62487 .41856 Metetra
.664 .741 .908 r
.62487 .41856 .62955 .42412 .63896 .42111 .6343 .41553 Metetra
.664 .741 .908 r
.6343 .41553 .63896 .42111 .64841 .41809 .64376 .41249 Metetra
.664 .741 .908 r
.64376 .41249 .64841 .41809 .65788 .41506 .65326 .40944 Metetra
.664 .741 .908 r
.65326 .40944 .65788 .41506 .66738 .41202 .66279 .40637 Metetra
.664 .741 .908 r
.66279 .40637 .66738 .41202 .67692 .40897 .67235 .4033 Metetra
.664 .741 .908 r
.67235 .4033 .67692 .40897 .68649 .4059 .68194 .40022 Metetra
.664 .741 .908 r
.68194 .40022 .68649 .4059 .69609 .40283 .69156 .39713 Metetra
.664 .741 .908 r
.69156 .39713 .69609 .40283 .70573 .39975 .70122 .39403 Metetra
.664 .741 .908 r
.70122 .39403 .70573 .39975 .71539 .39665 .71091 .39091 Metetra
.664 .741 .908 r
.71091 .39091 .71539 .39665 .72509 .39355 .72063 .38779 Metetra
.664 .741 .908 r
.72063 .38779 .72509 .39355 .73483 .39043 .73039 .38465 Metetra
.664 .741 .908 r
.73039 .38465 .73483 .39043 .74459 .38731 .74018 .38151 Metetra
.664 .741 .908 r
.74018 .38151 .74459 .38731 .75439 .38417 .75 .37835 Metetra
.664 .741 .908 r
.75 .37835 .75439 .38417 .76423 .38102 .75986 .37519 Metetra
.664 .741 .908 r
.75986 .37519 .76423 .38102 .7741 .37787 .76975 .37201 Metetra
.664 .741 .908 r
.76975 .37201 .7741 .37787 .784 .3747 .77968 .36882 Metetra
.664 .741 .908 r
.77968 .36882 .784 .3747 .79393 .37152 .78964 .36562 Metetra
.664 .741 .908 r
.78964 .36562 .79393 .37152 .8039 .36833 .79963 .36241 Metetra
.664 .741 .908 r
.79963 .36241 .8039 .36833 .81391 .36513 .80966 .35919 Metetra
.664 .741 .908 r
.80966 .35919 .81391 .36513 .82395 .36191 .81973 .35595 Metetra
.664 .741 .908 r
.81973 .35595 .82395 .36191 .83402 .35869 .82983 .35271 Metetra
.664 .741 .908 r
.82983 .35271 .83402 .35869 .84413 .35545 .83996 .34945 Metetra
.664 .741 .908 r
.83996 .34945 .84413 .35545 .85428 .35221 .85013 .34618 Metetra
.664 .741 .908 r
.85013 .34618 .85428 .35221 .86446 .34895 .86034 .3429 Metetra
.664 .741 .908 r
.86034 .3429 .86446 .34895 .87467 .34568 .87058 .33961 Metetra
.664 .741 .908 r
.87058 .33961 .87467 .34568 .88492 .3424 .88085 .33631 Metetra
.664 .741 .908 r
.88085 .33631 .88492 .3424 .89521 .33911 .89117 .333 Metetra
.664 .741 .908 r
.89117 .333 .89521 .33911 .90553 .3358 .90152 .32967 Metetra
.664 .741 .908 r
.30829 .51355 .31365 .51855 .32207 .51584 .31672 .51083 Metetra
.664 .741 .908 r
.31672 .51083 .32207 .51584 .3305 .51313 .32517 .50811 Metetra
.664 .741 .908 r
.32517 .50811 .3305 .51313 .33897 .51041 .33365 .50537 Metetra
.664 .741 .908 r
.33365 .50537 .33897 .51041 .34746 .50769 .34216 .50263 Metetra
.664 .741 .908 r
.34216 .50263 .34746 .50769 .35598 .50495 .3507 .49987 Metetra
.664 .741 .908 r
.3507 .49987 .35598 .50495 .36453 .5022 .35926 .49711 Metetra
.664 .741 .908 r
.35926 .49711 .36453 .5022 .3731 .49945 .36785 .49434 Metetra
.664 .741 .908 r
.36785 .49434 .3731 .49945 .3817 .49668 .37647 .49156 Metetra
.664 .741 .908 r
.37647 .49156 .3817 .49668 .39033 .49391 .38511 .48877 Metetra
.664 .741 .908 r
.38511 .48877 .39033 .49391 .39899 .49113 .39379 .48597 Metetra
.664 .741 .908 r
.39379 .48597 .39899 .49113 .40767 .48834 .40249 .48317 Metetra
.664 .741 .908 r
.40249 .48317 .40767 .48834 .41638 .48554 .41122 .48035 Metetra
.664 .741 .908 r
.41122 .48035 .41638 .48554 .42513 .48273 .41998 .47752 Metetra
.664 .741 .908 r
.41998 .47752 .42513 .48273 .4339 .47992 .42877 .47469 Metetra
.664 .741 .908 r
.42877 .47469 .4339 .47992 .44269 .47709 .43759 .47185 Metetra
.664 .741 .908 r
.43759 .47185 .44269 .47709 .45152 .47425 .44643 .46899 Metetra
.664 .741 .908 r
.44643 .46899 .45152 .47425 .46038 .47141 .4553 .46613 Metetra
.664 .741 .908 r
.4553 .46613 .46038 .47141 .46926 .46855 .46421 .46326 Metetra
.664 .741 .908 r
.46421 .46326 .46926 .46855 .47817 .46569 .47314 .46038 Metetra
.664 .741 .908 r
.47314 .46038 .47817 .46569 .48712 .46282 .4821 .45749 Metetra
.664 .741 .908 r
.4821 .45749 .48712 .46282 .49609 .45993 .49109 .45459 Metetra
.664 .741 .908 r
.49109 .45459 .49609 .45993 .50509 .45704 .50011 .45168 Metetra
.664 .741 .908 r
.50011 .45168 .50509 .45704 .51412 .45414 .50917 .44876 Metetra
.664 .741 .908 r
.50917 .44876 .51412 .45414 .52318 .45123 .51825 .44583 Metetra
.664 .741 .908 r
.51825 .44583 .52318 .45123 .53228 .44831 .52736 .44289 Metetra
.664 .741 .908 r
.52736 .44289 .53228 .44831 .5414 .44538 .5365 .43994 Metetra
.664 .741 .908 r
.5365 .43994 .5414 .44538 .55055 .44244 .54567 .43698 Metetra
.664 .741 .908 r
.54567 .43698 .55055 .44244 .55973 .43949 .55487 .43401 Metetra
.664 .741 .908 r
.55487 .43401 .55973 .43949 .56894 .43653 .56411 .43103 Metetra
.664 .741 .908 r
.56411 .43103 .56894 .43653 .57819 .43356 .57337 .42805 Metetra
.664 .741 .908 r
.57337 .42805 .57819 .43356 .58746 .43058 .58266 .42505 Metetra
.664 .741 .908 r
.58266 .42505 .58746 .43058 .59677 .42759 .59199 .42204 Metetra
.664 .741 .908 r
.59199 .42204 .59677 .42759 .6061 .42459 .60135 .41902 Metetra
.664 .741 .908 r
.60135 .41902 .6061 .42459 .61547 .42158 .61074 .41599 Metetra
.664 .741 .908 r
.61074 .41599 .61547 .42158 .62487 .41856 .62016 .41295 Metetra
.664 .741 .908 r
.62016 .41295 .62487 .41856 .6343 .41553 .62961 .40991 Metetra
.664 .741 .908 r
.62961 .40991 .6343 .41553 .64376 .41249 .63909 .40685 Metetra
.664 .741 .908 r
.63909 .40685 .64376 .41249 .65326 .40944 .64861 .40378 Metetra
.664 .741 .908 r
.64861 .40378 .65326 .40944 .66279 .40637 .65816 .4007 Metetra
.664 .741 .908 r
.65816 .4007 .66279 .40637 .67235 .4033 .66774 .39761 Metetra
.664 .741 .908 r
.66774 .39761 .67235 .4033 .68194 .40022 .67736 .3945 Metetra
.664 .741 .908 r
.67736 .3945 .68194 .40022 .69156 .39713 .687 .39139 Metetra
.664 .741 .908 r
.687 .39139 .69156 .39713 .70122 .39403 .69668 .38827 Metetra
.664 .741 .908 r
.69668 .38827 .70122 .39403 .71091 .39091 .7064 .38514 Metetra
.664 .741 .908 r
.7064 .38514 .71091 .39091 .72063 .38779 .71614 .38199 Metetra
.664 .741 .908 r
.71614 .38199 .72063 .38779 .73039 .38465 .72592 .37884 Metetra
.664 .741 .908 r
.72592 .37884 .73039 .38465 .74018 .38151 .73573 .37567 Metetra
.664 .741 .908 r
.73573 .37567 .74018 .38151 .75 .37835 .74558 .3725 Metetra
.664 .741 .908 r
.74558 .3725 .75 .37835 .75986 .37519 .75546 .36931 Metetra
.664 .741 .908 r
.75546 .36931 .75986 .37519 .76975 .37201 .76538 .36611 Metetra
.664 .741 .908 r
.76538 .36611 .76975 .37201 .77968 .36882 .77533 .3629 Metetra
.664 .741 .908 r
.77533 .3629 .77968 .36882 .78964 .36562 .78531 .35968 Metetra
.664 .741 .908 r
.78531 .35968 .78964 .36562 .79963 .36241 .79533 .35645 Metetra
.664 .741 .908 r
.79533 .35645 .79963 .36241 .80966 .35919 .80539 .35321 Metetra
.664 .741 .908 r
.80539 .35321 .80966 .35919 .81973 .35595 .81548 .34995 Metetra
.664 .741 .908 r
.81548 .34995 .81973 .35595 .82983 .35271 .8256 .34669 Metetra
.664 .741 .908 r
.8256 .34669 .82983 .35271 .83996 .34945 .83576 .34341 Metetra
.664 .741 .908 r
.83576 .34341 .83996 .34945 .85013 .34618 .84596 .34012 Metetra
.664 .741 .908 r
.84596 .34012 .85013 .34618 .86034 .3429 .85619 .33682 Metetra
.664 .741 .908 r
.85619 .33682 .86034 .3429 .87058 .33961 .86646 .33351 Metetra
.664 .741 .908 r
.86646 .33351 .87058 .33961 .88085 .33631 .87676 .33018 Metetra
.664 .741 .908 r
.87676 .33018 .88085 .33631 .89117 .333 .8871 .32685 Metetra
.664 .741 .908 r
.8871 .32685 .89117 .333 .90152 .32967 .89748 .3235 Metetra
.664 .741 .908 r
.30289 .50853 .30829 .51355 .31672 .51083 .31134 .50579 Metetra
.664 .741 .908 r
.31134 .50579 .31672 .51083 .32517 .50811 .31981 .50305 Metetra
.664 .741 .908 r
.31981 .50305 .32517 .50811 .33365 .50537 .3283 .5003 Metetra
.664 .741 .908 r
.3283 .5003 .33365 .50537 .34216 .50263 .33683 .49754 Metetra
.664 .741 .908 r
.33683 .49754 .34216 .50263 .3507 .49987 .34538 .49477 Metetra
.664 .741 .908 r
.34538 .49477 .3507 .49987 .35926 .49711 .35396 .49199 Metetra
.664 .741 .908 r
.35396 .49199 .35926 .49711 .36785 .49434 .36257 .4892 Metetra
.664 .741 .908 r
.36257 .4892 .36785 .49434 .37647 .49156 .37121 .4864 Metetra
.664 .741 .908 r
.37121 .4864 .37647 .49156 .38511 .48877 .37987 .4836 Metetra
.664 .741 .908 r
.37987 .4836 .38511 .48877 .39379 .48597 .38856 .48078 Metetra
.664 .741 .908 r
.38856 .48078 .39379 .48597 .40249 .48317 .39728 .47796 Metetra
.664 .741 .908 r
.39728 .47796 .40249 .48317 .41122 .48035 .40603 .47513 Metetra
.664 .741 .908 r
.40603 .47513 .41122 .48035 .41998 .47752 .41481 .47228 Metetra
.664 .741 .908 r
.41481 .47228 .41998 .47752 .42877 .47469 .42361 .46943 Metetra
.664 .741 .908 r
.42361 .46943 .42877 .47469 .43759 .47185 .43245 .46657 Metetra
.664 .741 .908 r
.43245 .46657 .43759 .47185 .44643 .46899 .44131 .4637 Metetra
.664 .741 .908 r
.44131 .4637 .44643 .46899 .4553 .46613 .4502 .46082 Metetra
.664 .741 .908 r
.4502 .46082 .4553 .46613 .46421 .46326 .45912 .45793 Metetra
.664 .741 .908 r
.45912 .45793 .46421 .46326 .47314 .46038 .46808 .45503 Metetra
.664 .741 .908 r
.46808 .45503 .47314 .46038 .4821 .45749 .47706 .45212 Metetra
.664 .741 .908 r
.47706 .45212 .4821 .45749 .49109 .45459 .48607 .44921 Metetra
.664 .741 .908 r
.48607 .44921 .49109 .45459 .50011 .45168 .49511 .44628 Metetra
.664 .741 .908 r
.49511 .44628 .50011 .45168 .50917 .44876 .50418 .44334 Metetra
.664 .741 .908 r
.50418 .44334 .50917 .44876 .51825 .44583 .51328 .44039 Metetra
.664 .741 .908 r
.51328 .44039 .51825 .44583 .52736 .44289 .52241 .43744 Metetra
.664 .741 .908 r
.52241 .43744 .52736 .44289 .5365 .43994 .53157 .43447 Metetra
.664 .741 .908 r
.53157 .43447 .5365 .43994 .54567 .43698 .54076 .43149 Metetra
.664 .741 .908 r
.54076 .43149 .54567 .43698 .55487 .43401 .54998 .42851 Metetra
.664 .741 .908 r
.54998 .42851 .55487 .43401 .56411 .43103 .55924 .42551 Metetra
.664 .741 .908 r
.55924 .42551 .56411 .43103 .57337 .42805 .56852 .4225 Metetra
.664 .741 .908 r
.56852 .4225 .57337 .42805 .58266 .42505 .57784 .41949 Metetra
.664 .741 .908 r
.57784 .41949 .58266 .42505 .59199 .42204 .58718 .41646 Metetra
.664 .741 .908 r
.58718 .41646 .59199 .42204 .60135 .41902 .59656 .41342 Metetra
.664 .741 .908 r
.59656 .41342 .60135 .41902 .61074 .41599 .60597 .41038 Metetra
.664 .741 .908 r
.60597 .41038 .61074 .41599 .62016 .41295 .61541 .40732 Metetra
.664 .741 .908 r
.61541 .40732 .62016 .41295 .62961 .40991 .62489 .40425 Metetra
.664 .741 .908 r
.62489 .40425 .62961 .40991 .63909 .40685 .6344 .40117 Metetra
.664 .741 .908 r
.6344 .40117 .63909 .40685 .64861 .40378 .64393 .39808 Metetra
.664 .741 .908 r
.64393 .39808 .64861 .40378 .65816 .4007 .6535 .39498 Metetra
.664 .741 .908 r
.6535 .39498 .65816 .4007 .66774 .39761 .66311 .39187 Metetra
.664 .741 .908 r
.66311 .39187 .66774 .39761 .67736 .3945 .67274 .38875 Metetra
.664 .741 .908 r
.67274 .38875 .67736 .3945 .687 .39139 .68241 .38562 Metetra
.664 .741 .908 r
.68241 .38562 .687 .39139 .69668 .38827 .69212 .38248 Metetra
.664 .741 .908 r
.69212 .38248 .69668 .38827 .7064 .38514 .70185 .37933 Metetra
.664 .741 .908 r
.70185 .37933 .7064 .38514 .71614 .38199 .71162 .37616 Metetra
.664 .741 .908 r
.71162 .37616 .71614 .38199 .72592 .37884 .72143 .37299 Metetra
.664 .741 .908 r
.72143 .37299 .72592 .37884 .73573 .37567 .73126 .3698 Metetra
.664 .741 .908 r
.73126 .3698 .73573 .37567 .74558 .3725 .74113 .3666 Metetra
.664 .741 .908 r
.74113 .3666 .74558 .3725 .75546 .36931 .75104 .3634 Metetra
.664 .741 .908 r
.75104 .3634 .75546 .36931 .76538 .36611 .76098 .36018 Metetra
.664 .741 .908 r
.76098 .36018 .76538 .36611 .77533 .3629 .77095 .35695 Metetra
.664 .741 .908 r
.77095 .35695 .77533 .3629 .78531 .35968 .78096 .35371 Metetra
.664 .741 .908 r
.78096 .35371 .78531 .35968 .79533 .35645 .79101 .35045 Metetra
.664 .741 .908 r
.79101 .35045 .79533 .35645 .80539 .35321 .80108 .34719 Metetra
.664 .741 .908 r
.80108 .34719 .80539 .35321 .81548 .34995 .8112 .34391 Metetra
.664 .741 .908 r
.8112 .34391 .81548 .34995 .8256 .34669 .82135 .34063 Metetra
.664 .741 .908 r
.82135 .34063 .8256 .34669 .83576 .34341 .83153 .33733 Metetra
.664 .741 .908 r
.83153 .33733 .83576 .34341 .84596 .34012 .84176 .33402 Metetra
.664 .741 .908 r
.84176 .33402 .84596 .34012 .85619 .33682 .85201 .3307 Metetra
.664 .741 .908 r
.85201 .3307 .85619 .33682 .86646 .33351 .86231 .32736 Metetra
.664 .741 .908 r
.86231 .32736 .86646 .33351 .87676 .33018 .87264 .32402 Metetra
.664 .741 .908 r
.87264 .32402 .87676 .33018 .8871 .32685 .883 .32066 Metetra
.664 .741 .908 r
.883 .32066 .8871 .32685 .89748 .3235 .89341 .31729 Metetra
.664 .741 .908 r
.29746 .50347 .30289 .50853 .31134 .50579 .30592 .50072 Metetra
.664 .741 .908 r
.30592 .50072 .31134 .50579 .31981 .50305 .31441 .49796 Metetra
.664 .741 .908 r
.31441 .49796 .31981 .50305 .3283 .5003 .32292 .49519 Metetra
.664 .741 .908 r
.32292 .49519 .3283 .5003 .33683 .49754 .33147 .49242 Metetra
.664 .741 .908 r
.33147 .49242 .33683 .49754 .34538 .49477 .34004 .48963 Metetra
.664 .741 .908 r
.34004 .48963 .34538 .49477 .35396 .49199 .34863 .48683 Metetra
.664 .741 .908 r
.34863 .48683 .35396 .49199 .36257 .4892 .35726 .48403 Metetra
.664 .741 .908 r
.35726 .48403 .36257 .4892 .37121 .4864 .36591 .48122 Metetra
.664 .741 .908 r
.36591 .48122 .37121 .4864 .37987 .4836 .37459 .47839 Metetra
.664 .741 .908 r
.37459 .47839 .37987 .4836 .38856 .48078 .3833 .47556 Metetra
.664 .741 .908 r
.3833 .47556 .38856 .48078 .39728 .47796 .39204 .47272 Metetra
.664 .741 .908 r
.39204 .47272 .39728 .47796 .40603 .47513 .4008 .46987 Metetra
.664 .741 .908 r
.4008 .46987 .40603 .47513 .41481 .47228 .4096 .46701 Metetra
.664 .741 .908 r
.4096 .46701 .41481 .47228 .42361 .46943 .41842 .46414 Metetra
.664 .741 .908 r
.41842 .46414 .42361 .46943 .43245 .46657 .42728 .46126 Metetra
.664 .741 .908 r
.42728 .46126 .43245 .46657 .44131 .4637 .43616 .45838 Metetra
.664 .741 .908 r
.43616 .45838 .44131 .4637 .4502 .46082 .44507 .45548 Metetra
.664 .741 .908 r
.44507 .45548 .4502 .46082 .45912 .45793 .45401 .45257 Metetra
.664 .741 .908 r
.45401 .45257 .45912 .45793 .46808 .45503 .46298 .44966 Metetra
.664 .741 .908 r
.46298 .44966 .46808 .45503 .47706 .45212 .47198 .44673 Metetra
.664 .741 .908 r
.47198 .44673 .47706 .45212 .48607 .44921 .48101 .44379 Metetra
.664 .741 .908 r
.48101 .44379 .48607 .44921 .49511 .44628 .49007 .44085 Metetra
.664 .741 .908 r
.49007 .44085 .49511 .44628 .50418 .44334 .49916 .43789 Metetra
.664 .741 .908 r
.49916 .43789 .50418 .44334 .51328 .44039 .50828 .43493 Metetra
.664 .741 .908 r
.50828 .43493 .51328 .44039 .52241 .43744 .51743 .43195 Metetra
.664 .741 .908 r
.51743 .43195 .52241 .43744 .53157 .43447 .52661 .42897 Metetra
.664 .741 .908 r
.52661 .42897 .53157 .43447 .54076 .43149 .53582 .42597 Metetra
.664 .741 .908 r
.53582 .42597 .54076 .43149 .54998 .42851 .54507 .42297 Metetra
.664 .741 .908 r
.54507 .42297 .54998 .42851 .55924 .42551 .55434 .41995 Metetra
.664 .741 .908 r
.55434 .41995 .55924 .42551 .56852 .4225 .56364 .41693 Metetra
.664 .741 .908 r
.56364 .41693 .56852 .4225 .57784 .41949 .57298 .41389 Metetra
.664 .741 .908 r
.57298 .41389 .57784 .41949 .58718 .41646 .58235 .41084 Metetra
.664 .741 .908 r
.58235 .41084 .58718 .41646 .59656 .41342 .59175 .40779 Metetra
.664 .741 .908 r
.59175 .40779 .59656 .41342 .60597 .41038 .60118 .40472 Metetra
.664 .741 .908 r
.60118 .40472 .60597 .41038 .61541 .40732 .61064 .40165 Metetra
.664 .741 .908 r
.61064 .40165 .61541 .40732 .62489 .40425 .62014 .39856 Metetra
.664 .741 .908 r
.62014 .39856 .62489 .40425 .6344 .40117 .62967 .39546 Metetra
.664 .741 .908 r
.62967 .39546 .6344 .40117 .64393 .39808 .63923 .39235 Metetra
.664 .741 .908 r
.63923 .39235 .64393 .39808 .6535 .39498 .64882 .38923 Metetra
.664 .741 .908 r
.64882 .38923 .6535 .39498 .66311 .39187 .65845 .3861 Metetra
.664 .741 .908 r
.65845 .3861 .66311 .39187 .67274 .38875 .6681 .38296 Metetra
.664 .741 .908 r
.6681 .38296 .67274 .38875 .68241 .38562 .6778 .37981 Metetra
.664 .741 .908 r
.6778 .37981 .68241 .38562 .69212 .38248 .68752 .37665 Metetra
.664 .741 .908 r
.68752 .37665 .69212 .38248 .70185 .37933 .69728 .37348 Metetra
.664 .741 .908 r
.69728 .37348 .70185 .37933 .71162 .37616 .70707 .37029 Metetra
.664 .741 .908 r
.70707 .37029 .71162 .37616 .72143 .37299 .7169 .3671 Metetra
.664 .741 .908 r
.7169 .3671 .72143 .37299 .73126 .3698 .72676 .36389 Metetra
.664 .741 .908 r
.72676 .36389 .73126 .3698 .74113 .3666 .73666 .36067 Metetra
.664 .741 .908 r
.73666 .36067 .74113 .3666 .75104 .3634 .74659 .35745 Metetra
.664 .741 .908 r
.74659 .35745 .75104 .3634 .76098 .36018 .75655 .35421 Metetra
.664 .741 .908 r
.75655 .35421 .76098 .36018 .77095 .35695 .76655 .35095 Metetra
.664 .741 .908 r
.76655 .35095 .77095 .35695 .78096 .35371 .77658 .34769 Metetra
.664 .741 .908 r
.77658 .34769 .78096 .35371 .79101 .35045 .78665 .34442 Metetra
.664 .741 .908 r
.78665 .34442 .79101 .35045 .80108 .34719 .79675 .34113 Metetra
.664 .741 .908 r
.79675 .34113 .80108 .34719 .8112 .34391 .80689 .33784 Metetra
.664 .741 .908 r
.80689 .33784 .8112 .34391 .82135 .34063 .81707 .33453 Metetra
.664 .741 .908 r
.81707 .33453 .82135 .34063 .83153 .33733 .82728 .33121 Metetra
.664 .741 .908 r
.82728 .33121 .83153 .33733 .84176 .33402 .83753 .32788 Metetra
.664 .741 .908 r
.83753 .32788 .84176 .33402 .85201 .3307 .84781 .32453 Metetra
.664 .741 .908 r
.84781 .32453 .85201 .3307 .86231 .32736 .85813 .32118 Metetra
.664 .741 .908 r
.85813 .32118 .86231 .32736 .87264 .32402 .86849 .31781 Metetra
.664 .741 .908 r
.86849 .31781 .87264 .32402 .883 .32066 .87888 .31443 Metetra
.664 .741 .908 r
.87888 .31443 .883 .32066 .89341 .31729 .88931 .31104 Metetra
.664 .741 .908 r
.292 .49839 .29746 .50347 .30592 .50072 .30048 .49562 Metetra
.664 .741 .908 r
.30048 .49562 .30592 .50072 .31441 .49796 .30898 .49284 Metetra
.664 .741 .908 r
.30898 .49284 .31441 .49796 .32292 .49519 .31751 .49006 Metetra
.664 .741 .908 r
.31751 .49006 .32292 .49519 .33147 .49242 .32607 .48726 Metetra
.664 .741 .908 r
.32607 .48726 .33147 .49242 .34004 .48963 .33466 .48446 Metetra
.664 .741 .908 r
.33466 .48446 .34004 .48963 .34863 .48683 .34327 .48165 Metetra
.664 .741 .908 r
.34327 .48165 .34863 .48683 .35726 .48403 .35191 .47883 Metetra
.664 .741 .908 r
.35191 .47883 .35726 .48403 .36591 .48122 .36058 .476 Metetra
.664 .741 .908 r
.36058 .476 .36591 .48122 .37459 .47839 .36928 .47316 Metetra
.664 .741 .908 r
.36928 .47316 .37459 .47839 .3833 .47556 .37801 .47031 Metetra
.664 .741 .908 r
.37801 .47031 .3833 .47556 .39204 .47272 .38676 .46745 Metetra
.664 .741 .908 r
.38676 .46745 .39204 .47272 .4008 .46987 .39555 .46458 Metetra
.664 .741 .908 r
.39555 .46458 .4008 .46987 .4096 .46701 .40436 .46171 Metetra
.664 .741 .908 r
.40436 .46171 .4096 .46701 .41842 .46414 .4132 .45882 Metetra
.664 .741 .908 r
.4132 .45882 .41842 .46414 .42728 .46126 .42208 .45593 Metetra
.664 .741 .908 r
.42208 .45593 .42728 .46126 .43616 .45838 .43098 .45302 Metetra
.664 .741 .908 r
.43098 .45302 .43616 .45838 .44507 .45548 .43991 .4501 Metetra
.664 .741 .908 r
.43991 .4501 .44507 .45548 .45401 .45257 .44886 .44718 Metetra
.664 .741 .908 r
.44886 .44718 .45401 .45257 .46298 .44966 .45785 .44425 Metetra
.664 .741 .908 r
.45785 .44425 .46298 .44966 .47198 .44673 .46687 .4413 Metetra
.664 .741 .908 r
.46687 .4413 .47198 .44673 .48101 .44379 .47592 .43835 Metetra
.664 .741 .908 r
.47592 .43835 .48101 .44379 .49007 .44085 .485 .43538 Metetra
.664 .741 .908 r
.485 .43538 .49007 .44085 .49916 .43789 .49411 .43241 Metetra
.664 .741 .908 r
.49411 .43241 .49916 .43789 .50828 .43493 .50325 .42943 Metetra
.664 .741 .908 r
.50325 .42943 .50828 .43493 .51743 .43195 .51242 .42643 Metetra
.664 .741 .908 r
.51242 .42643 .51743 .43195 .52661 .42897 .52162 .42343 Metetra
.664 .741 .908 r
.52162 .42343 .52661 .42897 .53582 .42597 .53085 .42042 Metetra
.664 .741 .908 r
.53085 .42042 .53582 .42597 .54507 .42297 .54012 .41739 Metetra
.664 .741 .908 r
.54012 .41739 .54507 .42297 .55434 .41995 .54941 .41436 Metetra
.664 .741 .908 r
.54941 .41436 .55434 .41995 .56364 .41693 .55874 .41131 Metetra
.664 .741 .908 r
.55874 .41131 .56364 .41693 .57298 .41389 .56809 .40826 Metetra
.664 .741 .908 r
.56809 .40826 .57298 .41389 .58235 .41084 .57748 .40519 Metetra
.664 .741 .908 r
.57748 .40519 .58235 .41084 .59175 .40779 .5869 .40212 Metetra
.664 .741 .908 r
.5869 .40212 .59175 .40779 .60118 .40472 .59636 .39903 Metetra
.664 .741 .908 r
.59636 .39903 .60118 .40472 .61064 .40165 .60584 .39594 Metetra
.664 .741 .908 r
.60584 .39594 .61064 .40165 .62014 .39856 .61536 .39283 Metetra
.664 .741 .908 r
.61536 .39283 .62014 .39856 .62967 .39546 .62491 .38971 Metetra
.664 .741 .908 r
.62491 .38971 .62967 .39546 .63923 .39235 .63449 .38658 Metetra
.664 .741 .908 r
.63449 .38658 .63923 .39235 .64882 .38923 .64411 .38345 Metetra
.664 .741 .908 r
.64411 .38345 .64882 .38923 .65845 .3861 .65375 .3803 Metetra
.664 .741 .908 r
.65375 .3803 .65845 .3861 .6681 .38296 .66344 .37714 Metetra
.664 .741 .908 r
.66344 .37714 .6681 .38296 .6778 .37981 .67315 .37396 Metetra
.664 .741 .908 r
.67315 .37396 .6778 .37981 .68752 .37665 .6829 .37078 Metetra
.664 .741 .908 r
.6829 .37078 .68752 .37665 .69728 .37348 .69268 .36759 Metetra
.664 .741 .908 r
.69268 .36759 .69728 .37348 .70707 .37029 .7025 .36438 Metetra
.664 .741 .908 r
.7025 .36438 .70707 .37029 .7169 .3671 .71235 .36117 Metetra
.664 .741 .908 r
.71235 .36117 .7169 .3671 .72676 .36389 .72223 .35794 Metetra
.664 .741 .908 r
.72223 .35794 .72676 .36389 .73666 .36067 .73215 .3547 Metetra
.664 .741 .908 r
.73215 .3547 .73666 .36067 .74659 .35745 .7421 .35146 Metetra
.664 .741 .908 r
.7421 .35146 .74659 .35745 .75655 .35421 .75209 .3482 Metetra
.664 .741 .908 r
.75209 .3482 .75655 .35421 .76655 .35095 .76212 .34492 Metetra
.664 .741 .908 r
.76212 .34492 .76655 .35095 .77658 .34769 .77217 .34164 Metetra
.664 .741 .908 r
.77217 .34164 .77658 .34769 .78665 .34442 .78227 .33834 Metetra
.664 .741 .908 r
.78227 .33834 .78665 .34442 .79675 .34113 .7924 .33504 Metetra
.664 .741 .908 r
.7924 .33504 .79675 .34113 .80689 .33784 .80256 .33172 Metetra
.664 .741 .908 r
.80256 .33172 .80689 .33784 .81707 .33453 .81276 .32839 Metetra
.664 .741 .908 r
.81276 .32839 .81707 .33453 .82728 .33121 .823 .32505 Metetra
.664 .741 .908 r
.823 .32505 .82728 .33121 .83753 .32788 .83327 .32169 Metetra
.664 .741 .908 r
.83327 .32169 .83753 .32788 .84781 .32453 .84358 .31833 Metetra
.664 .741 .908 r
.84358 .31833 .84781 .32453 .85813 .32118 .85393 .31495 Metetra
.664 .741 .908 r
.85393 .31495 .85813 .32118 .86849 .31781 .86431 .31156 Metetra
.664 .741 .908 r
.86431 .31156 .86849 .31781 .87888 .31443 .87473 .30816 Metetra
.664 .741 .908 r
.87473 .30816 .87888 .31443 .88931 .31104 .88519 .30475 Metetra
.664 .741 .908 r
.28651 .49327 .292 .49839 .30048 .49562 .295 .49049 Metetra
.664 .741 .908 r
.295 .49049 .30048 .49562 .30898 .49284 .30352 .4877 Metetra
.664 .741 .908 r
.30352 .4877 .30898 .49284 .31751 .49006 .31207 .48489 Metetra
.664 .741 .908 r
.31207 .48489 .31751 .49006 .32607 .48726 .32064 .48208 Metetra
.664 .741 .908 r
.32064 .48208 .32607 .48726 .33466 .48446 .32925 .47926 Metetra
.664 .741 .908 r
.32925 .47926 .33466 .48446 .34327 .48165 .33788 .47643 Metetra
.664 .741 .908 r
.33788 .47643 .34327 .48165 .35191 .47883 .34654 .4736 Metetra
.664 .741 .908 r
.34654 .4736 .35191 .47883 .36058 .476 .35523 .47075 Metetra
.664 .741 .908 r
.35523 .47075 .36058 .476 .36928 .47316 .36394 .46789 Metetra
.664 .741 .908 r
.36394 .46789 .36928 .47316 .37801 .47031 .37269 .46503 Metetra
.664 .741 .908 r
.37269 .46503 .37801 .47031 .38676 .46745 .38146 .46215 Metetra
.664 .741 .908 r
.38146 .46215 .38676 .46745 .39555 .46458 .39026 .45927 Metetra
.664 .741 .908 r
.39026 .45927 .39555 .46458 .40436 .46171 .39909 .45637 Metetra
.664 .741 .908 r
.39909 .45637 .40436 .46171 .4132 .45882 .40795 .45347 Metetra
.664 .741 .908 r
.40795 .45347 .4132 .45882 .42208 .45593 .41684 .45055 Metetra
.664 .741 .908 r
.41684 .45055 .42208 .45593 .43098 .45302 .42576 .44763 Metetra
.664 .741 .908 r
.42576 .44763 .43098 .45302 .43991 .4501 .43471 .4447 Metetra
.664 .741 .908 r
.43471 .4447 .43991 .4501 .44886 .44718 .44369 .44176 Metetra
.664 .741 .908 r
.44369 .44176 .44886 .44718 .45785 .44425 .4527 .4388 Metetra
.664 .741 .908 r
.4527 .4388 .45785 .44425 .46687 .4413 .46173 .43584 Metetra
.664 .741 .908 r
.46173 .43584 .46687 .4413 .47592 .43835 .4708 .43287 Metetra
.664 .741 .908 r
.4708 .43287 .47592 .43835 .485 .43538 .4799 .42989 Metetra
.664 .741 .908 r
.4799 .42989 .485 .43538 .49411 .43241 .48903 .42689 Metetra
.664 .741 .908 r
.48903 .42689 .49411 .43241 .50325 .42943 .49819 .42389 Metetra
.664 .741 .908 r
.49819 .42389 .50325 .42943 .51242 .42643 .50738 .42088 Metetra
.664 .741 .908 r
.50738 .42088 .51242 .42643 .52162 .42343 .5166 .41786 Metetra
.664 .741 .908 r
.5166 .41786 .52162 .42343 .53085 .42042 .52585 .41483 Metetra
.664 .741 .908 r
.52585 .41483 .53085 .42042 .54012 .41739 .53514 .41178 Metetra
.664 .741 .908 r
.53514 .41178 .54012 .41739 .54941 .41436 .54445 .40873 Metetra
.664 .741 .908 r
.54445 .40873 .54941 .41436 .55874 .41131 .5538 .40567 Metetra
.664 .741 .908 r
.5538 .40567 .55874 .41131 .56809 .40826 .56318 .40259 Metetra
.664 .741 .908 r
.56318 .40259 .56809 .40826 .57748 .40519 .57259 .39951 Metetra
.664 .741 .908 r
.57259 .39951 .57748 .40519 .5869 .40212 .58203 .39641 Metetra
.664 .741 .908 r
.58203 .39641 .5869 .40212 .59636 .39903 .5915 .39331 Metetra
.664 .741 .908 r
.5915 .39331 .59636 .39903 .60584 .39594 .60101 .39019 Metetra
.664 .741 .908 r
.60101 .39019 .60584 .39594 .61536 .39283 .61055 .38707 Metetra
.664 .741 .908 r
.61055 .38707 .61536 .39283 .62491 .38971 .62012 .38393 Metetra
.664 .741 .908 r
.62012 .38393 .62491 .38971 .63449 .38658 .62972 .38078 Metetra
.664 .741 .908 r
.62972 .38078 .63449 .38658 .64411 .38345 .63936 .37762 Metetra
.664 .741 .908 r
.63936 .37762 .64411 .38345 .65375 .3803 .64903 .37445 Metetra
.664 .741 .908 r
.64903 .37445 .65375 .3803 .66344 .37714 .65874 .37127 Metetra
.664 .741 .908 r
.65874 .37127 .66344 .37714 .67315 .37396 .66847 .36808 Metetra
.664 .741 .908 r
.66847 .36808 .67315 .37396 .6829 .37078 .67825 .36488 Metetra
.664 .741 .908 r
.67825 .36488 .6829 .37078 .69268 .36759 .68805 .36166 Metetra
.664 .741 .908 r
.68805 .36166 .69268 .36759 .7025 .36438 .69789 .35844 Metetra
.664 .741 .908 r
.69789 .35844 .7025 .36438 .71235 .36117 .70776 .3552 Metetra
.664 .741 .908 r
.70776 .3552 .71235 .36117 .72223 .35794 .71767 .35196 Metetra
.664 .741 .908 r
.71767 .35196 .72223 .35794 .73215 .3547 .72762 .3487 Metetra
.664 .741 .908 r
.72762 .3487 .73215 .3547 .7421 .35146 .73759 .34543 Metetra
.664 .741 .908 r
.73759 .34543 .7421 .35146 .75209 .3482 .74761 .34215 Metetra
.664 .741 .908 r
.74761 .34215 .75209 .3482 .76212 .34492 .75765 .33885 Metetra
.664 .741 .908 r
.75765 .33885 .76212 .34492 .77217 .34164 .76774 .33555 Metetra
.664 .741 .908 r
.76774 .33555 .77217 .34164 .78227 .33834 .77786 .33223 Metetra
.664 .741 .908 r
.77786 .33223 .78227 .33834 .7924 .33504 .78801 .3289 Metetra
.664 .741 .908 r
.78801 .3289 .7924 .33504 .80256 .33172 .7982 .32556 Metetra
.664 .741 .908 r
.7982 .32556 .80256 .33172 .81276 .32839 .80843 .32221 Metetra
.664 .741 .908 r
.80843 .32221 .81276 .32839 .823 .32505 .81869 .31885 Metetra
.664 .741 .908 r
.81869 .31885 .823 .32505 .83327 .32169 .82899 .31547 Metetra
.664 .741 .908 r
.82899 .31547 .83327 .32169 .84358 .31833 .83932 .31208 Metetra
.664 .741 .908 r
.83932 .31208 .84358 .31833 .85393 .31495 .8497 .30869 Metetra
.664 .741 .908 r
.8497 .30869 .85393 .31495 .86431 .31156 .86011 .30527 Metetra
.664 .741 .908 r
.86011 .30527 .86431 .31156 .87473 .30816 .87055 .30185 Metetra
.664 .741 .908 r
.87055 .30185 .87473 .30816 .88519 .30475 .88104 .29841 Metetra
.525 .276 .479 r
.27642 .55003 .28651 .49327 .295 .49049 .28508 .54728 Metetra
.525 .276 .479 r
.28508 .54728 .295 .49049 .30352 .4877 .29377 .54452 Metetra
.525 .276 .479 r
.29377 .54452 .30352 .4877 .31207 .48489 .30249 .54175 Metetra
.525 .276 .479 r
.30249 .54175 .31207 .48489 .32064 .48208 .31124 .53897 Metetra
.525 .276 .479 r
.31124 .53897 .32064 .48208 .32925 .47926 .32001 .53619 Metetra
.525 .276 .479 r
.32001 .53619 .32925 .47926 .33788 .47643 .32882 .53339 Metetra
.525 .276 .479 r
.32882 .53339 .33788 .47643 .34654 .4736 .33765 .53059 Metetra
.525 .276 .479 r
.33765 .53059 .34654 .4736 .35523 .47075 .34652 .52777 Metetra
.525 .276 .479 r
.34652 .52777 .35523 .47075 .36394 .46789 .35541 .52495 Metetra
.525 .276 .479 r
.35541 .52495 .36394 .46789 .37269 .46503 .36433 .52211 Metetra
.525 .276 .479 r
.36433 .52211 .37269 .46503 .38146 .46215 .37329 .51927 Metetra
.525 .276 .479 r
.37329 .51927 .38146 .46215 .39026 .45927 .38227 .51642 Metetra
.525 .276 .479 r
.38227 .51642 .39026 .45927 .39909 .45637 .39129 .51355 Metetra
.525 .276 .479 r
.39129 .51355 .39909 .45637 .40795 .45347 .40033 .51068 Metetra
.525 .276 .479 r
.40033 .51068 .40795 .45347 .41684 .45055 .4094 .5078 Metetra
.525 .276 .479 r
.4094 .5078 .41684 .45055 .42576 .44763 .41851 .50491 Metetra
.525 .276 .479 r
.41851 .50491 .42576 .44763 .43471 .4447 .42765 .50201 Metetra
.525 .276 .479 r
.42765 .50201 .43471 .4447 .44369 .44176 .43681 .49909 Metetra
.525 .276 .479 r
.43681 .49909 .44369 .44176 .4527 .4388 .44601 .49617 Metetra
.525 .276 .479 r
.44601 .49617 .4527 .4388 .46173 .43584 .45524 .49324 Metetra
.525 .276 .479 r
.45524 .49324 .46173 .43584 .4708 .43287 .4645 .4903 Metetra
.525 .276 .479 r
.4645 .4903 .4708 .43287 .4799 .42989 .4738 .48735 Metetra
.525 .276 .479 r
.4738 .48735 .4799 .42989 .48903 .42689 .48312 .48439 Metetra
.525 .276 .479 r
.48312 .48439 .48903 .42689 .49819 .42389 .49248 .48142 Metetra
.525 .276 .479 r
.49248 .48142 .49819 .42389 .50738 .42088 .50187 .47844 Metetra
.525 .276 .479 r
.50187 .47844 .50738 .42088 .5166 .41786 .51129 .47544 Metetra
.525 .276 .479 r
.51129 .47544 .5166 .41786 .52585 .41483 .52074 .47244 Metetra
.525 .276 .479 r
.52074 .47244 .52585 .41483 .53514 .41178 .53023 .46943 Metetra
.525 .276 .479 r
.53023 .46943 .53514 .41178 .54445 .40873 .53975 .46641 Metetra
.525 .276 .479 r
.53975 .46641 .54445 .40873 .5538 .40567 .5493 .46337 Metetra
.525 .276 .479 r
.5493 .46337 .5538 .40567 .56318 .40259 .55888 .46033 Metetra
.525 .276 .479 r
.55888 .46033 .56318 .40259 .57259 .39951 .5685 .45727 Metetra
.525 .276 .479 r
.5685 .45727 .57259 .39951 .58203 .39641 .57815 .45421 Metetra
.525 .276 .479 r
.57815 .45421 .58203 .39641 .5915 .39331 .58784 .45113 Metetra
.525 .276 .479 r
.58784 .45113 .5915 .39331 .60101 .39019 .59756 .44805 Metetra
.525 .276 .479 r
.59756 .44805 .60101 .39019 .61055 .38707 .60731 .44495 Metetra
.525 .276 .479 r
.60731 .44495 .61055 .38707 .62012 .38393 .6171 .44184 Metetra
.525 .276 .479 r
.6171 .44184 .62012 .38393 .62972 .38078 .62692 .43872 Metetra
.525 .276 .479 r
.62692 .43872 .62972 .38078 .63936 .37762 .63678 .43559 Metetra
.525 .276 .479 r
.63678 .43559 .63936 .37762 .64903 .37445 .64667 .43245 Metetra
.525 .276 .479 r
.64667 .43245 .64903 .37445 .65874 .37127 .6566 .4293 Metetra
.525 .276 .479 r
.6566 .4293 .65874 .37127 .66847 .36808 .66656 .42613 Metetra
.525 .276 .479 r
.66656 .42613 .66847 .36808 .67825 .36488 .67655 .42296 Metetra
.525 .276 .479 r
.67655 .42296 .67825 .36488 .68805 .36166 .68659 .41977 Metetra
.525 .276 .479 r
.68659 .41977 .68805 .36166 .69789 .35844 .69665 .41658 Metetra
.525 .276 .479 r
.69665 .41658 .69789 .35844 .70776 .3552 .70676 .41337 Metetra
.525 .276 .479 r
.70676 .41337 .70776 .3552 .71767 .35196 .7169 .41015 Metetra
.525 .276 .479 r
.7169 .41015 .71767 .35196 .72762 .3487 .72707 .40692 Metetra
.525 .276 .479 r
.72707 .40692 .72762 .3487 .73759 .34543 .73729 .40367 Metetra
.525 .276 .479 r
.73729 .40367 .73759 .34543 .74761 .34215 .74754 .40042 Metetra
.525 .276 .479 r
.74754 .40042 .74761 .34215 .75765 .33885 .75782 .39715 Metetra
.525 .276 .479 r
.75782 .39715 .75765 .33885 .76774 .33555 .76815 .39387 Metetra
.525 .276 .479 r
.76815 .39387 .76774 .33555 .77786 .33223 .77851 .39058 Metetra
.525 .276 .479 r
.77851 .39058 .77786 .33223 .78801 .3289 .7889 .38728 Metetra
.525 .276 .479 r
.7889 .38728 .78801 .3289 .7982 .32556 .79934 .38397 Metetra
.525 .276 .479 r
.79934 .38397 .7982 .32556 .80843 .32221 .80981 .38064 Metetra
.525 .276 .479 r
.80981 .38064 .80843 .32221 .81869 .31885 .82032 .3773 Metetra
.525 .276 .479 r
.82032 .3773 .81869 .31885 .82899 .31547 .83087 .37395 Metetra
.525 .276 .479 r
.83087 .37395 .82899 .31547 .83932 .31208 .84146 .37059 Metetra
.525 .276 .479 r
.84146 .37059 .83932 .31208 .8497 .30869 .85209 .36721 Metetra
.525 .276 .479 r
.85209 .36721 .8497 .30869 .86011 .30527 .86275 .36383 Metetra
.525 .276 .479 r
.86275 .36383 .86011 .30527 .87055 .30185 .87346 .36043 Metetra
.525 .276 .479 r
.87346 .36043 .87055 .30185 .88104 .29841 .8842 .35702 Metetra
.518 .262 .465 r
.26671 .59841 .27642 .55003 .28508 .54728 .27552 .59568 Metetra
.518 .262 .465 r
.27552 .59568 .28508 .54728 .29377 .54452 .28436 .59295 Metetra
.518 .262 .465 r
.28436 .59295 .29377 .54452 .30249 .54175 .29323 .59021 Metetra
.518 .262 .465 r
.29323 .59021 .30249 .54175 .31124 .53897 .30212 .58746 Metetra
.518 .262 .465 r
.30212 .58746 .31124 .53897 .32001 .53619 .31105 .58471 Metetra
.518 .262 .465 r
.31105 .58471 .32001 .53619 .32882 .53339 .32001 .58194 Metetra
.518 .262 .465 r
.32001 .58194 .32882 .53339 .33765 .53059 .329 .57916 Metetra
.518 .262 .465 r
.329 .57916 .33765 .53059 .34652 .52777 .33802 .57637 Metetra
.518 .262 .465 r
.33802 .57637 .34652 .52777 .35541 .52495 .34707 .57358 Metetra
.518 .262 .465 r
.34707 .57358 .35541 .52495 .36433 .52211 .35615 .57077 Metetra
.518 .262 .465 r
.35615 .57077 .36433 .52211 .37329 .51927 .36527 .56796 Metetra
.518 .262 .465 r
.36527 .56796 .37329 .51927 .38227 .51642 .37441 .56513 Metetra
.518 .262 .465 r
.37441 .56513 .38227 .51642 .39129 .51355 .38358 .5623 Metetra
.518 .262 .465 r
.38358 .5623 .39129 .51355 .40033 .51068 .39279 .55945 Metetra
.518 .262 .465 r
.39279 .55945 .40033 .51068 .4094 .5078 .40203 .5566 Metetra
.518 .262 .465 r
.40203 .5566 .4094 .5078 .41851 .50491 .4113 .55374 Metetra
.518 .262 .465 r
.4113 .55374 .41851 .50491 .42765 .50201 .4206 .55086 Metetra
.518 .262 .465 r
.4206 .55086 .42765 .50201 .43681 .49909 .42994 .54798 Metetra
.518 .262 .465 r
.42994 .54798 .43681 .49909 .44601 .49617 .4393 .54509 Metetra
.518 .262 .465 r
.4393 .54509 .44601 .49617 .45524 .49324 .4487 .54218 Metetra
.518 .262 .465 r
.4487 .54218 .45524 .49324 .4645 .4903 .45813 .53927 Metetra
.518 .262 .465 r
.45813 .53927 .4645 .4903 .4738 .48735 .4676 .53634 Metetra
.518 .262 .465 r
.4676 .53634 .4738 .48735 .48312 .48439 .4771 .53341 Metetra
.518 .262 .465 r
.4771 .53341 .48312 .48439 .49248 .48142 .48663 .53046 Metetra
.518 .262 .465 r
.48663 .53046 .49248 .48142 .50187 .47844 .49619 .52751 Metetra
.518 .262 .465 r
.49619 .52751 .50187 .47844 .51129 .47544 .50579 .52454 Metetra
.518 .262 .465 r
.50579 .52454 .51129 .47544 .52074 .47244 .51542 .52157 Metetra
.518 .262 .465 r
.51542 .52157 .52074 .47244 .53023 .46943 .52509 .51858 Metetra
.518 .262 .465 r
.52509 .51858 .53023 .46943 .53975 .46641 .53479 .51559 Metetra
.518 .262 .465 r
.53479 .51559 .53975 .46641 .5493 .46337 .54452 .51258 Metetra
.518 .262 .465 r
.54452 .51258 .5493 .46337 .55888 .46033 .55429 .50956 Metetra
.518 .262 .465 r
.55429 .50956 .55888 .46033 .5685 .45727 .56409 .50653 Metetra
.518 .262 .465 r
.56409 .50653 .5685 .45727 .57815 .45421 .57393 .50349 Metetra
.518 .262 .465 r
.57393 .50349 .57815 .45421 .58784 .45113 .58381 .50044 Metetra
.518 .262 .465 r
.58381 .50044 .58784 .45113 .59756 .44805 .59371 .49738 Metetra
.518 .262 .465 r
.59371 .49738 .59756 .44805 .60731 .44495 .60366 .49431 Metetra
.518 .262 .465 r
.60366 .49431 .60731 .44495 .6171 .44184 .61364 .49123 Metetra
.518 .262 .465 r
.61364 .49123 .6171 .44184 .62692 .43872 .62365 .48813 Metetra
.518 .262 .465 r
.62365 .48813 .62692 .43872 .63678 .43559 .6337 .48503 Metetra
.518 .262 .465 r
.6337 .48503 .63678 .43559 .64667 .43245 .64379 .48191 Metetra
.518 .262 .465 r
.64379 .48191 .64667 .43245 .6566 .4293 .65391 .47879 Metetra
.518 .262 .465 r
.65391 .47879 .6566 .4293 .66656 .42613 .66407 .47565 Metetra
.518 .262 .465 r
.66407 .47565 .66656 .42613 .67655 .42296 .67427 .4725 Metetra
.518 .262 .465 r
.67427 .4725 .67655 .42296 .68659 .41977 .6845 .46934 Metetra
.518 .262 .465 r
.6845 .46934 .68659 .41977 .69665 .41658 .69477 .46616 Metetra
.518 .262 .465 r
.69477 .46616 .69665 .41658 .70676 .41337 .70508 .46298 Metetra
.518 .262 .465 r
.70508 .46298 .70676 .41337 .7169 .41015 .71543 .45978 Metetra
.518 .262 .465 r
.71543 .45978 .7169 .41015 .72707 .40692 .72581 .45657 Metetra
.518 .262 .465 r
.72581 .45657 .72707 .40692 .73729 .40367 .73623 .45335 Metetra
.518 .262 .465 r
.73623 .45335 .73729 .40367 .74754 .40042 .74669 .45012 Metetra
.518 .262 .465 r
.74669 .45012 .74754 .40042 .75782 .39715 .75719 .44688 Metetra
.518 .262 .465 r
.75719 .44688 .75782 .39715 .76815 .39387 .76773 .44362 Metetra
.518 .262 .465 r
.76773 .44362 .76815 .39387 .77851 .39058 .7783 .44036 Metetra
.518 .262 .465 r
.7783 .44036 .77851 .39058 .7889 .38728 .78892 .43708 Metetra
.518 .262 .465 r
.78892 .43708 .7889 .38728 .79934 .38397 .79957 .43379 Metetra
.518 .262 .465 r
.79957 .43379 .79934 .38397 .80981 .38064 .81026 .43048 Metetra
.518 .262 .465 r
.81026 .43048 .80981 .38064 .82032 .3773 .82099 .42717 Metetra
.518 .262 .465 r
.82099 .42717 .82032 .3773 .83087 .37395 .83177 .42384 Metetra
.518 .262 .465 r
.83177 .42384 .83087 .37395 .84146 .37059 .84258 .4205 Metetra
.518 .262 .465 r
.84258 .4205 .84146 .37059 .85209 .36721 .85343 .41715 Metetra
.518 .262 .465 r
.85343 .41715 .85209 .36721 .86275 .36383 .86433 .41378 Metetra
.518 .262 .465 r
.86433 .41378 .86275 .36383 .87346 .36043 .87526 .4104 Metetra
.518 .262 .465 r
.87526 .4104 .87346 .36043 .8842 .35702 .88624 .40701 Metetra
.488 .198 .4 r
.2584 .62562 .26671 .59841 .27552 .59568 .26731 .62291 Metetra
.488 .198 .4 r
.26731 .62291 .27552 .59568 .28436 .59295 .27624 .62019 Metetra
.488 .198 .4 r
.27624 .62019 .28436 .59295 .29323 .59021 .28521 .61747 Metetra
.488 .198 .4 r
.28521 .61747 .29323 .59021 .30212 .58746 .29421 .61473 Metetra
.488 .198 .4 r
.29421 .61473 .30212 .58746 .31105 .58471 .30324 .61198 Metetra
.488 .198 .4 r
.30324 .61198 .31105 .58471 .32001 .58194 .31229 .60923 Metetra
.488 .198 .4 r
.31229 .60923 .32001 .58194 .329 .57916 .32139 .60646 Metetra
.488 .198 .4 r
.32139 .60646 .329 .57916 .33802 .57637 .33051 .60369 Metetra
.488 .198 .4 r
.33051 .60369 .33802 .57637 .34707 .57358 .33966 .6009 Metetra
.488 .198 .4 r
.33966 .6009 .34707 .57358 .35615 .57077 .34885 .59811 Metetra
.488 .198 .4 r
.34885 .59811 .35615 .57077 .36527 .56796 .35806 .5953 Metetra
.488 .198 .4 r
.35806 .5953 .36527 .56796 .37441 .56513 .36731 .59249 Metetra
.488 .198 .4 r
.36731 .59249 .37441 .56513 .38358 .5623 .37659 .58967 Metetra
.488 .198 .4 r
.37659 .58967 .38358 .5623 .39279 .55945 .3859 .58683 Metetra
.488 .198 .4 r
.3859 .58683 .39279 .55945 .40203 .5566 .39525 .58399 Metetra
.488 .198 .4 r
.39525 .58399 .40203 .5566 .4113 .55374 .40463 .58114 Metetra
.488 .198 .4 r
.40463 .58114 .4113 .55374 .4206 .55086 .41404 .57827 Metetra
.488 .198 .4 r
.41404 .57827 .4206 .55086 .42994 .54798 .42348 .5754 Metetra
.488 .198 .4 r
.42348 .5754 .42994 .54798 .4393 .54509 .43296 .57252 Metetra
.488 .198 .4 r
.43296 .57252 .4393 .54509 .4487 .54218 .44247 .56962 Metetra
.488 .198 .4 r
.44247 .56962 .4487 .54218 .45813 .53927 .45202 .56672 Metetra
.488 .198 .4 r
.45202 .56672 .45813 .53927 .4676 .53634 .46159 .56381 Metetra
.488 .198 .4 r
.46159 .56381 .4676 .53634 .4771 .53341 .47121 .56088 Metetra
.488 .198 .4 r
.47121 .56088 .4771 .53341 .48663 .53046 .48085 .55795 Metetra
.488 .198 .4 r
.48085 .55795 .48663 .53046 .49619 .52751 .49053 .555 Metetra
.488 .198 .4 r
.49053 .555 .49619 .52751 .50579 .52454 .50024 .55205 Metetra
.488 .198 .4 r
.50024 .55205 .50579 .52454 .51542 .52157 .50999 .54908 Metetra
.488 .198 .4 r
.50999 .54908 .51542 .52157 .52509 .51858 .51978 .5461 Metetra
.488 .198 .4 r
.51978 .5461 .52509 .51858 .53479 .51559 .5296 .54312 Metetra
.488 .198 .4 r
.5296 .54312 .53479 .51559 .54452 .51258 .53945 .54012 Metetra
.488 .198 .4 r
.53945 .54012 .54452 .51258 .55429 .50956 .54934 .53711 Metetra
.488 .198 .4 r
.54934 .53711 .55429 .50956 .56409 .50653 .55926 .53409 Metetra
.488 .198 .4 r
.55926 .53409 .56409 .50653 .57393 .50349 .56922 .53106 Metetra
.488 .198 .4 r
.56922 .53106 .57393 .50349 .58381 .50044 .57922 .52802 Metetra
.488 .198 .4 r
.57922 .52802 .58381 .50044 .59371 .49738 .58925 .52497 Metetra
.488 .198 .4 r
.58925 .52497 .59371 .49738 .60366 .49431 .59932 .52191 Metetra
.488 .198 .4 r
.59932 .52191 .60366 .49431 .61364 .49123 .60943 .51883 Metetra
.488 .198 .4 r
.60943 .51883 .61364 .49123 .62365 .48813 .61957 .51575 Metetra
.488 .198 .4 r
.61957 .51575 .62365 .48813 .6337 .48503 .62975 .51265 Metetra
.488 .198 .4 r
.62975 .51265 .6337 .48503 .64379 .48191 .63996 .50954 Metetra
.488 .198 .4 r
.63996 .50954 .64379 .48191 .65391 .47879 .65022 .50642 Metetra
.488 .198 .4 r
.65022 .50642 .65391 .47879 .66407 .47565 .66051 .50329 Metetra
.488 .198 .4 r
.66051 .50329 .66407 .47565 .67427 .4725 .67084 .50015 Metetra
.488 .198 .4 r
.67084 .50015 .67427 .4725 .6845 .46934 .6812 .497 Metetra
.488 .198 .4 r
.6812 .497 .6845 .46934 .69477 .46616 .69161 .49383 Metetra
.488 .198 .4 r
.69161 .49383 .69477 .46616 .70508 .46298 .70205 .49065 Metetra
.488 .198 .4 r
.70205 .49065 .70508 .46298 .71543 .45978 .71253 .48746 Metetra
.488 .198 .4 r
.71253 .48746 .71543 .45978 .72581 .45657 .72305 .48426 Metetra
.488 .198 .4 r
.72305 .48426 .72581 .45657 .73623 .45335 .73361 .48105 Metetra
.488 .198 .4 r
.73361 .48105 .73623 .45335 .74669 .45012 .74421 .47783 Metetra
.488 .198 .4 r
.74421 .47783 .74669 .45012 .75719 .44688 .75485 .47459 Metetra
.488 .198 .4 r
.75485 .47459 .75719 .44688 .76773 .44362 .76552 .47134 Metetra
.488 .198 .4 r
.76552 .47134 .76773 .44362 .7783 .44036 .77624 .46808 Metetra
.488 .198 .4 r
.77624 .46808 .7783 .44036 .78892 .43708 .787 .46481 Metetra
.488 .198 .4 r
.787 .46481 .78892 .43708 .79957 .43379 .7978 .46153 Metetra
.488 .198 .4 r
.7978 .46153 .79957 .43379 .81026 .43048 .80864 .45823 Metetra
.488 .198 .4 r
.80864 .45823 .81026 .43048 .82099 .42717 .81951 .45492 Metetra
.488 .198 .4 r
.81951 .45492 .82099 .42717 .83177 .42384 .83043 .4516 Metetra
.488 .198 .4 r
.83043 .4516 .83177 .42384 .84258 .4205 .8414 .44826 Metetra
.488 .198 .4 r
.8414 .44826 .84258 .4205 .85343 .41715 .8524 .44491 Metetra
.488 .198 .4 r
.8524 .44491 .85343 .41715 .86433 .41378 .86344 .44155 Metetra
.488 .198 .4 r
.86344 .44155 .86433 .41378 .87526 .4104 .87453 .43818 Metetra
.488 .198 .4 r
.87453 .43818 .87526 .4104 .88624 .40701 .88566 .4348 Metetra
.452 .13 .328 r
.2506 .64438 .2584 .62562 .26731 .62291 .25959 .64167 Metetra
.452 .13 .328 r
.25959 .64167 .26731 .62291 .27624 .62019 .2686 .63896 Metetra
.452 .13 .328 r
.2686 .63896 .27624 .62019 .28521 .61747 .27765 .63624 Metetra
.452 .13 .328 r
.27765 .63624 .28521 .61747 .29421 .61473 .28672 .6335 Metetra
.452 .13 .328 r
.28672 .6335 .29421 .61473 .30324 .61198 .29583 .63076 Metetra
.452 .13 .328 r
.29583 .63076 .30324 .61198 .31229 .60923 .30497 .62801 Metetra
.452 .13 .328 r
.30497 .62801 .31229 .60923 .32139 .60646 .31414 .62525 Metetra
.452 .13 .328 r
.31414 .62525 .32139 .60646 .33051 .60369 .32334 .62248 Metetra
.452 .13 .328 r
.32334 .62248 .33051 .60369 .33966 .6009 .33257 .6197 Metetra
.452 .13 .328 r
.33257 .6197 .33966 .6009 .34885 .59811 .34184 .61691 Metetra
.452 .13 .328 r
.34184 .61691 .34885 .59811 .35806 .5953 .35114 .61411 Metetra
.452 .13 .328 r
.35114 .61411 .35806 .5953 .36731 .59249 .36047 .6113 Metetra
.452 .13 .328 r
.36047 .6113 .36731 .59249 .37659 .58967 .36984 .60848 Metetra
.452 .13 .328 r
.36984 .60848 .37659 .58967 .3859 .58683 .37923 .60565 Metetra
.452 .13 .328 r
.37923 .60565 .3859 .58683 .39525 .58399 .38866 .60281 Metetra
.452 .13 .328 r
.38866 .60281 .39525 .58399 .40463 .58114 .39813 .59996 Metetra
.452 .13 .328 r
.39813 .59996 .40463 .58114 .41404 .57827 .40762 .5971 Metetra
.452 .13 .328 r
.40762 .5971 .41404 .57827 .42348 .5754 .41716 .59423 Metetra
.452 .13 .328 r
.41716 .59423 .42348 .5754 .43296 .57252 .42672 .59135 Metetra
.452 .13 .328 r
.42672 .59135 .43296 .57252 .44247 .56962 .43632 .58846 Metetra
.452 .13 .328 r
.43632 .58846 .44247 .56962 .45202 .56672 .44595 .58556 Metetra
.452 .13 .328 r
.44595 .58556 .45202 .56672 .46159 .56381 .45562 .58265 Metetra
.452 .13 .328 r
.45562 .58265 .46159 .56381 .47121 .56088 .46532 .57973 Metetra
.452 .13 .328 r
.46532 .57973 .47121 .56088 .48085 .55795 .47506 .5768 Metetra
.452 .13 .328 r
.47506 .5768 .48085 .55795 .49053 .555 .48483 .57386 Metetra
.452 .13 .328 r
.48483 .57386 .49053 .555 .50024 .55205 .49463 .5709 Metetra
.452 .13 .328 r
.49463 .5709 .50024 .55205 .50999 .54908 .50448 .56794 Metetra
.452 .13 .328 r
.50448 .56794 .50999 .54908 .51978 .5461 .51435 .56497 Metetra
.452 .13 .328 r
.51435 .56497 .51978 .5461 .5296 .54312 .52427 .56198 Metetra
.452 .13 .328 r
.52427 .56198 .5296 .54312 .53945 .54012 .53421 .55899 Metetra
.452 .13 .328 r
.53421 .55899 .53945 .54012 .54934 .53711 .5442 .55598 Metetra
.452 .13 .328 r
.5442 .55598 .54934 .53711 .55926 .53409 .55422 .55296 Metetra
.452 .13 .328 r
.55422 .55296 .55926 .53409 .56922 .53106 .56428 .54994 Metetra
.452 .13 .328 r
.56428 .54994 .56922 .53106 .57922 .52802 .57437 .5469 Metetra
.452 .13 .328 r
.57437 .5469 .57922 .52802 .58925 .52497 .5845 .54385 Metetra
.452 .13 .328 r
.5845 .54385 .58925 .52497 .59932 .52191 .59467 .54078 Metetra
.452 .13 .328 r
.59467 .54078 .59932 .52191 .60943 .51883 .60488 .53771 Metetra
.452 .13 .328 r
.60488 .53771 .60943 .51883 .61957 .51575 .61512 .53463 Metetra
.452 .13 .328 r
.61512 .53463 .61957 .51575 .62975 .51265 .6254 .53153 Metetra
.452 .13 .328 r
.6254 .53153 .62975 .51265 .63996 .50954 .63572 .52843 Metetra
.452 .13 .328 r
.63572 .52843 .63996 .50954 .65022 .50642 .64608 .52531 Metetra
.452 .13 .328 r
.64608 .52531 .65022 .50642 .66051 .50329 .65647 .52218 Metetra
.452 .13 .328 r
.65647 .52218 .66051 .50329 .67084 .50015 .6669 .51904 Metetra
.452 .13 .328 r
.6669 .51904 .67084 .50015 .6812 .497 .67738 .51588 Metetra
.452 .13 .328 r
.67738 .51588 .6812 .497 .69161 .49383 .68789 .51272 Metetra
.452 .13 .328 r
.68789 .51272 .69161 .49383 .70205 .49065 .69844 .50954 Metetra
.452 .13 .328 r
.69844 .50954 .70205 .49065 .71253 .48746 .70903 .50635 Metetra
.452 .13 .328 r
.70903 .50635 .71253 .48746 .72305 .48426 .71966 .50315 Metetra
.452 .13 .328 r
.71966 .50315 .72305 .48426 .73361 .48105 .73032 .49994 Metetra
.452 .13 .328 r
.73032 .49994 .73361 .48105 .74421 .47783 .74103 .49672 Metetra
.452 .13 .328 r
.74103 .49672 .74421 .47783 .75485 .47459 .75178 .49348 Metetra
.452 .13 .328 r
.75178 .49348 .75485 .47459 .76552 .47134 .76257 .49023 Metetra
.452 .13 .328 r
.76257 .49023 .76552 .47134 .77624 .46808 .7734 .48697 Metetra
.452 .13 .328 r
.7734 .48697 .77624 .46808 .787 .46481 .78427 .4837 Metetra
.452 .13 .328 r
.78427 .4837 .787 .46481 .7978 .46153 .79519 .48041 Metetra
.452 .13 .328 r
.79519 .48041 .7978 .46153 .80864 .45823 .80614 .47711 Metetra
.452 .13 .328 r
.80614 .47711 .80864 .45823 .81951 .45492 .81714 .4738 Metetra
.452 .13 .328 r
.81714 .4738 .81951 .45492 .83043 .4516 .82817 .47048 Metetra
.452 .13 .328 r
.82817 .47048 .83043 .4516 .8414 .44826 .83925 .46714 Metetra
.452 .13 .328 r
.83925 .46714 .8414 .44826 .8524 .44491 .85038 .4638 Metetra
.452 .13 .328 r
.85038 .4638 .8524 .44491 .86344 .44155 .86154 .46043 Metetra
.452 .13 .328 r
.86154 .46043 .86344 .44155 .87453 .43818 .87275 .45706 Metetra
.452 .13 .328 r
.87275 .45706 .87453 .43818 .88566 .4348 .884 .45367 Metetra
.355 0 .144 r
.24335 .65486 .2506 .64438 .25959 .64167 .25239 .65215 Metetra
.355 0 .144 r
.25239 .65215 .25959 .64167 .2686 .63896 .26146 .64943 Metetra
.355 0 .144 r
.26146 .64943 .2686 .63896 .27765 .63624 .27056 .64671 Metetra
.355 0 .144 r
.27056 .64671 .27765 .63624 .28672 .6335 .2797 .64397 Metetra
.355 0 .144 r
.2797 .64397 .28672 .6335 .29583 .63076 .28886 .64123 Metetra
.355 0 .144 r
.28886 .64123 .29583 .63076 .30497 .62801 .29806 .63847 Metetra
.355 0 .144 r
.29806 .63847 .30497 .62801 .31414 .62525 .30729 .63571 Metetra
.355 0 .144 r
.30729 .63571 .31414 .62525 .32334 .62248 .31655 .63293 Metetra
.355 0 .144 r
.31655 .63293 .32334 .62248 .33257 .6197 .32584 .63015 Metetra
.355 0 .144 r
.32584 .63015 .33257 .6197 .34184 .61691 .33517 .62736 Metetra
.355 0 .144 r
.33517 .62736 .34184 .61691 .35114 .61411 .34453 .62455 Metetra
.355 0 .144 r
.34453 .62455 .35114 .61411 .36047 .6113 .35392 .62174 Metetra
.355 0 .144 r
.35392 .62174 .36047 .6113 .36984 .60848 .36335 .61892 Metetra
.355 0 .144 r
.36335 .61892 .36984 .60848 .37923 .60565 .37281 .61609 Metetra
.355 0 .144 r
.37281 .61609 .37923 .60565 .38866 .60281 .3823 .61324 Metetra
.355 0 .144 r
.3823 .61324 .38866 .60281 .39813 .59996 .39183 .61039 Metetra
.355 0 .144 r
.39183 .61039 .39813 .59996 .40762 .5971 .40139 .60753 Metetra
.355 0 .144 r
.40139 .60753 .40762 .5971 .41716 .59423 .41099 .60465 Metetra
.355 0 .144 r
.41099 .60465 .41716 .59423 .42672 .59135 .42062 .60177 Metetra
.355 0 .144 r
.42062 .60177 .42672 .59135 .43632 .58846 .43028 .59887 Metetra
.355 0 .144 r
.43028 .59887 .43632 .58846 .44595 .58556 .43998 .59597 Metetra
.355 0 .144 r
.43998 .59597 .44595 .58556 .45562 .58265 .44971 .59305 Metetra
.355 0 .144 r
.44971 .59305 .45562 .58265 .46532 .57973 .45948 .59013 Metetra
.355 0 .144 r
.45948 .59013 .46532 .57973 .47506 .5768 .46928 .58719 Metetra
.355 0 .144 r
.46928 .58719 .47506 .5768 .48483 .57386 .47912 .58424 Metetra
.355 0 .144 r
.47912 .58424 .48483 .57386 .49463 .5709 .489 .58129 Metetra
.355 0 .144 r
.489 .58129 .49463 .5709 .50448 .56794 .49891 .57832 Metetra
.355 0 .144 r
.49891 .57832 .50448 .56794 .51435 .56497 .50886 .57534 Metetra
.355 0 .144 r
.50886 .57534 .51435 .56497 .52427 .56198 .51884 .57235 Metetra
.355 0 .144 r
.51884 .57235 .52427 .56198 .53421 .55899 .52886 .56935 Metetra
.355 0 .144 r
.52886 .56935 .53421 .55899 .5442 .55598 .53891 .56634 Metetra
.355 0 .144 r
.53891 .56634 .5442 .55598 .55422 .55296 .54901 .56331 Metetra
.355 0 .144 r
.54901 .56331 .55422 .55296 .56428 .54994 .55914 .56028 Metetra
.355 0 .144 r
.55914 .56028 .56428 .54994 .57437 .5469 .5693 .55724 Metetra
.355 0 .144 r
.5693 .55724 .57437 .5469 .5845 .54385 .57951 .55418 Metetra
.355 0 .144 r
.57951 .55418 .5845 .54385 .59467 .54078 .58975 .55111 Metetra
.355 0 .144 r
.58975 .55111 .59467 .54078 .60488 .53771 .60003 .54803 Metetra
.355 0 .144 r
.60003 .54803 .60488 .53771 .61512 .53463 .61035 .54494 Metetra
.355 0 .144 r
.61035 .54494 .61512 .53463 .6254 .53153 .6207 .54184 Metetra
.355 0 .144 r
.6207 .54184 .6254 .53153 .63572 .52843 .6311 .53873 Metetra
.355 0 .144 r
.6311 .53873 .63572 .52843 .64608 .52531 .64153 .5356 Metetra
.355 0 .144 r
.64153 .5356 .64608 .52531 .65647 .52218 .652 .53247 Metetra
.355 0 .144 r
.652 .53247 .65647 .52218 .6669 .51904 .66251 .52932 Metetra
.355 0 .144 r
.66251 .52932 .6669 .51904 .67738 .51588 .67306 .52616 Metetra
.355 0 .144 r
.67306 .52616 .67738 .51588 .68789 .51272 .68365 .52299 Metetra
.355 0 .144 r
.68365 .52299 .68789 .51272 .69844 .50954 .69428 .5198 Metetra
.355 0 .144 r
.69428 .5198 .69844 .50954 .70903 .50635 .70495 .51661 Metetra
.355 0 .144 r
.70495 .51661 .70903 .50635 .71966 .50315 .71567 .5134 Metetra
.355 0 .144 r
.71567 .5134 .71966 .50315 .73032 .49994 .72642 .51018 Metetra
.355 0 .144 r
.72642 .51018 .73032 .49994 .74103 .49672 .73721 .50695 Metetra
.355 0 .144 r
.73721 .50695 .74103 .49672 .75178 .49348 .74804 .5037 Metetra
.355 0 .144 r
.74804 .5037 .75178 .49348 .76257 .49023 .75891 .50045 Metetra
.355 0 .144 r
.75891 .50045 .76257 .49023 .7734 .48697 .76983 .49718 Metetra
.355 0 .144 r
.76983 .49718 .7734 .48697 .78427 .4837 .78078 .4939 Metetra
.355 0 .144 r
.78078 .4939 .78427 .4837 .79519 .48041 .79178 .4906 Metetra
.355 0 .144 r
.79178 .4906 .79519 .48041 .80614 .47711 .80282 .4873 Metetra
.355 0 .144 r
.80282 .4873 .80614 .47711 .81714 .4738 .81391 .48398 Metetra
.355 0 .144 r
.81391 .48398 .81714 .4738 .82817 .47048 .82503 .48065 Metetra
.355 0 .144 r
.82503 .48065 .82817 .47048 .83925 .46714 .8362 .4773 Metetra
.355 0 .144 r
.8362 .4773 .83925 .46714 .85038 .4638 .84741 .47394 Metetra
.355 0 .144 r
.84741 .47394 .85038 .4638 .86154 .46043 .85867 .47057 Metetra
.355 0 .144 r
.85867 .47057 .86154 .46043 .87275 .45706 .86997 .46719 Metetra
.355 0 .144 r
.86997 .46719 .87275 .45706 .884 .45367 .88131 .46379 Metetra
.252 0 0 r
.23627 .66212 .24335 .65486 .25239 .65215 .24535 .65941 Metetra
.252 0 0 r
.24535 .65941 .25239 .65215 .26146 .64943 .25447 .65669 Metetra
.252 0 0 r
.25447 .65669 .26146 .64943 .27056 .64671 .26362 .65395 Metetra
.252 0 0 r
.26362 .65395 .27056 .64671 .2797 .64397 .27281 .65121 Metetra
.252 0 0 r
.27281 .65121 .2797 .64397 .28886 .64123 .28202 .64846 Metetra
.252 0 0 r
.28202 .64846 .28886 .64123 .29806 .63847 .29127 .6457 Metetra
.252 0 0 r
.29127 .6457 .29806 .63847 .30729 .63571 .30055 .64293 Metetra
.252 0 0 r
.30055 .64293 .30729 .63571 .31655 .63293 .30986 .64015 Metetra
.252 0 0 r
.30986 .64015 .31655 .63293 .32584 .63015 .31921 .63736 Metetra
.252 0 0 r
.31921 .63736 .32584 .63015 .33517 .62736 .32859 .63456 Metetra
.252 0 0 r
.32859 .63456 .33517 .62736 .34453 .62455 .338 .63175 Metetra
.252 0 0 r
.338 .63175 .34453 .62455 .35392 .62174 .34745 .62893 Metetra
.252 0 0 r
.34745 .62893 .35392 .62174 .36335 .61892 .35693 .6261 Metetra
.252 0 0 r
.35693 .6261 .36335 .61892 .37281 .61609 .36644 .62326 Metetra
.252 0 0 r
.36644 .62326 .37281 .61609 .3823 .61324 .37599 .62041 Metetra
.252 0 0 r
.37599 .62041 .3823 .61324 .39183 .61039 .38557 .61755 Metetra
.252 0 0 r
.38557 .61755 .39183 .61039 .40139 .60753 .39519 .61468 Metetra
.252 0 0 r
.39519 .61468 .40139 .60753 .41099 .60465 .40484 .6118 Metetra
.252 0 0 r
.40484 .6118 .41099 .60465 .42062 .60177 .41452 .60891 Metetra
.252 0 0 r
.41452 .60891 .42062 .60177 .43028 .59887 .42425 .60601 Metetra
.252 0 0 r
.42425 .60601 .43028 .59887 .43998 .59597 .434 .60309 Metetra
.252 0 0 r
.434 .60309 .43998 .59597 .44971 .59305 .44379 .60017 Metetra
.252 0 0 r
.44379 .60017 .44971 .59305 .45948 .59013 .45362 .59724 Metetra
.252 0 0 r
.45362 .59724 .45948 .59013 .46928 .58719 .46348 .59429 Metetra
.252 0 0 r
.46348 .59429 .46928 .58719 .47912 .58424 .47338 .59134 Metetra
.252 0 0 r
.47338 .59134 .47912 .58424 .489 .58129 .48331 .58837 Metetra
.252 0 0 r
.48331 .58837 .489 .58129 .49891 .57832 .49328 .5854 Metetra
.252 0 0 r
.49328 .5854 .49891 .57832 .50886 .57534 .50329 .58241 Metetra
.252 0 0 r
.50329 .58241 .50886 .57534 .51884 .57235 .51333 .57941 Metetra
.252 0 0 r
.51333 .57941 .51884 .57235 .52886 .56935 .52341 .5764 Metetra
.252 0 0 r
.52341 .5764 .52886 .56935 .53891 .56634 .53353 .57338 Metetra
.252 0 0 r
.53353 .57338 .53891 .56634 .54901 .56331 .54369 .57035 Metetra
.252 0 0 r
.54369 .57035 .54901 .56331 .55914 .56028 .55388 .56731 Metetra
.252 0 0 r
.55388 .56731 .55914 .56028 .5693 .55724 .56411 .56426 Metetra
.252 0 0 r
.56411 .56426 .5693 .55724 .57951 .55418 .57438 .56119 Metetra
.252 0 0 r
.57438 .56119 .57951 .55418 .58975 .55111 .58468 .55811 Metetra
.252 0 0 r
.58468 .55811 .58975 .55111 .60003 .54803 .59503 .55503 Metetra
.252 0 0 r
.59503 .55503 .60003 .54803 .61035 .54494 .60541 .55193 Metetra
.252 0 0 r
.60541 .55193 .61035 .54494 .6207 .54184 .61583 .54882 Metetra
.252 0 0 r
.61583 .54882 .6207 .54184 .6311 .53873 .62629 .54569 Metetra
.252 0 0 r
.62629 .54569 .6311 .53873 .64153 .5356 .63679 .54256 Metetra
.252 0 0 r
.63679 .54256 .64153 .5356 .652 .53247 .64733 .53941 Metetra
.252 0 0 r
.64733 .53941 .652 .53247 .66251 .52932 .65791 .53625 Metetra
.252 0 0 r
.65791 .53625 .66251 .52932 .67306 .52616 .66853 .53308 Metetra
.252 0 0 r
.66853 .53308 .67306 .52616 .68365 .52299 .67919 .5299 Metetra
.252 0 0 r
.67919 .5299 .68365 .52299 .69428 .5198 .68989 .52671 Metetra
.252 0 0 r
.68989 .52671 .69428 .5198 .70495 .51661 .70063 .5235 Metetra
.252 0 0 r
.70063 .5235 .70495 .51661 .71567 .5134 .71141 .52028 Metetra
.252 0 0 r
.71141 .52028 .71567 .5134 .72642 .51018 .72223 .51705 Metetra
.252 0 0 r
.72223 .51705 .72642 .51018 .73721 .50695 .7331 .51381 Metetra
.252 0 0 r
.7331 .51381 .73721 .50695 .74804 .5037 .744 .51056 Metetra
.252 0 0 r
.744 .51056 .74804 .5037 .75891 .50045 .75495 .50729 Metetra
.252 0 0 r
.75495 .50729 .75891 .50045 .76983 .49718 .76594 .50401 Metetra
.252 0 0 r
.76594 .50401 .76983 .49718 .78078 .4939 .77697 .50072 Metetra
.252 0 0 r
.77697 .50072 .78078 .4939 .79178 .4906 .78804 .49741 Metetra
.252 0 0 r
.78804 .49741 .79178 .4906 .80282 .4873 .79916 .49409 Metetra
.252 0 0 r
.79916 .49409 .80282 .4873 .81391 .48398 .81031 .49076 Metetra
.252 0 0 r
.81031 .49076 .81391 .48398 .82503 .48065 .82152 .48742 Metetra
.252 0 0 r
.82152 .48742 .82503 .48065 .8362 .4773 .83276 .48406 Metetra
.252 0 0 r
.83276 .48406 .8362 .4773 .84741 .47394 .84405 .48069 Metetra
.252 0 0 r
.84405 .48069 .84741 .47394 .85867 .47057 .85538 .47731 Metetra
.252 0 0 r
.85538 .47731 .85867 .47057 .86997 .46719 .86676 .47391 Metetra
.252 0 0 r
.86676 .47391 .86997 .46719 .88131 .46379 .87818 .4705 Metetra
.2295 .66462 .23627 .66212 .24535 .65941 .23862 .6619 Metetra
.23862 .6619 .24535 .65941 .25447 .65669 .24778 .65917 Metetra
.24778 .65917 .25447 .65669 .26362 .65395 .25697 .65642 Metetra
.25697 .65642 .26362 .65395 .27281 .65121 .26619 .65367 Metetra
.26619 .65367 .27281 .65121 .28202 .64846 .27544 .65091 Metetra
.27544 .65091 .28202 .64846 .29127 .6457 .28473 .64814 Metetra
.28473 .64814 .29127 .6457 .30055 .64293 .29405 .64536 Metetra
.29405 .64536 .30055 .64293 .30986 .64015 .3034 .64257 Metetra
.3034 .64257 .30986 .64015 .31921 .63736 .31279 .63977 Metetra
.31279 .63977 .31921 .63736 .32859 .63456 .32221 .63696 Metetra
.32221 .63696 .32859 .63456 .338 .63175 .33166 .63413 Metetra
.33166 .63413 .338 .63175 .34745 .62893 .34115 .6313 Metetra
.34115 .6313 .34745 .62893 .35693 .6261 .35067 .62846 Metetra
.35067 .62846 .35693 .6261 .36644 .62326 .36022 .62561 Metetra
.36022 .62561 .36644 .62326 .37599 .62041 .36981 .62275 Metetra
.36981 .62275 .37599 .62041 .38557 .61755 .37944 .61988 Metetra
.37944 .61988 .38557 .61755 .39519 .61468 .38909 .617 Metetra
.38909 .617 .39519 .61468 .40484 .6118 .39879 .6141 Metetra
.39879 .6141 .40484 .6118 .41452 .60891 .40852 .6112 Metetra
.40852 .6112 .41452 .60891 .42425 .60601 .41828 .60829 Metetra
.41828 .60829 .42425 .60601 .434 .60309 .42808 .60536 Metetra
.42808 .60536 .434 .60309 .44379 .60017 .43791 .60243 Metetra
.43791 .60243 .44379 .60017 .45362 .59724 .44779 .59948 Metetra
.44779 .59948 .45362 .59724 .46348 .59429 .45769 .59652 Metetra
.45769 .59652 .46348 .59429 .47338 .59134 .46764 .59356 Metetra
.46764 .59356 .47338 .59134 .48331 .58837 .47762 .59058 Metetra
.47762 .59058 .48331 .58837 .49328 .5854 .48763 .58759 Metetra
.48763 .58759 .49328 .5854 .50329 .58241 .49768 .58459 Metetra
.49768 .58459 .50329 .58241 .51333 .57941 .50777 .58158 Metetra
.50777 .58158 .51333 .57941 .52341 .5764 .5179 .57856 Metetra
.5179 .57856 .52341 .5764 .53353 .57338 .52807 .57552 Metetra
.52807 .57552 .53353 .57338 .54369 .57035 .53827 .57248 Metetra
.53827 .57248 .54369 .57035 .55388 .56731 .54851 .56942 Metetra
.54851 .56942 .55388 .56731 .56411 .56426 .55879 .56635 Metetra
.55879 .56635 .56411 .56426 .57438 .56119 .56911 .56328 Metetra
.56911 .56328 .57438 .56119 .58468 .55811 .57946 .56019 Metetra
.57946 .56019 .58468 .55811 .59503 .55503 .58986 .55708 Metetra
.58986 .55708 .59503 .55503 .60541 .55193 .60029 .55397 Metetra
.60029 .55397 .60541 .55193 .61583 .54882 .61076 .55085 Metetra
.61076 .55085 .61583 .54882 .62629 .54569 .62127 .54771 Metetra
.62127 .54771 .62629 .54569 .63679 .54256 .63183 .54456 Metetra
.63183 .54456 .63679 .54256 .64733 .53941 .64242 .5414 Metetra
.64242 .5414 .64733 .53941 .65791 .53625 .65305 .53823 Metetra
.65305 .53823 .65791 .53625 .66853 .53308 .66372 .53504 Metetra
.66372 .53504 .66853 .53308 .67919 .5299 .67443 .53184 Metetra
.67443 .53184 .67919 .5299 .68989 .52671 .68519 .52864 Metetra
.68519 .52864 .68989 .52671 .70063 .5235 .69598 .52541 Metetra
.69598 .52541 .70063 .5235 .71141 .52028 .70682 .52218 Metetra
.70682 .52218 .71141 .52028 .72223 .51705 .71769 .51893 Metetra
.71769 .51893 .72223 .51705 .7331 .51381 .72861 .51568 Metetra
.72861 .51568 .7331 .51381 .744 .51056 .73957 .51241 Metetra
.73957 .51241 .744 .51056 .75495 .50729 .75058 .50912 Metetra
.75058 .50912 .75495 .50729 .76594 .50401 .76162 .50583 Metetra
.76162 .50583 .76594 .50401 .77697 .50072 .77271 .50252 Metetra
.77271 .50252 .77697 .50072 .78804 .49741 .78384 .4992 Metetra
.78384 .4992 .78804 .49741 .79916 .49409 .79501 .49586 Metetra
.79501 .49586 .79916 .49409 .81031 .49076 .80623 .49251 Metetra
.80623 .49251 .81031 .49076 .82152 .48742 .81749 .48915 Metetra
.81749 .48915 .82152 .48742 .83276 .48406 .8288 .48578 Metetra
.8288 .48578 .83276 .48406 .84405 .48069 .84015 .48239 Metetra
.84015 .48239 .84405 .48069 .85538 .47731 .85154 .47899 Metetra
.85154 .47899 .85538 .47731 .86676 .47391 .86298 .47558 Metetra
.86298 .47558 .86676 .47391 .87818 .4705 .87446 .47215 Metetra
.524 .889 .975 r
.22295 .66372 .2295 .66462 .23862 .6619 .2321 .66099 Metetra
.524 .889 .975 r
.2321 .66099 .23862 .6619 .24778 .65917 .24129 .65824 Metetra
.524 .889 .975 r
.24129 .65824 .24778 .65917 .25697 .65642 .25051 .65549 Metetra
.524 .889 .975 r
.25051 .65549 .25697 .65642 .26619 .65367 .25976 .65272 Metetra
.524 .889 .975 r
.25976 .65272 .26619 .65367 .27544 .65091 .26904 .64994 Metetra
.524 .889 .975 r
.26904 .64994 .27544 .65091 .28473 .64814 .27836 .64716 Metetra
.524 .889 .975 r
.27836 .64716 .28473 .64814 .29405 .64536 .28771 .64436 Metetra
.524 .889 .975 r
.28771 .64436 .29405 .64536 .3034 .64257 .29709 .64156 Metetra
.524 .889 .975 r
.29709 .64156 .3034 .64257 .31279 .63977 .30651 .63874 Metetra
.524 .889 .975 r
.30651 .63874 .31279 .63977 .32221 .63696 .31596 .63592 Metetra
.524 .889 .975 r
.31596 .63592 .32221 .63696 .33166 .63413 .32545 .63308 Metetra
.524 .889 .975 r
.32545 .63308 .33166 .63413 .34115 .6313 .33496 .63024 Metetra
.524 .889 .975 r
.33496 .63024 .34115 .6313 .35067 .62846 .34452 .62738 Metetra
.524 .889 .975 r
.34452 .62738 .35067 .62846 .36022 .62561 .3541 .62451 Metetra
.524 .889 .975 r
.3541 .62451 .36022 .62561 .36981 .62275 .36373 .62164 Metetra
.524 .889 .975 r
.36373 .62164 .36981 .62275 .37944 .61988 .37338 .61875 Metetra
.524 .889 .975 r
.37338 .61875 .37944 .61988 .38909 .617 .38307 .61585 Metetra
.524 .889 .975 r
.38307 .61585 .38909 .617 .39879 .6141 .3928 .61294 Metetra
.524 .889 .975 r
.3928 .61294 .39879 .6141 .40852 .6112 .40256 .61003 Metetra
.524 .889 .975 r
.40256 .61003 .40852 .6112 .41828 .60829 .41236 .6071 Metetra
.524 .889 .975 r
.41236 .6071 .41828 .60829 .42808 .60536 .4222 .60416 Metetra
.524 .889 .975 r
.4222 .60416 .42808 .60536 .43791 .60243 .43207 .60121 Metetra
.524 .889 .975 r
.43207 .60121 .43791 .60243 .44779 .59948 .44197 .59824 Metetra
.524 .889 .975 r
.44197 .59824 .44779 .59948 .45769 .59652 .45191 .59527 Metetra
.524 .889 .975 r
.45191 .59527 .45769 .59652 .46764 .59356 .46189 .59229 Metetra
.524 .889 .975 r
.46189 .59229 .46764 .59356 .47762 .59058 .47191 .58929 Metetra
.524 .889 .975 r
.47191 .58929 .47762 .59058 .48763 .58759 .48196 .58629 Metetra
.524 .889 .975 r
.48196 .58629 .48763 .58759 .49768 .58459 .49205 .58327 Metetra
.524 .889 .975 r
.49205 .58327 .49768 .58459 .50777 .58158 .50218 .58024 Metetra
.524 .889 .975 r
.50218 .58024 .50777 .58158 .5179 .57856 .51234 .57721 Metetra
.524 .889 .975 r
.51234 .57721 .5179 .57856 .52807 .57552 .52254 .57416 Metetra
.524 .889 .975 r
.52254 .57416 .52807 .57552 .53827 .57248 .53278 .57109 Metetra
.524 .889 .975 r
.53278 .57109 .53827 .57248 .54851 .56942 .54306 .56802 Metetra
.524 .889 .975 r
.54306 .56802 .54851 .56942 .55879 .56635 .55338 .56494 Metetra
.524 .889 .975 r
.55338 .56494 .55879 .56635 .56911 .56328 .56374 .56184 Metetra
.524 .889 .975 r
.56374 .56184 .56911 .56328 .57946 .56019 .57413 .55873 Metetra
.524 .889 .975 r
.57413 .55873 .57946 .56019 .58986 .55708 .58456 .55561 Metetra
.524 .889 .975 r
.58456 .55561 .58986 .55708 .60029 .55397 .59504 .55248 Metetra
.524 .889 .975 r
.59504 .55248 .60029 .55397 .61076 .55085 .60555 .54934 Metetra
.524 .889 .975 r
.60555 .54934 .61076 .55085 .62127 .54771 .6161 .54618 Metetra
.524 .889 .975 r
.6161 .54618 .62127 .54771 .63183 .54456 .62669 .54302 Metetra
.524 .889 .975 r
.62669 .54302 .63183 .54456 .64242 .5414 .63733 .53984 Metetra
.524 .889 .975 r
.63733 .53984 .64242 .5414 .65305 .53823 .648 .53665 Metetra
.524 .889 .975 r
.648 .53665 .65305 .53823 .66372 .53504 .65871 .53345 Metetra
.524 .889 .975 r
.65871 .53345 .66372 .53504 .67443 .53184 .66947 .53023 Metetra
.524 .889 .975 r
.66947 .53023 .67443 .53184 .68519 .52864 .68026 .527 Metetra
.524 .889 .975 r
.68026 .527 .68519 .52864 .69598 .52541 .6911 .52376 Metetra
.524 .889 .975 r
.6911 .52376 .69598 .52541 .70682 .52218 .70198 .52051 Metetra
.524 .889 .975 r
.70198 .52051 .70682 .52218 .71769 .51893 .7129 .51725 Metetra
.524 .889 .975 r
.7129 .51725 .71769 .51893 .72861 .51568 .72386 .51397 Metetra
.524 .889 .975 r
.72386 .51397 .72861 .51568 .73957 .51241 .73487 .51068 Metetra
.524 .889 .975 r
.73487 .51068 .73957 .51241 .75058 .50912 .74591 .50738 Metetra
.524 .889 .975 r
.74591 .50738 .75058 .50912 .76162 .50583 .757 .50406 Metetra
.524 .889 .975 r
.757 .50406 .76162 .50583 .77271 .50252 .76814 .50073 Metetra
.524 .889 .975 r
.76814 .50073 .77271 .50252 .78384 .4992 .77931 .49739 Metetra
.524 .889 .975 r
.77931 .49739 .78384 .4992 .79501 .49586 .79053 .49404 Metetra
.524 .889 .975 r
.79053 .49404 .79501 .49586 .80623 .49251 .8018 .49067 Metetra
.524 .889 .975 r
.8018 .49067 .80623 .49251 .81749 .48915 .81311 .48729 Metetra
.524 .889 .975 r
.81311 .48729 .81749 .48915 .8288 .48578 .82446 .48389 Metetra
.524 .889 .975 r
.82446 .48389 .8288 .48578 .84015 .48239 .83586 .48049 Metetra
.524 .889 .975 r
.83586 .48049 .84015 .48239 .85154 .47899 .8473 .47706 Metetra
.524 .889 .975 r
.8473 .47706 .85154 .47899 .86298 .47558 .85879 .47363 Metetra
.524 .889 .975 r
.85879 .47363 .86298 .47558 .87446 .47215 .87032 .47018 Metetra
.646 .762 .934 r
.21671 .65866 .22295 .66372 .2321 .66099 .22588 .65591 Metetra
.646 .762 .934 r
.22588 .65591 .2321 .66099 .24129 .65824 .23509 .65315 Metetra
.646 .762 .934 r
.23509 .65315 .24129 .65824 .25051 .65549 .24433 .65037 Metetra
.646 .762 .934 r
.24433 .65037 .25051 .65549 .25976 .65272 .2536 .64759 Metetra
.646 .762 .934 r
.2536 .64759 .25976 .65272 .26904 .64994 .2629 .64479 Metetra
.646 .762 .934 r
.2629 .64479 .26904 .64994 .27836 .64716 .27224 .64199 Metetra
.646 .762 .934 r
.27224 .64199 .27836 .64716 .28771 .64436 .28161 .63918 Metetra
.646 .762 .934 r
.28161 .63918 .28771 .64436 .29709 .64156 .29101 .63635 Metetra
.646 .762 .934 r
.29101 .63635 .29709 .64156 .30651 .63874 .30045 .63352 Metetra
.646 .762 .934 r
.30045 .63352 .30651 .63874 .31596 .63592 .30992 .63067 Metetra
.646 .762 .934 r
.30992 .63067 .31596 .63592 .32545 .63308 .31943 .62782 Metetra
.646 .762 .934 r
.31943 .62782 .32545 .63308 .33496 .63024 .32896 .62495 Metetra
.646 .762 .934 r
.32896 .62495 .33496 .63024 .34452 .62738 .33854 .62208 Metetra
.646 .762 .934 r
.33854 .62208 .34452 .62738 .3541 .62451 .34815 .61919 Metetra
.646 .762 .934 r
.34815 .61919 .3541 .62451 .36373 .62164 .35779 .6163 Metetra
.646 .762 .934 r
.35779 .6163 .36373 .62164 .37338 .61875 .36747 .61339 Metetra
.646 .762 .934 r
.36747 .61339 .37338 .61875 .38307 .61585 .37718 .61048 Metetra
.646 .762 .934 r
.37718 .61048 .38307 .61585 .3928 .61294 .38693 .60755 Metetra
.646 .762 .934 r
.38693 .60755 .3928 .61294 .40256 .61003 .39672 .60461 Metetra
.646 .762 .934 r
.39672 .60461 .40256 .61003 .41236 .6071 .40654 .60166 Metetra
.646 .762 .934 r
.40654 .60166 .41236 .6071 .4222 .60416 .41639 .5987 Metetra
.646 .762 .934 r
.41639 .5987 .4222 .60416 .43207 .60121 .42628 .59573 Metetra
.646 .762 .934 r
.42628 .59573 .43207 .60121 .44197 .59824 .43621 .59275 Metetra
.646 .762 .934 r
.43621 .59275 .44197 .59824 .45191 .59527 .44618 .58976 Metetra
.646 .762 .934 r
.44618 .58976 .45191 .59527 .46189 .59229 .45618 .58675 Metetra
.646 .762 .934 r
.45618 .58675 .46189 .59229 .47191 .58929 .46622 .58374 Metetra
.646 .762 .934 r
.46622 .58374 .47191 .58929 .48196 .58629 .4763 .58071 Metetra
.646 .762 .934 r
.4763 .58071 .48196 .58629 .49205 .58327 .48641 .57767 Metetra
.646 .762 .934 r
.48641 .57767 .49205 .58327 .50218 .58024 .49656 .57463 Metetra
.646 .762 .934 r
.49656 .57463 .50218 .58024 .51234 .57721 .50675 .57157 Metetra
.646 .762 .934 r
.50675 .57157 .51234 .57721 .52254 .57416 .51698 .56849 Metetra
.646 .762 .934 r
.51698 .56849 .52254 .57416 .53278 .57109 .52724 .56541 Metetra
.646 .762 .934 r
.52724 .56541 .53278 .57109 .54306 .56802 .53755 .56232 Metetra
.646 .762 .934 r
.53755 .56232 .54306 .56802 .55338 .56494 .54789 .55921 Metetra
.646 .762 .934 r
.54789 .55921 .55338 .56494 .56374 .56184 .55827 .55609 Metetra
.646 .762 .934 r
.55827 .55609 .56374 .56184 .57413 .55873 .56869 .55296 Metetra
.646 .762 .934 r
.56869 .55296 .57413 .55873 .58456 .55561 .57915 .54982 Metetra
.646 .762 .934 r
.57915 .54982 .58456 .55561 .59504 .55248 .58965 .54667 Metetra
.646 .762 .934 r
.58965 .54667 .59504 .55248 .60555 .54934 .60019 .54351 Metetra
.646 .762 .934 r
.60019 .54351 .60555 .54934 .6161 .54618 .61077 .54033 Metetra
.646 .762 .934 r
.61077 .54033 .6161 .54618 .62669 .54302 .62139 .53714 Metetra
.646 .762 .934 r
.62139 .53714 .62669 .54302 .63733 .53984 .63205 .53394 Metetra
.646 .762 .934 r
.63205 .53394 .63733 .53984 .648 .53665 .64275 .53073 Metetra
.646 .762 .934 r
.64275 .53073 .648 .53665 .65871 .53345 .65349 .5275 Metetra
.646 .762 .934 r
.65349 .5275 .65871 .53345 .66947 .53023 .66427 .52426 Metetra
.646 .762 .934 r
.66427 .52426 .66947 .53023 .68026 .527 .67509 .52101 Metetra
.646 .762 .934 r
.67509 .52101 .68026 .527 .6911 .52376 .68596 .51775 Metetra
.646 .762 .934 r
.68596 .51775 .6911 .52376 .70198 .52051 .69687 .51447 Metetra
.646 .762 .934 r
.69687 .51447 .70198 .52051 .7129 .51725 .70782 .51119 Metetra
.646 .762 .934 r
.70782 .51119 .7129 .51725 .72386 .51397 .71881 .50788 Metetra
.646 .762 .934 r
.71881 .50788 .72386 .51397 .73487 .51068 .72984 .50457 Metetra
.646 .762 .934 r
.72984 .50457 .73487 .51068 .74591 .50738 .74092 .50124 Metetra
.646 .762 .934 r
.74092 .50124 .74591 .50738 .757 .50406 .75204 .4979 Metetra
.646 .762 .934 r
.75204 .4979 .757 .50406 .76814 .50073 .7632 .49455 Metetra
.646 .762 .934 r
.7632 .49455 .76814 .50073 .77931 .49739 .77441 .49119 Metetra
.646 .762 .934 r
.77441 .49119 .77931 .49739 .79053 .49404 .78566 .48781 Metetra
.646 .762 .934 r
.78566 .48781 .79053 .49404 .8018 .49067 .79696 .48442 Metetra
.646 .762 .934 r
.79696 .48442 .8018 .49067 .81311 .48729 .8083 .48101 Metetra
.646 .762 .934 r
.8083 .48101 .81311 .48729 .82446 .48389 .81968 .47759 Metetra
.646 .762 .934 r
.81968 .47759 .82446 .48389 .83586 .48049 .83111 .47416 Metetra
.646 .762 .934 r
.83111 .47416 .83586 .48049 .8473 .47706 .84259 .47071 Metetra
.646 .762 .934 r
.84259 .47071 .8473 .47706 .85879 .47363 .85411 .46725 Metetra
.646 .762 .934 r
.85411 .46725 .85879 .47363 .87032 .47018 .86567 .46378 Metetra
.641 .637 .831 r
.21081 .64942 .21671 .65866 .22588 .65591 .21999 .64664 Metetra
.641 .637 .831 r
.21999 .64664 .22588 .65591 .23509 .65315 .2292 .64386 Metetra
.641 .637 .831 r
.2292 .64386 .23509 .65315 .24433 .65037 .23845 .64106 Metetra
.641 .637 .831 r
.23845 .64106 .24433 .65037 .2536 .64759 .24773 .63825 Metetra
.641 .637 .831 r
.24773 .63825 .2536 .64759 .2629 .64479 .25704 .63544 Metetra
.641 .637 .831 r
.25704 .63544 .2629 .64479 .27224 .64199 .26639 .63261 Metetra
.641 .637 .831 r
.26639 .63261 .27224 .64199 .28161 .63918 .27577 .62978 Metetra
.641 .637 .831 r
.27577 .62978 .28161 .63918 .29101 .63635 .28518 .62693 Metetra
.641 .637 .831 r
.28518 .62693 .29101 .63635 .30045 .63352 .29463 .62407 Metetra
.641 .637 .831 r
.29463 .62407 .30045 .63352 .30992 .63067 .30411 .6212 Metetra
.641 .637 .831 r
.30411 .6212 .30992 .63067 .31943 .62782 .31362 .61833 Metetra
.641 .637 .831 r
.31362 .61833 .31943 .62782 .32896 .62495 .32317 .61544 Metetra
.641 .637 .831 r
.32317 .61544 .32896 .62495 .33854 .62208 .33276 .61254 Metetra
.641 .637 .831 r
.33276 .61254 .33854 .62208 .34815 .61919 .34237 .60963 Metetra
.641 .637 .831 r
.34237 .60963 .34815 .61919 .35779 .6163 .35203 .60671 Metetra
.641 .637 .831 r
.35203 .60671 .35779 .6163 .36747 .61339 .36172 .60378 Metetra
.641 .637 .831 r
.36172 .60378 .36747 .61339 .37718 .61048 .37144 .60084 Metetra
.641 .637 .831 r
.37144 .60084 .37718 .61048 .38693 .60755 .3812 .59789 Metetra
.641 .637 .831 r
.3812 .59789 .38693 .60755 .39672 .60461 .39099 .59493 Metetra
.641 .637 .831 r
.39099 .59493 .39672 .60461 .40654 .60166 .40082 .59195 Metetra
.641 .637 .831 r
.40082 .59195 .40654 .60166 .41639 .5987 .41069 .58897 Metetra
.641 .637 .831 r
.41069 .58897 .41639 .5987 .42628 .59573 .42059 .58598 Metetra
.641 .637 .831 r
.42059 .58598 .42628 .59573 .43621 .59275 .43053 .58297 Metetra
.641 .637 .831 r
.43053 .58297 .43621 .59275 .44618 .58976 .44051 .57995 Metetra
.641 .637 .831 r
.44051 .57995 .44618 .58976 .45618 .58675 .45052 .57692 Metetra
.641 .637 .831 r
.45052 .57692 .45618 .58675 .46622 .58374 .46057 .57388 Metetra
.641 .637 .831 r
.46057 .57388 .46622 .58374 .4763 .58071 .47066 .57083 Metetra
.641 .637 .831 r
.47066 .57083 .4763 .58071 .48641 .57767 .48079 .56777 Metetra
.641 .637 .831 r
.48079 .56777 .48641 .57767 .49656 .57463 .49095 .5647 Metetra
.641 .637 .831 r
.49095 .5647 .49656 .57463 .50675 .57157 .50115 .56161 Metetra
.641 .637 .831 r
.50115 .56161 .50675 .57157 .51698 .56849 .51139 .55852 Metetra
.641 .637 .831 r
.51139 .55852 .51698 .56849 .52724 .56541 .52167 .55541 Metetra
.641 .637 .831 r
.52167 .55541 .52724 .56541 .53755 .56232 .53198 .55229 Metetra
.641 .637 .831 r
.53198 .55229 .53755 .56232 .54789 .55921 .54234 .54916 Metetra
.641 .637 .831 r
.54234 .54916 .54789 .55921 .55827 .55609 .55273 .54601 Metetra
.641 .637 .831 r
.55273 .54601 .55827 .55609 .56869 .55296 .56316 .54286 Metetra
.641 .637 .831 r
.56316 .54286 .56869 .55296 .57915 .54982 .57364 .53969 Metetra
.641 .637 .831 r
.57364 .53969 .57915 .54982 .58965 .54667 .58415 .53651 Metetra
.641 .637 .831 r
.58415 .53651 .58965 .54667 .60019 .54351 .5947 .53332 Metetra
.641 .637 .831 r
.5947 .53332 .60019 .54351 .61077 .54033 .60529 .53012 Metetra
.641 .637 .831 r
.60529 .53012 .61077 .54033 .62139 .53714 .61593 .5269 Metetra
.641 .637 .831 r
.61593 .5269 .62139 .53714 .63205 .53394 .6266 .52367 Metetra
.641 .637 .831 r
.6266 .52367 .63205 .53394 .64275 .53073 .63731 .52043 Metetra
.641 .637 .831 r
.63731 .52043 .64275 .53073 .65349 .5275 .64807 .51718 Metetra
.641 .637 .831 r
.64807 .51718 .65349 .5275 .66427 .52426 .65886 .51392 Metetra
.641 .637 .831 r
.65886 .51392 .66427 .52426 .67509 .52101 .6697 .51064 Metetra
.641 .637 .831 r
.6697 .51064 .67509 .52101 .68596 .51775 .68058 .50735 Metetra
.641 .637 .831 r
.68058 .50735 .68596 .51775 .69687 .51447 .6915 .50405 Metetra
.641 .637 .831 r
.6915 .50405 .69687 .51447 .70782 .51119 .70247 .50073 Metetra
.641 .637 .831 r
.70247 .50073 .70782 .51119 .71881 .50788 .71347 .4974 Metetra
.641 .637 .831 r
.71347 .4974 .71881 .50788 .72984 .50457 .72452 .49406 Metetra
.641 .637 .831 r
.72452 .49406 .72984 .50457 .74092 .50124 .73562 .49071 Metetra
.641 .637 .831 r
.73562 .49071 .74092 .50124 .75204 .4979 .74675 .48734 Metetra
.641 .637 .831 r
.74675 .48734 .75204 .4979 .7632 .49455 .75793 .48396 Metetra
.641 .637 .831 r
.75793 .48396 .7632 .49455 .77441 .49119 .76915 .48056 Metetra
.641 .637 .831 r
.76915 .48056 .77441 .49119 .78566 .48781 .78042 .47716 Metetra
.641 .637 .831 r
.78042 .47716 .78566 .48781 .79696 .48442 .79173 .47374 Metetra
.641 .637 .831 r
.79173 .47374 .79696 .48442 .8083 .48101 .80309 .4703 Metetra
.641 .637 .831 r
.80309 .4703 .8083 .48101 .81968 .47759 .81449 .46685 Metetra
.641 .637 .831 r
.81449 .46685 .81968 .47759 .83111 .47416 .82593 .46339 Metetra
.641 .637 .831 r
.82593 .46339 .83111 .47416 .84259 .47071 .83742 .45992 Metetra
.641 .637 .831 r
.83742 .45992 .84259 .47071 .85411 .46725 .84896 .45643 Metetra
.641 .637 .831 r
.84896 .45643 .85411 .46725 .86567 .46378 .86054 .45292 Metetra
.628 .572 .773 r
.2052 .63672 .21081 .64942 .21999 .64664 .21438 .63391 Metetra
.628 .572 .773 r
.21438 .63391 .21999 .64664 .2292 .64386 .22359 .6311 Metetra
.628 .572 .773 r
.22359 .6311 .2292 .64386 .23845 .64106 .23284 .62828 Metetra
.628 .572 .773 r
.23284 .62828 .23845 .64106 .24773 .63825 .24212 .62545 Metetra
.628 .572 .773 r
.24212 .62545 .24773 .63825 .25704 .63544 .25143 .6226 Metetra
.628 .572 .773 r
.25143 .6226 .25704 .63544 .26639 .63261 .26078 .61975 Metetra
.628 .572 .773 r
.26078 .61975 .26639 .63261 .27577 .62978 .27016 .61689 Metetra
.628 .572 .773 r
.27016 .61689 .27577 .62978 .28518 .62693 .27957 .61402 Metetra
.628 .572 .773 r
.27957 .61402 .28518 .62693 .29463 .62407 .28902 .61113 Metetra
.628 .572 .773 r
.28902 .61113 .29463 .62407 .30411 .6212 .2985 .60824 Metetra
.628 .572 .773 r
.2985 .60824 .30411 .6212 .31362 .61833 .30801 .60534 Metetra
.628 .572 .773 r
.30801 .60534 .31362 .61833 .32317 .61544 .31756 .60242 Metetra
.628 .572 .773 r
.31756 .60242 .32317 .61544 .33276 .61254 .32715 .5995 Metetra
.628 .572 .773 r
.32715 .5995 .33276 .61254 .34237 .60963 .33677 .59656 Metetra
.628 .572 .773 r
.33677 .59656 .34237 .60963 .35203 .60671 .34642 .59361 Metetra
.628 .572 .773 r
.34642 .59361 .35203 .60671 .36172 .60378 .35611 .59066 Metetra
.628 .572 .773 r
.35611 .59066 .36172 .60378 .37144 .60084 .36583 .58769 Metetra
.628 .572 .773 r
.36583 .58769 .37144 .60084 .3812 .59789 .37559 .58471 Metetra
.628 .572 .773 r
.37559 .58471 .3812 .59789 .39099 .59493 .38539 .58172 Metetra
.628 .572 .773 r
.38539 .58172 .39099 .59493 .40082 .59195 .39522 .57872 Metetra
.628 .572 .773 r
.39522 .57872 .40082 .59195 .41069 .58897 .40509 .57571 Metetra
.628 .572 .773 r
.40509 .57571 .41069 .58897 .42059 .58598 .41499 .57269 Metetra
.628 .572 .773 r
.41499 .57269 .42059 .58598 .43053 .58297 .42493 .56965 Metetra
.628 .572 .773 r
.42493 .56965 .43053 .58297 .44051 .57995 .43491 .56661 Metetra
.628 .572 .773 r
.43491 .56661 .44051 .57995 .45052 .57692 .44493 .56355 Metetra
.628 .572 .773 r
.44493 .56355 .45052 .57692 .46057 .57388 .45498 .56048 Metetra
.628 .572 .773 r
.45498 .56048 .46057 .57388 .47066 .57083 .46507 .5574 Metetra
.628 .572 .773 r
.46507 .5574 .47066 .57083 .48079 .56777 .47519 .55431 Metetra
.628 .572 .773 r
.47519 .55431 .48079 .56777 .49095 .5647 .48536 .55121 Metetra
.628 .572 .773 r
.48536 .55121 .49095 .5647 .50115 .56161 .49556 .5481 Metetra
.628 .572 .773 r
.49556 .5481 .50115 .56161 .51139 .55852 .5058 .54497 Metetra
.628 .572 .773 r
.5058 .54497 .51139 .55852 .52167 .55541 .51608 .54183 Metetra
.628 .572 .773 r
.51608 .54183 .52167 .55541 .53198 .55229 .52639 .53869 Metetra
.628 .572 .773 r
.52639 .53869 .53198 .55229 .54234 .54916 .53675 .53552 Metetra
.628 .572 .773 r
.53675 .53552 .54234 .54916 .55273 .54601 .54715 .53235 Metetra
.628 .572 .773 r
.54715 .53235 .55273 .54601 .56316 .54286 .55758 .52917 Metetra
.628 .572 .773 r
.55758 .52917 .56316 .54286 .57364 .53969 .56805 .52597 Metetra
.628 .572 .773 r
.56805 .52597 .57364 .53969 .58415 .53651 .57857 .52276 Metetra
.628 .572 .773 r
.57857 .52276 .58415 .53651 .5947 .53332 .58912 .51954 Metetra
.628 .572 .773 r
.58912 .51954 .5947 .53332 .60529 .53012 .59971 .51631 Metetra
.628 .572 .773 r
.59971 .51631 .60529 .53012 .61593 .5269 .61035 .51306 Metetra
.628 .572 .773 r
.61035 .51306 .61593 .5269 .6266 .52367 .62102 .5098 Metetra
.628 .572 .773 r
.62102 .5098 .6266 .52367 .63731 .52043 .63174 .50653 Metetra
.628 .572 .773 r
.63174 .50653 .63731 .52043 .64807 .51718 .6425 .50325 Metetra
.628 .572 .773 r
.6425 .50325 .64807 .51718 .65886 .51392 .6533 .49995 Metetra
.628 .572 .773 r
.6533 .49995 .65886 .51392 .6697 .51064 .66414 .49665 Metetra
.628 .572 .773 r
.66414 .49665 .6697 .51064 .68058 .50735 .67502 .49332 Metetra
.628 .572 .773 r
.67502 .49332 .68058 .50735 .6915 .50405 .68594 .48999 Metetra
.628 .572 .773 r
.68594 .48999 .6915 .50405 .70247 .50073 .69691 .48664 Metetra
.628 .572 .773 r
.69691 .48664 .70247 .50073 .71347 .4974 .70792 .48328 Metetra
.628 .572 .773 r
.70792 .48328 .71347 .4974 .72452 .49406 .71897 .47991 Metetra
.628 .572 .773 r
.71897 .47991 .72452 .49406 .73562 .49071 .73006 .47652 Metetra
.628 .572 .773 r
.73006 .47652 .73562 .49071 .74675 .48734 .7412 .47313 Metetra
.628 .572 .773 r
.7412 .47313 .74675 .48734 .75793 .48396 .75238 .46971 Metetra
.628 .572 .773 r
.75238 .46971 .75793 .48396 .76915 .48056 .76361 .46629 Metetra
.628 .572 .773 r
.76361 .46629 .76915 .48056 .78042 .47716 .77488 .46285 Metetra
.628 .572 .773 r
.77488 .46285 .78042 .47716 .79173 .47374 .78619 .45939 Metetra
.628 .572 .773 r
.78619 .45939 .79173 .47374 .80309 .4703 .79755 .45593 Metetra
.628 .572 .773 r
.79755 .45593 .80309 .4703 .81449 .46685 .80895 .45245 Metetra
.628 .572 .773 r
.80895 .45245 .81449 .46685 .82593 .46339 .8204 .44895 Metetra
.628 .572 .773 r
.8204 .44895 .82593 .46339 .83742 .45992 .83189 .44545 Metetra
.628 .572 .773 r
.83189 .44545 .83742 .45992 .84896 .45643 .84343 .44192 Metetra
.628 .572 .773 r
.84343 .44192 .84896 .45643 .86054 .45292 .85502 .43839 Metetra
.612 .514 .718 r
.20003 .61914 .2052 .63672 .21438 .63391 .2092 .6163 Metetra
.612 .514 .718 r
.2092 .6163 .21438 .63391 .22359 .6311 .2184 .61346 Metetra
.612 .514 .718 r
.2184 .61346 .22359 .6311 .23284 .62828 .22764 .61061 Metetra
.612 .514 .718 r
.22764 .61061 .23284 .62828 .24212 .62545 .23691 .60775 Metetra
.612 .514 .718 r
.23691 .60775 .24212 .62545 .25143 .6226 .24621 .60487 Metetra
.612 .514 .718 r
.24621 .60487 .25143 .6226 .26078 .61975 .25554 .60199 Metetra
.612 .514 .718 r
.25554 .60199 .26078 .61975 .27016 .61689 .26491 .5991 Metetra
.612 .514 .718 r
.26491 .5991 .27016 .61689 .27957 .61402 .27431 .59619 Metetra
.612 .514 .718 r
.27431 .59619 .27957 .61402 .28902 .61113 .28374 .59328 Metetra
.612 .514 .718 r
.28374 .59328 .28902 .61113 .2985 .60824 .29321 .59035 Metetra
.612 .514 .718 r
.29321 .59035 .2985 .60824 .30801 .60534 .30271 .58742 Metetra
.612 .514 .718 r
.30271 .58742 .30801 .60534 .31756 .60242 .31225 .58447 Metetra
.612 .514 .718 r
.31225 .58447 .31756 .60242 .32715 .5995 .32182 .58151 Metetra
.612 .514 .718 r
.32182 .58151 .32715 .5995 .33677 .59656 .33143 .57855 Metetra
.612 .514 .718 r
.33143 .57855 .33677 .59656 .34642 .59361 .34107 .57557 Metetra
.612 .514 .718 r
.34107 .57557 .34642 .59361 .35611 .59066 .35074 .57258 Metetra
.612 .514 .718 r
.35074 .57258 .35611 .59066 .36583 .58769 .36045 .56958 Metetra
.612 .514 .718 r
.36045 .56958 .36583 .58769 .37559 .58471 .3702 .56657 Metetra
.612 .514 .718 r
.3702 .56657 .37559 .58471 .38539 .58172 .37998 .56355 Metetra
.612 .514 .718 r
.37998 .56355 .38539 .58172 .39522 .57872 .3898 .56051 Metetra
.612 .514 .718 r
.3898 .56051 .39522 .57872 .40509 .57571 .39966 .55747 Metetra
.612 .514 .718 r
.39966 .55747 .40509 .57571 .41499 .57269 .40955 .55442 Metetra
.612 .514 .718 r
.40955 .55442 .41499 .57269 .42493 .56965 .41947 .55135 Metetra
.612 .514 .718 r
.41947 .55135 .42493 .56965 .43491 .56661 .42944 .54827 Metetra
.612 .514 .718 r
.42944 .54827 .43491 .56661 .44493 .56355 .43944 .54518 Metetra
.612 .514 .718 r
.43944 .54518 .44493 .56355 .45498 .56048 .44948 .54208 Metetra
.612 .514 .718 r
.44948 .54208 .45498 .56048 .46507 .5574 .45955 .53897 Metetra
.612 .514 .718 r
.45955 .53897 .46507 .5574 .47519 .55431 .46967 .53584 Metetra
.612 .514 .718 r
.46967 .53584 .47519 .55431 .48536 .55121 .47982 .53271 Metetra
.612 .514 .718 r
.47982 .53271 .48536 .55121 .49556 .5481 .49 .52956 Metetra
.612 .514 .718 r
.49 .52956 .49556 .5481 .5058 .54497 .50023 .5264 Metetra
.612 .514 .718 r
.50023 .5264 .5058 .54497 .51608 .54183 .51049 .52323 Metetra
.612 .514 .718 r
.51049 .52323 .51608 .54183 .52639 .53869 .5208 .52005 Metetra
.612 .514 .718 r
.5208 .52005 .52639 .53869 .53675 .53552 .53114 .51685 Metetra
.612 .514 .718 r
.53114 .51685 .53675 .53552 .54715 .53235 .54152 .51365 Metetra
.612 .514 .718 r
.54152 .51365 .54715 .53235 .55758 .52917 .55194 .51043 Metetra
.612 .514 .718 r
.55194 .51043 .55758 .52917 .56805 .52597 .5624 .5072 Metetra
.612 .514 .718 r
.5624 .5072 .56805 .52597 .57857 .52276 .5729 .50395 Metetra
.612 .514 .718 r
.5729 .50395 .57857 .52276 .58912 .51954 .58344 .5007 Metetra
.612 .514 .718 r
.58344 .5007 .58912 .51954 .59971 .51631 .59402 .49743 Metetra
.612 .514 .718 r
.59402 .49743 .59971 .51631 .61035 .51306 .60464 .49415 Metetra
.612 .514 .718 r
.60464 .49415 .61035 .51306 .62102 .5098 .6153 .49086 Metetra
.612 .514 .718 r
.6153 .49086 .62102 .5098 .63174 .50653 .626 .48755 Metetra
.612 .514 .718 r
.626 .48755 .63174 .50653 .6425 .50325 .63674 .48423 Metetra
.612 .514 .718 r
.63674 .48423 .6425 .50325 .6533 .49995 .64753 .4809 Metetra
.612 .514 .718 r
.64753 .4809 .6533 .49995 .66414 .49665 .65835 .47756 Metetra
.612 .514 .718 r
.65835 .47756 .66414 .49665 .67502 .49332 .66922 .4742 Metetra
.612 .514 .718 r
.66922 .4742 .67502 .49332 .68594 .48999 .68013 .47083 Metetra
.612 .514 .718 r
.68013 .47083 .68594 .48999 .69691 .48664 .69108 .46745 Metetra
.612 .514 .718 r
.69108 .46745 .69691 .48664 .70792 .48328 .70207 .46405 Metetra
.612 .514 .718 r
.70207 .46405 .70792 .48328 .71897 .47991 .71311 .46064 Metetra
.612 .514 .718 r
.71311 .46064 .71897 .47991 .73006 .47652 .72419 .45722 Metetra
.612 .514 .718 r
.72419 .45722 .73006 .47652 .7412 .47313 .73531 .45379 Metetra
.612 .514 .718 r
.73531 .45379 .7412 .47313 .75238 .46971 .74647 .45034 Metetra
.612 .514 .718 r
.74647 .45034 .75238 .46971 .76361 .46629 .75768 .44687 Metetra
.612 .514 .718 r
.75768 .44687 .76361 .46629 .77488 .46285 .76894 .4434 Metetra
.612 .514 .718 r
.76894 .4434 .77488 .46285 .78619 .45939 .78024 .43991 Metetra
.612 .514 .718 r
.78024 .43991 .78619 .45939 .79755 .45593 .79158 .4364 Metetra
.612 .514 .718 r
.79158 .4364 .79755 .45593 .80895 .45245 .80297 .43289 Metetra
.612 .514 .718 r
.80297 .43289 .80895 .45245 .8204 .44895 .8144 .42935 Metetra
.612 .514 .718 r
.8144 .42935 .8204 .44895 .83189 .44545 .82588 .42581 Metetra
.612 .514 .718 r
.82588 .42581 .83189 .44545 .84343 .44192 .8374 .42225 Metetra
.612 .514 .718 r
.8374 .42225 .84343 .44192 .85502 .43839 .84897 .41868 Metetra
.604 .486 .692 r
.1952 .5982 .20003 .61914 .2092 .6163 .20434 .59534 Metetra
.604 .486 .692 r
.20434 .59534 .2092 .6163 .2184 .61346 .21353 .59246 Metetra
.604 .486 .692 r
.21353 .59246 .2184 .61346 .22764 .61061 .22274 .58958 Metetra
.604 .486 .692 r
.22274 .58958 .22764 .61061 .23691 .60775 .23199 .58668 Metetra
.604 .486 .692 r
.23199 .58668 .23691 .60775 .24621 .60487 .24126 .58377 Metetra
.604 .486 .692 r
.24126 .58377 .24621 .60487 .25554 .60199 .25058 .58086 Metetra
.604 .486 .692 r
.25058 .58086 .25554 .60199 .26491 .5991 .25992 .57793 Metetra
.604 .486 .692 r
.25992 .57793 .26491 .5991 .27431 .59619 .2693 .57499 Metetra
.604 .486 .692 r
.2693 .57499 .27431 .59619 .28374 .59328 .27871 .57204 Metetra
.604 .486 .692 r
.27871 .57204 .28374 .59328 .29321 .59035 .28816 .56908 Metetra
.604 .486 .692 r
.28816 .56908 .29321 .59035 .30271 .58742 .29764 .56611 Metetra
.604 .486 .692 r
.29764 .56611 .30271 .58742 .31225 .58447 .30716 .56313 Metetra
.604 .486 .692 r
.30716 .56313 .31225 .58447 .32182 .58151 .31671 .56014 Metetra
.604 .486 .692 r
.31671 .56014 .32182 .58151 .33143 .57855 .32629 .55714 Metetra
.604 .486 .692 r
.32629 .55714 .33143 .57855 .34107 .57557 .33591 .55413 Metetra
.604 .486 .692 r
.33591 .55413 .34107 .57557 .35074 .57258 .34556 .5511 Metetra
.604 .486 .692 r
.34556 .5511 .35074 .57258 .36045 .56958 .35525 .54807 Metetra
.604 .486 .692 r
.35525 .54807 .36045 .56958 .3702 .56657 .36498 .54502 Metetra
.604 .486 .692 r
.36498 .54502 .3702 .56657 .37998 .56355 .37474 .54196 Metetra
.604 .486 .692 r
.37474 .54196 .37998 .56355 .3898 .56051 .38453 .5389 Metetra
.604 .486 .692 r
.38453 .5389 .3898 .56051 .39966 .55747 .39436 .53582 Metetra
.604 .486 .692 r
.39436 .53582 .39966 .55747 .40955 .55442 .40423 .53272 Metetra
.604 .486 .692 r
.40423 .53272 .40955 .55442 .41947 .55135 .41413 .52962 Metetra
.604 .486 .692 r
.41413 .52962 .41947 .55135 .42944 .54827 .42407 .52651 Metetra
.604 .486 .692 r
.42407 .52651 .42944 .54827 .43944 .54518 .43405 .52338 Metetra
.604 .486 .692 r
.43405 .52338 .43944 .54518 .44948 .54208 .44407 .52025 Metetra
.604 .486 .692 r
.44407 .52025 .44948 .54208 .45955 .53897 .45412 .5171 Metetra
.604 .486 .692 r
.45412 .5171 .45955 .53897 .46967 .53584 .46421 .51394 Metetra
.604 .486 .692 r
.46421 .51394 .46967 .53584 .47982 .53271 .47433 .51077 Metetra
.604 .486 .692 r
.47433 .51077 .47982 .53271 .49 .52956 .4845 .50758 Metetra
.604 .486 .692 r
.4845 .50758 .49 .52956 .50023 .5264 .4947 .50439 Metetra
.604 .486 .692 r
.4947 .50439 .50023 .5264 .51049 .52323 .50494 .50118 Metetra
.604 .486 .692 r
.50494 .50118 .51049 .52323 .5208 .52005 .51522 .49796 Metetra
.604 .486 .692 r
.51522 .49796 .5208 .52005 .53114 .51685 .52553 .49473 Metetra
.604 .486 .692 r
.52553 .49473 .53114 .51685 .54152 .51365 .53589 .49148 Metetra
.604 .486 .692 r
.53589 .49148 .54152 .51365 .55194 .51043 .54628 .48823 Metetra
.604 .486 .692 r
.54628 .48823 .55194 .51043 .5624 .5072 .55672 .48496 Metetra
.604 .486 .692 r
.55672 .48496 .5624 .5072 .5729 .50395 .56719 .48168 Metetra
.604 .486 .692 r
.56719 .48168 .5729 .50395 .58344 .5007 .57771 .47838 Metetra
.604 .486 .692 r
.57771 .47838 .58344 .5007 .59402 .49743 .58826 .47508 Metetra
.604 .486 .692 r
.58826 .47508 .59402 .49743 .60464 .49415 .59885 .47176 Metetra
.604 .486 .692 r
.59885 .47176 .60464 .49415 .6153 .49086 .60949 .46843 Metetra
.604 .486 .692 r
.60949 .46843 .6153 .49086 .626 .48755 .62016 .46508 Metetra
.604 .486 .692 r
.62016 .46508 .626 .48755 .63674 .48423 .63088 .46173 Metetra
.604 .486 .692 r
.63088 .46173 .63674 .48423 .64753 .4809 .64163 .45836 Metetra
.604 .486 .692 r
.64163 .45836 .64753 .4809 .65835 .47756 .65243 .45498 Metetra
.604 .486 .692 r
.65243 .45498 .65835 .47756 .66922 .4742 .66327 .45158 Metetra
.604 .486 .692 r
.66327 .45158 .66922 .4742 .68013 .47083 .67415 .44817 Metetra
.604 .486 .692 r
.67415 .44817 .68013 .47083 .69108 .46745 .68508 .44475 Metetra
.604 .486 .692 r
.68508 .44475 .69108 .46745 .70207 .46405 .69604 .44131 Metetra
.604 .486 .692 r
.69604 .44131 .70207 .46405 .71311 .46064 .70705 .43787 Metetra
.604 .486 .692 r
.70705 .43787 .71311 .46064 .72419 .45722 .7181 .4344 Metetra
.604 .486 .692 r
.7181 .4344 .72419 .45722 .73531 .45379 .7292 .43093 Metetra
.604 .486 .692 r
.7292 .43093 .73531 .45379 .74647 .45034 .74034 .42744 Metetra
.604 .486 .692 r
.74034 .42744 .74647 .45034 .75768 .44687 .75152 .42394 Metetra
.604 .486 .692 r
.75152 .42394 .75768 .44687 .76894 .4434 .76274 .42042 Metetra
.604 .486 .692 r
.76274 .42042 .76894 .4434 .78024 .43991 .77401 .41689 Metetra
.604 .486 .692 r
.77401 .41689 .78024 .43991 .79158 .4364 .78533 .41335 Metetra
.604 .486 .692 r
.78533 .41335 .79158 .4364 .80297 .43289 .79669 .40979 Metetra
.604 .486 .692 r
.79669 .40979 .80297 .43289 .8144 .42935 .80809 .40622 Metetra
.604 .486 .692 r
.80809 .40622 .8144 .42935 .82588 .42581 .81954 .40263 Metetra
.604 .486 .692 r
.81954 .40263 .82588 .42581 .8374 .42225 .83103 .39903 Metetra
.604 .486 .692 r
.83103 .39903 .8374 .42225 .84897 .41868 .84257 .39542 Metetra
.588 .441 .649 r
.19122 .56873 .1952 .5982 .20434 .59534 .20032 .56582 Metetra
.588 .441 .649 r
.20032 .56582 .20434 .59534 .21353 .59246 .20946 .56291 Metetra
.588 .441 .649 r
.20946 .56291 .21353 .59246 .22274 .58958 .21863 .55998 Metetra
.588 .441 .649 r
.21863 .55998 .22274 .58958 .23199 .58668 .22784 .55704 Metetra
.588 .441 .649 r
.22784 .55704 .23199 .58668 .24126 .58377 .23707 .55409 Metetra
.588 .441 .649 r
.23707 .55409 .24126 .58377 .25058 .58086 .24634 .55114 Metetra
.588 .441 .649 r
.24634 .55114 .25058 .58086 .25992 .57793 .25564 .54817 Metetra
.588 .441 .649 r
.25564 .54817 .25992 .57793 .2693 .57499 .26498 .54519 Metetra
.588 .441 .649 r
.26498 .54519 .2693 .57499 .27871 .57204 .27435 .5422 Metetra
.588 .441 .649 r
.27435 .5422 .27871 .57204 .28816 .56908 .28375 .5392 Metetra
.588 .441 .649 r
.28375 .5392 .28816 .56908 .29764 .56611 .29318 .53618 Metetra
.588 .441 .649 r
.29318 .53618 .29764 .56611 .30716 .56313 .30265 .53316 Metetra
.588 .441 .649 r
.30265 .53316 .30716 .56313 .31671 .56014 .31216 .53013 Metetra
.588 .441 .649 r
.31216 .53013 .31671 .56014 .32629 .55714 .3217 .52708 Metetra
.588 .441 .649 r
.3217 .52708 .32629 .55714 .33591 .55413 .33127 .52403 Metetra
.588 .441 .649 r
.33127 .52403 .33591 .55413 .34556 .5511 .34088 .52096 Metetra
.588 .441 .649 r
.34088 .52096 .34556 .5511 .35525 .54807 .35052 .51788 Metetra
.588 .441 .649 r
.35052 .51788 .35525 .54807 .36498 .54502 .36019 .51479 Metetra
.588 .441 .649 r
.36019 .51479 .36498 .54502 .37474 .54196 .36991 .51169 Metetra
.588 .441 .649 r
.36991 .51169 .37474 .54196 .38453 .5389 .37965 .50858 Metetra
.588 .441 .649 r
.37965 .50858 .38453 .5389 .39436 .53582 .38944 .50546 Metetra
.588 .441 .649 r
.38944 .50546 .39436 .53582 .40423 .53272 .39926 .50233 Metetra
.588 .441 .649 r
.39926 .50233 .40423 .53272 .41413 .52962 .40911 .49918 Metetra
.588 .441 .649 r
.40911 .49918 .41413 .52962 .42407 .52651 .419 .49602 Metetra
.588 .441 .649 r
.419 .49602 .42407 .52651 .43405 .52338 .42893 .49285 Metetra
.588 .441 .649 r
.42893 .49285 .43405 .52338 .44407 .52025 .4389 .48967 Metetra
.588 .441 .649 r
.4389 .48967 .44407 .52025 .45412 .5171 .4489 .48648 Metetra
.588 .441 .649 r
.4489 .48648 .45412 .5171 .46421 .51394 .45894 .48328 Metetra
.588 .441 .649 r
.45894 .48328 .46421 .51394 .47433 .51077 .46901 .48006 Metetra
.588 .441 .649 r
.46901 .48006 .47433 .51077 .4845 .50758 .47912 .47683 Metetra
.588 .441 .649 r
.47912 .47683 .4845 .50758 .4947 .50439 .48927 .47359 Metetra
.588 .441 .649 r
.48927 .47359 .4947 .50439 .50494 .50118 .49946 .47034 Metetra
.588 .441 .649 r
.49946 .47034 .50494 .50118 .51522 .49796 .50969 .46708 Metetra
.588 .441 .649 r
.50969 .46708 .51522 .49796 .52553 .49473 .51995 .4638 Metetra
.588 .441 .649 r
.51995 .4638 .52553 .49473 .53589 .49148 .53026 .46051 Metetra
.588 .441 .649 r
.53026 .46051 .53589 .49148 .54628 .48823 .5406 .45721 Metetra
.588 .441 .649 r
.5406 .45721 .54628 .48823 .55672 .48496 .55098 .4539 Metetra
.588 .441 .649 r
.55098 .4539 .55672 .48496 .56719 .48168 .5614 .45057 Metetra
.588 .441 .649 r
.5614 .45057 .56719 .48168 .57771 .47838 .57186 .44723 Metetra
.588 .441 .649 r
.57186 .44723 .57771 .47838 .58826 .47508 .58236 .44388 Metetra
.588 .441 .649 r
.58236 .44388 .58826 .47508 .59885 .47176 .5929 .44052 Metetra
.588 .441 .649 r
.5929 .44052 .59885 .47176 .60949 .46843 .60348 .43714 Metetra
.588 .441 .649 r
.60348 .43714 .60949 .46843 .62016 .46508 .6141 .43375 Metetra
.588 .441 .649 r
.6141 .43375 .62016 .46508 .63088 .46173 .62476 .43035 Metetra
.588 .441 .649 r
.62476 .43035 .63088 .46173 .64163 .45836 .63546 .42693 Metetra
.588 .441 .649 r
.63546 .42693 .64163 .45836 .65243 .45498 .6462 .4235 Metetra
.588 .441 .649 r
.6462 .4235 .65243 .45498 .66327 .45158 .65698 .42006 Metetra
.588 .441 .649 r
.65698 .42006 .66327 .45158 .67415 .44817 .6678 .41661 Metetra
.588 .441 .649 r
.6678 .41661 .67415 .44817 .68508 .44475 .67867 .41314 Metetra
.588 .441 .649 r
.67867 .41314 .68508 .44475 .69604 .44131 .68958 .40966 Metetra
.588 .441 .649 r
.68958 .40966 .69604 .44131 .70705 .43787 .70053 .40616 Metetra
.588 .441 .649 r
.70053 .40616 .70705 .43787 .7181 .4344 .71152 .40265 Metetra
.588 .441 .649 r
.71152 .40265 .7181 .4344 .7292 .43093 .72256 .39913 Metetra
.588 .441 .649 r
.72256 .39913 .7292 .43093 .74034 .42744 .73363 .3956 Metetra
.588 .441 .649 r
.73363 .3956 .74034 .42744 .75152 .42394 .74475 .39205 Metetra
.588 .441 .649 r
.74475 .39205 .75152 .42394 .76274 .42042 .75592 .38848 Metetra
.588 .441 .649 r
.75592 .38848 .76274 .42042 .77401 .41689 .76713 .38491 Metetra
.588 .441 .649 r
.76713 .38491 .77401 .41689 .78533 .41335 .77838 .38131 Metetra
.588 .441 .649 r
.77838 .38131 .78533 .41335 .79669 .40979 .78967 .37771 Metetra
.588 .441 .649 r
.78967 .37771 .79669 .40979 .80809 .40622 .80102 .37409 Metetra
.588 .441 .649 r
.80102 .37409 .80809 .40622 .81954 .40263 .8124 .37045 Metetra
.588 .441 .649 r
.8124 .37045 .81954 .40263 .83103 .39903 .82383 .36681 Metetra
.588 .441 .649 r
.82383 .36681 .83103 .39903 .84257 .39542 .83531 .36314 Metetra
.578 .413 .621 r
.18817 .53046 .19122 .56873 .20032 .56582 .19722 .52751 Metetra
.578 .413 .621 r
.19722 .52751 .20032 .56582 .20946 .56291 .20629 .52454 Metetra
.578 .413 .621 r
.20629 .52454 .20946 .56291 .21863 .55998 .21539 .52157 Metetra
.578 .413 .621 r
.21539 .52157 .21863 .55998 .22784 .55704 .22453 .51858 Metetra
.578 .413 .621 r
.22453 .51858 .22784 .55704 .23707 .55409 .2337 .51559 Metetra
.578 .413 .621 r
.2337 .51559 .23707 .55409 .24634 .55114 .2429 .51258 Metetra
.578 .413 .621 r
.2429 .51258 .24634 .55114 .25564 .54817 .25214 .50956 Metetra
.578 .413 .621 r
.25214 .50956 .25564 .54817 .26498 .54519 .26141 .50653 Metetra
.578 .413 .621 r
.26141 .50653 .26498 .54519 .27435 .5422 .27071 .50349 Metetra
.578 .413 .621 r
.27071 .50349 .27435 .5422 .28375 .5392 .28004 .50044 Metetra
.578 .413 .621 r
.28004 .50044 .28375 .5392 .29318 .53618 .28941 .49738 Metetra
.578 .413 .621 r
.28941 .49738 .29318 .53618 .30265 .53316 .29881 .49431 Metetra
.578 .413 .621 r
.29881 .49431 .30265 .53316 .31216 .53013 .30824 .49123 Metetra
.578 .413 .621 r
.30824 .49123 .31216 .53013 .3217 .52708 .31771 .48813 Metetra
.578 .413 .621 r
.31771 .48813 .3217 .52708 .33127 .52403 .32721 .48503 Metetra
.578 .413 .621 r
.32721 .48503 .33127 .52403 .34088 .52096 .33675 .48191 Metetra
.578 .413 .621 r
.33675 .48191 .34088 .52096 .35052 .51788 .34632 .47879 Metetra
.578 .413 .621 r
.34632 .47879 .35052 .51788 .36019 .51479 .35592 .47565 Metetra
.578 .413 .621 r
.35592 .47565 .36019 .51479 .36991 .51169 .36556 .4725 Metetra
.578 .413 .621 r
.36556 .4725 .36991 .51169 .37965 .50858 .37523 .46934 Metetra
.578 .413 .621 r
.37523 .46934 .37965 .50858 .38944 .50546 .38494 .46616 Metetra
.578 .413 .621 r
.38494 .46616 .38944 .50546 .39926 .50233 .39469 .46298 Metetra
.578 .413 .621 r
.39469 .46298 .39926 .50233 .40911 .49918 .40447 .45978 Metetra
.578 .413 .621 r
.40447 .45978 .40911 .49918 .419 .49602 .41428 .45657 Metetra
.578 .413 .621 r
.41428 .45657 .419 .49602 .42893 .49285 .42414 .45335 Metetra
.578 .413 .621 r
.42414 .45335 .42893 .49285 .4389 .48967 .43402 .45012 Metetra
.578 .413 .621 r
.43402 .45012 .4389 .48967 .4489 .48648 .44395 .44688 Metetra
.578 .413 .621 r
.44395 .44688 .4489 .48648 .45894 .48328 .45391 .44362 Metetra
.578 .413 .621 r
.45391 .44362 .45894 .48328 .46901 .48006 .46391 .44036 Metetra
.578 .413 .621 r
.46391 .44036 .46901 .48006 .47912 .47683 .47394 .43708 Metetra
.578 .413 .621 r
.47394 .43708 .47912 .47683 .48927 .47359 .48401 .43379 Metetra
.578 .413 .621 r
.48401 .43379 .48927 .47359 .49946 .47034 .49412 .43048 Metetra
.578 .413 .621 r
.49412 .43048 .49946 .47034 .50969 .46708 .50427 .42717 Metetra
.578 .413 .621 r
.50427 .42717 .50969 .46708 .51995 .4638 .51445 .42384 Metetra
.578 .413 .621 r
.51445 .42384 .51995 .4638 .53026 .46051 .52467 .4205 Metetra
.578 .413 .621 r
.52467 .4205 .53026 .46051 .5406 .45721 .53493 .41715 Metetra
.578 .413 .621 r
.53493 .41715 .5406 .45721 .55098 .4539 .54523 .41378 Metetra
.578 .413 .621 r
.54523 .41378 .55098 .4539 .5614 .45057 .55557 .4104 Metetra
.578 .413 .621 r
.55557 .4104 .5614 .45057 .57186 .44723 .56594 .40701 Metetra
.578 .413 .621 r
.56594 .40701 .57186 .44723 .58236 .44388 .57636 .40361 Metetra
.578 .413 .621 r
.57636 .40361 .58236 .44388 .5929 .44052 .58681 .40019 Metetra
.578 .413 .621 r
.58681 .40019 .5929 .44052 .60348 .43714 .59731 .39676 Metetra
.578 .413 .621 r
.59731 .39676 .60348 .43714 .6141 .43375 .60784 .39332 Metetra
.578 .413 .621 r
.60784 .39332 .6141 .43375 .62476 .43035 .61841 .38987 Metetra
.578 .413 .621 r
.61841 .38987 .62476 .43035 .63546 .42693 .62903 .3864 Metetra
.578 .413 .621 r
.62903 .3864 .63546 .42693 .6462 .4235 .63968 .38292 Metetra
.578 .413 .621 r
.63968 .38292 .6462 .4235 .65698 .42006 .65037 .37942 Metetra
.578 .413 .621 r
.65037 .37942 .65698 .42006 .6678 .41661 .66111 .37591 Metetra
.578 .413 .621 r
.66111 .37591 .6678 .41661 .67867 .41314 .67188 .37239 Metetra
.578 .413 .621 r
.67188 .37239 .67867 .41314 .68958 .40966 .6827 .36886 Metetra
.578 .413 .621 r
.6827 .36886 .68958 .40966 .70053 .40616 .69356 .36531 Metetra
.578 .413 .621 r
.69356 .36531 .70053 .40616 .71152 .40265 .70446 .36175 Metetra
.578 .413 .621 r
.70446 .36175 .71152 .40265 .72256 .39913 .7154 .35817 Metetra
.578 .413 .621 r
.7154 .35817 .72256 .39913 .73363 .3956 .72639 .35458 Metetra
.578 .413 .621 r
.72639 .35458 .73363 .3956 .74475 .39205 .73741 .35098 Metetra
.578 .413 .621 r
.73741 .35098 .74475 .39205 .75592 .38848 .74848 .34736 Metetra
.578 .413 .621 r
.74848 .34736 .75592 .38848 .76713 .38491 .7596 .34373 Metetra
.578 .413 .621 r
.7596 .34373 .76713 .38491 .77838 .38131 .77075 .34008 Metetra
.578 .413 .621 r
.77075 .34008 .77838 .38131 .78967 .37771 .78195 .33642 Metetra
.578 .413 .621 r
.78195 .33642 .78967 .37771 .80102 .37409 .7932 .33275 Metetra
.578 .413 .621 r
.7932 .33275 .80102 .37409 .8124 .37045 .80448 .32906 Metetra
.578 .413 .621 r
.80448 .32906 .8124 .37045 .82383 .36681 .81582 .32536 Metetra
.578 .413 .621 r
.81582 .32536 .82383 .36681 .83531 .36314 .82719 .32164 Metetra
.563 .376 .586 r
.18746 .47036 .18817 .53046 .19722 .52751 .19638 .46734 Metetra
.563 .376 .586 r
.19638 .46734 .19722 .52751 .20629 .52454 .20533 .46431 Metetra
.563 .376 .586 r
.20533 .46431 .20629 .52454 .21539 .52157 .21432 .46127 Metetra
.563 .376 .586 r
.21432 .46127 .21539 .52157 .22453 .51858 .22333 .45821 Metetra
.563 .376 .586 r
.22333 .45821 .22453 .51858 .2337 .51559 .23238 .45515 Metetra
.563 .376 .586 r
.23238 .45515 .2337 .51559 .2429 .51258 .24145 .45208 Metetra
.563 .376 .586 r
.24145 .45208 .2429 .51258 .25214 .50956 .25056 .449 Metetra
.563 .376 .586 r
.25056 .449 .25214 .50956 .26141 .50653 .2597 .4459 Metetra
.563 .376 .586 r
.2597 .4459 .26141 .50653 .27071 .50349 .26888 .4428 Metetra
.563 .376 .586 r
.26888 .4428 .27071 .50349 .28004 .50044 .27808 .43968 Metetra
.563 .376 .586 r
.27808 .43968 .28004 .50044 .28941 .49738 .28732 .43656 Metetra
.563 .376 .586 r
.28732 .43656 .28941 .49738 .29881 .49431 .29659 .43342 Metetra
.563 .376 .586 r
.29659 .43342 .29881 .49431 .30824 .49123 .30589 .43027 Metetra
.563 .376 .586 r
.30589 .43027 .30824 .49123 .31771 .48813 .31523 .42711 Metetra
.563 .376 .586 r
.31523 .42711 .31771 .48813 .32721 .48503 .3246 .42394 Metetra
.563 .376 .586 r
.3246 .42394 .32721 .48503 .33675 .48191 .334 .42075 Metetra
.563 .376 .586 r
.334 .42075 .33675 .48191 .34632 .47879 .34344 .41756 Metetra
.563 .376 .586 r
.34344 .41756 .34632 .47879 .35592 .47565 .35291 .41436 Metetra
.563 .376 .586 r
.35291 .41436 .35592 .47565 .36556 .4725 .36241 .41114 Metetra
.563 .376 .586 r
.36241 .41114 .36556 .4725 .37523 .46934 .37195 .40791 Metetra
.563 .376 .586 r
.37195 .40791 .37523 .46934 .38494 .46616 .38152 .40467 Metetra
.563 .376 .586 r
.38152 .40467 .38494 .46616 .39469 .46298 .39112 .40142 Metetra
.563 .376 .586 r
.39112 .40142 .39469 .46298 .40447 .45978 .40076 .39816 Metetra
.563 .376 .586 r
.40076 .39816 .40447 .45978 .41428 .45657 .41044 .39488 Metetra
.563 .376 .586 r
.41044 .39488 .41428 .45657 .42414 .45335 .42015 .3916 Metetra
.563 .376 .586 r
.42015 .3916 .42414 .45335 .43402 .45012 .42989 .3883 Metetra
.563 .376 .586 r
.42989 .3883 .43402 .45012 .44395 .44688 .43967 .38499 Metetra
.563 .376 .586 r
.43967 .38499 .44395 .44688 .45391 .44362 .44949 .38166 Metetra
.563 .376 .586 r
.44949 .38166 .45391 .44362 .46391 .44036 .45934 .37833 Metetra
.563 .376 .586 r
.45934 .37833 .46391 .44036 .47394 .43708 .46923 .37498 Metetra
.563 .376 .586 r
.46923 .37498 .47394 .43708 .48401 .43379 .47915 .37163 Metetra
.563 .376 .586 r
.47915 .37163 .48401 .43379 .49412 .43048 .48911 .36825 Metetra
.563 .376 .586 r
.48911 .36825 .49412 .43048 .50427 .42717 .49911 .36487 Metetra
.563 .376 .586 r
.49911 .36487 .50427 .42717 .51445 .42384 .50914 .36148 Metetra
.563 .376 .586 r
.50914 .36148 .51445 .42384 .52467 .4205 .51921 .35807 Metetra
.563 .376 .586 r
.51921 .35807 .52467 .4205 .53493 .41715 .52931 .35465 Metetra
.563 .376 .586 r
.52931 .35465 .53493 .41715 .54523 .41378 .53946 .35121 Metetra
.563 .376 .586 r
.53946 .35121 .54523 .41378 .55557 .4104 .54964 .34777 Metetra
.563 .376 .586 r
.54964 .34777 .55557 .4104 .56594 .40701 .55986 .34431 Metetra
.563 .376 .586 r
.55986 .34431 .56594 .40701 .57636 .40361 .57011 .34084 Metetra
.563 .376 .586 r
.57011 .34084 .57636 .40361 .58681 .40019 .58041 .33735 Metetra
.563 .376 .586 r
.58041 .33735 .58681 .40019 .59731 .39676 .59074 .33385 Metetra
.563 .376 .586 r
.59074 .33385 .59731 .39676 .60784 .39332 .60111 .33034 Metetra
.563 .376 .586 r
.60111 .33034 .60784 .39332 .61841 .38987 .61152 .32682 Metetra
.563 .376 .586 r
.61152 .32682 .61841 .38987 .62903 .3864 .62197 .32328 Metetra
.563 .376 .586 r
.62197 .32328 .62903 .3864 .63968 .38292 .63246 .31973 Metetra
.563 .376 .586 r
.63246 .31973 .63968 .38292 .65037 .37942 .64299 .31617 Metetra
.563 .376 .586 r
.64299 .31617 .65037 .37942 .66111 .37591 .65355 .31259 Metetra
.563 .376 .586 r
.65355 .31259 .66111 .37591 .67188 .37239 .66416 .309 Metetra
.563 .376 .586 r
.66416 .309 .67188 .37239 .6827 .36886 .67481 .3054 Metetra
.563 .376 .586 r
.67481 .3054 .6827 .36886 .69356 .36531 .68549 .30178 Metetra
.563 .376 .586 r
.68549 .30178 .69356 .36531 .70446 .36175 .69622 .29815 Metetra
.563 .376 .586 r
.69622 .29815 .70446 .36175 .7154 .35817 .70699 .29451 Metetra
.563 .376 .586 r
.70699 .29451 .7154 .35817 .72639 .35458 .7178 .29085 Metetra
.563 .376 .586 r
.7178 .29085 .72639 .35458 .73741 .35098 .72865 .28717 Metetra
.563 .376 .586 r
.72865 .28717 .73741 .35098 .74848 .34736 .73954 .28349 Metetra
.563 .376 .586 r
.73954 .28349 .74848 .34736 .7596 .34373 .75048 .27979 Metetra
.563 .376 .586 r
.75048 .27979 .7596 .34373 .77075 .34008 .76145 .27607 Metetra
.563 .376 .586 r
.76145 .27607 .77075 .34008 .78195 .33642 .77247 .27234 Metetra
.563 .376 .586 r
.77247 .27234 .78195 .33642 .7932 .33275 .78353 .2686 Metetra
.563 .376 .586 r
.78353 .2686 .7932 .33275 .80448 .32906 .79463 .26484 Metetra
.563 .376 .586 r
.79463 .26484 .80448 .32906 .81582 .32536 .80578 .26107 Metetra
.563 .376 .586 r
.80578 .26107 .81582 .32536 .82719 .32164 .81697 .25728 Metetra
.559 .367 .577 r
.18785 .40141 .18746 .47036 .19638 .46734 .19663 .39832 Metetra
.559 .367 .577 r
.19663 .39832 .19638 .46734 .20533 .46431 .20543 .39522 Metetra
.559 .367 .577 r
.20543 .39522 .20533 .46431 .21432 .46127 .21427 .39211 Metetra
.559 .367 .577 r
.21427 .39211 .21432 .46127 .22333 .45821 .22314 .38899 Metetra
.559 .367 .577 r
.22314 .38899 .22333 .45821 .23238 .45515 .23204 .38586 Metetra
.559 .367 .577 r
.23204 .38586 .23238 .45515 .24145 .45208 .24097 .38272 Metetra
.559 .367 .577 r
.24097 .38272 .24145 .45208 .25056 .449 .24993 .37957 Metetra
.559 .367 .577 r
.24993 .37957 .25056 .449 .2597 .4459 .25892 .37641 Metetra
.559 .367 .577 r
.25892 .37641 .2597 .4459 .26888 .4428 .26794 .37323 Metetra
.559 .367 .577 r
.26794 .37323 .26888 .4428 .27808 .43968 .27699 .37005 Metetra
.559 .367 .577 r
.27699 .37005 .27808 .43968 .28732 .43656 .28608 .36685 Metetra
.559 .367 .577 r
.28608 .36685 .28732 .43656 .29659 .43342 .29519 .36364 Metetra
.559 .367 .577 r
.29519 .36364 .29659 .43342 .30589 .43027 .30434 .36043 Metetra
.559 .367 .577 r
.30434 .36043 .30589 .43027 .31523 .42711 .31352 .3572 Metetra
.559 .367 .577 r
.31352 .3572 .31523 .42711 .3246 .42394 .32273 .35396 Metetra
.559 .367 .577 r
.32273 .35396 .3246 .42394 .334 .42075 .33197 .3507 Metetra
.559 .367 .577 r
.33197 .3507 .334 .42075 .34344 .41756 .34125 .34744 Metetra
.559 .367 .577 r
.34125 .34744 .34344 .41756 .35291 .41436 .35056 .34417 Metetra
.559 .367 .577 r
.35056 .34417 .35291 .41436 .36241 .41114 .3599 .34088 Metetra
.559 .367 .577 r
.3599 .34088 .36241 .41114 .37195 .40791 .36927 .33758 Metetra
.559 .367 .577 r
.36927 .33758 .37195 .40791 .38152 .40467 .37868 .33427 Metetra
.559 .367 .577 r
.37868 .33427 .38152 .40467 .39112 .40142 .38811 .33095 Metetra
.559 .367 .577 r
.38811 .33095 .39112 .40142 .40076 .39816 .39759 .32762 Metetra
.559 .367 .577 r
.39759 .32762 .40076 .39816 .41044 .39488 .40709 .32428 Metetra
.559 .367 .577 r
.40709 .32428 .41044 .39488 .42015 .3916 .41663 .32092 Metetra
.559 .367 .577 r
.41663 .32092 .42015 .3916 .42989 .3883 .42621 .31755 Metetra
.559 .367 .577 r
.42621 .31755 .42989 .3883 .43967 .38499 .43582 .31417 Metetra
.559 .367 .577 r
.43582 .31417 .43967 .38499 .44949 .38166 .44546 .31078 Metetra
.559 .367 .577 r
.44546 .31078 .44949 .38166 .45934 .37833 .45513 .30737 Metetra
.559 .367 .577 r
.45513 .30737 .45934 .37833 .46923 .37498 .46485 .30396 Metetra
.559 .367 .577 r
.46485 .30396 .46923 .37498 .47915 .37163 .47459 .30053 Metetra
.559 .367 .577 r
.47459 .30053 .47915 .37163 .48911 .36825 .48437 .29709 Metetra
.559 .367 .577 r
.48437 .29709 .48911 .36825 .49911 .36487 .49419 .29363 Metetra
.559 .367 .577 r
.49419 .29363 .49911 .36487 .50914 .36148 .50404 .29017 Metetra
.559 .367 .577 r
.50404 .29017 .50914 .36148 .51921 .35807 .51393 .28669 Metetra
.559 .367 .577 r
.51393 .28669 .51921 .35807 .52931 .35465 .52385 .2832 Metetra
.559 .367 .577 r
.52385 .2832 .52931 .35465 .53946 .35121 .53381 .2797 Metetra
.559 .367 .577 r
.53381 .2797 .53946 .35121 .54964 .34777 .54381 .27618 Metetra
.559 .367 .577 r
.54381 .27618 .54964 .34777 .55986 .34431 .55384 .27265 Metetra
.559 .367 .577 r
.55384 .27265 .55986 .34431 .57011 .34084 .5639 .26911 Metetra
.559 .367 .577 r
.5639 .26911 .57011 .34084 .58041 .33735 .57401 .26555 Metetra
.559 .367 .577 r
.57401 .26555 .58041 .33735 .59074 .33385 .58415 .26199 Metetra
.559 .367 .577 r
.58415 .26199 .59074 .33385 .60111 .33034 .59433 .2584 Metetra
.559 .367 .577 r
.59433 .2584 .60111 .33034 .61152 .32682 .60455 .25481 Metetra
.559 .367 .577 r
.60455 .25481 .61152 .32682 .62197 .32328 .6148 .2512 Metetra
.559 .367 .577 r
.6148 .2512 .62197 .32328 .63246 .31973 .62509 .24758 Metetra
.559 .367 .577 r
.62509 .24758 .63246 .31973 .64299 .31617 .63542 .24395 Metetra
.559 .367 .577 r
.63542 .24395 .64299 .31617 .65355 .31259 .64579 .2403 Metetra
.559 .367 .577 r
.64579 .2403 .65355 .31259 .66416 .309 .65619 .23664 Metetra
.559 .367 .577 r
.65619 .23664 .66416 .309 .67481 .3054 .66664 .23297 Metetra
.559 .367 .577 r
.66664 .23297 .67481 .3054 .68549 .30178 .67712 .22928 Metetra
.559 .367 .577 r
.67712 .22928 .68549 .30178 .69622 .29815 .68764 .22558 Metetra
.559 .367 .577 r
.68764 .22558 .69622 .29815 .70699 .29451 .6982 .22186 Metetra
.559 .367 .577 r
.6982 .22186 .70699 .29451 .7178 .29085 .70881 .21813 Metetra
.559 .367 .577 r
.70881 .21813 .7178 .29085 .72865 .28717 .71945 .21439 Metetra
.559 .367 .577 r
.71945 .21439 .72865 .28717 .73954 .28349 .73013 .21063 Metetra
.559 .367 .577 r
.73013 .21063 .73954 .28349 .75048 .27979 .74085 .20686 Metetra
.559 .367 .577 r
.74085 .20686 .75048 .27979 .76145 .27607 .75161 .20307 Metetra
.559 .367 .577 r
.75161 .20307 .76145 .27607 .77247 .27234 .76241 .19927 Metetra
.559 .367 .577 r
.76241 .19927 .77247 .27234 .78353 .2686 .77325 .19546 Metetra
.559 .367 .577 r
.77325 .19546 .78353 .2686 .79463 .26484 .78414 .19163 Metetra
.559 .367 .577 r
.78414 .19163 .79463 .26484 .80578 .26107 .79506 .18779 Metetra
.559 .367 .577 r
.79506 .18779 .80578 .26107 .81697 .25728 .80603 .18393 Metetra
.664 .741 .908 r
.18172 .3957 .18785 .40141 .19663 .39832 .19051 .39259 Metetra
.664 .741 .908 r
.19051 .39259 .19663 .39832 .20543 .39522 .19934 .38947 Metetra
.664 .741 .908 r
.19934 .38947 .20543 .39522 .21427 .39211 .20819 .38634 Metetra
.664 .741 .908 r
.20819 .38634 .21427 .39211 .22314 .38899 .21708 .3832 Metetra
.664 .741 .908 r
.21708 .3832 .22314 .38899 .23204 .38586 .22599 .38005 Metetra
.664 .741 .908 r
.22599 .38005 .23204 .38586 .24097 .38272 .23494 .37689 Metetra
.664 .741 .908 r
.23494 .37689 .24097 .38272 .24993 .37957 .24392 .37372 Metetra
.664 .741 .908 r
.24392 .37372 .24993 .37957 .25892 .37641 .25293 .37054 Metetra
.664 .741 .908 r
.25293 .37054 .25892 .37641 .26794 .37323 .26197 .36734 Metetra
.664 .741 .908 r
.26197 .36734 .26794 .37323 .27699 .37005 .27104 .36414 Metetra
.664 .741 .908 r
.27104 .36414 .27699 .37005 .28608 .36685 .28014 .36092 Metetra
.664 .741 .908 r
.28014 .36092 .28608 .36685 .29519 .36364 .28928 .35769 Metetra
.664 .741 .908 r
.28928 .35769 .29519 .36364 .30434 .36043 .29844 .35446 Metetra
.664 .741 .908 r
.29844 .35446 .30434 .36043 .31352 .3572 .30764 .35121 Metetra
.664 .741 .908 r
.30764 .35121 .31352 .3572 .32273 .35396 .31687 .34794 Metetra
.664 .741 .908 r
.31687 .34794 .32273 .35396 .33197 .3507 .32613 .34467 Metetra
.664 .741 .908 r
.32613 .34467 .33197 .3507 .34125 .34744 .33543 .34139 Metetra
.664 .741 .908 r
.33543 .34139 .34125 .34744 .35056 .34417 .34476 .33809 Metetra
.664 .741 .908 r
.34476 .33809 .35056 .34417 .3599 .34088 .35412 .33478 Metetra
.664 .741 .908 r
.35412 .33478 .3599 .34088 .36927 .33758 .36351 .33146 Metetra
.664 .741 .908 r
.36351 .33146 .36927 .33758 .37868 .33427 .37294 .32813 Metetra
.664 .741 .908 r
.37294 .32813 .37868 .33427 .38811 .33095 .3824 .32479 Metetra
.664 .741 .908 r
.3824 .32479 .38811 .33095 .39759 .32762 .39189 .32144 Metetra
.664 .741 .908 r
.39189 .32144 .39759 .32762 .40709 .32428 .40142 .31807 Metetra
.664 .741 .908 r
.40142 .31807 .40709 .32428 .41663 .32092 .41098 .31469 Metetra
.664 .741 .908 r
.41098 .31469 .41663 .32092 .42621 .31755 .42058 .3113 Metetra
.664 .741 .908 r
.42058 .3113 .42621 .31755 .43582 .31417 .43021 .3079 Metetra
.664 .741 .908 r
.43021 .3079 .43582 .31417 .44546 .31078 .43987 .30448 Metetra
.664 .741 .908 r
.43987 .30448 .44546 .31078 .45513 .30737 .44957 .30106 Metetra
.664 .741 .908 r
.44957 .30106 .45513 .30737 .46485 .30396 .4593 .29762 Metetra
.664 .741 .908 r
.4593 .29762 .46485 .30396 .47459 .30053 .46907 .29417 Metetra
.664 .741 .908 r
.46907 .29417 .47459 .30053 .48437 .29709 .47887 .2907 Metetra
.664 .741 .908 r
.47887 .2907 .48437 .29709 .49419 .29363 .48871 .28723 Metetra
.664 .741 .908 r
.48871 .28723 .49419 .29363 .50404 .29017 .49859 .28374 Metetra
.664 .741 .908 r
.49859 .28374 .50404 .29017 .51393 .28669 .5085 .28024 Metetra
.664 .741 .908 r
.5085 .28024 .51393 .28669 .52385 .2832 .51844 .27672 Metetra
.664 .741 .908 r
.51844 .27672 .52385 .2832 .53381 .2797 .52843 .27319 Metetra
.664 .741 .908 r
.52843 .27319 .53381 .2797 .54381 .27618 .53845 .26965 Metetra
.664 .741 .908 r
.53845 .26965 .54381 .27618 .55384 .27265 .5485 .2661 Metetra
.664 .741 .908 r
.5485 .2661 .55384 .27265 .5639 .26911 .55859 .26254 Metetra
.664 .741 .908 r
.55859 .26254 .5639 .26911 .57401 .26555 .56872 .25896 Metetra
.664 .741 .908 r
.56872 .25896 .57401 .26555 .58415 .26199 .57889 .25536 Metetra
.664 .741 .908 r
.57889 .25536 .58415 .26199 .59433 .2584 .58909 .25176 Metetra
.664 .741 .908 r
.58909 .25176 .59433 .2584 .60455 .25481 .59933 .24814 Metetra
.664 .741 .908 r
.59933 .24814 .60455 .25481 .6148 .2512 .60961 .24451 Metetra
.664 .741 .908 r
.60961 .24451 .6148 .2512 .62509 .24758 .61993 .24086 Metetra
.664 .741 .908 r
.61993 .24086 .62509 .24758 .63542 .24395 .63028 .2372 Metetra
.664 .741 .908 r
.63028 .2372 .63542 .24395 .64579 .2403 .64068 .23353 Metetra
.664 .741 .908 r
.64068 .23353 .64579 .2403 .65619 .23664 .65111 .22985 Metetra
.664 .741 .908 r
.65111 .22985 .65619 .23664 .66664 .23297 .66158 .22615 Metetra
.664 .741 .908 r
.66158 .22615 .66664 .23297 .67712 .22928 .67209 .22243 Metetra
.664 .741 .908 r
.67209 .22243 .67712 .22928 .68764 .22558 .68264 .21871 Metetra
.664 .741 .908 r
.68264 .21871 .68764 .22558 .6982 .22186 .69323 .21496 Metetra
.664 .741 .908 r
.69323 .21496 .6982 .22186 .70881 .21813 .70386 .21121 Metetra
.664 .741 .908 r
.70386 .21121 .70881 .21813 .71945 .21439 .71452 .20744 Metetra
.664 .741 .908 r
.71452 .20744 .71945 .21439 .73013 .21063 .72523 .20366 Metetra
.664 .741 .908 r
.72523 .20366 .73013 .21063 .74085 .20686 .73598 .19986 Metetra
.664 .741 .908 r
.73598 .19986 .74085 .20686 .75161 .20307 .74677 .19605 Metetra
.664 .741 .908 r
.74677 .19605 .75161 .20307 .76241 .19927 .7576 .19222 Metetra
.664 .741 .908 r
.7576 .19222 .76241 .19927 .77325 .19546 .76847 .18838 Metetra
.664 .741 .908 r
.76847 .18838 .77325 .19546 .78414 .19163 .77939 .18452 Metetra
.664 .741 .908 r
.77939 .18452 .78414 .19163 .79506 .18779 .79034 .18065 Metetra
.664 .741 .908 r
.79034 .18065 .79506 .18779 .80603 .18393 .80134 .17677 Metetra
.664 .741 .908 r
.17555 .38995 .18172 .3957 .19051 .39259 .18436 .38683 Metetra
.664 .741 .908 r
.18436 .38683 .19051 .39259 .19934 .38947 .1932 .38369 Metetra
.664 .741 .908 r
.1932 .38369 .19934 .38947 .20819 .38634 .20207 .38054 Metetra
.664 .741 .908 r
.20207 .38054 .20819 .38634 .21708 .3832 .21098 .37738 Metetra
.664 .741 .908 r
.21098 .37738 .21708 .3832 .22599 .38005 .21991 .37421 Metetra
.664 .741 .908 r
.21991 .37421 .22599 .38005 .23494 .37689 .22888 .37103 Metetra
.664 .741 .908 r
.22888 .37103 .23494 .37689 .24392 .37372 .23787 .36784 Metetra
.664 .741 .908 r
.23787 .36784 .24392 .37372 .25293 .37054 .2469 .36463 Metetra
.664 .741 .908 r
.2469 .36463 .25293 .37054 .26197 .36734 .25596 .36142 Metetra
.664 .741 .908 r
.25596 .36142 .26197 .36734 .27104 .36414 .26505 .35819 Metetra
.664 .741 .908 r
.26505 .35819 .27104 .36414 .28014 .36092 .27417 .35495 Metetra
.664 .741 .908 r
.27417 .35495 .28014 .36092 .28928 .35769 .28332 .35171 Metetra
.664 .741 .908 r
.28332 .35171 .28928 .35769 .29844 .35446 .29251 .34845 Metetra
.664 .741 .908 r
.29251 .34845 .29844 .35446 .30764 .35121 .30173 .34518 Metetra
.664 .741 .908 r
.30173 .34518 .30764 .35121 .31687 .34794 .31098 .34189 Metetra
.664 .741 .908 r
.31098 .34189 .31687 .34794 .32613 .34467 .32026 .3386 Metetra
.664 .741 .908 r
.32026 .3386 .32613 .34467 .33543 .34139 .32957 .33529 Metetra
.664 .741 .908 r
.32957 .33529 .33543 .34139 .34476 .33809 .33892 .33198 Metetra
.664 .741 .908 r
.33892 .33198 .34476 .33809 .35412 .33478 .3483 .32865 Metetra
.664 .741 .908 r
.3483 .32865 .35412 .33478 .36351 .33146 .35772 .32531 Metetra
.664 .741 .908 r
.35772 .32531 .36351 .33146 .37294 .32813 .36716 .32195 Metetra
.664 .741 .908 r
.36716 .32195 .37294 .32813 .3824 .32479 .37664 .31859 Metetra
.664 .741 .908 r
.37664 .31859 .3824 .32479 .39189 .32144 .38616 .31521 Metetra
.664 .741 .908 r
.38616 .31521 .39189 .32144 .40142 .31807 .39571 .31182 Metetra
.664 .741 .908 r
.39571 .31182 .40142 .31807 .41098 .31469 .40529 .30842 Metetra
.664 .741 .908 r
.40529 .30842 .41098 .31469 .42058 .3113 .41491 .30501 Metetra
.664 .741 .908 r
.41491 .30501 .42058 .3113 .43021 .3079 .42456 .30159 Metetra
.664 .741 .908 r
.42456 .30159 .43021 .3079 .43987 .30448 .43424 .29815 Metetra
.664 .741 .908 r
.43424 .29815 .43987 .30448 .44957 .30106 .44396 .2947 Metetra
.664 .741 .908 r
.44396 .2947 .44957 .30106 .4593 .29762 .45372 .29124 Metetra
.664 .741 .908 r
.45372 .29124 .4593 .29762 .46907 .29417 .46351 .28776 Metetra
.664 .741 .908 r
.46351 .28776 .46907 .29417 .47887 .2907 .47334 .28427 Metetra
.664 .741 .908 r
.47334 .28427 .47887 .2907 .48871 .28723 .4832 .28078 Metetra
.664 .741 .908 r
.4832 .28078 .48871 .28723 .49859 .28374 .4931 .27726 Metetra
.664 .741 .908 r
.4931 .27726 .49859 .28374 .5085 .28024 .50303 .27374 Metetra
.664 .741 .908 r
.50303 .27374 .5085 .28024 .51844 .27672 .513 .2702 Metetra
.664 .741 .908 r
.513 .2702 .51844 .27672 .52843 .27319 .52301 .26665 Metetra
.664 .741 .908 r
.52301 .26665 .52843 .27319 .53845 .26965 .53305 .26308 Metetra
.664 .741 .908 r
.53305 .26308 .53845 .26965 .5485 .2661 .54313 .25951 Metetra
.664 .741 .908 r
.54313 .25951 .5485 .2661 .55859 .26254 .55325 .25592 Metetra
.664 .741 .908 r
.55325 .25592 .55859 .26254 .56872 .25896 .5634 .25231 Metetra
.664 .741 .908 r
.5634 .25231 .56872 .25896 .57889 .25536 .57359 .2487 Metetra
.664 .741 .908 r
.57359 .2487 .57889 .25536 .58909 .25176 .58382 .24507 Metetra
.664 .741 .908 r
.58382 .24507 .58909 .25176 .59933 .24814 .59408 .24143 Metetra
.664 .741 .908 r
.59408 .24143 .59933 .24814 .60961 .24451 .60439 .23777 Metetra
.664 .741 .908 r
.60439 .23777 .60961 .24451 .61993 .24086 .61473 .2341 Metetra
.664 .741 .908 r
.61473 .2341 .61993 .24086 .63028 .2372 .62511 .23041 Metetra
.664 .741 .908 r
.62511 .23041 .63028 .2372 .64068 .23353 .63553 .22672 Metetra
.664 .741 .908 r
.63553 .22672 .64068 .23353 .65111 .22985 .64599 .22301 Metetra
.664 .741 .908 r
.64599 .22301 .65111 .22985 .66158 .22615 .65649 .21928 Metetra
.664 .741 .908 r
.65649 .21928 .66158 .22615 .67209 .22243 .66702 .21554 Metetra
.664 .741 .908 r
.66702 .21554 .67209 .22243 .68264 .21871 .6776 .21179 Metetra
.664 .741 .908 r
.6776 .21179 .68264 .21871 .69323 .21496 .68822 .20802 Metetra
.664 .741 .908 r
.68822 .20802 .69323 .21496 .70386 .21121 .69887 .20424 Metetra
.664 .741 .908 r
.69887 .20424 .70386 .21121 .71452 .20744 .70957 .20044 Metetra
.664 .741 .908 r
.70957 .20044 .71452 .20744 .72523 .20366 .7203 .19663 Metetra
.664 .741 .908 r
.7203 .19663 .72523 .20366 .73598 .19986 .73108 .19281 Metetra
.664 .741 .908 r
.73108 .19281 .73598 .19986 .74677 .19605 .7419 .18897 Metetra
.664 .741 .908 r
.7419 .18897 .74677 .19605 .7576 .19222 .75276 .18512 Metetra
.664 .741 .908 r
.75276 .18512 .7576 .19222 .76847 .18838 .76366 .18125 Metetra
.664 .741 .908 r
.76366 .18125 .76847 .18838 .77939 .18452 .7746 .17736 Metetra
.664 .741 .908 r
.7746 .17736 .77939 .18452 .79034 .18065 .78558 .17347 Metetra
.664 .741 .908 r
.78558 .17347 .79034 .18065 .80134 .17677 .79661 .16955 Metetra
.664 .741 .908 r
.16934 .38417 .17555 .38995 .18436 .38683 .17817 .38102 Metetra
.664 .741 .908 r
.17817 .38102 .18436 .38683 .1932 .38369 .18703 .37787 Metetra
.664 .741 .908 r
.18703 .37787 .1932 .38369 .20207 .38054 .19592 .3747 Metetra
.664 .741 .908 r
.19592 .3747 .20207 .38054 .21098 .37738 .20484 .37152 Metetra
.664 .741 .908 r
.20484 .37152 .21098 .37738 .21991 .37421 .21379 .36833 Metetra
.664 .741 .908 r
.21379 .36833 .21991 .37421 .22888 .37103 .22277 .36513 Metetra
.664 .741 .908 r
.22277 .36513 .22888 .37103 .23787 .36784 .23179 .36191 Metetra
.664 .741 .908 r
.23179 .36191 .23787 .36784 .2469 .36463 .24083 .35869 Metetra
.664 .741 .908 r
.24083 .35869 .2469 .36463 .25596 .36142 .24991 .35545 Metetra
.664 .741 .908 r
.24991 .35545 .25596 .36142 .26505 .35819 .25902 .35221 Metetra
.664 .741 .908 r
.25902 .35221 .26505 .35819 .27417 .35495 .26816 .34895 Metetra
.664 .741 .908 r
.26816 .34895 .27417 .35495 .28332 .35171 .27733 .34568 Metetra
.664 .741 .908 r
.27733 .34568 .28332 .35171 .29251 .34845 .28654 .3424 Metetra
.664 .741 .908 r
.28654 .3424 .29251 .34845 .30173 .34518 .29577 .33911 Metetra
.664 .741 .908 r
.29577 .33911 .30173 .34518 .31098 .34189 .30504 .3358 Metetra
.664 .741 .908 r
.30504 .3358 .31098 .34189 .32026 .3386 .31434 .33249 Metetra
.664 .741 .908 r
.31434 .33249 .32026 .3386 .32957 .33529 .32368 .32916 Metetra
.664 .741 .908 r
.32368 .32916 .32957 .33529 .33892 .33198 .33305 .32582 Metetra
.664 .741 .908 r
.33305 .32582 .33892 .33198 .3483 .32865 .34245 .32247 Metetra
.664 .741 .908 r
.34245 .32247 .3483 .32865 .35772 .32531 .35188 .31911 Metetra
.664 .741 .908 r
.35188 .31911 .35772 .32531 .36716 .32195 .36135 .31573 Metetra
.664 .741 .908 r
.36135 .31573 .36716 .32195 .37664 .31859 .37085 .31235 Metetra
.664 .741 .908 r
.37085 .31235 .37664 .31859 .38616 .31521 .38039 .30895 Metetra
.664 .741 .908 r
.38039 .30895 .38616 .31521 .39571 .31182 .38996 .30554 Metetra
.664 .741 .908 r
.38996 .30554 .39571 .31182 .40529 .30842 .39956 .30211 Metetra
.664 .741 .908 r
.39956 .30211 .40529 .30842 .41491 .30501 .4092 .29868 Metetra
.664 .741 .908 r
.4092 .29868 .41491 .30501 .42456 .30159 .41887 .29523 Metetra
.664 .741 .908 r
.41887 .29523 .42456 .30159 .43424 .29815 .42858 .29177 Metetra
.664 .741 .908 r
.42858 .29177 .43424 .29815 .44396 .2947 .43832 .2883 Metetra
.664 .741 .908 r
.43832 .2883 .44396 .2947 .45372 .29124 .4481 .28481 Metetra
.664 .741 .908 r
.4481 .28481 .45372 .29124 .46351 .28776 .45792 .28131 Metetra
.664 .741 .908 r
.45792 .28131 .46351 .28776 .47334 .28427 .46776 .2778 Metetra
.664 .741 .908 r
.46776 .2778 .47334 .28427 .4832 .28078 .47765 .27428 Metetra
.664 .741 .908 r
.47765 .27428 .4832 .28078 .4931 .27726 .48757 .27074 Metetra
.664 .741 .908 r
.48757 .27074 .4931 .27726 .50303 .27374 .49753 .2672 Metetra
.664 .741 .908 r
.49753 .2672 .50303 .27374 .513 .2702 .50752 .26363 Metetra
.664 .741 .908 r
.50752 .26363 .513 .2702 .52301 .26665 .51755 .26006 Metetra
.664 .741 .908 r
.51755 .26006 .52301 .26665 .53305 .26308 .52762 .25647 Metetra
.664 .741 .908 r
.52762 .25647 .53305 .26308 .54313 .25951 .53772 .25287 Metetra
.664 .741 .908 r
.53772 .25287 .54313 .25951 .55325 .25592 .54786 .24926 Metetra
.664 .741 .908 r
.54786 .24926 .55325 .25592 .5634 .25231 .55804 .24563 Metetra
.664 .741 .908 r
.55804 .24563 .5634 .25231 .57359 .2487 .56826 .24199 Metetra
.664 .741 .908 r
.56826 .24199 .57359 .2487 .58382 .24507 .57851 .23833 Metetra
.664 .741 .908 r
.57851 .23833 .58382 .24507 .59408 .24143 .5888 .23466 Metetra
.664 .741 .908 r
.5888 .23466 .59408 .24143 .60439 .23777 .59913 .23098 Metetra
.664 .741 .908 r
.59913 .23098 .60439 .23777 .61473 .2341 .6095 .22729 Metetra
.664 .741 .908 r
.6095 .22729 .61473 .2341 .62511 .23041 .61991 .22358 Metetra
.664 .741 .908 r
.61991 .22358 .62511 .23041 .63553 .22672 .63035 .21985 Metetra
.664 .741 .908 r
.63035 .21985 .63553 .22672 .64599 .22301 .64084 .21612 Metetra
.664 .741 .908 r
.64084 .21612 .64599 .22301 .65649 .21928 .65136 .21237 Metetra
.664 .741 .908 r
.65136 .21237 .65649 .21928 .66702 .21554 .66192 .2086 Metetra
.664 .741 .908 r
.66192 .2086 .66702 .21554 .6776 .21179 .67253 .20482 Metetra
.664 .741 .908 r
.67253 .20482 .6776 .21179 .68822 .20802 .68317 .20103 Metetra
.664 .741 .908 r
.68317 .20103 .68822 .20802 .69887 .20424 .69385 .19722 Metetra
.664 .741 .908 r
.69385 .19722 .69887 .20424 .70957 .20044 .70458 .1934 Metetra
.664 .741 .908 r
.70458 .1934 .70957 .20044 .7203 .19663 .71534 .18956 Metetra
.664 .741 .908 r
.71534 .18956 .7203 .19663 .73108 .19281 .72615 .18571 Metetra
.664 .741 .908 r
.72615 .18571 .73108 .19281 .7419 .18897 .73699 .18184 Metetra
.664 .741 .908 r
.73699 .18184 .7419 .18897 .75276 .18512 .74788 .17796 Metetra
.664 .741 .908 r
.74788 .17796 .75276 .18512 .76366 .18125 .75881 .17407 Metetra
.664 .741 .908 r
.75881 .17407 .76366 .18125 .7746 .17736 .76978 .17016 Metetra
.664 .741 .908 r
.76978 .17016 .7746 .17736 .78558 .17347 .7808 .16623 Metetra
.664 .741 .908 r
.7808 .16623 .78558 .17347 .79661 .16955 .79185 .16229 Metetra
.664 .741 .908 r
.16309 .37835 .16934 .38417 .17817 .38102 .17193 .37519 Metetra
.664 .741 .908 r
.17193 .37519 .17817 .38102 .18703 .37787 .18081 .37201 Metetra
.664 .741 .908 r
.18081 .37201 .18703 .37787 .19592 .3747 .18972 .36882 Metetra
.664 .741 .908 r
.18972 .36882 .19592 .3747 .20484 .37152 .19866 .36562 Metetra
.664 .741 .908 r
.19866 .36562 .20484 .37152 .21379 .36833 .20763 .36241 Metetra
.664 .741 .908 r
.20763 .36241 .21379 .36833 .22277 .36513 .21663 .35919 Metetra
.664 .741 .908 r
.21663 .35919 .22277 .36513 .23179 .36191 .22566 .35595 Metetra
.664 .741 .908 r
.22566 .35595 .23179 .36191 .24083 .35869 .23473 .35271 Metetra
.664 .741 .908 r
.23473 .35271 .24083 .35869 .24991 .35545 .24382 .34945 Metetra
.664 .741 .908 r
.24382 .34945 .24991 .35545 .25902 .35221 .25295 .34618 Metetra
.664 .741 .908 r
.25295 .34618 .25902 .35221 .26816 .34895 .26211 .3429 Metetra
.664 .741 .908 r
.26211 .3429 .26816 .34895 .27733 .34568 .2713 .33961 Metetra
.664 .741 .908 r
.2713 .33961 .27733 .34568 .28654 .3424 .28052 .33631 Metetra
.664 .741 .908 r
.28052 .33631 .28654 .3424 .29577 .33911 .28978 .333 Metetra
.664 .741 .908 r
.28978 .333 .29577 .33911 .30504 .3358 .29907 .32967 Metetra
.664 .741 .908 r
.29907 .32967 .30504 .3358 .31434 .33249 .30839 .32634 Metetra
.664 .741 .908 r
.30839 .32634 .31434 .33249 .32368 .32916 .31775 .32299 Metetra
.664 .741 .908 r
.31775 .32299 .32368 .32916 .33305 .32582 .32713 .31963 Metetra
.664 .741 .908 r
.32713 .31963 .33305 .32582 .34245 .32247 .33656 .31625 Metetra
.664 .741 .908 r
.33656 .31625 .34245 .32247 .35188 .31911 .34601 .31287 Metetra
.664 .741 .908 r
.34601 .31287 .35188 .31911 .36135 .31573 .3555 .30947 Metetra
.664 .741 .908 r
.3555 .30947 .36135 .31573 .37085 .31235 .36502 .30606 Metetra
.664 .741 .908 r
.36502 .30606 .37085 .31235 .38039 .30895 .37458 .30264 Metetra
.664 .741 .908 r
.37458 .30264 .38039 .30895 .38996 .30554 .38417 .29921 Metetra
.664 .741 .908 r
.38417 .29921 .38996 .30554 .39956 .30211 .3938 .29576 Metetra
.664 .741 .908 r
.3938 .29576 .39956 .30211 .4092 .29868 .40346 .2923 Metetra
.664 .741 .908 r
.40346 .2923 .4092 .29868 .41887 .29523 .41315 .28883 Metetra
.664 .741 .908 r
.41315 .28883 .41887 .29523 .42858 .29177 .42288 .28535 Metetra
.664 .741 .908 r
.42288 .28535 .42858 .29177 .43832 .2883 .43265 .28185 Metetra
.664 .741 .908 r
.43265 .28185 .43832 .2883 .4481 .28481 .44245 .27834 Metetra
.664 .741 .908 r
.44245 .27834 .4481 .28481 .45792 .28131 .45228 .27482 Metetra
.664 .741 .908 r
.45228 .27482 .45792 .28131 .46776 .2778 .46215 .27129 Metetra
.664 .741 .908 r
.46215 .27129 .46776 .2778 .47765 .27428 .47206 .26774 Metetra
.664 .741 .908 r
.47206 .26774 .47765 .27428 .48757 .27074 .48201 .26418 Metetra
.664 .741 .908 r
.48201 .26418 .48757 .27074 .49753 .2672 .49199 .26061 Metetra
.664 .741 .908 r
.49199 .26061 .49753 .2672 .50752 .26363 .502 .25702 Metetra
.664 .741 .908 r
.502 .25702 .50752 .26363 .51755 .26006 .51206 .25342 Metetra
.664 .741 .908 r
.51206 .25342 .51755 .26006 .52762 .25647 .52215 .24981 Metetra
.664 .741 .908 r
.52215 .24981 .52762 .25647 .53772 .25287 .53228 .24619 Metetra
.664 .741 .908 r
.53228 .24619 .53772 .25287 .54786 .24926 .54244 .24255 Metetra
.664 .741 .908 r
.54244 .24255 .54786 .24926 .55804 .24563 .55264 .2389 Metetra
.664 .741 .908 r
.55264 .2389 .55804 .24563 .56826 .24199 .56288 .23523 Metetra
.664 .741 .908 r
.56288 .23523 .56826 .24199 .57851 .23833 .57316 .23155 Metetra
.664 .741 .908 r
.57316 .23155 .57851 .23833 .5888 .23466 .58348 .22786 Metetra
.664 .741 .908 r
.58348 .22786 .5888 .23466 .59913 .23098 .59384 .22415 Metetra
.664 .741 .908 r
.59384 .22415 .59913 .23098 .6095 .22729 .60423 .22043 Metetra
.664 .741 .908 r
.60423 .22043 .6095 .22729 .61991 .22358 .61466 .21669 Metetra
.664 .741 .908 r
.61466 .21669 .61991 .22358 .63035 .21985 .62513 .21294 Metetra
.664 .741 .908 r
.62513 .21294 .63035 .21985 .64084 .21612 .63565 .20918 Metetra
.664 .741 .908 r
.63565 .20918 .64084 .21612 .65136 .21237 .6462 .2054 Metetra
.664 .741 .908 r
.6462 .2054 .65136 .21237 .66192 .2086 .65679 .20161 Metetra
.664 .741 .908 r
.65679 .20161 .66192 .2086 .67253 .20482 .66742 .19781 Metetra
.664 .741 .908 r
.66742 .19781 .67253 .20482 .68317 .20103 .67809 .19399 Metetra
.664 .741 .908 r
.67809 .19399 .68317 .20103 .69385 .19722 .6888 .19015 Metetra
.664 .741 .908 r
.6888 .19015 .69385 .19722 .70458 .1934 .69955 .1863 Metetra
.664 .741 .908 r
.69955 .1863 .70458 .1934 .71534 .18956 .71034 .18244 Metetra
.664 .741 .908 r
.71034 .18244 .71534 .18956 .72615 .18571 .72118 .17856 Metetra
.664 .741 .908 r
.72118 .17856 .72615 .18571 .73699 .18184 .73205 .17467 Metetra
.664 .741 .908 r
.73205 .17467 .73699 .18184 .74788 .17796 .74297 .17076 Metetra
.664 .741 .908 r
.74297 .17076 .74788 .17796 .75881 .17407 .75393 .16684 Metetra
.664 .741 .908 r
.75393 .16684 .75881 .17407 .76978 .17016 .76493 .1629 Metetra
.664 .741 .908 r
.76493 .1629 .76978 .17016 .7808 .16623 .77597 .15895 Metetra
.664 .741 .908 r
.77597 .15895 .7808 .16623 .79185 .16229 .78706 .15498 Metetra
.664 .741 .908 r
.1568 .3725 .16309 .37835 .17193 .37519 .16566 .36931 Metetra
.664 .741 .908 r
.16566 .36931 .17193 .37519 .18081 .37201 .17456 .36611 Metetra
.664 .741 .908 r
.17456 .36611 .18081 .37201 .18972 .36882 .18348 .3629 Metetra
.664 .741 .908 r
.18348 .3629 .18972 .36882 .19866 .36562 .19244 .35968 Metetra
.664 .741 .908 r
.19244 .35968 .19866 .36562 .20763 .36241 .20143 .35645 Metetra
.664 .741 .908 r
.20143 .35645 .20763 .36241 .21663 .35919 .21045 .35321 Metetra
.664 .741 .908 r
.21045 .35321 .21663 .35919 .22566 .35595 .2195 .34995 Metetra
.664 .741 .908 r
.2195 .34995 .22566 .35595 .23473 .35271 .22858 .34669 Metetra
.664 .741 .908 r
.22858 .34669 .23473 .35271 .24382 .34945 .2377 .34341 Metetra
.664 .741 .908 r
.2377 .34341 .24382 .34945 .25295 .34618 .24684 .34012 Metetra
.664 .741 .908 r
.24684 .34012 .25295 .34618 .26211 .3429 .25602 .33682 Metetra
.664 .741 .908 r
.25602 .33682 .26211 .3429 .2713 .33961 .26523 .33351 Metetra
.664 .741 .908 r
.26523 .33351 .2713 .33961 .28052 .33631 .27447 .33018 Metetra
.664 .741 .908 r
.27447 .33018 .28052 .33631 .28978 .333 .28375 .32685 Metetra
.664 .741 .908 r
.28375 .32685 .28978 .333 .29907 .32967 .29306 .3235 Metetra
.664 .741 .908 r
.29306 .3235 .29907 .32967 .30839 .32634 .3024 .32014 Metetra
.664 .741 .908 r
.3024 .32014 .30839 .32634 .31775 .32299 .31177 .31677 Metetra
.664 .741 .908 r
.31177 .31677 .31775 .32299 .32713 .31963 .32118 .31339 Metetra
.664 .741 .908 r
.32118 .31339 .32713 .31963 .33656 .31625 .33063 .30999 Metetra
.664 .741 .908 r
.33063 .30999 .33656 .31625 .34601 .31287 .3401 .30659 Metetra
.664 .741 .908 r
.3401 .30659 .34601 .31287 .3555 .30947 .34961 .30317 Metetra
.664 .741 .908 r
.34961 .30317 .3555 .30947 .36502 .30606 .35915 .29974 Metetra
.664 .741 .908 r
.35915 .29974 .36502 .30606 .37458 .30264 .36873 .29629 Metetra
.664 .741 .908 r
.36873 .29629 .37458 .30264 .38417 .29921 .37834 .29284 Metetra
.664 .741 .908 r
.37834 .29284 .38417 .29921 .3938 .29576 .38799 .28937 Metetra
.664 .741 .908 r
.38799 .28937 .3938 .29576 .40346 .2923 .39767 .28589 Metetra
.664 .741 .908 r
.39767 .28589 .40346 .2923 .41315 .28883 .40739 .28239 Metetra
.664 .741 .908 r
.40739 .28239 .41315 .28883 .42288 .28535 .41714 .27889 Metetra
.664 .741 .908 r
.41714 .27889 .42288 .28535 .43265 .28185 .42693 .27537 Metetra
.664 .741 .908 r
.42693 .27537 .43265 .28185 .44245 .27834 .43675 .27183 Metetra
.664 .741 .908 r
.43675 .27183 .44245 .27834 .45228 .27482 .44661 .26829 Metetra
.664 .741 .908 r
.44661 .26829 .45228 .27482 .46215 .27129 .45651 .26473 Metetra
.664 .741 .908 r
.45651 .26473 .46215 .27129 .47206 .26774 .46644 .26116 Metetra
.664 .741 .908 r
.46644 .26116 .47206 .26774 .48201 .26418 .4764 .25758 Metetra
.664 .741 .908 r
.4764 .25758 .48201 .26418 .49199 .26061 .48641 .25398 Metetra
.664 .741 .908 r
.48641 .25398 .49199 .26061 .502 .25702 .49645 .25037 Metetra
.664 .741 .908 r
.49645 .25037 .502 .25702 .51206 .25342 .50653 .24675 Metetra
.664 .741 .908 r
.50653 .24675 .51206 .25342 .52215 .24981 .51664 .24311 Metetra
.664 .741 .908 r
.51664 .24311 .52215 .24981 .53228 .24619 .52679 .23946 Metetra
.664 .741 .908 r
.52679 .23946 .53228 .24619 .54244 .24255 .53698 .23579 Metetra
.664 .741 .908 r
.53698 .23579 .54244 .24255 .55264 .2389 .54721 .23212 Metetra
.664 .741 .908 r
.54721 .23212 .55264 .2389 .56288 .23523 .55748 .22843 Metetra
.664 .741 .908 r
.55748 .22843 .56288 .23523 .57316 .23155 .56778 .22472 Metetra
.664 .741 .908 r
.56778 .22472 .57316 .23155 .58348 .22786 .57812 .221 Metetra
.664 .741 .908 r
.57812 .221 .58348 .22786 .59384 .22415 .5885 .21727 Metetra
.664 .741 .908 r
.5885 .21727 .59384 .22415 .60423 .22043 .59892 .21352 Metetra
.664 .741 .908 r
.59892 .21352 .60423 .22043 .61466 .21669 .60938 .20976 Metetra
.664 .741 .908 r
.60938 .20976 .61466 .21669 .62513 .21294 .61988 .20599 Metetra
.664 .741 .908 r
.61988 .20599 .62513 .21294 .63565 .20918 .63042 .2022 Metetra
.664 .741 .908 r
.63042 .2022 .63565 .20918 .6462 .2054 .641 .19839 Metetra
.664 .741 .908 r
.641 .19839 .6462 .2054 .65679 .20161 .65162 .19458 Metetra
.664 .741 .908 r
.65162 .19458 .65679 .20161 .66742 .19781 .66227 .19074 Metetra
.664 .741 .908 r
.66227 .19074 .66742 .19781 .67809 .19399 .67297 .1869 Metetra
.664 .741 .908 r
.67297 .1869 .67809 .19399 .6888 .19015 .68371 .18304 Metetra
.664 .741 .908 r
.68371 .18304 .6888 .19015 .69955 .1863 .69449 .17916 Metetra
.664 .741 .908 r
.69449 .17916 .69955 .1863 .71034 .18244 .70531 .17527 Metetra
.664 .741 .908 r
.70531 .17527 .71034 .18244 .72118 .17856 .71617 .17136 Metetra
.664 .741 .908 r
.71617 .17136 .72118 .17856 .73205 .17467 .72708 .16744 Metetra
.664 .741 .908 r
.72708 .16744 .73205 .17467 .74297 .17076 .73802 .16351 Metetra
.664 .741 .908 r
.73802 .16351 .74297 .17076 .75393 .16684 .74901 .15955 Metetra
.664 .741 .908 r
.74901 .15955 .75393 .16684 .76493 .1629 .76004 .15559 Metetra
.664 .741 .908 r
.76004 .15559 .76493 .1629 .77597 .15895 .77112 .15161 Metetra
.664 .741 .908 r
.77112 .15161 .77597 .15895 .78706 .15498 .78223 .14761 Metetra
.664 .741 .908 r
.15047 .3666 .1568 .3725 .16566 .36931 .15935 .3634 Metetra
.664 .741 .908 r
.15935 .3634 .16566 .36931 .17456 .36611 .16826 .36018 Metetra
.664 .741 .908 r
.16826 .36018 .17456 .36611 .18348 .3629 .17721 .35695 Metetra
.664 .741 .908 r
.17721 .35695 .18348 .3629 .19244 .35968 .18618 .35371 Metetra
.664 .741 .908 r
.18618 .35371 .19244 .35968 .20143 .35645 .19519 .35045 Metetra
.664 .741 .908 r
.19519 .35045 .20143 .35645 .21045 .35321 .20423 .34719 Metetra
.664 .741 .908 r
.20423 .34719 .21045 .35321 .2195 .34995 .21329 .34391 Metetra
.664 .741 .908 r
.21329 .34391 .2195 .34995 .22858 .34669 .2224 .34063 Metetra
.664 .741 .908 r
.2224 .34063 .22858 .34669 .2377 .34341 .23153 .33733 Metetra
.664 .741 .908 r
.23153 .33733 .2377 .34341 .24684 .34012 .24069 .33402 Metetra
.664 .741 .908 r
.24069 .33402 .24684 .34012 .25602 .33682 .24989 .3307 Metetra
.664 .741 .908 r
.24989 .3307 .25602 .33682 .26523 .33351 .25912 .32736 Metetra
.664 .741 .908 r
.25912 .32736 .26523 .33351 .27447 .33018 .26838 .32402 Metetra
.664 .741 .908 r
.26838 .32402 .27447 .33018 .28375 .32685 .27768 .32066 Metetra
.664 .741 .908 r
.27768 .32066 .28375 .32685 .29306 .3235 .28701 .31729 Metetra
.664 .741 .908 r
.28701 .31729 .29306 .3235 .3024 .32014 .29637 .31391 Metetra
.664 .741 .908 r
.29637 .31391 .3024 .32014 .31177 .31677 .30576 .31052 Metetra
.664 .741 .908 r
.30576 .31052 .31177 .31677 .32118 .31339 .31519 .30711 Metetra
.664 .741 .908 r
.31519 .30711 .32118 .31339 .33063 .30999 .32466 .30369 Metetra
.664 .741 .908 r
.32466 .30369 .33063 .30999 .3401 .30659 .33415 .30026 Metetra
.664 .741 .908 r
.33415 .30026 .3401 .30659 .34961 .30317 .34368 .29682 Metetra
.664 .741 .908 r
.34368 .29682 .34961 .30317 .35915 .29974 .35325 .29337 Metetra
.664 .741 .908 r
.35325 .29337 .35915 .29974 .36873 .29629 .36285 .2899 Metetra
.664 .741 .908 r
.36285 .2899 .36873 .29629 .37834 .29284 .37248 .28642 Metetra
.664 .741 .908 r
.37248 .28642 .37834 .29284 .38799 .28937 .38215 .28293 Metetra
.664 .741 .908 r
.38215 .28293 .38799 .28937 .39767 .28589 .39185 .27943 Metetra
.664 .741 .908 r
.39185 .27943 .39767 .28589 .40739 .28239 .40159 .27591 Metetra
.664 .741 .908 r
.40159 .27591 .40739 .28239 .41714 .27889 .41136 .27238 Metetra
.664 .741 .908 r
.41136 .27238 .41714 .27889 .42693 .27537 .42117 .26884 Metetra
.664 .741 .908 r
.42117 .26884 .42693 .27537 .43675 .27183 .43102 .26528 Metetra
.664 .741 .908 r
.43102 .26528 .43675 .27183 .44661 .26829 .4409 .26171 Metetra
.664 .741 .908 r
.4409 .26171 .44661 .26829 .45651 .26473 .45082 .25813 Metetra
.664 .741 .908 r
.45082 .25813 .45651 .26473 .46644 .26116 .46077 .25453 Metetra
.664 .741 .908 r
.46077 .25453 .46644 .26116 .4764 .25758 .47076 .25093 Metetra
.664 .741 .908 r
.47076 .25093 .4764 .25758 .48641 .25398 .48079 .2473 Metetra
.664 .741 .908 r
.48079 .2473 .48641 .25398 .49645 .25037 .49086 .24367 Metetra
.664 .741 .908 r
.49086 .24367 .49645 .25037 .50653 .24675 .50096 .24002 Metetra
.664 .741 .908 r
.50096 .24002 .50653 .24675 .51664 .24311 .5111 .23636 Metetra
.664 .741 .908 r
.5111 .23636 .51664 .24311 .52679 .23946 .52127 .23268 Metetra
.664 .741 .908 r
.52127 .23268 .52679 .23946 .53698 .23579 .53149 .22899 Metetra
.664 .741 .908 r
.53149 .22899 .53698 .23579 .54721 .23212 .54174 .22529 Metetra
.664 .741 .908 r
.54174 .22529 .54721 .23212 .55748 .22843 .55203 .22157 Metetra
.664 .741 .908 r
.55203 .22157 .55748 .22843 .56778 .22472 .56236 .21784 Metetra
.664 .741 .908 r
.56236 .21784 .56778 .22472 .57812 .221 .57273 .2141 Metetra
.664 .741 .908 r
.57273 .2141 .57812 .221 .5885 .21727 .58314 .21034 Metetra
.664 .741 .908 r
.58314 .21034 .5885 .21727 .59892 .21352 .59358 .20657 Metetra
.664 .741 .908 r
.59358 .20657 .59892 .21352 .60938 .20976 .60407 .20278 Metetra
.664 .741 .908 r
.60407 .20278 .60938 .20976 .61988 .20599 .61459 .19898 Metetra
.664 .741 .908 r
.61459 .19898 .61988 .20599 .63042 .2022 .62516 .19516 Metetra
.664 .741 .908 r
.62516 .19516 .63042 .2022 .641 .19839 .63576 .19133 Metetra
.664 .741 .908 r
.63576 .19133 .641 .19839 .65162 .19458 .64641 .18749 Metetra
.664 .741 .908 r
.64641 .18749 .65162 .19458 .66227 .19074 .65709 .18363 Metetra
.664 .741 .908 r
.65709 .18363 .66227 .19074 .67297 .1869 .66782 .17976 Metetra
.664 .741 .908 r
.66782 .17976 .67297 .1869 .68371 .18304 .67859 .17587 Metetra
.664 .741 .908 r
.67859 .17587 .68371 .18304 .69449 .17916 .68939 .17196 Metetra
.664 .741 .908 r
.68939 .17196 .69449 .17916 .70531 .17527 .70024 .16805 Metetra
.664 .741 .908 r
.70024 .16805 .70531 .17527 .71617 .17136 .71113 .16411 Metetra
.664 .741 .908 r
.71113 .16411 .71617 .17136 .72708 .16744 .72207 .16016 Metetra
.664 .741 .908 r
.72207 .16016 .72708 .16744 .73802 .16351 .73304 .1562 Metetra
.664 .741 .908 r
.73304 .1562 .73802 .16351 .74901 .15955 .74406 .15222 Metetra
.664 .741 .908 r
.74406 .15222 .74901 .15955 .76004 .15559 .75512 .14823 Metetra
.664 .741 .908 r
.75512 .14823 .76004 .15559 .77112 .15161 .76622 .14422 Metetra
.664 .741 .908 r
.76622 .14422 .77112 .15161 .78223 .14761 .77737 .14019 Metetra
.664 .741 .908 r
.1441 .36067 .15047 .3666 .15935 .3634 .153 .35745 Metetra
.664 .741 .908 r
.153 .35745 .15935 .3634 .16826 .36018 .16193 .35421 Metetra
.664 .741 .908 r
.16193 .35421 .16826 .36018 .17721 .35695 .17089 .35095 Metetra
.664 .741 .908 r
.17089 .35095 .17721 .35695 .18618 .35371 .17988 .34769 Metetra
.664 .741 .908 r
.17988 .34769 .18618 .35371 .19519 .35045 .18891 .34442 Metetra
.664 .741 .908 r
.18891 .34442 .19519 .35045 .20423 .34719 .19796 .34113 Metetra
.664 .741 .908 r
.19796 .34113 .20423 .34719 .21329 .34391 .20705 .33784 Metetra
.664 .741 .908 r
.20705 .33784 .21329 .34391 .2224 .34063 .21617 .33453 Metetra
.664 .741 .908 r
.21617 .33453 .2224 .34063 .23153 .33733 .22532 .33121 Metetra
.664 .741 .908 r
.22532 .33121 .23153 .33733 .24069 .33402 .23451 .32788 Metetra
.664 .741 .908 r
.23451 .32788 .24069 .33402 .24989 .3307 .24372 .32453 Metetra
.664 .741 .908 r
.24372 .32453 .24989 .3307 .25912 .32736 .25297 .32118 Metetra
.664 .741 .908 r
.25297 .32118 .25912 .32736 .26838 .32402 .26225 .31781 Metetra
.664 .741 .908 r
.26225 .31781 .26838 .32402 .27768 .32066 .27157 .31443 Metetra
.664 .741 .908 r
.27157 .31443 .27768 .32066 .28701 .31729 .28092 .31104 Metetra
.664 .741 .908 r
.28092 .31104 .28701 .31729 .29637 .31391 .2903 .30764 Metetra
.664 .741 .908 r
.2903 .30764 .29637 .31391 .30576 .31052 .29971 .30422 Metetra
.664 .741 .908 r
.29971 .30422 .30576 .31052 .31519 .30711 .30916 .30079 Metetra
.664 .741 .908 r
.30916 .30079 .31519 .30711 .32466 .30369 .31865 .29735 Metetra
.664 .741 .908 r
.31865 .29735 .32466 .30369 .33415 .30026 .32816 .2939 Metetra
.664 .741 .908 r
.32816 .2939 .33415 .30026 .34368 .29682 .33771 .29044 Metetra
.664 .741 .908 r
.33771 .29044 .34368 .29682 .35325 .29337 .3473 .28696 Metetra
.664 .741 .908 r
.3473 .28696 .35325 .29337 .36285 .2899 .35692 .28347 Metetra
.664 .741 .908 r
.35692 .28347 .36285 .2899 .37248 .28642 .36657 .27997 Metetra
.664 .741 .908 r
.36657 .27997 .37248 .28642 .38215 .28293 .37627 .27645 Metetra
.664 .741 .908 r
.37627 .27645 .38215 .28293 .39185 .27943 .38599 .27292 Metetra
.664 .741 .908 r
.38599 .27292 .39185 .27943 .40159 .27591 .39575 .26938 Metetra
.664 .741 .908 r
.39575 .26938 .40159 .27591 .41136 .27238 .40555 .26583 Metetra
.664 .741 .908 r
.40555 .26583 .41136 .27238 .42117 .26884 .41538 .26226 Metetra
.664 .741 .908 r
.41538 .26226 .42117 .26884 .43102 .26528 .42525 .25868 Metetra
.664 .741 .908 r
.42525 .25868 .43102 .26528 .4409 .26171 .43515 .25509 Metetra
.664 .741 .908 r
.43515 .25509 .4409 .26171 .45082 .25813 .44509 .25148 Metetra
.664 .741 .908 r
.44509 .25148 .45082 .25813 .46077 .25453 .45507 .24786 Metetra
.664 .741 .908 r
.45507 .24786 .46077 .25453 .47076 .25093 .46509 .24423 Metetra
.664 .741 .908 r
.46509 .24423 .47076 .25093 .48079 .2473 .47514 .24058 Metetra
.664 .741 .908 r
.47514 .24058 .48079 .2473 .49086 .24367 .48523 .23692 Metetra
.664 .741 .908 r
.48523 .23692 .49086 .24367 .50096 .24002 .49535 .23325 Metetra
.664 .741 .908 r
.49535 .23325 .50096 .24002 .5111 .23636 .50551 .22956 Metetra
.664 .741 .908 r
.50551 .22956 .5111 .23636 .52127 .23268 .51572 .22586 Metetra
.664 .741 .908 r
.51572 .22586 .52127 .23268 .53149 .22899 .52596 .22215 Metetra
.664 .741 .908 r
.52596 .22215 .53149 .22899 .54174 .22529 .53623 .21842 Metetra
.664 .741 .908 r
.53623 .21842 .54174 .22529 .55203 .22157 .54655 .21468 Metetra
.664 .741 .908 r
.54655 .21468 .55203 .22157 .56236 .21784 .5569 .21092 Metetra
.664 .741 .908 r
.5569 .21092 .56236 .21784 .57273 .2141 .5673 .20715 Metetra
.664 .741 .908 r
.5673 .20715 .57273 .2141 .58314 .21034 .57773 .20336 Metetra
.664 .741 .908 r
.57773 .20336 .58314 .21034 .59358 .20657 .5882 .19957 Metetra
.664 .741 .908 r
.5882 .19957 .59358 .20657 .60407 .20278 .59871 .19575 Metetra
.664 .741 .908 r
.59871 .19575 .60407 .20278 .61459 .19898 .60927 .19192 Metetra
.664 .741 .908 r
.60927 .19192 .61459 .19898 .62516 .19516 .61986 .18808 Metetra
.664 .741 .908 r
.61986 .18808 .62516 .19516 .63576 .19133 .63049 .18422 Metetra
.664 .741 .908 r
.63049 .18422 .63576 .19133 .64641 .18749 .64116 .18035 Metetra
.664 .741 .908 r
.64116 .18035 .64641 .18749 .65709 .18363 .65188 .17647 Metetra
.664 .741 .908 r
.65188 .17647 .65709 .18363 .66782 .17976 .66263 .17257 Metetra
.664 .741 .908 r
.66263 .17257 .66782 .17976 .67859 .17587 .67342 .16865 Metetra
.664 .741 .908 r
.67342 .16865 .67859 .17587 .68939 .17196 .68426 .16472 Metetra
.664 .741 .908 r
.68426 .16472 .68939 .17196 .70024 .16805 .69514 .16077 Metetra
.664 .741 .908 r
.69514 .16077 .70024 .16805 .71113 .16411 .70606 .15681 Metetra
.664 .741 .908 r
.70606 .15681 .71113 .16411 .72207 .16016 .71702 .15283 Metetra
.664 .741 .908 r
.71702 .15283 .72207 .16016 .73304 .1562 .72803 .14884 Metetra
.664 .741 .908 r
.72803 .14884 .73304 .1562 .74406 .15222 .73907 .14483 Metetra
.664 .741 .908 r
.73907 .14483 .74406 .15222 .75512 .14823 .75016 .14081 Metetra
.664 .741 .908 r
.75016 .14081 .75512 .14823 .76622 .14422 .7613 .13677 Metetra
.664 .741 .908 r
.7613 .13677 .76622 .14422 .77737 .14019 .77247 .13272 Metetra
.664 .741 .908 r
.13769 .3547 .1441 .36067 .153 .35745 .14661 .35146 Metetra
.664 .741 .908 r
.14661 .35146 .153 .35745 .16193 .35421 .15555 .3482 Metetra
.664 .741 .908 r
.15555 .3482 .16193 .35421 .17089 .35095 .16453 .34492 Metetra
.664 .741 .908 r
.16453 .34492 .17089 .35095 .17988 .34769 .17354 .34164 Metetra
.664 .741 .908 r
.17354 .34164 .17988 .34769 .18891 .34442 .18259 .33834 Metetra
.664 .741 .908 r
.18259 .33834 .18891 .34442 .19796 .34113 .19166 .33504 Metetra
.664 .741 .908 r
.19166 .33504 .19796 .34113 .20705 .33784 .20077 .33172 Metetra
.664 .741 .908 r
.20077 .33172 .20705 .33784 .21617 .33453 .2099 .32839 Metetra
.664 .741 .908 r
.2099 .32839 .21617 .33453 .22532 .33121 .21907 .32505 Metetra
.664 .741 .908 r
.21907 .32505 .22532 .33121 .23451 .32788 .22828 .32169 Metetra
.664 .741 .908 r
.22828 .32169 .23451 .32788 .24372 .32453 .23751 .31833 Metetra
.664 .741 .908 r
.23751 .31833 .24372 .32453 .25297 .32118 .24678 .31495 Metetra
.664 .741 .908 r
.24678 .31495 .25297 .32118 .26225 .31781 .25608 .31156 Metetra
.664 .741 .908 r
.25608 .31156 .26225 .31781 .27157 .31443 .26542 .30816 Metetra
.664 .741 .908 r
.26542 .30816 .27157 .31443 .28092 .31104 .27479 .30475 Metetra
.664 .741 .908 r
.27479 .30475 .28092 .31104 .2903 .30764 .28419 .30132 Metetra
.664 .741 .908 r
.28419 .30132 .2903 .30764 .29971 .30422 .29362 .29788 Metetra
.664 .741 .908 r
.29362 .29788 .29971 .30422 .30916 .30079 .30309 .29443 Metetra
.664 .741 .908 r
.30309 .29443 .30916 .30079 .31865 .29735 .3126 .29097 Metetra
.664 .741 .908 r
.3126 .29097 .31865 .29735 .32816 .2939 .32213 .28749 Metetra
.664 .741 .908 r
.32213 .28749 .32816 .2939 .33771 .29044 .33171 .28401 Metetra
.664 .741 .908 r
.33171 .28401 .33771 .29044 .3473 .28696 .34131 .28051 Metetra
.664 .741 .908 r
.34131 .28051 .3473 .28696 .35692 .28347 .35095 .27699 Metetra
.664 .741 .908 r
.35095 .27699 .35692 .28347 .36657 .27997 .36063 .27347 Metetra
.664 .741 .908 r
.36063 .27347 .36657 .27997 .37627 .27645 .37034 .26993 Metetra
.664 .741 .908 r
.37034 .26993 .37627 .27645 .38599 .27292 .38009 .26638 Metetra
.664 .741 .908 r
.38009 .26638 .38599 .27292 .39575 .26938 .38987 .26281 Metetra
.664 .741 .908 r
.38987 .26281 .39575 .26938 .40555 .26583 .39969 .25923 Metetra
.664 .741 .908 r
.39969 .25923 .40555 .26583 .41538 .26226 .40955 .25564 Metetra
.664 .741 .908 r
.40955 .25564 .41538 .26226 .42525 .25868 .41944 .25204 Metetra
.664 .741 .908 r
.41944 .25204 .42525 .25868 .43515 .25509 .42937 .24842 Metetra
.664 .741 .908 r
.42937 .24842 .43515 .25509 .44509 .25148 .43933 .24479 Metetra
.664 .741 .908 r
.43933 .24479 .44509 .25148 .45507 .24786 .44933 .24114 Metetra
.664 .741 .908 r
.44933 .24114 .45507 .24786 .46509 .24423 .45937 .23749 Metetra
.664 .741 .908 r
.45937 .23749 .46509 .24423 .47514 .24058 .46944 .23382 Metetra
.664 .741 .908 r
.46944 .23382 .47514 .24058 .48523 .23692 .47956 .23013 Metetra
.664 .741 .908 r
.47956 .23013 .48523 .23692 .49535 .23325 .48971 .22643 Metetra
.664 .741 .908 r
.48971 .22643 .49535 .23325 .50551 .22956 .49989 .22272 Metetra
.664 .741 .908 r
.49989 .22272 .50551 .22956 .51572 .22586 .51012 .21899 Metetra
.664 .741 .908 r
.51012 .21899 .51572 .22586 .52596 .22215 .52038 .21525 Metetra
.664 .741 .908 r
.52038 .21525 .52596 .22215 .53623 .21842 .53069 .2115 Metetra
.664 .741 .908 r
.53069 .2115 .53623 .21842 .54655 .21468 .54103 .20773 Metetra
.664 .741 .908 r
.54103 .20773 .54655 .21468 .5569 .21092 .55141 .20395 Metetra
.664 .741 .908 r
.55141 .20395 .5569 .21092 .5673 .20715 .56183 .20015 Metetra
.664 .741 .908 r
.56183 .20015 .5673 .20715 .57773 .20336 .57229 .19634 Metetra
.664 .741 .908 r
.57229 .19634 .57773 .20336 .5882 .19957 .58279 .19251 Metetra
.664 .741 .908 r
.58279 .19251 .5882 .19957 .59871 .19575 .59332 .18867 Metetra
.664 .741 .908 r
.59332 .18867 .59871 .19575 .60927 .19192 .6039 .18482 Metetra
.664 .741 .908 r
.6039 .18482 .60927 .19192 .61986 .18808 .61452 .18095 Metetra
.664 .741 .908 r
.61452 .18095 .61986 .18808 .63049 .18422 .62518 .17707 Metetra
.664 .741 .908 r
.62518 .17707 .63049 .18422 .64116 .18035 .63588 .17317 Metetra
.664 .741 .908 r
.63588 .17317 .64116 .18035 .65188 .17647 .64662 .16925 Metetra
.664 .741 .908 r
.64662 .16925 .65188 .17647 .66263 .17257 .6574 .16532 Metetra
.664 .741 .908 r
.6574 .16532 .66263 .17257 .67342 .16865 .66823 .16138 Metetra
.664 .741 .908 r
.66823 .16138 .67342 .16865 .68426 .16472 .67909 .15742 Metetra
.664 .741 .908 r
.67909 .15742 .68426 .16472 .69514 .16077 .69 .15345 Metetra
.664 .741 .908 r
.69 .15345 .69514 .16077 .70606 .15681 .70095 .14946 Metetra
.664 .741 .908 r
.70095 .14946 .70606 .15681 .71702 .15283 .71194 .14545 Metetra
.664 .741 .908 r
.71194 .14545 .71702 .15283 .72803 .14884 .72297 .14143 Metetra
.664 .741 .908 r
.72297 .14143 .72803 .14884 .73907 .14483 .73405 .13739 Metetra
.664 .741 .908 r
.73405 .13739 .73907 .14483 .75016 .14081 .74517 .13334 Metetra
.664 .741 .908 r
.74517 .13334 .75016 .14081 .7613 .13677 .75634 .12927 Metetra
.664 .741 .908 r
.75634 .12927 .7613 .13677 .77247 .13272 .76754 .12519 Metetra
.664 .741 .908 r
.13124 .3487 .13769 .3547 .14661 .35146 .14017 .34543 Metetra
.664 .741 .908 r
.14017 .34543 .14661 .35146 .15555 .3482 .14914 .34215 Metetra
.664 .741 .908 r
.14914 .34215 .15555 .3482 .16453 .34492 .15813 .33885 Metetra
.664 .741 .908 r
.15813 .33885 .16453 .34492 .17354 .34164 .16716 .33555 Metetra
.664 .741 .908 r
.16716 .33555 .17354 .34164 .18259 .33834 .17622 .33223 Metetra
.664 .741 .908 r
.17622 .33223 .18259 .33834 .19166 .33504 .18532 .3289 Metetra
.664 .741 .908 r
.18532 .3289 .19166 .33504 .20077 .33172 .19444 .32556 Metetra
.664 .741 .908 r
.19444 .32556 .20077 .33172 .2099 .32839 .2036 .32221 Metetra
.664 .741 .908 r
.2036 .32221 .2099 .32839 .21907 .32505 .21279 .31885 Metetra
.664 .741 .908 r
.21279 .31885 .21907 .32505 .22828 .32169 .22201 .31547 Metetra
.664 .741 .908 r
.22201 .31547 .22828 .32169 .23751 .31833 .23126 .31208 Metetra
.664 .741 .908 r
.23126 .31208 .23751 .31833 .24678 .31495 .24055 .30869 Metetra
.664 .741 .908 r
.24055 .30869 .24678 .31495 .25608 .31156 .24987 .30527 Metetra
.664 .741 .908 r
.24987 .30527 .25608 .31156 .26542 .30816 .25923 .30185 Metetra
.664 .741 .908 r
.25923 .30185 .26542 .30816 .27479 .30475 .26861 .29841 Metetra
.664 .741 .908 r
.26861 .29841 .27479 .30475 .28419 .30132 .27804 .29496 Metetra
.664 .741 .908 r
.27804 .29496 .28419 .30132 .29362 .29788 .28749 .2915 Metetra
.664 .741 .908 r
.28749 .2915 .29362 .29788 .30309 .29443 .29698 .28803 Metetra
.664 .741 .908 r
.29698 .28803 .30309 .29443 .3126 .29097 .30651 .28454 Metetra
.664 .741 .908 r
.30651 .28454 .3126 .29097 .32213 .28749 .31606 .28104 Metetra
.664 .741 .908 r
.31606 .28104 .32213 .28749 .33171 .28401 .32566 .27753 Metetra
.664 .741 .908 r
.32566 .27753 .33171 .28401 .34131 .28051 .33529 .27401 Metetra
.664 .741 .908 r
.33529 .27401 .34131 .28051 .35095 .27699 .34495 .27047 Metetra
.664 .741 .908 r
.34495 .27047 .35095 .27699 .36063 .27347 .35465 .26692 Metetra
.664 .741 .908 r
.35465 .26692 .36063 .27347 .37034 .26993 .36438 .26336 Metetra
.664 .741 .908 r
.36438 .26336 .37034 .26993 .38009 .26638 .37415 .25978 Metetra
.664 .741 .908 r
.37415 .25978 .38009 .26638 .38987 .26281 .38396 .25619 Metetra
.664 .741 .908 r
.38396 .25619 .38987 .26281 .39969 .25923 .3938 .25259 Metetra
.664 .741 .908 r
.3938 .25259 .39969 .25923 .40955 .25564 .40367 .24898 Metetra
.664 .741 .908 r
.40367 .24898 .40955 .25564 .41944 .25204 .41359 .24535 Metetra
.664 .741 .908 r
.41359 .24535 .41944 .25204 .42937 .24842 .42354 .24171 Metetra
.664 .741 .908 r
.42354 .24171 .42937 .24842 .43933 .24479 .43353 .23805 Metetra
.664 .741 .908 r
.43353 .23805 .43933 .24479 .44933 .24114 .44355 .23438 Metetra
.664 .741 .908 r
.44355 .23438 .44933 .24114 .45937 .23749 .45361 .2307 Metetra
.664 .741 .908 r
.45361 .2307 .45937 .23749 .46944 .23382 .46371 .227 Metetra
.664 .741 .908 r
.46371 .227 .46944 .23382 .47956 .23013 .47385 .22329 Metetra
.664 .741 .908 r
.47385 .22329 .47956 .23013 .48971 .22643 .48402 .21957 Metetra
.664 .741 .908 r
.48402 .21957 .48971 .22643 .49989 .22272 .49423 .21583 Metetra
.664 .741 .908 r
.49423 .21583 .49989 .22272 .51012 .21899 .50449 .21208 Metetra
.664 .741 .908 r
.50449 .21208 .51012 .21899 .52038 .21525 .51477 .20831 Metetra
.664 .741 .908 r
.51477 .20831 .52038 .21525 .53069 .2115 .5251 .20453 Metetra
.664 .741 .908 r
.5251 .20453 .53069 .2115 .54103 .20773 .53547 .20074 Metetra
.664 .741 .908 r
.53547 .20074 .54103 .20773 .55141 .20395 .54588 .19693 Metetra
.664 .741 .908 r
.54588 .19693 .55141 .20395 .56183 .20015 .55632 .1931 Metetra
.664 .741 .908 r
.55632 .1931 .56183 .20015 .57229 .19634 .56681 .18927 Metetra
.664 .741 .908 r
.56681 .18927 .57229 .19634 .58279 .19251 .57733 .18541 Metetra
.664 .741 .908 r
.57733 .18541 .58279 .19251 .59332 .18867 .5879 .18155 Metetra
.664 .741 .908 r
.5879 .18155 .59332 .18867 .6039 .18482 .5985 .17766 Metetra
.664 .741 .908 r
.5985 .17766 .6039 .18482 .61452 .18095 .60915 .17377 Metetra
.664 .741 .908 r
.60915 .17377 .61452 .18095 .62518 .17707 .61983 .16986 Metetra
.664 .741 .908 r
.61983 .16986 .62518 .17707 .63588 .17317 .63056 .16593 Metetra
.664 .741 .908 r
.63056 .16593 .63588 .17317 .64662 .16925 .64133 .16199 Metetra
.664 .741 .908 r
.64133 .16199 .64662 .16925 .6574 .16532 .65214 .15803 Metetra
.664 .741 .908 r
.65214 .15803 .6574 .16532 .66823 .16138 .66299 .15406 Metetra
.664 .741 .908 r
.66299 .15406 .66823 .16138 .67909 .15742 .67389 .15007 Metetra
.664 .741 .908 r
.67389 .15007 .67909 .15742 .69 .15345 .68482 .14607 Metetra
.664 .741 .908 r
.68482 .14607 .69 .15345 .70095 .14946 .6958 .14205 Metetra
.664 .741 .908 r
.6958 .14205 .70095 .14946 .71194 .14545 .70682 .13802 Metetra
.664 .741 .908 r
.70682 .13802 .71194 .14545 .72297 .14143 .71789 .13397 Metetra
.664 .741 .908 r
.71789 .13397 .72297 .14143 .73405 .13739 .72899 .1299 Metetra
.664 .741 .908 r
.72899 .1299 .73405 .13739 .74517 .13334 .74014 .12582 Metetra
.664 .741 .908 r
.74014 .12582 .74517 .13334 .75634 .12927 .75134 .12172 Metetra
.664 .741 .908 r
.75134 .12172 .75634 .12927 .76754 .12519 .76258 .11761 Metetra
.664 .741 .908 r
.12474 .34265 .13124 .3487 .14017 .34543 .1337 .33936 Metetra
.664 .741 .908 r
.1337 .33936 .14017 .34543 .14914 .34215 .14268 .33606 Metetra
.664 .741 .908 r
.14268 .33606 .14914 .34215 .15813 .33885 .15169 .33274 Metetra
.664 .741 .908 r
.15169 .33274 .15813 .33885 .16716 .33555 .16074 .32942 Metetra
.664 .741 .908 r
.16074 .32942 .16716 .33555 .17622 .33223 .16982 .32608 Metetra
.664 .741 .908 r
.16982 .32608 .17622 .33223 .18532 .3289 .17893 .32273 Metetra
.664 .741 .908 r
.17893 .32273 .18532 .3289 .19444 .32556 .18807 .31937 Metetra
.664 .741 .908 r
.18807 .31937 .19444 .32556 .2036 .32221 .19725 .31599 Metetra
.664 .741 .908 r
.19725 .31599 .2036 .32221 .21279 .31885 .20646 .31261 Metetra
.664 .741 .908 r
.20646 .31261 .21279 .31885 .22201 .31547 .2157 .30921 Metetra
.664 .741 .908 r
.2157 .30921 .22201 .31547 .23126 .31208 .22497 .3058 Metetra
.664 .741 .908 r
.22497 .3058 .23126 .31208 .24055 .30869 .23428 .30238 Metetra
.664 .741 .908 r
.23428 .30238 .24055 .30869 .24987 .30527 .24362 .29894 Metetra
.664 .741 .908 r
.24362 .29894 .24987 .30527 .25923 .30185 .25299 .2955 Metetra
.664 .741 .908 r
.25299 .2955 .25923 .30185 .26861 .29841 .2624 .29204 Metetra
.664 .741 .908 r
.2624 .29204 .26861 .29841 .27804 .29496 .27184 .28856 Metetra
.664 .741 .908 r
.27184 .28856 .27804 .29496 .28749 .2915 .28132 .28508 Metetra
.664 .741 .908 r
.28132 .28508 .28749 .2915 .29698 .28803 .29083 .28158 Metetra
.664 .741 .908 r
.29083 .28158 .29698 .28803 .30651 .28454 .30038 .27807 Metetra
.664 .741 .908 r
.30038 .27807 .30651 .28454 .31606 .28104 .30995 .27455 Metetra
.664 .741 .908 r
.30995 .27455 .31606 .28104 .32566 .27753 .31957 .27102 Metetra
.664 .741 .908 r
.31957 .27102 .32566 .27753 .33529 .27401 .32922 .26747 Metetra
.664 .741 .908 r
.32922 .26747 .33529 .27401 .34495 .27047 .3389 .26391 Metetra
.664 .741 .908 r
.3389 .26391 .34495 .27047 .35465 .26692 .34862 .26033 Metetra
.664 .741 .908 r
.34862 .26033 .35465 .26692 .36438 .26336 .35838 .25675 Metetra
.664 .741 .908 r
.35838 .25675 .36438 .26336 .37415 .25978 .36817 .25315 Metetra
.664 .741 .908 r
.36817 .25315 .37415 .25978 .38396 .25619 .378 .24953 Metetra
.664 .741 .908 r
.378 .24953 .38396 .25619 .3938 .25259 .38786 .24591 Metetra
.664 .741 .908 r
.38786 .24591 .3938 .25259 .40367 .24898 .39776 .24227 Metetra
.664 .741 .908 r
.39776 .24227 .40367 .24898 .41359 .24535 .4077 .23861 Metetra
.664 .741 .908 r
.4077 .23861 .41359 .24535 .42354 .24171 .41767 .23495 Metetra
.664 .741 .908 r
.41767 .23495 .42354 .24171 .43353 .23805 .42768 .23127 Metetra
.664 .741 .908 r
.42768 .23127 .43353 .23805 .44355 .23438 .43773 .22757 Metetra
.664 .741 .908 r
.43773 .22757 .44355 .23438 .45361 .2307 .44782 .22386 Metetra
.664 .741 .908 r
.44782 .22386 .45361 .2307 .46371 .227 .45794 .22014 Metetra
.664 .741 .908 r
.45794 .22014 .46371 .227 .47385 .22329 .4681 .21641 Metetra
.664 .741 .908 r
.4681 .21641 .47385 .22329 .48402 .21957 .4783 .21266 Metetra
.664 .741 .908 r
.4783 .21266 .48402 .21957 .49423 .21583 .48854 .20889 Metetra
.664 .741 .908 r
.48854 .20889 .49423 .21583 .50449 .21208 .49881 .20511 Metetra
.664 .741 .908 r
.49881 .20511 .50449 .21208 .51477 .20831 .50913 .20132 Metetra
.664 .741 .908 r
.50913 .20132 .51477 .20831 .5251 .20453 .51948 .19751 Metetra
.664 .741 .908 r
.51948 .19751 .5251 .20453 .53547 .20074 .52987 .19369 Metetra
.664 .741 .908 r
.52987 .19369 .53547 .20074 .54588 .19693 .5403 .18986 Metetra
.664 .741 .908 r
.5403 .18986 .54588 .19693 .55632 .1931 .55077 .18601 Metetra
.664 .741 .908 r
.55077 .18601 .55632 .1931 .56681 .18927 .56129 .18214 Metetra
.664 .741 .908 r
.56129 .18214 .56681 .18927 .57733 .18541 .57184 .17826 Metetra
.664 .741 .908 r
.57184 .17826 .57733 .18541 .5879 .18155 .58243 .17437 Metetra
.664 .741 .908 r
.58243 .17437 .5879 .18155 .5985 .17766 .59306 .17046 Metetra
.664 .741 .908 r
.59306 .17046 .5985 .17766 .60915 .17377 .60373 .16653 Metetra
.664 .741 .908 r
.60373 .16653 .60915 .17377 .61983 .16986 .61445 .16259 Metetra
.664 .741 .908 r
.61445 .16259 .61983 .16986 .63056 .16593 .6252 .15864 Metetra
.664 .741 .908 r
.6252 .15864 .63056 .16593 .64133 .16199 .636 .15467 Metetra
.664 .741 .908 r
.636 .15467 .64133 .16199 .65214 .15803 .64684 .15069 Metetra
.664 .741 .908 r
.64684 .15069 .65214 .15803 .66299 .15406 .65772 .14668 Metetra
.664 .741 .908 r
.65772 .14668 .66299 .15406 .67389 .15007 .66864 .14267 Metetra
.664 .741 .908 r
.66864 .14267 .67389 .15007 .68482 .14607 .67961 .13864 Metetra
.664 .741 .908 r
.67961 .13864 .68482 .14607 .6958 .14205 .69061 .13459 Metetra
.664 .741 .908 r
.69061 .13459 .6958 .14205 .70682 .13802 .70167 .13053 Metetra
.664 .741 .908 r
.70167 .13053 .70682 .13802 .71789 .13397 .71276 .12645 Metetra
.664 .741 .908 r
.71276 .12645 .71789 .13397 .72899 .1299 .7239 .12235 Metetra
.664 .741 .908 r
.7239 .12235 .72899 .1299 .74014 .12582 .73508 .11824 Metetra
.664 .741 .908 r
.73508 .11824 .74014 .12582 .75134 .12172 .7463 .11411 Metetra
.664 .741 .908 r
.7463 .11411 .75134 .12172 .76258 .11761 .75757 .10997 Metetra
.664 .741 .908 r
.11821 .33657 .12474 .34265 .1337 .33936 .12718 .33325 Metetra
.664 .741 .908 r
.12718 .33325 .1337 .33936 .14268 .33606 .13618 .32993 Metetra
.664 .741 .908 r
.13618 .32993 .14268 .33606 .15169 .33274 .14521 .32659 Metetra
.664 .741 .908 r
.14521 .32659 .15169 .33274 .16074 .32942 .15428 .32324 Metetra
.664 .741 .908 r
.15428 .32324 .16074 .32942 .16982 .32608 .16337 .31988 Metetra
.664 .741 .908 r
.16337 .31988 .16982 .32608 .17893 .32273 .1725 .31651 Metetra
.664 .741 .908 r
.1725 .31651 .17893 .32273 .18807 .31937 .18166 .31313 Metetra
.664 .741 .908 r
.18166 .31313 .18807 .31937 .19725 .31599 .19086 .30973 Metetra
.664 .741 .908 r
.19086 .30973 .19725 .31599 .20646 .31261 .20009 .30632 Metetra
.664 .741 .908 r
.20009 .30632 .20646 .31261 .2157 .30921 .20935 .3029 Metetra
.664 .741 .908 r
.20935 .3029 .2157 .30921 .22497 .3058 .21864 .29947 Metetra
.664 .741 .908 r
.21864 .29947 .22497 .3058 .23428 .30238 .22797 .29603 Metetra
.664 .741 .908 r
.22797 .29603 .23428 .30238 .24362 .29894 .23733 .29257 Metetra
.664 .741 .908 r
.23733 .29257 .24362 .29894 .25299 .2955 .24672 .2891 Metetra
.664 .741 .908 r
.24672 .2891 .25299 .2955 .2624 .29204 .25615 .28562 Metetra
.664 .741 .908 r
.25615 .28562 .2624 .29204 .27184 .28856 .26561 .28212 Metetra
.664 .741 .908 r
.26561 .28212 .27184 .28856 .28132 .28508 .27511 .27862 Metetra
.664 .741 .908 r
.27511 .27862 .28132 .28508 .29083 .28158 .28464 .27509 Metetra
.664 .741 .908 r
.28464 .27509 .29083 .28158 .30038 .27807 .2942 .27156 Metetra
.664 .741 .908 r
.2942 .27156 .30038 .27807 .30995 .27455 .3038 .26802 Metetra
.664 .741 .908 r
.3038 .26802 .30995 .27455 .31957 .27102 .31344 .26446 Metetra
.664 .741 .908 r
.31344 .26446 .31957 .27102 .32922 .26747 .32311 .26089 Metetra
.664 .741 .908 r
.32311 .26089 .32922 .26747 .3389 .26391 .33282 .2573 Metetra
.664 .741 .908 r
.33282 .2573 .3389 .26391 .34862 .26033 .34256 .2537 Metetra
.664 .741 .908 r
.34256 .2537 .34862 .26033 .35838 .25675 .35234 .25009 Metetra
.664 .741 .908 r
.35234 .25009 .35838 .25675 .36817 .25315 .36215 .24647 Metetra
.664 .741 .908 r
.36215 .24647 .36817 .25315 .378 .24953 .372 .24283 Metetra
.664 .741 .908 r
.372 .24283 .378 .24953 .38786 .24591 .38189 .23918 Metetra
.664 .741 .908 r
.38189 .23918 .38786 .24591 .39776 .24227 .39181 .23551 Metetra
.664 .741 .908 r
.39181 .23551 .39776 .24227 .4077 .23861 .40177 .23183 Metetra
.664 .741 .908 r
.40177 .23183 .4077 .23861 .41767 .23495 .41177 .22814 Metetra
.664 .741 .908 r
.41177 .22814 .41767 .23495 .42768 .23127 .4218 .22443 Metetra
.664 .741 .908 r
.4218 .22443 .42768 .23127 .43773 .22757 .43187 .22071 Metetra
.664 .741 .908 r
.43187 .22071 .43773 .22757 .44782 .22386 .44198 .21698 Metetra
.664 .741 .908 r
.44198 .21698 .44782 .22386 .45794 .22014 .45213 .21323 Metetra
.664 .741 .908 r
.45213 .21323 .45794 .22014 .4681 .21641 .46231 .20947 Metetra
.664 .741 .908 r
.46231 .20947 .4681 .21641 .4783 .21266 .47254 .2057 Metetra
.664 .741 .908 r
.47254 .2057 .4783 .21266 .48854 .20889 .4828 .2019 Metetra
.664 .741 .908 r
.4828 .2019 .48854 .20889 .49881 .20511 .4931 .1981 Metetra
.664 .741 .908 r
.4931 .1981 .49881 .20511 .50913 .20132 .50344 .19428 Metetra
.664 .741 .908 r
.50344 .19428 .50913 .20132 .51948 .19751 .51382 .19045 Metetra
.664 .741 .908 r
.51382 .19045 .51948 .19751 .52987 .19369 .52423 .1866 Metetra
.664 .741 .908 r
.52423 .1866 .52987 .19369 .5403 .18986 .53469 .18274 Metetra
.664 .741 .908 r
.53469 .18274 .5403 .18986 .55077 .18601 .54519 .17886 Metetra
.664 .741 .908 r
.54519 .17886 .55077 .18601 .56129 .18214 .55573 .17497 Metetra
.664 .741 .908 r
.55573 .17497 .56129 .18214 .57184 .17826 .56631 .17106 Metetra
.664 .741 .908 r
.56631 .17106 .57184 .17826 .58243 .17437 .57692 .16714 Metetra
.664 .741 .908 r
.57692 .16714 .58243 .17437 .59306 .17046 .58758 .1632 Metetra
.664 .741 .908 r
.58758 .1632 .59306 .17046 .60373 .16653 .59828 .15925 Metetra
.664 .741 .908 r
.59828 .15925 .60373 .16653 .61445 .16259 .60903 .15528 Metetra
.664 .741 .908 r
.60903 .15528 .61445 .16259 .6252 .15864 .61981 .1513 Metetra
.664 .741 .908 r
.61981 .1513 .6252 .15864 .636 .15467 .63063 .1473 Metetra
.664 .741 .908 r
.63063 .1473 .636 .15467 .64684 .15069 .6415 .14329 Metetra
.664 .741 .908 r
.6415 .14329 .64684 .15069 .65772 .14668 .65241 .13926 Metetra
.664 .741 .908 r
.65241 .13926 .65772 .14668 .66864 .14267 .66336 .13521 Metetra
.664 .741 .908 r
.66336 .13521 .66864 .14267 .67961 .13864 .67436 .13115 Metetra
.664 .741 .908 r
.67436 .13115 .67961 .13864 .69061 .13459 .68539 .12708 Metetra
.664 .741 .908 r
.68539 .12708 .69061 .13459 .70167 .13053 .69647 .12298 Metetra
.664 .741 .908 r
.69647 .12298 .70167 .13053 .71276 .12645 .7076 .11888 Metetra
.664 .741 .908 r
.7076 .11888 .71276 .12645 .7239 .12235 .71876 .11475 Metetra
.664 .741 .908 r
.71876 .11475 .7239 .12235 .73508 .11824 .72998 .11061 Metetra
.664 .741 .908 r
.72998 .11061 .73508 .11824 .7463 .11411 .74123 .10645 Metetra
.664 .741 .908 r
.74123 .10645 .7463 .11411 .75757 .10997 .75253 .10228 Metetra
.664 .741 .908 r
.11163 .33044 .11821 .33657 .12718 .33325 .12062 .32711 Metetra
.664 .741 .908 r
.12062 .32711 .12718 .33325 .13618 .32993 .12964 .32376 Metetra
.664 .741 .908 r
.12964 .32376 .13618 .32993 .14521 .32659 .13869 .3204 Metetra
.664 .741 .908 r
.13869 .3204 .14521 .32659 .15428 .32324 .14777 .31703 Metetra
.664 .741 .908 r
.14777 .31703 .15428 .32324 .16337 .31988 .15688 .31365 Metetra
.664 .741 .908 r
.15688 .31365 .16337 .31988 .1725 .31651 .16603 .31026 Metetra
.664 .741 .908 r
.16603 .31026 .1725 .31651 .18166 .31313 .17521 .30685 Metetra
.664 .741 .908 r
.17521 .30685 .18166 .31313 .19086 .30973 .18443 .30343 Metetra
.664 .741 .908 r
.18443 .30343 .19086 .30973 .20009 .30632 .19367 .3 Metetra
.664 .741 .908 r
.19367 .3 .20009 .30632 .20935 .3029 .20295 .29656 Metetra
.664 .741 .908 r
.20295 .29656 .20935 .3029 .21864 .29947 .21226 .2931 Metetra
.664 .741 .908 r
.21226 .2931 .21864 .29947 .22797 .29603 .22161 .28963 Metetra
.664 .741 .908 r
.22161 .28963 .22797 .29603 .23733 .29257 .23099 .28615 Metetra
.664 .741 .908 r
.23099 .28615 .23733 .29257 .24672 .2891 .2404 .28266 Metetra
.664 .741 .908 r
.2404 .28266 .24672 .2891 .25615 .28562 .24985 .27916 Metetra
.664 .741 .908 r
.24985 .27916 .25615 .28562 .26561 .28212 .25934 .27564 Metetra
.664 .741 .908 r
.25934 .27564 .26561 .28212 .27511 .27862 .26885 .27211 Metetra
.664 .741 .908 r
.26885 .27211 .27511 .27862 .28464 .27509 .2784 .26856 Metetra
.664 .741 .908 r
.2784 .26856 .28464 .27509 .2942 .27156 .28799 .26501 Metetra
.664 .741 .908 r
.28799 .26501 .2942 .27156 .3038 .26802 .29761 .26144 Metetra
.664 .741 .908 r
.29761 .26144 .3038 .26802 .31344 .26446 .30727 .25785 Metetra
.664 .741 .908 r
.30727 .25785 .31344 .26446 .32311 .26089 .31696 .25426 Metetra
.664 .741 .908 r
.31696 .25426 .32311 .26089 .33282 .2573 .32669 .25065 Metetra
.664 .741 .908 r
.32669 .25065 .33282 .2573 .34256 .2537 .33645 .24702 Metetra
.664 .741 .908 r
.33645 .24702 .34256 .2537 .35234 .25009 .34625 .24339 Metetra
.664 .741 .908 r
.34625 .24339 .35234 .25009 .36215 .24647 .35609 .23974 Metetra
.664 .741 .908 r
.35609 .23974 .36215 .24647 .372 .24283 .36596 .23608 Metetra
.664 .741 .908 r
.36596 .23608 .372 .24283 .38189 .23918 .37587 .2324 Metetra
.664 .741 .908 r
.37587 .2324 .38189 .23918 .39181 .23551 .38581 .22871 Metetra
.664 .741 .908 r
.38581 .22871 .39181 .23551 .40177 .23183 .3958 .22501 Metetra
.664 .741 .908 r
.3958 .22501 .40177 .23183 .41177 .22814 .40582 .22129 Metetra
.664 .741 .908 r
.40582 .22129 .41177 .22814 .4218 .22443 .41587 .21756 Metetra
.664 .741 .908 r
.41587 .21756 .4218 .22443 .43187 .22071 .42597 .21381 Metetra
.664 .741 .908 r
.42597 .21381 .43187 .22071 .44198 .21698 .4361 .21005 Metetra
.664 .741 .908 r
.4361 .21005 .44198 .21698 .45213 .21323 .44627 .20628 Metetra
.664 .741 .908 r
.44627 .20628 .45213 .21323 .46231 .20947 .45648 .20249 Metetra
.664 .741 .908 r
.45648 .20249 .46231 .20947 .47254 .2057 .46673 .19869 Metetra
.664 .741 .908 r
.46673 .19869 .47254 .2057 .4828 .2019 .47702 .19487 Metetra
.664 .741 .908 r
.47702 .19487 .4828 .2019 .4931 .1981 .48734 .19104 Metetra
.664 .741 .908 r
.48734 .19104 .4931 .1981 .50344 .19428 .49771 .18719 Metetra
.664 .741 .908 r
.49771 .18719 .50344 .19428 .51382 .19045 .50811 .18333 Metetra
.664 .741 .908 r
.50811 .18333 .51382 .19045 .52423 .1866 .51856 .17946 Metetra
.664 .741 .908 r
.51856 .17946 .52423 .1866 .53469 .18274 .52904 .17557 Metetra
.664 .741 .908 r
.52904 .17557 .53469 .18274 .54519 .17886 .53957 .17166 Metetra
.664 .741 .908 r
.53957 .17166 .54519 .17886 .55573 .17497 .55013 .16774 Metetra
.664 .741 .908 r
.55013 .16774 .55573 .17497 .56631 .17106 .56073 .16381 Metetra
.664 .741 .908 r
.56073 .16381 .56631 .17106 .57692 .16714 .57138 .15986 Metetra
.664 .741 .908 r
.57138 .15986 .57692 .16714 .58758 .1632 .58207 .15589 Metetra
.664 .741 .908 r
.58207 .15589 .58758 .1632 .59828 .15925 .59279 .15191 Metetra
.664 .741 .908 r
.59279 .15191 .59828 .15925 .60903 .15528 .60356 .14792 Metetra
.664 .741 .908 r
.60356 .14792 .60903 .15528 .61981 .1513 .61438 .14391 Metetra
.664 .741 .908 r
.61438 .14391 .61981 .1513 .63063 .1473 .62523 .13988 Metetra
.664 .741 .908 r
.62523 .13988 .63063 .1473 .6415 .14329 .63612 .13584 Metetra
.664 .741 .908 r
.63612 .13584 .6415 .14329 .65241 .13926 .64706 .13178 Metetra
.664 .741 .908 r
.64706 .13178 .65241 .13926 .66336 .13521 .65804 .1277 Metetra
.664 .741 .908 r
.65804 .1277 .66336 .13521 .67436 .13115 .66907 .12361 Metetra
.664 .741 .908 r
.66907 .12361 .67436 .13115 .68539 .12708 .68013 .11951 Metetra
.664 .741 .908 r
.68013 .11951 .68539 .12708 .69647 .12298 .69124 .11539 Metetra
.664 .741 .908 r
.69124 .11539 .69647 .12298 .7076 .11888 .7024 .11125 Metetra
.664 .741 .908 r
.7024 .11125 .7076 .11888 .71876 .11475 .71359 .10709 Metetra
.664 .741 .908 r
.71359 .10709 .71876 .11475 .72998 .11061 .72484 .10292 Metetra
.664 .741 .908 r
.72484 .10292 .72998 .11061 .74123 .10645 .73612 .09873 Metetra
.664 .741 .908 r
.73612 .09873 .74123 .10645 .75253 .10228 .74745 .09453 Metetra
.664 .741 .908 r
.10501 .32428 .11163 .33044 .12062 .32711 .11401 .32092 Metetra
.664 .741 .908 r
.11401 .32092 .12062 .32711 .12964 .32376 .12305 .31755 Metetra
.664 .741 .908 r
.12305 .31755 .12964 .32376 .13869 .3204 .13212 .31417 Metetra
.664 .741 .908 r
.13212 .31417 .13869 .3204 .14777 .31703 .14122 .31078 Metetra
.664 .741 .908 r
.14122 .31078 .14777 .31703 .15688 .31365 .15035 .30737 Metetra
.664 .741 .908 r
.15035 .30737 .15688 .31365 .16603 .31026 .15952 .30396 Metetra
.664 .741 .908 r
.15952 .30396 .16603 .31026 .17521 .30685 .16872 .30053 Metetra
.664 .741 .908 r
.16872 .30053 .17521 .30685 .18443 .30343 .17795 .29709 Metetra
.664 .741 .908 r
.17795 .29709 .18443 .30343 .19367 .3 .18722 .29363 Metetra
.664 .741 .908 r
.18722 .29363 .19367 .3 .20295 .29656 .19651 .29017 Metetra
.664 .741 .908 r
.19651 .29017 .20295 .29656 .21226 .2931 .20585 .28669 Metetra
.664 .741 .908 r
.20585 .28669 .21226 .2931 .22161 .28963 .21521 .2832 Metetra
.664 .741 .908 r
.21521 .2832 .22161 .28963 .23099 .28615 .22461 .2797 Metetra
.664 .741 .908 r
.22461 .2797 .23099 .28615 .2404 .28266 .23405 .27618 Metetra
.664 .741 .908 r
.23405 .27618 .2404 .28266 .24985 .27916 .24351 .27265 Metetra
.664 .741 .908 r
.24351 .27265 .24985 .27916 .25934 .27564 .25302 .26911 Metetra
.664 .741 .908 r
.25302 .26911 .25934 .27564 .26885 .27211 .26255 .26555 Metetra
.664 .741 .908 r
.26255 .26555 .26885 .27211 .2784 .26856 .27213 .26199 Metetra
.664 .741 .908 r
.27213 .26199 .2784 .26856 .28799 .26501 .28173 .2584 Metetra
.664 .741 .908 r
.28173 .2584 .28799 .26501 .29761 .26144 .29138 .25481 Metetra
.664 .741 .908 r
.29138 .25481 .29761 .26144 .30727 .25785 .30106 .2512 Metetra
.664 .741 .908 r
.30106 .2512 .30727 .25785 .31696 .25426 .31077 .24758 Metetra
.664 .741 .908 r
.31077 .24758 .31696 .25426 .32669 .25065 .32052 .24395 Metetra
.664 .741 .908 r
.32052 .24395 .32669 .25065 .33645 .24702 .3303 .2403 Metetra
.664 .741 .908 r
.3303 .2403 .33645 .24702 .34625 .24339 .34013 .23664 Metetra
.664 .741 .908 r
.34013 .23664 .34625 .24339 .35609 .23974 .34998 .23297 Metetra
.664 .741 .908 r
.34998 .23297 .35609 .23974 .36596 .23608 .35988 .22928 Metetra
.664 .741 .908 r
.35988 .22928 .36596 .23608 .37587 .2324 .36981 .22558 Metetra
.664 .741 .908 r
.36981 .22558 .37587 .2324 .38581 .22871 .37978 .22186 Metetra
.664 .741 .908 r
.37978 .22186 .38581 .22871 .3958 .22501 .38979 .21813 Metetra
.664 .741 .908 r
.38979 .21813 .3958 .22501 .40582 .22129 .39983 .21439 Metetra
.664 .741 .908 r
.39983 .21439 .40582 .22129 .41587 .21756 .40991 .21063 Metetra
.664 .741 .908 r
.40991 .21063 .41587 .21756 .42597 .21381 .42003 .20686 Metetra
.664 .741 .908 r
.42003 .20686 .42597 .21381 .4361 .21005 .43019 .20307 Metetra
.664 .741 .908 r
.43019 .20307 .4361 .21005 .44627 .20628 .44038 .19927 Metetra
.664 .741 .908 r
.44038 .19927 .44627 .20628 .45648 .20249 .45062 .19546 Metetra
.664 .741 .908 r
.45062 .19546 .45648 .20249 .46673 .19869 .46089 .19163 Metetra
.664 .741 .908 r
.46089 .19163 .46673 .19869 .47702 .19487 .4712 .18779 Metetra
.664 .741 .908 r
.4712 .18779 .47702 .19487 .48734 .19104 .48155 .18393 Metetra
.664 .741 .908 r
.48155 .18393 .48734 .19104 .49771 .18719 .49194 .18005 Metetra
.664 .741 .908 r
.49194 .18005 .49771 .18719 .50811 .18333 .50237 .17617 Metetra
.664 .741 .908 r
.50237 .17617 .50811 .18333 .51856 .17946 .51284 .17226 Metetra
.664 .741 .908 r
.51284 .17226 .51856 .17946 .52904 .17557 .52335 .16835 Metetra
.664 .741 .908 r
.52335 .16835 .52904 .17557 .53957 .17166 .5339 .16441 Metetra
.664 .741 .908 r
.5339 .16441 .53957 .17166 .55013 .16774 .54449 .16047 Metetra
.664 .741 .908 r
.54449 .16047 .55013 .16774 .56073 .16381 .55512 .1565 Metetra
.664 .741 .908 r
.55512 .1565 .56073 .16381 .57138 .15986 .5658 .15253 Metetra
.664 .741 .908 r
.5658 .15253 .57138 .15986 .58207 .15589 .57651 .14853 Metetra
.664 .741 .908 r
.57651 .14853 .58207 .15589 .59279 .15191 .58727 .14452 Metetra
.664 .741 .908 r
.58727 .14452 .59279 .15191 .60356 .14792 .59806 .1405 Metetra
.664 .741 .908 r
.59806 .1405 .60356 .14792 .61438 .14391 .6089 .13646 Metetra
.664 .741 .908 r
.6089 .13646 .61438 .14391 .62523 .13988 .61978 .1324 Metetra
.664 .741 .908 r
.61978 .1324 .62523 .13988 .63612 .13584 .63071 .12833 Metetra
.664 .741 .908 r
.63071 .12833 .63612 .13584 .64706 .13178 .64167 .12424 Metetra
.664 .741 .908 r
.64167 .12424 .64706 .13178 .65804 .1277 .65268 .12014 Metetra
.664 .741 .908 r
.65268 .12014 .65804 .1277 .66907 .12361 .66374 .11602 Metetra
.664 .741 .908 r
.66374 .11602 .66907 .12361 .68013 .11951 .67483 .11189 Metetra
.664 .741 .908 r
.67483 .11189 .68013 .11951 .69124 .11539 .68597 .10773 Metetra
.664 .741 .908 r
.68597 .10773 .69124 .11539 .7024 .11125 .69716 .10356 Metetra
.664 .741 .908 r
.69716 .10356 .7024 .11125 .71359 .10709 .70839 .09938 Metetra
.664 .741 .908 r
.70839 .09938 .71359 .10709 .72484 .10292 .71966 .09518 Metetra
.664 .741 .908 r
.71966 .09518 .72484 .10292 .73612 .09873 .73098 .09096 Metetra
.664 .741 .908 r
.73098 .09096 .73612 .09873 .74745 .09453 .74234 .08672 Metetra
.664 .741 .908 r
.09834 .31807 .10501 .32428 .11401 .32092 .10737 .31469 Metetra
.664 .741 .908 r
.10737 .31469 .11401 .32092 .12305 .31755 .11642 .3113 Metetra
.664 .741 .908 r
.11642 .3113 .12305 .31755 .13212 .31417 .12551 .3079 Metetra
.664 .741 .908 r
.12551 .3079 .13212 .31417 .14122 .31078 .13463 .30448 Metetra
.664 .741 .908 r
.13463 .30448 .14122 .31078 .15035 .30737 .14378 .30106 Metetra
.664 .741 .908 r
.14378 .30106 .15035 .30737 .15952 .30396 .15296 .29762 Metetra
.664 .741 .908 r
.15296 .29762 .15952 .30396 .16872 .30053 .16218 .29417 Metetra
.664 .741 .908 r
.16218 .29417 .16872 .30053 .17795 .29709 .17143 .2907 Metetra
.664 .741 .908 r
.17143 .2907 .17795 .29709 .18722 .29363 .18072 .28723 Metetra
.664 .741 .908 r
.18072 .28723 .18722 .29363 .19651 .29017 .19003 .28374 Metetra
.664 .741 .908 r
.19003 .28374 .19651 .29017 .20585 .28669 .19939 .28024 Metetra
.664 .741 .908 r
.19939 .28024 .20585 .28669 .21521 .2832 .20877 .27672 Metetra
.664 .741 .908 r
.20877 .27672 .21521 .2832 .22461 .2797 .21819 .27319 Metetra
.664 .741 .908 r
.21819 .27319 .22461 .2797 .23405 .27618 .22765 .26965 Metetra
.664 .741 .908 r
.22765 .26965 .23405 .27618 .24351 .27265 .23713 .2661 Metetra
.664 .741 .908 r
.23713 .2661 .24351 .27265 .25302 .26911 .24666 .26254 Metetra
.664 .741 .908 r
.24666 .26254 .25302 .26911 .26255 .26555 .25622 .25896 Metetra
.664 .741 .908 r
.25622 .25896 .26255 .26555 .27213 .26199 .26581 .25536 Metetra
.664 .741 .908 r
.26581 .25536 .27213 .26199 .28173 .2584 .27544 .25176 Metetra
.664 .741 .908 r
.27544 .25176 .28173 .2584 .29138 .25481 .2851 .24814 Metetra
.664 .741 .908 r
.2851 .24814 .29138 .25481 .30106 .2512 .2948 .24451 Metetra
.664 .741 .908 r
.2948 .24451 .30106 .2512 .31077 .24758 .30454 .24086 Metetra
.664 .741 .908 r
.30454 .24086 .31077 .24758 .32052 .24395 .31431 .2372 Metetra
.664 .741 .908 r
.31431 .2372 .32052 .24395 .3303 .2403 .32411 .23353 Metetra
.664 .741 .908 r
.32411 .23353 .3303 .2403 .34013 .23664 .33396 .22985 Metetra
.664 .741 .908 r
.33396 .22985 .34013 .23664 .34998 .23297 .34384 .22615 Metetra
.664 .741 .908 r
.34384 .22615 .34998 .23297 .35988 .22928 .35376 .22243 Metetra
.664 .741 .908 r
.35376 .22243 .35988 .22928 .36981 .22558 .36371 .21871 Metetra
.664 .741 .908 r
.36371 .21871 .36981 .22558 .37978 .22186 .3737 .21496 Metetra
.664 .741 .908 r
.3737 .21496 .37978 .22186 .38979 .21813 .38373 .21121 Metetra
.664 .741 .908 r
.38373 .21121 .38979 .21813 .39983 .21439 .3938 .20744 Metetra
.664 .741 .908 r
.3938 .20744 .39983 .21439 .40991 .21063 .4039 .20366 Metetra
.664 .741 .908 r
.4039 .20366 .40991 .21063 .42003 .20686 .41405 .19986 Metetra
.664 .741 .908 r
.41405 .19986 .42003 .20686 .43019 .20307 .42423 .19605 Metetra
.664 .741 .908 r
.42423 .19605 .43019 .20307 .44038 .19927 .43445 .19222 Metetra
.664 .741 .908 r
.43445 .19222 .44038 .19927 .45062 .19546 .44471 .18838 Metetra
.664 .741 .908 r
.44471 .18838 .45062 .19546 .46089 .19163 .455 .18452 Metetra
.664 .741 .908 r
.455 .18452 .46089 .19163 .4712 .18779 .46534 .18065 Metetra
.664 .741 .908 r
.46534 .18065 .4712 .18779 .48155 .18393 .47572 .17677 Metetra
.664 .741 .908 r
.47572 .17677 .48155 .18393 .49194 .18005 .48613 .17287 Metetra
.664 .741 .908 r
.48613 .17287 .49194 .18005 .50237 .17617 .49659 .16895 Metetra
.664 .741 .908 r
.49659 .16895 .50237 .17617 .51284 .17226 .50708 .16502 Metetra
.664 .741 .908 r
.50708 .16502 .51284 .17226 .52335 .16835 .51762 .16108 Metetra
.664 .741 .908 r
.51762 .16108 .52335 .16835 .5339 .16441 .5282 .15712 Metetra
.664 .741 .908 r
.5282 .15712 .5339 .16441 .54449 .16047 .53881 .15314 Metetra
.664 .741 .908 r
.53881 .15314 .54449 .16047 .55512 .1565 .54947 .14915 Metetra
.664 .741 .908 r
.54947 .14915 .55512 .1565 .5658 .15253 .56017 .14514 Metetra
.664 .741 .908 r
.56017 .14514 .5658 .15253 .57651 .14853 .57091 .14112 Metetra
.664 .741 .908 r
.57091 .14112 .57651 .14853 .58727 .14452 .5817 .13708 Metetra
.664 .741 .908 r
.5817 .13708 .58727 .14452 .59806 .1405 .59252 .13303 Metetra
.664 .741 .908 r
.59252 .13303 .59806 .1405 .6089 .13646 .60339 .12896 Metetra
.664 .741 .908 r
.60339 .12896 .6089 .13646 .61978 .1324 .6143 .12487 Metetra
.664 .741 .908 r
.6143 .12487 .61978 .1324 .63071 .12833 .62525 .12077 Metetra
.664 .741 .908 r
.62525 .12077 .63071 .12833 .64167 .12424 .63625 .11666 Metetra
.664 .741 .908 r
.63625 .11666 .64167 .12424 .65268 .12014 .64729 .11252 Metetra
.664 .741 .908 r
.64729 .11252 .65268 .12014 .66374 .11602 .65837 .10837 Metetra
.664 .741 .908 r
.65837 .10837 .66374 .11602 .67483 .11189 .6695 .10421 Metetra
.664 .741 .908 r
.6695 .10421 .67483 .11189 .68597 .10773 .68067 .10002 Metetra
.664 .741 .908 r
.68067 .10002 .68597 .10773 .69716 .10356 .69188 .09582 Metetra
.664 .741 .908 r
.69188 .09582 .69716 .10356 .70839 .09938 .70314 .09161 Metetra
.664 .741 .908 r
.70314 .09161 .70839 .09938 .71966 .09518 .71444 .08738 Metetra
.664 .741 .908 r
.71444 .08738 .71966 .09518 .73098 .09096 .72579 .08313 Metetra
.664 .741 .908 r
.72579 .08313 .73098 .09096 .74234 .08672 .73719 .07886 Metetra
.664 .741 .908 r
.09164 .31182 .09834 .31807 .10737 .31469 .10068 .30842 Metetra
.664 .741 .908 r
.10068 .30842 .10737 .31469 .11642 .3113 .10975 .30501 Metetra
.664 .741 .908 r
.10975 .30501 .11642 .3113 .12551 .3079 .11885 .30159 Metetra
.664 .741 .908 r
.11885 .30159 .12551 .3079 .13463 .30448 .12799 .29815 Metetra
.664 .741 .908 r
.12799 .29815 .13463 .30448 .14378 .30106 .13716 .2947 Metetra
.664 .741 .908 r
.13716 .2947 .14378 .30106 .15296 .29762 .14636 .29124 Metetra
.664 .741 .908 r
.14636 .29124 .15296 .29762 .16218 .29417 .1556 .28776 Metetra
.664 .741 .908 r
.1556 .28776 .16218 .29417 .17143 .2907 .16487 .28427 Metetra
.664 .741 .908 r
.16487 .28427 .17143 .2907 .18072 .28723 .17417 .28078 Metetra
.664 .741 .908 r
.17417 .28078 .18072 .28723 .19003 .28374 .18351 .27726 Metetra
.664 .741 .908 r
.18351 .27726 .19003 .28374 .19939 .28024 .19288 .27374 Metetra
.664 .741 .908 r
.19288 .27374 .19939 .28024 .20877 .27672 .20229 .2702 Metetra
.664 .741 .908 r
.20229 .2702 .20877 .27672 .21819 .27319 .21173 .26665 Metetra
.664 .741 .908 r
.21173 .26665 .21819 .27319 .22765 .26965 .2212 .26308 Metetra
.664 .741 .908 r
.2212 .26308 .22765 .26965 .23713 .2661 .23071 .25951 Metetra
.664 .741 .908 r
.23071 .25951 .23713 .2661 .24666 .26254 .24025 .25592 Metetra
.664 .741 .908 r
.24025 .25592 .24666 .26254 .25622 .25896 .24983 .25231 Metetra
.664 .741 .908 r
.24983 .25231 .25622 .25896 .26581 .25536 .25945 .2487 Metetra
.664 .741 .908 r
.25945 .2487 .26581 .25536 .27544 .25176 .2691 .24507 Metetra
.664 .741 .908 r
.2691 .24507 .27544 .25176 .2851 .24814 .27878 .24143 Metetra
.664 .741 .908 r
.27878 .24143 .2851 .24814 .2948 .24451 .2885 .23777 Metetra
.664 .741 .908 r
.2885 .23777 .2948 .24451 .30454 .24086 .29826 .2341 Metetra
.664 .741 .908 r
.29826 .2341 .30454 .24086 .31431 .2372 .30805 .23041 Metetra
.664 .741 .908 r
.30805 .23041 .31431 .2372 .32411 .23353 .31788 .22672 Metetra
.664 .741 .908 r
.31788 .22672 .32411 .23353 .33396 .22985 .32775 .22301 Metetra
.664 .741 .908 r
.32775 .22301 .33396 .22985 .34384 .22615 .33765 .21928 Metetra
.664 .741 .908 r
.33765 .21928 .34384 .22615 .35376 .22243 .34759 .21554 Metetra
.664 .741 .908 r
.34759 .21554 .35376 .22243 .36371 .21871 .35757 .21179 Metetra
.664 .741 .908 r
.35757 .21179 .36371 .21871 .3737 .21496 .36758 .20802 Metetra
.664 .741 .908 r
.36758 .20802 .3737 .21496 .38373 .21121 .37764 .20424 Metetra
.664 .741 .908 r
.37764 .20424 .38373 .21121 .3938 .20744 .38773 .20044 Metetra
.664 .741 .908 r
.38773 .20044 .3938 .20744 .4039 .20366 .39785 .19663 Metetra
.664 .741 .908 r
.39785 .19663 .4039 .20366 .41405 .19986 .40802 .19281 Metetra
.664 .741 .908 r
.40802 .19281 .41405 .19986 .42423 .19605 .41823 .18897 Metetra
.664 .741 .908 r
.41823 .18897 .42423 .19605 .43445 .19222 .42847 .18512 Metetra
.664 .741 .908 r
.42847 .18512 .43445 .19222 .44471 .18838 .43875 .18125 Metetra
.664 .741 .908 r
.43875 .18125 .44471 .18838 .455 .18452 .44908 .17736 Metetra
.664 .741 .908 r
.44908 .17736 .455 .18452 .46534 .18065 .45944 .17347 Metetra
.664 .741 .908 r
.45944 .17347 .46534 .18065 .47572 .17677 .46984 .16955 Metetra
.664 .741 .908 r
.46984 .16955 .47572 .17677 .48613 .17287 .48028 .16563 Metetra
.664 .741 .908 r
.48028 .16563 .48613 .17287 .49659 .16895 .49076 .16168 Metetra
.664 .741 .908 r
.49076 .16168 .49659 .16895 .50708 .16502 .50129 .15773 Metetra
.664 .741 .908 r
.50129 .15773 .50708 .16502 .51762 .16108 .51185 .15375 Metetra
.664 .741 .908 r
.51185 .15375 .51762 .16108 .5282 .15712 .52245 .14976 Metetra
.664 .741 .908 r
.52245 .14976 .5282 .15712 .53881 .15314 .5331 .14576 Metetra
.664 .741 .908 r
.5331 .14576 .53881 .15314 .54947 .14915 .54378 .14174 Metetra
.664 .741 .908 r
.54378 .14174 .54947 .14915 .56017 .14514 .55451 .1377 Metetra
.664 .741 .908 r
.55451 .1377 .56017 .14514 .57091 .14112 .56528 .13365 Metetra
.664 .741 .908 r
.56528 .13365 .57091 .14112 .5817 .13708 .57609 .12959 Metetra
.664 .741 .908 r
.57609 .12959 .5817 .13708 .59252 .13303 .58694 .1255 Metetra
.664 .741 .908 r
.58694 .1255 .59252 .13303 .60339 .12896 .59784 .12141 Metetra
.664 .741 .908 r
.59784 .12141 .60339 .12896 .6143 .12487 .60878 .11729 Metetra
.664 .741 .908 r
.60878 .11729 .6143 .12487 .62525 .12077 .61976 .11316 Metetra
.664 .741 .908 r
.61976 .11316 .62525 .12077 .63625 .11666 .63078 .10901 Metetra
.664 .741 .908 r
.63078 .10901 .63625 .11666 .64729 .11252 .64185 .10485 Metetra
.664 .741 .908 r
.64185 .10485 .64729 .11252 .65837 .10837 .65296 .10067 Metetra
.664 .741 .908 r
.65296 .10067 .65837 .10837 .6695 .10421 .66412 .09647 Metetra
.664 .741 .908 r
.66412 .09647 .6695 .10421 .68067 .10002 .67532 .09226 Metetra
.664 .741 .908 r
.67532 .09226 .68067 .10002 .69188 .09582 .68657 .08803 Metetra
.664 .741 .908 r
.68657 .08803 .69188 .09582 .70314 .09161 .69786 .08378 Metetra
.664 .741 .908 r
.69786 .08378 .70314 .09161 .71444 .08738 .70919 .07952 Metetra
.664 .741 .908 r
.70919 .07952 .71444 .08738 .72579 .08313 .72057 .07524 Metetra
.664 .741 .908 r
.72057 .07524 .72579 .08313 .73719 .07886 .732 .07094 Metetra
.664 .741 .908 r
.08488 .30554 .09164 .31182 .10068 .30842 .09394 .30211 Metetra
.664 .741 .908 r
.09394 .30211 .10068 .30842 .10975 .30501 .10303 .29868 Metetra
.664 .741 .908 r
.10303 .29868 .10975 .30501 .11885 .30159 .11215 .29523 Metetra
.664 .741 .908 r
.11215 .29523 .11885 .30159 .12799 .29815 .12131 .29177 Metetra
.664 .741 .908 r
.12131 .29177 .12799 .29815 .13716 .2947 .1305 .2883 Metetra
.664 .741 .908 r
.1305 .2883 .13716 .2947 .14636 .29124 .13972 .28481 Metetra
.664 .741 .908 r
.13972 .28481 .14636 .29124 .1556 .28776 .14898 .28131 Metetra
.664 .741 .908 r
.14898 .28131 .1556 .28776 .16487 .28427 .15826 .2778 Metetra
.664 .741 .908 r
.15826 .2778 .16487 .28427 .17417 .28078 .16759 .27428 Metetra
.664 .741 .908 r
.16759 .27428 .17417 .28078 .18351 .27726 .17694 .27074 Metetra
.664 .741 .908 r
.17694 .27074 .18351 .27726 .19288 .27374 .18634 .2672 Metetra
.664 .741 .908 r
.18634 .2672 .19288 .27374 .20229 .2702 .19576 .26363 Metetra
.664 .741 .908 r
.19576 .26363 .20229 .2702 .21173 .26665 .20522 .26006 Metetra
.664 .741 .908 r
.20522 .26006 .21173 .26665 .2212 .26308 .21471 .25647 Metetra
.664 .741 .908 r
.21471 .25647 .2212 .26308 .23071 .25951 .22424 .25287 Metetra
.664 .741 .908 r
.22424 .25287 .23071 .25951 .24025 .25592 .23381 .24926 Metetra
.664 .741 .908 r
.23381 .24926 .24025 .25592 .24983 .25231 .24341 .24563 Metetra
.664 .741 .908 r
.24341 .24563 .24983 .25231 .25945 .2487 .25304 .24199 Metetra
.664 .741 .908 r
.25304 .24199 .25945 .2487 .2691 .24507 .26271 .23833 Metetra
.664 .741 .908 r
.26271 .23833 .2691 .24507 .27878 .24143 .27242 .23466 Metetra
.664 .741 .908 r
.27242 .23466 .27878 .24143 .2885 .23777 .28216 .23098 Metetra
.664 .741 .908 r
.28216 .23098 .2885 .23777 .29826 .2341 .29194 .22729 Metetra
.664 .741 .908 r
.29194 .22729 .29826 .2341 .30805 .23041 .30175 .22358 Metetra
.664 .741 .908 r
.30175 .22358 .30805 .23041 .31788 .22672 .31161 .21985 Metetra
.664 .741 .908 r
.31161 .21985 .31788 .22672 .32775 .22301 .32149 .21612 Metetra
.664 .741 .908 r
.32149 .21612 .32775 .22301 .33765 .21928 .33142 .21237 Metetra
.664 .741 .908 r
.33142 .21237 .33765 .21928 .34759 .21554 .34138 .2086 Metetra
.664 .741 .908 r
.34138 .2086 .34759 .21554 .35757 .21179 .35138 .20482 Metetra
.664 .741 .908 r
.35138 .20482 .35757 .21179 .36758 .20802 .36142 .20103 Metetra
.664 .741 .908 r
.36142 .20103 .36758 .20802 .37764 .20424 .3715 .19722 Metetra
.664 .741 .908 r
.3715 .19722 .37764 .20424 .38773 .20044 .38161 .1934 Metetra
.664 .741 .908 r
.38161 .1934 .38773 .20044 .39785 .19663 .39176 .18956 Metetra
.664 .741 .908 r
.39176 .18956 .39785 .19663 .40802 .19281 .40195 .18571 Metetra
.664 .741 .908 r
.40195 .18571 .40802 .19281 .41823 .18897 .41218 .18184 Metetra
.664 .741 .908 r
.41218 .18184 .41823 .18897 .42847 .18512 .42245 .17796 Metetra
.664 .741 .908 r
.42245 .17796 .42847 .18512 .43875 .18125 .43276 .17407 Metetra
.664 .741 .908 r
.43276 .17407 .43875 .18125 .44908 .17736 .44311 .17016 Metetra
.664 .741 .908 r
.44311 .17016 .44908 .17736 .45944 .17347 .4535 .16623 Metetra
.664 .741 .908 r
.4535 .16623 .45944 .17347 .46984 .16955 .46392 .16229 Metetra
.664 .741 .908 r
.46392 .16229 .46984 .16955 .48028 .16563 .47439 .15834 Metetra
.664 .741 .908 r
.47439 .15834 .48028 .16563 .49076 .16168 .4849 .15436 Metetra
.664 .741 .908 r
.4849 .15436 .49076 .16168 .50129 .15773 .49545 .15038 Metetra
.664 .741 .908 r
.49545 .15038 .50129 .15773 .51185 .15375 .50603 .14638 Metetra
.664 .741 .908 r
.50603 .14638 .51185 .15375 .52245 .14976 .51666 .14236 Metetra
.664 .741 .908 r
.51666 .14236 .52245 .14976 .5331 .14576 .52734 .13833 Metetra
.664 .741 .908 r
.52734 .13833 .5331 .14576 .54378 .14174 .53805 .13428 Metetra
.664 .741 .908 r
.53805 .13428 .54378 .14174 .55451 .1377 .5488 .13021 Metetra
.664 .741 .908 r
.5488 .13021 .55451 .1377 .56528 .13365 .5596 .12613 Metetra
.664 .741 .908 r
.5596 .12613 .56528 .13365 .57609 .12959 .57044 .12204 Metetra
.664 .741 .908 r
.57044 .12204 .57609 .12959 .58694 .1255 .58132 .11792 Metetra
.664 .741 .908 r
.58132 .11792 .58694 .1255 .59784 .12141 .59225 .1138 Metetra
.664 .741 .908 r
.59225 .1138 .59784 .12141 .60878 .11729 .60321 .10965 Metetra
.664 .741 .908 r
.60321 .10965 .60878 .11729 .61976 .11316 .61422 .10549 Metetra
.664 .741 .908 r
.61422 .10549 .61976 .11316 .63078 .10901 .62528 .10131 Metetra
.664 .741 .908 r
.62528 .10131 .63078 .10901 .64185 .10485 .63638 .09712 Metetra
.664 .741 .908 r
.63638 .09712 .64185 .10485 .65296 .10067 .64752 .09291 Metetra
.664 .741 .908 r
.64752 .09291 .65296 .10067 .66412 .09647 .6587 .08868 Metetra
.664 .741 .908 r
.6587 .08868 .66412 .09647 .67532 .09226 .66994 .08444 Metetra
.664 .741 .908 r
.66994 .08444 .67532 .09226 .68657 .08803 .68121 .08017 Metetra
.664 .741 .908 r
.68121 .08017 .68657 .08803 .69786 .08378 .69253 .0759 Metetra
.664 .741 .908 r
.69253 .0759 .69786 .08378 .70919 .07952 .7039 .0716 Metetra
.664 .741 .908 r
.7039 .0716 .70919 .07952 .72057 .07524 .71531 .06729 Metetra
.664 .741 .908 r
.71531 .06729 .72057 .07524 .732 .07094 .72677 .06296 Metetra
.664 .741 .908 r
.07809 .29921 .08488 .30554 .09394 .30211 .08716 .29576 Metetra
.664 .741 .908 r
.08716 .29576 .09394 .30211 .10303 .29868 .09627 .2923 Metetra
.664 .741 .908 r
.09627 .2923 .10303 .29868 .11215 .29523 .10541 .28883 Metetra
.664 .741 .908 r
.10541 .28883 .11215 .29523 .12131 .29177 .11458 .28535 Metetra
.664 .741 .908 r
.11458 .28535 .12131 .29177 .1305 .2883 .12379 .28185 Metetra
.664 .741 .908 r
.12379 .28185 .1305 .2883 .13972 .28481 .13303 .27834 Metetra
.664 .741 .908 r
.13303 .27834 .13972 .28481 .14898 .28131 .14231 .27482 Metetra
.664 .741 .908 r
.14231 .27482 .14898 .28131 .15826 .2778 .15162 .27129 Metetra
.664 .741 .908 r
.15162 .27129 .15826 .2778 .16759 .27428 .16096 .26774 Metetra
.664 .741 .908 r
.16096 .26774 .16759 .27428 .17694 .27074 .17033 .26418 Metetra
.664 .741 .908 r
.17033 .26418 .17694 .27074 .18634 .2672 .17974 .26061 Metetra
.664 .741 .908 r
.17974 .26061 .18634 .2672 .19576 .26363 .18919 .25702 Metetra
.664 .741 .908 r
.18919 .25702 .19576 .26363 .20522 .26006 .19867 .25342 Metetra
.664 .741 .908 r
.19867 .25342 .20522 .26006 .21471 .25647 .20818 .24981 Metetra
.664 .741 .908 r
.20818 .24981 .21471 .25647 .22424 .25287 .21773 .24619 Metetra
.664 .741 .908 r
.21773 .24619 .22424 .25287 .23381 .24926 .22732 .24255 Metetra
.664 .741 .908 r
.22732 .24255 .23381 .24926 .24341 .24563 .23694 .2389 Metetra
.664 .741 .908 r
.23694 .2389 .24341 .24563 .25304 .24199 .24659 .23523 Metetra
.664 .741 .908 r
.24659 .23523 .25304 .24199 .26271 .23833 .25628 .23155 Metetra
.664 .741 .908 r
.25628 .23155 .26271 .23833 .27242 .23466 .26601 .22786 Metetra
.664 .741 .908 r
.26601 .22786 .27242 .23466 .28216 .23098 .27578 .22415 Metetra
.664 .741 .908 r
.27578 .22415 .28216 .23098 .29194 .22729 .28558 .22043 Metetra
.664 .741 .908 r
.28558 .22043 .29194 .22729 .30175 .22358 .29541 .21669 Metetra
.664 .741 .908 r
.29541 .21669 .30175 .22358 .31161 .21985 .30529 .21294 Metetra
.664 .741 .908 r
.30529 .21294 .31161 .21985 .32149 .21612 .3152 .20918 Metetra
.664 .741 .908 r
.3152 .20918 .32149 .21612 .33142 .21237 .32515 .2054 Metetra
.664 .741 .908 r
.32515 .2054 .33142 .21237 .34138 .2086 .33513 .20161 Metetra
.664 .741 .908 r
.33513 .20161 .34138 .2086 .35138 .20482 .34516 .19781 Metetra
.664 .741 .908 r
.34516 .19781 .35138 .20482 .36142 .20103 .35522 .19399 Metetra
.664 .741 .908 r
.35522 .19399 .36142 .20103 .3715 .19722 .36532 .19015 Metetra
.664 .741 .908 r
.36532 .19015 .3715 .19722 .38161 .1934 .37545 .1863 Metetra
.664 .741 .908 r
.37545 .1863 .38161 .1934 .39176 .18956 .38563 .18244 Metetra
.664 .741 .908 r
.38563 .18244 .39176 .18956 .40195 .18571 .39585 .17856 Metetra
.664 .741 .908 r
.39585 .17856 .40195 .18571 .41218 .18184 .4061 .17467 Metetra
.664 .741 .908 r
.4061 .17467 .41218 .18184 .42245 .17796 .41639 .17076 Metetra
.664 .741 .908 r
.41639 .17076 .42245 .17796 .43276 .17407 .42673 .16684 Metetra
.664 .741 .908 r
.42673 .16684 .43276 .17407 .44311 .17016 .4371 .1629 Metetra
.664 .741 .908 r
.4371 .1629 .44311 .17016 .4535 .16623 .44751 .15895 Metetra
.664 .741 .908 r
.44751 .15895 .4535 .16623 .46392 .16229 .45796 .15498 Metetra
.664 .741 .908 r
.45796 .15498 .46392 .16229 .47439 .15834 .46846 .15099 Metetra
.664 .741 .908 r
.46846 .15099 .47439 .15834 .4849 .15436 .47899 .14699 Metetra
.664 .741 .908 r
.47899 .14699 .4849 .15436 .49545 .15038 .48956 .14298 Metetra
.664 .741 .908 r
.48956 .14298 .49545 .15038 .50603 .14638 .50018 .13895 Metetra
.664 .741 .908 r
.50018 .13895 .50603 .14638 .51666 .14236 .51084 .1349 Metetra
.664 .741 .908 r
.51084 .1349 .51666 .14236 .52734 .13833 .52154 .13084 Metetra
.664 .741 .908 r
.52154 .13084 .52734 .13833 .53805 .13428 .53228 .12676 Metetra
.664 .741 .908 r
.53228 .12676 .53805 .13428 .5488 .13021 .54306 .12267 Metetra
.664 .741 .908 r
.54306 .12267 .5488 .13021 .5596 .12613 .55388 .11856 Metetra
.664 .741 .908 r
.55388 .11856 .5596 .12613 .57044 .12204 .56475 .11443 Metetra
.664 .741 .908 r
.56475 .11443 .57044 .12204 .58132 .11792 .57566 .11029 Metetra
.664 .741 .908 r
.57566 .11029 .58132 .11792 .59225 .1138 .58661 .10613 Metetra
.664 .741 .908 r
.58661 .10613 .59225 .1138 .60321 .10965 .59761 .10196 Metetra
.664 .741 .908 r
.59761 .10196 .60321 .10965 .61422 .10549 .60865 .09777 Metetra
.664 .741 .908 r
.60865 .09777 .61422 .10549 .62528 .10131 .61973 .09356 Metetra
.664 .741 .908 r
.61973 .09356 .62528 .10131 .63638 .09712 .63086 .08933 Metetra
.664 .741 .908 r
.63086 .08933 .63638 .09712 .64752 .09291 .64203 .08509 Metetra
.664 .741 .908 r
.64203 .08509 .64752 .09291 .6587 .08868 .65325 .08083 Metetra
.664 .741 .908 r
.65325 .08083 .6587 .08868 .66994 .08444 .66451 .07656 Metetra
.664 .741 .908 r
.66451 .07656 .66994 .08444 .68121 .08017 .67582 .07226 Metetra
.664 .741 .908 r
.67582 .07226 .68121 .08017 .69253 .0759 .68717 .06795 Metetra
.664 .741 .908 r
.68717 .06795 .69253 .0759 .7039 .0716 .69857 .06363 Metetra
.664 .741 .908 r
.69857 .06363 .7039 .0716 .71531 .06729 .71001 .05928 Metetra
.664 .741 .908 r
.71001 .05928 .71531 .06729 .72677 .06296 .7215 .05492 Metetra
.664 .741 .908 r
.07124 .29284 .07809 .29921 .08716 .29576 .08034 .28937 Metetra
.664 .741 .908 r
.08034 .28937 .08716 .29576 .09627 .2923 .08946 .28589 Metetra
.664 .741 .908 r
.08946 .28589 .09627 .2923 .10541 .28883 .09862 .28239 Metetra
.664 .741 .908 r
.09862 .28239 .10541 .28883 .11458 .28535 .10781 .27889 Metetra
.664 .741 .908 r
.10781 .27889 .11458 .28535 .12379 .28185 .11704 .27537 Metetra
.664 .741 .908 r
.11704 .27537 .12379 .28185 .13303 .27834 .1263 .27183 Metetra
.664 .741 .908 r
.1263 .27183 .13303 .27834 .14231 .27482 .13559 .26829 Metetra
.664 .741 .908 r
.13559 .26829 .14231 .27482 .15162 .27129 .14492 .26473 Metetra
.664 .741 .908 r
.14492 .26473 .15162 .27129 .16096 .26774 .15428 .26116 Metetra
.664 .741 .908 r
.15428 .26116 .16096 .26774 .17033 .26418 .16368 .25758 Metetra
.664 .741 .908 r
.16368 .25758 .17033 .26418 .17974 .26061 .17311 .25398 Metetra
.664 .741 .908 r
.17311 .25398 .17974 .26061 .18919 .25702 .18257 .25037 Metetra
.664 .741 .908 r
.18257 .25037 .18919 .25702 .19867 .25342 .19207 .24675 Metetra
.664 .741 .908 r
.19207 .24675 .19867 .25342 .20818 .24981 .20161 .24311 Metetra
.664 .741 .908 r
.20161 .24311 .20818 .24981 .21773 .24619 .21118 .23946 Metetra
.664 .741 .908 r
.21118 .23946 .21773 .24619 .22732 .24255 .22078 .23579 Metetra
.664 .741 .908 r
.22078 .23579 .22732 .24255 .23694 .2389 .23042 .23212 Metetra
.664 .741 .908 r
.23042 .23212 .23694 .2389 .24659 .23523 .2401 .22843 Metetra
.664 .741 .908 r
.2401 .22843 .24659 .23523 .25628 .23155 .24981 .22472 Metetra
.664 .741 .908 r
.24981 .22472 .25628 .23155 .26601 .22786 .25956 .221 Metetra
.664 .741 .908 r
.25956 .221 .26601 .22786 .27578 .22415 .26935 .21727 Metetra
.664 .741 .908 r
.26935 .21727 .27578 .22415 .28558 .22043 .27917 .21352 Metetra
.664 .741 .908 r
.27917 .21352 .28558 .22043 .29541 .21669 .28903 .20976 Metetra
.664 .741 .908 r
.28903 .20976 .29541 .21669 .30529 .21294 .29892 .20599 Metetra
.664 .741 .908 r
.29892 .20599 .30529 .21294 .3152 .20918 .30886 .2022 Metetra
.664 .741 .908 r
.30886 .2022 .3152 .20918 .32515 .2054 .31883 .19839 Metetra
.664 .741 .908 r
.31883 .19839 .32515 .2054 .33513 .20161 .32884 .19458 Metetra
.664 .741 .908 r
.32884 .19458 .33513 .20161 .34516 .19781 .33888 .19074 Metetra
.664 .741 .908 r
.33888 .19074 .34516 .19781 .35522 .19399 .34897 .1869 Metetra
.664 .741 .908 r
.34897 .1869 .35522 .19399 .36532 .19015 .35909 .18304 Metetra
.664 .741 .908 r
.35909 .18304 .36532 .19015 .37545 .1863 .36925 .17916 Metetra
.664 .741 .908 r
.36925 .17916 .37545 .1863 .38563 .18244 .37945 .17527 Metetra
.664 .741 .908 r
.37945 .17527 .38563 .18244 .39585 .17856 .38969 .17136 Metetra
.664 .741 .908 r
.38969 .17136 .39585 .17856 .4061 .17467 .39997 .16744 Metetra
.664 .741 .908 r
.39997 .16744 .4061 .17467 .41639 .17076 .41029 .16351 Metetra
.664 .741 .908 r
.41029 .16351 .41639 .17076 .42673 .16684 .42065 .15955 Metetra
.664 .741 .908 r
.42065 .15955 .42673 .16684 .4371 .1629 .43105 .15559 Metetra
.664 .741 .908 r
.43105 .15559 .4371 .1629 .44751 .15895 .44148 .15161 Metetra
.664 .741 .908 r
.44148 .15161 .44751 .15895 .45796 .15498 .45196 .14761 Metetra
.664 .741 .908 r
.45196 .14761 .45796 .15498 .46846 .15099 .46248 .1436 Metetra
.664 .741 .908 r
.46248 .1436 .46846 .15099 .47899 .14699 .47304 .13957 Metetra
.664 .741 .908 r
.47304 .13957 .47899 .14699 .48956 .14298 .48364 .13553 Metetra
.664 .741 .908 r
.48364 .13553 .48956 .14298 .50018 .13895 .49428 .13147 Metetra
.664 .741 .908 r
.49428 .13147 .50018 .13895 .51084 .1349 .50497 .12739 Metetra
.664 .741 .908 r
.50497 .12739 .51084 .1349 .52154 .13084 .51569 .1233 Metetra
.664 .741 .908 r
.51569 .1233 .52154 .13084 .53228 .12676 .52646 .11919 Metetra
.664 .741 .908 r
.52646 .11919 .53228 .12676 .54306 .12267 .53727 .11507 Metetra
.664 .741 .908 r
.53727 .11507 .54306 .12267 .55388 .11856 .54812 .11093 Metetra
.664 .741 .908 r
.54812 .11093 .55388 .11856 .56475 .11443 .55902 .10677 Metetra
.664 .741 .908 r
.55902 .10677 .56475 .11443 .57566 .11029 .56996 .1026 Metetra
.664 .741 .908 r
.56996 .1026 .57566 .11029 .58661 .10613 .58094 .09841 Metetra
.664 .741 .908 r
.58094 .09841 .58661 .10613 .59761 .10196 .59196 .09421 Metetra
.664 .741 .908 r
.59196 .09421 .59761 .10196 .60865 .09777 .60303 .08998 Metetra
.664 .741 .908 r
.60303 .08998 .60865 .09777 .61973 .09356 .61415 .08574 Metetra
.664 .741 .908 r
.61415 .08574 .61973 .09356 .63086 .08933 .6253 .08149 Metetra
.664 .741 .908 r
.6253 .08149 .63086 .08933 .64203 .08509 .63651 .07721 Metetra
.664 .741 .908 r
.63651 .07721 .64203 .08509 .65325 .08083 .64775 .07292 Metetra
.664 .741 .908 r
.64775 .07292 .65325 .08083 .66451 .07656 .65904 .06862 Metetra
.664 .741 .908 r
.65904 .06862 .66451 .07656 .67582 .07226 .67038 .06429 Metetra
.664 .741 .908 r
.67038 .06429 .67582 .07226 .68717 .06795 .68177 .05995 Metetra
.664 .741 .908 r
.68177 .05995 .68717 .06795 .69857 .06363 .6932 .05559 Metetra
.664 .741 .908 r
.6932 .05559 .69857 .06363 .71001 .05928 .70467 .05121 Metetra
.664 .741 .908 r
.70467 .05121 .71001 .05928 .7215 .05492 .71619 .04682 Metetra
.664 .741 .908 r
.06435 .28642 .07124 .29284 .08034 .28937 .07347 .28293 Metetra
.664 .741 .908 r
.07347 .28293 .08034 .28937 .08946 .28589 .08261 .27943 Metetra
.664 .741 .908 r
.08261 .27943 .08946 .28589 .09862 .28239 .09179 .27591 Metetra
.664 .741 .908 r
.09179 .27591 .09862 .28239 .10781 .27889 .101 .27238 Metetra
.664 .741 .908 r
.101 .27238 .10781 .27889 .11704 .27537 .11024 .26884 Metetra
.664 .741 .908 r
.11024 .26884 .11704 .27537 .1263 .27183 .11952 .26528 Metetra
.664 .741 .908 r
.11952 .26528 .1263 .27183 .13559 .26829 .12883 .26171 Metetra
.664 .741 .908 r
.12883 .26171 .13559 .26829 .14492 .26473 .13818 .25813 Metetra
.664 .741 .908 r
.13818 .25813 .14492 .26473 .15428 .26116 .14756 .25453 Metetra
.664 .741 .908 r
.14756 .25453 .15428 .26116 .16368 .25758 .15698 .25093 Metetra
.664 .741 .908 r
.15698 .25093 .16368 .25758 .17311 .25398 .16643 .2473 Metetra
.664 .741 .908 r
.16643 .2473 .17311 .25398 .18257 .25037 .17591 .24367 Metetra
.664 .741 .908 r
.17591 .24367 .18257 .25037 .19207 .24675 .18543 .24002 Metetra
.664 .741 .908 r
.18543 .24002 .19207 .24675 .20161 .24311 .19498 .23636 Metetra
.664 .741 .908 r
.19498 .23636 .20161 .24311 .21118 .23946 .20458 .23268 Metetra
.664 .741 .908 r
.20458 .23268 .21118 .23946 .22078 .23579 .2142 .22899 Metetra
.664 .741 .908 r
.2142 .22899 .22078 .23579 .23042 .23212 .22386 .22529 Metetra
.664 .741 .908 r
.22386 .22529 .23042 .23212 .2401 .22843 .23356 .22157 Metetra
.664 .741 .908 r
.23356 .22157 .2401 .22843 .24981 .22472 .2433 .21784 Metetra
.664 .741 .908 r
.2433 .21784 .24981 .22472 .25956 .221 .25307 .2141 Metetra
.664 .741 .908 r
.25307 .2141 .25956 .221 .26935 .21727 .26287 .21034 Metetra
.664 .741 .908 r
.26287 .21034 .26935 .21727 .27917 .21352 .27272 .20657 Metetra
.664 .741 .908 r
.27272 .20657 .27917 .21352 .28903 .20976 .2826 .20278 Metetra
.664 .741 .908 r
.2826 .20278 .28903 .20976 .29892 .20599 .29252 .19898 Metetra
.664 .741 .908 r
.29252 .19898 .29892 .20599 .30886 .2022 .30247 .19516 Metetra
.664 .741 .908 r
.30247 .19516 .30886 .2022 .31883 .19839 .31247 .19133 Metetra
.664 .741 .908 r
.31247 .19133 .31883 .19839 .32884 .19458 .3225 .18749 Metetra
.664 .741 .908 r
.3225 .18749 .32884 .19458 .33888 .19074 .33257 .18363 Metetra
.664 .741 .908 r
.33257 .18363 .33888 .19074 .34897 .1869 .34268 .17976 Metetra
.664 .741 .908 r
.34268 .17976 .34897 .1869 .35909 .18304 .35282 .17587 Metetra
.664 .741 .908 r
.35282 .17587 .35909 .18304 .36925 .17916 .36301 .17196 Metetra
.664 .741 .908 r
.36301 .17196 .36925 .17916 .37945 .17527 .37323 .16805 Metetra
.664 .741 .908 r
.37323 .16805 .37945 .17527 .38969 .17136 .3835 .16411 Metetra
.664 .741 .908 r
.3835 .16411 .38969 .17136 .39997 .16744 .3938 .16016 Metetra
.664 .741 .908 r
.3938 .16016 .39997 .16744 .41029 .16351 .40414 .1562 Metetra
.664 .741 .908 r
.40414 .1562 .41029 .16351 .42065 .15955 .41453 .15222 Metetra
.664 .741 .908 r
.41453 .15222 .42065 .15955 .43105 .15559 .42495 .14823 Metetra
.664 .741 .908 r
.42495 .14823 .43105 .15559 .44148 .15161 .43541 .14422 Metetra
.664 .741 .908 r
.43541 .14422 .44148 .15161 .45196 .14761 .44592 .14019 Metetra
.664 .741 .908 r
.44592 .14019 .45196 .14761 .46248 .1436 .45646 .13615 Metetra
.664 .741 .908 r
.45646 .13615 .46248 .1436 .47304 .13957 .46705 .13209 Metetra
.664 .741 .908 r
.46705 .13209 .47304 .13957 .48364 .13553 .47767 .12802 Metetra
.664 .741 .908 r
.47767 .12802 .48364 .13553 .49428 .13147 .48834 .12393 Metetra
.664 .741 .908 r
.48834 .12393 .49428 .13147 .50497 .12739 .49905 .11982 Metetra
.664 .741 .908 r
.49905 .11982 .50497 .12739 .51569 .1233 .50981 .1157 Metetra
.664 .741 .908 r
.50981 .1157 .51569 .1233 .52646 .11919 .5206 .11157 Metetra
.664 .741 .908 r
.5206 .11157 .52646 .11919 .53727 .11507 .53144 .10741 Metetra
.664 .741 .908 r
.53144 .10741 .53727 .11507 .54812 .11093 .54232 .10324 Metetra
.664 .741 .908 r
.54232 .10324 .54812 .11093 .55902 .10677 .55324 .09906 Metetra
.664 .741 .908 r
.55324 .09906 .55902 .10677 .56996 .1026 .56421 .09485 Metetra
.664 .741 .908 r
.56421 .09485 .56996 .1026 .58094 .09841 .57522 .09063 Metetra
.664 .741 .908 r
.57522 .09063 .58094 .09841 .59196 .09421 .58628 .0864 Metetra
.664 .741 .908 r
.58628 .0864 .59196 .09421 .60303 .08998 .59737 .08214 Metetra
.664 .741 .908 r
.59737 .08214 .60303 .08998 .61415 .08574 .60852 .07787 Metetra
.664 .741 .908 r
.60852 .07787 .61415 .08574 .6253 .08149 .61971 .07359 Metetra
.664 .741 .908 r
.61971 .07359 .6253 .08149 .63651 .07721 .63094 .06928 Metetra
.664 .741 .908 r
.63094 .06928 .63651 .07721 .64775 .07292 .64222 .06496 Metetra
.664 .741 .908 r
.64222 .06496 .64775 .07292 .65904 .06862 .65354 .06062 Metetra
.664 .741 .908 r
.65354 .06062 .65904 .06862 .67038 .06429 .66491 .05626 Metetra
.664 .741 .908 r
.66491 .05626 .67038 .06429 .68177 .05995 .67632 .05189 Metetra
.664 .741 .908 r
.67632 .05189 .68177 .05995 .6932 .05559 .68778 .04749 Metetra
.664 .741 .908 r
.68778 .04749 .6932 .05559 .70467 .05121 .69929 .04308 Metetra
.664 .741 .908 r
.69929 .04308 .70467 .05121 .71619 .04682 .71085 .03866 Metetra
.664 .741 .908 r
.05742 .27997 .06435 .28642 .07347 .28293 .06655 .27645 Metetra
.664 .741 .908 r
.06655 .27645 .07347 .28293 .08261 .27943 .07571 .27292 Metetra
.664 .741 .908 r
.07571 .27292 .08261 .27943 .09179 .27591 .08491 .26938 Metetra
.664 .741 .908 r
.08491 .26938 .09179 .27591 .101 .27238 .09414 .26583 Metetra
.664 .741 .908 r
.09414 .26583 .101 .27238 .11024 .26884 .1034 .26226 Metetra
.664 .741 .908 r
.1034 .26226 .11024 .26884 .11952 .26528 .1127 .25868 Metetra
.664 .741 .908 r
.1127 .25868 .11952 .26528 .12883 .26171 .12203 .25509 Metetra
.664 .741 .908 r
.12203 .25509 .12883 .26171 .13818 .25813 .13139 .25148 Metetra
.664 .741 .908 r
.13139 .25148 .13818 .25813 .14756 .25453 .14079 .24786 Metetra
.664 .741 .908 r
.14079 .24786 .14756 .25453 .15698 .25093 .15023 .24423 Metetra
.664 .741 .908 r
.15023 .24423 .15698 .25093 .16643 .2473 .1597 .24058 Metetra
.664 .741 .908 r
.1597 .24058 .16643 .2473 .17591 .24367 .1692 .23692 Metetra
.664 .741 .908 r
.1692 .23692 .17591 .24367 .18543 .24002 .17874 .23325 Metetra
.664 .741 .908 r
.17874 .23325 .18543 .24002 .19498 .23636 .18832 .22956 Metetra
.664 .741 .908 r
.18832 .22956 .19498 .23636 .20458 .23268 .19793 .22586 Metetra
.664 .741 .908 r
.19793 .22586 .20458 .23268 .2142 .22899 .20758 .22215 Metetra
.664 .741 .908 r
.20758 .22215 .2142 .22899 .22386 .22529 .21726 .21842 Metetra
.664 .741 .908 r
.21726 .21842 .22386 .22529 .23356 .22157 .22698 .21468 Metetra
.664 .741 .908 r
.22698 .21468 .23356 .22157 .2433 .21784 .23673 .21092 Metetra
.664 .741 .908 r
.23673 .21092 .2433 .21784 .25307 .2141 .24653 .20715 Metetra
.664 .741 .908 r
.24653 .20715 .25307 .2141 .26287 .21034 .25635 .20336 Metetra
.664 .741 .908 r
.25635 .20336 .26287 .21034 .27272 .20657 .26622 .19957 Metetra
.664 .741 .908 r
.26622 .19957 .27272 .20657 .2826 .20278 .27612 .19575 Metetra
.664 .741 .908 r
.27612 .19575 .2826 .20278 .29252 .19898 .28607 .19192 Metetra
.664 .741 .908 r
.28607 .19192 .29252 .19898 .30247 .19516 .29604 .18808 Metetra
.664 .741 .908 r
.29604 .18808 .30247 .19516 .31247 .19133 .30606 .18422 Metetra
.664 .741 .908 r
.30606 .18422 .31247 .19133 .3225 .18749 .31612 .18035 Metetra
.664 .741 .908 r
.31612 .18035 .3225 .18749 .33257 .18363 .32621 .17647 Metetra
.664 .741 .908 r
.32621 .17647 .33257 .18363 .34268 .17976 .33634 .17257 Metetra
.664 .741 .908 r
.33634 .17257 .34268 .17976 .35282 .17587 .34651 .16865 Metetra
.664 .741 .908 r
.34651 .16865 .35282 .17587 .36301 .17196 .35672 .16472 Metetra
.664 .741 .908 r
.35672 .16472 .36301 .17196 .37323 .16805 .36697 .16077 Metetra
.664 .741 .908 r
.36697 .16077 .37323 .16805 .3835 .16411 .37726 .15681 Metetra
.664 .741 .908 r
.37726 .15681 .3835 .16411 .3938 .16016 .38758 .15283 Metetra
.664 .741 .908 r
.38758 .15283 .3938 .16016 .40414 .1562 .39795 .14884 Metetra
.664 .741 .908 r
.39795 .14884 .40414 .1562 .41453 .15222 .40836 .14483 Metetra
.664 .741 .908 r
.40836 .14483 .41453 .15222 .42495 .14823 .41881 .14081 Metetra
.664 .741 .908 r
.41881 .14081 .42495 .14823 .43541 .14422 .4293 .13677 Metetra
.664 .741 .908 r
.4293 .13677 .43541 .14422 .44592 .14019 .43983 .13272 Metetra
.664 .741 .908 r
.43983 .13272 .44592 .14019 .45646 .13615 .4504 .12865 Metetra
.664 .741 .908 r
.4504 .12865 .45646 .13615 .46705 .13209 .46101 .12456 Metetra
.664 .741 .908 r
.46101 .12456 .46705 .13209 .47767 .12802 .47166 .12046 Metetra
.664 .741 .908 r
.47166 .12046 .47767 .12802 .48834 .12393 .48236 .11634 Metetra
.664 .741 .908 r
.48236 .11634 .48834 .12393 .49905 .11982 .4931 .1122 Metetra
.664 .741 .908 r
.4931 .1122 .49905 .11982 .50981 .1157 .50388 .10805 Metetra
.664 .741 .908 r
.50388 .10805 .50981 .1157 .5206 .11157 .5147 .10389 Metetra
.664 .741 .908 r
.5147 .10389 .5206 .11157 .53144 .10741 .52557 .0997 Metetra
.664 .741 .908 r
.52557 .0997 .53144 .10741 .54232 .10324 .53648 .0955 Metetra
.664 .741 .908 r
.53648 .0955 .54232 .10324 .55324 .09906 .54743 .09128 Metetra
.664 .741 .908 r
.54743 .09128 .55324 .09906 .56421 .09485 .55842 .08705 Metetra
.664 .741 .908 r
.55842 .08705 .56421 .09485 .57522 .09063 .56946 .0828 Metetra
.664 .741 .908 r
.56946 .0828 .57522 .09063 .58628 .0864 .58055 .07853 Metetra
.664 .741 .908 r
.58055 .07853 .58628 .0864 .59737 .08214 .59168 .07425 Metetra
.664 .741 .908 r
.59168 .07425 .59737 .08214 .60852 .07787 .60285 .06994 Metetra
.664 .741 .908 r
.60285 .06994 .60852 .07787 .61971 .07359 .61407 .06562 Metetra
.664 .741 .908 r
.61407 .06562 .61971 .07359 .63094 .06928 .62533 .06129 Metetra
.664 .741 .908 r
.62533 .06129 .63094 .06928 .64222 .06496 .63664 .05693 Metetra
.664 .741 .908 r
.63664 .05693 .64222 .06496 .65354 .06062 .64799 .05256 Metetra
.664 .741 .908 r
.64799 .05256 .65354 .06062 .66491 .05626 .65939 .04817 Metetra
.664 .741 .908 r
.65939 .04817 .66491 .05626 .67632 .05189 .67084 .04376 Metetra
.664 .741 .908 r
.67084 .04376 .67632 .05189 .68778 .04749 .68233 .03934 Metetra
.664 .741 .908 r
.68233 .03934 .68778 .04749 .69929 .04308 .69387 .03489 Metetra
.664 .741 .908 r
.69387 .03489 .69929 .04308 .71085 .03866 .70546 .03043 Metetra
.664 .741 .908 r
.05044 .27347 .05742 .27997 .06655 .27645 .05959 .26993 Metetra
.664 .741 .908 r
.05959 .26993 .06655 .27645 .07571 .27292 .06877 .26638 Metetra
.664 .741 .908 r
.06877 .26638 .07571 .27292 .08491 .26938 .07798 .26281 Metetra
.664 .741 .908 r
.07798 .26281 .08491 .26938 .09414 .26583 .08723 .25923 Metetra
.664 .741 .908 r
.08723 .25923 .09414 .26583 .1034 .26226 .09651 .25564 Metetra
.664 .741 .908 r
.09651 .25564 .1034 .26226 .1127 .25868 .10583 .25204 Metetra
.664 .741 .908 r
.10583 .25204 .1127 .25868 .12203 .25509 .11518 .24842 Metetra
.664 .741 .908 r
.11518 .24842 .12203 .25509 .13139 .25148 .12456 .24479 Metetra
.664 .741 .908 r
.12456 .24479 .13139 .25148 .14079 .24786 .13398 .24114 Metetra
.664 .741 .908 r
.13398 .24114 .14079 .24786 .15023 .24423 .14344 .23749 Metetra
.664 .741 .908 r
.14344 .23749 .15023 .24423 .1597 .24058 .15293 .23382 Metetra
.664 .741 .908 r
.15293 .23382 .1597 .24058 .1692 .23692 .16245 .23013 Metetra
.664 .741 .908 r
.16245 .23013 .1692 .23692 .17874 .23325 .17201 .22643 Metetra
.664 .741 .908 r
.17201 .22643 .17874 .23325 .18832 .22956 .18161 .22272 Metetra
.664 .741 .908 r
.18161 .22272 .18832 .22956 .19793 .22586 .19124 .21899 Metetra
.664 .741 .908 r
.19124 .21899 .19793 .22586 .20758 .22215 .20091 .21525 Metetra
.664 .741 .908 r
.20091 .21525 .20758 .22215 .21726 .21842 .21061 .2115 Metetra
.664 .741 .908 r
.21061 .2115 .21726 .21842 .22698 .21468 .22035 .20773 Metetra
.664 .741 .908 r
.22035 .20773 .22698 .21468 .23673 .21092 .23013 .20395 Metetra
.664 .741 .908 r
.23013 .20395 .23673 .21092 .24653 .20715 .23994 .20015 Metetra
.664 .741 .908 r
.23994 .20015 .24653 .20715 .25635 .20336 .24979 .19634 Metetra
.664 .741 .908 r
.24979 .19634 .25635 .20336 .26622 .19957 .25968 .19251 Metetra
.664 .741 .908 r
.25968 .19251 .26622 .19957 .27612 .19575 .2696 .18867 Metetra
.664 .741 .908 r
.2696 .18867 .27612 .19575 .28607 .19192 .27957 .18482 Metetra
.664 .741 .908 r
.27957 .18482 .28607 .19192 .29604 .18808 .28957 .18095 Metetra
.664 .741 .908 r
.28957 .18095 .29604 .18808 .30606 .18422 .29961 .17707 Metetra
.664 .741 .908 r
.29961 .17707 .30606 .18422 .31612 .18035 .30969 .17317 Metetra
.664 .741 .908 r
.30969 .17317 .31612 .18035 .32621 .17647 .3198 .16925 Metetra
.664 .741 .908 r
.3198 .16925 .32621 .17647 .33634 .17257 .32996 .16532 Metetra
.664 .741 .908 r
.32996 .16532 .33634 .17257 .34651 .16865 .34015 .16138 Metetra
.664 .741 .908 r
.34015 .16138 .34651 .16865 .35672 .16472 .35039 .15742 Metetra
.664 .741 .908 r
.35039 .15742 .35672 .16472 .36697 .16077 .36066 .15345 Metetra
.664 .741 .908 r
.36066 .15345 .36697 .16077 .37726 .15681 .37097 .14946 Metetra
.664 .741 .908 r
.37097 .14946 .37726 .15681 .38758 .15283 .38132 .14545 Metetra
.664 .741 .908 r
.38132 .14545 .38758 .15283 .39795 .14884 .39172 .14143 Metetra
.664 .741 .908 r
.39172 .14143 .39795 .14884 .40836 .14483 .40215 .13739 Metetra
.664 .741 .908 r
.40215 .13739 .40836 .14483 .41881 .14081 .41262 .13334 Metetra
.664 .741 .908 r
.41262 .13334 .41881 .14081 .4293 .13677 .42314 .12927 Metetra
.664 .741 .908 r
.42314 .12927 .4293 .13677 .43983 .13272 .43369 .12519 Metetra
.664 .741 .908 r
.43369 .12519 .43983 .13272 .4504 .12865 .44429 .12109 Metetra
.664 .741 .908 r
.44429 .12109 .4504 .12865 .46101 .12456 .45493 .11697 Metetra
.664 .741 .908 r
.45493 .11697 .46101 .12456 .47166 .12046 .46561 .11284 Metetra
.664 .741 .908 r
.46561 .11284 .47166 .12046 .48236 .11634 .47633 .10869 Metetra
.664 .741 .908 r
.47633 .10869 .48236 .11634 .4931 .1122 .4871 .10453 Metetra
.664 .741 .908 r
.4871 .10453 .4931 .1122 .50388 .10805 .49791 .10035 Metetra
.664 .741 .908 r
.49791 .10035 .50388 .10805 .5147 .10389 .50876 .09615 Metetra
.664 .741 .908 r
.50876 .09615 .5147 .10389 .52557 .0997 .51965 .09193 Metetra
.664 .741 .908 r
.51965 .09193 .52557 .0997 .53648 .0955 .53059 .0877 Metetra
.664 .741 .908 r
.53059 .0877 .53648 .0955 .54743 .09128 .54157 .08345 Metetra
.664 .741 .908 r
.54157 .08345 .54743 .09128 .55842 .08705 .55259 .07919 Metetra
.664 .741 .908 r
.55259 .07919 .55842 .08705 .56946 .0828 .56366 .07491 Metetra
.664 .741 .908 r
.56366 .07491 .56946 .0828 .58055 .07853 .57478 .07061 Metetra
.664 .741 .908 r
.57478 .07061 .58055 .07853 .59168 .07425 .58593 .06629 Metetra
.664 .741 .908 r
.58593 .06629 .59168 .07425 .60285 .06994 .59714 .06196 Metetra
.664 .741 .908 r
.59714 .06196 .60285 .06994 .61407 .06562 .60838 .0576 Metetra
.664 .741 .908 r
.60838 .0576 .61407 .06562 .62533 .06129 .61968 .05323 Metetra
.664 .741 .908 r
.61968 .05323 .62533 .06129 .63664 .05693 .63102 .04885 Metetra
.664 .741 .908 r
.63102 .04885 .63664 .05693 .64799 .05256 .6424 .04444 Metetra
.664 .741 .908 r
.6424 .04444 .64799 .05256 .65939 .04817 .65383 .04002 Metetra
.664 .741 .908 r
.65383 .04002 .65939 .04817 .67084 .04376 .66531 .03558 Metetra
.664 .741 .908 r
.66531 .03558 .67084 .04376 .68233 .03934 .67684 .03112 Metetra
.664 .741 .908 r
.67684 .03112 .68233 .03934 .69387 .03489 .68841 .02664 Metetra
.664 .741 .908 r
.68841 .02664 .69387 .03489 .70546 .03043 .70003 .02215 Metetra
.664 .741 .908 r
.04341 .26692 .05044 .27347 .05959 .26993 .05258 .26336 Metetra
.664 .741 .908 r
.05258 .26336 .05959 .26993 .06877 .26638 .06178 .25978 Metetra
.664 .741 .908 r
.06178 .25978 .06877 .26638 .07798 .26281 .07101 .25619 Metetra
.664 .741 .908 r
.07101 .25619 .07798 .26281 .08723 .25923 .08028 .25259 Metetra
.664 .741 .908 r
.08028 .25259 .08723 .25923 .09651 .25564 .08958 .24898 Metetra
.664 .741 .908 r
.08958 .24898 .09651 .25564 .10583 .25204 .09891 .24535 Metetra
.664 .741 .908 r
.09891 .24535 .10583 .25204 .11518 .24842 .10828 .24171 Metetra
.664 .741 .908 r
.10828 .24171 .11518 .24842 .12456 .24479 .11768 .23805 Metetra
.664 .741 .908 r
.11768 .23805 .12456 .24479 .13398 .24114 .12712 .23438 Metetra
.664 .741 .908 r
.12712 .23438 .13398 .24114 .14344 .23749 .1366 .2307 Metetra
.664 .741 .908 r
.1366 .2307 .14344 .23749 .15293 .23382 .14611 .227 Metetra
.664 .741 .908 r
.14611 .227 .15293 .23382 .16245 .23013 .15565 .22329 Metetra
.664 .741 .908 r
.15565 .22329 .16245 .23013 .17201 .22643 .16523 .21957 Metetra
.664 .741 .908 r
.16523 .21957 .17201 .22643 .18161 .22272 .17485 .21583 Metetra
.664 .741 .908 r
.17485 .21583 .18161 .22272 .19124 .21899 .1845 .21208 Metetra
.664 .741 .908 r
.1845 .21208 .19124 .21899 .20091 .21525 .19419 .20831 Metetra
.664 .741 .908 r
.19419 .20831 .20091 .21525 .21061 .2115 .20391 .20453 Metetra
.664 .741 .908 r
.20391 .20453 .21061 .2115 .22035 .20773 .21367 .20074 Metetra
.664 .741 .908 r
.21367 .20074 .22035 .20773 .23013 .20395 .22347 .19693 Metetra
.664 .741 .908 r
.22347 .19693 .23013 .20395 .23994 .20015 .23331 .1931 Metetra
.664 .741 .908 r
.23331 .1931 .23994 .20015 .24979 .19634 .24318 .18927 Metetra
.664 .741 .908 r
.24318 .18927 .24979 .19634 .25968 .19251 .25309 .18541 Metetra
.664 .741 .908 r
.25309 .18541 .25968 .19251 .2696 .18867 .26304 .18155 Metetra
.664 .741 .908 r
.26304 .18155 .2696 .18867 .27957 .18482 .27303 .17766 Metetra
.664 .741 .908 r
.27303 .17766 .27957 .18482 .28957 .18095 .28305 .17377 Metetra
.664 .741 .908 r
.28305 .17377 .28957 .18095 .29961 .17707 .29311 .16986 Metetra
.664 .741 .908 r
.29311 .16986 .29961 .17707 .30969 .17317 .30321 .16593 Metetra
.664 .741 .908 r
.30321 .16593 .30969 .17317 .3198 .16925 .31335 .16199 Metetra
.664 .741 .908 r
.31335 .16199 .3198 .16925 .32996 .16532 .32353 .15803 Metetra
.664 .741 .908 r
.32353 .15803 .32996 .16532 .34015 .16138 .33375 .15406 Metetra
.664 .741 .908 r
.33375 .15406 .34015 .16138 .35039 .15742 .34401 .15007 Metetra
.664 .741 .908 r
.34401 .15007 .35039 .15742 .36066 .15345 .3543 .14607 Metetra
.664 .741 .908 r
.3543 .14607 .36066 .15345 .37097 .14946 .36464 .14205 Metetra
.664 .741 .908 r
.36464 .14205 .37097 .14946 .38132 .14545 .37502 .13802 Metetra
.664 .741 .908 r
.37502 .13802 .38132 .14545 .39172 .14143 .38544 .13397 Metetra
.664 .741 .908 r
.38544 .13397 .39172 .14143 .40215 .13739 .3959 .1299 Metetra
.664 .741 .908 r
.3959 .1299 .40215 .13739 .41262 .13334 .4064 .12582 Metetra
.664 .741 .908 r
.4064 .12582 .41262 .13334 .42314 .12927 .41694 .12172 Metetra
.664 .741 .908 r
.41694 .12172 .42314 .12927 .43369 .12519 .42752 .11761 Metetra
.664 .741 .908 r
.42752 .11761 .43369 .12519 .44429 .12109 .43814 .11348 Metetra
.664 .741 .908 r
.43814 .11348 .44429 .12109 .45493 .11697 .44881 .10933 Metetra
.664 .741 .908 r
.44881 .10933 .45493 .11697 .46561 .11284 .45951 .10517 Metetra
.664 .741 .908 r
.45951 .10517 .46561 .11284 .47633 .10869 .47026 .10099 Metetra
.664 .741 .908 r
.47026 .10099 .47633 .10869 .4871 .10453 .48106 .0968 Metetra
.664 .741 .908 r
.48106 .0968 .4871 .10453 .49791 .10035 .49189 .09258 Metetra
.664 .741 .908 r
.49189 .09258 .49791 .10035 .50876 .09615 .50277 .08835 Metetra
.664 .741 .908 r
.50277 .08835 .50876 .09615 .51965 .09193 .51369 .08411 Metetra
.664 .741 .908 r
.51369 .08411 .51965 .09193 .53059 .0877 .52466 .07985 Metetra
.664 .741 .908 r
.52466 .07985 .53059 .0877 .54157 .08345 .53567 .07557 Metetra
.664 .741 .908 r
.53567 .07557 .54157 .08345 .55259 .07919 .54672 .07127 Metetra
.664 .741 .908 r
.54672 .07127 .55259 .07919 .56366 .07491 .55782 .06696 Metetra
.664 .741 .908 r
.55782 .06696 .56366 .07491 .57478 .07061 .56896 .06262 Metetra
.664 .741 .908 r
.56896 .06262 .57478 .07061 .58593 .06629 .58015 .05827 Metetra
.664 .741 .908 r
.58015 .05827 .58593 .06629 .59714 .06196 .59138 .05391 Metetra
.664 .741 .908 r
.59138 .05391 .59714 .06196 .60838 .0576 .60266 .04952 Metetra
.664 .741 .908 r
.60266 .04952 .60838 .0576 .61968 .05323 .61399 .04512 Metetra
.664 .741 .908 r
.61399 .04512 .61968 .05323 .63102 .04885 .62536 .0407 Metetra
.664 .741 .908 r
.62536 .0407 .63102 .04885 .6424 .04444 .63677 .03626 Metetra
.664 .741 .908 r
.63677 .03626 .6424 .04444 .65383 .04002 .64824 .03181 Metetra
.664 .741 .908 r
.64824 .03181 .65383 .04002 .66531 .03558 .65975 .02733 Metetra
.664 .741 .908 r
.65975 .02733 .66531 .03558 .67684 .03112 .6713 .02284 Metetra
.664 .741 .908 r
.6713 .02284 .67684 .03112 .68841 .02664 .68291 .01833 Metetra
.664 .741 .908 r
.68291 .01833 .68841 .02664 .70003 .02215 .69456 .0138 Metetra
.664 .741 .908 r
.03634 .26033 .04341 .26692 .05258 .26336 .04552 .25675 Metetra
.664 .741 .908 r
.04552 .25675 .05258 .26336 .06178 .25978 .05474 .25315 Metetra
.664 .741 .908 r
.05474 .25315 .06178 .25978 .07101 .25619 .06399 .24953 Metetra
.664 .741 .908 r
.06399 .24953 .07101 .25619 .08028 .25259 .07327 .24591 Metetra
.664 .741 .908 r
.07327 .24591 .08028 .25259 .08958 .24898 .08259 .24227 Metetra
.664 .741 .908 r
.08259 .24227 .08958 .24898 .09891 .24535 .09195 .23861 Metetra
.664 .741 .908 r
.09195 .23861 .09891 .24535 .10828 .24171 .10133 .23495 Metetra
.664 .741 .908 r
.10133 .23495 .10828 .24171 .11768 .23805 .11076 .23127 Metetra
.664 .741 .908 r
.11076 .23127 .11768 .23805 .12712 .23438 .12022 .22757 Metetra
.664 .741 .908 r
.12022 .22757 .12712 .23438 .1366 .2307 .12971 .22386 Metetra
.664 .741 .908 r
.12971 .22386 .1366 .2307 .14611 .227 .13924 .22014 Metetra
.664 .741 .908 r
.13924 .22014 .14611 .227 .15565 .22329 .1488 .21641 Metetra
.664 .741 .908 r
.1488 .21641 .15565 .22329 .16523 .21957 .1584 .21266 Metetra
.664 .741 .908 r
.1584 .21266 .16523 .21957 .17485 .21583 .16804 .20889 Metetra
.664 .741 .908 r
.16804 .20889 .17485 .21583 .1845 .21208 .17771 .20511 Metetra
.664 .741 .908 r
.17771 .20511 .1845 .21208 .19419 .20831 .18742 .20132 Metetra
.664 .741 .908 r
.18742 .20132 .19419 .20831 .20391 .20453 .19717 .19751 Metetra
.664 .741 .908 r
.19717 .19751 .20391 .20453 .21367 .20074 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21367 .20074 .22347 .19693 .21677 .18986 Metetra
.664 .741 .908 r
.21677 .18986 .22347 .19693 .23331 .1931 .22663 .18601 Metetra
.664 .741 .908 r
.22663 .18601 .23331 .1931 .24318 .18927 .23652 .18214 Metetra
.664 .741 .908 r
.23652 .18214 .24318 .18927 .25309 .18541 .24646 .17826 Metetra
.664 .741 .908 r
.24646 .17826 .25309 .18541 .26304 .18155 .25643 .17437 Metetra
.664 .741 .908 r
.25643 .17437 .26304 .18155 .27303 .17766 .26644 .17046 Metetra
.664 .741 .908 r
.26644 .17046 .27303 .17766 .28305 .17377 .27648 .16653 Metetra
.664 .741 .908 r
.27648 .16653 .28305 .17377 .29311 .16986 .28657 .16259 Metetra
.664 .741 .908 r
.28657 .16259 .29311 .16986 .30321 .16593 .29669 .15864 Metetra
.664 .741 .908 r
.29669 .15864 .30321 .16593 .31335 .16199 .30686 .15467 Metetra
.664 .741 .908 r
.30686 .15467 .31335 .16199 .32353 .15803 .31706 .15069 Metetra
.664 .741 .908 r
.31706 .15069 .32353 .15803 .33375 .15406 .3273 .14668 Metetra
.664 .741 .908 r
.3273 .14668 .33375 .15406 .34401 .15007 .33758 .14267 Metetra
.664 .741 .908 r
.33758 .14267 .34401 .15007 .3543 .14607 .3479 .13864 Metetra
.664 .741 .908 r
.3479 .13864 .3543 .14607 .36464 .14205 .35827 .13459 Metetra
.664 .741 .908 r
.35827 .13459 .36464 .14205 .37502 .13802 .36867 .13053 Metetra
.664 .741 .908 r
.36867 .13053 .37502 .13802 .38544 .13397 .37911 .12645 Metetra
.664 .741 .908 r
.37911 .12645 .38544 .13397 .3959 .1299 .3896 .12235 Metetra
.664 .741 .908 r
.3896 .12235 .3959 .1299 .4064 .12582 .40012 .11824 Metetra
.664 .741 .908 r
.40012 .11824 .4064 .12582 .41694 .12172 .41069 .11411 Metetra
.664 .741 .908 r
.41069 .11411 .41694 .12172 .42752 .11761 .4213 .10997 Metetra
.664 .741 .908 r
.4213 .10997 .42752 .11761 .43814 .11348 .43195 .10581 Metetra
.664 .741 .908 r
.43195 .10581 .43814 .11348 .44881 .10933 .44264 .10163 Metetra
.664 .741 .908 r
.44264 .10163 .44881 .10933 .45951 .10517 .45337 .09744 Metetra
.664 .741 .908 r
.45337 .09744 .45951 .10517 .47026 .10099 .46415 .09323 Metetra
.664 .741 .908 r
.46415 .09323 .47026 .10099 .48106 .0968 .47497 .08901 Metetra
.664 .741 .908 r
.47497 .08901 .48106 .0968 .49189 .09258 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49189 .09258 .50277 .08835 .49674 .0805 Metetra
.664 .741 .908 r
.49674 .0805 .50277 .08835 .51369 .08411 .50769 .07623 Metetra
.664 .741 .908 r
.50769 .07623 .51369 .08411 .52466 .07985 .51868 .07193 Metetra
.664 .741 .908 r
.51868 .07193 .52466 .07985 .53567 .07557 .52972 .06762 Metetra
.664 .741 .908 r
.52972 .06762 .53567 .07557 .54672 .07127 .5408 .06329 Metetra
.664 .741 .908 r
.5408 .06329 .54672 .07127 .55782 .06696 .55193 .05895 Metetra
.664 .741 .908 r
.55193 .05895 .55782 .06696 .56896 .06262 .5631 .05458 Metetra
.664 .741 .908 r
.5631 .05458 .56896 .06262 .58015 .05827 .57432 .0502 Metetra
.664 .741 .908 r
.57432 .0502 .58015 .05827 .59138 .05391 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .59138 .05391 .60266 .04952 .59689 .04138 Metetra
.664 .741 .908 r
.59689 .04138 .60266 .04952 .61399 .04512 .60825 .03695 Metetra
.664 .741 .908 r
.60825 .03695 .61399 .04512 .62536 .0407 .61965 .03249 Metetra
.664 .741 .908 r
.61965 .03249 .62536 .0407 .63677 .03626 .6311 .02802 Metetra
.664 .741 .908 r
.6311 .02802 .63677 .03626 .64824 .03181 .64259 .02353 Metetra
.664 .741 .908 r
.64259 .02353 .64824 .03181 .65975 .02733 .65414 .01902 Metetra
.664 .741 .908 r
.65414 .01902 .65975 .02733 .6713 .02284 .66573 .0145 Metetra
.664 .741 .908 r
.66573 .0145 .6713 .02284 .68291 .01833 .67736 .00995 Metetra
.664 .741 .908 r
.67736 .00995 .68291 .01833 .69456 .0138 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 233.562},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GQ000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo2Goo00IcW248000002U:Li`4Ool015[F248003W>VWoo003oOol9Ool01RU:>Lioogoo>LhYBP=o
o`06HaPHaW>LLi`@Q5:DVGoo003oOol9Ool00`Q2Oomoo`02Ool01P00Oomoogoo8@QBU09oo`03DY@H
aWoo09Qoo`00ogoo2Goo00<007>LOol00Woo00D007ooOomoo`0000Aoo`03001oogoo09Moo`00ogoo
2Goo00H002U:LiaoocW>:DX3Ool00`00Oomoo`02Ool00`00Oomoo`2GOol00?moo`Uoo`0648@icP00
000YBW>L0goo00<007ooOol00Woo00<007ooOol0Ugoo003oOol9Ool00d8@<Haoo`06Ool01R48DYAo
ogooDY@Q29Uoo`00ogoo2Woo00<HaS6<JeX01Goo00IS61S6LiacW1S6HaPDOol20023Ool00?moo`]o
o`04>Lh8@P0048@4Ool015[F2488@V<H4Woo0`0000=oo`00Ool0PWoo003oOolWOol20003Ool30022
Ool00?moobAoo`<0009oo`<00004E_d007oo0021Ool00?moob5oo`<000=oo`8000AFo@<0085oo`00
ogoo7goo0P000goo0`0000=Fo@00E_d00eKm0P0000=oo`00Ool0Ogoo003oOolLOol30003Ool20005
E_d01000E_eFoEKm0`0000=oo`00Ool0OWoo003oOolJOol20004Ool20002E_d00`00E_eFo@02E_d5
000015Km001oo`00Ogoo003oOolGOol40003Ool20005E_d01P00E_d00000E_d0009Fo@06001FoEKm
001oo`00OWoo003oOolEOol20004Ool300000eKm001Fo@04E_d20004E_d01@00E_eFo@00E_d00P00
00=oo`00Ool0O7oo003oOolBOol30003Ool300000eKm001Fo@02E_d00`00E_d0000200000eKm001F
o@04E_d01000E_d000000UKm0P00OGoo003oOol@Ool20002Ool40002E_d00`00E_eFo@03E_d20005
E_d00`00E_eFo@02E_d30004E_d2001lOol00?moo`eoo`<0009oo`800003E_d005Km00AFo@03001F
o@0000800003E_d005Km00AFo@03001Fo@0000800003E_d0000000AFo@8007aoo`00ogoo2Woo0`00
0goo0P0015Km00<005KmE_d00UKm0P001EKm00@005KmE_eFo@<000EFo@03001Fo@0000800003E_d0
000007]oo`00ogoo27oo0P000goo0`0000=Fo@00E_d015Km00@005Km0000009Fo@03001FoEKm009F
o@@0009Fo@03001FoEKm00=Fo@8000EFo@8007Yoo`00ogoo1Goo0`000goo0P001EKm00<005KmE_d0
0UKm0P001EKm00H005Km000005Km0005E_d00`00E_d000040005E_d2001jOol00?moo`=oo`8000Ao
o`80009Fo@03001FoEKm009Fo@03001Fo@0000800003E_d005Km00AFo@8000AFo@03001FoEKm009F
o@8000=Fo@03001Fo@0000=Fo@@007Uoo`00ogoo10000goo0P001EKm00<005KmE_d00`001EKm00<0
05Km00000P0000=Fo@00E_d015Km00H005Km000005Km0003E_d00`00E_d000030002E_d00`00Ool0
001hOol00?eoo`8000Aoo`<00003E_d005Km00AFo@<0009Fo@03001FoEKm00=Fo@8000EFo@03001F
oEKm009Fo@8000AFo@03001Fo@0000800003E_d005Km00AFo@8007Qoo`00nWoo0`000goo0`001EKm
00<005Km00000P0000=Fo@00E_d00eKm00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P00
00=Fo@00E_d00eKm0P0000=Fo@00E_d00UKm00<005KmE_d00UKm0`00Mgoo003gOol30003Ool30002
E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm0P001EKm00@005KmE_eFo@<000EFo@08001Fo@00
001Fo@00E_d000=Fo@03001Fo@0000800004E_d007oo001fOol00?Eoo`8000=oo`<00003E_d005Km
00=Fo@03001Fo@0000800003E_d005Km00AFo@04001Fo@000002E_d00`00E_eFo@02E_d40002E_d0
0`00E_eFo@03E_d20004E_d20003E_d20005E_d2001fOol00?9oo`<000=oo`8000EFo@04001FoEKm
E_d20005E_d01000E_eFoEKm0`001EKm00H005Km000005Km0005E_d00`00E_d0000200000eKm001F
o@04E_d01P00E_d00000E_d000EFo@<007Eoo`00l7oo0P000goo0`0000=Fo@00E_d015Km00@005Km
0000009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm00=Fo@8000AFo@03001FoEKm009Fo@8000EF
o@04001FoEKmE_d30004E_d00`00E_d00002000015Km001oo`00M7oo003]Ool30003Ool20005E_d0
1000E_eFoEKm0`001EKm00H005Km000005Km0005E_d00`00E_d0000200000eKm001Fo@04E_d01P00
E_d00000E_d000EFo@@00003E_d0000000AFo@8000EFo@8007Aoo`00jgoo0P0017oo0P000UKm00<0
05KmE_d00UKm10000UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00UKm0P001EKm00@005KmE_eF
o@<000AFo@03001Fo@0000800003E_d005Km009Fo@04001Fo@00E_d20002E_d00`00E_eFo@02E_d0
0`00Ool0001cOol00>Qoo`@0009oo`<000EFo@06001Fo@00001Fo@001EKm00<005Km00000P0000=F
o@00E_d015Km00H005Km000005Km0005E_d40002E_d00`00E_eFo@02E_d20005E_d01000E_eFoEKm
0`001EKm00<005KmE_d00`0000=oo`00Ool0LGoo003VOol20002Ool40002E_d00`00E_eFo@03E_d2
0004E_d00`00E_eFo@02E_d20005E_d01000E_eFoEKm0`0015Km00<005Km00000P0000=Fo@00E_d0
15Km00@005Km0000009Fo@03001FoEKm009Fo@03001Fo@0000800003E_d005Km00AFo@<0009Fo@03
001oo`00079oo`00/7oo0P0000<8@WooOol00Woo00AJePQ2000icRQoo`<0009oo`800003E_d005Km
00AFo@03001Fo@0000800003E_d005Km00AFo@04001Fo@000002E_d00`00E_eFo@02E_d40002E_d0
0`00E_eFo@02E_d20005E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030002E_d01@00E_eFo@00
E_d00`0000=Fo@00E_d00eKm00<007oo0000LGoo002aOol00`00Oomoo`02Ool01V<H6<IcW7>L48AB
U2Aoo`<000=oo`8000AFo@03001FoEKm009Fo@8000EFo@04001FoEKmE_d30005E_d01P00E_d00000
E_d000EFo@04001Fo@000002E_d00`00E_eFo@02E_d00`00E_d0000200000eKm001Fo@04E_d30002
E_d01000E_eFo@000UKm0P001EKm00<005KmE_d00`0000=oo`00Ool0Kgoo002]Ool60003Ool01R48
DYAoogooDY@HaR9oo`8000Aoo`800003E_d005Km00AFo@04001Fo@000002E_d00`00E_eFo@02E_d4
0002E_d00`00E_eFo@03E_d20004E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030005E_d00`00
E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@04E_d30002E_d3001`Ool00:eo
o`05>LiBU7ooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`0MOol30004Ool20004E_d01000E_eF
oEKm0`001EKm00H005Km000005Km0005E_d00`00E_d0000200000eKm001Fo@03E_d00`00E_d00002
00000eKm001Fo@04E_d30002E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@040004E_d00`00E_d0
000200000eKm001Fo@03E_d00`00Ool0001_Ool00:eoo`05Li`HaW>LOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`0KOol20004Ool300000eKm001Fo@03E_d40002E_d00`00E_eFo@03E_d20004E_d0
0`00E_eFo@02E_d20005E_d00`00E_eFo@030005E_d00`00E_d0000200000eKm001Fo@03E_d00`00
E_d0000200000eKm001Fo@04E_d30002E_d20004E_d20005E_d01000E_eFoEKm0`00Kgoo002^Ool0
15:D<Haoo`0017oo00<007ooOol00Woo00<007ooOol067oo0`000goo0`001EKm00H005Km000005Km
0005E_d00`00E_d0000200000eKm001Fo@04E_d01P00E_d00000E_d000EFo@<000=Fo@03001FoEKm
009Fo@8000EFo@03001FoEKm00<000EFo@03001Fo@0000800003E_d005Km00=Fo@03001Fo@000080
0003E_d005Km00AFo@08001Fo@00001Fo@00Ool006ioo`00[goo00<Q26<H000017oo00HQ25:DOomo
oe:D8@PHOol20003Ool30003E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@02E_d20005E_d01000
E_eFoEKm0`0015Km00<005Km00000P0000=Fo@00E_d015Km00H005Km000005Km0005E_d30003E_d0
0`00E_eFo@02E_d20005E_d01000E_eFoEKm0P001EKm00@005KmE_eFo@<000AFo@03001oo`0006eo
o`00[goo00=[FR48000017oo00IS61S6LiacW1S6HaPEOol30002Ool300000eKm001Fo@04E_d01P00
E_d00000E_d000EFo@04001Fo@000002E_d00`00E_eFo@02E_d40002E_d00`00E_eFo@02E_d20005
E_d01000E_eFoEKm0`0015Km00<005Km00000P0000=Fo@00E_d015Km00H005Km000005Km0005E_d0
0`00E_d0000200000eKm001Fo@03E_d40002E_d00`00E_eFo@02E_d3001]Ool00;1oo`03>Lh8@Woo
00Aoo`04F]H8@PQ2HaPCOol30003Ool20005E_d01000E_eFoEKm0`0015Km00@005KmE_eFo@<000EF
o@06001Fo@00001Fo@001EKm00@005Km0000009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm009F
o@8000EFo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30002E_d01@00E_eFo@00E_d00P0000=F
o@00E_d015Km00@005Km0000009Fo@8006aoo`00c7oo0P0017oo0P000UKm00<005KmE_d00UKm1000
0UKm00<005KmE_d00UKm10000UKm00<005KmE_d00eKm0P0015Km00@005KmE_eFo@<000EFo@06001F
o@00001Fo@001EKm00@005Km0000009Fo@03001FoEKm009Fo@03001Fo@0000800003E_d005Km00=F
o@@0009Fo@04001FoEKm0002E_d20004E_d00`00E_eFo@02E_d20005E_d2001[Ool00<Uoo`<000=o
o`<000EFo@06001Fo@00001Fo@001EKm00@005Km0000009Fo@03001FoEKm009Fo@03001Fo@000080
0003E_d005Km00=Fo@@0009Fo@03001FoEKm00=Fo@8000AFo@03001FoEKm009Fo@8000EFo@03001F
oEKm00<000EFo@06001Fo@00001Fo@001EKm00<005Km00000P0000=Fo@00E_d00eKm00<005Km0000
0P0000=Fo@00E_d015Km0P00Jgoo0037Ool20003Ool30002E_d00`00E_eFo@03E_d20004E_d00`00
E_eFo@02E_d20005E_d00`00E_eFo@030005E_d01P00E_d00000E_d000EFo@03001Fo@0000800003
E_d005Km00=Fo@03001Fo@0000800003E_d005Km00AFo@<0009Fo@03001FoEKm00=Fo@8000AFo@03
001FoEKm009Fo@<000AFo@03001FoEKm00<000EFo@03001Fo@0000800003E_d0000006Yoo`00a7oo
0`000Woo0`0000=Fo@00E_d00eKm00<005Km00000P0000=Fo@00E_d015Km00H005Km000005Km0005
E_d30003E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030005E_d0
0`00E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@04E_d01@00E_d00000E_d0
0P0015Km0`000UKm00<005KmE_d00eKm0P001EKm0P00JGoo0032Ool20003Ool20005E_d01000E_eF
oEKm0P001EKm00@005KmE_eFo@<000AFo@03001Fo@0000800003E_d005Km00AFo@06001Fo@00001F
o@001EKm00H005Km000005Km0005E_d30003E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030005
E_d01000E_eFoEKm0`0015Km00<005Km00000P0000=Fo@00E_d00eKm00<005Km00000P0000=Fo@00
E_d015Km0P00JGoo002oOol30003Ool20002E_d00`00E_eFo@02E_d01000E_d000000UKm00<005Km
E_d00UKm10000UKm00<005KmE_d00UKm0P001EKm00@005KmE_eFo@<000AFo@04001FoEKmE_d30004
E_d00`00E_d0000200000eKm001Fo@04E_d01P00E_d00000E_d000EFo@<000=Fo@03001FoEKm009F
o@@0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000EFo@03001Fo@0000800003E_d00000
06Qoo`00_Goo0P0000Aoo`00Oomoo`8000EFo@03001FoEKm00<000EFo@04001Fo@000002E_d00`00
E_eFo@02E_d01000E_d000000UKm00<005KmE_d00UKm10000UKm00<005KmE_d00UKm10000UKm00<0
05KmE_d00UKm0P001EKm00@005KmE_eFo@<000AFo@03001Fo@0000800003E_d005Km00AFo@06001F
o@00001Fo@001EKm00H005Km000005Km0005E_d30002E_d00`00E_eFo@03E_d20005E_d2001WOol0
0;Yoo`<000Aoo`800003E_d005Km00AFo@<000=Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<0
00EFo@06001Fo@00001Fo@001EKm00@005Km0000009Fo@03001FoEKm009Fo@04001Fo@000002E_d0
0`00E_eFo@02E_d40002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@02E_d20004E_d01000E_eF
oEKm0`000eKm0P0000IFo@00000005Km0004E_d00`00E_d0000200000eKm001Fo@04E_d2001WOol0
0;Moo`<000Aoo`<000AFo@03001Fo@0000800003E_d005Km00AFo@06001Fo@00001Fo@001EKm0`00
0UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00UKm0P001EKm00<005KmE_d00`001EKm00H005Km
000005Km0005E_d01000E_d000000UKm00<005KmE_d00UKm00<005Km00000P0000=Fo@00E_d00eKm
10000UKm00@005KmE_eFo@<000EFo@03001FoEKm00<000EFo@04001FoEKmE_d4001VOol00;Eoo`80
00=oo`@0009Fo@03001FoEKm009Fo@8000EFo@04001FoEKmE_d30004E_d00`00E_d0000200000eKm
001Fo@03E_d00`00E_d0000200000eKm001Fo@04E_d01P00E_d00000E_d000EFo@<0009Fo@03001F
oEKm00=Fo@8000AFo@04001FoEKmE_d30005E_d00`00E_eFo@030005E_d01P00E_d00000E_d000EF
o@06001Fo@00001Fo@001EKm0`000eKm00<005KmE_d00UKm10000UKm00<007oo0000IGoo002bOol3
0003Ool20002E_d00`00E_eFo@02E_d01000E_d000000UKm00<005KmE_d00UKm10000UKm00<005Km
E_d00UKm0P001EKm00@005KmE_eFo@8000EFo@04001FoEKmE_d30004E_d00`00E_d0000200000eKm
001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d40002E_d00`00E_eFo@03E_d30002E_d00`00
E_eFo@03E_d20004E_d01000E_eFoEKm0`0000IFo@00E_eFo@00E_d300000eKm001Fo@04E_d01P00
E_d00000E_d000EFo@8006Eoo`00/7oo0P0017oo0P001EKm00<005KmE_d00`001EKm00@005Km0000
009Fo@03001FoEKm009Fo@04001Fo@000002E_d00`00E_eFo@02E_d01000E_d000000UKm00<005Km
E_d00UKm10000UKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`001EKm00H005Km000005Km0005
E_d00`00E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d40002E_d00`00
E_d00002E_d20005E_d00`00E_eFo@02E_d20004E_d01000E_eFoEKm1000I7oo002]Ool30004Ool2
0002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030005E_d00`00
E_eFo@030005E_d01P00E_d00000E_d000EFo@04001Fo@000002E_d00`00E_eFo@02E_d30003E_d0
0`00E_eFo@02E_d20004E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030005E_d01P00E_d00000
E_d000EFo@@0009Fo@03001FoEKm009Fo@03001Fo@0000800003E_d005Km00=Fo@@0009Fo@8006Ao
o`00Zgoo0P0017oo0`001EKm00H005Km000005Km0005E_d01P00E_d00000E_d000EFo@<0009Fo@03
001FoEKm00=Fo@<0009Fo@03001FoEKm00=Fo@8000AFo@04001FoEKmE_d30005E_d01P00E_d00000
E_d000EFo@06001Fo@00001Fo@001EKm00H005Km000005Km0005E_d30002E_d00`00E_eFo@03E_d2
0004E_d01000E_eFoEKm0`001EKm00<005KmE_d00`001EKm00H005Km000005Km0005E_d2001SOol0
0:Qoo`<000=oo`<0009Fo@03001FoEKm00=Fo@8000AFo@04001FoEKmE_d30004E_d00`00E_d00002
00000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03
E_d40002E_d00`00E_eFo@03E_d20004E_d01000E_eFoEKm0`0015Km00@005KmE_eFo@<000AFo@03
001Fo@0000800003E_d005Km00=Fo@03001Fo@0000800003E_d005Km00=Fo@@0009Fo@03001FoEKm
00=Fo@<0009Fo@03001FoEKm00=Fo@8000AFo@04001FoEKmE_d4001ROol00:Eoo`<000=oo`<00003
E_d005Km00=Fo@03001Fo@0000800003E_d005Km00=Fo@@0009Fo@03001FoEKm009Fo@8000EFo@03
001FoEKm00<000EFo@03001FoEKm00<000EFo@04001Fo@000002E_d00`00E_eFo@02E_d00`00E_d0
000200000eKm001Fo@03E_d40002E_d00`00E_eFo@02E_d40002E_d00`00E_eFo@02E_d20005E_d0
0`00E_eFo@030005E_d01000E_d000000UKm00@005KmE_eFo@800006E_d00000001Fo@0015Km00<0
05Km00000P0000=Fo@00E_d00eKm10000UKm0P00HWoo002SOol20003Ool30005E_d00`00E_eFo@03
0005E_d01000E_d000000UKm00<005KmE_d00UKm00@005Km0000009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000EFo@06001Fo@00
001Fo@001EKm00H005Km000005Km0005E_d01000E_d000000UKm00<005KmE_d00UKm0`000eKm00<0
05KmE_d00UKm0P001EKm00<005KmE_d00`001EKm00<005KmE_d00`001EKm00H005Km000005Km0005
E_d2001QOol00:1oo`<0009oo`<000=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000EF
o@03001FoEKm00<000EFo@06001Fo@00001Fo@001EKm00@005Km0000009Fo@03001FoEKm009Fo@04
001Fo@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@03E_d20004E_d01000E_eFoEKm0`00
15Km00@005KmE_eFo@<000EFo@06001Fo@00001Fo@001EKm00H005Km000005Km0005E_d400000eKm
001Fo@04E_d30002E_d00`00E_eFo@03E_d20004E_d01000E_eFoEKm10002Goo1P0017oo00AJePQ2
000icTUoo`00WWoo0P000goo0P0000=Fo@00E_d015Km00@005Km0000009Fo@03001FoEKm009Fo@04
001Fo@000002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@02E_d2
0005E_d00`00E_eFo@030005E_d01P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km00=F
o@@0009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm00=Fo@8000AFo@04001FoEKmE_d30004E_d0
0`00E_d00002000015Km001Fo@000UKm00<005Km00000P0000=Fo@00E_d00eKm00<005Km00000P00
00=Fo@00E_d00eKm10000UKm0P002Goo00=:DP00HaP00Woo00H8@WooOomoof<H6<H2Li`00a24DYAo
o`17Ool009]oo`<000=oo`8000AFo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000EFo@06001F
o@00001Fo@001EKm00H005Km000005Km0005E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm
00=Fo@8000AFo@03001FoEKm00<000EFo@06001Fo@00001Fo@001EKm00@005Km0000009Fo@03001F
oEKm009Fo@03001Fo@0000800003E_d005Km00=Fo@@0009Fo@03001FoEKm009Fo@8000EFo@80009F
o@8000EFo@03001FoEKm00<000EFo@06001Fo@00001Fo@001EKm0P002Goo00=:DP00HaP01Goo00HQ
25:DOomooe:D6<I8Ool009Uoo`8000Aoo`800003E_d005Km00AFo@06001Fo@00001Fo@001EKm0`00
0UKm00<005KmE_d00eKm0P0015Km00@005KmE_eFo@<000AFo@04001FoEKmE_d30004E_d00`00E_d0
000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d30003E_d00`00E_eFo@02E_d2
0004E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030005E_d01P00E_d00000E_d000EFo@06001F
o@00001Fo@001EKm100000=Fo@00E_d015Km0`000UKm00<005KmE_d00eKm0P0015Km00@005KmE_eF
o@@000Uoo`03DY@8@V<H00Aoo`03001oogoo009oo`03001oogoo04Ioo`00UWoo0`000goo0`0015Km
00@005KmE_eFo@<000AFo@03001Fo@0000800003E_d005Km00=Fo@03001Fo@0000800003E_d005Km
00=Fo@@0009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000EF
o@06001Fo@00001Fo@001EKm00H005Km000005Km0005E_d01P00E_d00000E_d000EFo@<0009Fo@03
001FoEKm00=Fo@8000AFo@04001FoEKmE_d30004E_d01000E_eFoEKm0`0015Km00<005Km00000P00
00=Fo@00E_d00eKm00<005Km00000P0000=Fo@00E_d00eKm10000UKm0P002Woo00=S60Q2HaP00goo
00<007ooOol00Woo00<007ooOol0AWoo002COol40002Ool30002E_d00`00E_eFo@02E_d40002E_d0
0`00E_eFo@02E_d20005E_d00`00E_eFo@030005E_d01000E_d000000UKm00<005KmE_d00UKm00@0
05Km0000009Fo@03001FoEKm009Fo@04001Fo@000002E_d00`00E_eFo@02E_d30003E_d00`00E_eF
o@02E_d20004E_d01000E_eFoEKm0`0015Km00@005KmE_eFo@<000AFo@03001Fo@0000800003E_d0
05Km00=Fo@03001Fo@0000800003E_d005Km00=Fo@@0009Fo@03001FoEKm009Fo@@0009Fo@8000=F
o@8000EFo@03001FoEKm00<000EFo@06001Fo@00001Fo@001EKm0P002Woo00=BU1S6Ool00Woo00<0
07ooOol00Woo00<007ooOol0AWoo002AOol20003Ool300000eKm001Fo@03E_d01000E_d000000UKm
00<005KmE_d00UKm00@005Km0000009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000EF
o@03001FoEKm00<000EFo@03001FoEKm00<000EFo@06001Fo@00001Fo@001EKm00H005Km000005Km
0004E_d40002E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@030005E_d00`00E_eFo@030005E_d0
1P00E_d00000E_d000EFo@06001Fo@00001Fo@001EKm00H005Km000005Km0005E_d30002E_d00`00
E_eFo@03E_d20004E_d01000E_eFoEKm10002Woo00H007ooOomoob48DY@2Ool00e:D8@Qoo`17Ool0
05Uoo`H000Aoo`04F]H8@P00>LhWOol30003Ool20005E_d00`00E_eFo@030005E_d00`00E_eFo@04
0004E_d01000E_d000000UKm00<005KmE_d00UKm00@005Km0000009Fo@03001FoEKm009Fo@<0009F
o@03001FoEKm00=Fo@<000=Fo@04001FoEKmE_d30004E_d01000E_eFoEKm0`0015Km00@005Km0000
009Fo@03001FoEKm009Fo@04001Fo@000002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@02E_d3
0002E_d00`00E_eFo@03E_d20004E_d01000E_eFoEKm0`0015Km00@005KmE_eFo@<000AFo@03001F
o@0000800003E_d005Km00=Fo@03001Fo@0000800003E_d005Km00=Fo@@0009Fo@8000Eoo`060012
47>LOolicQS60goo00IS61S6LiacW1S6HaQ8Ool005Uoo`03BU8006<H009oo`06249oogooOomS61S6
0W>L00<@Q5:DOol08goo0P0017oo0P000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00UKm0`00
15Km00<005KmE_d00`001EKm00<005KmE_d00`001EKm00H005Km000005Km0004E_d00`00E_d00002
00000eKm001Fo@03E_d40002E_d00`00E_eFo@02E_d40002E_d00`00E_eFo@02E_d20005E_d00`00
E_eFo@030005E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km00<005Km00000P0000=F
o@00E_d00eKm10000UKm00<005KmE_d00UKm100000AFo@00E_d0009Fo@<000EFo@03001FoEKm00<0
00EFo@06001Fo@00001Fo@001EKm0P0017oo00IBU1S6000002U:Li`4Ool015[F2488@V<HBGoo001J
Ool00dYB001S6005Ool01R48DYAoogooDY@HaR5oo`<000=oo`<000EFo@04001Fo@000002E_d00`00
E_eFo@02E_d01000E_d000000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00eKm0`000UKm00<0
05KmE_d00eKm0P0015Km00<005KmE_d00`001EKm00@005Km0000009Fo@03001FoEKm009Fo@04001F
o@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm00=Fo@8000AF
o@04001FoEKmE_d30004E_d00`00E_eFo@030005E_d01P00E_d00000E_d000EFo@06001Fo@00001F
o@000eKm00<005Km00000P000UKm00<005KmE_d00eKm0`000UKm00<005KmE_d00eKm0P0015Km00@0
05KmE_eFo@@005Yoo`00Fgoo00=BU0Q2HaP017oo00<007ooOol00Woo00<007ooOol07Goo0P000goo
0`000eKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`001EKm00H005Km000005Km0004E_d00`00
E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d30003E_d00`00E_eFo@02
E_d20005E_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03
E_d00`00E_d0000200000eKm001Fo@03E_d40002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@02
E_d20004E_d01000E_eFoEKm0`0015Km00<005Km00000P0000=Fo@00E_d00eKm00<005Km00000P00
00=Fo@00E_d00eKm00<005Km00000P0000=Fo@00E_d00eKm10000UKm0P00FWoo001LOol00f<H249S
6003Ool00`00Oomoo`02Ool00`00Oomoo`0JOol30003Ool20002E_d00`00E_eFo@02E_d01000E_d0
00000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00`001EKm00<0
05KmE_d00`001EKm00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@001EKm0`000UKm
00<005KmE_d00eKm0`000UKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`001EKm00H005Km0000
05Km0005E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km10000UKm00<005KmE_d00UKm
0P0000=Fo@00E_d00UKm00<005KmE_d00`001EKm00<005KmE_d00`001EKm00H005Km000005Km0005
E_d2001IOol005eoo`03DY@HaWoo009oo`03001oogoo009oo`03001oogoo01Qoo`8000=oo`<000EF
o@03001FoEKm00<000EFo@06001Fo@00001Fo@0015Km00<005Km00000P0000=Fo@00E_d00eKm0`00
0eKm00<005KmE_d00UKm0`000eKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00<005Km
00000P0000=Fo@00E_d00eKm00<005Km00000P0000=Fo@00E_d00eKm00@005Km0000009Fo@03001F
oEKm009Fo@<000=Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d01000E_eFoEKm0`00
15Km00@005Km0000009Fo@03001FoEKm009Fo@08001Fo@00001Fo@00E_d000=Fo@<0009Fo@03001F
oEKm00=Fo@<0009Fo@03001FoEKm00=Fo@8000AFo@04001FoEKmE_d4001HOol005ioo`06001oogoo
OolQ25:D0Woo00=BU248Ool05Woo0`000Woo0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d0
0UKm0P0015Km00<005KmE_d00`001EKm00@005Km0000009Fo@03001FoEKm009Fo@04001Fo@000002
E_d00`00E_eFo@02E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@8000EFo@03001F
oEKm00<000EFo@03001FoEKm00<000EFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d4
0002E_d00`00E_eFo@02E_d40002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030004E_d50000
0eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d4
0002E_d2001HOol005Uoo`06001247>LOolicQS60goo00IS61S6LiacW1S6HaPDOol30003Ool20002
E_d00`00E_eFo@02E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km0`000eKm00<005Km
E_d00UKm0P001EKm00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00
E_d00eKm00@005Km0000009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@<000=Fo@04001F
oEKmE_d30004E_d01000E_eFoEKm0`0015Km00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00
001Fo@001EKm00H005Km000005Km0005E_d30002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@03
0005E_d00`00E_eFo@030005E_d01P00E_d00000E_d000EFo@8005Moo`00FGoo00IBU1S6000002U:
Li`4Ool015[F2488@V<H4goo0P0017oo0P001EKm00<005KmE_d00`0015Km00@005KmE_eFo@<000AF
o@04001Fo@000002E_d00`00E_eFo@02E_d01000E_d000000UKm00<005KmE_d00UKm0`000UKm00<0
05KmE_d00eKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`001EKm00H005Km000005Km0005
E_d01P00E_d00000E_d000AFo@@0009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm009Fo@8000EF
o@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d00`00E_d0000200000eKm001Fo@03E_d01P00
E_d00000E_d000EFo@<0009Fo@03001FoEKm00=Fo@<000=Fo@04001FoEKmE_d30004E_d00`00E_eF
o@04001GOol007Moo`<000Aoo`80009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@@000=F
o@03001FoEKm00<000EFo@03001FoEKm00<000EFo@06001Fo@00001Fo@0015Km00<005Km00000P00
00=Fo@00E_d00eKm0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d00UKm0P0015Km00@005Km
E_eFo@<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01000E_d000000UKm00<005KmE_d00UKm
00H005Km000005Km0005E_d30002E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@030005E_d00`00
E_eFo@030003E_d200001UKm00000000E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@@0009F
o@03001FoEKm009Fo@<0009Fo@03001oo`0005Ioo`00MGoo0P0017oo100015Km00H005Km000005Km
0004E_d01000E_d000000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00UKm0`000eKm00<005Km
E_d00UKm0P0015Km00<005KmE_d00`001EKm00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00
001Fo@001EKm00H005Km000005Km0004E_d40002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@03
0005E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03E_d01000E_d000000UKm00<0
05KmE_d00UKm0`000UKm00<005KmE_d00eKm0`000UKm00@005KmE_eFo@<000EFo@03001FoEKm00<0
00EFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d00`00Ool0001EOol0079oo`<000=o
o`<000AFo@03001FoEKm00<000AFo@03001FoEKm00<000EFo@04001Fo@000002E_d00`00E_eFo@02
E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00UKm0P001EKm
00<005KmE_d00`0015Km00@005KmE_eFo@<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00
E_d00000E_d000EFo@<0009Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm00<000EFo@03001FoEKm
00<000EFo@06001Fo@00001Fo@0015Km00<005Km00000P0000=Fo@00E_d00eKm00@005Km0000009F
o@03001FoEKm009Fo@<0009Fo@03001FoEKm00=Fo@8000AFo@04001FoEKmE_d30004E_d00`00E_eF
o@04001EOol0071oo`8000Aoo`80009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d01000E_d00000
0UKm00<005KmE_d00UKm00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@@0
00=Fo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@03
001Fo@0000800003E_d005Km00=Fo@<0009Fo@03001FoEKm00=Fo@<0009Fo@03001FoEKm00=Fo@80
00AFo@03001FoEKm00<000EFo@03001FoEKm00<00003E_d005Km009Fo@06001Fo@00001Fo@0015Km
00<005Km00000P0000=Fo@00E_d00eKm10000UKm00<005KmE_d00UKm0`000eKm0P00E7oo001]Ool3
0003Ool30005E_d01P00E_d00000E_d000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01000E_d0
00000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm10000eKm00<005KmE_d00`001EKm00<0
05KmE_d00`001EKm00H005Km000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm0`000eKm
00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`001EKm00H005Km0000
05Km0004E_d00`00E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d30002
E_d00`00E_eFo@03E_d30003E_d20002E_d30004E_d00`00E_eFo@030005E_d01P00E_d00000E_d0
00EFo@@00003E_d005Km00=Fo@<005=oo`00JWoo10000Woo0`000eKm00<005KmE_d00UKm0P0015Km
00<005KmE_d00`001EKm00<005KmE_d0100015Km00H005Km000005Km0004E_d01000E_d000000UKm
00<005KmE_d00UKm0`000eKm00<005KmE_d00UKm0`000eKm00@005KmE_eFo@<000AFo@03001FoEKm
00<000EFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d01000E_d000000UKm00<005Km
E_d00UKm0`000UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00`001EKm00<005KmE_d00`001EKm
00H005Km000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d40002E_d00`00E_eFo@02E_d3
0003E_d01000E_eFoEKm0`0015Km00<005KmE_d00`001EKm00D005Km000004Eb00<0059oo`00J7oo
0P0017oo0P000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d30003E_d00`00E_eFo@02E_d3
0004E_d00`00E_eFo@030004E_d00`00E_eFo@030005E_d01000E_d000000UKm00<005KmE_d00UKm
00H005Km000005Km0004E_d40002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@02E_d20004E_d0
1000E_eFoEKm0`0015Km00<005KmE_d0100015Km00H005Km000005Km0004E_d00`00E_d000020000
0eKm001Fo@03E_d30003E_d00`00E_eFo@02E_d30003E_d01000E_eFoEKm0`0015Km00<005KmE_d0
0`001EKm00D005Km000005Km008000AFo@06001Fo@00001Fo@0015Km10000UKm00<005KmE_d00UKm
0`000UKm00<005KmE_d00eKm0P000dEb00<007oo0000DWoo001UOol30003Ool300000eKm001Fo@02
E_d00`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d00UKm00@005Km0000009Fo@03001F
oEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<0
00AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@00
15Km10000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d00`0015Km00<005KmE_d0100015Km00H0
05Km000005Km0005E_d01P00E_d00000E_d000AFo@@0009Fo@03001FoEKm009Fo@<0009Fo@03001F
oEKm00=Fo@8000AFo@04001FoEKmE_d30004E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@00
15Km00<005Km00000P0000=5LP00AG800TEb00@007ooOol0055oo`00Hgoo0P000goo0`000eKm00<0
05KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`001EKm00H005Km000005Km0004
E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0005E_d30002E_d00`00E_eFo@02
E_d20005E_d00`00E_eFo@030004E_d01000E_eFoEKm0`0015Km00@005Km0000009Fo@03001FoEKm
009Fo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d00`0015Km
00@005KmE_eFo@<000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d00`00E_d00002
00000eKm001Fo@03E_d40002E_d00`00E_eFo@02E_d20004E_d01000E_eFoEKm0`0015Km00<005Km
E_d00`0014Eb00<004EbAG800TEb00<007oo0000DGoo001POol30003Ool20002E_d00`00E_eFo@02
E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000AF
o@03001FoEKm00<000EFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@04001F
o@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@030005E_d0
0`00E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000EFo@<0009F
o@03001FoEKm009Fo@@0009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d00`00E_eF
o@040004E_d00`00E_d000030005E_d01P00E_d00000E_d000AFo@@0009Fo@03001FoEKm009Fo@<0
0095LP030015LTEb0095LP030015LTEb0095LP04001oogoo001@Ool005ioo`8000=oo`<000EFo@03
001FoEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000EFo@06001F
o@00001Fo@0015Km0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d0
100015Km00H005Km000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm0`000UKm00<005Km
E_d00eKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00
E_d00eKm00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km10000UKm00<005Km
E_d00UKm0`0015Km00<005KmE_d00`000UKm00<005Km00000eKm0`0015Km00H005Km000005Km0005
E_d01P00E_d00000AG8000=5LP030015LTEb0095LP030015LTEb0095LP05001oogooOol0001?Ool0
05]oo`<0009oo`<000=Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm
00<000AFo@04001FoEKmE_d30004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km
0004E_d30003E_d00`00E_eFo@02E_d30004E_d00`00E_eFo@030004E_d00`00E_eFo@040004E_d0
1P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@<000=Fo@03001FoEKm009Fo@<0
009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@04001Fo@00
0002E_d00`00E_eFo@02E_d01P00E_d00000E_d000EFo@<0009Fo@05001FoEKm001Fo@040003E_d0
0`00E_eFo@030004E_d01000E_eFoEKm0`000dEb00D004EbAG95LP0000E5LP050015LTEbAG800003
Ool00`00Oomoo`1=Ool005Uoo`8000=oo`80009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km
00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@@000=Fo@03001FoEKm00<0
00EFo@03001FoEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000EF
o@<0009Fo@03001FoEKm009Fo@<000AFo@03001FoEKm00<000AFo@03001FoEKm00<000EFo@06001F
o@00001Fo@001EKm00H005Km000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm0`000UKm
00<005KmE_d00eKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<005Km00000P00
00=Fo@00E_d00eKm00H005Km000005Km0005E_d30002E_d00`00E_eFo@02E_d40002AG801@00AG95
LTEb000014Eb00<004EbAG800TEb00D004EbAG95LP0000Aoo`03001oogoo04aoo`00EWoo0`0000=o
o`00Ool00P001EKm00<005KmE_d00`0015Km00<005KmE_d0100015Km00@005Km0000009Fo@06001F
oEKmE_d005Km0P000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d0
0`001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00E_d00eKm00@005Km0000009Fo@03
001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000AFo@04001FoEKm
E_d30004E_d00`00E_eFo@030005E_d01P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km
00=Fo@<0009Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm00<000EFo@03001FoEKm00@000=Fo@03
001Fo@0000800003E_d005Km00=Fo@06001Fo@000015LP0014Eb00D004EbAG95LP0000A5LP030015
LTEb0095LP050015LTEbAG800005Ool00`00Oomoo`1;Ool005=oo`<000Aoo`80009Fo@03001FoEKm
009Fo@<0009Fo@03001FoEKm009Fo@<000AFo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@04
001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<0
00=Fo@03001FoEKm00<000EFo@03001FoEKm00<000EFo@06001Fo@00001Fo@0015Km00@005Km0000
009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km10000UKm00<005KmE_d00UKm0`000eKm00@0
05KmE_eFo@<000AFo@03001FoEKm00<000EFo@06001Fo@00001Fo@0015Km00<005Km00000P0000=F
o@00E_d00eKm0`000UKm00<005KmE_d00eKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`00
0dEb00<004EbAG800TEb00<004EbAG800TEb00D004EbAG95LP0000A5LP030015LTEb0095LP03001o
ogoo009oo`03001oogoo04]oo`00DGoo0P0017oo100015Km00H005Km000005Km0004E_d01000E_d0
00000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<0
05KmE_d00`0015Km00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km0`000eKm
00<005KmE_d00UKm0`000UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00`001EKm00<005KmE_d0
0`0015Km00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km10000UKm00<005Km
E_d00UKm0`000eKm00@005KmE_eFo@<000AFo@03001FoEKm00<000EFo@06001Fo@00001Fo@0015Km
00<005Km00000P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00eKm0`000TEb00D004EbAG95LP00
00A5LP030015LTEb0095LP050015LTEbAG800004AG800`00AG95LP02AG800`00Oomoo`03Ool00`00
Oomoo`1:Ool004ioo`<000=oo`<000AFo@03001FoEKm00<000AFo@03001FoEKm00@000AFo@04001F
o@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000EFo@03001FoEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00
E_d00000E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@<000=Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000EFo@03001FoEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00
E_d00000E_d000AFo@@0009Fo@03001FoEKm009Fo@<000=Fo@04001FoEKmE_d30004E_d00`00E_eF
o@030005E_d00`00E_d000030004E_d00`00E_d0000200000dEb0015LP02AG801@00AG95LTEb0000
1DEb00D004EbAG95LP0000=5LP030015LTEb0095LP030015LTEb0095LP03001oogoo00Aoo`03001o
ogoo04Uoo`00C7oo0P0017oo0P000UKm00<005KmE_d00UKm0`000eKm00@005KmE_eFo@<000AFo@03
001FoEKm00<000EFo@03001FoEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d0
0000E_d000AFo@<000=Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm
00<000AFo@03001FoEKm00@000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d30003
E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d01000E_d00000
0UKm00<005KmE_d00UKm00H005Km000005Km0004E_d40002E_d00`00E_eFo@02E_d30002E_d00`00
E_eFo@03E_d20002E_d00`00E_d00002E_d30004AG801@00AG95LTEb000014Eb00<004EbAG800TEb
00D004EbAG95LP0000=5LP030015LTEb0095LP030015LTEb0095LP03001oogoo00Aoo`03001oogoo
04Uoo`00BGoo0`0017oo0`0015Km00@005Km0000009Fo@03001FoEKm009Fo@03001Fo@00009Fo@03
001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000EFo@03001FoEKm00<0
00AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@04001Fo@000002E_d0
0`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30004E_d00`00E_eFo@030004E_d01000E_eFoEKm
0`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm00=Fo@<0
00=Fo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@06001Fo@00001Fo@001EKm00H005Km0000
05Km0004E_d00`00E_d0000200001UKm001FoEKm001Fo@<00095LP030015LTEb0095LP050015LTEb
AG800004AG800`00AG95LP02AG801@00AG95LTEb000014Eb00<004EbAG800TEb00D004EbAG95LP00
00Moo`03001oogoo04Qoo`00Agoo0P0017oo0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`00
15Km00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d0
0UKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<005KmE_d0100015Km00H005Km
000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm10000eKm
00<005KmE_d00`0015Km00@005KmE_eFo@<000AFo@06001Fo@00001Fo@0015Km00<005Km00000P00
00=Fo@00E_d00eKm0`000UKm00<005KmE_d00eKm0`000eKm00<005KmE_d00`0015Km00@005KmE_eF
o@<000AFo@03001FoEKm00<000EFo@06001Fo@000015LP000dEb00<004EbAG800TEb00<004EbAG80
0TEb00D004EbAG95LP0000A5LP050015LTEbAG800004AG800`00AG95LP02AG801@00AG95LTEb0000
1goo0P00BGoo0014Ool30004Ool200000eKm001Fo@03E_d30003E_d00`00E_eFo@02E_d30003E_d0
0`00E_eFo@030005E_d00`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km
000005Km0004E_d30003E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30004E_d00`00E_eF
o@030004E_d00`00E_eFo@040004E_d01P00E_d00000E_d000AFo@04001Fo@000002E_d00`00E_eF
o@02E_d30002E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@030004E_d00`00E_eFo@040004E_d0
1P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@<0009Fo@03001FoEKm009Fo@@0
009Fo@03001FoEKm009Fo@<000=Fo@04001FoEKmE_d40002AG801@00AG95LTEb000014Eb00<004Eb
AG800TEb00D004EbAG95LP0000A5LP050015LTEbAG800004AG800`00AG95LP02AG800`00AG95LP02
AG800`00Oomoo`04Ool20019Ool0045oo`<000=oo`@000AFo@04001Fo@000002E_d00`00E_eFo@02
E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000EFo@03
001FoEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@04001F
o@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30004E_d00`00E_eFo@030004E_d0
0`00E_eFo@040004E_d01P00E_d00000E_d000AFo@04001Fo@000002E_d00`00E_eFo@02E_d30002
E_d00`00E_eFo@02E_d30004E_d00`00E_eFo@030004E_d00`00E_eFo@040004E_d01P00E_d00000
E_d000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@@00095LP800095
LP050015LTEbAG800005AG801@00AG95LTEb00000dEb00<004EbAG800TEb00<004EbAG800TEb00D0
04EbAG95LP0000A5LP030015LTEb0095LP03001oogoo00Ioo`03001oogoo04Ioo`00?goo0P0017oo
0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`0015Km00@005Km0000009Fo@03001FoEKm009F
o@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<0
05KmE_d00`0015Km00<005KmE_d0100015Km00H005Km000005Km0004E_d01000E_d000000UKm00<0
05KmE_d00UKm0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d00`0015Km00<005KmE_d01000
15Km00H005Km000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d0
0UKm0`0015Km00<005KmE_d00`0015Km00<005KmE_d00`001EKm00<005KmE_d00`0015Km00H005Km
000004Eb0004AG801@00AG8004Eb000014Eb00<004EbAG800TEb00D004EbAG95LP0000=5LP030015
LTEb0095LP030015LTEb0095LP050015LTEbAG800004AG800`00AG95LP02AG800`00Oomoo`06Ool0
0`00Oomoo`16Ool003aoo`<000Aoo`80009Fo@04001FoEKmE_d30003E_d00`00E_eFo@02E_d30003
E_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d00UKm00H0
05Km000005Km0004E_d30003E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30004E_d00`00
E_eFo@030004E_d00`00E_eFo@040004E_d01P00E_d00000E_d000AFo@04001Fo@000002E_d00`00
E_eFo@02E_d30002E_d00`00E_eFo@02E_d30004E_d00`00E_eFo@030004E_d00`00E_eFo@030005
E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm0`000UKm
00<005KmE_d00eKm0`000eKm00<005KmE_d00`000dEb00<004EbAG800TEb00<004Eb00000TEb00D0
04EbAG95LP0000A5LP050015LTEbAG800003AG800`00AG95LP03AG801@00AG95LTEb000014Eb00D0
04EbAG95LP0000A5LP03001oogoo00Moo`03001oogoo04Eoo`00>Woo0P0017oo100015Km00<005Km
00000UKm00<005KmE_d00UKm00@005Km0000009Fo@04001FoEKmE_d30003E_d00`00E_eFo@02E_d3
0003E_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d00UKm
00H005Km000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm
0`0015Km00<005KmE_d00`0015Km00<005KmE_d0100015Km00H005Km000005Km0004E_d01P00E_d0
0000E_d000EFo@<0009Fo@03001FoEKm009Fo@<000=Fo@04001FoEKmE_d30004E_d00`00E_eFo@03
0004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000AFo@03001Fo@0000800003
E_d005Km00=Fo@<00095LP050015LTEbAG800004AG800`00AG800002AG801@00AG95LTEb000014Eb
00D004EbAG95LP0000A5LP030015LTEb0095LP050015LTEbAG800004AG801@00AG95LTEb000014Eb
00<007ooOol027oo00<007ooOol0A7oo000gOol30003Ool30004E_d00`00E_eFo@030004E_d00`00
E_eFo@040004E_d00`00E_d00002E_d00`00E_eFo@02E_d01000E_d000000UKm00@005KmE_eFo@<0
00=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@03001FoEKm
00@000AFo@06001Fo@00001Fo@0015Km00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001F
oEKm009Fo@<000AFo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d0
05Km00=Fo@06001Fo@00001Fo@0015Km10000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`00
1EKm00<005KmE_d00`0015Km00<005KmE_d00`001EKm00H005Km000004Eb0003AG801@00AG95LTEb
000014Eb00<004Eb00000TEb00D004EbAG95LP0000A5LP050015LTEbAG800004AG800`00AG95LP02
AG801@00AG95LTEb000014Eb00D004EbAG95LP0000A5LP03001oogoo00Qoo`03001oogoo04Aoo`00
=Goo0P0017oo0P000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d0
0`0015Km00<005KmE_d0100015Km00<005Km00000UKm00<005KmE_d00UKm00@005Km0000009Fo@04
001FoEKmE_d30003E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040004E_d00`00E_eFo@030004
E_d00`00E_eFo@040004E_d01P00E_d00000E_d000AFo@04001Fo@000002E_d00`00E_eFo@02E_d3
0002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d01000E_d0
00000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d30002E_d00`00E_eFo@03E_d30003E_d0
0`00E_eFo@040003E_d01000E_eFoEKm0`000dEb00D004EbAG95LP0000A5LP030015LTEb0095LP80
0095LP050015LTEbAG800004AG800`00AG95LP02AG801@00AG95LTEb000014Eb00D004EbAG95LP00
00A5LP030015LTEb0095LP030015LTEb0095LP03001oogoo00Qoo`03001oogoo04=oo`00<Woo0`00
17oo0`0015Km00@005Km0000009Fo@06001FoEKmE_d005Km0P000UKm00<005KmE_d00UKm0`000UKm
00<005KmE_d00UKm0`0015Km00<005KmE_d00`0015Km00<005KmE_d0100015Km00<005Km00000UKm
00<005KmE_d00UKm00H005Km000005Km0004E_d30003E_d00`00E_eFo@02E_d30002E_d00`00E_eF
o@02E_d30004E_d00`00E_eFo@030004E_d00`00E_eFo@030005E_d01P00E_d00000E_d000AFo@06
001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<005Km
E_d00`0015Km00H005Km000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d30002E_d00`00
E_eFo@02E_d40002AG801@00AG95LTEb00000dEb00<004EbAG800TEb00<004EbAG800TEb0P000TEb
00D004EbAG95LP0000A5LP030015LTEb0095LP050015LTEbAG800004AG801@00AG95LTEb000014Eb
00<004EbAG800TEb00<004EbAG800TEb00<007ooOol02Goo00<007ooOol0@Woo000`Ool2000017oo
001oogoo0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`0015Km00H005Km000005Km0004E_d0
1000E_d000000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d00`00
15Km00<005KmE_d010000eKm00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km
00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@04001FoEKmE_d3
0004E_d00`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0004
E_d30002E_d00`00E_eFo@03E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@040004E_d01P00
E_d00000E_d000AFo@06001Fo@000015LP0014Eb00D004EbAG95LP0000=5LP030015LTEb0095LP03
0015LTEb0095LP800095LP050015LTEbAG800004AG800`00AG95LP02AG801@00AG95LTEb000014Eb
00D004EbAG95LP0000A5LP030015LTEb0095LP030015LTEb0095LP03001oogoo00Uoo`03001oogoo
049oo`00;Goo0`0017oo0P0000=Fo@00E_d00eKm0`000eKm00<005KmE_d00UKm0`000eKm00<005Km
E_d00`0015Km00<005KmE_d0100015Km00H005Km000005Km0004E_d01000E_d000000UKm00<005Km
E_d00UKm0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d00P001EKm00<005KmE_d00`0015Km
00<005KmE_d0100015Km00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@@0009Fo@03001F
oEKm009Fo@<000=Fo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km
00<005Km00000P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d00`00
15Km00<005KmE_d00`000dEb00<004EbAG800TEb00D004EbAG95LP0000A5LP050015LTEbAG800004
AG820002AG800`00AG95LP02AG801@00AG95LTEb000014Eb00D004EbAG95LP0000A5LP030015LTEb
0095LP030015LTEb0095LP050015LTEbAG800004AG800`00Oomoo`0:Ool00`00Oomoo`11Ool002Yo
o`<000Aoo`@000=Fo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<000=F
o@04001FoEKmE_d30004E_d00`00E_eFo@030004E_d00`00E_eFo@040004E_d01P00E_d00000E_d0
00AFo@04001Fo@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eF
o@040004E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d0
0UKm00H005Km000005Km0004E_d30003E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030004E_d0
0`00E_eFo@040004E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@001EKm0`000UKm00<005Km
E_d00UKm0`000TEb00D004EbAG95LP0000A5LP030015LTEb0095LP050015LTEbAG800003AG800`00
AG8000040003AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP0000E5LP050015
LTEbAG800004AG801@00AG95LTEb000014Eb00<007ooOol02goo00<007ooOol0@7oo000XOol20003
Ool40004E_d00`00E_eFo@030004E_d00`00E_eFo@040003E_d01000E_d000000UKm00<005KmE_d0
0UKm00<005Km00000UKm00<005KmE_d00UKm0`000eKm00@005KmE_eFo@<000AFo@03001FoEKm00<0
00AFo@03001FoEKm00@000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d30003E_d0
0`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@040004E_d00`00E_eFo@030004
E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d30002E_d00`00E_eFo@02
E_d30004E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03
E_d01P00E_d00000AG8000=5LP050015LTEbAG800004AG800`00AG95LP02AG801@00AG95LTEb0000
0TEb0`000dEb00<004Eb00000TEb00D004EbAG95LP0000A5LP050015LTEbAG800003AG800`00AG95
LP03AG801@00AG95LTEb000014Eb00D004EbAG95LP0000A5LP03001oogoo00]oo`03001oogoo041o
o`009Goo0`000Woo0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d0100015Km00<005KmE_d0
0`0015Km00<005KmE_d00`0015Km00@005Km0000009Fo@03001FoEKm009Fo@03001Fo@00009Fo@03
001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000AFo@03001FoEKm00<000AFo@03001FoEKm00<0
00AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm
009Fo@<000AFo@03001FoEKm00@000=Fo@03001FoEKm00@000AFo@03001FoEKm00<000AFo@06001F
o@00001Fo@0015Km00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000EFo@03001FoEKm00<000=5LP050015LTEbAG800004AG800`00AG95LP02AG80
1@00AG95LTEb00000dEb0`0000=5LP00AG800dEb00H004EbAG8004Eb0003AG800`00AG95LP02AG80
1@00AG95LTEb000014Eb00<004EbAG800TEb00D004EbAG95LP0000A5LP050015LTEbAG800005AG80
0`00Oomoo`0;Ool00`00Oomoo`0oOol002Aoo`8000=oo`04001FoEKm0004E_d01P00E_d00000E_d0
00AFo@<000=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00@000AFo@03
001FoEKm00<000AFo@04001Fo@000002E_d01P00E_eFoEKm001Fo@80009Fo@03001FoEKm009Fo@<0
009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@04001Fo@00
0002E_d01P00E_eFoEKm001Fo@80009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000AF
o@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00@000AFo@06001Fo@00001Fo@00
15Km00H005Km000005Km0004E_d30003E_d00`00E_eFo@02E_d30002AG801@00AG95LTEb00000dEb
00<004EbAG800TEb00<004EbAG800TEb00@004EbAG95LPD000A5LP050015LTEbAG800003AG820003
AG800`00AG95LP02AG800`00AG95LP02AG801@00AG95LTEb000014Eb00D004EbAG95LP0000A5LP03
0015LTEb0095LP030015LTEb0095LP03001oogoo00]oo`80041oo`0097oo1@0015Km00<005KmE_d0
10000eKm00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km0`000eKm00@005Km
E_eFo@<000AFo@03001FoEKm00@000=Fo@03001FoEKm00@000AFo@03001FoEKm00<000AFo@06001F
o@00001Fo@0015Km00@005Km0000009Fo@04001FoEKmE_d30003E_d00`00E_eFo@02E_d30003E_d0
0`00E_eFo@030005E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@04001Fo@000002E_d0
0`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040004E_d00`00E_eFo@03
0004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000EFo@06001Fo@000015LP000dEb00D004Eb
AG95LP0000=5LP030015LTEb0095LP030015LTEb0095LP030015LP00008000=5LP030015LTEb0095
LP050015LTEbAG800003AG820003AG800`00AG95LP02AG800`00AG95LP02AG801@00AG95LTEb0000
14Eb00D004EbAG95LP0000A5LP030015LTEb0095LP040015LTEbAG82000>Ool00`00Oomoo`0nOol0
02Aoo`80009Fo@03001FoEKm009Fo@<000AFo@03001FoEKm008000EFo@03001FoEKm00@000=Fo@04
001Fo@000002E_d00`00E_eFo@02E_d00`00E_d00002E_d00`00E_eFo@02E_d30002E_d00`00E_eF
o@02E_d30004E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@040004E_d00`00
E_d00002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000AFo@03001FoEKm00@000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km
0004E_d30002E_d00`00E_eFo@03E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d0
1000E_eFoEKm0`000dEb00D004EbAG95LP0000=5LP030015LTEb0095LP050015LTEbAG800003AG83
0002AG801@00AG95LTEb000014Eb00<004EbAG800TEb00D004EbAG95LP0000=5LP030015LTEb0095
LP030015LTEb0095LP050015LTEbAG800004AG801@00AG95LTEb00001DEb00@004EbAG95LP@00003
BI8007oo00ioo`03001oogoo03eoo`0097oo0P000eKm00@005Km0000009Fo@03001FoEKm009Fo@<0
009Fo@03001FoEKm009Fo@<000AFo@03001FoEKm008000EFo@03001FoEKm00<000AFo@04001Fo@00
0002E_d01P00E_eFoEKm001Fo@80009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00@000AFo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@04001Fo@000002E_d0
0`00E_eFo@02E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm009Fo@<000AFo@03001FoEKm
00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00<005Km00000P0000=Fo@00E_d0
0eKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d01@000TEb00D004EbAG95LP0000=5LP03
0015LTEb0095LP050015LTEbAG800003AG8400000dEb0015LP02AG801@00AG95LTEb000014Eb00<0
04EbAG800TEb00@004EbAG95LP8000=5LP050015LTEbAG800004AG801@00AG95LTEb000014Eb00<0
04EbAG800TEb00<004EbAG800TEb00<004Eb00000P0014VB00<007ooOol03Woo00<007ooOol0?7oo
000SOol01000Oomoo`000UKm0`0015Km00@005Km0000009Fo@06001FoEKmE_d005Km0P000UKm00<0
05KmE_d00UKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`00
15Km00H005Km000005Km0004E_d01000E_d000000UKm00@005KmE_eFo@<000=Fo@03001FoEKm009F
o@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00@000AFo@03001FoEKm00<000AFo@06001Fo@00
001Fo@0015Km00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03
001FoEKm00<000AFo@03001FoEKm00@000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004
E_d30002AG800`00AG95LP02AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP00
0095LP8000A5LP050015LTEbAG800003AG800`00AG95LP02AG800`00AG95LP02AG801000AG95LTEb
0P000dEb00D004EbAG95LP0000A5LP050015LTEbAG800005AG801@00AG95LTEb00000dEb0`000TVB
00<004VBBI800TVB00<007ooOol03Woo00<007ooOol0?7oo000HOol015[F248003W>1goo00@007oo
Oomoo`8000=Fo@03001FoEKm00@000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00@0
05Km0000009Fo@04001FoEKmE_d30003E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030004E_d0
0`00E_eFo@040004E_d00`00E_d00002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<0009F
o@03001FoEKm009Fo@<000AFo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00@0
00AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30004
E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01P00E_d00000AG8000=5LP030015LTEb0095
LP050015LTEbAG800004AG801@00AG95LTEb00000dEb0`0000=5LP00AG800dEb00D004EbAG95LP00
00A5LP050015LTEbAG800004AG800`00AG95LP02AG820002AG801@00AG95LTEb000014Eb00D004Eb
AG95LP0000E5LP040015LTEbAG8400000dVB0019TP02BI800`00BI99TP03BI800`00Oomoo`0>Ool0
0`00Oomoo`0kOol001Moo`06HaPHaW>LLi`@Q5:D1Woo00<007ooOol00Woo00@005KmE_eFo@<000AF
o@03001FoEKm00@000=Fo@03001FoEKm00@000=Fo@03001FoEKm00@000AFo@03001Fo@00009Fo@03
001FoEKm009Fo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d0
0`0015Km00<005KmE_d00`0015Km00@005Km0000009Fo@06001FoEKmE_d005Km0P000UKm00<005Km
E_d00UKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d0100015Km00<005KmE_d00`0015Km
00<005KmE_d00`0015Km00H005Km000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm0`00
0UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`000dEb00D004EbAG95LP0000A5LP030015LTEb
0095LP050015LTEbAG800003AG850004AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004Eb
AG95LP0000A5LP030015LTEb0095LP050015LP00AG800003AG800`00AG95LP02AG800`00AG95LP02
AG800`00AG95LP02AG800`00AG8000020004BI801@00BI99TTVB00001DVB00<007ooOol03Woo00<0
07ooOol037oo0P0000<8@WooOol00Woo00AJePQ2000icRAoo`005goo00HQ25:DOomooe:D6<H6Ool3
0003Ool00`00E_d00002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30004E_d00`00E_eF
o@030004E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01000E_d000000UKm00H005KmE_eF
o@00E_d20002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030005
E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000eKm00<0
05KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km00<005KmE_d0100015Km
00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@<00095LP050015LTEbAG800003AG800`00
AG95LP02AG800`00AG95LP02AG801P00AG95LTEb0015LP<000=5LP030015LTEb0095LP050015LTEb
AG800004AG801@00AG95LTEb00000dEb00<004EbAG800TEb00<004EbAG800TEb00<004EbAG800P00
0dEb00<004EbAG800dEb00D004EbAG95LP0000=5LP<00099TP030019TTVB0099TP030019TTVB0099
TP030019TTVB0099TP03001oogoo00moo`03001oogoo00aoo`03001oogoo009oo`06HaPHaW>LLi`@
Q5:D8goo000GOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00E_eFo@02E_d0
1000E_d000000UKm00H005KmE_eFo@00E_d20002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02
E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@040004E_d00`00E_eFo@030004E_d01P00E_d0
0000E_d000AFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d0
0`0015Km00<005KmE_d00`0015Km00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@00
15Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d0100015Km00<005KmE_d00`0015Km00<0
05KmE_d00`0015Km00H005Km000004Eb0003AG801@00AG95LTEb00000dEb00<004EbAG800TEb00<0
04EbAG800TEb00<004EbAG800`000TEb00D004EbAG95LP0000A5LP030015LTEb0095LP050015LTEb
AG800003AG800`00AG95LP02AG801@00AG95LTEb000014Eb00<004EbAG800P0014Eb00<004EbAG80
0TEb00@004EbAG95LP@00003BI8004VB0099TP030019TTVB00=9TP050019TTVBBI800004BI800`00
Oomoo`0@Ool00`00Oomoo`07Ool60003Ool01R48DYAoogooDY@HaR=oo`005goo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol01Goo00<005KmE_d00`001EKm00<005KmE_d00`0015Km00H005Km
000005Km0004E_d01P00E_d00000E_d000AFo@<000=Fo@04001FoEKmE_d30004E_d00`00E_eFo@04
0003E_d00`00E_eFo@030004E_d00`00E_eFo@040003E_d01000E_d000000UKm00<005KmE_d00UKm
00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030005E_d00`00
E_eFo@030004E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d0
0UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`000dEb00D004EbAG95LP0000=5LP030015
LTEb0095LP050015LTEbAG800004AG8300000dEb0015LP02AG801@00AG95LTEb000014Eb00<004Eb
AG800TEb00D004EbAG95LP0000=5LP030015LTEb0095LP050015LTEbAG800004AG801@00AG95LTEb
000014Eb00<004EbAG800TEb00<004Eb00000P0014VB00D004VBBI99TP0000E9TP050019TTVBBI80
0004BI800`00Oomoo`0@Ool00`00Oomoo`07Ool01CW>DYAoogoo000017oo00<007ooOol00Woo00<0
07ooOol08Goo000GOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool20003E_d00`00
E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@040003E_d01000E_d000000UKm00<0
05KmE_d00UKm00<005Km00000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm0`000eKm00<0
05KmE_d0100015Km00<005KmE_d00`0015Km00<005KmE_d00`0015Km00H005Km000005Km0004E_d0
1000E_d000000UKm00@005KmE_eFo@<000=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AF
o@03001FoEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<0
009Fo@03001FoEKm009Fo@<00095LP050015LTEbAG800003AG800`00AG95LP02AG801@00AG95LTEb
000014Eb1@000dEb00D004EbAG95LP0000=5LP030015LTEb0095LP030015LTEb0095LP050015LTEb
AG800003AG800`00AG95LP02AG801@00AG95LTEb000014Eb00<004EbAG800TEb00D004EbAG95LP00
00=5LP<00099TP030019TTVB0099TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI800004
BI800`00Oomoo`0AOol00`00Oomoo`06Ool01G>L6<IcW7oo000017oo00<007ooOol00Woo00<007oo
Ool08Goo000GOol01R48DYAoogooDY@Q20Eoo`03001oogoo00Qoo`03001FoEKm009Fo@06001Fo@00
001Fo@0015Km0`0015Km00<005KmE_d00`0015Km00<005KmE_d00`0015Km00<005KmE_d00`0015Km
00H005Km000005Km0004E_d01000E_d000000UKm00@005KmE_eFo@<000=Fo@03001FoEKm009Fo@<0
00=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00@000AFo@03001Fo@00009F
o@03001FoEKm009Fo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d010000eKm00<005KmE_d0
100015Km00<005KmE_d00`0015Km00H005Km000005Km0004E_d01P00E_d00000AG8000=5LP050015
LTEbAG800003AG800`00AG95LP02AG801@00AG95LTEb00000TEb0`000dEb00D004EbAG95LP0000=5
LP030015LTEb0095LP050015LTEbAG800004AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D0
04EbAG95LP0000A5LP030015LTEb0095LP800095LP@00003BI8004VB0099TP030019TTVB0099TP03
0019TTVB0099TP030019TTVB0099TP050019TTVBBI800004BI800`00Oomoo`0BOol00`00Oomoo`06
Ool015:D<Haoo`0017oo00<007ooOol00Woo00<007ooOol08Goo000GOol01V<H6<IcW7>L6<IS60Eo
o`<000Uoo`03001FoEKm00@000=Fo@04001Fo@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eF
o@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@040003E_d00`00E_eFo@040004E_d00`00
E_d00002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00@000AFo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@00
15Km0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d010000eKm00<005KmE_d00`0015Km00<0
05KmE_d00`000dEb00D004EbAG95LP0000=5LP030015LTEb0095LP050015LTEbAG800003AG830002
AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP0000=5LP030015LTEb0095LP05
0015LTEbAG800003AG800`00AG95LP02AG800`00AG95LP02AG800`00AG95LP02AG801000AG95LTEb
1@0014VB00D004VBBI99TP0000E9TP050019TTVBBI800004BI801@00BI99TTVB00001DVB00<007oo
Ool04Goo00<007ooOol01goo00<Q26<H000017oo00HQ25:DOomooe:D8@PSOol001Qoo`04F]H8@PQ2
HaP6Ool00`00Oomoo`0:Ool20004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06001F
o@00001Fo@0015Km0`000eKm00@005KmE_eFo@<000AFo@03001FoEKm00<000AFo@03001FoEKm00<0
00AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00@005Km0000009Fo@04001FoEKmE_d3
0003E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d01000E_d0
00000UKm00H005KmE_eFo@00E_d20002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30003
E_d00`00E_eFo@040002AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP0000=5
LP030015LP00008000A5LP050015LTEbAG800003AG800`00AG95LP02AG801@00AG95LTEb000014Eb
00D004EbAG95LP0000=5LP050015LTEbAG800004AG800`00AG95LP02AG800`00AG95LP02AG800`00
AG95LP0400000dVB0019TP03BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB000014VB
00D004VBBI99TP0000E9TP03001oogoo019oo`8000Moo`03JeXQ200000Aoo`06HaPHaW>LLi`HaV<H
8goo000ROol00`00Oomoo`0;Ool00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eF
o@040003E_d01000E_d000000UKm00<005KmE_d00UKm00<005Km00000UKm00<005KmE_d00UKm0`00
0UKm00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d010000eKm00<005KmE_d0
100015Km00<005Km00000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d30002E_d00`00E_eF
o@02E_d30003E_d00`00E_eFo@040004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06
001Fo@00001Fo@0015Km0`000TEb00D004EbAG95LP0000=5LP050015LTEbAG800004AG801@00AG95
LTEb00000TEb0`000TEb00<004EbAG800TEb00D004EbAG95LP0000A5LP050015LTEbAG800003AG80
0`00AG95LP02AG801@00AG95LTEb00000dEb00D004EbAG95LP0000A5LP030015LTEb0095LP030015
LTEb0095LP<00004BI8004VBBI820004BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB
000014VB00<004VBBI800TVB00<004VBBI800TVB00<007ooOol047oo0P0000=oo`00Ool01goo00<i
cPQ2Ool017oo00AJePQ2249S62Aoo`008Woo00<007ooOol037oo00H005Km000005Km0004E_d30004
E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01P00E_d00000E_d0
00AFo@06001Fo@00001Fo@0015Km0`000eKm00@005KmE_eFo@<000AFo@03001FoEKm00<000AFo@03
001FoEKm00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004
E_d30004E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01P00E_d0
0000AG8000=5LP050015LTEbAG800003AG800`00AG95LP02AG801@00AG95LTEb00000dEb0`0000=5
LP00AG800TEb00<004EbAG800TEb00<004EbAG800TEb00D004EbAG95LP0000=5LP050015LTEbAG80
0004AG801@00AG95LTEb00000dEb00<004EbAG800TEb00<004EbAG800TEb00D004EbAG95LP000095
LP<000=9TP030019TTVB008000E9TP050019TTVBBI800004BI801@00BI99TTVB00001DVB00D004VB
BI99TP0000A9TP03001oogoo01=oo`03001oogoo03Eoo`008Woo00<007ooOol03Goo0P000eKm00@0
05Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=F
o@03001FoEKm00@000=Fo@03001FoEKm00@000=Fo@04001Fo@000002E_d00`00E_eFo@02E_d00`00
E_d00002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d0
0`00E_eFo@030004E_d00`00E_eFo@040003E_d01000E_d000000UKm00<005KmE_d00UKm0`000UKm
00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`000dEb00D004EbAG95LP00
00=5LP050015LTEbAG800004AG801000AG95LTEb1@000dEb00D004EbAG95LP0000A5LP030015LTEb
0095LP050015LTEbAG800003AG801@00AG95LTEb000014Eb00D004EbAG95LP0000=5LP030015LTEb
0095LP030015LTEb0095LP030015LTEb00@00099TP050019TTVBBI800003BI820004BI801@00BI99
TTVB000014VB00D004VBBI99TP0000E9TP050019TTVBBI800004BI800`00Oomoo`0DOol00`00Oomo
o`0dOol0025oo`03001oogoo011oo`03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00H005Km
000005Km0004E_d30002E_d00`00E_eFo@02E_d30004E_d00`00E_eFo@030004E_d00`00E_eFo@03
0004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000UKm
00<005KmE_d00UKm0`000eKm00<005KmE_d0100015Km00<005KmE_d00`0015Km00H005Km000005Km
0004E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm009Fo@<00095LP050015LTEbAG800003
AG801@00AG95LTEb00000dEb00<004EbAG800TEb00<004Eb00000P000dEb00D004EbAG95LP0000=5
LP030015LTEb0095LP030015LTEb0095LP050015LTEbAG800003AG801@00AG95LTEb000014Eb00D0
04EbAG95LP0000A5LP050015LTEbAG800004AG8300000dVB0019TP03BI801@00BI99TTVB000014VB
00<004VBBI800TVB00D004VBBI99TP0000A9TP030019TTVB0099TP030019TTVB0099TP050019TTVB
BI800004BI800`00Oomoo`0EOol00`00Oomoo`0cOol0025oo`<0015oo`8000=Fo@03001FoEKm00@0
00=Fo@03001FoEKm00@000=Fo@04001Fo@000002E_d01P00E_eFoEKm001Fo@80009Fo@03001FoEKm
009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03
001FoEKm00<000AFo@04001Fo@000002E_d01P00E_eFoEKm001Fo@80009Fo@04001FoEKmE_d30004
E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01P00E_d00000E_d0
00AFo@06001Fo@000015LP000dEb00D004EbAG95LP0000=5LP050015LTEbAG800004AG800`00AG95
LP030002AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP0000A5LP050015LTEb
AG800003AG801@00AG95LTEb000014Eb00<004EbAG800TEb00D004EbAG95LP0000=5LP030015LTEb
00<000=9TP030019TTVB0099TP030019TTVB0099TP040019TTVBBI820003BI801@00BI99TTVB0000
14VB00<004VBBI800TVB00<004VBBI800TVB00D004VBBI99TP0000E9TP03001oogoo019oo`<003Eo
o`008Goo00<007ooOol04Woo00@005KmE_eFo@<000AFo@03001FoEKm00<000AFo@03001FoEKm00<0
00AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d30002E_d0
0`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@040004E_d00`00E_eFo@030004
E_d00`00E_d00002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@04
0003E_d00`00E_eFo@030004E_d00`00E_eFo@030003AG801@00AG95LTEb00000dEb00D004EbAG95
LP0000=5LP030015LTEb0095LP<00003AG8004Eb0095LP050015LTEbAG800003AG800`00AG95LP02
AG801@00AG95LTEb000014Eb00D004EbAG95LP0000=5LP050015LTEbAG800004AG800`00AG95LP02
AG801@00AG95LTEb00000TEb10000TVB00D004VBBI99TP0000A9TP030019TTVB0099TP040019TTVB
BI820003BI801@00BI99TTVB000014VB00<004VBBI800TVB00<004VBBI800TVB00D004VBBI99TP00
00E9TP03001oogoo00ioo`@000913`8003Aoo`008Goo00<007ooOol04goo00<005Km00000UKm00<0
05KmE_d00UKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`00
15Km00<005KmE_d00`0015Km00H005Km000005Km0004E_d01000E_d000000UKm00@005KmE_eFo@<0
00AFo@03001FoEKm00<000AFo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@06001Fo@00001F
o@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040002
AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP030015LTEb0095LPD000=5LP050015LTEb
AG800003AG800`00AG95LP02AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP00
00=5LP050015LTEbAG800005AG801@00AG95LTEb00000dEb0`0000=9TP00BI800dVB00<004VBBI80
0TVB00<004VBBI800TVB00D004VBBI99TP0000=9TP030019TP000099TP030019TTVB0099TP050019
TTVBBI800004BI800`00BI99TP02BI800`00BI99TP02BI800`00BI99TP02BI800`00Oomoo`0<Ool2
00000d4?00113`03@@l3000cOol0025oo`03001oogoo01Aoo`03001FoEKm009Fo@06001Fo@00001F
o@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003
E_d00`00E_eFo@040003E_d00`00E_eFo@040004E_d00`00E_d00002E_d00`00E_eFo@02E_d30002
E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@03
0004E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000TEb00D004EbAG95LP0000=5
LP050015LTEbAG800003AG800`00AG95LP02AG800`00AG95LP020003AG801@00AG95LTEb00000dEb
00<004EbAG800TEb00D004EbAG95LP0000=5LP050015LTEbAG800004AG801@00AG95LTEb00000dEb
00<004EbAG800TEb00<004EbAG800TEb00H004EbAG95LP00AG830003BI800`00BI99TP02BI800`00
BI99TP02BI800`00BI99TP02BI801@00BI99TTVB00000dVB00H004VBBI8004VB0004BI800`00BI99
TP02BI801@00BI99TTVB00001DVB00D004VBBI99TP0000A9TP03001oogoo00Uoo`<000=13`030011
3d4?00913`<003=oo`008Goo00<007ooOol05Goo00<005KmE_d010000eKm00<005KmE_d010000eKm
00@005Km0000009Fo@06001FoEKmE_d005Km0P000UKm00@005KmE_eFo@<000=Fo@04001FoEKmE_d3
0004E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06001Fo@00
001Fo@0015Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`00
15Km00<005KmE_d00`0015Km00H005Km000004Eb0003AG801@00AG95LTEb00000dEb00D004EbAG95
LP0000A5LP040015LTEbAG8300000dEb0015LP02AG801@00AG95LTEb000014Eb00D004EbAG95LP00
00=5LP050015LTEbAG800003AG800`00AG95LP02AG801@00AG95LTEb000014Eb00D004EbAG95LP00
00A5LP030015LP0000<00099TP050019TTVBBI800004BI800`00BI99TP02BI800`00BI99TP02BI80
1@00BI99TTVB00000dVB00@004VBBI99TP8000A9TP030019TTVB0099TP050019TTVBBI800005BI80
1@00BI99TTVB000014VB00<007ooOol01Goo10000T4?00D0044?@@m13`0000A13`04001Fo@00000b
Ool0021oo`<001Moo`8000AFo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@03001FoEKm00<0
00AFo@03001Fo@00009Fo@03001FoEKm009Fo@03001Fo@00009Fo@03001FoEKm009Fo@<000=Fo@03
001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km
00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00
E_eFo@030003AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP030015LTEb0095LPD000=5
LP050015LTEbAG800003AG800`00AG95LP02AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5
LP030015LTEb0095LP050015LTEbAG800004AG801@00AG95LTEb00000dEb0`000TVB00D004VBBI99
TP0000A9TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB00<004VBBI80
0P0014VB00<004VBBI800TVB00<004VBBI800TVB00<004VBBI800TVB00D004VBBI99TP0000A9TP03
001oogoo009oo`<000913`0500113d4?@@l00003@@l00`00@@m13`02@@l5000aOol0021oo`03001o
ogoo01Qoo`03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03
001FoEKm00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d0
0UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d010000eKm00<005KmE_d010000eKm00@005Km
0000009Fo@06001FoEKmE_d005Km0P000UKm00@005KmE_eFo@<000=Fo@04001FoEKmE_d30002AG80
1@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP030015LTEb0095LP030015LP00008000=5LP05
0015LTEbAG800003AG800`00AG95LP02AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP05
0015LTEbAG800004AG800`00AG95LP02AG801@00AG95LTEb00000dEb100000=9TP00BI800TVB00D0
04VBBI99TP0000A9TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB00@0
04VBBI99TP8000=9TP030019TTVB0099TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI80
0004BI800`00Oomoo`0200000d4?00113`02@@l01@00@@m13d4?00000d4?00<0044?@@l00T4?00D0
05KmE_eFo@00035oo`0087oo00<007ooOol06Goo00H005Km000005Km0004E_d01P00E_d00000E_d0
00AFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00@000=Fo@03001FoEKm00@000=Fo@04001F
o@000002E_d01P00E_eFoEKm001Fo@80009Fo@04001FoEKmE_d30003E_d01000E_eFoEKm0`0015Km
00<005KmE_d00`0015Km00<005KmE_d00`0015Km00<005KmE_d00`0015Km00<005Km00000UKm00<0
05KmE_d00UKm00D005Km0015LP0000=5LP050015LTEbAG800003AG801@00AG95LTEb000014Eb00<0
04EbAG800`000TEb00D004EbAG95LP0000=5LP050015LTEbAG800004AG801@00AG95LTEb00000dEb
00D004EbAG95LP0000=5LP030015LTEb0095LP030015LTEb0095LP050015LTEbAG800003AG800`00
AG8000020004BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<004VBBI800TVB00D004VBBI99
TP0000A9TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB000014VB00<004VBBI80
0TVB00<004VBBI800TVB00D004VBBI99TP0000E9TP8000=13`0500113d4?@@l00003@@l01@00@@m1
3d4?0000144?00@005KmE_eFo@80031oo`0087oo00<007ooOol06Woo0P000eKm00<005KmE_d01000
0eKm00@005Km0000009Fo@04001FoEKmE_d30003E_d01000E_eFoEKm0`0015Km00<005KmE_d00`00
15Km00<005KmE_d00`0015Km00<005KmE_d00`0015Km00<005Km00000UKm00<005KmE_d00UKm00<0
05Km00000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d010000eKm00<0
05KmE_d00`0015Km00<005KmE_d00`000TEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG80
0`00AG95LP02AG8300000dEb0015LP02AG801@00AG95LTEb00000dEb00D004EbAG95LP0000A5LP05
0015LTEbAG800003AG801@00AG95LTEb00000dEb00<004EbAG800TEb00<004EbAG800TEb00D004Eb
AG95LP000095LP<00099TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB
00D004VBBI99TP0000A9TP050019TTVBBI800004BI800`00BI99TP02BI800`00BI99TP02BI801@00
BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP0000E9TP8000=13`0500113d4?@@l00003
@@l00`00@@m13`02@@l01000@@m13d4?100000=Fo@000000;goo000POol00`00Oomoo`0LOol00`00
E_eFo@030004E_d00`00E_eFo@030004E_d00`00E_d00002E_d00`00E_eFo@02E_d00`00E_d00002
E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eF
o@030004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm009Fo@<0
00=Fo@03001FoEKm00@000=Fo@03001FoEKm00@00095LP040015LTEb0003AG801@00AG95LTEb0000
0dEb00<004EbAG800TEb1@000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG800`00AG95
LP02AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP030015LTEb0095LP030015LTEb0095
LP040015LTEbAG8300000dVB0019TP02BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB
00000dVB00<004VBBI800TVB00<004VBBI800TVB00D004VBBI99TP0000A9TP050019TTVBBI800004
BI820003BI801@00BI99TTVB000014VB00<004VBBI800TVB00<004VBBI800TVB00@004VBBI99TP<0
00=13`0500113d4?@@l00003@@l00`00@@m13`02@@l01@00@@m13d4?00001EKm00<007ooOol0;Goo
000POol3000MOol20003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@030004
E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d010000eKm00<0
05KmE_d010000eKm00<005KmE_d00`0015Km00H005Km000005Km0004E_d01P00E_d00000E_d000AF
o@<0009Fo@03001FoEKm009Fo@<00095LP050015LTEbAG800002AG801@00AG95LTEb00000dEb00<0
04EbAG800TEb00<004Eb00000P000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG801@00
AG95LTEb000014Eb00D004EbAG95LP0000=5LP050015LTEbAG800004AG801@00AG95LTEb000014Eb
00<004Eb00000P000dVB00D004VBBI99TP0000E9TP050019TTVBBI800003BI801@00BI99TTVB0000
14VB00<004VBBI800TVB00<004VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP030019
TP000099TP050019TTVBBI800004BI800`00BI99TP03BI801000BI99TTVB100000=9/`0000000d4?
00D0044?@@m13`0000=13`0300113d4?00913`0400113d4?@@l20002E_d4000^Ool001moo`8001mo
o`03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm
00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm0`00
0eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km00<005KmE_d00`0015Km00H005Km000005Km
0004E_d01P00E_d00000AG8000=5LP050015LTEbAG800002AG801@00AG95LTEb000014Eb00@004Eb
AG95LP800095LP050015LTEbAG800003AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP03
0015LTEb0095LP050015LTEbAG800003AG801@00AG95LTEb000014Eb00D004EbAG95LP0000=5LP<0
0099TP050019TTVBBI800003BI800`00BI99TP03BI801@00BI99TTVB00000dVB00D004VBBI99TP00
00A9TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB00000TVB
00<004VB00000dVB00<004VBBI800TVB00<004VBBI800dVB00<004VB00000P0014Vc0P000d4?00D0
044?@@m13`0000=13`0300113d4?00913`0400113d4?@@l40003E_d00`00Oomoo`0/Ool001moo`03
001oogoo01moo`04001Fo@000002E_d01P00E_eFoEKm001Fo@80009Fo@04001FoEKmE_d30003E_d0
0`00E_eFo@040003E_d00`00E_eFo@040003E_d00`00E_eFo@040003E_d01P00E_d00000E_d000AF
o@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<0
05KmE_d00`0015Km00<005KmE_d00`000dEb00D004EbAG95LP0000=5LP040015LTEb0003AG800`00
AG95LP02AG850003AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003
AG800`00AG95LP02AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP0000=5LP@0
0003BI8004VB0099TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<0
04VBBI800TVB00D004VBBI99TP0000A9TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99
TTVB00000TVB00<004VB000014VB00<004VBBI800TVB00@004VBBI99TP<00099/`030019/dVc0099
/`8000=13`0500113d4?@@l00003@@l00`00@@m13`02@@l00`00@@m13`02@@l20004E_d2000]Ool0
01moo`03001oogoo021oo`8000AFo@03001FoEKm00<000AFo@03001Fo@00009Fo@04001FoEKmE_d3
0003E_d01000E_eFoEKm0`0015Km00<005KmE_d00`0015Km00<005KmE_d00`000eKm00<005KmE_d0
10000eKm00@005Km0000009Fo@06001FoEKmE_d005Km0P0000=Fo@00E_d00eKm0`000eKm00<005Km
E_d010000eKm00<005KmE_d010000TEb00D004EbAG95LP0000=5LP050015LTEbAG800002AG800`00
AG95LP02AG800`00AG8000020003AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015
LTEbAG800003AG801@00AG95LTEb000014Eb00D004EbAG95LP0000A5LP050015LTEbAG800003AG80
0`00AG8000020004BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP050019TTVBBI800003
BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP05
0019TTVBBI800003BI820004BI800`00BI99TP02BI8400000dVc0019/`02BK<00`00BK=9/`03BK<0
1@00@@m13d4?00000d4?00D0044?@@m13`0000A13`0300113d4?00913`04001Fo@00E_d200000eKm
0000000/Ool000]oo`@00003249oogoo009oo`04F]H8@P00>Lh7Ool00`00Oomoo`0ROol00`00E_eF
o@040003E_d00`00E_eFo@030004E_d00`00E_d00002E_d00`00E_eFo@02E_d00`00E_d00002E_d0
0`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@03
0004E_d00`00E_eFo@030003E_d01000E_d000000UKm00@005KmE_eFo@<000=Fo@04001FoEKmE_d3
0002AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800002AG830002AG80
1@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG801@00AG95LTEb0000
0dEb00<004EbAG800TEb00<004EbAG800TEb00D004EbAG95LP0000=5LP030015LTEb00<00099TP03
0019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP03
0019TTVB0099TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB00D004VB
BI99TP0000A9TP030019TTVB0099TP030019TTVB00<000A9/`050019/dVcBK<00005BK<01@00@@m1
3d4?00000d4?00D0044?@@m13`0000A13`0300113d4?00913`@000AFo@03001oogoo02Yoo`003Goo
00<007ooOol00goo00IS61S6LiacW124DY@6Ool00`00Oomoo`0SOol20003E_d00`00E_eFo@040003
E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06001Fo@00001F
o@0015Km0`000eKm00<005KmE_d010000eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km00<0
05Km00000UKm00<005KmE_d00UKm00D005Km0015LP0000=5LP050015LTEbAG800003AG801@00AG95
LTEb00000dEb00@004EbAG95LP<00003AG8004Eb0095LP050015LTEbAG800003AG801@00AG95LTEb
00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800004AG801@00AG95LTEb000014Eb00D004Eb
AG95LP0000=5LP<00003BI8004VB0099TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI80
0003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<004VBBI800TVB00<0
04VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP030019TTVB0099TP030019TTVB0099
TP030019TTVB00@00099/`030019/dVc0099/`030019/dVc0099/`030019/dVc0099/`0500113d4?
@@l00003@@l00`00@@m13`02@@l01@00@@m13d4?0000144?00@005KmE_d0009Fo@@002]oo`003Goo
00<007ooOol00goo00HQ25:DOomooe:D6<H6Ool2000UOol01000E_eFoEKm0`0015Km00<005KmE_d0
0`000eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km00<005KmE_d00`0015Km00H005Km0000
05Km0004E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030004
E_d00`00E_eFo@030002AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP040015LTEbAG85
0003AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG801@00AG95
LTEb00000dEb00<004EbAG800TEb00<004EbAG800TEb00D004EbAG95LP0000=5LP030015LP000080
00=9TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI800TVB
00D004VBBI99TP0000A9TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB00000dVB
00<004VBBI800TVB00<004VBBI800TVB00<004VBBI800TVB0`0000=9/`00BK<00dVc00<004VcBK<0
0dVc00D004VcBK=9/`0000A9/`0500113d4?@@l00003@@l00`00@@m13`02@@l01@00@@m13d4?0000
144?00<005KmE_d00`000eKm0P00:Woo000=Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Oomoo`0UOol00`00E_d00002E_d00`00E_eFo@02E_d30002E_d01000E_eFoEKm0`00
15Km00<005KmE_d00`000eKm00<005KmE_d010000eKm00<005KmE_d010000eKm00H005Km000005Km
0004E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00@00095LP04
0015LTEb0003AG801@00AG95LTEb00000dEb00H004EbAG95LP00AG830003AG801@00AG95LTEb0000
0dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG801@00AG95LTEb00000dEb00<004EbAG80
0TEb00D004EbAG95LP0000A5LP060015LTEbAG8004Eb10000TVB00D004VBBI99TP0000=9TP030019
TTVB0099TP030019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB0000
14VB00D004VBBI99TP0000A9TP030019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI80
0`00BI99TP02BI800`00BI99TP040002BK<00`00BK=9/`02BK<00`00BK=9/`03BK<01@00BK=9/dVc
000014Vc00D0044?@@m13`0000A13`0500113d4?@@l00003@@l00`00@@m13`02@@l300000eKm001F
o@03E_d2000ZOol000eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
02Moo`03001FoEKm009Fo@06001Fo@00001Fo@0015Km00<005Km00000UKm00<005KmE_d00UKm0`00
0eKm00<005KmE_d00`0015Km00<005KmE_d00`0015Km00<005KmE_d00`000eKm00<005KmE_d01000
0eKm00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30002AG801@00AG95LTEb00000TEb
00D004EbAG95LP0000=5LP050015LTEbAG800002AG830002AG801@00AG95LTEb00000dEb00D004Eb
AG95LP0000=5LP050015LTEbAG800003AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004Eb
AG95LP0000=5LP030015LTEb0095LP030015LTEb00<00099TP050019TTVBBI800003BI800`00BI99
TP02BI800`00BI99TP02BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP030019TTVB0099
TP050019TTVBBI800004BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP030019TTVB0099
TP030019TTVB00@00099/`030019/`000099/`030019/dVc0099/`030019/dVc0099/`050019/dVc
BK<00005BK<01@00@@m13d4?00000d4?00D0044?@@m13`0000=13`0300113d4?00913`03001FoEKm
009Fo@05001Fo@00001Fo@02000YOol000eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo02Qoo`03001FoEKm00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@00
15Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km00<0
05KmE_d00`000eKm00H005Km000005Km0004E_d01P00E_d00000AG8000=5LP050015LTEbAG800002
AG801@00AG95LTEb00000dEb00@004EbAG95LP<00003AG8004Eb0095LP050015LTEbAG800003AG80
1@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800004AG801@00AG95LTEb0000
0dEb00D004EbAG95LP0000A5LP<00003BI8004VB0099TP050019TTVBBI800004BI801@00BI99TTVB
000014VB00D004VBBI99TP0000=9TP050019TTVBBI800005BI801@00BI99TTVB00000dVB00<004VB
BI800TVB00D004VBBI99TP0000A9TP030019TTVB0099TP050019TTVBBI800004BI8300000dVc0019
/`03BK<00`00BK<00002BK<00`00BK=9/`02BK<00`00BK=9/`02BK<01@00BK=9/dVc00001DVc00D0
044?@@m13`0000=13`0500113d4?@@l00003@@l00`00@@m13`02@@l20002E_d30004E_d2000XOol0
00eoo`03001oogoo00=oo`068@QBU7ooOomBU2481Goo00<007ooOol0:Goo0P000eKm00<005KmE_d0
10000eKm00<005KmE_d00`0015Km00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@<0009F
o@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<0
00=5LP050015LTEbAG800003AG801000AG95LP000dEb00H004EbAG95LP00AG830003AG801@00AG95
LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG801@00AG95LTEb00000dEb00<0
04EbAG800TEb00D004EbAG95LP0000=5LP050015LTEbAG800002AG830003BI801@00BI99TTVB0000
0dVB00<004VBBI800TVB00D004VBBI99TP0000A9TP050019TTVBBI800003BI801@00BI99TTVB0000
1DVB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800004BI800`00BI99TP02BI80
1@00BI99TTVB00000TVB0`000dVc00<004VcBK<00TVc00H004VcBK<004Vc0004BK<00`00BK=9/`02
BK<00`00BK=9/`02BK<00`00BK=9/`02BK<01@00@@m13d4?00000d4?00D0044?@@m13`0000A13`04
00113d4?@@l40003E_d00`00E_eFo@04000WOol000]oo`03000Q200000Eoo`06HaPHaW>LLi`HaV<H
1Goo00<007ooOol0:Woo00@005KmE_eFo@<000AFo@03001FoEKm00<000=Fo@03001FoEKm00@000=F
o@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d30003E_d00`00
E_eFo@040003E_d00`00E_eFo@030002AG801@00AG95LTEb00000dEb00D004EbAG95LP000095LP05
0015LTEbAG800002AG830002AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEb
AG800003AG801@00AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP0000=5LP050015LTEb
AG800002AG840002BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP03
0019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB
00000dVB00<004VBBI800TVB00D004VBBI99TP0000A9TP030019TTVB0099TP030019TP0000@00099
/`030019/dVc0099/`030019/dVc0099/`030019/dVc008000A9/`030019/dVc00=9/`050019/dVc
BK<00004BK<01@00@@m13d4?00000d4?00D0044?@@m13`0000A13`0700113d4?@@l005Km00000eKm
10000UKm0P009goo000;Ool00f<H:DX00006Ool015[F2488@V<H1Woo0P00;7oo00<005Km00000UKm
00<005KmE_d00UKm0`000eKm00<005KmE_d00`0015Km00<005KmE_d00`000eKm00<005KmE_d01000
0eKm00<005KmE_d00`0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d300000dEb
0015LP02AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP030015LTEb00<00003AG8004Eb
0095LP050015LTEbAG800003AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEb
AG800004AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP<00003BI8004VB00=9TP050019
TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99
TP0000A9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<004VBBI80
0TVB00<004VBBI800TVB00<004VBBI800`000TVc00<004VcBK<00TVc00<004VcBK<00TVc00<004Vc
BK<00TVc00@004VcBK=9/`8000=9/`030019/dVc00=9/`050019/dVcBK<00004BK<01@00@@m13d4?
00000d4?00D0044?@@m13`0000A13`0600113d4?@@l005Km10000UKm00@005KmE_eFo@<002Ioo`00
7Woo00<007ooOol0;7oo00<005KmE_d00UKm00H005Km000005Km0004E_d30002E_d00`00E_eFo@02
E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d01P00E_d0
0000E_d000AFo@06001Fo@000015LP000TEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG80
1000AG95LTEb10000dEb00D004EbAG95LP0000=5LP030015LTEb0095LP040015LTEb0003AG801@00
AG95LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG800`00
AG8000020003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99
TP0000=9TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI80
1@00BI99TTVB00000dVB00<004VBBI800TVB00<004VBBI800TVB00<004VBBI800TVB0`0000=9/`00
BK<00TVc00<004VcBK<00TVc00<004VcBK<00TVc00<004VcBK<00TVc00@004VcBK=9/`8000A9/`03
0019/dVc0099/`050019/dVcBK<00004BK<01@00@@m13d4?00000d4?00D0044?@@m13`0000A13`03
00113d4?00<00003E_d005Km00AFo@<00003E_d0000002Ioo`007Goo00<007ooOol0;Woo00<005Km
E_d010000eKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm00@0
00=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=5LP040015LTEb0003
AG801@00AG95LTEb00000dEb00@004EbAG95LPD00095LP050015LTEbAG800003AG800`00AG95LP02
AG801@00AG95LTEb00000TEb00D004EbAG95LP0000=5LP050015LTEbAG800004AG801@00AG95LTEb
00000dEb00H004EbAG95LP00AG840002BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP05
0019TTVBBI800003BI801@00BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP0000=9TP03
0019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI800`00BI99TP02BI800`00BI99TP03
0003BK<01@00BK=9/dVc00001DVc00D004VcBK=9/`0000A9/`030019/dVc0099/`030019/dVc0099
/`030019/dVc0099/`050019/dVcBK<00005BK<01000@@m13`000d4?00D0044?@@m13`0000A13`<0
0003@@h005Km009Fo@03001FoEKm00<000AFo@8002Eoo`007Goo00<007ooOol0;goo0P0015Km00<0
05KmE_d00`000eKm00<005KmE_d010000eKm00H005Km000005Km0004E_d30002E_d00`00E_eFo@02
E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030002AG801@00AG95LTEb00000TEb00D004Eb
AG95LP0000=5LP060015LTEbAG8004Eb0`000dEb00@004EbAG8000=5LP030015LTEb0095LP050015
LTEbAG800003AG801000AG95LP000dEb00D004EbAG95LP0000A5LP050015LTEbAG800003AG801@00
AG95LTEb00000TEb0`000TVB00D004VBBI99TP0000=9TP030019TTVB0099TP030019TTVB0099TP05
0019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<004VBBI800TVB00D004VB
BI99TP0000=9TP030019TTVB0099TP050019TTVBBI800004BI800`00BI99TP02BI800`00BI99TP04
0002BK<01@00BK=9/dVc000014Vc00<004VcBK<00TVc00<004VcBK<00TVc00D004VcBK=9/`0000A9
/`8000=9/`030019/dVc0099/`030019/dVc0099/`030019/dVc0099/`0400113d4?0003@@l01@00
@@m13d4?00000T4?0`000d4>00<005KmE_d010000eKm00<005KmE_d00`009Goo000MOol00`00Oomo
o`0aOol00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d01P00E_d00000
E_d000AFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d0100000=5LP00AG800TEb00D004Eb
AG95LP000095LP050015LTEbAG800003AG800`00AG95LP030002AG801@00AG95LTEb00000TEb00D0
04EbAG95LP0000A5LP050015LTEbAG800003AG801000AG95LP000dEb00<004EbAG800TEb00D004Eb
AG95LP0000=5LP050015LTEbAG800003AG8300000dVB0019TP02BI801@00BI99TTVB000014VB00D0
04VBBI99TP0000A9TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9
TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB000014VB00<004VBBI800TVB0`00
00=9/`00BK<00dVc00<004VcBK<00TVc00D004VcBK=9/`0000A9/`030019/dVc0099/`030019/dVc
0099/`070019/dVcBK<004Vc00000TVc00<004VcBK<00TVc00<004VcBK<00TVc00<004VcBK<00`00
0T4?00D0044?@@m13`0000913`@000913P0400113T4>@@h30003E_d00`00E_eFo@040002E_d2000T
Ool001eoo`8003=oo`8000=Fo@03001FoEKm00@000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<0
00=Fo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km0`000TEb00@004EbAG8000=5LP050015
LTEbAG800002AG801@00AG95LTEb00000dEb0`0000=5LP00AG800TEb00D004EbAG95LP000095LP03
0015LTEb0095LP050015LTEbAG800003AG801@00AG95LTEb00000TEb00<004EbAG800TEb00D004Eb
AG95LP0000=5LP050015LTEbAG800003AG800`00AG8000020003BI801@00BI99TTVB00000dVB00<0
04VBBI800TVB00<004VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI800`00BI99
TP02BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP030019TTVB0099TP030019TTVB0099
TP050019TTVBBI800002BI830003BK<00`00BK=9/`02BK<00`00BK=9/`02BK<01@00BK=9/dVc0000
14Vc00<004VcBK<00TVc00<004VcBK<00TVc00<004VcBK<00TVc0P000TVc00<004VcBK<00dVc00<0
04VcBK<010000TWD00@0044?@@l000=13`<00003@@h0044>00=13P0400113T4>@@h20004E_d30002
E_d00`00E_eFo@04000SOol001eoo`03001oogoo03=oo`04001FoEKmE_d30002E_d00`00E_eFo@02
E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d01P00E_d0
0000AG8000=5LP040015LTEb0003AG801@00AG95LTEb00000TEb00H004EbAG95LP00AG830003AG80
1@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG801@00AG95LTEb0000
0TEb00<004EbAG800TEb00D004EbAG95LP0000=5LP060015LTEbAG8004Eb10000TVB00D004VBBI99
TP0000=9TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00D004VBBI99
TP0000A9TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI80
0dVB00D004VBBI99TP000099TP@00099/`050019/dVcBK<00004BK<00`00BK=9/`02BK<01@00BK=9
/dVc000014Vc00<004VcBK<00TVc00<004VcBK<00TVc00<004VcBK<00TVc00<004Vc00000TVc00<0
04VcBK<00TVc0`0000=9e000BM@00dWD00D0044?@@l0044?00<000=13P0300113T4>00913P080011
3T4>@@h005Km001Fo@800003E_d005Km009Fo@<000=Fo@03001oogoo025oo`007Goo00<007ooOol0
=7oo00<005Km00000UKm00H005KmE_eFo@00E_d200000eKm001Fo@03E_d30003E_d00`00E_eFo@04
0003E_d00`00E_eFo@030004E_d00`00E_eFo@020003AG801@00AG95LTEb00000TEb00D004EbAG95
LP0000=5LP040015LTEb0002AG830002AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP05
0015LTEbAG800003AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003
AG800`00AG95LP030002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP050019TTVBBI80
0004BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI80
0004BI801@00BI99TTVB00000dVB00<004VBBI800dVB00@004VBBI99TP<00003BK<004Vc00=9/`03
0019/dVc0099/`030019/dVc0099/`050019/dVcBK<00003BK<00`00BK=9/`03BK<01@00BK=9/dVc
000014Vc00<004VcBK<00TVc00H004VcBK<004Vc0002BK<30003BM@00`00BMA9e003BM@40002@@h0
1@00@@i13T4>0000144>00@0044>@@i13P@000AFo@<00003E_d005Km00=Fo@80029oo`0077oo00<0
07ooOol0=Woo00<005KmE_d00UKm00<005KmE_d00`000eKm00@005Km0000009Fo@04001FoEKmE_d3
0002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@0400000dEb0015LP02AG801@00AG95LTEb0000
0TEb00D004EbAG95LP0000=5LP030015LTEb00<00003AG8004Eb0095LP050015LTEbAG800003AG80
1@00AG95LTEb00000dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG801@00AG95LTEb0000
0dEb00D004EbAG95LP0000=5LP<00003BI8004VB0099TP050019TTVBBI800003BI801@00BI99TTVB
000014VB00D004VBBI99TP0000A9TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB
00000dVB00D004VBBI99TP0000A9TP050019TTVBBI800004BI800`00BI99TP02BI800`00BI800002
0003BK<00`00BK=9/`02BK<00`00BK=9/`02BK<00`00BK=9/`02BK<01@00BK=9/dVc000014Vc00<0
04VcBK<00TVc00<004VcBK<00TVc00D004VcBK=9/`0000A9/`030019/dVc00D00099e0030019e4WD
0099e0030019e4WD0099e00300113P0000=13P0500113T4>@@h00004@@h01@00@@i13T4>00000UKm
00<005KmE_d00`0015Km00D005Km000005Km0080025oo`0077oo00<007ooOol0=goo00<005KmE_d0
10000eKm00<005KmE_d00`0015Km00<005Km00000UKm00H005KmE_eFo@00E_d200000eKm001Fo@03
E_d30002AG801000AG95LP000dEb00D004EbAG95LP000095LP050015LTEbAG800003AG840003AG80
1@00AG95LTEb00000dEb00<004EbAG800TEb00@004EbAG8000=5LP050015LTEbAG800003AG801@00
AG95LTEb00000dEb00D004EbAG95LP0000=5LP060015LTEbAG8004Eb0`000dVB00D004VBBI99TP00
00=9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP00
00=9TP030019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB000014VB
00D004VBBI99TP0000=9TP<00099/`050019/dVcBK<00005BK<01@00BK=9/dVc000014Vc00<004Vc
BK<00TVc00D004VcBK=9/`0000A9/`030019/dVc0099/`030019/dVc0099/`030019/dVc0099/`D0
00A9e0030019e4WD0099e0030019e4WD0099e00300113P0000=13P0500113T4>@@h00004@@h01P00
@@i13T4>001Fo@@000=Fo@03001FoEKm00<000AFo@03001oogoo01moo`0077oo00<007ooOol0>7oo
0P000eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km00<005KmE_d00`000eKm00H005Km0000
04Eb0003AG801000AG95LP000dEb00D004EbAG95LP000095LP040015LTEbAG850002AG801@00AG95
LTEb00000dEb00<004EbAG800TEb00D004EbAG95LP000095LP050015LTEbAG800003AG801@00AG95
LTEb00000dEb00D004EbAG95LP0000=5LP060015LTEbAG8004Eb10000TVB00D004VBBI99TP0000=9
TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP050019TTVBBI80
0003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<004VBBI800TVB00D0
04VBBI99TP0000=9TP@00003BK<004Vc0099/`030019/dVc0099/`030019/dVc0099/`050019/dVc
BK<00004BK<00`00BK=9/`02BK<01@00BK=9/dVc000014Vc00<004VcBK<00TVc00<004VcBK<00TVc
00<004VcBK<00`000dWD00<004WDBM@00dWD00D004WDBMA9e00000A9e00300113P0000=13P050011
3T4>@@h00004@@h01000@@i13T4>0P000eKm00<005KmE_d010000UKm00@005KmE_eFo@@001moo`00
77oo0`00>Woo00<005KmE_d00`000eKm00<005KmE_d010000eKm00<005KmE_d010000eKm00<005Km
E_d00P000dEb00D004EbAG95LP000095LP050015LTEbAG800003AG801@00AG95LP00AG800`000dEb
00@004EbAG8000=5LP030015LTEb0095LP050015LTEbAG800003AG801000AG95LP000dEb00D004Eb
AG95LP0000=5LP050015LTEbAG800003AG801@00AG95LTEb00000TEb0`000TVB00D004VBBI99TP00
00=9TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00D004VBBI99TP00
00A9TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI800TVB
00<004VBBI800TVB00H004VBBI99TP00BI830004BK<01@00BK=9/dVc000014Vc00<004VcBK<00TVc
00D004VcBK=9/`0000A9/`030019/dVc0099/`050019/dVcBK<00004BK<00`00BK=9/`02BK<01000
BK=9/dVc10000TWD00<004WDBM@00TWD00<004WDBM@00TWD00D004WDBMA9e00000E9e08000=13P05
00113T4>@@h00004@@h01@00@@i13T4>000015Km0`000UKm00<005KmE_d01@000UKm0P007goo000L
Ool00`00Oomoo`0kOol20002E_d01000E_eFoEKm0`000eKm00<005KmE_d010000eKm00<005KmE_d0
100000=5LP00AG800TEb00D004EbAG95LP000095LP050015LTEbAG800003AG800`00AG8000020002
AG801@00AG95LTEb00000TEb00D004EbAG95LP0000A5LP050015LTEbAG800003AG801000AG95LP00
0dEb00D004EbAG95LP0000=5LP050015LTEbAG800003AG801000AG95LTEb0`0000=9TP00BI800TVB
00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00D004VBBI99TP00
00A9TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP030019TTVB
0099TP030019TTVB0099TP030019TP0000<00099/`030019/dVc0099/`030019/dVc0099/`050019
/dVcBK<00004BK<00`00BK=9/`02BK<01@00BK=9/dVc000014Vc00D004VcBK=9/`0000E9/`030019
/dVc0099/`<00003BM@004WD00=9e0030019e4WD0099e0030019e4WD0099e0030019e4WD0099e003
0019e4WD0099e08000=13P0500113T4>@@h00004@@h00`00@@i13P02@@h01P00E_d00000E_d000=F
o@<000=Fo@03001FoEKm00<001moo`0077oo00<007ooOol0>goo00<005KmE_d00UKm00<005Km0000
0UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@00095LP040015LTEb0003AG801@00AG95LTEb0000
0TEb00D004EbAG95LP000095LP<00003AG8004Eb0095LP050015LTEbAG800002AG800`00AG95LP02
AG801@00AG95LTEb00000dEb00D004EbAG95LP000095LP050015LTEbAG800003AG801@00AG95LTEb
00000dEb00H004EbAG95LP00AG830003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP05
0019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP05
0019TTVBBI800004BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP<00099/`050019/dVc
BK<00004BK<00`00BK=9/`02BK<01@00BK=9/dVc000014Vc00<004VcBK<00TVc00D004VcBK=9/`00
00A9/`050019/dVcBK<00005BK<00`00BK=9/`030003BM@00`00BMA9e002BM@00`00BMA9e002BM@2
0003BM@00`00BMA9e002BM@00`00BMA9e002BM@20003@@h01@00@@i13T4>0000144>00<0044>@@h0
0T4>0P0015Km0`0000=Fo@00E_d00eKm0`000UKm0P007Woo000LOol00`00Oomoo`0lOol00`00E_eF
o@030004E_d00`00E_d00002E_d01000E_eFoEKm0`000TEb00D004EbAG95LP000095LP050015LTEb
AG800003AG801000AG95LP000dEb0`0000E5LP00AG95LP0000=5LP050015LTEbAG800003AG801@00
AG95LTEb00000dEb00D004EbAG95LP0000=5LP040015LTEb0003AG801@00AG95LTEb00000dEb00H0
04EbAG95LP00AG840002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP050019TTVBBI80
0003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI80
0003BI800`00BI99TP02BI801@00BI99TTVB000014VB00@004VBBI99TP@00003BK<004Vc0099/`05
0019/dVcBK<00005BK<01@00BK=9/dVc00000dVc00<004VcBK<00dVc00D004VcBK=9/`0000=9/`03
0019/dVc0099/`030019/dVc0099/`040019/dVcBK<40002BM@00`00BMA9e002BM@00`00BMA9e002
BM@01`00BMA9e4WD0019e00000=9e0050019e4WDBM@00004BM@20003@@h01@00@@i13T4>0000144>
00<0044>@@h00T4>0P000UKm0`0015Km00H005Km000005Km0004E_d2000MOol001]oo`03001oogoo
03ioo`8000=Fo@03001FoEKm00<000AFo@05001Fo@00AG800003AG801@00AG95LTEb00000TEb00D0
04EbAG95LP0000=5LP050015LTEb0015LP030003AG801000AG95LP000dEb00D004EbAG95LP0000=5
LP050015LTEbAG800003AG801@00AG95LTEb00000dEb00D004EbAG95LP000095LP050015LTEbAG80
0003AG800`00AG95LP030002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP030019TTVB
0099TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP00
00=9TP050019TTVBBI800004BI801@00BI99TTVB000014VB00H004VBBI99TP00BI830004BK<01@00
BK=9/dVc000014Vc00<004VcBK<00TVc00D004VcBK=9/`0000A9/`030019/dVc0099/`050019/dVc
BK<00003BK<00`00BK=9/`03BK<01000BK=9/dVc100000=9e000BM@00dWD00<004WDBM@00TWD00<0
04WDBM@00TWD00<004WDBM@00TWD00<004WD00000TWD00D004WDBMA9e00000A9e08000=13P030011
3T4>00913P0500113T4>@@h00004@@h40003E_d00`00E_eFo@030004E_d00`00E_eFo@03000:Ool0
1W>L8@P00000:DYcW0Aoo`04F]H8@P00>Lh5Ool001]oo`04001oo`00000oOol00`00E_eFo@030003
E_d00`00E_eFo@030002AG801@00AG95LTEb00000dEb00@004EbAG8000=5LP060015LTEbAG8004Eb
0`000TEb00D004EbAG95LP000095LP050015LTEbAG800003AG801@00AG95LTEb00000dEb00D004Eb
AG95LP0000=5LP050015LTEbAG800003AG801000AG95LP000dEb00@004EbAG95LP<00003BI8004VB
0099TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP050019TTVB
BI800003BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVB
BI800004BI801@00BI99TTVB00000TVB0`000TVc00<004VcBK<00TVc00<004VcBK<00TVc00D004Vc
BK=9/`0000A9/`050019/dVcBK<00004BK<00`00BK=9/`02BK<01@00BK=9/dVc000014Vc00<004Vc
BK<00TVc00<004Vc00000P0014WD00<004WDBM@00TWD00<004WDBM@00TWD00<004WDBM@00TWD00<0
04WDBM@00TWD00<004WD00000TWD00D004WDBMA9e00000E9e00500113T4>@@h00004@@h01@00@@i1
3T4>0000144>00@005KmE_d0009Fo@@000=Fo@03001FoEKm00@0009Fo@8000Uoo`06:DXicWooOoli
cRU:0goo00IS61S6LiacW124DY@4Ool001]oo`80049oo`8000=Fo@03001FoEKm00<00095LP040015
LTEb0003AG801@00AG95LTEb00000TEb00D004EbAG95LP000095LP<00003AG8004Eb0095LP050015
LTEbAG800002AG800`00AG95LP02AG801000AG95LP000dEb00D004EbAG95LP0000=5LP050015LTEb
AG800003AG801@00AG95LTEb00000TEb00H004EbAG95LP00AG830003BI801@00BI99TTVB00000dVB
00D004VBBI99TP0000A9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP00
00=9TP030019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB000014VB
00@004VBBI99TP<00003BK<004Vc0099/`030019/dVc0099/`030019/dVc0099/`050019/dVcBK<0
0004BK<00`00BK=9/`02BK<01@00BK=9/dVc000014Vc00D004VcBK=9/`0000A9/`040019/dVcBK<3
0002BM@00`00BMA9e003BM@00`00BMA9e002BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD00H0
04WDBM@004WD0004BM@00`00BMA9e0030003@@h00`00@@i13P02@@h01@00@@i13T4>0000144>00<0
05Km00000`000UKm00@005KmE_eFo@@0009Fo@03001FoEKm00@000Qoo`03249oogoo009oo`06001o
ogooOolQ25:D0Woo00=BU1S6Ool00goo000KOol00`00Oomoo`12Ool00`00E_eFo@0400000dEb0015
LP02AG801000AG95LP000dEb00D004EbAG95LP000095LP040015LTEbAG8300001DEb0015LTEb0000
0dEb00D004EbAG95LP0000=5LP050015LTEbAG800002AG801@00AG95LTEb00000dEb00D004EbAG95
LP0000=5LP050015LTEbAG800003AG801@00AG95LP00AG8010000TVB00D004VBBI99TP0000=9TP05
0019TTVBBI800004BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003
BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP050019TTVBBI800003BI800`00BI99TP02
BI800`00BI8000020003BK<01@00BK=9/dVc00001DVc00D004VcBK=9/`0000=9/`030019/dVc0099
/`030019/dVc0099/`050019/dVcBK<00004BK<00`00BK=9/`02BK<01000BK=9/dVc100000=9e000
BM@00TWD00<004WDBM@00dWD00<004WDBM@00TWD00<004WDBM@00TWD00D004WDBMA9e00000A9e004
0019e4WDBM@20003BM@40002COH01@00@@i13T4>0000144>00D0044>@@i13P0000A13P80009Fo@04
001FoEKmE_d40002E_d00`00E_eFo@040003E_d00`00Oomoo`06Ool00`00Liaoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol00Woo0005Ool60004Ool015[F248003W>27oo00<007ooOol0@goo0P00
0TEb00@004EbAG8000=5LP040015LTEb0003AG801@00AG95LTEb00000TEb1@000dEb00@004EbAG80
00=5LP050015LTEbAG800003AG801@00AG95LTEb00000TEb00D004EbAG95LP0000=5LP050015LTEb
AG800003AG801@00AG95LTEb00000dEb00<004Eb00000P000TVB00D004VBBI99TP0000=9TP050019
TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019
TTVBBI800003BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP050019TTVBBI800003BI80
0`00BI99TP040002BK<01@00BK=9/dVc000014Vc00<004VcBK<00TVc00D004VcBK=9/`0000=9/`03
0019/dVc0099/`030019/dVc0099/`050019/dVcBK<00005BK<01P00BK=9/dVc0019/`<000A9e003
0019e4WD0099e0030019e4WD0099e0030019e4WD0099e0030019e4WD0099e0050019e4WDBM@00004
BM@01P00BMA9e4WD0019e0<00003COH004gf00A=mP0400113T4>0004@@h01@00@@i13T4>0000144>
00<005KmE_d00UKm0`0000=Fo@00E_d00eKm0`000eKm00<005KmE_d00`001goo00H002U:LiaoocW>
:DX3Ool00`00Oomoo`02Ool00`00Oomoo`02Ool000Eoo`03BU8006<H009oo`06249oogooOomS61S6
0W>L00<@Q5:DOol01Woo00<007ooOol0@goo00D004EbAG95LP000095LP050015LTEbAG800002AG80
1@00AG95LTEb00000dEb10000dEb00D004EbAG95LP000095LP050015LTEbAG800003AG801@00AG95
LTEb00000dEb00@004EbAG8000=5LP050015LTEbAG800003AG801@00AG95LTEb00000dEb00@004Eb
AG95LP800003BI8004VB0099TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D004VBBI99
TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP030019
TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB00000TVB10000TVc00D004VcBK=9/`0000A9
/`050019/dVcBK<00004BK<01@00BK=9/dVc000014Vc00D004VcBK=9/`0000A9/`050019/dVcBK<0
0005BK<00`00BK<000030002BM@00`00BMA9e003BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD
00<004WDBM@00TWD00D004WDBMA9e00000E9e0030019e4WD00<000==mP03001=mTgf00==mP040011
3T4>0004@@h01@00@@i13T4>0000144>0P0000AFo@00000000AFo@06001Fo@00001Fo@0015Km0`00
0UKm0P001Woo00H@Q3W>000002U:Li`3Ool00`00Oomoo`02Ool00`00Oomoo`02Ool000Ioo`03BU80
06<H00Eoo`068@QBU7ooOomBU1S61Woo00<007ooOol0A7oo00D004EbAG95LP000095LP050015LTEb
AG800002AG801P00AG95LTEb0015LP<00095LP050015LTEbAG800003AG801000AG95LP000dEb00D0
04EbAG95LP0000=5LP050015LTEbAG800002AG801@00AG95LTEb00000dEb00D004EbAG95LP0000=5
LP060015LTEbAG8004Eb0`000TVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99
TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D0
04VBBI99TP0000A9TP030019TTVB0099TP050019TTVBBI800003BI8300000dVc0019/`03BK<01@00
BK=9/dVc000014Vc00D004VcBK=9/`0000A9/`030019/dVc0099/`050019/dVcBK<00003BK<00`00
BK=9/`02BK<00`00BK=9/`02BK<01000BK=9/dVc0`000TWD00D004WDBMA9e00000E9e0050019e4WD
BM@00005BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD00@004WDBMA9e0@0009=mP03001=mTgf
009=mP03001=mTgf009=mP0400113T4>0004@@h01@00@@i13T4>0000144>0`000eKm00<005KmE_d0
0`0015Km00H005Km000005Km0003E_d20006Ool00d8@<Haoo`06Ool01R48DYAoogooDY@Q20Aoo`00
1goo00=BU0Q2HaP017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0A7oo00D004EbAG95
LP000095LP050015LTEbAG800002AG801000AG95LTEb0P000TEb00@004EbAG8000=5LP050015LTEb
AG800003AG801000AG95LP000dEb00D004EbAG95LP0000=5LP040015LTEb0003AG801@00AG95LTEb
00000dEb00H004EbAG95LP00AG840002BI801000BI99TP000dVB00D004VBBI99TP0000A9TP050019
TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI80
1@00BI99TTVB000014VB00D004VBBI99TP0000A9TP060019TTVBBI8004VB0`000dVc00<004VcBK<0
0TVc00D004VcBK=9/`0000A9/`050019/dVcBK<00004BK<00`00BK=9/`02BK<01@00BK=9/dVc0000
0dVc00<004VcBK<00dVc00@004VcBK=9/`@00003BM@004WD0099e0030019e4WD0099e0030019e4WD
0099e0050019e4WDBM@00005BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD100000==mP00COH0
0dgf0P000dgf00<004gfCOH00dgf00<0044>0000144>00D0044>@@i13P0000913P<00004E_d005Km
E_d40003E_d00`00E_eFo@030004E_d300000eKm00000006Ool00aS6<Ha[FP05Ool01V<H6<IcW7>L
6<IS60Aoo`0027oo00=S60Q2HaP00goo00<007ooOol00Woo00<007ooOol017oo0`00A7oo00D004Eb
AG95LP000095LP050015LTEbAG800002AG850003AG801000AG95LP000dEb00D004EbAG95LP0000=5
LP040015LTEb0003AG801@00AG95LTEb00000dEb00@004EbAG8000=5LP050015LTEbAG800003AG80
0`00AG95LP030002BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP030019TTVB0099TP05
0019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003
BI800`00BI99TP02BI801@00BI99TTVB000014VB00H004VBBI99TP00BI840002BK<01@00BK=9/dVc
000014Vc00<004VcBK<00TVc00D004VcBK=9/`0000=9/`030019/dVc0099/`030019/dVc0099/`05
0019/dVcBK<00004BK<00`00BK=9/`02BK<00`00BK<000020004BM@00`00BMA9e002BM@01@00BMA9
e4WD000014WD00<004WDBM@00TWD00<004WDBM@00TWD00D004WDBMA9e00000E9e0030019e0000080
00A=mP03001=mTgf00==mP05001=mTgfCOH00005COH00`00@@h00004@@h00`00@@h000040002?<`5
0003E_d00`00E_eFo@040002E_d00`00E_eFo@030004E_d00`00Oomoo`05Ool013W>2480012417oo
00AJePQ2249S60Eoo`002Goo00=BU1S6Ool00Woo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0A7oo00D004EbAG95LP000095LP040015LTEbAG840003AG801@00AG95LTEb00000TEb00D004Eb
AG95LP0000=5LP050015LTEbAG800002AG801@00AG95LTEb00000dEb00D004EbAG95LP000095LP05
0015LTEbAG800003AG801000AG95LTEb0`0000=9TP00BI800TVB00D004VBBI99TP000099TP050019
TTVBBI800004BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI80
1@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP050019TTVBBI800004BI800`00BI99TP030002
BK<01@00BK=9/dVc000014Vc00<004VcBK<00TVc00D004VcBK=9/`0000=9/`030019/dVc0099/`05
0019/dVcBK<00004BK<01@00BK=9/dVc000014Vc00@004VcBK=9/`<00099e0030019e4WD0099e003
0019e4WD0099e0050019e4WDBM@00005BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD00@004WD
BMA9e0<0009=mP03001=mTgf00==mP03001=mTgf009=mP8000==mP03001=mTgf009=mP0300113P00
00=13P<0008lc003000lc3c<008lc005001FoEKmE_d00002E_d40002E_d00`00E_eFo@040003E_d0
0`00E_eFo@03000GOol000Yoo`06001oogooOolQ25:D0Woo00=BU248Ool01Goo00<007ooOol0A7oo
00D004EbAG95LP000095LP030015LP0000800095LP050015LTEbAG800003AG801000AG95LP000dEb
00D004EbAG95LP0000=5LP040015LTEb0003AG801@00AG95LTEb00000dEb00@004EbAG8000=5LP06
0015LTEbAG8004Eb0`000dVB00D004VBBI99TP0000=9TP040019TTVB0004BI801@00BI99TTVB0000
0dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99
TP0000A9TP050019TTVBBI800003BI800`00BI99TP02BI8300000dVc0019/`02BK<01@00BK=9/dVc
000014Vc00<004VcBK<00TVc00D004VcBK=9/`0000A9/`050019/dVcBK<00003BK<00`00BK=9/`02
BK<00`00BK=9/`02BK<01000BK=9/dVc100000=9e000BM@00TWD00<004WDBM@00dWD00D004WDBMA9
e00000=9e0030019e4WD00=9e0050019e4WDBM@00004BM@00`00BMA9e002BM@400000dgf001=mP03
COH00`00COI=mP02COH00`00COI=mP02COH00`00COH00002COH00`00COI=mP03COH500000cc<000l
c002?<`00`00?<`lc002?<`01000E_eFoEKm0`000UKm00<005KmE_d010000eKm00<005KmE_d01000
0UKm0P005Woo0005Ool01P00@Q1cW7oo>LhHaP=oo`06HaPHaW>LLi`HaV<H1Woo00<007ooOol0A7oo
00H004EbAG95LP00AG830002AG801000AG95LP000dEb00D004EbAG95LP0000=5LP040015LTEb0003
AG801@00AG95LTEb00000TEb00D004EbAG95LP0000=5LP050015LTEbAG800002AG801P00AG95LTEb
0015LP@00099TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP05
0019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800004
BI801@00BI99TTVB00000dVB00D004VBBI99TP000099TP<000=9/`050019/dVcBK<00004BK<01@00
BK=9/dVc000014Vc00D004VcBK=9/`0000A9/`050019/dVcBK<00003BK<00`00BK=9/`03BK<01P00
BK=9/dVc0019/`<000A9e0030019e4WD0099e0030019e4WD0099e0050019e4WDBM@00004BM@00`00
BMA9e002BM@01@00BMA9e4WD00001DWD00<004WD00000P0014gf00<004gfCOH00Tgf00<004gfCOH0
0Tgf00<004gfCOH00Tgf00H004gfCOH004gf0004COH30004?<`01@00?<`lc3c<000013c<00H005Km
000005Km0003E_d30003E_d00`00E_eFo@040002E_d00`00E_eFo@03000FOol000Eoo`06DY@HaP00
000YBW>L17oo00AJePQ2249S60Ioo`03001oogoo04Eoo`030015LTEb00<00003AG8004Eb0095LP04
0015LTEb0003AG801@00AG95LTEb00000dEb00@004EbAG8000=5LP050015LTEbAG800002AG801@00
AG95LTEb00000dEb00D004EbAG95LP000095LP030015LTEb00<00099TP050019TTVBBI800003BI80
1@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB0000
0dVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00D004VBBI99
TP000099TP@00099/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc000014Vc00D0
04VcBK=9/`0000A9/`050019/dVcBK<00004BK<00`00BK=9/`02BK<00`00BK<000030002BM@00`00
BMA9e002BM@00`00BMA9e002BM@00`00BMA9e002BM@00`00BMA9e002BM@01@00BMA9e4WD000014WD
00D004WDBMA9e00000A9e0<0009=mP03001=mTgf00==mP05001=mTgfCOH00005COH01@00COI=mTgf
00000Tgf00<004gfCOH0100000=>5P00000013c<00D003c<?<`lc00000@lc08000AFo@<00003E_d0
05Km00=Fo@<0009Fo@03001FoEKm00@000=Fo@03001oogoo01=oo`006Goo0`00AGoo0`0000E5LP00
AG95LP0000=5LP040015LTEb0003AG801@00AG95LTEb00000dEb00@004EbAG8000=5LP050015LTEb
AG800002AG801@00AG95LTEb00000dEb00D004EbAG95LP000095LP<00003BI8004VB0099TP050019
TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI80
1@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99TTVB0000
0dVB00@004VBBI99TP<00003BK<004Vc00=9/`050019/dVcBK<00004BK<01@00BK=9/dVc00000dVc
00<004VcBK<00TVc00D004VcBK=9/`0000A9/`050019/dVcBK<00004BK<01000BK=9/dVc0`000TWD
00D004WDBMA9e00000E9e0050019e4WDBM@00004BM@00`00BMA9e002BM@01@00BMA9e4WD000014WD
00<004WDBM@00TWD100000==mP00COH00dgf00<004gfCOH00Tgf00<004gfCOH00Tgf00<004gfCOH0
0Tgf00<004gfCOH00Tgf00<004gfCOH00`0014hF0P0013c<00D003c<?<`lc00000<lc003001Fo@00
009Fo@<000AFo@06001Fo@00001Fo@000eKm0`000eKm00<005KmE_d00`0057oo000IOol00`00Oomo
o`12Ool40003AG801000AG95LP000dEb00D004EbAG95LP000095LP050015LTEbAG800003AG801000
AG95LP000dEb00D004EbAG95LP000095LP050015LTEbAG800003AG801P00AG95LTEb0015LP8000=9
TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI80
0003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99
TTVB00000dVB00H004VBBI99TP00BI830003BK<00`00BK=9/`02BK<00`00BK=9/`02BK<01@00BK=9
/dVc00000dVc00<004VcBK<00TVc00D004VcBK=9/`0000=9/`030019/dVc0099/`030019/dVc0099
/`040019/dVcBK<400000dWD0019e002BM@00`00BMA9e002BM@00`00BMA9e002BM@01@00BMA9e4WD
000014WD00<004WDBM@00TWD00D004WDBMA9e00000E9e0030019e000008000A=mP03001=mTgf009=
mP03001=mTgf009=mP03001=mTgf009=mP03001=mTgf009=mP04001=mTgfCOH400000dhF00000005
CQH00`00?<`lc002?<`01@00?<`lc3c<00000cc<1@000eKm00<005KmE_d00`0015Km0`0000=Fo@00
E_d00eKm0`000UKm00<007ooOol04Woo000IOol00`00Oomoo`10Ool20003Ool01@00AG95LTEb0000
0TEb00D004EbAG95LP0000=5LP040015LTEb0003AG801@00AG95LTEb00000TEb00D004EbAG95LP00
00=5LP040015LTEb0003AG801P00AG95LTEb0015LP@00003BI8004VB0099TP050019TTVBBI800003
BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB
00000dVB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800003BI801P00BI99TTVB
0019TP@00099/`050019/dVcBK<00004BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc00<004Vc
BK<00TVc00D004VcBK=9/`0000=9/`030019/dVc0099/`030019/dVc0099/`030019/`00008000A9
e0050019e4WDBM@00004BM@00`00BMA9e002BM@00`00BMA9e002BM@01@00BMA9e4WD000014WD00<0
04WDBM@00TWD00<004WDBM@010000Tgf00<004gfCOH00dgf00D004gfCOI=mP0000A=mP03001=mTgf
009=mP03001=mTgf00==mP<00003CQH004hF009>5P8000E>5P03000lc3c<008lc005000lc3c<?<`0
0003?<`01@00E_eFoEKm00000UKm10000UKm00<005KmE_d00`0015Km00H005Km000005Km0003E_d2
000COol001Uoo`03001oogoo03eoo`<000Eoo`050015LTEbAG800002AG801@00AG95LTEb00000dEb
00@004EbAG8000=5LP050015LTEbAG800002AG801@00AG95LTEb00000dEb00@004EbAG8000=5LP03
0015LP0000<00099TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP05
0019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800004
BI801@00BI99TTVB00000dVB00D004VBBI99TP000099TP<00099/`050019/dVcBK<00004BK<00`00
BK=9/`02BK<01@00BK=9/dVc00000dVc00<004VcBK<00TVc00D004VcBK=9/`0000=9/`030019/dVc
0099/`030019/dVc0099/`030019/dVc00<00099e0030019e4WD0099e0030019e4WD0099e0050019
e4WDBM@00004BM@00`00BMA9e002BM@01@00BMA9e4WD000014WD00@004WDBMA9e0@0009=mP03001=
mTgf009=mP03001=mTgf009=mP03001=mTgf009=mP05001=mTgfCOH00005COH00`00COI=mP030004
CQH01000CQI>5ThF0P0014hF00D003c<?<`lc00000@lc005000lc3c<?<`00002E_d40002E_d00`00
E_eFo@040003E_d00`00E_eFo@030004E_d300000eKm0000000BOol001Uoo`03001oogoo03Yoo`<0
00Qoo`050015LTEbAG800002AG801@00AG95LTEb00000dEb00@004EbAG8000=5LP050015LTEbAG80
0002AG801@00AG95LTEb00000dEb00@004EbAG800095LP<00099TP050019TTVBBI800002BI801@00
BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB
00D004VBBI99TP0000=9TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB
00@004VBBI99TP<00003BK<004Vc0099/`050019/dVcBK<00004BK<00`00BK=9/`02BK<01@00BK=9
/dVc00000dVc00<004VcBK<00TVc00D004VcBK=9/`0000A9/`050019/dVcBK<00004BK<300000dWD
0019e002BM@00`00BMA9e003BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD00<004WDBM@00TWD
00<004WDBM@00TWD00<004WDBM@00TWD0`0000==mP00COH00dgf00<004gfCOH00Tgf00<004gfCOH0
0Tgf00<004gfCOH00Tgf00<004gfCOH00Tgf00@004gfCOI=mP@0009>5P03001>5ThF009>5P03001>
5ThF009>5P03001>5ThF009>5P05000lc3c<?<`00004?<`01000?<`lc3c<0`000UKm00<005KmE_d0
10000eKm00<005KmE_d010000UKm00<005KmE_d00`0015Km00<007ooOol047oo000IOol00`00Oomo
o`0gOol3000;Ool01@00AG95LTEb00000TEb00D004EbAG95LP0000=5LP040015LTEb0003AG801@00
AG95LTEb00000TEb00D004EbAG95LP0000=5LP030015LTEb00<00003BI8004VB0099TP050019TTVB
BI800002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00
BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB
00H004VBBI99TP00BI830003BK<01@00BK=9/dVc000014Vc00D004VcBK=9/`0000A9/`050019/dVc
BK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc000014Vc00D004VcBK=9/`000099/`<000=9e003
0019e4WD0099e0030019e4WD0099e0050019e4WDBM@00004BM@01@00BMA9e4WD000014WD00<004WD
BM@00TWD00<004WDBM@00`000dgf00<004gfCOH00dgf00D004gfCOI=mP0000A=mP03001=mTgf009=
mP03001=mTgf009=mP@00003CQH004hF00=>5P03001>5ThF009>5P03001>5ThF009>5P8000A>5P04
000lc3c<0004?<`00`00?<`000030002E_d40003E_d00`00E_eFo@040002E_d00`00E_eFo@040003
E_d00`00E_eFo@03000AOol001Qoo`<003Eoo`<000ioo`050015LTEbAG800002AG801@00AG95LTEb
00000dEb00@004EbAG8000=5LP050015LTEbAG800002AG801@00AG95LTEb00000dEb00@004Eb0000
00=9TP050019TTVBBI800003BI801000BI99TP000dVB00D004VBBI99TP0000=9TP050019TTVBBI80
0003BI800`00BI99TP02BI801000BI99TP000dVB00D004VBBI99TP0000=9TP030019TTVB0099TP05
0019TTVBBI800003BI801P00BI99TTVB0019TP@00099/`050019/dVcBK<00003BK<00`00BK=9/`02
BK<01@00BK=9/dVc000014Vc00D004VcBK=9/`0000=9/`030019/dVc0099/`050019/dVcBK<00004
BK<00`00BK<000040002BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD00D004WDBMA9e00000A9
e0050019e4WDBM@00004BM@01000BMA9e4WD10000Tgf00<004gfCOH00Tgf00<004gfCOH00Tgf00<0
04gfCOH00Tgf00D004gfCOI=mP0000E=mP03001=mP00008000A>5P03001>5ThF00=>5P03001>5ThF
009>5P04001>5ThFCQH20003CQH20002?<`01000?<`lc3c<0`000SR:10000eKm00<005KmE_d01000
0UKm00<005KmE_d010000eKm00<005KmE_d0100000=oo`00Ool04Goo000HOol00`00Oomoo`0bOol3
000AOol01@00AG95LTEb00000TEb00D004EbAG95LP0000=5LP040015LTEb0003AG801@00AG95LTEb
00000TEb00H004EbAG95LP00AG8400000dVB0019TP02BI801@00BI99TTVB00000dVB00@004VBBI80
00=9TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D004VBBI99TP000099TP050019TTVB
BI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00D004VBBI99TP000099TP<00099/`05
0019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc00<004VcBK<00TVc00D004Vc
BK=9/`0000=9/`030019/dVc0099/`030019/dVc0099/`030019/dVc00<00099e0030019e4WD0099
e0030019e4WD0099e0050019e4WDBM@00004BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD00<0
04WDBM@00TWD0`0000==mP00COH00dgf00<004gfCOH00Tgf00<004gfCOH00Tgf00<004gfCOH00Tgf
00<004gfCOH00Tgf00<004gfCOH010000ThF00<004hFCQH00dhF00<004hFCQH00ThF00<004hFCQH0
0ThF00<004hFCQH00ThF100000ABF000?<`lc0@00003>8X003R:008hRP03001Fo@0000AFo@<0009F
o@03001FoEKm00@000=Fo@03001FoEKm00@000Ioo`03001oogoo00moo`0067oo00<007ooOol0;goo
0`0057oo00D004EbAG95LP000095LP050015LTEbAG800003AG801000AG95LP000dEb00D004EbAG95
LP000095LP030015LP0000<00099TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VBBI99
TP000099TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00@004VBBI80
00=9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00@004VBBI99TP<00003BK<004Vc0099
/`050019/dVcBK<00004BK<01@00BK=9/dVc00000dVc00<004VcBK<00TVc00D004VcBK=9/`0000=9
/`030019/dVc0099/`030019/dVc0099/`040019/dVcBK<300000dWD0019e002BM@00`00BMA9e002
BM@00`00BMA9e002BM@01@00BMA9e4WD000014WD00D004WDBMA9e00000A9e0030019e4WD0099e003
0019e4WD00<000A=mP03001=mTgf009=mP05001=mTgfCOH00004COH00`00COI=mP02COH01000COI=
mTgf10000ThF00<004hFCQH00ThF00<004hFCQH00ThF00<004hFCQH00ThF00<004hFCQH00ThF00<0
04hFCQH00`0000=BF000DUP00U9H0`0013R:00D003R:>8XhRP00009Fo@06001Fo@00001Fo@000eKm
0`000eKm00<005KmE_d010002Woo00<007ooOol03goo000HOol00`00Oomoo`0/Ool3000GOol01@00
AG95LTEb00000TEb00D004EbAG95LP0000=5LP040015LTEb0003AG801P00AG95LTEb0015LP<00099
TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP040019TTVB0003
BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP040019TTVB0003BI800`00BI99TP02BI80
1@00BI99TTVB00000dVB00H004VBBI99TP00BI830003BK<01@00BK=9/dVc00000dVc00<004VcBK<0
0TVc00D004VcBK=9/`0000=9/`030019/dVc0099/`050019/dVcBK<00003BK<00`00BK=9/`02BK<0
0`00BK=9/`02BK<00`00BK<000020003BM@00`00BMA9e002BM@00`00BMA9e002BM@01@00BMA9e4WD
000014WD00D004WDBMA9e00000=9e0030019e4WD00=9e0030019e00000@0009=mP03001=mTgf009=
mP03001=mTgf009=mP03001=mTgf009=mP05001=mTgfCOH00005COH300000dhF001>5P03CQH00`00
CQI>5P02CQH00`00CQI>5P02CQH00`00CQI>5P02CQH00`00CQI>5P02CQH30002DUP01000DUQBF000
0U9H00<003R:000013R:00H003R:>8XhRP00E_d30004E_d300000eKm001Fo@03E_d3000>Ool00`00
Oomoo`0?Ool001Qoo`03001oogoo02Uoo`<001Yoo`050015LTEbAG800002AG801@00AG95LTEb0000
0dEb00@004EbAG8000=5LP040015LTEbAG8200000dVB0019TP02BI801@00BI99TTVB00000TVB00D0
04VBBI99TP0000=9TP050019TTVBBI800003BI801000BI99TP000dVB00<004VBBI800TVB00D004VB
BI99TP0000=9TP050019TTVBBI800002BI800`00BI99TP02BI801@00BI99TTVB00000dVB00H004VB
BI99TP00BI840002BK<01@00BK=9/dVc00000dVc00<004VcBK<00TVc00D004VcBK=9/`0000=9/`03
0019/dVc0099/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000TVc10000TWD
00D004WDBMA9e00000A9e0030019e4WD0099e0050019e4WDBM@00004BM@01@00BMA9e4WD000014WD
00@004WDBMA9e0<0009=mP03001=mTgf009=mP03001=mTgf009=mP03001=mTgf009=mP03001=mTgf
009=mP03001=mTgf009=mP03001=mTgf00<000A>5P03001>5ThF009>5P03001>5ThF009>5P05001>
5ThFCQH00005CQH400000e9H001BF003DUP00`00DUP00002DUP00`00>8X00004>8X01000>8XhRSR:
0P000UKm00<005KmE_d00`0015Km00@005Km0000015oo`03001oogoo00moo`0067oo00<007ooOol0
9goo0P007Goo00D004EbAG95LP000095LP050015LTEbAG800003AG801000AG95LP000dEb00<004Eb
00000P000TVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VB
BI99TP000099TP030019TTVB0099TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VB
BI99TP0000=9TP050019TTVBBI800003BI800`00BI8000030002BK<01@00BK=9/dVc00000dVc00<0
04VcBK<00TVc00D004VcBK=9/`0000=9/`050019/dVcBK<00004BK<01@00BK=9/dVc000014Vc00D0
04VcBK=9/`000099/`@00099e0050019e4WDBM@00004BM@01@00BMA9e4WD000014WD00D004WDBMA9
e00000A9e0030019e4WD0099e0040019e4WDBM@400000dgf001=mP03COH00`00COI=mP02COH00`00
COI=mP02COH01@00COI=mTgf000014gf00@004gfCOI=mP@0009>5P03001>5ThF009>5P03001>5ThF
009>5P03001>5ThF009>5P03001>5ThF009>5P03001>5ThF00<000EBF005001BF59HDUP00002DUP0
0`00DUQBF0020003>8X00`00>8XhRP02>8X00`00E_eFo@040003E_d00`00E_eFo@03000COol00`00
Oomoo`0?Ool001Moo`<002Eoo`<001moo`050015LTEbAG800002AG801@00AG95LTEb00000dEb00D0
04EbAG8004Eb00@00099TP040019TTVB0003BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9
TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI80
0003BI801@00BI99TTVB00000dVB00D004VBBI99TP000099TP<00099/`050019/dVcBK<00003BK<0
0`00BK=9/`02BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`0000=9/`030019/dVc0099/`050019
/dVcBK<00004BK<01000BK=9/dVc0`0000=9e000BM@00dWD00D004WDBMA9e00000A9e0050019e4WD
BM@00004BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD00<004WD00000P0014gf00<004gfCOH0
0Tgf00<004gfCOH00Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000E=mP<00003CQH004hF00=>5P03
001>5ThF009>5P03001>5ThF009>5P03001>5ThF009>5P03001>5ThF00D0009BF003001BF59H00=B
F003001BF59H009BF003001BF59H00@000<hRP03000hRSR:008hRP<000=Fo@03001FoEKm00@001Io
o`03001oogoo00moo`005goo00<007ooOol08Woo0`008Woo00D004EbAG95LP000095LP050015LTEb
AG800003AG800`00AG8000020002BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP040019
TTVB0003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00
BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI8300000dVc0019/`02BK<0
1@00BK=9/dVc00000dVc00<004VcBK<00TVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<0
0`00BK=9/`02BK<00`00BK=9/`02BK<01P00BK=9/dVc0019/`<000=9e0030019e4WD0099e0030019
e4WD0099e0050019e4WDBM@00004BM@01@00BMA9e4WD00000dWD00<004WDBM@00dWD00<004WD0000
0`000Tgf00<004gfCOH00dgf00D004gfCOI=mP0000A=mP03001=mTgf009=mP03001=mTgf009=mP03
001=mTgf00<000A>5P03001>5ThF009>5P03001>5ThF009>5P05001>5ThFCQH00004CQH30002DUP0
0`00DUQBF003DUP00`00DUQBF002DUP00`00DUQBF002DUP01@00DUP00000DYX00P000cR:00<003R:
>8X00`0000AFo@00E_eFo@@001Yoo`03001oogoo00moo`005goo00<007ooOol07goo0`009Goo00D0
04EbAG95LP000095LP050015LTEbAG800002AG8300000dVB0019TP02BI801@00BI99TTVB00000TVB
00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9
TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP060019TTVBBI80
04VB0`000dVc00D004VcBK=9/`0000=9/`030019/dVc0099/`050019/dVcBK<00003BK<01@00BK=9
/dVc00000dVc00D004VcBK=9/`0000A9/`030019/dVc0099/`030019/`0000<00099e0030019e4WD
0099e0030019e4WD0099e0050019e4WDBM@00003BM@00`00BMA9e002BM@01@00BMA9e4WD000014WD
00@004WDBMA9e0<0009=mP03001=mTgf009=mP03001=mTgf009=mP03001=mTgf009=mP05001=mTgf
COH00005COH00`00COH000040002CQH00`00CQI>5P02CQH00`00CQI>5P02CQH00`00CQI>5P02CQH0
0`00CQI>5P02CQH400000e9H001BF003DUP00`00DUQBF002DUP00`00DUQBF003DUP00`00DUQBF003
0002DYX01000DYX003R:1@000R`41@007goo00<007ooOol03Woo000GOol00`00Oomoo`0LOol3000X
Ool01@00AG95LTEb00000TEb00@004EbAG95LP<00005BI8004VBBI800003BI801@00BI99TTVB0000
0TVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB000014VB00@004VBBI8000=9
TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP030019TP0000<0
0099/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`00
00=9/`050019/dVcBK<00004BK<00`00BK=9/`02BK<00`00BK=9/`030002BM@01@00BMA9e4WD0000
14WD00<004WDBM@00TWD00D004WDBMA9e00000=9e0030019e4WD0099e0030019e4WD0099e0040019
e4WDBM@400000dgf001=mP02COH00`00COI=mP02COH00`00COI=mP02COH00`00COI=mP02COH01@00
COI=mTgf000014gf0`000ThF00<004hFCQH00ThF00<004hFCQH00ThF00<004hFCQH00ThF00<004hF
CQH00ThF00<004hFCQH00`001E9H00D0059HDUQBF00000ABF003001BF59H009BF0@0009BVP04001B
VU:JDYX30002;0@00`00;0@/1002;0@00`00Oomoo`0QOol00`00Oomoo`0>Ool001Moo`03001oogoo
01Uoo`<002]oo`050015LTEbAG800002AG800`00AG8000020003BI801000BI99TP000dVB00D004VB
BI99TP000099TP050019TTVBBI800003BI801000BI99TP000dVB00<004VBBI800TVB00D004VBBI99
TP000099TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP030019
TTVB00<00099/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc00D004Vc
BK=9/`0000=9/`050019/dVcBK<00004BK<01@00BK=9/dVc000014Vc0`0000=9e000BM@00TWD00D0
04WDBMA9e00000A9e0030019e4WD0099e0050019e4WDBM@00003BM@00`00BMA9e002BM@00`00BMA9
e002BM@00`00BM@000020004COH00`00COI=mP02COH01@00COI=mTgf000014gf00<004gfCOH00Tgf
00<004gfCOH00Tgf100000=>5P00CQH00dhF00<004hFCQH00ThF00<004hFCQH00ThF00D004hFCQI>
5P0000A>5P<0009BF003001BF59H00=BF003001BF59H009BF003001BF59H009BF0@00003DYX005:J
00ABVP05001BVU:JDYX00003;0@01@00;0@/12`4000097oo00<007ooOol03Woo000GOol00`00Oomo
o`0FOol3000^Ool01P00AG95LTEb0015LP<00099TP050019TTVBBI800002BI801@00BI99TTVB0000
0dVB00@004VBBI8000=9TP050019TTVBBI800002BI800`00BI99TP02BI801@00BI99TTVB00000dVB
00@004VBBI8000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00@004VBBI99TP<00003
BK<004Vc0099/`050019/dVcBK<00004BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`0000=9/`05
0019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000TVc0`000dWD00D004WDBMA9e000
00A9e0050019e4WDBM@00004BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD00@004WDBMA9e0<0
009=mP03001=mTgf00==mP05001=mTgfCOH00004COH01@00COI=mTgf00001Dgf00<004gf00000P00
14hF00<004hFCQH00ThF00<004hFCQH00ThF00<004hFCQH00ThF00<004hFCQH00ThF100000=BF000
DUP00e9H00<0059HDUP00U9H00<0059HDUP00U9H00<0059HDUP00`001E:J00<005:JDYX00U:J00<0
05:JDYX00`0000@/1000;0@/10<002Aoo`03001oogoo00ioo`005Woo00@007oo000001=oo`<0035o
o`030015LP0000<00003BI8004VB0099TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00@0
04VBBI8000=9TP050019TTVBBI800002BI800`00BI99TP02BI801@00BI99TTVB00000dVB00@004VB
BI8000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VB00000P000dVc00D004Vc
BK=9/`0000=9/`030019/dVc0099/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D004Vc
BK=9/`0000A9/`060019/dVcBK<004Vc1@000TWD00D004WDBMA9e00000A9e0050019e4WDBM@00004
BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD00<004WDBM@00TWD0`0000==mP00COH00dgf00<0
04gfCOH00Tgf00D004gfCOI=mP0000A=mP03001=mTgf009=mP04001=mTgfCOH30002CQH00`00CQI>
5P03CQH01@00CQI>5ThF000014hF00<004hFCQH00ThF00<004hFCQH00`001E9H00D0059HDUQBF000
00EBF003001BF59H00@0009BVP03001BVU:J00=BVP04001BVU:JDYX40002Dad500000b00001oo`0T
Ool00`00Oomoo`0>Ool001Ioo`8001=oo`8003Aoo`800099TP040019TTVB0003BI801@00BI99TTVB
00000TVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VBBI99
TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP030019
TP0000<00099/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc00D004Vc
BK=9/`0000=9/`050019/dVcBK<00004BK<01@00BK=9/dVc00000TVc0`000TWD00<004WDBM@00TWD
00<004WDBM@00TWD00D004WDBMA9e00000=9e0030019e4WD0099e0050019e4WDBM@00004BM@01@00
BMA9e4WD00000TWD0`000dgf00<004gfCOH00Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000A=mP03
001=mTgf009=mP@00003CQH004hF00=>5P03001>5ThF009>5P03001>5ThF009>5P03001>5ThF009>
5P03001>5ThF00@0009BF003001BF59H00=BF005001BF59HDUP00004DUP40002DYX00`00DYYBVP02
DYX00`00DYYBVP02DYX40002Dad00`00DaeC7@02Dad5000VOol00`00Oomoo`0>Ool001Ioo`03001o
ogoo00moo`<003Ioo`050019TTVBBI800002BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP05
0019TTVBBI800002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003
BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP030019TP0000<00099/`050019/dVcBK<0
0003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`0000=9/`050019/dVcBK<0
0004BK<01@00BK=9/dVc00000dVc0`0000=9e000BM@00TWD00<004WDBM@00TWD00<004WDBM@00TWD
00D004WDBMA9e00000=9e0030019e4WD0099e0050019e4WDBM@00004BM@00`00BM@000040002COH0
0`00COI=mP02COH01@00COI=mTgf000014gf00D004gfCOI=mP0000E=mP03001=mP00008000A>5P03
001>5ThF009>5P03001>5ThF009>5P03001>5ThF009>5P04001>5ThFCQH40002DUP00`00DUQBF002
DUP00`00DUQBF002DUP00`00DUQBF002DUP400000e:J001BVP04DYX01P00DYYBVU:J001BVP<00003
Dad005<M00AC7@05001C7@000013W`03000WOol00`00Oomoo`0>Ool00003OomBU12400800003:DYc
W7oo00=oo`04F]H8@P00>Lh7Ool00`00Oomoo`0<Ool3000iOol01@00BI99TTVB00000TVB00D004VB
BI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB00000TVB00<004VBBI800TVB00@004VBBI80
00=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP030019TTVB00<0
0099/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`00
00=9/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01P00BK=9/dVc0019/`<000=9e0030019e4WD
0099e0030019e4WD0099e0050019e4WDBM@00003BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD
00<004WDBM@00`000Tgf00<004gfCOH00Tgf00<004gfCOH00Tgf00<004gfCOH00Tgf00D004gfCOI=
mP0000A=mP03001=mTgf00@0009>5P03001>5ThF00=>5P05001>5ThFCQH00004CQH00`00CQI>5P02
CQH01P00CQH00000DUP000EBF005001BF59HDUP00005DUP00`00DUP000020005DYX00`00DYYBVP02
DYX00`00DYYBVP030005Dad01000DaeC7E<M1`00:Woo00<007ooOol03Goo00000goo249BU002Ool0
0cW>6<Ioo`02Ool01V<H6<IcW7>L48ABU0Ioo`03001oogoo00Uoo`<003aoo`050019TTVBBI800002
BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP050019TTVBBI800003BI801@00BI99TTVB0000
0TVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000TVB00@004VBBI99
TP<00003BK<004Vc0099/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc
00D004VcBK=9/`0000=9/`050019/dVcBK<00004BK<01P00BK=9/dVc0019/`@00099e0050019e4WD
BM@00004BM@00`00BMA9e002BM@01@00BMA9e4WD00000dWD00D004WDBMA9e00000A9e0030019e4WD
0099e0<00003COH004gf00==mP03001=mTgf009=mP05001=mTgfCOH00004COH00`00COI=mP02COH0
0`00COI=mP040002CQH00`00CQI>5P02CQH00`00CQI>5P02CQH00`00CQI>5P02CQH00`00CQI>5P02
CQH00`00CQI>5P030004DUP00`00DUQBF002DUP01@00DUQBF59H00000e9H10000U:J00<005:JDYX0
0e:J00<005:JDYX00U:J0`000e<M00@005<MDaeC7@P000Aoo`03001oogoo02Moo`03001oogoo00eo
o`001Woo00H007ooOomoob48DY@2Ool00e:D6<Ioo`05Ool00`00Oomoo`06Ool3000oOol01@00BI99
TTVB00000TVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VB
BI99TP000099TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP000099TP03
0019TP00008000=9/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc00D0
04VcBK=9/`0000=9/`050019/dVcBK<00004BK<01@00BK=9/dVc00000TVc0`000TWD00D004WDBMA9
e00000A9e0050019e4WDBM@00004BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD00<004WDBM@0
0TWD00<004WD00000P000dgf00<004gfCOH00Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000A=mP03
001=mTgf009=mP<00003CQH004hF00=>5P03001>5ThF009>5P03001>5ThF009>5P03001>5ThF009>
5P04001>5ThFCQH40002DUP00`00DUQBF002DUP00`00DUQBF002DUP01000DUQBF59H10000U:J00<0
05:JDYX00U:J00<005:JDYX00U:J00<005:J00000P0000=C7@00Dad00e<M10000T>O0`0027oo00<0
07ooOol09Woo00<007ooOol03Goo0005Ool00cW>48Aoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool20004Ool30012Ool01@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP040019TTVB0003BI80
1@00BI99TTVB00000dVB00D004VBBI99TP000099TP050019TTVBBI800003BI801@00BI99TTVB0000
0dVB00H004VBBI99TP00BI830002BK<01@00BK=9/dVc00000dVc00<004VcBK<00TVc00D004VcBK=9
/`0000=9/`050019/dVcBK<00003BK<01@00BK=9/dVc000014Vc00D004VcBK=9/`0000=9/`<00003
BM@004WD0099e0050019e4WDBM@00004BM@01@00BMA9e4WD000014WD00D004WDBMA9e00000=9e003
0019e4WD0099e0030019e4WD00@0009=mP03001=mTgf009=mP05001=mTgfCOH00004COH01@00COI=
mTgf00001Dgf00<004gf00000P0014hF00<004hFCQH00ThF00<004hFCQH00ThF00D004hFCQI>5P00
00A>5P06001>5P00001BF0001E9H00D0059HDUQBF00000EBF0<00003DYX005:J00ABVP03001BVU:J
009BVP03001BVU:J00<000EC7@04001C7@000002@il4000;Ool00`00Oomoo`0VOol00`00Oomoo`0=
Ool000=oo`0448@00000F]H3Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool30015Ool01@00
BI99TTVB00000TVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB00000dVB00D0
04VBBI99TP000099TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VBBI800`0000=9
/`00BK<00TVc00D004VcBK=9/`0000A9/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D0
04VcBK=9/`0000A9/`050019/dVcBK<00003BK<00`00BK<000020003BM@01@00BMA9e4WD000014WD
00D004WDBMA9e00000A9e0050019e4WDBM@00003BM@00`00BMA9e002BM@00`00BMA9e0040002COH0
1@00COI=mTgf000014gf00<004gfCOH00Tgf00D004gfCOI=mP0000A=mP03001=mTgf00@0009>5P03
001>5ThF009>5P03001>5ThF009>5P03001>5ThF009>5P03001>5ThF009>5P03001>5ThF00<000AB
F003001BF59H009BF003001BF59H009BF003001BF59H00<000ABVP03001BVU:J009BVP04001BVU:J
DYX40003Dad01000DaeC7E<M0`0000=3W`0000000P003goo00<007ooOol09Goo00<007ooOol03Goo
0004Ool00g>L>LhHaP03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool40018Ool01@00BI99TTVB0000
0TVB00D004VBBI99TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00D004VBBI99
TP000099TP050019TTVBBI800003BI801@00BI99TTVB00000dVB0`0000E9/`00BK=9/`0000=9/`03
0019/dVc0099/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`0000=9/`03
0019/dVc0099/`060019/dVcBK<004Vc10000TWD00D004WDBMA9e00000A9e0050019e4WDBM@00003
BM@00`00BMA9e002BM@01@00BMA9e4WD000014WD00@004WDBMA9e0<00003COH004gf00==mP03001=
mTgf009=mP05001=mTgfCOH00004COH01@00COI=mTgf00000dgf10000ThF00D004hFCQI>5P0000A>
5P03001>5ThF009>5P03001>5ThF009>5P03001>5ThF00D0009BF003001BF59H009BF003001BF59H
009BF004001BF59HDUP40002DYX00`00DYYBVP02DYX00`00DYYBVP02DYX40002Dad00`00DaeC7@02
Dad4000014>O0000000057oo00<007ooOol097oo00<007ooOol03Goo0006Ool01P00Oomoogoo8@QB
U09oo`03DY@Q27oo00Aoo`8004Yoo`050019TTVBBI800002BI801@00BI99TTVB00000dVB00D004VB
BI99TP000099TP050019TTVBBI800003BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP06
0019TTVBBI8004VB0`000dVc00@004VcBK<000=9/`030019/dVc0099/`050019/dVcBK<00003BK<0
1@00BK=9/dVc00000dVc00D004VcBK=9/`0000A9/`060019/dVcBK<004Vc10000TWD00D004WDBMA9
e00000A9e0050019e4WDBM@00003BM@01@00BMA9e4WD000014WD00<004WDBM@00TWD00H004WDBMA9
e000BM@30004COH00`00COI=mP02COH01@00COI=mTgf00000dgf00<004gfCOH00Tgf00<004gfCOH0
0Tgf0`0000=>5P00CQH00dhF00<004hFCQH00ThF00<004hFCQH00ThF00D004hFCQI>5P0000A>5P<0
009BF003001BF59H00=BF005001BF59HDUP00005DUP300000e:J001BVP04DYX01P00DYYBVU:J001B
VP<00003Dad005<M00AC7@05001C7@000013W`04000HOol00`00Oomoo`0SOol00`00Oomoo`0=Ool0
0003Ool@Q48@009oo`03<H`HaWoo009oo`06HaPHaW>LLi`HaV<H1goo00<007ooOol0Agoo00D004VB
BI99TP000099TP050019TTVBBI800003BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP05
0019TTVBBI800002BI801@00BI99TTVB00000dVB00<004VB00000`000TVc00D004VcBK=9/`000099
/`030019/dVc0099/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`0000A9
/`050019/dVcBK<00002BK<30002BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD00D004WDBMA9
e00000=9e0050019e4WDBM@00004BM@00`00BMA9e002BM@00`00BM@000030002COH00`00COI=mP02
COH00`00COI=mP02COH01@00COI=mTgf00000dgf00<004gfCOH00dgf00<004gf00000P0014hF00<0
04hFCQH00ThF00D004hFCQI>5P0000A>5P03001>5ThF009>5P@00003DUP0059H00=BF003001BF59H
009BF003001BF59H009BF003001BF59H00<000ABVP03001BVU:J009BVP03001BVU:J00<000EC7@04
001C7E<MDad6000LOol00`00Oomoo`0TOol00`00Oomoo`0<Ool00003OomJeR48008000038@QcW7oo
00=oo`04F]H8@PQ2HaP9Ool00`00Oomoo`16Ool01@00BI99TTVB00000TVB00D004VBBI99TP0000=9
TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00D004VBBI99TP000099TP060019TTVBBI80
04VB10000TVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D0
04VcBK=9/`0000=9/`030019/dVc0099/`050019/dVcBK<00003BK<300000dWD0019e002BM@01@00
BMA9e4WD000014WD00D004WDBMA9e00000=9e0050019e4WDBM@00003BM@00`00BMA9e003BM@00`00
BM@000030002COH01@00COI=mTgf000014gf00<004gfCOH00Tgf00D004gfCOI=mP0000A=mP03001=
mTgf00@0009>5P03001>5ThF009>5P03001>5ThF009>5P05001>5ThFCQH00004CQH00`00CQI>5P03
0005DUP01@00DUQBF59H0000159H00<0059HDUP01@000U:J00<005:JDYX00U:J00@005:JDYYBVP@0
00=C7@04001C7E<MDad8000POol00`00Oomoo`0SOol00`00Oomoo`0<Ool001Uoo`03001oogoo04Eo
o`050019TTVBBI800003BI801000BI99TP000dVB00D004VBBI99TP000099TP050019TTVBBI800003
BI801@00BI99TTVB00000TVB00<004VB00000`000TVc00D004VcBK=9/`0000=9/`050019/dVcBK<0
0003BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`0000=9/`050019/dVcBK<00004BK<01P00BK=9
/dVc0019/`<000=9e0050019e4WDBM@00004BM@01@00BMA9e4WD00000dWD00D004WDBMA9e00000=9
e0030019e4WD0099e0040019e4WDBM@30002COH01@00COI=mTgf000014gf00<004gfCOH00Tgf00D0
04gfCOI=mP0000==mP04001=mTgfCOH40002CQH01@00CQI>5ThF000014hF00<004hFCQH00ThF00<0
04hFCQH00ThF00<004hFCQH010000U9H00<0059HDUP00e9H00D0059HDUQBF00000ABF0<0009BVP03
001BVU:J00=BVP04001BVU:JDYX40002Dad00`00DaeC7@02Dad40002@il3000TOol00`00Oomoo`0R
Ool00`00Oomoo`0<Ool001Yoo`8004Eoo`050019TTVBBI800003BI801000BI99TP000dVB00D004VB
BI99TP000099TP050019TTVBBI800003BI801P00BI99TTVB0019TP<00099/`050019/dVcBK<00003
BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01@00BK=9/dVc
000014Vc00H004VcBK=9/`00BK<40002BM@01@00BMA9e4WD000014WD00D004WDBMA9e00000=9e005
0019e4WDBM@00003BM@00`00BMA9e002BM@01000BMA9e4WD100000==mP00COH00Tgf00<004gfCOH0
0Tgf00D004gfCOI=mP0000A=mP05001=mTgfCOH00004COH300000dhF001>5P03CQH00`00CQI>5P02
CQH00`00CQI>5P02CQH01@00CQI>5ThF00000dhF10000U9H00<0059HDUP00U9H00<0059HDUP00U9H
00<0059HDUP00U9H100000=BVP00DYX00e:J00<005:JDYX00U:J00H005:J000005<M0005Dad01@00
Dad00000@il01@00:7oo00<007ooOol08Goo00<007ooOol037oo000LOol00`00Oomoo`12Ool01@00
BI99TTVB00000dVB00@004VBBI8000=9TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00@0
04VBBI99TP800003BK<004Vc0099/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D004Vc
BK=9/`0000=9/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000TVc0`000TWD
00D004WDBMA9e00000A9e0050019e4WDBM@00003BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD
00H004WDBMA9e000BM@30004COH00`00COI=mP02COH01@00COI=mTgf00000dgf00<004gfCOH00Tgf
00<004gfCOH00Tgf00<004gf00000P0014hF00<004hFCQH00ThF00D004hFCQI>5P0000A>5P03001>
5ThF009>5P<00003DUP0059H00ABF005001BF59HDUP00005DUP00`00DUP000020005DYX01@00DYYB
VU:J00000e:J0`0015<M00@005<MDaeC7@H002eoo`03001oogoo025oo`03001oogoo00aoo`007Goo
00<007ooOol0@Goo00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB00000TVB00D0
04VBBI99TP0000=9TP030019TP0000800099/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc
00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<00`00BK=9/`02BK<01@00BK=9/dVc00000dVc
0`0000=9e000BM@00TWD00D004WDBMA9e00000A9e0050019e4WDBM@00003BM@01@00BMA9e4WD0000
0dWD00<004WDBM@00TWD00<004WD00000`000Tgf00<004gfCOH00dgf00D004gfCOI=mP0000==mP05
001=mTgfCOH00005COH00`00COH000030002CQH00`00CQI>5P02CQH00`00CQI>5P02CQH01@00CQI>
5ThF000014hF00<004hFCQH00`00159H00<0059HDUP00U9H00D0059HDUQBF00000=BF0@0009BVP03
001BVU:J00=BVP04001BVU:JDYX40003Dad00`00DaeC7@08000aOol00`00Oomoo`0POol00`00Oomo
o`0<Ool001ioo`03001oogoo041oo`050019TTVBBI800003BI801000BI99TP000dVB00D004VBBI99
TP000099TP060019TTVBBI8004VB10000TVc00@004VcBK<000=9/`030019/dVc0099/`040019/dVc
0003BK<00`00BK=9/`02BK<01000BK=9/`000dVc00<004VcBK<00TVc00D004VcBK=9/`0000=9/`03
0019/`00008000=9e0050019e4WDBM@00004BM@01@00BMA9e4WD00000dWD00D004WDBMA9e00000=9
e0030019e4WD0099e0030019e4WD00<0009=mP03001=mTgf009=mP03001=mTgf009=mP05001=mTgf
COH00003COH01@00COI=mTgf000014gf0`000ThF00D004hFCQI>5P0000A>5P03001>5ThF009>5P03
001>5ThF009>5P03001>5ThF00@0009BF003001BF59H009BF003001BF59H009BF004001BF59HDUP4
0002DYX00`00DYYBVP02DYX00`00DYYBVP02DYX01P00DYX00000Dad000EC7@<00093W`<003Eoo`03
001oogoo01moo`03001oogoo00aoo`007goo0P00@7oo00D004VBBI99TP0000=9TP040019TTVB0003
BI801@00BI99TTVB00000TVB00<004VB00000`000TVc00D004VcBK=9/`000099/`030019/dVc0099
/`050019/dVcBK<00002BK<00`00BK=9/`02BK<01@00BK=9/dVc00000TVc00D004VcBK=9/`0000A9
/`060019/dVcBK<004Vc10000TWD00D004WDBMA9e00000A9e0050019e4WDBM@00003BM@01@00BMA9
e4WD00000dWD00<004WDBM@00TWD00@004WDBMA9e0<00003COH004gf00==mP05001=mTgfCOH00004
COH01@00COI=mTgf00000dgf00<004gfCOH00Tgf100000=>5P00CQH00ThF00<004hFCQH00ThF00<0
04hFCQH00ThF00D004hFCQI>5P0000=>5P@0009BF003001BF59H009BF003001BF59H009BF003001B
F59H009BF0<00003DYX005:J00ABVP03001BVU:J009BVP03001BVU:J00<000AC7@03001C7@000080
0003@il00000008003Qoo`03001oogoo021oo`03001oogoo00]oo`008Goo00<007ooOol0?Goo00D0
04VBBI99TP0000=9TP040019TTVB0003BI801P00BI99TTVB0019TP<00099/`050019/dVcBK<00003
BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`000099/`030019/dVc0099/`050019/dVcBK<00002
BK<00`00BK=9/`02BK<01P00BK=9/dVc0019/`@00099e0050019e4WDBM@00004BM@01@00BMA9e4WD
00000dWD00D004WDBMA9e00000=9e0030019e4WD0099e0060019e4WDBM@004WD0`000dgf00<004gf
COH00Tgf00D004gfCOI=mP0000A=mP05001=mTgfCOH00004COH00`00COH000020004CQH00`00CQI>
5P02CQH01@00CQI>5ThF000014hF00<004hFCQH00ThF0`0000=BF000DUP0159H00D0059HDUQBF000
00ABF003001BF59H00<000ABVP03001BVU:J009BVP04001BVU:JDYX40003Dad00`00DaeC7@07000m
Ool00`00Oomoo`0OOol00`00Oomoo`0;Ool0029oo`03001oogoo03aoo`050019TTVBBI800003BI80
1000BI99TP000dVB00@004VBBI99TP800003BK<004Vc0099/`050019/dVcBK<00003BK<01@00BK=9
/dVc00000dVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00<0
04VcBK<00`000TWD00D004WDBMA9e00000=9e0030019e4WD0099e0050019e4WDBM@00003BM@01@00
BMA9e4WD00000dWD00<004WDBM@00TWD00<004WD00000`000Tgf00<004gfCOH00Tgf00D004gfCOI=
mP0000A=mP05001=mTgfCOH00004COH00`00COH000030002CQH00`00CQI>5P03CQH01@00CQI>5ThF
00000dhF00<004hFCQH00ThF00<004hFCQH00`00159H00<0059HDUP00U9H00D0059HDUQBF00000=B
F0@0009BVP03001BVU:J00=BVP03001BVU:J00D000=C7@03001C7E<M00@00004@il000000011Ool0
0`00Oomoo`0NOol00`00Oomoo`0;Ool002=oo`03001oogoo03]oo`050019TTVBBI800003BI801000
BI99TP000dVB00<004VB00000P000TVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01@00
BK=9/dVc00000dVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01000BK=9/dVc0`0000=9
e000BM@00TWD00D004WDBMA9e00000A9e0050019e4WDBM@00003BM@01@00BMA9e4WD00000dWD00<0
04WDBM@00TWD00<004WDBM@00`000Tgf00D004gfCOI=mP0000A=mP03001=mTgf009=mP05001=mTgf
COH00004COH00`00COH000030002CQH00`00CQI>5P02CQH00`00CQI>5P02CQH01@00CQI>5ThF0000
14hF00<004hFCQH010000U9H00<0059HDUP00U9H00<0059HDUP00U9H00@0059HDUQBF0@0009BVP03
001BVU:J009BVP03001BVU:J009BVP<0009C7@03001C7E<M00=C7@<00093W`<004Eoo`03001oogoo
01eoo`03001oogoo00]oo`0097oo00<007ooOol0>Woo00D004VBBI99TP0000=9TP050019TTVB0019
TP040002BK<01000BK=9/`000dVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01@00BK=9
/dVc00000dVc00D004VcBK=9/`0000=9/`060019/dVcBK<004Vc0`000dWD00D004WDBMA9e00000A9
e0050019e4WDBM@00003BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD00@004WDBMA9e0<00003
COH004gf009=mP03001=mTgf009=mP05001=mTgfCOH00004COH01@00COI=mTgf00000dgf0`000ThF
00<004hFCQH00ThF00D004hFCQI>5P0000A>5P05001>5ThFCQH00003CQH40002DUP00`00DUQBF002
DUP00`00DUQBF002DUP00`00DUQBF002DUP300000e:J001BVP04DYX01P00DYYBVU:J001BVP<00003
Dad005<M00=C7@03001C7@0000800003@il00000008004Qoo`03001oogoo01eoo`03001oogoo00]o
o`009Goo0P00>Woo00D004VBBI99TP0000=9TP030019TP0000800099/`050019/dVcBK<00002BK<0
0`00BK=9/`02BK<01000BK=9/`000dVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01@00
BK=9/dVc00000dVc00<004Vc00000`000TWD00D004WDBMA9e00000A9e0050019e4WDBM@00003BM@0
1@00BMA9e4WD00000dWD00<004WDBM@00TWD00H004WDBMA9e000BM@30003COH00`00COI=mP02COH0
1@00COI=mTgf00000dgf00<004gfCOH00Tgf00<004gfCOH00Tgf0`0000=>5P00CQH00ThF00<004hF
CQH00ThF00<004hFCQH00ThF00D004hFCQI>5P0000A>5P<00003DUP0059H00ABF005001BF59HDUP0
0004DUP00`00DUQBF0030004DYX00`00DYYBVP02DYX00`00DYYBVP030005Dad00`00DaeC7@07001=
Ool00`00Oomoo`0LOol00`00Oomoo`0;Ool002Moo`03001oogoo03Moo`060019TTVBBI8004VB1000
00=9/`00BK<00TVc00D004VcBK=9/`0000=9/`050019/dVcBK<00002BK<00`00BK=9/`02BK<01000
BK=9/`000dVc00D004VcBK=9/`0000=9/`060019/dVcBK<004Vc10000TWD00D004WDBMA9e00000A9
e0050019e4WDBM@00003BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD00H004WDBMA9e000BM@4
0002COH00`00COI=mP02COH01@00COI=mTgf00000dgf00D004gfCOI=mP0000E=mP03001=mP000080
00=>5P03001>5ThF009>5P03001>5ThF009>5P05001>5ThFCQH00004CQH00`00CQH000020004DUP0
0`00DUQBF002DUP01@00DUQBF59H00000e9H10000U:J00<005:JDYX00e:J00<005:JDYX010000e<M
00@005<MDaeC7@@00004@il00000001AOol00`00Oomoo`0KOol00`00Oomoo`0;Ool002Qoo`03001o
ogoo03Ioo`030019TTVB00<00099/`040019/dVc0003BK<01@00BK=9/dVc00000dVc00D004VcBK=9
/`000099/`030019/dVc0099/`040019/dVc0003BK<00`00BK=9/`02BK<01000BK=9/`000TVc0`00
0TWD00D004WDBMA9e00000=9e0030019e4WD0099e0050019e4WDBM@00003BM@01@00BMA9e4WD0000
0dWD00<004WDBM@00TWD00<004WD00000`000Tgf00D004gfCOI=mP0000A=mP05001=mTgfCOH00003
COH00`00COI=mP02COH00`00COI=mP040002CQH00`00CQI>5P02CQH01@00CQI>5ThF000014hF00D0
04hFCQI>5P00009>5P@0009BF003001BF59H009BF003001BF59H009BF003001BF59H00D0009BVP03
001BVU:J009BVP03001BVU:J009BVP<0009C7@03001C7E<M009C7@@00093W`<005Eoo`03001oogoo
01]oo`03001oogoo00Yoo`00:Goo00<007ooOol0=Goo0`0000=9/`00BK<00TVc00@004VcBK<000=9
/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`000099/`030019/dVc0099
/`050019/dVcBK<00002BK<300000dWD0019e002BM@01@00BMA9e4WD000014WD00D004WDBMA9e000
00=9e0050019e4WDBM@00003BM@00`00BMA9e002BM@00`00BMA9e0030002COH01@00COI=mTgf0000
14gf00D004gfCOI=mP0000==mP05001=mTgfCOH00003COH40002CQH01@00CQI>5ThF000014hF00D0
04hFCQI>5P0000A>5P03001>5ThF00@0009BF003001BF59H009BF003001BF59H009BF004001BF59H
DUP30002DYX00`00DYYBVP03DYX01P00DYYBVU:J001BVP<00003Dad005<M00=C7@05001C7@000013
W`05001HOol00`00Oomoo`0KOol00`00Oomoo`0:Ool002Yoo`8003Eoo`050019/dVcBK<00003BK<0
1000BK=9/`000dVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc
00D004VcBK=9/`0000=9/`040019/`000003BM@01@00BMA9e4WD000014WD00D004WDBMA9e00000=9
e0050019e4WDBM@00003BM@00`00BMA9e002BM@01000BMA9e4WD0`0000==mP00COH00Tgf00<004gf
COH00Tgf00D004gfCOI=mP0000==mP05001=mTgfCOH00004COH300000dhF001>5P03CQH00`00CQI>
5P02CQH01@00CQI>5ThF00000dhF00<004hFCQH00ThF0`000U9H00<0059HDUP00U9H00D0059HDUQB
F00000ABF006001BF000001BVP0015:J00<005:JDYX00U:J00<005:JDYX00`001E<M00<005<MDad0
1P00GWoo00<007ooOol06Woo00<007ooOol02Woo000/Ool00`00Oomoo`0bOol01@00BK=9/dVc0000
0dVc00D004VcBK=9/`000099/`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D004VcBK=9
/`0000=9/`060019/dVcBK<004Vc100000=9e000BM@00TWD00<004WDBM@00TWD00D004WDBMA9e000
00=9e0050019e4WDBM@00003BM@00`00BMA9e002BM@01P00BMA9e4WD0019e0<000==mP03001=mTgf
009=mP05001=mTgfCOH00003COH01@00COI=mTgf000014gf00<004gf00000P0014hF00<004hFCQH0
0ThF00D004hFCQI>5P0000=>5P03001>5ThF009>5P@00003DUP0059H00=BF005001BF59HDUP00003
DUP01000DUQBF59H0`0015:J00<005:JDYX00U:J00<005:JDYX010000e<M00@005<MDaeC7@L0069o
o`03001oogoo01Uoo`03001oogoo00Yoo`00;Goo00<007ooOol0<Goo00D004VcBK=9/`0000=9/`05
0019/dVcBK<00002BK<00`00BK=9/`02BK<01000BK=9/`000dVc00D004VcBK=9/`0000=9/`060019
/dVcBK<004Vc10000TWD00@004WDBM@000A9e0050019e4WDBM@00003BM@01@00BMA9e4WD00000dWD
00<004WDBM@00TWD00H004WDBMA9e000BM@40002COH00`00COI=mP02COH01@00COI=mTgf00000dgf
00D004gfCOI=mP0000A=mP03001=mP0000<0009>5P03001>5ThF009>5P03001>5ThF009>5P05001>
5ThFCQH00004CQH00`00CQH000020005DUP01@00DUQBF59H00000e9H00<0059HDUP01@000U:J00<0
05:JDYX00U:J00<005:JDYX00U:J0`000e<M00<005<MDad02@00IGoo00<007ooOol06Goo00<007oo
Ool02Woo000^Ool00`00Oomoo`0`Ool01@00BK=9/dVc00000dVc00D004VcBK=9/`0000=9/`050019
/dVcBK<00002BK<01@00BK=9/dVc00000dVc00H004VcBK=9/`00BK<40002BM@01@00BMA9e4WD0000
0TWD00<004WDBM@00TWD00D004WDBMA9e00000=9e0050019e4WDBM@00003BM@00`00BMA9e002BM@0
0`00BM@000030002COH01@00COI=mTgf000014gf00D004gfCOI=mP0000==mP03001=mTgf009=mP03
001=mP0000<0009>5P03001>5ThF009>5P05001>5ThFCQH00004CQH00`00CQI>5P02CQH00`00CQH0
00030002DUP00`00DUQBF003DUP01@00DUQBF59H00000e9H0`000U:J00<005:JDYX00e:J00H005:J
DYYBVP00DYX300000e<M001C7@03Dad30002@il3001ZOol00`00Oomoo`0HOol00`00Oomoo`0:Ool0
02moo`80031oo`050019/dVcBK<00003BK<01@00BK=9/dVc00000dVc00D004VcBK=9/`000099/`03
0019/dVc0099/`040019/dVc0002BK<30002BM@01@00BMA9e4WD00000dWD00D004WDBMA9e00000=9
e0050019e4WDBM@00003BM@01@00BMA9e4WD000014WD00<004WDBM@00`000Tgf00D004gfCOI=mP00
00A=mP05001=mTgfCOH00003COH01@00COI=mTgf00000dgf0`000ThF00D004hFCQI>5P0000A>5P03
001>5ThF009>5P05001>5ThFCQH00003CQH30002DUP00`00DUQBF002DUP00`00DUQBF002DUP00`00
DUQBF002DUP300000e:J001BVP03DYX00`00DYYBVP02DYX00`00DYYBVP030005Dad01@00Dad00000
@il01000KWoo00<007ooOol05goo00<007ooOol02Woo000aOol00`00Oomoo`0^Ool01000BK=9/`00
0dVc00D004VcBK=9/`0000=9/`050019/dVcBK<00003BK<01@00BK=9/dVc00000TVc0`0000=9e000
BM@00TWD00D004WDBMA9e00000=9e0050019e4WDBM@00003BM@01@00BMA9e4WD00000dWD00<004WD
BM@00TWD00@004WDBMA9e0<00003COH004gf009=mP03001=mTgf009=mP05001=mTgfCOH00003COH0
1@00COI=mTgf000014gf0`0000=>5P00CQH00ThF00<004hFCQH00ThF00<004hFCQH00ThF00D004hF
CQI>5P0000A>5P<00003DUP0059H00=BF003001BF59H009BF003001BF59H009BF003001BF0000080
00ABVP03001BVU:J009BVP03001BVU:J00@000=C7@04001C7E<MDad7001bOol00`00Oomoo`0GOol0
0`00Oomoo`09Ool0039oo`03001oogoo02eoo`040019/dVc0004BK<01000BK=9/`000dVc00D004Vc
BK=9/`0000=9/`060019/dVcBK<004Vc0P000dWD00D004WDBMA9e00000A9e0040019e4WD0003BM@0
1@00BMA9e4WD00000dWD00<004WDBM@00TWD00H004WDBMA9e000BM@30003COH00`00COI=mP02COH0
1@00COI=mTgf00000dgf00D004gfCOI=mP0000A=mP03001=mP00008000=>5P03001>5ThF009>5P05
001>5ThFCQH00004CQH01@00CQI>5ThF00000ThF0`00159H00D0059HDUQBF00000ABF003001BF59H
00@0009BVP03001BVU:J009BVP04001BVU:JDYX40003Dad00`00DaeC7@09001eOol00`00Oomoo`0G
Ool00`00Oomoo`09Ool003=oo`03001oogoo02aoo`050019/dVcBK<00003BK<01000BK=9/`000dVc
00D004VcBK=9/`0000=9/`030019/`0000<00003BM@004WD0099e0030019e4WD0099e0050019e4WD
BM@00002BM@01@00BMA9e4WD00000dWD00<004WDBM@00TWD00H004WDBMA9e000BM@40002COH00`00
COI=mP02COH01@00COI=mTgf00000dgf00D004gfCOI=mP0000A=mP03001=mP0000<0009>5P03001>
5ThF009>5P05001>5ThFCQH00003CQH00`00CQI>5P02CQH00`00CQI>5P040002DUP00`00DUQBF002
DUP01@00DUQBF59H00000e9H10000U:J00<005:JDYX00U:J00@005:JDYYBVP@0009C7@03001C7E<M
009C7@<00093W`@007Uoo`03001oogoo01Ioo`03001oogoo00Uoo`00=7oo0P00;7oo00D004VcBK=9
/`0000=9/`040019/dVc0003BK<01P00BK=9/dVc0019/`@00099e0040019e4WD0004BM@01@00BMA9
e4WD00000dWD00D004WDBMA9e0000099e0030019e4WD0099e0060019e4WDBM@004WD10000Tgf00D0
04gfCOI=mP0000A=mP05001=mTgfCOH00003COH00`00COI=mP02COH00`00COH000030002CQH01@00
CQI>5ThF000014hF00D004hFCQI>5P0000A>5P03001>5ThF00@0009BF003001BF59H009BF005001B
F59HDUP00003DUP40002DYX00`00DYYBVP02DYX01P00DYYBVU:J001BVP80009C7@03001C7E<M009C
7@05001C7@000013W`04001nOol00`00Oomoo`0EOol00`00Oomoo`09Ool003Ioo`03001oogoo02Uo
o`050019/dVcBK<00003BK<01@00BK=9/dVc00000TVc00<004Vc00000`000TWD00D004WDBMA9e000
0099e0030019e4WD0099e0050019e4WDBM@00003BM@01@00BMA9e4WD00000TWD00<004WDBM@00TWD
00<004WD00000`000Tgf00D004gfCOI=mP0000A=mP05001=mTgfCOH00003COH01@00COI=mTgf0000
0dgf0`000ThF00D004hFCQI>5P0000A>5P05001>5ThFCQH00003CQH01000CQI>5ThF10000U9H00<0
059HDUP00U9H00D0059HDUQBF00000ABF0<00003DYX005:J00ABVP05001BVU:JDYX00002DYX30005
Dad00`00DaeC7@060023Ool00`00Oomoo`0DOol00`00Oomoo`09Ool003Moo`03001oogoo02Qoo`05
0019/dVcBK<00003BK<01P00BK=9/dVc0019/`<00099e0050019e4WDBM@00003BM@01@00BMA9e4WD
00000dWD00D004WDBMA9e00000=9e0050019e4WDBM@00003BM@00`00BMA9e0030002COH01@00COI=
mTgf000014gf00D004gfCOI=mP0000==mP05001=mTgfCOH00004COH300000dhF001>5P02CQH00`00
CQI>5P02CQH01@00CQI>5ThF00000dhF00<004hFCQH00ThF0`0000=BF000DUP0159H00D0059HDUQB
F00000=BF003001BF59H00<000ABVP03001BVU:J009BVP03001BVU:J00@000=C7@04001C7E<MDad7
0026Ool00`00Oomoo`0DOol00`00Oomoo`09Ool003Qoo`03001oogoo02Moo`050019/dVcBK<00003
BK<01000BK=9/dVc0P0000=9e000BM@00TWD00D004WDBMA9e00000=9e0050019e4WDBM@00003BM@0
1@00BMA9e4WD00000dWD00D004WDBMA9e00000=9e0<00003COH004gf009=mP03001=mTgf009=mP05
001=mTgfCOH00003COH01@00COI=mTgf000014gf00<004gf00000P000dhF00<004hFCQH00ThF00D0
04hFCQI>5P0000=>5P03001>5ThF009>5P03001>5P00008000ABF003001BF59H009BF005001BF59H
DUP00002DUP40002DYX00`00DYYBVP03DYX01000DYYBVU:J0`000e<M00<005<MDad01@0000A3W`00
000008Yoo`03001oogoo01=oo`03001oogoo00Uoo`00>Goo0P00:7oo00@004VcBK<000=9/`030019
/`0000800099e0050019e4WDBM@00004BM@01000BMA9e0000dWD00D004WDBMA9e00000=9e0030019
e4WD0099e0050019e4WD0019e0030003COH00`00COI=mP02COH01@00COI=mTgf00000dgf00D004gf
COI=mP0000A=mP03001=mP0000<0009>5P03001>5ThF009>5P05001>5ThFCQH00003CQH00`00CQI>
5P02CQH00`00CQH000030002DUP00`00DUQBF002DUP00`00DUQBF002DUP00`00DUQBF0040002DYX0
0`00DYYBVP02DYX00`00DYYBVP02DYX01P00DYX00000Dad000AC7@<000=3W`<008ioo`03001oogoo
01=oo`03001oogoo00Qoo`00>goo00<007ooOol09Goo00D004VcBK<004Vc00@00099e0040019e4WD
0004BM@01@00BMA9e4WD00000TWD00D004WDBMA9e00000=9e0030019e4WD0099e0060019e4WDBM@0
04WD0`000Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000==mP05001=mTgfCOH00004COH00`00COH0
00030002CQH01@00CQI>5ThF000014hF00D004hFCQI>5P0000A>5P03001>5P0000<0009BF003001B
F59H009BF003001BF59H009BF004001BF59HDUP30002DYX00`00DYYBVP02DYX01@00DYYBVU:J0000
0e:J0`0015<M00D005<M000004>O00D0095oo`03001oogoo01=oo`03001oogoo00Qoo`00?7oo00<0
07ooOol097oo00<004Vc00000P000TWD00D004WDBMA9e00000=9e0050019e4WDBM@00003BM@01@00
BMA9e4WD00000TWD00<004WDBM@00TWD00H004WDBMA9e000BM@400000dgf001=mP02COH00`00COI=
mP02COH01@00COI=mTgf00000dgf00<004gfCOH00Tgf00<004gf00000`000ThF00D004hFCQI>5P00
00A>5P05001>5ThFCQH00004CQH00`00CQH000030002DUP00`00DUQBF002DUP00`00DUQBF002DUP0
1P00DUQBF59H001BF0800003DYX005:J00=BVP05001BVU:JDYX00002DYX50003Dad00`00DaeC7@06
002GOol00`00Oomoo`0BOol00`00Oomoo`08Ool003eoo`03001oogoo02=oo`800003BM@004WD0099
e0050019e4WDBM@00003BM@01@00BMA9e4WD00000dWD00D004WDBMA9e0000099e0030019e4WD0099
e0030019e00000<0009=mP04001=mTgf0004COH01@00COI=mTgf00000dgf00D004gfCOI=mP0000==
mP<0009>5P05001>5ThFCQH00004CQH01@00CQI>5ThF00000dhF00@004hFCQI>5P<0009BF003001B
F59H009BF005001BF59HDUP00004DUP00`00DUQBF0030004DYX01@00DYYBVU:J00000U:J100015<M
00<005<MDad01`00Vgoo00<007ooOol04Goo00<007ooOol027oo000nOol00`00Oomoo`0ROol01000
BMA9e0000dWD00D004WDBMA9e00000=9e0050019e4WDBM@00003BM@01@00BMA9e4WD00000dWD00<0
04WDBM@00`000Tgf00D004gfCOI=mP0000==mP05001=mTgfCOH00003COH01@00COI=mTgf000014gf
0`0000=>5P00CQH00ThF00<004hFCQH00ThF00D004hFCQI>5P0000=>5P03001>5ThF009>5P<00003
DUP0059H00=BF005001BF59HDUP00003DUP01000DUQBF59H10000U:J00<005:JDYX00U:J00@005:J
DYYBVP<000AC7@03001C7E<M00@00004@il00000002OOol00`00Oomoo`0@Ool00`00Oomoo`08Ool0
03moo`80029oo`040019e4WD0004BM@01000BMA9e0000dWD00D004WDBMA9e00000=9e0050019e4WD
BM@00003BM@300000dgf001=mP02COH00`00COI=mP02COH01000COI=mP000dgf00D004gfCOI=mP00
00A=mP03001=mP00008000=>5P03001>5ThF009>5P05001>5ThFCQH00003CQH00`00CQI>5P02CQH0
0`00CQH000020004DUP01@00DUQBF59H00000e9H00<0059HDUP01@000U:J00<005:JDYX00U:J00H0
05:JDYYBVP00DYX200000e<M001C7@04Dad30002@il3002ROol00`00Oomoo`0@Ool00`00Oomoo`08
Ool0045oo`03001oogoo01moo`050019e4WDBM@00003BM@01000BMA9e0000dWD00D004WDBMA9e000
00A9e0050019e4WD0019e0030003COH00`00COI=mP02COH01@00COI=mTgf00000Tgf00D004gfCOI=
mP0000A=mP03001=mP0000<0009>5P03001>5ThF009>5P05001>5ThFCQH00003CQH00`00CQI>5P02
CQH00`00CQH000030002DUP00`00DUQBF002DUP01@00DUQBF59H00000e9H0`000U:J00<005:JDYX0
0e:J00D005:JDYYBVP00009BVP<000AC7@03001C7@0000800003@il0000000800:Ioo`03001oogoo
00moo`03001oogoo00Qoo`00@Woo00<007ooOol07Woo00D004WDBMA9e00000=9e0050019e4WDBM@0
0002BM@00`00BMA9e002BM@01P00BMA9e4WD0019e0<0009=mP03001=mTgf009=mP05001=mTgfCOH0
0003COH01000COI=mP0014gf00<004gf00000`000ThF00D004hFCQI>5P0000A>5P05001>5ThFCQH0
0004CQH00`00CQH000030002DUP00`00DUQBF002DUP01@00DUQBF59H0000159H0`0000=BVP00DYX0
0e:J00<005:JDYX00U:J00<005:JDYX010000e<M00<005<MDad01`00Zgoo00<007ooOol03goo00<0
07ooOol01goo0013Ool00`00Oomoo`0MOol01@00BMA9e4WD00000dWD00D004WDBMA9e00000=9e006
0019e4WDBM@004WD100000==mP00COH00Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000==mP06001=
mTgfCOH004gf10000ThF00D004hFCQI>5P0000A>5P05001>5ThFCQH00003CQH01000CQI>5ThF0`00
0U9H00<0059HDUP00U9H00D0059HDUQBF00000ABF003001BF000008000ABVP03001BVU:J009BVP03
001BVU:J00@000=C7@03001C7E<M00L00;1oo`03001oogoo00ioo`03001oogoo00Moo`00A7oo0P00
7Goo00D004WDBMA9e00000=9e0050019e4WDBM@00003BM@00`00BM@000030002COH01000COI=mP00
14gf00D004gfCOI=mP0000==mP05001=mTgfCOH00002COH30002CQH01@00CQI>5ThF000014hF00D0
04hFCQI>5P0000=>5P03001>5ThF009>5P<00003DUP0059H00=BF005001BF59HDUP00003DUP00`00
DUQBF0040002DYX00`00DYYBVP03DYX00`00DYYBVP040003Dad00`00DaeC7@0500000d>O0000002c
Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool004Ioo`03001oogoo01]oo`040019e4WD0003BM@01@00
BMA9e4WD00000TWD0`000Tgf00D004gfCOI=mP0000==mP05001=mTgfCOH00003COH01@00COI=mTgf
000014gf0P0000=>5P00CQH00dhF00D004hFCQI>5P0000=>5P05001>5ThFCQH00004CQH00`00CQH0
00020004DUP01@00DUQBF59H00000e9H00<0059HDUP010000U:J00<005:JDYX00U:J00<005:JDYX0
0U:J0`000e<M00<005<MDad010000d>O0`00]Woo00<007ooOol03Goo00<007ooOol01goo0017Ool0
0`00Oomoo`0JOol01000BMA9e00014WD00<004WDBM@00`0000==mP00COH00Tgf00<004gfCOH00Tgf
00@004gfCOH000==mP05001=mTgfCOH00004COH00`00COH000020003CQH01@00CQI>5ThF00000dhF
00D004hFCQI>5P0000A>5P03001>5P0000<0009BF003001BF59H009BF005001BF59HDUP00003DUP3
0002DYX00`00DYYBVP02DYX00`00DYYBVP02DYX01P00DYX00000Dad000AC7@<00093W`D00;Yoo`03
001oogoo00aoo`03001oogoo00Moo`00B7oo00<007ooOol06Goo00D004WDBMA9e00000=9e0040019
e0000003COH00`00COI=mP02COH01@00COI=mTgf00000Tgf00D004gfCOI=mP0000A=mP03001=mP00
00<0009>5P05001>5ThFCQH00003CQH01@00CQI>5ThF000014hF00<004hF00000`000U9H00<0059H
DUP00U9H00D0059HDUQBF00000ABF0<00003DYX005:J00=BVP03001BVU:J009BVP03001BVU:J00<0
00AC7@05001C7@000013W`04002oOol00`00Oomoo`0<Ool00`00Oomoo`07Ool004Uoo`8001Uoo`06
0019e4WDBM@004WD100000==mP00COH00dgf00D004gfCOI=mP0000==mP04001=mTgf0004COH00`00
COH000030002CQH01@00CQI>5ThF00000dhF00<004hFCQH00ThF00H004hFCQI>5P00CQH40002DUP0
0`00DUQBF002DUP01@00DUQBF59H0000159H00<0059H00000P0015:J00<005:JDYX00U:J00<005:J
DYX010000e<M00<005<MDad01P00a7oo00<007ooOol02goo00<007ooOol01goo001;Ool00`00Oomo
o`0FOol00`00BM@000030002COH01000COI=mP0014gf00D004gfCOI=mP0000==mP06001=mTgfCOH0
04gf10000ThF00D004hFCQI>5P0000A>5P05001>5ThFCQH00003CQH00`00CQI>5P030002DUP00`00
DUQBF002DUP01@00DUQBF59H00000e9H00<0059HDUP010000e:J00<005:JDYX00U:J00<005:JDYX0
10000e<M00<005<MDad01P00bGoo00<007ooOol02goo00<007ooOol01Woo001<Ool00`00Oomoo`0E
Ool20002COH01@00COI=mTgf00000dgf00D004gfCOI=mP0000==mP05001=mTgfCOH00002COH30002
CQH01@00CQI>5ThF000014hF00D004hFCQI>5P0000=>5P09001>5ThFCQH004hF001BF00000ABF003
001BF59H009BF004001BF59H0002DUP40002DYX00`00DYYBVP03DYX00`00DYYBVP040003Dad00`00
DaeC7@04000014>O00000000c7oo00<007ooOol02Woo00<007ooOol01Woo001=Ool00`00Oomoo`0D
Ool01@00COI=mTgf000014gf00@004gfCOH000==mP05001=mTgfCOH00004COH200000dhF001>5P02
CQH00`00CQI>5P02CQH01@00CQI>5ThF00000dhF00D004hFCQI>5P00009>5P<000=BF003001BF59H
009BF005001BF59HDUP00002DUP30002DYX00`00DYYBVP02DYX00`00DYYBVP02DYX30003Dad00`00
DaeC7@040002@il4003>Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool004ioo`8001Aoo`03001=mTgf
009=mP05001=mTgfCOH00002COH01@00COI=mTgf000014gf00<004gf00000P000ThF00<004hFCQH0
0ThF00D004hFCQI>5P0000=>5P03001>5ThF009>5P03001>5P0000<0009BF005001BF59HDUP00004
DUP00`00DUQBF00400000e:J001BVP03DYX00`00DYYBVP02DYX01P00DYX00000Dad000AC7@<00093
W`@00==oo`03001oogoo00Uoo`03001oogoo00Ioo`00D7oo00<007ooOol04Woo00D004gfCOI=mP00
00==mP04001=mTgf0004COH00`00COH000030002CQH01@00CQI>5ThF00000dhF00D004hFCQI>5P00
00A>5P03001>5P0000<0009BF003001BF59H009BF005001BF59HDUP00003DUP30002DYX01@00DYYB
VU:J000015:J00<005:JDYX00`0015<M00D005<M000004>O00@00=Qoo`03001oogoo00Qoo`03001o
ogoo00Ioo`00DGoo00<007ooOol04Goo00D004gfCOI=mP0000==mP06001=mTgfCOH004gf10000ThF
00D004hFCQI>5P0000=>5P05001>5ThFCQH00004CQH00`00CQH000030002DUP00`00DUQBF002DUP0
1@00DUQBF59H00000e9H00H0059H000005:J0004DYX01@00DYYBVU:J00000U:J10000e<M00<005<M
Dad01P00gGoo00<007ooOol01goo00<007ooOol01Woo001BOol00`00Oomoo`0@Ool01@00COI=mTgf
000014gf00<004gf00000P000ThF00D004hFCQI>5P0000A>5P04001>5ThF0004CQH00`00CQH00003
0002DUP00`00DUQBF002DUP01@00DUQBF59H00000e9H00<0059HDUP00`0015:J00D005:JDYYBVP00
009BVP@000=C7@03001C7E<M00H00>5oo`03001oogoo00Moo`03001oogoo00Ioo`00Dgoo0P0047oo
00<004gfCOH00Tgf00<004gf00000`0000=>5P00CQH00ThF00<004hFCQH00ThF00D004hFCQI>5P00
009>5P04001>5ThFCQH30002DUP00`00DUQBF002DUP01@00DUQBF59H00000e9H00<0059HDUP01000
0U:J00<005:JDYX00U:J00<005:JDYX010000e<M00<005<MDad02000i7oo00<007ooOol01goo00<0
07ooOol01Goo001EOol00`00Oomoo`0=Ool01000COI=mTgf0`000ThF00@004hFCQH000A>5P05001>
5ThFCQH00003CQH01000CQI>5ThF0`0000=BF000DUP00e9H00D0059HDUQBF00000=BF003001BF59H
00@0009BVP03001BVU:J009BVP04001BVU:JDYX30003Dad00`00DaeC7@05000014>O000000000Woo
00<007ooOol0hgoo00<007ooOol01Woo00<007ooOol01Goo001FOol00`00Oomoo`0=Ool300000dhF
001>5P02CQH01@00CQI>5ThF00000dhF00D004hFCQI>5P0000A>5P04001>5P000004DUP01@00DUQB
F59H00000e9H00<0059HDUP010000U:J00<005:JDYX00U:J00H005:JDYYBVP00DYX200000e<M001C
7@03Dad40002@il30005Ool00`00Oomoo`3SOol00`00Oomoo`06Ool00`00Oomoo`05Ool005Moo`03
001oogoo00aoo`05001>5ThFCQH00004CQH01000CQI>5P000dhF00<004hFCQH00ThF00<004hF0000
0`0000=BF000DUP00e9H00D0059HDUQBF00000=BF0<0009BVP03001BVU:J009BVP05001BVU:JDYX0
0002DYX30004Dad01000Dad000000T>O100027oo00<007ooOol0i7oo00<007ooOol01Goo00<007oo
Ool01Goo001HOol00`00Oomoo`0;Ool00`00CQI>5P02CQH01@00CQI>5ThF00000ThF00<004hFCQH0
0ThF00<004hF00000`000U9H00D0059HDUQBF00000ABF004001BF59HDUP300000e:J001BVP03DYX0
1@00DYYBVU:J00000U:J10000e<M00<005<MDad01`0037oo00<007ooOol0iGoo00<007ooOol017oo
00<007ooOol01Goo001IOol2000;Ool00`00CQI>5P02CQH01@00CQI>5ThF00000dhF00<004hF0000
0`000U9H00<0059HDUP00U9H00D0059HDUQBF00000=BF003001BF59H008000ABVP05001BVU:JDYX0
0002DYX40004Dad00`00DaeC7@06000@Ool00`00Oomoo`3VOol00`00Oomoo`03Ool00`00Oomoo`05
Ool005]oo`03001oogoo00Uoo`05001>5ThFCQH00004CQH00`00CQH000020002DUP00`00DUQBF002
DUP01@00DUQBF59H00000e9H00<0059HDUP010000U:J00<005:JDYX00U:J00<005:JDYX00`0015<M
00<005<MDad01P0057oo00<007ooOol0iWoo00<007ooOol00goo00<007ooOol01Goo001LOol00`00
Oomoo`08Ool00`00CQI>5P02CQH00`00CQH0000300000e9H001BF003DUP01@00DUQBF59H00000e9H
00<0059HDUP010000U:J00<005:JDYX00U:J00<005:JDYX010000e<M00<005<MDad01P0067oo00<0
07ooOol0igoo00<007ooOol00goo00<007ooOol017oo001MOol00`00Oomoo`07Ool01000CQI>5ThF
0`000U9H00D0059HDUQBF00000=BF005001BF59HDUP00002DUP40002DYX00`00DYYBVP02DYX00`00
DYYBVP040003Dad00`00DaeC7@04000014>O000000006Woo00<007ooOol0j7oo00<007ooOol00Woo
00<007ooOol017oo001NOol20008Ool300000e9H001BF003DUP01@00DUQBF59H00000U9H00<0059H
DUP010000U:J00<005:JDYX00U:J00@005:JDYYBVP<000=C7@03001C7E<M00D00093W`<001]oo`03
001oogoo0>Yoo`05001oogooOol00006Ool0061oo`03001oogoo00Eoo`03001BF59H009BF005001B
F59HDUP00003DUP00`00DUQBF0030002DYX00`00DYYBVP02DYX01P00DYYBVU:J001BVP800003Dad0
05<M00=C7@@00093W`@001ioo`03001oogoo0>Yoo`05001oogooOol00006Ool0065oo`03001oogoo
00Aoo`03001BF59H009BF005001BF59HDUP00003DUP300000e:J001BVP03DYX01@00DYYBVU:J0000
0U:J10000e<M00@005<M00000093W`@0029oo`03001oogoo0>]oo`04001oogoo0006Ool0069oo`03
001oogoo00Aoo`05001BF59HDUP00004DUP300000e:J001BVP02DYX00`00DYYBVP02DYX00`00DYYB
VP030004Dad00`00DaeC7@06000VOol00`00Oomoo`3/Ool00`00Ool00006Ool006=oo`8000Aoo`03
001BF59H009BF003001BF000008000ABVP05001BVU:JDYX00002DYX40003Dad00`00DaeC7@06000Z
Ool00`00Oomoo`3/Ool00`00Ool00006Ool006Eoo`05001oogooOol00002DUP40002DYX00`00DYYB
VP02DYX00`00DYYBVP040003Dad00`00DaeC7@06000^Ool00`00Oomoo`3]Ool00`00Ool00005Ool0
06Ioo`04001oogooOol20003DYX01@00DYYBVU:J00000U:J10000e<M00<005<MDad01`00<Goo00<0
07ooOol0kWoo0P001Goo001WOol01@00Oomoogoo000015:J00<005:JDYX00`0015<M00<005<MDad0
1P00=Goo00<007ooOol0kGoo0`001Goo001XOol20002Ool00`00DYYBVP040003Dad00`00DaeC7@04
000014>O00000000=goo00<007ooOol0jGoo100027oo001ZOol00`00Oomoo`020003Dad00`00DaeC
7@040002@il4000iOol00`00Oomoo`3UOol4000<Ool006]oo`03001oo`0000AC7@@00093W`<003eo
o`03001oogoo0>9oo`<0011oo`00K7oo00@007oo001C7@800093W`@0041oo`03001oogoo0=ioo`@0
01=oo`00KGoo1`00A7oo00<007ooOol0fWoo10005goo001_Ool00`00Oomoo`16Ool00`00Oomoo`3F
Ool4000KOol0071oo`03001oogoo04Eoo`03001oogoo0=9oo`@001moo`00LGoo00<007ooOol0A7oo
00<007ooOol0cgoo0`008goo001bOol20014Ool00`00Oomoo`3;Ool4000VOol007Aoo`03001oogoo
045oo`03001oogoo0<Moo`@002Yoo`00MGoo00<007ooOol0@7oo00<007ooOol0`goo1000;Woo001f
Ool00`00Oomoo`0oOol00`00Oomoo`2oOol4000bOol007Moo`03001oogoo03ioo`03001oogoo0;ao
o`<003Ioo`00N7oo0P00?Woo00<007ooOol0^7oo1000>Goo001jOol00`00Oomoo`0kOol00`00Oomo
o`2dOol4000mOol007]oo`03001oogoo03Yoo`03001oogoo0;1oo`@0045oo`00O7oo00<007ooOol0
>Goo00<007ooOol0[7oo1000AGoo001mOol2000iOol00`00Oomoo`2XOol40019Ool007moo`03001o
ogoo03Ioo`03001oogoo0:Eoo`<004eoo`00P7oo00<007ooOol0=Goo00<007ooOol0XGoo1000D7oo
0021Ool00`00Oomoo`0dOol00`00Oomoo`2MOol4001DOol0089oo`8003=oo`03001oogoo09Yoo`@0
05Qoo`00Q7oo00<007ooOol0<7oo00<007ooOol0UWoo1000G7oo0025Ool00`00Oomoo`0_Ool00`00
Oomoo`2COol3001POol008Ioo`03001oogoo02ioo`03001oogoo08moo`@006=oo`00Qgoo0P00;Woo
00<007ooOol0Rgoo1000Igoo0029Ool00`00Oomoo`0[Ool00`00Oomoo`27Ool4001[Ool008Yoo`03
001oogoo02Yoo`03001oogoo08=oo`@006moo`00Rgoo00<007ooOol0:Goo00<007ooOol0P7oo0`00
Lgoo002<Ool2000YOol00`00Oomoo`1lOol4001fOol008ioo`03001oogoo02Ioo`03001oogoo07Qo
o`@007Yoo`00Sgoo00<007ooOol09Goo00<007ooOol0M7oo1000OWoo002@Ool00`00Oomoo`0TOol0
0`00Oomoo`1`Ool40022Ool0095oo`03001oogoo02=oo`03001oogoo06aoo`@008Ioo`00TWoo0P00
8goo00<007ooOol0JGoo0`00RWoo002DOol00`00Oomoo`0POol00`00Oomoo`1UOol4002=Ool009Eo
o`03001oogoo01moo`03001oogoo065oo`@0095oo`00UWoo00<007ooOol07Woo00<007ooOol0GGoo
1000UGoo002GOol2000NOol00`00Oomoo`1IOol4002IOol009Uoo`03001oogoo01]oo`03001oogoo
05Ioo`<009eoo`00VWoo00<007ooOol06Woo00<007ooOol0DWoo1000X7oo002KOol00`00Oomoo`0I
Ool00`00Oomoo`1>Ool4002TOol009aoo`8001Uoo`03001oogoo04Yoo`@00:Qoo`00WWoo00<007oo
Ool05Woo00<007ooOol0AWoo1000[7oo002OOol00`00Oomoo`0EOol00`00Oomoo`13Ool3002`Ool0
0:1oo`03001oogoo01Aoo`03001oogoo03moo`@00;=oo`00XGoo0P0057oo00<007ooOol0>goo1000
]goo002SOol00`00Oomoo`0AOol00`00Oomoo`0gOol4002kOol00:Aoo`03001oogoo011oo`03001o
ogoo03=oo`@00;moo`00YGoo00<007ooOol03goo00<007ooOol0;goo1000`goo002VOol2000>Ool0
0`00Oomoo`0]Ool30037Ool00:Qoo`03001oogoo00]oo`03001oogoo02Uoo`@00<Yoo`00ZGoo00<0
07ooOol02Woo00<007ooOol09Goo1000cWoo002ZOol00`00Oomoo`09Ool00`00Oomoo`0QOol4003B
Ool00:]oo`03001oogoo00Qoo`03001oogoo01eoo`@00=Ioo`00[7oo0P0027oo00<007ooOol06Woo
0`00fWoo002^Ool00`00Oomoo`05Ool00`00Oomoo`0FOol4003MOol00:moo`03001oogoo00Aoo`03
001oogoo019oo`@00>5oo`00/7oo00<007ooOol00goo00<007ooOol03Woo1000iGoo002aOol20003
Ool00`00Oomoo`0:Ool4003YOol00;=oo`04001oogoo0009Ool3003]Ool00;Aoo`03001oo`0000Eo
o`@00?1oo`00]Goo0P0000=oo`0000000P00m7oo002fOol2003hOol00?mook5oo`00ogoo/Goo003o
OonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
   ImageRangeCache->{{{0, 431}, {349.312, 0}} -> {-0.0510306, 0.027389,
   0.00353217, 0.00353217}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Filtered Back Projection", "Section"],

Cell[BoxData[
     \(\(Fdata = Fourier[Robject1]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
     \(ListPlot3D[Re[Fdata], {PlotRange \[Rule] All}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.2083 .17506 -11.6698 -9 ]
[.2083 .17506 .33019 0 ]
[.41321 .09446 -10.8756 -9 ]
[.41321 .09446 1.12444 0 ]
[.63499 .00731 -10.0813 -9 ]
[.63499 .00731 1.9187 0 ]
[.79894 .14525 0 -6.11522 ]
[.79894 .14525 12 2.88478 ]
[.88874 .28276 0 -5.98496 ]
[.88874 .28276 12 3.01504 ]
[.96735 .40315 0 -5.87414 ]
[.96735 .40315 12 3.12586 ]
[.01672 .31148 -24 -2.78151 ]
[.01672 .31148 0 6.21849 ]
[.00765 .36827 -6 -2.82968 ]
[.00765 .36827 0 6.17032 ]
[-0.00175 .42718 -18 -2.87983 ]
[-0.00175 .42718 0 6.12017 ]
[-0.0115 .4883 -18 -2.93206 ]
[-0.0115 .4883 0 6.06794 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78659 .14969 m
.78042 .1519 L
s
[(20)] .79894 .14525 -1 .35894 Mshowa
.87628 .28687 m
.87005 .28893 L
s
[(40)] .88874 .28276 -1 .32999 Mshowa
.9548 .40699 m
.94853 .4089 L
s
[(60)] .96735 .40315 -1 .30537 Mshowa
.125 Mabswid
.7105 .03329 m
.70682 .0347 L
s
.7368 .07352 m
.73311 .0749 L
s
.76215 .11229 m
.75845 .11365 L
s
.81019 .18578 m
.80647 .18708 L
s
.83297 .22063 m
.82925 .22191 L
s
.85499 .25431 m
.85126 .25557 L
s
.89687 .31837 m
.89312 .31958 L
s
.9168 .34886 m
.91305 .35005 L
s
.9361 .37838 m
.93234 .37955 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02897 .30679 m
.0351 .30445 L
s
[(-200)] .01672 .31148 1 -0.38189 Mshowa
.01995 .36371 m
.02611 .36143 L
s
[(0)] .00765 .36827 1 -0.37118 Mshowa
.0106 .42273 m
.01677 .42051 L
s
[(200)] -0.00175 .42718 1 -0.36004 Mshowa
.00089 .48398 m
.00709 .48182 L
s
[(400)] -0.0115 .4883 1 -0.34843 Mshowa
.125 Mabswid
.02675 .32083 m
.03043 .31944 L
s
.0245 .33499 m
.02819 .33361 L
s
.02224 .34929 m
.02593 .34791 L
s
.01765 .37826 m
.02134 .3769 L
s
.01532 .39295 m
.01902 .3916 L
s
.01297 .40777 m
.01667 .40643 L
s
.00821 .43783 m
.01192 .43651 L
s
.00579 .45307 m
.0095 .45176 L
s
.00336 .46845 m
.00707 .46715 L
s
.03118 .29288 m
.03485 .29147 L
s
.03336 .27909 m
.03704 .27767 L
s
.03553 .26543 m
.0392 .264 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.363 .184 .499 r
.39403 .77077 .40512 .60371 .41018 .69553 .40521 .69116 Metetra
.656 .751 .92 r
.40521 .69116 .41018 .69553 .41855 .69317 .4136 .68878 Metetra
.656 .751 .92 r
.4136 .68878 .41855 .69317 .42694 .69079 .42201 .68639 Metetra
.656 .751 .92 r
.42201 .68639 .42694 .69079 .43537 .68841 .43045 .684 Metetra
.656 .751 .92 r
.43045 .684 .43537 .68841 .44382 .68602 .43892 .68159 Metetra
.656 .751 .92 r
.43892 .68159 .44382 .68602 .4523 .68363 .44741 .67919 Metetra
.656 .751 .92 r
.44741 .67919 .4523 .68363 .4608 .68122 .45593 .67677 Metetra
.656 .751 .92 r
.45593 .67677 .4608 .68122 .46933 .67881 .46448 .67434 Metetra
.656 .751 .92 r
.46448 .67434 .46933 .67881 .47789 .67639 .47305 .67191 Metetra
.656 .751 .92 r
.47305 .67191 .47789 .67639 .48647 .67397 .48165 .66947 Metetra
.656 .751 .92 r
.48165 .66947 .48647 .67397 .49508 .67153 .49028 .66702 Metetra
.656 .751 .92 r
.49028 .66702 .49508 .67153 .50372 .66909 .49894 .66457 Metetra
.656 .751 .92 r
.49894 .66457 .50372 .66909 .51238 .66664 .50762 .6621 Metetra
.656 .751 .92 r
.50762 .6621 .51238 .66664 .52108 .66419 .51633 .65963 Metetra
.656 .751 .92 r
.51633 .65963 .52108 .66419 .5298 .66172 .52507 .65715 Metetra
.656 .751 .92 r
.52507 .65715 .5298 .66172 .53854 .65925 .53384 .65466 Metetra
.656 .751 .92 r
.53384 .65466 .53854 .65925 .54732 .65677 .54263 .65217 Metetra
.656 .751 .92 r
.54263 .65217 .54732 .65677 .55612 .65428 .55145 .64966 Metetra
.656 .751 .92 r
.55145 .64966 .55612 .65428 .56495 .65178 .5603 .64715 Metetra
.656 .751 .92 r
.5603 .64715 .56495 .65178 .57381 .64928 .56918 .64463 Metetra
.656 .751 .92 r
.56918 .64463 .57381 .64928 .5827 .64677 .57809 .64211 Metetra
.656 .751 .92 r
.57809 .64211 .5827 .64677 .59162 .64425 .58702 .63957 Metetra
.656 .751 .92 r
.58702 .63957 .59162 .64425 .60057 .64172 .59599 .63703 Metetra
.656 .751 .92 r
.59599 .63703 .60057 .64172 .60954 .63918 .60498 .63448 Metetra
.656 .751 .92 r
.60498 .63448 .60954 .63918 .61854 .63664 .61401 .63192 Metetra
.656 .751 .92 r
.61401 .63192 .61854 .63664 .62758 .63408 .62306 .62935 Metetra
.656 .751 .92 r
.62306 .62935 .62758 .63408 .63664 .63152 .63214 .62677 Metetra
.656 .751 .92 r
.63214 .62677 .63664 .63152 .64573 .62895 .64125 .62418 Metetra
.656 .751 .92 r
.64125 .62418 .64573 .62895 .65485 .62637 .65039 .62159 Metetra
.656 .751 .92 r
.65039 .62159 .65485 .62637 .664 .62379 .65956 .61899 Metetra
.656 .751 .92 r
.65956 .61899 .664 .62379 .67318 .62119 .66876 .61638 Metetra
.656 .751 .92 r
.66876 .61638 .67318 .62119 .68239 .61859 .67799 .61376 Metetra
.656 .751 .92 r
.67799 .61376 .68239 .61859 .69163 .61598 .68725 .61113 Metetra
.656 .751 .92 r
.68725 .61113 .69163 .61598 .7009 .61336 .69655 .6085 Metetra
.656 .751 .92 r
.69655 .6085 .7009 .61336 .7102 .61073 .70587 .60585 Metetra
.656 .751 .92 r
.70587 .60585 .7102 .61073 .71953 .60809 .71522 .6032 Metetra
.656 .751 .92 r
.71522 .6032 .71953 .60809 .72889 .60544 .7246 .60053 Metetra
.656 .751 .92 r
.7246 .60053 .72889 .60544 .73829 .60279 .73402 .59786 Metetra
.656 .751 .92 r
.73402 .59786 .73829 .60279 .74771 .60012 .74346 .59518 Metetra
.656 .751 .92 r
.74346 .59518 .74771 .60012 .75717 .59745 .75294 .59249 Metetra
.656 .751 .92 r
.75294 .59249 .75717 .59745 .76665 .59477 .76245 .5898 Metetra
.656 .751 .92 r
.76245 .5898 .76665 .59477 .77617 .59208 .77199 .58709 Metetra
.656 .751 .92 r
.77199 .58709 .77617 .59208 .78572 .58938 .78156 .58437 Metetra
.656 .751 .92 r
.78156 .58437 .78572 .58938 .7953 .58667 .79116 .58165 Metetra
.656 .751 .92 r
.79116 .58165 .7953 .58667 .80491 .58396 .8008 .57892 Metetra
.656 .751 .92 r
.8008 .57892 .80491 .58396 .81456 .58123 .81047 .57617 Metetra
.656 .751 .92 r
.81047 .57617 .81456 .58123 .82424 .57849 .82017 .57342 Metetra
.656 .751 .92 r
.82017 .57342 .82424 .57849 .83394 .57575 .8299 .57066 Metetra
.656 .751 .92 r
.8299 .57066 .83394 .57575 .84369 .573 .83967 .56789 Metetra
.656 .751 .92 r
.83967 .56789 .84369 .573 .85346 .57023 .84946 .56511 Metetra
.656 .751 .92 r
.84946 .56511 .85346 .57023 .86327 .56746 .8593 .56232 Metetra
.656 .751 .92 r
.8593 .56232 .86327 .56746 .87311 .56468 .86916 .55952 Metetra
.656 .751 .92 r
.86916 .55952 .87311 .56468 .88298 .56189 .87906 .55671 Metetra
.656 .751 .92 r
.87906 .55671 .88298 .56189 .89289 .55909 .88899 .55389 Metetra
.656 .751 .92 r
.88899 .55389 .89289 .55909 .90283 .55628 .89896 .55106 Metetra
.656 .751 .92 r
.89896 .55106 .90283 .55628 .91281 .55346 .90896 .54823 Metetra
.656 .751 .92 r
.90896 .54823 .91281 .55346 .92282 .55063 .91899 .54538 Metetra
.656 .751 .92 r
.91899 .54538 .92282 .55063 .93286 .54779 .92906 .54252 Metetra
.656 .751 .92 r
.92906 .54252 .93286 .54779 .94294 .54494 .93916 .53966 Metetra
.656 .751 .92 r
.93916 .53966 .94294 .54494 .95305 .54208 .9493 .53678 Metetra
.656 .751 .92 r
.9493 .53678 .95305 .54208 .96319 .53921 .95947 .53389 Metetra
.656 .751 .92 r
.95947 .53389 .96319 .53921 .97338 .53634 .96968 .531 Metetra
.656 .751 .92 r
.96968 .531 .97338 .53634 .98359 .53345 .97992 .52809 Metetra
.429 .267 .559 r
.3936 .6426 .39403 .77077 .40521 .69116 .40021 .68676 Metetra
.656 .751 .92 r
.40021 .68676 .40521 .69116 .4136 .68878 .40862 .68437 Metetra
.656 .751 .92 r
.40862 .68437 .4136 .68878 .42201 .68639 .41705 .68197 Metetra
.656 .751 .92 r
.41705 .68197 .42201 .68639 .43045 .684 .42551 .67956 Metetra
.656 .751 .92 r
.42551 .67956 .43045 .684 .43892 .68159 .43399 .67714 Metetra
.656 .751 .92 r
.43399 .67714 .43892 .68159 .44741 .67919 .4425 .67472 Metetra
.656 .751 .92 r
.4425 .67472 .44741 .67919 .45593 .67677 .45104 .67228 Metetra
.656 .751 .92 r
.45104 .67228 .45593 .67677 .46448 .67434 .4596 .66985 Metetra
.656 .751 .92 r
.4596 .66985 .46448 .67434 .47305 .67191 .46819 .6674 Metetra
.656 .751 .92 r
.46819 .6674 .47305 .67191 .48165 .66947 .47681 .66494 Metetra
.656 .751 .92 r
.47681 .66494 .48165 .66947 .49028 .66702 .48546 .66248 Metetra
.656 .751 .92 r
.48546 .66248 .49028 .66702 .49894 .66457 .49413 .66001 Metetra
.656 .751 .92 r
.49413 .66001 .49894 .66457 .50762 .6621 .50283 .65753 Metetra
.656 .751 .92 r
.50283 .65753 .50762 .6621 .51633 .65963 .51156 .65505 Metetra
.656 .751 .92 r
.51156 .65505 .51633 .65963 .52507 .65715 .52032 .65255 Metetra
.656 .751 .92 r
.52032 .65255 .52507 .65715 .53384 .65466 .5291 .65005 Metetra
.656 .751 .92 r
.5291 .65005 .53384 .65466 .54263 .65217 .53791 .64754 Metetra
.656 .751 .92 r
.53791 .64754 .54263 .65217 .55145 .64966 .54675 .64502 Metetra
.656 .751 .92 r
.54675 .64502 .55145 .64966 .5603 .64715 .55562 .6425 Metetra
.656 .751 .92 r
.55562 .6425 .5603 .64715 .56918 .64463 .56452 .63996 Metetra
.656 .751 .92 r
.56452 .63996 .56918 .64463 .57809 .64211 .57345 .63742 Metetra
.656 .751 .92 r
.57345 .63742 .57809 .64211 .58702 .63957 .5824 .63487 Metetra
.656 .751 .92 r
.5824 .63487 .58702 .63957 .59599 .63703 .59139 .63231 Metetra
.656 .751 .92 r
.59139 .63231 .59599 .63703 .60498 .63448 .6004 .62974 Metetra
.656 .751 .92 r
.6004 .62974 .60498 .63448 .61401 .63192 .60944 .62717 Metetra
.656 .751 .92 r
.60944 .62717 .61401 .63192 .62306 .62935 .61851 .62458 Metetra
.656 .751 .92 r
.61851 .62458 .62306 .62935 .63214 .62677 .62762 .62199 Metetra
.656 .751 .92 r
.62762 .62199 .63214 .62677 .64125 .62418 .63675 .61939 Metetra
.656 .751 .92 r
.63675 .61939 .64125 .62418 .65039 .62159 .64591 .61678 Metetra
.656 .751 .92 r
.64591 .61678 .65039 .62159 .65956 .61899 .6551 .61416 Metetra
.656 .751 .92 r
.6551 .61416 .65956 .61899 .66876 .61638 .66432 .61154 Metetra
.656 .751 .92 r
.66432 .61154 .66876 .61638 .67799 .61376 .67357 .6089 Metetra
.656 .751 .92 r
.67357 .6089 .67799 .61376 .68725 .61113 .68285 .60626 Metetra
.656 .751 .92 r
.68285 .60626 .68725 .61113 .69655 .6085 .69216 .60361 Metetra
.656 .751 .92 r
.69216 .60361 .69655 .6085 .70587 .60585 .70151 .60094 Metetra
.656 .751 .92 r
.70151 .60094 .70587 .60585 .71522 .6032 .71088 .59828 Metetra
.656 .751 .92 r
.71088 .59828 .71522 .6032 .7246 .60053 .72029 .5956 Metetra
.656 .751 .92 r
.72029 .5956 .7246 .60053 .73402 .59786 .72972 .59291 Metetra
.656 .751 .92 r
.72972 .59291 .73402 .59786 .74346 .59518 .73919 .59021 Metetra
.656 .751 .92 r
.73919 .59021 .74346 .59518 .75294 .59249 .74869 .58751 Metetra
.656 .751 .92 r
.74869 .58751 .75294 .59249 .76245 .5898 .75822 .58479 Metetra
.656 .751 .92 r
.75822 .58479 .76245 .5898 .77199 .58709 .76778 .58207 Metetra
.656 .751 .92 r
.76778 .58207 .77199 .58709 .78156 .58437 .77737 .57934 Metetra
.656 .751 .92 r
.77737 .57934 .78156 .58437 .79116 .58165 .787 .57659 Metetra
.656 .751 .92 r
.787 .57659 .79116 .58165 .8008 .57892 .79666 .57384 Metetra
.656 .751 .92 r
.79666 .57384 .8008 .57892 .81047 .57617 .80635 .57108 Metetra
.656 .751 .92 r
.80635 .57108 .81047 .57617 .82017 .57342 .81607 .56831 Metetra
.656 .751 .92 r
.81607 .56831 .82017 .57342 .8299 .57066 .82583 .56554 Metetra
.656 .751 .92 r
.82583 .56554 .8299 .57066 .83967 .56789 .83562 .56275 Metetra
.656 .751 .92 r
.83562 .56275 .83967 .56789 .84946 .56511 .84544 .55995 Metetra
.656 .751 .92 r
.84544 .55995 .84946 .56511 .8593 .56232 .8553 .55714 Metetra
.656 .751 .92 r
.8553 .55714 .8593 .56232 .86916 .55952 .86519 .55433 Metetra
.656 .751 .92 r
.86519 .55433 .86916 .55952 .87906 .55671 .87511 .5515 Metetra
.656 .751 .92 r
.87511 .5515 .87906 .55671 .88899 .55389 .88506 .54866 Metetra
.656 .751 .92 r
.88506 .54866 .88899 .55389 .89896 .55106 .89505 .54582 Metetra
.656 .751 .92 r
.89505 .54582 .89896 .55106 .90896 .54823 .90508 .54296 Metetra
.656 .751 .92 r
.90508 .54296 .90896 .54823 .91899 .54538 .91514 .5401 Metetra
.656 .751 .92 r
.91514 .5401 .91899 .54538 .92906 .54252 .92523 .53722 Metetra
.656 .751 .92 r
.92523 .53722 .92906 .54252 .93916 .53966 .93536 .53434 Metetra
.656 .751 .92 r
.93536 .53434 .93916 .53966 .9493 .53678 .94552 .53144 Metetra
.656 .751 .92 r
.94552 .53144 .9493 .53678 .95947 .53389 .95572 .52854 Metetra
.656 .751 .92 r
.95572 .52854 .95947 .53389 .96968 .531 .96595 .52563 Metetra
.656 .751 .92 r
.96595 .52563 .96968 .531 .97992 .52809 .97622 .5227 Metetra
.42 .205 .48 r
.38603 .70421 .3936 .6426 .40021 .68676 .39519 .68233 Metetra
.656 .751 .92 r
.39519 .68233 .40021 .68676 .40862 .68437 .40361 .67993 Metetra
.656 .751 .92 r
.40361 .67993 .40862 .68437 .41705 .68197 .41206 .67751 Metetra
.656 .751 .92 r
.41206 .67751 .41705 .68197 .42551 .67956 .42053 .67509 Metetra
.656 .751 .92 r
.42053 .67509 .42551 .67956 .43399 .67714 .42903 .67266 Metetra
.656 .751 .92 r
.42903 .67266 .43399 .67714 .4425 .67472 .43756 .67022 Metetra
.656 .751 .92 r
.43756 .67022 .4425 .67472 .45104 .67228 .44611 .66778 Metetra
.656 .751 .92 r
.44611 .66778 .45104 .67228 .4596 .66985 .45469 .66532 Metetra
.656 .751 .92 r
.45469 .66532 .4596 .66985 .46819 .6674 .4633 .66286 Metetra
.656 .751 .92 r
.4633 .66286 .46819 .6674 .47681 .66494 .47194 .66039 Metetra
.656 .751 .92 r
.47194 .66039 .47681 .66494 .48546 .66248 .4806 .65791 Metetra
.656 .751 .92 r
.4806 .65791 .48546 .66248 .49413 .66001 .48929 .65543 Metetra
.656 .751 .92 r
.48929 .65543 .49413 .66001 .50283 .65753 .49801 .65294 Metetra
.656 .751 .92 r
.49801 .65294 .50283 .65753 .51156 .65505 .50676 .65044 Metetra
.656 .751 .92 r
.50676 .65044 .51156 .65505 .52032 .65255 .51553 .64793 Metetra
.656 .751 .92 r
.51553 .64793 .52032 .65255 .5291 .65005 .52434 .64541 Metetra
.656 .751 .92 r
.52434 .64541 .5291 .65005 .53791 .64754 .53317 .64289 Metetra
.656 .751 .92 r
.53317 .64289 .53791 .64754 .54675 .64502 .54203 .64035 Metetra
.656 .751 .92 r
.54203 .64035 .54675 .64502 .55562 .6425 .55091 .63781 Metetra
.656 .751 .92 r
.55091 .63781 .55562 .6425 .56452 .63996 .55983 .63526 Metetra
.656 .751 .92 r
.55983 .63526 .56452 .63996 .57345 .63742 .56878 .6327 Metetra
.656 .751 .92 r
.56878 .6327 .57345 .63742 .5824 .63487 .57775 .63014 Metetra
.656 .751 .92 r
.57775 .63014 .5824 .63487 .59139 .63231 .58675 .62756 Metetra
.656 .751 .92 r
.58675 .62756 .59139 .63231 .6004 .62974 .59579 .62498 Metetra
.656 .751 .92 r
.59579 .62498 .6004 .62974 .60944 .62717 .60485 .62239 Metetra
.656 .751 .92 r
.60485 .62239 .60944 .62717 .61851 .62458 .61394 .61979 Metetra
.656 .751 .92 r
.61394 .61979 .61851 .62458 .62762 .62199 .62306 .61718 Metetra
.656 .751 .92 r
.62306 .61718 .62762 .62199 .63675 .61939 .63221 .61457 Metetra
.656 .751 .92 r
.63221 .61457 .63675 .61939 .64591 .61678 .64139 .61194 Metetra
.656 .751 .92 r
.64139 .61194 .64591 .61678 .6551 .61416 .65061 .60931 Metetra
.656 .751 .92 r
.65061 .60931 .6551 .61416 .66432 .61154 .65985 .60667 Metetra
.656 .751 .92 r
.65985 .60667 .66432 .61154 .67357 .6089 .66912 .60401 Metetra
.656 .751 .92 r
.66912 .60401 .67357 .6089 .68285 .60626 .67842 .60135 Metetra
.656 .751 .92 r
.67842 .60135 .68285 .60626 .69216 .60361 .68776 .59869 Metetra
.656 .751 .92 r
.68776 .59869 .69216 .60361 .70151 .60094 .69712 .59601 Metetra
.656 .751 .92 r
.69712 .59601 .70151 .60094 .71088 .59828 .70651 .59332 Metetra
.656 .751 .92 r
.70651 .59332 .71088 .59828 .72029 .5956 .71594 .59063 Metetra
.656 .751 .92 r
.71594 .59063 .72029 .5956 .72972 .59291 .7254 .58792 Metetra
.656 .751 .92 r
.7254 .58792 .72972 .59291 .73919 .59021 .73489 .58521 Metetra
.656 .751 .92 r
.73489 .58521 .73919 .59021 .74869 .58751 .74441 .58249 Metetra
.656 .751 .92 r
.74441 .58249 .74869 .58751 .75822 .58479 .75396 .57976 Metetra
.656 .751 .92 r
.75396 .57976 .75822 .58479 .76778 .58207 .76355 .57702 Metetra
.656 .751 .92 r
.76355 .57702 .76778 .58207 .77737 .57934 .77316 .57427 Metetra
.656 .751 .92 r
.77316 .57427 .77737 .57934 .787 .57659 .78281 .57151 Metetra
.656 .751 .92 r
.78281 .57151 .787 .57659 .79666 .57384 .79249 .56874 Metetra
.656 .751 .92 r
.79249 .56874 .79666 .57384 .80635 .57108 .80221 .56596 Metetra
.656 .751 .92 r
.80221 .56596 .80635 .57108 .81607 .56831 .81195 .56318 Metetra
.656 .751 .92 r
.81195 .56318 .81607 .56831 .82583 .56554 .82173 .56038 Metetra
.656 .751 .92 r
.82173 .56038 .82583 .56554 .83562 .56275 .83155 .55757 Metetra
.656 .751 .92 r
.83155 .55757 .83562 .56275 .84544 .55995 .84139 .55476 Metetra
.656 .751 .92 r
.84139 .55476 .84544 .55995 .8553 .55714 .85127 .55193 Metetra
.656 .751 .92 r
.85127 .55193 .8553 .55714 .86519 .55433 .86119 .5491 Metetra
.656 .751 .92 r
.86119 .5491 .86519 .55433 .87511 .5515 .87113 .54626 Metetra
.656 .751 .92 r
.87113 .54626 .87511 .5515 .88506 .54866 .88111 .5434 Metetra
.656 .751 .92 r
.88111 .5434 .88506 .54866 .89505 .54582 .89113 .54054 Metetra
.656 .751 .92 r
.89113 .54054 .89505 .54582 .90508 .54296 .90118 .53767 Metetra
.656 .751 .92 r
.90118 .53767 .90508 .54296 .91514 .5401 .91126 .53478 Metetra
.656 .751 .92 r
.91126 .53478 .91514 .5401 .92523 .53722 .92138 .53189 Metetra
.656 .751 .92 r
.92138 .53189 .92523 .53722 .93536 .53434 .93153 .52899 Metetra
.656 .751 .92 r
.93153 .52899 .93536 .53434 .94552 .53144 .94172 .52607 Metetra
.656 .751 .92 r
.94172 .52607 .94552 .53144 .95572 .52854 .95195 .52315 Metetra
.656 .751 .92 r
.95195 .52315 .95572 .52854 .96595 .52563 .96221 .52022 Metetra
.656 .751 .92 r
.96221 .52022 .96595 .52563 .97622 .5227 .9725 .51727 Metetra
.628 .488 .673 r
.38167 .68157 .38603 .70421 .39519 .68233 .39013 .67788 Metetra
.656 .751 .92 r
.39013 .67788 .39519 .68233 .40361 .67993 .39857 .67546 Metetra
.656 .751 .92 r
.39857 .67546 .40361 .67993 .41206 .67751 .40704 .67303 Metetra
.656 .751 .92 r
.40704 .67303 .41206 .67751 .42053 .67509 .41553 .6706 Metetra
.656 .751 .92 r
.41553 .6706 .42053 .67509 .42903 .67266 .42404 .66815 Metetra
.656 .751 .92 r
.42404 .66815 .42903 .67266 .43756 .67022 .43259 .6657 Metetra
.656 .751 .92 r
.43259 .6657 .43756 .67022 .44611 .66778 .44116 .66324 Metetra
.656 .751 .92 r
.44116 .66324 .44611 .66778 .45469 .66532 .44976 .66077 Metetra
.656 .751 .92 r
.44976 .66077 .45469 .66532 .4633 .66286 .45838 .6583 Metetra
.656 .751 .92 r
.45838 .6583 .4633 .66286 .47194 .66039 .46704 .65581 Metetra
.656 .751 .92 r
.46704 .65581 .47194 .66039 .4806 .65791 .47572 .65332 Metetra
.656 .751 .92 r
.47572 .65332 .4806 .65791 .48929 .65543 .48443 .65082 Metetra
.656 .751 .92 r
.48443 .65082 .48929 .65543 .49801 .65294 .49316 .64831 Metetra
.656 .751 .92 r
.49316 .64831 .49801 .65294 .50676 .65044 .50193 .6458 Metetra
.656 .751 .92 r
.50193 .6458 .50676 .65044 .51553 .64793 .51072 .64327 Metetra
.656 .751 .92 r
.51072 .64327 .51553 .64793 .52434 .64541 .51954 .64074 Metetra
.656 .751 .92 r
.51954 .64074 .52434 .64541 .53317 .64289 .52839 .6382 Metetra
.656 .751 .92 r
.52839 .6382 .53317 .64289 .54203 .64035 .53727 .63565 Metetra
.656 .751 .92 r
.53727 .63565 .54203 .64035 .55091 .63781 .54618 .6331 Metetra
.656 .751 .92 r
.54618 .6331 .55091 .63781 .55983 .63526 .55511 .63053 Metetra
.656 .751 .92 r
.55511 .63053 .55983 .63526 .56878 .6327 .56408 .62796 Metetra
.656 .751 .92 r
.56408 .62796 .56878 .6327 .57775 .63014 .57307 .62538 Metetra
.656 .751 .92 r
.57307 .62538 .57775 .63014 .58675 .62756 .5821 .62279 Metetra
.656 .751 .92 r
.5821 .62279 .58675 .62756 .59579 .62498 .59115 .62019 Metetra
.656 .751 .92 r
.59115 .62019 .59579 .62498 .60485 .62239 .60023 .61758 Metetra
.656 .751 .92 r
.60023 .61758 .60485 .62239 .61394 .61979 .60934 .61497 Metetra
.656 .751 .92 r
.60934 .61497 .61394 .61979 .62306 .61718 .61848 .61235 Metetra
.656 .751 .92 r
.61848 .61235 .62306 .61718 .63221 .61457 .62765 .60971 Metetra
.656 .751 .92 r
.62765 .60971 .63221 .61457 .64139 .61194 .63686 .60707 Metetra
.656 .751 .92 r
.63686 .60707 .64139 .61194 .65061 .60931 .64609 .60442 Metetra
.656 .751 .92 r
.64609 .60442 .65061 .60931 .65985 .60667 .65535 .60176 Metetra
.656 .751 .92 r
.65535 .60176 .65985 .60667 .66912 .60401 .66464 .5991 Metetra
.656 .751 .92 r
.66464 .5991 .66912 .60401 .67842 .60135 .67397 .59642 Metetra
.656 .751 .92 r
.67397 .59642 .67842 .60135 .68776 .59869 .68332 .59374 Metetra
.656 .751 .92 r
.68332 .59374 .68776 .59869 .69712 .59601 .69271 .59104 Metetra
.656 .751 .92 r
.69271 .59104 .69712 .59601 .70651 .59332 .70212 .58834 Metetra
.656 .751 .92 r
.70212 .58834 .70651 .59332 .71594 .59063 .71157 .58563 Metetra
.656 .751 .92 r
.71157 .58563 .71594 .59063 .7254 .58792 .72105 .58291 Metetra
.656 .751 .92 r
.72105 .58291 .7254 .58792 .73489 .58521 .73056 .58018 Metetra
.656 .751 .92 r
.73056 .58018 .73489 .58521 .74441 .58249 .7401 .57744 Metetra
.656 .751 .92 r
.7401 .57744 .74441 .58249 .75396 .57976 .74968 .57469 Metetra
.656 .751 .92 r
.74968 .57469 .75396 .57976 .76355 .57702 .75929 .57193 Metetra
.656 .751 .92 r
.75929 .57193 .76355 .57702 .77316 .57427 .76893 .56917 Metetra
.656 .751 .92 r
.76893 .56917 .77316 .57427 .78281 .57151 .7786 .56639 Metetra
.656 .751 .92 r
.7786 .56639 .78281 .57151 .79249 .56874 .7883 .56361 Metetra
.656 .751 .92 r
.7883 .56361 .79249 .56874 .80221 .56596 .79804 .56081 Metetra
.656 .751 .92 r
.79804 .56081 .80221 .56596 .81195 .56318 .80781 .55801 Metetra
.656 .751 .92 r
.80781 .55801 .81195 .56318 .82173 .56038 .81761 .55519 Metetra
.656 .751 .92 r
.81761 .55519 .82173 .56038 .83155 .55757 .82745 .55237 Metetra
.656 .751 .92 r
.82745 .55237 .83155 .55757 .84139 .55476 .83732 .54954 Metetra
.656 .751 .92 r
.83732 .54954 .84139 .55476 .85127 .55193 .84722 .54669 Metetra
.656 .751 .92 r
.84722 .54669 .85127 .55193 .86119 .5491 .85716 .54384 Metetra
.656 .751 .92 r
.85716 .54384 .86119 .5491 .87113 .54626 .86713 .54098 Metetra
.656 .751 .92 r
.86713 .54098 .87113 .54626 .88111 .5434 .87714 .53811 Metetra
.656 .751 .92 r
.87714 .53811 .88111 .5434 .89113 .54054 .88718 .53523 Metetra
.656 .751 .92 r
.88718 .53523 .89113 .54054 .90118 .53767 .89725 .53234 Metetra
.656 .751 .92 r
.89725 .53234 .90118 .53767 .91126 .53478 .90736 .52943 Metetra
.656 .751 .92 r
.90736 .52943 .91126 .53478 .92138 .53189 .91751 .52652 Metetra
.656 .751 .92 r
.91751 .52652 .92138 .53189 .93153 .52899 .92768 .5236 Metetra
.656 .751 .92 r
.92768 .5236 .93153 .52899 .94172 .52607 .9379 .52067 Metetra
.656 .751 .92 r
.9379 .52067 .94172 .52607 .95195 .52315 .94815 .51773 Metetra
.656 .751 .92 r
.94815 .51773 .95195 .52315 .96221 .52022 .95843 .51478 Metetra
.656 .751 .92 r
.95843 .51478 .96221 .52022 .9725 .51727 .96876 .51181 Metetra
.316 .312 .696 r
.37711 .66436 .38167 .68157 .39013 .67788 .38505 .67341 Metetra
.656 .751 .92 r
.38505 .67341 .39013 .67788 .39857 .67546 .39351 .67097 Metetra
.656 .751 .92 r
.39351 .67097 .39857 .67546 .40704 .67303 .40199 .66853 Metetra
.656 .751 .92 r
.40199 .66853 .40704 .67303 .41553 .6706 .41049 .66608 Metetra
.656 .751 .92 r
.41049 .66608 .41553 .6706 .42404 .66815 .41903 .66362 Metetra
.656 .751 .92 r
.41903 .66362 .42404 .66815 .43259 .6657 .42759 .66115 Metetra
.656 .751 .92 r
.42759 .66115 .43259 .6657 .44116 .66324 .43618 .65868 Metetra
.656 .751 .92 r
.43618 .65868 .44116 .66324 .44976 .66077 .44479 .65619 Metetra
.656 .751 .92 r
.44479 .65619 .44976 .66077 .45838 .6583 .45344 .6537 Metetra
.656 .751 .92 r
.45344 .6537 .45838 .6583 .46704 .65581 .46211 .65121 Metetra
.656 .751 .92 r
.46211 .65121 .46704 .65581 .47572 .65332 .47081 .6487 Metetra
.656 .751 .92 r
.47081 .6487 .47572 .65332 .48443 .65082 .47953 .64619 Metetra
.656 .751 .92 r
.47953 .64619 .48443 .65082 .49316 .64831 .48829 .64366 Metetra
.656 .751 .92 r
.48829 .64366 .49316 .64831 .50193 .6458 .49707 .64113 Metetra
.656 .751 .92 r
.49707 .64113 .50193 .6458 .51072 .64327 .50588 .63859 Metetra
.656 .751 .92 r
.50588 .63859 .51072 .64327 .51954 .64074 .51472 .63605 Metetra
.656 .751 .92 r
.51472 .63605 .51954 .64074 .52839 .6382 .52359 .63349 Metetra
.656 .751 .92 r
.52359 .63349 .52839 .6382 .53727 .63565 .53249 .63093 Metetra
.656 .751 .92 r
.53249 .63093 .53727 .63565 .54618 .6331 .54141 .62836 Metetra
.656 .751 .92 r
.54141 .62836 .54618 .6331 .55511 .63053 .55037 .62578 Metetra
.656 .751 .92 r
.55037 .62578 .55511 .63053 .56408 .62796 .55935 .62319 Metetra
.656 .751 .92 r
.55935 .62319 .56408 .62796 .57307 .62538 .56837 .62059 Metetra
.656 .751 .92 r
.56837 .62059 .57307 .62538 .5821 .62279 .57741 .61799 Metetra
.656 .751 .92 r
.57741 .61799 .5821 .62279 .59115 .62019 .58648 .61537 Metetra
.656 .751 .92 r
.58648 .61537 .59115 .62019 .60023 .61758 .59558 .61275 Metetra
.656 .751 .92 r
.59558 .61275 .60023 .61758 .60934 .61497 .60471 .61012 Metetra
.656 .751 .92 r
.60471 .61012 .60934 .61497 .61848 .61235 .61387 .60748 Metetra
.656 .751 .92 r
.61387 .60748 .61848 .61235 .62765 .60971 .62307 .60483 Metetra
.656 .751 .92 r
.62307 .60483 .62765 .60971 .63686 .60707 .63229 .60217 Metetra
.656 .751 .92 r
.63229 .60217 .63686 .60707 .64609 .60442 .64154 .59951 Metetra
.656 .751 .92 r
.64154 .59951 .64609 .60442 .65535 .60176 .65082 .59683 Metetra
.656 .751 .92 r
.65082 .59683 .65535 .60176 .66464 .5991 .66014 .59415 Metetra
.656 .751 .92 r
.66014 .59415 .66464 .5991 .67397 .59642 .66948 .59146 Metetra
.656 .751 .92 r
.66948 .59146 .67397 .59642 .68332 .59374 .67886 .58876 Metetra
.656 .751 .92 r
.67886 .58876 .68332 .59374 .69271 .59104 .68826 .58605 Metetra
.656 .751 .92 r
.68826 .58605 .69271 .59104 .70212 .58834 .6977 .58333 Metetra
.656 .751 .92 r
.6977 .58333 .70212 .58834 .71157 .58563 .70717 .5806 Metetra
.656 .751 .92 r
.70717 .5806 .71157 .58563 .72105 .58291 .71667 .57786 Metetra
.656 .751 .92 r
.71667 .57786 .72105 .58291 .73056 .58018 .72621 .57511 Metetra
.656 .751 .92 r
.72621 .57511 .73056 .58018 .7401 .57744 .73577 .57236 Metetra
.656 .751 .92 r
.73577 .57236 .7401 .57744 .74968 .57469 .74537 .56959 Metetra
.656 .751 .92 r
.74537 .56959 .74968 .57469 .75929 .57193 .755 .56682 Metetra
.656 .751 .92 r
.755 .56682 .75929 .57193 .76893 .56917 .76466 .56403 Metetra
.656 .751 .92 r
.76466 .56403 .76893 .56917 .7786 .56639 .77436 .56124 Metetra
.656 .751 .92 r
.77436 .56124 .7786 .56639 .7883 .56361 .78408 .55844 Metetra
.656 .751 .92 r
.78408 .55844 .7883 .56361 .79804 .56081 .79384 .55563 Metetra
.656 .751 .92 r
.79384 .55563 .79804 .56081 .80781 .55801 .80364 .55281 Metetra
.656 .751 .92 r
.80364 .55281 .80781 .55801 .81761 .55519 .81347 .54997 Metetra
.656 .751 .92 r
.81347 .54997 .81761 .55519 .82745 .55237 .82333 .54713 Metetra
.656 .751 .92 r
.82333 .54713 .82745 .55237 .83732 .54954 .83322 .54428 Metetra
.656 .751 .92 r
.83322 .54428 .83732 .54954 .84722 .54669 .84315 .54142 Metetra
.656 .751 .92 r
.84315 .54142 .84722 .54669 .85716 .54384 .85311 .53855 Metetra
.656 .751 .92 r
.85311 .53855 .85716 .54384 .86713 .54098 .86311 .53567 Metetra
.656 .751 .92 r
.86311 .53567 .86713 .54098 .87714 .53811 .87314 .53278 Metetra
.656 .751 .92 r
.87314 .53278 .87714 .53811 .88718 .53523 .8832 .52988 Metetra
.656 .751 .92 r
.8832 .52988 .88718 .53523 .89725 .53234 .8933 .52697 Metetra
.656 .751 .92 r
.8933 .52697 .89725 .53234 .90736 .52943 .90344 .52405 Metetra
.656 .751 .92 r
.90344 .52405 .90736 .52943 .91751 .52652 .91361 .52112 Metetra
.656 .751 .92 r
.91361 .52112 .91751 .52652 .92768 .5236 .92381 .51818 Metetra
.656 .751 .92 r
.92381 .51818 .92768 .5236 .9379 .52067 .93405 .51523 Metetra
.656 .751 .92 r
.93405 .51523 .9379 .52067 .94815 .51773 .94433 .51227 Metetra
.656 .751 .92 r
.94433 .51227 .94815 .51773 .95843 .51478 .95464 .5093 Metetra
.656 .751 .92 r
.95464 .5093 .95843 .51478 .96876 .51181 .96499 .50632 Metetra
.106 0 .219 r
.37096 .68347 .37711 .66436 .38505 .67341 .37994 .6689 Metetra
.656 .751 .92 r
.37994 .6689 .38505 .67341 .39351 .67097 .38841 .66645 Metetra
.656 .751 .92 r
.38841 .66645 .39351 .67097 .40199 .66853 .39691 .664 Metetra
.656 .751 .92 r
.39691 .664 .40199 .66853 .41049 .66608 .40543 .66153 Metetra
.656 .751 .92 r
.40543 .66153 .41049 .66608 .41903 .66362 .41398 .65906 Metetra
.656 .751 .92 r
.41398 .65906 .41903 .66362 .42759 .66115 .42256 .65658 Metetra
.656 .751 .92 r
.42256 .65658 .42759 .66115 .43618 .65868 .43117 .65409 Metetra
.656 .751 .92 r
.43117 .65409 .43618 .65868 .44479 .65619 .4398 .65159 Metetra
.656 .751 .92 r
.4398 .65159 .44479 .65619 .45344 .6537 .44846 .64909 Metetra
.656 .751 .92 r
.44846 .64909 .45344 .6537 .46211 .65121 .45715 .64657 Metetra
.656 .751 .92 r
.45715 .64657 .46211 .65121 .47081 .6487 .46587 .64405 Metetra
.656 .751 .92 r
.46587 .64405 .47081 .6487 .47953 .64619 .47461 .64152 Metetra
.656 .751 .92 r
.47461 .64152 .47953 .64619 .48829 .64366 .48338 .63898 Metetra
.656 .751 .92 r
.48338 .63898 .48829 .64366 .49707 .64113 .49219 .63644 Metetra
.656 .751 .92 r
.49219 .63644 .49707 .64113 .50588 .63859 .50102 .63389 Metetra
.656 .751 .92 r
.50102 .63389 .50588 .63859 .51472 .63605 .50987 .63132 Metetra
.656 .751 .92 r
.50987 .63132 .51472 .63605 .52359 .63349 .51876 .62875 Metetra
.656 .751 .92 r
.51876 .62875 .52359 .63349 .53249 .63093 .52768 .62617 Metetra
.656 .751 .92 r
.52768 .62617 .53249 .63093 .54141 .62836 .53662 .62359 Metetra
.656 .751 .92 r
.53662 .62359 .54141 .62836 .55037 .62578 .54559 .62099 Metetra
.656 .751 .92 r
.54559 .62099 .55037 .62578 .55935 .62319 .5546 .61839 Metetra
.656 .751 .92 r
.5546 .61839 .55935 .62319 .56837 .62059 .56363 .61578 Metetra
.656 .751 .92 r
.56363 .61578 .56837 .62059 .57741 .61799 .57269 .61315 Metetra
.656 .751 .92 r
.57269 .61315 .57741 .61799 .58648 .61537 .58178 .61052 Metetra
.656 .751 .92 r
.58178 .61052 .58648 .61537 .59558 .61275 .59091 .60789 Metetra
.656 .751 .92 r
.59091 .60789 .59558 .61275 .60471 .61012 .60006 .60524 Metetra
.656 .751 .92 r
.60006 .60524 .60471 .61012 .61387 .60748 .60924 .60258 Metetra
.656 .751 .92 r
.60924 .60258 .61387 .60748 .62307 .60483 .61845 .59992 Metetra
.656 .751 .92 r
.61845 .59992 .62307 .60483 .63229 .60217 .62769 .59725 Metetra
.656 .751 .92 r
.62769 .59725 .63229 .60217 .64154 .59951 .63697 .59456 Metetra
.656 .751 .92 r
.63697 .59456 .64154 .59951 .65082 .59683 .64627 .59187 Metetra
.656 .751 .92 r
.64627 .59187 .65082 .59683 .66014 .59415 .65561 .58917 Metetra
.656 .751 .92 r
.65561 .58917 .66014 .59415 .66948 .59146 .66497 .58646 Metetra
.656 .751 .92 r
.66497 .58646 .66948 .59146 .67886 .58876 .67437 .58375 Metetra
.656 .751 .92 r
.67437 .58375 .67886 .58876 .68826 .58605 .6838 .58102 Metetra
.656 .751 .92 r
.6838 .58102 .68826 .58605 .6977 .58333 .69326 .57828 Metetra
.656 .751 .92 r
.69326 .57828 .6977 .58333 .70717 .5806 .70275 .57554 Metetra
.656 .751 .92 r
.70275 .57554 .70717 .5806 .71667 .57786 .71227 .57278 Metetra
.656 .751 .92 r
.71227 .57278 .71667 .57786 .72621 .57511 .72183 .57002 Metetra
.656 .751 .92 r
.72183 .57002 .72621 .57511 .73577 .57236 .73141 .56725 Metetra
.656 .751 .92 r
.73141 .56725 .73577 .57236 .74537 .56959 .74103 .56446 Metetra
.656 .751 .92 r
.74103 .56446 .74537 .56959 .755 .56682 .75069 .56167 Metetra
.656 .751 .92 r
.75069 .56167 .755 .56682 .76466 .56403 .76037 .55887 Metetra
.656 .751 .92 r
.76037 .55887 .76466 .56403 .77436 .56124 .77009 .55606 Metetra
.656 .751 .92 r
.77009 .55606 .77436 .56124 .78408 .55844 .77984 .55324 Metetra
.656 .751 .92 r
.77984 .55324 .78408 .55844 .79384 .55563 .78962 .55041 Metetra
.656 .751 .92 r
.78962 .55041 .79384 .55563 .80364 .55281 .79944 .54757 Metetra
.656 .751 .92 r
.79944 .54757 .80364 .55281 .81347 .54997 .80929 .54472 Metetra
.656 .751 .92 r
.80929 .54472 .81347 .54997 .82333 .54713 .81918 .54186 Metetra
.656 .751 .92 r
.81918 .54186 .82333 .54713 .83322 .54428 .82909 .53899 Metetra
.656 .751 .92 r
.82909 .53899 .83322 .54428 .84315 .54142 .83905 .53612 Metetra
.656 .751 .92 r
.83905 .53612 .84315 .54142 .85311 .53855 .84903 .53323 Metetra
.656 .751 .92 r
.84903 .53323 .85311 .53855 .86311 .53567 .85905 .53033 Metetra
.656 .751 .92 r
.85905 .53033 .86311 .53567 .87314 .53278 .86911 .52742 Metetra
.656 .751 .92 r
.86911 .52742 .87314 .53278 .8832 .52988 .8792 .5245 Metetra
.656 .751 .92 r
.8792 .5245 .8832 .52988 .8933 .52697 .88933 .52157 Metetra
.656 .751 .92 r
.88933 .52157 .8933 .52697 .90344 .52405 .89949 .51863 Metetra
.656 .751 .92 r
.89949 .51863 .90344 .52405 .91361 .52112 .90968 .51569 Metetra
.656 .751 .92 r
.90968 .51569 .91361 .52112 .92381 .51818 .91991 .51273 Metetra
.656 .751 .92 r
.91991 .51273 .92381 .51818 .93405 .51523 .93018 .50976 Metetra
.656 .751 .92 r
.93018 .50976 .93405 .51523 .94433 .51227 .94048 .50678 Metetra
.656 .751 .92 r
.94048 .50678 .94433 .51227 .95464 .5093 .95082 .50379 Metetra
.656 .751 .92 r
.95082 .50379 .95464 .5093 .96499 .50632 .96119 .50079 Metetra
.509 .406 .673 r
.36664 .66021 .37096 .68347 .37994 .6689 .3748 .66438 Metetra
.656 .751 .92 r
.3748 .66438 .37994 .6689 .38841 .66645 .38328 .66191 Metetra
.656 .751 .92 r
.38328 .66191 .38841 .66645 .39691 .664 .3918 .65944 Metetra
.656 .751 .92 r
.3918 .65944 .39691 .664 .40543 .66153 .40034 .65696 Metetra
.656 .751 .92 r
.40034 .65696 .40543 .66153 .41398 .65906 .40891 .65447 Metetra
.656 .751 .92 r
.40891 .65447 .41398 .65906 .42256 .65658 .4175 .65198 Metetra
.656 .751 .92 r
.4175 .65198 .42256 .65658 .43117 .65409 .42613 .64947 Metetra
.656 .751 .92 r
.42613 .64947 .43117 .65409 .4398 .65159 .43478 .64696 Metetra
.656 .751 .92 r
.43478 .64696 .4398 .65159 .44846 .64909 .44346 .64444 Metetra
.656 .751 .92 r
.44346 .64444 .44846 .64909 .45715 .64657 .45216 .64191 Metetra
.656 .751 .92 r
.45216 .64191 .45715 .64657 .46587 .64405 .4609 .63938 Metetra
.656 .751 .92 r
.4609 .63938 .46587 .64405 .47461 .64152 .46966 .63683 Metetra
.656 .751 .92 r
.46966 .63683 .47461 .64152 .48338 .63898 .47845 .63428 Metetra
.656 .751 .92 r
.47845 .63428 .48338 .63898 .49219 .63644 .48727 .63172 Metetra
.656 .751 .92 r
.48727 .63172 .49219 .63644 .50102 .63389 .49612 .62915 Metetra
.656 .751 .92 r
.49612 .62915 .50102 .63389 .50987 .63132 .505 .62657 Metetra
.656 .751 .92 r
.505 .62657 .50987 .63132 .51876 .62875 .5139 .62399 Metetra
.656 .751 .92 r
.5139 .62399 .51876 .62875 .52768 .62617 .52284 .62139 Metetra
.656 .751 .92 r
.52284 .62139 .52768 .62617 .53662 .62359 .5318 .61879 Metetra
.656 .751 .92 r
.5318 .61879 .53662 .62359 .54559 .62099 .54079 .61618 Metetra
.656 .751 .92 r
.54079 .61618 .54559 .62099 .5546 .61839 .54981 .61356 Metetra
.656 .751 .92 r
.54981 .61356 .5546 .61839 .56363 .61578 .55887 .61093 Metetra
.656 .751 .92 r
.55887 .61093 .56363 .61578 .57269 .61315 .56795 .60829 Metetra
.656 .751 .92 r
.56795 .60829 .57269 .61315 .58178 .61052 .57706 .60565 Metetra
.656 .751 .92 r
.57706 .60565 .58178 .61052 .59091 .60789 .5862 .60299 Metetra
.656 .751 .92 r
.5862 .60299 .59091 .60789 .60006 .60524 .59537 .60033 Metetra
.656 .751 .92 r
.59537 .60033 .60006 .60524 .60924 .60258 .60457 .59766 Metetra
.656 .751 .92 r
.60457 .59766 .60924 .60258 .61845 .59992 .61381 .59498 Metetra
.656 .751 .92 r
.61381 .59498 .61845 .59992 .62769 .59725 .62307 .59229 Metetra
.656 .751 .92 r
.62307 .59229 .62769 .59725 .63697 .59456 .63236 .58959 Metetra
.656 .751 .92 r
.63236 .58959 .63697 .59456 .64627 .59187 .64169 .58688 Metetra
.656 .751 .92 r
.64169 .58688 .64627 .59187 .65561 .58917 .65104 .58416 Metetra
.656 .751 .92 r
.65104 .58416 .65561 .58917 .66497 .58646 .66043 .58144 Metetra
.656 .751 .92 r
.66043 .58144 .66497 .58646 .67437 .58375 .66985 .5787 Metetra
.656 .751 .92 r
.66985 .5787 .67437 .58375 .6838 .58102 .6793 .57596 Metetra
.656 .751 .92 r
.6793 .57596 .6838 .58102 .69326 .57828 .68878 .57321 Metetra
.656 .751 .92 r
.68878 .57321 .69326 .57828 .70275 .57554 .6983 .57045 Metetra
.656 .751 .92 r
.6983 .57045 .70275 .57554 .71227 .57278 .70784 .56767 Metetra
.656 .751 .92 r
.70784 .56767 .71227 .57278 .72183 .57002 .71742 .56489 Metetra
.656 .751 .92 r
.71742 .56489 .72183 .57002 .73141 .56725 .72703 .5621 Metetra
.656 .751 .92 r
.72703 .5621 .73141 .56725 .74103 .56446 .73667 .5593 Metetra
.656 .751 .92 r
.73667 .5593 .74103 .56446 .75069 .56167 .74635 .55649 Metetra
.656 .751 .92 r
.74635 .55649 .75069 .56167 .76037 .55887 .75605 .55367 Metetra
.656 .751 .92 r
.75605 .55367 .76037 .55887 .77009 .55606 .76579 .55085 Metetra
.656 .751 .92 r
.76579 .55085 .77009 .55606 .77984 .55324 .77557 .54801 Metetra
.656 .751 .92 r
.77557 .54801 .77984 .55324 .78962 .55041 .78538 .54516 Metetra
.656 .751 .92 r
.78538 .54516 .78962 .55041 .79944 .54757 .79522 .5423 Metetra
.656 .751 .92 r
.79522 .5423 .79944 .54757 .80929 .54472 .80509 .53944 Metetra
.656 .751 .92 r
.80509 .53944 .80929 .54472 .81918 .54186 .815 .53656 Metetra
.656 .751 .92 r
.815 .53656 .81918 .54186 .82909 .53899 .82494 .53367 Metetra
.656 .751 .92 r
.82494 .53367 .82909 .53899 .83905 .53612 .83492 .53077 Metetra
.656 .751 .92 r
.83492 .53077 .83905 .53612 .84903 .53323 .84493 .52787 Metetra
.656 .751 .92 r
.84493 .52787 .84903 .53323 .85905 .53033 .85498 .52495 Metetra
.656 .751 .92 r
.85498 .52495 .85905 .53033 .86911 .52742 .86506 .52202 Metetra
.656 .751 .92 r
.86506 .52202 .86911 .52742 .8792 .5245 .87517 .51909 Metetra
.656 .751 .92 r
.87517 .51909 .8792 .5245 .88933 .52157 .88532 .51614 Metetra
.656 .751 .92 r
.88532 .51614 .88933 .52157 .89949 .51863 .89551 .51318 Metetra
.656 .751 .92 r
.89551 .51318 .89949 .51863 .90968 .51569 .90573 .51021 Metetra
.656 .751 .92 r
.90573 .51021 .90968 .51569 .91991 .51273 .91599 .50724 Metetra
.656 .751 .92 r
.91599 .50724 .91991 .51273 .93018 .50976 .92628 .50425 Metetra
.656 .751 .92 r
.92628 .50425 .93018 .50976 .94048 .50678 .93661 .50125 Metetra
.656 .751 .92 r
.93661 .50125 .94048 .50678 .95082 .50379 .94697 .49824 Metetra
.656 .751 .92 r
.94697 .49824 .95082 .50379 .96119 .50079 .95738 .49522 Metetra
.36115 .66213 .36664 .66021 .3748 .66438 .36962 .65982 Metetra
.656 .751 .92 r
.36962 .65982 .3748 .66438 .38328 .66191 .37813 .65734 Metetra
.656 .751 .92 r
.37813 .65734 .38328 .66191 .3918 .65944 .38666 .65485 Metetra
.656 .751 .92 r
.38666 .65485 .3918 .65944 .40034 .65696 .39522 .65236 Metetra
.656 .751 .92 r
.39522 .65236 .40034 .65696 .40891 .65447 .4038 .64986 Metetra
.656 .751 .92 r
.4038 .64986 .40891 .65447 .4175 .65198 .41242 .64735 Metetra
.656 .751 .92 r
.41242 .64735 .4175 .65198 .42613 .64947 .42106 .64483 Metetra
.656 .751 .92 r
.42106 .64483 .42613 .64947 .43478 .64696 .42972 .6423 Metetra
.656 .751 .92 r
.42972 .6423 .43478 .64696 .44346 .64444 .43842 .63977 Metetra
.656 .751 .92 r
.43842 .63977 .44346 .64444 .45216 .64191 .44715 .63722 Metetra
.656 .751 .92 r
.44715 .63722 .45216 .64191 .4609 .63938 .4559 .63467 Metetra
.656 .751 .92 r
.4559 .63467 .4609 .63938 .46966 .63683 .46468 .63211 Metetra
.656 .751 .92 r
.46468 .63211 .46966 .63683 .47845 .63428 .47349 .62954 Metetra
.656 .751 .92 r
.47349 .62954 .47845 .63428 .48727 .63172 .48233 .62697 Metetra
.656 .751 .92 r
.48233 .62697 .48727 .63172 .49612 .62915 .49119 .62438 Metetra
.656 .751 .92 r
.49119 .62438 .49612 .62915 .505 .62657 .50009 .62179 Metetra
.656 .751 .92 r
.50009 .62179 .505 .62657 .5139 .62399 .50901 .61919 Metetra
.656 .751 .92 r
.50901 .61919 .5139 .62399 .52284 .62139 .51797 .61658 Metetra
.656 .751 .92 r
.51797 .61658 .52284 .62139 .5318 .61879 .52695 .61396 Metetra
.656 .751 .92 r
.52695 .61396 .5318 .61879 .54079 .61618 .53596 .61133 Metetra
.656 .751 .92 r
.53596 .61133 .54079 .61618 .54981 .61356 .545 .6087 Metetra
.656 .751 .92 r
.545 .6087 .54981 .61356 .55887 .61093 .55407 .60605 Metetra
.656 .751 .92 r
.55407 .60605 .55887 .61093 .56795 .60829 .56317 .6034 Metetra
.656 .751 .92 r
.56317 .6034 .56795 .60829 .57706 .60565 .57231 .60074 Metetra
.656 .751 .92 r
.57231 .60074 .57706 .60565 .5862 .60299 .58147 .59807 Metetra
.656 .751 .92 r
.58147 .59807 .5862 .60299 .59537 .60033 .59066 .59539 Metetra
.656 .751 .92 r
.59066 .59539 .59537 .60033 .60457 .59766 .59988 .5927 Metetra
.656 .751 .92 r
.59988 .5927 .60457 .59766 .61381 .59498 .60914 .59 Metetra
.656 .751 .92 r
.60914 .59 .61381 .59498 .62307 .59229 .61842 .5873 Metetra
.656 .751 .92 r
.61842 .5873 .62307 .59229 .63236 .58959 .62773 .58458 Metetra
.656 .751 .92 r
.62773 .58458 .63236 .58959 .64169 .58688 .63708 .58186 Metetra
.656 .751 .92 r
.63708 .58186 .64169 .58688 .65104 .58416 .64646 .57913 Metetra
.656 .751 .92 r
.64646 .57913 .65104 .58416 .66043 .58144 .65586 .57638 Metetra
.656 .751 .92 r
.65586 .57638 .66043 .58144 .66985 .5787 .6653 .57363 Metetra
.656 .751 .92 r
.6653 .57363 .66985 .5787 .6793 .57596 .67478 .57087 Metetra
.656 .751 .92 r
.67478 .57087 .6793 .57596 .68878 .57321 .68428 .5681 Metetra
.656 .751 .92 r
.68428 .5681 .68878 .57321 .6983 .57045 .69381 .56532 Metetra
.656 .751 .92 r
.69381 .56532 .6983 .57045 .70784 .56767 .70338 .56253 Metetra
.656 .751 .92 r
.70338 .56253 .70784 .56767 .71742 .56489 .71298 .55973 Metetra
.656 .751 .92 r
.71298 .55973 .71742 .56489 .72703 .5621 .72262 .55693 Metetra
.656 .751 .92 r
.72262 .55693 .72703 .5621 .73667 .5593 .73228 .55411 Metetra
.656 .751 .92 r
.73228 .55411 .73667 .5593 .74635 .55649 .74198 .55128 Metetra
.656 .751 .92 r
.74198 .55128 .74635 .55649 .75605 .55367 .75171 .54845 Metetra
.656 .751 .92 r
.75171 .54845 .75605 .55367 .76579 .55085 .76147 .5456 Metetra
.656 .751 .92 r
.76147 .5456 .76579 .55085 .77557 .54801 .77127 .54274 Metetra
.656 .751 .92 r
.77127 .54274 .77557 .54801 .78538 .54516 .7811 .53988 Metetra
.656 .751 .92 r
.7811 .53988 .78538 .54516 .79522 .5423 .79097 .537 Metetra
.656 .751 .92 r
.79097 .537 .79522 .5423 .80509 .53944 .80087 .53412 Metetra
.656 .751 .92 r
.80087 .53412 .80509 .53944 .815 .53656 .8108 .53122 Metetra
.656 .751 .92 r
.8108 .53122 .815 .53656 .82494 .53367 .82077 .52832 Metetra
.656 .751 .92 r
.82077 .52832 .82494 .53367 .83492 .53077 .83077 .5254 Metetra
.656 .751 .92 r
.83077 .5254 .83492 .53077 .84493 .52787 .8408 .52248 Metetra
.656 .751 .92 r
.8408 .52248 .84493 .52787 .85498 .52495 .85087 .51954 Metetra
.656 .751 .92 r
.85087 .51954 .85498 .52495 .86506 .52202 .86098 .51659 Metetra
.656 .751 .92 r
.86098 .51659 .86506 .52202 .87517 .51909 .87112 .51364 Metetra
.656 .751 .92 r
.87112 .51364 .87517 .51909 .88532 .51614 .8813 .51067 Metetra
.656 .751 .92 r
.8813 .51067 .88532 .51614 .89551 .51318 .89151 .50769 Metetra
.656 .751 .92 r
.89151 .50769 .89551 .51318 .90573 .51021 .90175 .50471 Metetra
.656 .751 .92 r
.90175 .50471 .90573 .51021 .91599 .50724 .91204 .50171 Metetra
.656 .751 .92 r
.91204 .50171 .91599 .50724 .92628 .50425 .92236 .4987 Metetra
.656 .751 .92 r
.92236 .4987 .92628 .50425 .93661 .50125 .93271 .49568 Metetra
.656 .751 .92 r
.93271 .49568 .93661 .50125 .94697 .49824 .9431 .49265 Metetra
.656 .751 .92 r
.9431 .49265 .94697 .49824 .95738 .49522 .95353 .48962 Metetra
.823 .965 .897 r
.3557 .6624 .36115 .66213 .36962 .65982 .36442 .65524 Metetra
.656 .751 .92 r
.36442 .65524 .36962 .65982 .37813 .65734 .37294 .65274 Metetra
.656 .751 .92 r
.37294 .65274 .37813 .65734 .38666 .65485 .38149 .65024 Metetra
.656 .751 .92 r
.38149 .65024 .38666 .65485 .39522 .65236 .39006 .64773 Metetra
.656 .751 .92 r
.39006 .64773 .39522 .65236 .4038 .64986 .39867 .64522 Metetra
.656 .751 .92 r
.39867 .64522 .4038 .64986 .41242 .64735 .4073 .64269 Metetra
.656 .751 .92 r
.4073 .64269 .41242 .64735 .42106 .64483 .41596 .64016 Metetra
.656 .751 .92 r
.41596 .64016 .42106 .64483 .42972 .6423 .42464 .63762 Metetra
.656 .751 .92 r
.42464 .63762 .42972 .6423 .43842 .63977 .43336 .63507 Metetra
.656 .751 .92 r
.43336 .63507 .43842 .63977 .44715 .63722 .4421 .63251 Metetra
.656 .751 .92 r
.4421 .63251 .44715 .63722 .4559 .63467 .45087 .62994 Metetra
.656 .751 .92 r
.45087 .62994 .4559 .63467 .46468 .63211 .45967 .62737 Metetra
.656 .751 .92 r
.45967 .62737 .46468 .63211 .47349 .62954 .46849 .62478 Metetra
.656 .751 .92 r
.46849 .62478 .47349 .62954 .48233 .62697 .47735 .62219 Metetra
.656 .751 .92 r
.47735 .62219 .48233 .62697 .49119 .62438 .48624 .61959 Metetra
.656 .751 .92 r
.48624 .61959 .49119 .62438 .50009 .62179 .49515 .61698 Metetra
.656 .751 .92 r
.49515 .61698 .50009 .62179 .50901 .61919 .50409 .61436 Metetra
.656 .751 .92 r
.50409 .61436 .50901 .61919 .51797 .61658 .51307 .61174 Metetra
.656 .751 .92 r
.51307 .61174 .51797 .61658 .52695 .61396 .52207 .6091 Metetra
.656 .751 .92 r
.52207 .6091 .52695 .61396 .53596 .61133 .5311 .60646 Metetra
.656 .751 .92 r
.5311 .60646 .53596 .61133 .545 .6087 .54016 .60381 Metetra
.656 .751 .92 r
.54016 .60381 .545 .6087 .55407 .60605 .54925 .60115 Metetra
.656 .751 .92 r
.54925 .60115 .55407 .60605 .56317 .6034 .55837 .59848 Metetra
.656 .751 .92 r
.55837 .59848 .56317 .6034 .57231 .60074 .56752 .5958 Metetra
.656 .751 .92 r
.56752 .5958 .57231 .60074 .58147 .59807 .57671 .59312 Metetra
.656 .751 .92 r
.57671 .59312 .58147 .59807 .59066 .59539 .58592 .59042 Metetra
.656 .751 .92 r
.58592 .59042 .59066 .59539 .59988 .5927 .59516 .58772 Metetra
.656 .751 .92 r
.59516 .58772 .59988 .5927 .60914 .59 .60443 .585 Metetra
.656 .751 .92 r
.60443 .585 .60914 .59 .61842 .5873 .61374 .58228 Metetra
.656 .751 .92 r
.61374 .58228 .61842 .5873 .62773 .58458 .62307 .57955 Metetra
.656 .751 .92 r
.62307 .57955 .62773 .58458 .63708 .58186 .63244 .57681 Metetra
.656 .751 .92 r
.63244 .57681 .63708 .58186 .64646 .57913 .64184 .57406 Metetra
.656 .751 .92 r
.64184 .57406 .64646 .57913 .65586 .57638 .65127 .5713 Metetra
.656 .751 .92 r
.65127 .5713 .65586 .57638 .6653 .57363 .66073 .56853 Metetra
.656 .751 .92 r
.66073 .56853 .6653 .57363 .67478 .57087 .67022 .56575 Metetra
.656 .751 .92 r
.67022 .56575 .67478 .57087 .68428 .5681 .67975 .56296 Metetra
.656 .751 .92 r
.67975 .56296 .68428 .5681 .69381 .56532 .68931 .56016 Metetra
.656 .751 .92 r
.68931 .56016 .69381 .56532 .70338 .56253 .6989 .55736 Metetra
.656 .751 .92 r
.6989 .55736 .70338 .56253 .71298 .55973 .70852 .55454 Metetra
.656 .751 .92 r
.70852 .55454 .71298 .55973 .72262 .55693 .71817 .55172 Metetra
.656 .751 .92 r
.71817 .55172 .72262 .55693 .73228 .55411 .72786 .54888 Metetra
.656 .751 .92 r
.72786 .54888 .73228 .55411 .74198 .55128 .73758 .54604 Metetra
.656 .751 .92 r
.73758 .54604 .74198 .55128 .75171 .54845 .74734 .54318 Metetra
.656 .751 .92 r
.74734 .54318 .75171 .54845 .76147 .5456 .75713 .54032 Metetra
.656 .751 .92 r
.75713 .54032 .76147 .5456 .77127 .54274 .76695 .53744 Metetra
.656 .751 .92 r
.76695 .53744 .77127 .54274 .7811 .53988 .7768 .53456 Metetra
.656 .751 .92 r
.7768 .53456 .7811 .53988 .79097 .537 .78669 .53167 Metetra
.656 .751 .92 r
.78669 .53167 .79097 .537 .80087 .53412 .79661 .52876 Metetra
.656 .751 .92 r
.79661 .52876 .80087 .53412 .8108 .53122 .80657 .52585 Metetra
.656 .751 .92 r
.80657 .52585 .8108 .53122 .82077 .52832 .81656 .52293 Metetra
.656 .751 .92 r
.81656 .52293 .82077 .52832 .83077 .5254 .82659 .51999 Metetra
.656 .751 .92 r
.82659 .51999 .83077 .5254 .8408 .52248 .83665 .51705 Metetra
.656 .751 .92 r
.83665 .51705 .8408 .52248 .85087 .51954 .84674 .51409 Metetra
.656 .751 .92 r
.84674 .51409 .85087 .51954 .86098 .51659 .85687 .51113 Metetra
.656 .751 .92 r
.85687 .51113 .86098 .51659 .87112 .51364 .86704 .50815 Metetra
.656 .751 .92 r
.86704 .50815 .87112 .51364 .8813 .51067 .87724 .50517 Metetra
.656 .751 .92 r
.87724 .50517 .8813 .51067 .89151 .50769 .88748 .50217 Metetra
.656 .751 .92 r
.88748 .50217 .89151 .50769 .90175 .50471 .89775 .49917 Metetra
.656 .751 .92 r
.89775 .49917 .90175 .50471 .91204 .50171 .90806 .49615 Metetra
.656 .751 .92 r
.90806 .49615 .91204 .50171 .92236 .4987 .91841 .49312 Metetra
.656 .751 .92 r
.91841 .49312 .92236 .4987 .93271 .49568 .92879 .49008 Metetra
.656 .751 .92 r
.92879 .49008 .93271 .49568 .9431 .49265 .93921 .48703 Metetra
.656 .751 .92 r
.93921 .48703 .9431 .49265 .95353 .48962 .94967 .48397 Metetra
.494 .453 .741 r
.35095 .6477 .3557 .6624 .36442 .65524 .35919 .65063 Metetra
.656 .751 .92 r
.35919 .65063 .36442 .65524 .37294 .65274 .36772 .64812 Metetra
.656 .751 .92 r
.36772 .64812 .37294 .65274 .38149 .65024 .37629 .6456 Metetra
.656 .751 .92 r
.37629 .6456 .38149 .65024 .39006 .64773 .38488 .64308 Metetra
.656 .751 .92 r
.38488 .64308 .39006 .64773 .39867 .64522 .3935 .64055 Metetra
.656 .751 .92 r
.3935 .64055 .39867 .64522 .4073 .64269 .40215 .63801 Metetra
.656 .751 .92 r
.40215 .63801 .4073 .64269 .41596 .64016 .41082 .63546 Metetra
.656 .751 .92 r
.41082 .63546 .41596 .64016 .42464 .63762 .41953 .6329 Metetra
.656 .751 .92 r
.41953 .6329 .42464 .63762 .43336 .63507 .42826 .63034 Metetra
.656 .751 .92 r
.42826 .63034 .43336 .63507 .4421 .63251 .43702 .62776 Metetra
.656 .751 .92 r
.43702 .62776 .4421 .63251 .45087 .62994 .44581 .62518 Metetra
.656 .751 .92 r
.44581 .62518 .45087 .62994 .45967 .62737 .45463 .62259 Metetra
.656 .751 .92 r
.45463 .62259 .45967 .62737 .46849 .62478 .46347 .61999 Metetra
.656 .751 .92 r
.46347 .61999 .46849 .62478 .47735 .62219 .47235 .61738 Metetra
.656 .751 .92 r
.47235 .61738 .47735 .62219 .48624 .61959 .48125 .61477 Metetra
.656 .751 .92 r
.48125 .61477 .48624 .61959 .49515 .61698 .49018 .61214 Metetra
.656 .751 .92 r
.49018 .61214 .49515 .61698 .50409 .61436 .49914 .60951 Metetra
.656 .751 .92 r
.49914 .60951 .50409 .61436 .51307 .61174 .50814 .60687 Metetra
.656 .751 .92 r
.50814 .60687 .51307 .61174 .52207 .6091 .51716 .60422 Metetra
.656 .751 .92 r
.51716 .60422 .52207 .6091 .5311 .60646 .52621 .60156 Metetra
.656 .751 .92 r
.52621 .60156 .5311 .60646 .54016 .60381 .53529 .59889 Metetra
.656 .751 .92 r
.53529 .59889 .54016 .60381 .54925 .60115 .5444 .59622 Metetra
.656 .751 .92 r
.5444 .59622 .54925 .60115 .55837 .59848 .55354 .59353 Metetra
.656 .751 .92 r
.55354 .59353 .55837 .59848 .56752 .5958 .56271 .59084 Metetra
.656 .751 .92 r
.56271 .59084 .56752 .5958 .57671 .59312 .57191 .58813 Metetra
.656 .751 .92 r
.57191 .58813 .57671 .59312 .58592 .59042 .58115 .58542 Metetra
.656 .751 .92 r
.58115 .58542 .58592 .59042 .59516 .58772 .59041 .5827 Metetra
.656 .751 .92 r
.59041 .5827 .59516 .58772 .60443 .585 .5997 .57997 Metetra
.656 .751 .92 r
.5997 .57997 .60443 .585 .61374 .58228 .60903 .57723 Metetra
.656 .751 .92 r
.60903 .57723 .61374 .58228 .62307 .57955 .61839 .57448 Metetra
.656 .751 .92 r
.61839 .57448 .62307 .57955 .63244 .57681 .62777 .57172 Metetra
.656 .751 .92 r
.62777 .57172 .63244 .57681 .64184 .57406 .63719 .56895 Metetra
.656 .751 .92 r
.63719 .56895 .64184 .57406 .65127 .5713 .64664 .56618 Metetra
.656 .751 .92 r
.64664 .56618 .65127 .5713 .66073 .56853 .65613 .56339 Metetra
.656 .751 .92 r
.65613 .56339 .66073 .56853 .67022 .56575 .66564 .5606 Metetra
.656 .751 .92 r
.66564 .5606 .67022 .56575 .67975 .56296 .67519 .55779 Metetra
.656 .751 .92 r
.67519 .55779 .67975 .56296 .68931 .56016 .68477 .55498 Metetra
.656 .751 .92 r
.68477 .55498 .68931 .56016 .6989 .55736 .69438 .55215 Metetra
.656 .751 .92 r
.69438 .55215 .6989 .55736 .70852 .55454 .70403 .54932 Metetra
.656 .751 .92 r
.70403 .54932 .70852 .55454 .71817 .55172 .71371 .54648 Metetra
.656 .751 .92 r
.71371 .54648 .71817 .55172 .72786 .54888 .72342 .54362 Metetra
.656 .751 .92 r
.72342 .54362 .72786 .54888 .73758 .54604 .73316 .54076 Metetra
.656 .751 .92 r
.73316 .54076 .73758 .54604 .74734 .54318 .74294 .53789 Metetra
.656 .751 .92 r
.74294 .53789 .74734 .54318 .75713 .54032 .75275 .53501 Metetra
.656 .751 .92 r
.75275 .53501 .75713 .54032 .76695 .53744 .76259 .53211 Metetra
.656 .751 .92 r
.76259 .53211 .76695 .53744 .7768 .53456 .77247 .52921 Metetra
.656 .751 .92 r
.77247 .52921 .7768 .53456 .78669 .53167 .78239 .5263 Metetra
.656 .751 .92 r
.78239 .5263 .78669 .53167 .79661 .52876 .79233 .52338 Metetra
.656 .751 .92 r
.79233 .52338 .79661 .52876 .80657 .52585 .80231 .52044 Metetra
.656 .751 .92 r
.80231 .52044 .80657 .52585 .81656 .52293 .81233 .5175 Metetra
.656 .751 .92 r
.81233 .5175 .81656 .52293 .82659 .51999 .82238 .51455 Metetra
.656 .751 .92 r
.82238 .51455 .82659 .51999 .83665 .51705 .83247 .51159 Metetra
.656 .751 .92 r
.83247 .51159 .83665 .51705 .84674 .51409 .84259 .50861 Metetra
.656 .751 .92 r
.84259 .50861 .84674 .51409 .85687 .51113 .85274 .50563 Metetra
.656 .751 .92 r
.85274 .50563 .85687 .51113 .86704 .50815 .86294 .50263 Metetra
.656 .751 .92 r
.86294 .50263 .86704 .50815 .87724 .50517 .87316 .49963 Metetra
.656 .751 .92 r
.87316 .49963 .87724 .50517 .88748 .50217 .88343 .49661 Metetra
.656 .751 .92 r
.88343 .49661 .88748 .50217 .89775 .49917 .89373 .49359 Metetra
.656 .751 .92 r
.89373 .49359 .89775 .49917 .90806 .49615 .90406 .49055 Metetra
.656 .751 .92 r
.90406 .49055 .90806 .49615 .91841 .49312 .91443 .4875 Metetra
.656 .751 .92 r
.91443 .4875 .91841 .49312 .92879 .49008 .92484 .48445 Metetra
.656 .751 .92 r
.92484 .48445 .92879 .49008 .93921 .48703 .93529 .48138 Metetra
.656 .751 .92 r
.93529 .48138 .93921 .48703 .94967 .48397 .94577 .4783 Metetra
.34523 .65172 .35095 .6477 .35919 .65063 .35392 .64599 Metetra
.656 .751 .92 r
.35392 .64599 .35919 .65063 .36772 .64812 .36248 .64347 Metetra
.656 .751 .92 r
.36248 .64347 .36772 .64812 .37629 .6456 .37106 .64094 Metetra
.656 .751 .92 r
.37106 .64094 .37629 .6456 .38488 .64308 .37967 .6384 Metetra
.656 .751 .92 r
.37967 .6384 .38488 .64308 .3935 .64055 .3883 .63585 Metetra
.656 .751 .92 r
.3883 .63585 .3935 .64055 .40215 .63801 .39697 .63329 Metetra
.656 .751 .92 r
.39697 .63329 .40215 .63801 .41082 .63546 .40566 .63073 Metetra
.656 .751 .92 r
.40566 .63073 .41082 .63546 .41953 .6329 .41438 .62816 Metetra
.656 .751 .92 r
.41438 .62816 .41953 .6329 .42826 .63034 .42313 .62558 Metetra
.656 .751 .92 r
.42313 .62558 .42826 .63034 .43702 .62776 .43191 .62299 Metetra
.656 .751 .92 r
.43191 .62299 .43702 .62776 .44581 .62518 .44072 .62039 Metetra
.656 .751 .92 r
.44072 .62039 .44581 .62518 .45463 .62259 .44955 .61779 Metetra
.656 .751 .92 r
.44955 .61779 .45463 .62259 .46347 .61999 .45842 .61517 Metetra
.656 .751 .92 r
.45842 .61517 .46347 .61999 .47235 .61738 .46731 .61255 Metetra
.656 .751 .92 r
.46731 .61255 .47235 .61738 .48125 .61477 .47623 .60992 Metetra
.656 .751 .92 r
.47623 .60992 .48125 .61477 .49018 .61214 .48519 .60728 Metetra
.656 .751 .92 r
.48519 .60728 .49018 .61214 .49914 .60951 .49417 .60463 Metetra
.656 .751 .92 r
.49417 .60463 .49914 .60951 .50814 .60687 .50318 .60197 Metetra
.656 .751 .92 r
.50318 .60197 .50814 .60687 .51716 .60422 .51222 .5993 Metetra
.656 .751 .92 r
.51222 .5993 .51716 .60422 .52621 .60156 .52129 .59663 Metetra
.656 .751 .92 r
.52129 .59663 .52621 .60156 .53529 .59889 .53039 .59394 Metetra
.656 .751 .92 r
.53039 .59394 .53529 .59889 .5444 .59622 .53952 .59125 Metetra
.656 .751 .92 r
.53952 .59125 .5444 .59622 .55354 .59353 .54868 .58855 Metetra
.656 .751 .92 r
.54868 .58855 .55354 .59353 .56271 .59084 .55787 .58584 Metetra
.656 .751 .92 r
.55787 .58584 .56271 .59084 .57191 .58813 .56709 .58312 Metetra
.656 .751 .92 r
.56709 .58312 .57191 .58813 .58115 .58542 .57635 .58039 Metetra
.656 .751 .92 r
.57635 .58039 .58115 .58542 .59041 .5827 .58563 .57765 Metetra
.656 .751 .92 r
.58563 .57765 .59041 .5827 .5997 .57997 .59495 .5749 Metetra
.656 .751 .92 r
.59495 .5749 .5997 .57997 .60903 .57723 .60429 .57215 Metetra
.656 .751 .92 r
.60429 .57215 .60903 .57723 .61839 .57448 .61367 .56938 Metetra
.656 .751 .92 r
.61367 .56938 .61839 .57448 .62777 .57172 .62308 .56661 Metetra
.656 .751 .92 r
.62308 .56661 .62777 .57172 .63719 .56895 .63252 .56382 Metetra
.656 .751 .92 r
.63252 .56382 .63719 .56895 .64664 .56618 .64199 .56103 Metetra
.656 .751 .92 r
.64199 .56103 .64664 .56618 .65613 .56339 .6515 .55822 Metetra
.656 .751 .92 r
.6515 .55822 .65613 .56339 .66564 .5606 .66103 .55541 Metetra
.656 .751 .92 r
.66103 .55541 .66564 .5606 .67519 .55779 .6706 .55259 Metetra
.656 .751 .92 r
.6706 .55259 .67519 .55779 .68477 .55498 .68021 .54976 Metetra
.656 .751 .92 r
.68021 .54976 .68477 .55498 .69438 .55215 .68984 .54691 Metetra
.656 .751 .92 r
.68984 .54691 .69438 .55215 .70403 .54932 .69951 .54406 Metetra
.656 .751 .92 r
.69951 .54406 .70403 .54932 .71371 .54648 .70921 .5412 Metetra
.656 .751 .92 r
.70921 .5412 .71371 .54648 .72342 .54362 .71894 .53833 Metetra
.656 .751 .92 r
.71894 .53833 .72342 .54362 .73316 .54076 .72871 .53545 Metetra
.656 .751 .92 r
.72871 .53545 .73316 .54076 .74294 .53789 .73851 .53256 Metetra
.656 .751 .92 r
.73851 .53256 .74294 .53789 .75275 .53501 .74835 .52966 Metetra
.656 .751 .92 r
.74835 .52966 .75275 .53501 .76259 .53211 .75821 .52675 Metetra
.656 .751 .92 r
.75821 .52675 .76259 .53211 .77247 .52921 .76812 .52383 Metetra
.656 .751 .92 r
.76812 .52383 .77247 .52921 .78239 .5263 .77805 .5209 Metetra
.656 .751 .92 r
.77805 .5209 .78239 .5263 .79233 .52338 .78802 .51795 Metetra
.656 .751 .92 r
.78802 .51795 .79233 .52338 .80231 .52044 .79803 .515 Metetra
.656 .751 .92 r
.79803 .515 .80231 .52044 .81233 .5175 .80807 .51204 Metetra
.656 .751 .92 r
.80807 .51204 .81233 .5175 .82238 .51455 .81815 .50907 Metetra
.656 .751 .92 r
.81815 .50907 .82238 .51455 .83247 .51159 .82826 .50609 Metetra
.656 .751 .92 r
.82826 .50609 .83247 .51159 .84259 .50861 .8384 .5031 Metetra
.656 .751 .92 r
.8384 .5031 .84259 .50861 .85274 .50563 .84859 .50009 Metetra
.656 .751 .92 r
.84859 .50009 .85274 .50563 .86294 .50263 .8588 .49708 Metetra
.656 .751 .92 r
.8588 .49708 .86294 .50263 .87316 .49963 .86906 .49405 Metetra
.656 .751 .92 r
.86906 .49405 .87316 .49963 .88343 .49661 .87935 .49102 Metetra
.656 .751 .92 r
.87935 .49102 .88343 .49661 .89373 .49359 .88967 .48797 Metetra
.656 .751 .92 r
.88967 .48797 .89373 .49359 .90406 .49055 .90004 .48492 Metetra
.656 .751 .92 r
.90004 .48492 .90406 .49055 .91443 .4875 .91043 .48185 Metetra
.656 .751 .92 r
.91043 .48185 .91443 .4875 .92484 .48445 .92087 .47877 Metetra
.656 .751 .92 r
.92087 .47877 .92484 .48445 .93529 .48138 .93134 .47568 Metetra
.656 .751 .92 r
.93134 .47568 .93529 .48138 .94577 .4783 .94185 .47258 Metetra
.652 .647 .832 r
.34008 .64388 .34523 .65172 .35392 .64599 .34863 .64133 Metetra
.656 .751 .92 r
.34863 .64133 .35392 .64599 .36248 .64347 .3572 .63879 Metetra
.656 .751 .92 r
.3572 .63879 .36248 .64347 .37106 .64094 .3658 .63624 Metetra
.656 .751 .92 r
.3658 .63624 .37106 .64094 .37967 .6384 .37442 .63369 Metetra
.656 .751 .92 r
.37442 .63369 .37967 .6384 .3883 .63585 .38308 .63113 Metetra
.656 .751 .92 r
.38308 .63113 .3883 .63585 .39697 .63329 .39176 .62855 Metetra
.656 .751 .92 r
.39176 .62855 .39697 .63329 .40566 .63073 .40047 .62598 Metetra
.656 .751 .92 r
.40047 .62598 .40566 .63073 .41438 .62816 .40921 .62339 Metetra
.656 .751 .92 r
.40921 .62339 .41438 .62816 .42313 .62558 .41798 .62079 Metetra
.656 .751 .92 r
.41798 .62079 .42313 .62558 .43191 .62299 .42677 .61819 Metetra
.656 .751 .92 r
.42677 .61819 .43191 .62299 .44072 .62039 .4356 .61557 Metetra
.656 .751 .92 r
.4356 .61557 .44072 .62039 .44955 .61779 .44445 .61295 Metetra
.656 .751 .92 r
.44445 .61295 .44955 .61779 .45842 .61517 .45333 .61032 Metetra
.656 .751 .92 r
.45333 .61032 .45842 .61517 .46731 .61255 .46225 .60768 Metetra
.656 .751 .92 r
.46225 .60768 .46731 .61255 .47623 .60992 .47119 .60504 Metetra
.656 .751 .92 r
.47119 .60504 .47623 .60992 .48519 .60728 .48016 .60238 Metetra
.656 .751 .92 r
.48016 .60238 .48519 .60728 .49417 .60463 .48916 .59971 Metetra
.656 .751 .92 r
.48916 .59971 .49417 .60463 .50318 .60197 .49819 .59704 Metetra
.656 .751 .92 r
.49819 .59704 .50318 .60197 .51222 .5993 .50725 .59436 Metetra
.656 .751 .92 r
.50725 .59436 .51222 .5993 .52129 .59663 .51634 .59167 Metetra
.656 .751 .92 r
.51634 .59167 .52129 .59663 .53039 .59394 .52546 .58896 Metetra
.656 .751 .92 r
.52546 .58896 .53039 .59394 .53952 .59125 .53461 .58626 Metetra
.656 .751 .92 r
.53461 .58626 .53952 .59125 .54868 .58855 .54379 .58354 Metetra
.656 .751 .92 r
.54379 .58354 .54868 .58855 .55787 .58584 .553 .58081 Metetra
.656 .751 .92 r
.553 .58081 .55787 .58584 .56709 .58312 .56224 .57807 Metetra
.656 .751 .92 r
.56224 .57807 .56709 .58312 .57635 .58039 .57152 .57533 Metetra
.656 .751 .92 r
.57152 .57533 .57635 .58039 .58563 .57765 .58082 .57257 Metetra
.656 .751 .92 r
.58082 .57257 .58563 .57765 .59495 .5749 .59016 .56981 Metetra
.656 .751 .92 r
.59016 .56981 .59495 .5749 .60429 .57215 .59952 .56703 Metetra
.656 .751 .92 r
.59952 .56703 .60429 .57215 .61367 .56938 .60892 .56425 Metetra
.656 .751 .92 r
.60892 .56425 .61367 .56938 .62308 .56661 .61835 .56146 Metetra
.656 .751 .92 r
.61835 .56146 .62308 .56661 .63252 .56382 .62782 .55865 Metetra
.656 .751 .92 r
.62782 .55865 .63252 .56382 .64199 .56103 .63731 .55584 Metetra
.656 .751 .92 r
.63731 .55584 .64199 .56103 .6515 .55822 .64684 .55302 Metetra
.656 .751 .92 r
.64684 .55302 .6515 .55822 .66103 .55541 .6564 .55019 Metetra
.656 .751 .92 r
.6564 .55019 .66103 .55541 .6706 .55259 .66599 .54735 Metetra
.656 .751 .92 r
.66599 .54735 .6706 .55259 .68021 .54976 .67561 .5445 Metetra
.656 .751 .92 r
.67561 .5445 .68021 .54976 .68984 .54691 .68527 .54164 Metetra
.656 .751 .92 r
.68527 .54164 .68984 .54691 .69951 .54406 .69496 .53877 Metetra
.656 .751 .92 r
.69496 .53877 .69951 .54406 .70921 .5412 .70468 .53589 Metetra
.656 .751 .92 r
.70468 .53589 .70921 .5412 .71894 .53833 .71444 .533 Metetra
.656 .751 .92 r
.71444 .533 .71894 .53833 .72871 .53545 .72423 .5301 Metetra
.656 .751 .92 r
.72423 .5301 .72871 .53545 .73851 .53256 .73406 .5272 Metetra
.656 .751 .92 r
.73406 .5272 .73851 .53256 .74835 .52966 .74391 .52428 Metetra
.656 .751 .92 r
.74391 .52428 .74835 .52966 .75821 .52675 .75381 .52135 Metetra
.656 .751 .92 r
.75381 .52135 .75821 .52675 .76812 .52383 .76373 .51841 Metetra
.656 .751 .92 r
.76373 .51841 .76812 .52383 .77805 .5209 .77369 .51546 Metetra
.656 .751 .92 r
.77369 .51546 .77805 .5209 .78802 .51795 .78369 .5125 Metetra
.656 .751 .92 r
.78369 .5125 .78802 .51795 .79803 .515 .79372 .50953 Metetra
.656 .751 .92 r
.79372 .50953 .79803 .515 .80807 .51204 .80379 .50655 Metetra
.656 .751 .92 r
.80379 .50655 .80807 .51204 .81815 .50907 .81389 .50356 Metetra
.656 .751 .92 r
.81389 .50356 .81815 .50907 .82826 .50609 .82402 .50055 Metetra
.656 .751 .92 r
.82402 .50055 .82826 .50609 .8384 .5031 .83419 .49754 Metetra
.656 .751 .92 r
.83419 .49754 .8384 .5031 .84859 .50009 .8444 .49452 Metetra
.656 .751 .92 r
.8444 .49452 .84859 .50009 .8588 .49708 .85465 .49149 Metetra
.656 .751 .92 r
.85465 .49149 .8588 .49708 .86906 .49405 .86492 .48844 Metetra
.656 .751 .92 r
.86492 .48844 .86906 .49405 .87935 .49102 .87524 .48539 Metetra
.656 .751 .92 r
.87524 .48539 .87935 .49102 .88967 .48797 .88559 .48232 Metetra
.656 .751 .92 r
.88559 .48232 .88967 .48797 .90004 .48492 .89598 .47925 Metetra
.656 .751 .92 r
.89598 .47925 .90004 .48492 .91043 .48185 .90641 .47616 Metetra
.656 .751 .92 r
.90641 .47616 .91043 .48185 .92087 .47877 .91687 .47306 Metetra
.656 .751 .92 r
.91687 .47306 .92087 .47877 .93134 .47568 .92737 .46995 Metetra
.656 .751 .92 r
.92737 .46995 .93134 .47568 .94185 .47258 .93791 .46683 Metetra
.556 .631 .882 r
.33487 .63686 .34008 .64388 .34863 .64133 .3433 .63664 Metetra
.656 .751 .92 r
.3433 .63664 .34863 .64133 .3572 .63879 .35189 .63408 Metetra
.656 .751 .92 r
.35189 .63408 .3572 .63879 .3658 .63624 .3605 .63152 Metetra
.656 .751 .92 r
.3605 .63152 .3658 .63624 .37442 .63369 .36915 .62895 Metetra
.656 .751 .92 r
.36915 .62895 .37442 .63369 .38308 .63113 .37782 .62637 Metetra
.656 .751 .92 r
.37782 .62637 .38308 .63113 .39176 .62855 .38652 .62379 Metetra
.656 .751 .92 r
.38652 .62379 .39176 .62855 .40047 .62598 .39525 .62119 Metetra
.656 .751 .92 r
.39525 .62119 .40047 .62598 .40921 .62339 .404 .61859 Metetra
.656 .751 .92 r
.404 .61859 .40921 .62339 .41798 .62079 .41279 .61598 Metetra
.656 .751 .92 r
.41279 .61598 .41798 .62079 .42677 .61819 .4216 .61336 Metetra
.656 .751 .92 r
.4216 .61336 .42677 .61819 .4356 .61557 .43045 .61073 Metetra
.656 .751 .92 r
.43045 .61073 .4356 .61557 .44445 .61295 .43932 .60809 Metetra
.656 .751 .92 r
.43932 .60809 .44445 .61295 .45333 .61032 .44822 .60544 Metetra
.656 .751 .92 r
.44822 .60544 .45333 .61032 .46225 .60768 .45715 .60279 Metetra
.656 .751 .92 r
.45715 .60279 .46225 .60768 .47119 .60504 .46611 .60012 Metetra
.656 .751 .92 r
.46611 .60012 .47119 .60504 .48016 .60238 .4751 .59745 Metetra
.656 .751 .92 r
.4751 .59745 .48016 .60238 .48916 .59971 .48412 .59477 Metetra
.656 .751 .92 r
.48412 .59477 .48916 .59971 .49819 .59704 .49317 .59208 Metetra
.656 .751 .92 r
.49317 .59208 .49819 .59704 .50725 .59436 .50225 .58938 Metetra
.656 .751 .92 r
.50225 .58938 .50725 .59436 .51634 .59167 .51136 .58667 Metetra
.656 .751 .92 r
.51136 .58667 .51634 .59167 .52546 .58896 .5205 .58396 Metetra
.656 .751 .92 r
.5205 .58396 .52546 .58896 .53461 .58626 .52967 .58123 Metetra
.656 .751 .92 r
.52967 .58123 .53461 .58626 .54379 .58354 .53887 .57849 Metetra
.656 .751 .92 r
.53887 .57849 .54379 .58354 .553 .58081 .5481 .57575 Metetra
.656 .751 .92 r
.5481 .57575 .553 .58081 .56224 .57807 .55736 .573 Metetra
.656 .751 .92 r
.55736 .573 .56224 .57807 .57152 .57533 .56666 .57023 Metetra
.656 .751 .92 r
.56666 .57023 .57152 .57533 .58082 .57257 .57598 .56746 Metetra
.656 .751 .92 r
.57598 .56746 .58082 .57257 .59016 .56981 .58534 .56468 Metetra
.656 .751 .92 r
.58534 .56468 .59016 .56981 .59952 .56703 .59473 .56189 Metetra
.656 .751 .92 r
.59473 .56189 .59952 .56703 .60892 .56425 .60415 .55909 Metetra
.656 .751 .92 r
.60415 .55909 .60892 .56425 .61835 .56146 .6136 .55628 Metetra
.656 .751 .92 r
.6136 .55628 .61835 .56146 .62782 .55865 .62308 .55346 Metetra
.656 .751 .92 r
.62308 .55346 .62782 .55865 .63731 .55584 .6326 .55063 Metetra
.656 .751 .92 r
.6326 .55063 .63731 .55584 .64684 .55302 .64215 .54779 Metetra
.656 .751 .92 r
.64215 .54779 .64684 .55302 .6564 .55019 .65173 .54494 Metetra
.656 .751 .92 r
.65173 .54494 .6564 .55019 .66599 .54735 .66134 .54208 Metetra
.656 .751 .92 r
.66134 .54208 .66599 .54735 .67561 .5445 .67099 .53921 Metetra
.656 .751 .92 r
.67099 .53921 .67561 .5445 .68527 .54164 .68067 .53634 Metetra
.656 .751 .92 r
.68067 .53634 .68527 .54164 .69496 .53877 .69038 .53345 Metetra
.656 .751 .92 r
.69038 .53345 .69496 .53877 .70468 .53589 .70013 .53055 Metetra
.656 .751 .92 r
.70013 .53055 .70468 .53589 .71444 .533 .70991 .52764 Metetra
.656 .751 .92 r
.70991 .52764 .71444 .533 .72423 .5301 .71972 .52473 Metetra
.656 .751 .92 r
.71972 .52473 .72423 .5301 .73406 .5272 .72957 .5218 Metetra
.656 .751 .92 r
.72957 .5218 .73406 .5272 .74391 .52428 .73945 .51886 Metetra
.656 .751 .92 r
.73945 .51886 .74391 .52428 .75381 .52135 .74937 .51591 Metetra
.656 .751 .92 r
.74937 .51591 .75381 .52135 .76373 .51841 .75932 .51295 Metetra
.656 .751 .92 r
.75932 .51295 .76373 .51841 .77369 .51546 .76931 .50999 Metetra
.656 .751 .92 r
.76931 .50999 .77369 .51546 .78369 .5125 .77933 .50701 Metetra
.656 .751 .92 r
.77933 .50701 .78369 .5125 .79372 .50953 .78938 .50402 Metetra
.656 .751 .92 r
.78938 .50402 .79372 .50953 .80379 .50655 .79947 .50102 Metetra
.656 .751 .92 r
.79947 .50102 .80379 .50655 .81389 .50356 .8096 .49801 Metetra
.656 .751 .92 r
.8096 .49801 .81389 .50356 .82402 .50055 .81976 .49499 Metetra
.656 .751 .92 r
.81976 .49499 .82402 .50055 .83419 .49754 .82996 .49195 Metetra
.656 .751 .92 r
.82996 .49195 .83419 .49754 .8444 .49452 .84019 .48891 Metetra
.656 .751 .92 r
.84019 .48891 .8444 .49452 .85465 .49149 .85046 .48586 Metetra
.656 .751 .92 r
.85046 .48586 .85465 .49149 .86492 .48844 .86077 .4828 Metetra
.656 .751 .92 r
.86077 .4828 .86492 .48844 .87524 .48539 .87111 .47972 Metetra
.656 .751 .92 r
.87111 .47972 .87524 .48539 .88559 .48232 .88149 .47663 Metetra
.656 .751 .92 r
.88149 .47663 .88559 .48232 .89598 .47925 .8919 .47354 Metetra
.656 .751 .92 r
.8919 .47354 .89598 .47925 .90641 .47616 .90235 .47043 Metetra
.656 .751 .92 r
.90235 .47043 .90641 .47616 .91687 .47306 .91285 .46731 Metetra
.656 .751 .92 r
.91285 .46731 .91687 .47306 .92737 .46995 .92337 .46418 Metetra
.656 .751 .92 r
.92337 .46418 .92737 .46995 .93791 .46683 .93394 .46104 Metetra
.718 .971 .93 r
.32921 .63723 .33487 .63686 .3433 .63664 .33794 .63192 Metetra
.656 .751 .92 r
.33794 .63192 .3433 .63664 .35189 .63408 .34654 .62935 Metetra
.656 .751 .92 r
.34654 .62935 .35189 .63408 .3605 .63152 .35518 .62677 Metetra
.656 .751 .92 r
.35518 .62677 .3605 .63152 .36915 .62895 .36384 .62418 Metetra
.656 .751 .92 r
.36384 .62418 .36915 .62895 .37782 .62637 .37253 .62159 Metetra
.656 .751 .92 r
.37253 .62159 .37782 .62637 .38652 .62379 .38125 .61899 Metetra
.656 .751 .92 r
.38125 .61899 .38652 .62379 .39525 .62119 .38999 .61638 Metetra
.656 .751 .92 r
.38999 .61638 .39525 .62119 .404 .61859 .39877 .61376 Metetra
.656 .751 .92 r
.39877 .61376 .404 .61859 .41279 .61598 .40757 .61113 Metetra
.656 .751 .92 r
.40757 .61113 .41279 .61598 .4216 .61336 .4164 .6085 Metetra
.656 .751 .92 r
.4164 .6085 .4216 .61336 .43045 .61073 .42526 .60585 Metetra
.656 .751 .92 r
.42526 .60585 .43045 .61073 .43932 .60809 .43415 .6032 Metetra
.656 .751 .92 r
.43415 .6032 .43932 .60809 .44822 .60544 .44307 .60053 Metetra
.656 .751 .92 r
.44307 .60053 .44822 .60544 .45715 .60279 .45202 .59786 Metetra
.656 .751 .92 r
.45202 .59786 .45715 .60279 .46611 .60012 .461 .59518 Metetra
.656 .751 .92 r
.461 .59518 .46611 .60012 .4751 .59745 .47001 .59249 Metetra
.656 .751 .92 r
.47001 .59249 .4751 .59745 .48412 .59477 .47905 .5898 Metetra
.656 .751 .92 r
.47905 .5898 .48412 .59477 .49317 .59208 .48812 .58709 Metetra
.656 .751 .92 r
.48812 .58709 .49317 .59208 .50225 .58938 .49722 .58437 Metetra
.656 .751 .92 r
.49722 .58437 .50225 .58938 .51136 .58667 .50635 .58165 Metetra
.656 .751 .92 r
.50635 .58165 .51136 .58667 .5205 .58396 .5155 .57892 Metetra
.656 .751 .92 r
.5155 .57892 .5205 .58396 .52967 .58123 .5247 .57617 Metetra
.656 .751 .92 r
.5247 .57617 .52967 .58123 .53887 .57849 .53392 .57342 Metetra
.656 .751 .92 r
.53392 .57342 .53887 .57849 .5481 .57575 .54317 .57066 Metetra
.656 .751 .92 r
.54317 .57066 .5481 .57575 .55736 .573 .55245 .56789 Metetra
.656 .751 .92 r
.55245 .56789 .55736 .573 .56666 .57023 .56177 .56511 Metetra
.656 .751 .92 r
.56177 .56511 .56666 .57023 .57598 .56746 .57111 .56232 Metetra
.656 .751 .92 r
.57111 .56232 .57598 .56746 .58534 .56468 .58049 .55952 Metetra
.656 .751 .92 r
.58049 .55952 .58534 .56468 .59473 .56189 .5899 .55671 Metetra
.656 .751 .92 r
.5899 .55671 .59473 .56189 .60415 .55909 .59934 .55389 Metetra
.656 .751 .92 r
.59934 .55389 .60415 .55909 .6136 .55628 .60881 .55106 Metetra
.656 .751 .92 r
.60881 .55106 .6136 .55628 .62308 .55346 .61832 .54823 Metetra
.656 .751 .92 r
.61832 .54823 .62308 .55346 .6326 .55063 .62786 .54538 Metetra
.656 .751 .92 r
.62786 .54538 .6326 .55063 .64215 .54779 .63743 .54252 Metetra
.656 .751 .92 r
.63743 .54252 .64215 .54779 .65173 .54494 .64703 .53966 Metetra
.656 .751 .92 r
.64703 .53966 .65173 .54494 .66134 .54208 .65667 .53678 Metetra
.656 .751 .92 r
.65667 .53678 .66134 .54208 .67099 .53921 .66634 .53389 Metetra
.656 .751 .92 r
.66634 .53389 .67099 .53921 .68067 .53634 .67604 .531 Metetra
.656 .751 .92 r
.67604 .531 .68067 .53634 .69038 .53345 .68578 .52809 Metetra
.656 .751 .92 r
.68578 .52809 .69038 .53345 .70013 .53055 .69555 .52518 Metetra
.656 .751 .92 r
.69555 .52518 .70013 .53055 .70991 .52764 .70535 .52225 Metetra
.656 .751 .92 r
.70535 .52225 .70991 .52764 .71972 .52473 .71519 .51931 Metetra
.656 .751 .92 r
.71519 .51931 .71972 .52473 .72957 .5218 .72506 .51637 Metetra
.656 .751 .92 r
.72506 .51637 .72957 .5218 .73945 .51886 .73496 .51341 Metetra
.656 .751 .92 r
.73496 .51341 .73945 .51886 .74937 .51591 .7449 .51044 Metetra
.656 .751 .92 r
.7449 .51044 .74937 .51591 .75932 .51295 .75488 .50747 Metetra
.656 .751 .92 r
.75488 .50747 .75932 .51295 .76931 .50999 .76489 .50448 Metetra
.656 .751 .92 r
.76489 .50448 .76931 .50999 .77933 .50701 .77493 .50148 Metetra
.656 .751 .92 r
.77493 .50148 .77933 .50701 .78938 .50402 .78501 .49847 Metetra
.656 .751 .92 r
.78501 .49847 .78938 .50402 .79947 .50102 .79513 .49545 Metetra
.656 .751 .92 r
.79513 .49545 .79947 .50102 .8096 .49801 .80528 .49242 Metetra
.656 .751 .92 r
.80528 .49242 .8096 .49801 .81976 .49499 .81547 .48938 Metetra
.656 .751 .92 r
.81547 .48938 .81976 .49499 .82996 .49195 .82569 .48633 Metetra
.656 .751 .92 r
.82569 .48633 .82996 .49195 .84019 .48891 .83595 .48327 Metetra
.656 .751 .92 r
.83595 .48327 .84019 .48891 .85046 .48586 .84625 .48019 Metetra
.656 .751 .92 r
.84625 .48019 .85046 .48586 .86077 .4828 .85658 .47711 Metetra
.656 .751 .92 r
.85658 .47711 .86077 .4828 .87111 .47972 .86695 .47402 Metetra
.656 .751 .92 r
.86695 .47402 .87111 .47972 .88149 .47663 .87735 .47091 Metetra
.656 .751 .92 r
.87735 .47091 .88149 .47663 .8919 .47354 .8878 .46779 Metetra
.656 .751 .92 r
.8878 .46779 .8919 .47354 .90235 .47043 .89828 .46466 Metetra
.656 .751 .92 r
.89828 .46466 .90235 .47043 .91285 .46731 .90879 .46153 Metetra
.656 .751 .92 r
.90879 .46153 .91285 .46731 .92337 .46418 .91935 .45837 Metetra
.656 .751 .92 r
.91935 .45837 .92337 .46418 .93394 .46104 .92994 .45521 Metetra
.596 .598 .824 r
.32405 .62816 .32921 .63723 .33794 .63192 .33255 .62717 Metetra
.656 .751 .92 r
.33255 .62717 .33794 .63192 .34654 .62935 .34117 .62458 Metetra
.656 .751 .92 r
.34117 .62458 .34654 .62935 .35518 .62677 .34982 .62199 Metetra
.656 .751 .92 r
.34982 .62199 .35518 .62677 .36384 .62418 .3585 .61939 Metetra
.656 .751 .92 r
.3585 .61939 .36384 .62418 .37253 .62159 .36721 .61678 Metetra
.656 .751 .92 r
.36721 .61678 .37253 .62159 .38125 .61899 .37594 .61416 Metetra
.656 .751 .92 r
.37594 .61416 .38125 .61899 .38999 .61638 .3847 .61154 Metetra
.656 .751 .92 r
.3847 .61154 .38999 .61638 .39877 .61376 .3935 .6089 Metetra
.656 .751 .92 r
.3935 .6089 .39877 .61376 .40757 .61113 .40232 .60626 Metetra
.656 .751 .92 r
.40232 .60626 .40757 .61113 .4164 .6085 .41117 .60361 Metetra
.656 .751 .92 r
.41117 .60361 .4164 .6085 .42526 .60585 .42005 .60094 Metetra
.656 .751 .92 r
.42005 .60094 .42526 .60585 .43415 .6032 .42896 .59828 Metetra
.656 .751 .92 r
.42896 .59828 .43415 .6032 .44307 .60053 .4379 .5956 Metetra
.656 .751 .92 r
.4379 .5956 .44307 .60053 .45202 .59786 .44686 .59291 Metetra
.656 .751 .92 r
.44686 .59291 .45202 .59786 .461 .59518 .45586 .59021 Metetra
.656 .751 .92 r
.45586 .59021 .461 .59518 .47001 .59249 .46489 .58751 Metetra
.656 .751 .92 r
.46489 .58751 .47001 .59249 .47905 .5898 .47395 .58479 Metetra
.656 .751 .92 r
.47395 .58479 .47905 .5898 .48812 .58709 .48304 .58207 Metetra
.656 .751 .92 r
.48304 .58207 .48812 .58709 .49722 .58437 .49215 .57934 Metetra
.656 .751 .92 r
.49215 .57934 .49722 .58437 .50635 .58165 .5013 .57659 Metetra
.656 .751 .92 r
.5013 .57659 .50635 .58165 .5155 .57892 .51048 .57384 Metetra
.656 .751 .92 r
.51048 .57384 .5155 .57892 .5247 .57617 .51969 .57108 Metetra
.656 .751 .92 r
.51969 .57108 .5247 .57617 .53392 .57342 .52893 .56831 Metetra
.656 .751 .92 r
.52893 .56831 .53392 .57342 .54317 .57066 .53821 .56554 Metetra
.656 .751 .92 r
.53821 .56554 .54317 .57066 .55245 .56789 .54751 .56275 Metetra
.656 .751 .92 r
.54751 .56275 .55245 .56789 .56177 .56511 .55685 .55995 Metetra
.656 .751 .92 r
.55685 .55995 .56177 .56511 .57111 .56232 .56621 .55714 Metetra
.656 .751 .92 r
.56621 .55714 .57111 .56232 .58049 .55952 .57561 .55433 Metetra
.656 .751 .92 r
.57561 .55433 .58049 .55952 .5899 .55671 .58504 .5515 Metetra
.656 .751 .92 r
.58504 .5515 .5899 .55671 .59934 .55389 .5945 .54866 Metetra
.656 .751 .92 r
.5945 .54866 .59934 .55389 .60881 .55106 .604 .54582 Metetra
.656 .751 .92 r
.604 .54582 .60881 .55106 .61832 .54823 .61353 .54296 Metetra
.656 .751 .92 r
.61353 .54296 .61832 .54823 .62786 .54538 .62309 .5401 Metetra
.656 .751 .92 r
.62309 .5401 .62786 .54538 .63743 .54252 .63268 .53722 Metetra
.656 .751 .92 r
.63268 .53722 .63743 .54252 .64703 .53966 .64231 .53434 Metetra
.656 .751 .92 r
.64231 .53434 .64703 .53966 .65667 .53678 .65196 .53144 Metetra
.656 .751 .92 r
.65196 .53144 .65667 .53678 .66634 .53389 .66166 .52854 Metetra
.656 .751 .92 r
.66166 .52854 .66634 .53389 .67604 .531 .67138 .52563 Metetra
.656 .751 .92 r
.67138 .52563 .67604 .531 .68578 .52809 .68114 .5227 Metetra
.656 .751 .92 r
.68114 .5227 .68578 .52809 .69555 .52518 .69093 .51977 Metetra
.656 .751 .92 r
.69093 .51977 .69555 .52518 .70535 .52225 .70076 .51682 Metetra
.656 .751 .92 r
.70076 .51682 .70535 .52225 .71519 .51931 .71062 .51387 Metetra
.656 .751 .92 r
.71062 .51387 .71519 .51931 .72506 .51637 .72052 .5109 Metetra
.656 .751 .92 r
.72052 .5109 .72506 .51637 .73496 .51341 .73045 .50792 Metetra
.656 .751 .92 r
.73045 .50792 .73496 .51341 .7449 .51044 .74041 .50494 Metetra
.656 .751 .92 r
.74041 .50494 .7449 .51044 .75488 .50747 .75041 .50194 Metetra
.656 .751 .92 r
.75041 .50194 .75488 .50747 .76489 .50448 .76045 .49893 Metetra
.656 .751 .92 r
.76045 .49893 .76489 .50448 .77493 .50148 .77051 .49592 Metetra
.656 .751 .92 r
.77051 .49592 .77493 .50148 .78501 .49847 .78062 .49289 Metetra
.656 .751 .92 r
.78062 .49289 .78501 .49847 .79513 .49545 .79076 .48985 Metetra
.656 .751 .92 r
.79076 .48985 .79513 .49545 .80528 .49242 .80094 .4868 Metetra
.656 .751 .92 r
.80094 .4868 .80528 .49242 .81547 .48938 .81115 .48374 Metetra
.656 .751 .92 r
.81115 .48374 .81547 .48938 .82569 .48633 .8214 .48067 Metetra
.656 .751 .92 r
.8214 .48067 .82569 .48633 .83595 .48327 .83168 .47759 Metetra
.656 .751 .92 r
.83168 .47759 .83595 .48327 .84625 .48019 .84201 .47449 Metetra
.656 .751 .92 r
.84201 .47449 .84625 .48019 .85658 .47711 .85236 .47139 Metetra
.656 .751 .92 r
.85236 .47139 .85658 .47711 .86695 .47402 .86276 .46827 Metetra
.656 .751 .92 r
.86276 .46827 .86695 .47402 .87735 .47091 .87319 .46515 Metetra
.656 .751 .92 r
.87319 .46515 .87735 .47091 .8878 .46779 .88366 .46201 Metetra
.656 .751 .92 r
.88366 .46201 .8878 .46779 .89828 .46466 .89417 .45886 Metetra
.656 .751 .92 r
.89417 .45886 .89828 .46466 .90879 .46153 .90471 .4557 Metetra
.656 .751 .92 r
.90471 .4557 .90879 .46153 .91935 .45837 .9153 .45253 Metetra
.656 .751 .92 r
.9153 .45253 .91935 .45837 .92994 .45521 .92592 .44935 Metetra
.636 .811 .967 r
.31852 .62484 .32405 .62816 .33255 .62717 .32712 .62239 Metetra
.656 .751 .92 r
.32712 .62239 .33255 .62717 .34117 .62458 .33576 .61979 Metetra
.656 .751 .92 r
.33576 .61979 .34117 .62458 .34982 .62199 .34443 .61718 Metetra
.656 .751 .92 r
.34443 .61718 .34982 .62199 .3585 .61939 .35313 .61457 Metetra
.656 .751 .92 r
.35313 .61457 .3585 .61939 .36721 .61678 .36185 .61194 Metetra
.656 .751 .92 r
.36185 .61194 .36721 .61678 .37594 .61416 .3706 .60931 Metetra
.656 .751 .92 r
.3706 .60931 .37594 .61416 .3847 .61154 .37939 .60667 Metetra
.656 .751 .92 r
.37939 .60667 .3847 .61154 .3935 .6089 .3882 .60401 Metetra
.656 .751 .92 r
.3882 .60401 .3935 .6089 .40232 .60626 .39704 .60135 Metetra
.656 .751 .92 r
.39704 .60135 .40232 .60626 .41117 .60361 .4059 .59869 Metetra
.656 .751 .92 r
.4059 .59869 .41117 .60361 .42005 .60094 .4148 .59601 Metetra
.656 .751 .92 r
.4148 .59601 .42005 .60094 .42896 .59828 .42373 .59332 Metetra
.656 .751 .92 r
.42373 .59332 .42896 .59828 .4379 .5956 .43269 .59063 Metetra
.656 .751 .92 r
.43269 .59063 .4379 .5956 .44686 .59291 .44167 .58792 Metetra
.656 .751 .92 r
.44167 .58792 .44686 .59291 .45586 .59021 .45069 .58521 Metetra
.656 .751 .92 r
.45069 .58521 .45586 .59021 .46489 .58751 .45974 .58249 Metetra
.656 .751 .92 r
.45974 .58249 .46489 .58751 .47395 .58479 .46881 .57976 Metetra
.656 .751 .92 r
.46881 .57976 .47395 .58479 .48304 .58207 .47792 .57702 Metetra
.656 .751 .92 r
.47792 .57702 .48304 .58207 .49215 .57934 .48706 .57427 Metetra
.656 .751 .92 r
.48706 .57427 .49215 .57934 .5013 .57659 .49623 .57151 Metetra
.656 .751 .92 r
.49623 .57151 .5013 .57659 .51048 .57384 .50543 .56874 Metetra
.656 .751 .92 r
.50543 .56874 .51048 .57384 .51969 .57108 .51466 .56596 Metetra
.656 .751 .92 r
.51466 .56596 .51969 .57108 .52893 .56831 .52392 .56318 Metetra
.656 .751 .92 r
.52392 .56318 .52893 .56831 .53821 .56554 .53321 .56038 Metetra
.656 .751 .92 r
.53321 .56038 .53821 .56554 .54751 .56275 .54254 .55757 Metetra
.656 .751 .92 r
.54254 .55757 .54751 .56275 .55685 .55995 .55189 .55476 Metetra
.656 .751 .92 r
.55189 .55476 .55685 .55995 .56621 .55714 .56128 .55193 Metetra
.656 .751 .92 r
.56128 .55193 .56621 .55714 .57561 .55433 .5707 .5491 Metetra
.656 .751 .92 r
.5707 .5491 .57561 .55433 .58504 .5515 .58015 .54626 Metetra
.656 .751 .92 r
.58015 .54626 .58504 .5515 .5945 .54866 .58964 .5434 Metetra
.656 .751 .92 r
.58964 .5434 .5945 .54866 .604 .54582 .59915 .54054 Metetra
.656 .751 .92 r
.59915 .54054 .604 .54582 .61353 .54296 .6087 .53767 Metetra
.656 .751 .92 r
.6087 .53767 .61353 .54296 .62309 .5401 .61829 .53478 Metetra
.656 .751 .92 r
.61829 .53478 .62309 .5401 .63268 .53722 .6279 .53189 Metetra
.656 .751 .92 r
.6279 .53189 .63268 .53722 .64231 .53434 .63755 .52899 Metetra
.656 .751 .92 r
.63755 .52899 .64231 .53434 .65196 .53144 .64723 .52607 Metetra
.656 .751 .92 r
.64723 .52607 .65196 .53144 .66166 .52854 .65694 .52315 Metetra
.656 .751 .92 r
.65694 .52315 .66166 .52854 .67138 .52563 .66669 .52022 Metetra
.656 .751 .92 r
.66669 .52022 .67138 .52563 .68114 .5227 .67648 .51727 Metetra
.656 .751 .92 r
.67648 .51727 .68114 .5227 .69093 .51977 .68629 .51432 Metetra
.656 .751 .92 r
.68629 .51432 .69093 .51977 .70076 .51682 .69614 .51136 Metetra
.656 .751 .92 r
.69614 .51136 .70076 .51682 .71062 .51387 .70603 .50838 Metetra
.656 .751 .92 r
.70603 .50838 .71062 .51387 .72052 .5109 .71595 .5054 Metetra
.656 .751 .92 r
.71595 .5054 .72052 .5109 .73045 .50792 .7259 .5024 Metetra
.656 .751 .92 r
.7259 .5024 .73045 .50792 .74041 .50494 .73589 .4994 Metetra
.656 .751 .92 r
.73589 .4994 .74041 .50494 .75041 .50194 .74591 .49638 Metetra
.656 .751 .92 r
.74591 .49638 .75041 .50194 .76045 .49893 .75597 .49335 Metetra
.656 .751 .92 r
.75597 .49335 .76045 .49893 .77051 .49592 .76607 .49032 Metetra
.656 .751 .92 r
.76607 .49032 .77051 .49592 .78062 .49289 .7762 .48727 Metetra
.656 .751 .92 r
.7762 .48727 .78062 .49289 .79076 .48985 .78636 .48421 Metetra
.656 .751 .92 r
.78636 .48421 .79076 .48985 .80094 .4868 .79656 .48114 Metetra
.656 .751 .92 r
.79656 .48114 .80094 .4868 .81115 .48374 .8068 .47806 Metetra
.656 .751 .92 r
.8068 .47806 .81115 .48374 .8214 .48067 .81708 .47497 Metetra
.656 .751 .92 r
.81708 .47497 .8214 .48067 .83168 .47759 .82739 .47187 Metetra
.656 .751 .92 r
.82739 .47187 .83168 .47759 .84201 .47449 .83774 .46875 Metetra
.656 .751 .92 r
.83774 .46875 .84201 .47449 .85236 .47139 .84812 .46563 Metetra
.656 .751 .92 r
.84812 .46563 .85236 .47139 .86276 .46827 .85854 .46249 Metetra
.656 .751 .92 r
.85854 .46249 .86276 .46827 .87319 .46515 .869 .45935 Metetra
.656 .751 .92 r
.869 .45935 .87319 .46515 .88366 .46201 .8795 .45619 Metetra
.656 .751 .92 r
.8795 .45619 .88366 .46201 .89417 .45886 .89003 .45302 Metetra
.656 .751 .92 r
.89003 .45302 .89417 .45886 .90471 .4557 .90061 .44984 Metetra
.656 .751 .92 r
.90061 .44984 .90471 .4557 .9153 .45253 .91122 .44664 Metetra
.656 .751 .92 r
.91122 .44664 .9153 .45253 .92592 .44935 .92187 .44344 Metetra
.713 .824 .934 r
.31296 .62152 .31852 .62484 .32712 .62239 .32167 .61758 Metetra
.656 .751 .92 r
.32167 .61758 .32712 .62239 .33576 .61979 .33032 .61497 Metetra
.656 .751 .92 r
.33032 .61497 .33576 .61979 .34443 .61718 .33901 .61235 Metetra
.656 .751 .92 r
.33901 .61235 .34443 .61718 .35313 .61457 .34772 .60971 Metetra
.656 .751 .92 r
.34772 .60971 .35313 .61457 .36185 .61194 .35646 .60707 Metetra
.656 .751 .92 r
.35646 .60707 .36185 .61194 .3706 .60931 .36523 .60442 Metetra
.656 .751 .92 r
.36523 .60442 .3706 .60931 .37939 .60667 .37403 .60176 Metetra
.656 .751 .92 r
.37403 .60176 .37939 .60667 .3882 .60401 .38286 .5991 Metetra
.656 .751 .92 r
.38286 .5991 .3882 .60401 .39704 .60135 .39172 .59642 Metetra
.656 .751 .92 r
.39172 .59642 .39704 .60135 .4059 .59869 .40061 .59374 Metetra
.656 .751 .92 r
.40061 .59374 .4059 .59869 .4148 .59601 .40952 .59104 Metetra
.656 .751 .92 r
.40952 .59104 .4148 .59601 .42373 .59332 .41847 .58834 Metetra
.656 .751 .92 r
.41847 .58834 .42373 .59332 .43269 .59063 .42745 .58563 Metetra
.656 .751 .92 r
.42745 .58563 .43269 .59063 .44167 .58792 .43645 .58291 Metetra
.656 .751 .92 r
.43645 .58291 .44167 .58792 .45069 .58521 .44549 .58018 Metetra
.656 .751 .92 r
.44549 .58018 .45069 .58521 .45974 .58249 .45455 .57744 Metetra
.656 .751 .92 r
.45455 .57744 .45974 .58249 .46881 .57976 .46365 .57469 Metetra
.656 .751 .92 r
.46365 .57469 .46881 .57976 .47792 .57702 .47278 .57193 Metetra
.656 .751 .92 r
.47278 .57193 .47792 .57702 .48706 .57427 .48193 .56917 Metetra
.656 .751 .92 r
.48193 .56917 .48706 .57427 .49623 .57151 .49112 .56639 Metetra
.656 .751 .92 r
.49112 .56639 .49623 .57151 .50543 .56874 .50034 .56361 Metetra
.656 .751 .92 r
.50034 .56361 .50543 .56874 .51466 .56596 .50959 .56081 Metetra
.656 .751 .92 r
.50959 .56081 .51466 .56596 .52392 .56318 .51888 .55801 Metetra
.656 .751 .92 r
.51888 .55801 .52392 .56318 .53321 .56038 .52819 .55519 Metetra
.656 .751 .92 r
.52819 .55519 .53321 .56038 .54254 .55757 .53753 .55237 Metetra
.656 .751 .92 r
.53753 .55237 .54254 .55757 .55189 .55476 .54691 .54954 Metetra
.656 .751 .92 r
.54691 .54954 .55189 .55476 .56128 .55193 .55632 .54669 Metetra
.656 .751 .92 r
.55632 .54669 .56128 .55193 .5707 .5491 .56576 .54384 Metetra
.656 .751 .92 r
.56576 .54384 .5707 .5491 .58015 .54626 .57523 .54098 Metetra
.656 .751 .92 r
.57523 .54098 .58015 .54626 .58964 .5434 .58474 .53811 Metetra
.656 .751 .92 r
.58474 .53811 .58964 .5434 .59915 .54054 .59428 .53523 Metetra
.656 .751 .92 r
.59428 .53523 .59915 .54054 .6087 .53767 .60385 .53234 Metetra
.656 .751 .92 r
.60385 .53234 .6087 .53767 .61829 .53478 .61345 .52943 Metetra
.656 .751 .92 r
.61345 .52943 .61829 .53478 .6279 .53189 .62309 .52652 Metetra
.656 .751 .92 r
.62309 .52652 .6279 .53189 .63755 .52899 .63276 .5236 Metetra
.656 .751 .92 r
.63276 .5236 .63755 .52899 .64723 .52607 .64247 .52067 Metetra
.656 .751 .92 r
.64247 .52067 .64723 .52607 .65694 .52315 .6522 .51773 Metetra
.656 .751 .92 r
.6522 .51773 .65694 .52315 .66669 .52022 .66197 .51478 Metetra
.656 .751 .92 r
.66197 .51478 .66669 .52022 .67648 .51727 .67178 .51181 Metetra
.656 .751 .92 r
.67178 .51181 .67648 .51727 .68629 .51432 .68162 .50884 Metetra
.656 .751 .92 r
.68162 .50884 .68629 .51432 .69614 .51136 .69149 .50586 Metetra
.656 .751 .92 r
.69149 .50586 .69614 .51136 .70603 .50838 .7014 .50286 Metetra
.656 .751 .92 r
.7014 .50286 .70603 .50838 .71595 .5054 .71135 .49986 Metetra
.656 .751 .92 r
.71135 .49986 .71595 .5054 .7259 .5024 .72132 .49685 Metetra
.656 .751 .92 r
.72132 .49685 .7259 .5024 .73589 .4994 .73134 .49382 Metetra
.656 .751 .92 r
.73134 .49382 .73589 .4994 .74591 .49638 .74139 .49079 Metetra
.656 .751 .92 r
.74139 .49079 .74591 .49638 .75597 .49335 .75147 .48774 Metetra
.656 .751 .92 r
.75147 .48774 .75597 .49335 .76607 .49032 .76159 .48468 Metetra
.656 .751 .92 r
.76159 .48468 .76607 .49032 .7762 .48727 .77174 .48161 Metetra
.656 .751 .92 r
.77174 .48161 .7762 .48727 .78636 .48421 .78194 .47854 Metetra
.656 .751 .92 r
.78194 .47854 .78636 .48421 .79656 .48114 .79216 .47545 Metetra
.656 .751 .92 r
.79216 .47545 .79656 .48114 .8068 .47806 .80243 .47234 Metetra
.656 .751 .92 r
.80243 .47234 .8068 .47806 .81708 .47497 .81273 .46923 Metetra
.656 .751 .92 r
.81273 .46923 .81708 .47497 .82739 .47187 .82306 .46611 Metetra
.656 .751 .92 r
.82306 .46611 .82739 .47187 .83774 .46875 .83344 .46298 Metetra
.656 .751 .92 r
.83344 .46298 .83774 .46875 .84812 .46563 .84385 .45983 Metetra
.656 .751 .92 r
.84385 .45983 .84812 .46563 .85854 .46249 .8543 .45667 Metetra
.656 .751 .92 r
.8543 .45667 .85854 .46249 .869 .45935 .86479 .45351 Metetra
.656 .751 .92 r
.86479 .45351 .869 .45935 .8795 .45619 .87531 .45033 Metetra
.656 .751 .92 r
.87531 .45033 .8795 .45619 .89003 .45302 .88587 .44713 Metetra
.656 .751 .92 r
.88587 .44713 .89003 .45302 .90061 .44984 .89647 .44393 Metetra
.656 .751 .92 r
.89647 .44393 .90061 .44984 .91122 .44664 .90711 .44072 Metetra
.656 .751 .92 r
.90711 .44072 .91122 .44664 .92187 .44344 .91779 .43749 Metetra
.597 .637 .861 r
.30763 .6139 .31296 .62152 .32167 .61758 .31618 .61275 Metetra
.656 .751 .92 r
.31618 .61275 .32167 .61758 .33032 .61497 .32485 .61012 Metetra
.656 .751 .92 r
.32485 .61012 .33032 .61497 .33901 .61235 .33355 .60748 Metetra
.656 .751 .92 r
.33355 .60748 .33901 .61235 .34772 .60971 .34228 .60483 Metetra
.656 .751 .92 r
.34228 .60483 .34772 .60971 .35646 .60707 .35104 .60217 Metetra
.656 .751 .92 r
.35104 .60217 .35646 .60707 .36523 .60442 .35983 .59951 Metetra
.656 .751 .92 r
.35983 .59951 .36523 .60442 .37403 .60176 .36865 .59683 Metetra
.656 .751 .92 r
.36865 .59683 .37403 .60176 .38286 .5991 .3775 .59415 Metetra
.656 .751 .92 r
.3775 .59415 .38286 .5991 .39172 .59642 .38637 .59146 Metetra
.656 .751 .92 r
.38637 .59146 .39172 .59642 .40061 .59374 .39528 .58876 Metetra
.656 .751 .92 r
.39528 .58876 .40061 .59374 .40952 .59104 .40421 .58605 Metetra
.656 .751 .92 r
.40421 .58605 .40952 .59104 .41847 .58834 .41318 .58333 Metetra
.656 .751 .92 r
.41318 .58333 .41847 .58834 .42745 .58563 .42217 .5806 Metetra
.656 .751 .92 r
.42217 .5806 .42745 .58563 .43645 .58291 .4312 .57786 Metetra
.656 .751 .92 r
.4312 .57786 .43645 .58291 .44549 .58018 .44025 .57511 Metetra
.656 .751 .92 r
.44025 .57511 .44549 .58018 .45455 .57744 .44934 .57236 Metetra
.656 .751 .92 r
.44934 .57236 .45455 .57744 .46365 .57469 .45845 .56959 Metetra
.656 .751 .92 r
.45845 .56959 .46365 .57469 .47278 .57193 .4676 .56682 Metetra
.656 .751 .92 r
.4676 .56682 .47278 .57193 .48193 .56917 .47678 .56403 Metetra
.656 .751 .92 r
.47678 .56403 .48193 .56917 .49112 .56639 .48599 .56124 Metetra
.656 .751 .92 r
.48599 .56124 .49112 .56639 .50034 .56361 .49523 .55844 Metetra
.656 .751 .92 r
.49523 .55844 .50034 .56361 .50959 .56081 .5045 .55563 Metetra
.656 .751 .92 r
.5045 .55563 .50959 .56081 .51888 .55801 .5138 .55281 Metetra
.656 .751 .92 r
.5138 .55281 .51888 .55801 .52819 .55519 .52313 .54997 Metetra
.656 .751 .92 r
.52313 .54997 .52819 .55519 .53753 .55237 .5325 .54713 Metetra
.656 .751 .92 r
.5325 .54713 .53753 .55237 .54691 .54954 .5419 .54428 Metetra
.656 .751 .92 r
.5419 .54428 .54691 .54954 .55632 .54669 .55133 .54142 Metetra
.656 .751 .92 r
.55133 .54142 .55632 .54669 .56576 .54384 .56079 .53855 Metetra
.656 .751 .92 r
.56079 .53855 .56576 .54384 .57523 .54098 .57028 .53567 Metetra
.656 .751 .92 r
.57028 .53567 .57523 .54098 .58474 .53811 .57981 .53278 Metetra
.656 .751 .92 r
.57981 .53278 .58474 .53811 .59428 .53523 .58937 .52988 Metetra
.656 .751 .92 r
.58937 .52988 .59428 .53523 .60385 .53234 .59896 .52697 Metetra
.656 .751 .92 r
.59896 .52697 .60385 .53234 .61345 .52943 .60859 .52405 Metetra
.656 .751 .92 r
.60859 .52405 .61345 .52943 .62309 .52652 .61825 .52112 Metetra
.656 .751 .92 r
.61825 .52112 .62309 .52652 .63276 .5236 .62794 .51818 Metetra
.656 .751 .92 r
.62794 .51818 .63276 .5236 .64247 .52067 .63767 .51523 Metetra
.656 .751 .92 r
.63767 .51523 .64247 .52067 .6522 .51773 .64743 .51227 Metetra
.656 .751 .92 r
.64743 .51227 .6522 .51773 .66197 .51478 .65723 .5093 Metetra
.656 .751 .92 r
.65723 .5093 .66197 .51478 .67178 .51181 .66705 .50632 Metetra
.656 .751 .92 r
.66705 .50632 .67178 .51181 .68162 .50884 .67692 .50333 Metetra
.656 .751 .92 r
.67692 .50333 .68162 .50884 .69149 .50586 .68682 .50032 Metetra
.656 .751 .92 r
.68682 .50032 .69149 .50586 .7014 .50286 .69675 .49731 Metetra
.656 .751 .92 r
.69675 .49731 .7014 .50286 .71135 .49986 .70671 .49429 Metetra
.656 .751 .92 r
.70671 .49429 .71135 .49986 .72132 .49685 .71672 .49125 Metetra
.656 .751 .92 r
.71672 .49125 .72132 .49685 .73134 .49382 .72675 .48821 Metetra
.656 .751 .92 r
.72675 .48821 .73134 .49382 .74139 .49079 .73683 .48515 Metetra
.656 .751 .92 r
.73683 .48515 .74139 .49079 .75147 .48774 .74694 .48209 Metetra
.656 .751 .92 r
.74694 .48209 .75147 .48774 .76159 .48468 .75708 .47901 Metetra
.656 .751 .92 r
.75708 .47901 .76159 .48468 .77174 .48161 .76726 .47592 Metetra
.656 .751 .92 r
.76726 .47592 .77174 .48161 .78194 .47854 .77748 .47282 Metetra
.656 .751 .92 r
.77748 .47282 .78194 .47854 .79216 .47545 .78773 .46971 Metetra
.656 .751 .92 r
.78773 .46971 .79216 .47545 .80243 .47234 .79802 .46659 Metetra
.656 .751 .92 r
.79802 .46659 .80243 .47234 .81273 .46923 .80835 .46346 Metetra
.656 .751 .92 r
.80835 .46346 .81273 .46923 .82306 .46611 .81871 .46031 Metetra
.656 .751 .92 r
.81871 .46031 .82306 .46611 .83344 .46298 .82911 .45716 Metetra
.656 .751 .92 r
.82911 .45716 .83344 .46298 .84385 .45983 .83955 .45399 Metetra
.656 .751 .92 r
.83955 .45399 .84385 .45983 .8543 .45667 .85003 .45082 Metetra
.656 .751 .92 r
.85003 .45082 .8543 .45667 .86479 .45351 .86054 .44763 Metetra
.656 .751 .92 r
.86054 .44763 .86479 .45351 .87531 .45033 .87109 .44443 Metetra
.656 .751 .92 r
.87109 .44443 .87531 .45033 .88587 .44713 .88168 .44121 Metetra
.656 .751 .92 r
.88168 .44121 .88587 .44713 .89647 .44393 .89231 .43799 Metetra
.656 .751 .92 r
.89231 .43799 .89647 .44393 .90711 .44072 .90298 .43475 Metetra
.656 .751 .92 r
.90298 .43475 .90711 .44072 .91779 .43749 .91369 .43151 Metetra
.679 .854 .966 r
.30194 .61128 .30763 .6139 .31618 .61275 .31066 .60789 Metetra
.656 .751 .92 r
.31066 .60789 .31618 .61275 .32485 .61012 .31935 .60524 Metetra
.656 .751 .92 r
.31935 .60524 .32485 .61012 .33355 .60748 .32807 .60258 Metetra
.656 .751 .92 r
.32807 .60258 .33355 .60748 .34228 .60483 .33681 .59992 Metetra
.656 .751 .92 r
.33681 .59992 .34228 .60483 .35104 .60217 .34559 .59725 Metetra
.656 .751 .92 r
.34559 .59725 .35104 .60217 .35983 .59951 .3544 .59456 Metetra
.656 .751 .92 r
.3544 .59456 .35983 .59951 .36865 .59683 .36323 .59187 Metetra
.656 .751 .92 r
.36323 .59187 .36865 .59683 .3775 .59415 .3721 .58917 Metetra
.656 .751 .92 r
.3721 .58917 .3775 .59415 .38637 .59146 .38099 .58646 Metetra
.656 .751 .92 r
.38099 .58646 .38637 .59146 .39528 .58876 .38992 .58375 Metetra
.656 .751 .92 r
.38992 .58375 .39528 .58876 .40421 .58605 .39887 .58102 Metetra
.656 .751 .92 r
.39887 .58102 .40421 .58605 .41318 .58333 .40785 .57828 Metetra
.656 .751 .92 r
.40785 .57828 .41318 .58333 .42217 .5806 .41687 .57554 Metetra
.656 .751 .92 r
.41687 .57554 .42217 .5806 .4312 .57786 .42591 .57278 Metetra
.656 .751 .92 r
.42591 .57278 .4312 .57786 .44025 .57511 .43498 .57002 Metetra
.656 .751 .92 r
.43498 .57002 .44025 .57511 .44934 .57236 .44409 .56725 Metetra
.656 .751 .92 r
.44409 .56725 .44934 .57236 .45845 .56959 .45322 .56446 Metetra
.656 .751 .92 r
.45322 .56446 .45845 .56959 .4676 .56682 .46239 .56167 Metetra
.656 .751 .92 r
.46239 .56167 .4676 .56682 .47678 .56403 .47159 .55887 Metetra
.656 .751 .92 r
.47159 .55887 .47678 .56403 .48599 .56124 .48082 .55606 Metetra
.656 .751 .92 r
.48082 .55606 .48599 .56124 .49523 .55844 .49008 .55324 Metetra
.656 .751 .92 r
.49008 .55324 .49523 .55844 .5045 .55563 .49937 .55041 Metetra
.656 .751 .92 r
.49937 .55041 .5045 .55563 .5138 .55281 .50869 .54757 Metetra
.656 .751 .92 r
.50869 .54757 .5138 .55281 .52313 .54997 .51805 .54472 Metetra
.656 .751 .92 r
.51805 .54472 .52313 .54997 .5325 .54713 .52743 .54186 Metetra
.656 .751 .92 r
.52743 .54186 .5325 .54713 .5419 .54428 .53685 .53899 Metetra
.656 .751 .92 r
.53685 .53899 .5419 .54428 .55133 .54142 .5463 .53612 Metetra
.656 .751 .92 r
.5463 .53612 .55133 .54142 .56079 .53855 .55579 .53323 Metetra
.656 .751 .92 r
.55579 .53323 .56079 .53855 .57028 .53567 .5653 .53033 Metetra
.656 .751 .92 r
.5653 .53033 .57028 .53567 .57981 .53278 .57485 .52742 Metetra
.656 .751 .92 r
.57485 .52742 .57981 .53278 .58937 .52988 .58443 .5245 Metetra
.656 .751 .92 r
.58443 .5245 .58937 .52988 .59896 .52697 .59405 .52157 Metetra
.656 .751 .92 r
.59405 .52157 .59896 .52697 .60859 .52405 .6037 .51863 Metetra
.656 .751 .92 r
.6037 .51863 .60859 .52405 .61825 .52112 .61338 .51569 Metetra
.656 .751 .92 r
.61338 .51569 .61825 .52112 .62794 .51818 .6231 .51273 Metetra
.656 .751 .92 r
.6231 .51273 .62794 .51818 .63767 .51523 .63284 .50976 Metetra
.656 .751 .92 r
.63284 .50976 .63767 .51523 .64743 .51227 .64263 .50678 Metetra
.656 .751 .92 r
.64263 .50678 .64743 .51227 .65723 .5093 .65245 .50379 Metetra
.656 .751 .92 r
.65245 .50379 .65723 .5093 .66705 .50632 .6623 .50079 Metetra
.656 .751 .92 r
.6623 .50079 .66705 .50632 .67692 .50333 .67218 .49777 Metetra
.656 .751 .92 r
.67218 .49777 .67692 .50333 .68682 .50032 .68211 .49475 Metetra
.656 .751 .92 r
.68211 .49475 .68682 .50032 .69675 .49731 .69206 .49172 Metetra
.656 .751 .92 r
.69206 .49172 .69675 .49731 .70671 .49429 .70205 .48868 Metetra
.656 .751 .92 r
.70205 .48868 .70671 .49429 .71672 .49125 .71208 .48562 Metetra
.656 .751 .92 r
.71208 .48562 .71672 .49125 .72675 .48821 .72214 .48256 Metetra
.656 .751 .92 r
.72214 .48256 .72675 .48821 .73683 .48515 .73224 .47948 Metetra
.656 .751 .92 r
.73224 .47948 .73683 .48515 .74694 .48209 .74238 .4764 Metetra
.656 .751 .92 r
.74238 .4764 .74694 .48209 .75708 .47901 .75254 .4733 Metetra
.656 .751 .92 r
.75254 .4733 .75708 .47901 .76726 .47592 .76275 .47019 Metetra
.656 .751 .92 r
.76275 .47019 .76726 .47592 .77748 .47282 .77299 .46707 Metetra
.656 .751 .92 r
.77299 .46707 .77748 .47282 .78773 .46971 .78327 .46394 Metetra
.656 .751 .92 r
.78327 .46394 .78773 .46971 .79802 .46659 .79359 .4608 Metetra
.656 .751 .92 r
.79359 .4608 .79802 .46659 .80835 .46346 .80394 .45765 Metetra
.656 .751 .92 r
.80394 .45765 .80835 .46346 .81871 .46031 .81433 .45448 Metetra
.656 .751 .92 r
.81433 .45448 .81871 .46031 .82911 .45716 .82476 .45131 Metetra
.656 .751 .92 r
.82476 .45131 .82911 .45716 .83955 .45399 .83522 .44812 Metetra
.656 .751 .92 r
.83522 .44812 .83955 .45399 .85003 .45082 .84573 .44492 Metetra
.656 .751 .92 r
.84573 .44492 .85003 .45082 .86054 .44763 .85627 .44171 Metetra
.656 .751 .92 r
.85627 .44171 .86054 .44763 .87109 .44443 .86685 .43849 Metetra
.656 .751 .92 r
.86685 .43849 .87109 .44443 .88168 .44121 .87747 .43525 Metetra
.656 .751 .92 r
.87747 .43525 .88168 .44121 .89231 .43799 .88812 .43201 Metetra
.656 .751 .92 r
.88812 .43201 .89231 .43799 .90298 .43475 .89882 .42875 Metetra
.656 .751 .92 r
.89882 .42875 .90298 .43475 .91369 .43151 .90955 .42548 Metetra
.665 .732 .899 r
.29641 .60585 .30194 .61128 .31066 .60789 .3051 .60299 Metetra
.656 .751 .92 r
.3051 .60299 .31066 .60789 .31935 .60524 .31381 .60033 Metetra
.656 .751 .92 r
.31381 .60033 .31935 .60524 .32807 .60258 .32254 .59766 Metetra
.656 .751 .92 r
.32254 .59766 .32807 .60258 .33681 .59992 .33131 .59498 Metetra
.656 .751 .92 r
.33131 .59498 .33681 .59992 .34559 .59725 .3401 .59229 Metetra
.656 .751 .92 r
.3401 .59229 .34559 .59725 .3544 .59456 .34893 .58959 Metetra
.656 .751 .92 r
.34893 .58959 .3544 .59456 .36323 .59187 .35778 .58688 Metetra
.656 .751 .92 r
.35778 .58688 .36323 .59187 .3721 .58917 .36666 .58416 Metetra
.656 .751 .92 r
.36666 .58416 .3721 .58917 .38099 .58646 .37558 .58144 Metetra
.656 .751 .92 r
.37558 .58144 .38099 .58646 .38992 .58375 .38452 .5787 Metetra
.656 .751 .92 r
.38452 .5787 .38992 .58375 .39887 .58102 .39349 .57596 Metetra
.656 .751 .92 r
.39349 .57596 .39887 .58102 .40785 .57828 .40249 .57321 Metetra
.656 .751 .92 r
.40249 .57321 .40785 .57828 .41687 .57554 .41153 .57045 Metetra
.656 .751 .92 r
.41153 .57045 .41687 .57554 .42591 .57278 .42059 .56767 Metetra
.656 .751 .92 r
.42059 .56767 .42591 .57278 .43498 .57002 .42968 .56489 Metetra
.656 .751 .92 r
.42968 .56489 .43498 .57002 .44409 .56725 .43881 .5621 Metetra
.656 .751 .92 r
.43881 .5621 .44409 .56725 .45322 .56446 .44796 .5593 Metetra
.656 .751 .92 r
.44796 .5593 .45322 .56446 .46239 .56167 .45715 .55649 Metetra
.656 .751 .92 r
.45715 .55649 .46239 .56167 .47159 .55887 .46637 .55367 Metetra
.656 .751 .92 r
.46637 .55367 .47159 .55887 .48082 .55606 .47561 .55085 Metetra
.656 .751 .92 r
.47561 .55085 .48082 .55606 .49008 .55324 .48489 .54801 Metetra
.656 .751 .92 r
.48489 .54801 .49008 .55324 .49937 .55041 .49421 .54516 Metetra
.656 .751 .92 r
.49421 .54516 .49937 .55041 .50869 .54757 .50355 .5423 Metetra
.656 .751 .92 r
.50355 .5423 .50869 .54757 .51805 .54472 .51293 .53944 Metetra
.656 .751 .92 r
.51293 .53944 .51805 .54472 .52743 .54186 .52233 .53656 Metetra
.656 .751 .92 r
.52233 .53656 .52743 .54186 .53685 .53899 .53177 .53367 Metetra
.656 .751 .92 r
.53177 .53367 .53685 .53899 .5463 .53612 .54125 .53077 Metetra
.656 .751 .92 r
.54125 .53077 .5463 .53612 .55579 .53323 .55075 .52787 Metetra
.656 .751 .92 r
.55075 .52787 .55579 .53323 .5653 .53033 .56029 .52495 Metetra
.656 .751 .92 r
.56029 .52495 .5653 .53033 .57485 .52742 .56986 .52202 Metetra
.656 .751 .92 r
.56986 .52202 .57485 .52742 .58443 .5245 .57946 .51909 Metetra
.656 .751 .92 r
.57946 .51909 .58443 .5245 .59405 .52157 .5891 .51614 Metetra
.656 .751 .92 r
.5891 .51614 .59405 .52157 .6037 .51863 .59877 .51318 Metetra
.656 .751 .92 r
.59877 .51318 .6037 .51863 .61338 .51569 .60848 .51021 Metetra
.656 .751 .92 r
.60848 .51021 .61338 .51569 .6231 .51273 .61822 .50724 Metetra
.656 .751 .92 r
.61822 .50724 .6231 .51273 .63284 .50976 .62799 .50425 Metetra
.656 .751 .92 r
.62799 .50425 .63284 .50976 .64263 .50678 .63779 .50125 Metetra
.656 .751 .92 r
.63779 .50125 .64263 .50678 .65245 .50379 .64764 .49824 Metetra
.656 .751 .92 r
.64764 .49824 .65245 .50379 .6623 .50079 .65751 .49522 Metetra
.656 .751 .92 r
.65751 .49522 .6623 .50079 .67218 .49777 .66742 .49219 Metetra
.656 .751 .92 r
.66742 .49219 .67218 .49777 .68211 .49475 .67737 .48915 Metetra
.656 .751 .92 r
.67737 .48915 .68211 .49475 .69206 .49172 .68735 .48609 Metetra
.656 .751 .92 r
.68735 .48609 .69206 .49172 .70205 .48868 .69736 .48303 Metetra
.656 .751 .92 r
.69736 .48303 .70205 .48868 .71208 .48562 .70741 .47996 Metetra
.656 .751 .92 r
.70741 .47996 .71208 .48562 .72214 .48256 .7175 .47687 Metetra
.656 .751 .92 r
.7175 .47687 .72214 .48256 .73224 .47948 .72762 .47378 Metetra
.656 .751 .92 r
.72762 .47378 .73224 .47948 .74238 .4764 .73778 .47067 Metetra
.656 .751 .92 r
.73778 .47067 .74238 .4764 .75254 .4733 .74798 .46755 Metetra
.656 .751 .92 r
.74798 .46755 .75254 .4733 .76275 .47019 .75821 .46442 Metetra
.656 .751 .92 r
.75821 .46442 .76275 .47019 .77299 .46707 .76848 .46128 Metetra
.656 .751 .92 r
.76848 .46128 .77299 .46707 .78327 .46394 .77878 .45813 Metetra
.656 .751 .92 r
.77878 .45813 .78327 .46394 .79359 .4608 .78913 .45497 Metetra
.656 .751 .92 r
.78913 .45497 .79359 .4608 .80394 .45765 .7995 .45179 Metetra
.656 .751 .92 r
.7995 .45179 .80394 .45765 .81433 .45448 .80992 .44861 Metetra
.656 .751 .92 r
.80992 .44861 .81433 .45448 .82476 .45131 .82038 .44541 Metetra
.656 .751 .92 r
.82038 .44541 .82476 .45131 .83522 .44812 .83087 .4422 Metetra
.656 .751 .92 r
.83087 .4422 .83522 .44812 .84573 .44492 .8414 .43898 Metetra
.656 .751 .92 r
.8414 .43898 .84573 .44492 .85627 .44171 .85197 .43575 Metetra
.656 .751 .92 r
.85197 .43575 .85627 .44171 .86685 .43849 .86257 .43251 Metetra
.656 .751 .92 r
.86257 .43251 .86685 .43849 .87747 .43525 .87322 .42925 Metetra
.656 .751 .92 r
.87322 .42925 .87747 .43525 .88812 .43201 .88391 .42598 Metetra
.656 .751 .92 r
.88391 .42598 .88812 .43201 .89882 .42875 .89463 .4227 Metetra
.656 .751 .92 r
.89463 .4227 .89882 .42875 .90955 .42548 .90539 .41941 Metetra
.622 .704 .904 r
.29087 .59995 .29641 .60585 .3051 .60299 .29951 .59807 Metetra
.656 .751 .92 r
.29951 .59807 .3051 .60299 .31381 .60033 .30823 .59539 Metetra
.656 .751 .92 r
.30823 .59539 .31381 .60033 .32254 .59766 .31699 .5927 Metetra
.656 .751 .92 r
.31699 .5927 .32254 .59766 .33131 .59498 .32577 .59 Metetra
.656 .751 .92 r
.32577 .59 .33131 .59498 .3401 .59229 .33458 .5873 Metetra
.656 .751 .92 r
.33458 .5873 .3401 .59229 .34893 .58959 .34343 .58458 Metetra
.656 .751 .92 r
.34343 .58458 .34893 .58959 .35778 .58688 .3523 .58186 Metetra
.656 .751 .92 r
.3523 .58186 .35778 .58688 .36666 .58416 .3612 .57913 Metetra
.656 .751 .92 r
.3612 .57913 .36666 .58416 .37558 .58144 .37013 .57638 Metetra
.656 .751 .92 r
.37013 .57638 .37558 .58144 .38452 .5787 .37909 .57363 Metetra
.656 .751 .92 r
.37909 .57363 .38452 .5787 .39349 .57596 .38808 .57087 Metetra
.656 .751 .92 r
.38808 .57087 .39349 .57596 .40249 .57321 .3971 .5681 Metetra
.656 .751 .92 r
.3971 .5681 .40249 .57321 .41153 .57045 .40615 .56532 Metetra
.656 .751 .92 r
.40615 .56532 .41153 .57045 .42059 .56767 .41524 .56253 Metetra
.656 .751 .92 r
.41524 .56253 .42059 .56767 .42968 .56489 .42435 .55973 Metetra
.656 .751 .92 r
.42435 .55973 .42968 .56489 .43881 .5621 .43349 .55693 Metetra
.656 .751 .92 r
.43349 .55693 .43881 .5621 .44796 .5593 .44267 .55411 Metetra
.656 .751 .92 r
.44267 .55411 .44796 .5593 .45715 .55649 .45187 .55128 Metetra
.656 .751 .92 r
.45187 .55128 .45715 .55649 .46637 .55367 .46111 .54845 Metetra
.656 .751 .92 r
.46111 .54845 .46637 .55367 .47561 .55085 .47038 .5456 Metetra
.656 .751 .92 r
.47038 .5456 .47561 .55085 .48489 .54801 .47968 .54274 Metetra
.656 .751 .92 r
.47968 .54274 .48489 .54801 .49421 .54516 .48901 .53988 Metetra
.656 .751 .92 r
.48901 .53988 .49421 .54516 .50355 .5423 .49838 .537 Metetra
.656 .751 .92 r
.49838 .537 .50355 .5423 .51293 .53944 .50777 .53412 Metetra
.656 .751 .92 r
.50777 .53412 .51293 .53944 .52233 .53656 .5172 .53122 Metetra
.656 .751 .92 r
.5172 .53122 .52233 .53656 .53177 .53367 .52666 .52832 Metetra
.656 .751 .92 r
.52666 .52832 .53177 .53367 .54125 .53077 .53616 .5254 Metetra
.656 .751 .92 r
.53616 .5254 .54125 .53077 .55075 .52787 .54568 .52248 Metetra
.656 .751 .92 r
.54568 .52248 .55075 .52787 .56029 .52495 .55524 .51954 Metetra
.656 .751 .92 r
.55524 .51954 .56029 .52495 .56986 .52202 .56484 .51659 Metetra
.656 .751 .92 r
.56484 .51659 .56986 .52202 .57946 .51909 .57446 .51364 Metetra
.656 .751 .92 r
.57446 .51364 .57946 .51909 .5891 .51614 .58412 .51067 Metetra
.656 .751 .92 r
.58412 .51067 .5891 .51614 .59877 .51318 .59382 .50769 Metetra
.656 .751 .92 r
.59382 .50769 .59877 .51318 .60848 .51021 .60354 .50471 Metetra
.656 .751 .92 r
.60354 .50471 .60848 .51021 .61822 .50724 .6133 .50171 Metetra
.656 .751 .92 r
.6133 .50171 .61822 .50724 .62799 .50425 .6231 .4987 Metetra
.656 .751 .92 r
.6231 .4987 .62799 .50425 .63779 .50125 .63293 .49568 Metetra
.656 .751 .92 r
.63293 .49568 .63779 .50125 .64764 .49824 .64279 .49265 Metetra
.656 .751 .92 r
.64279 .49265 .64764 .49824 .65751 .49522 .65269 .48962 Metetra
.656 .751 .92 r
.65269 .48962 .65751 .49522 .66742 .49219 .66263 .48656 Metetra
.656 .751 .92 r
.66263 .48656 .66742 .49219 .67737 .48915 .6726 .4835 Metetra
.656 .751 .92 r
.6726 .4835 .67737 .48915 .68735 .48609 .6826 .48043 Metetra
.656 .751 .92 r
.6826 .48043 .68735 .48609 .69736 .48303 .69264 .47735 Metetra
.656 .751 .92 r
.69264 .47735 .69736 .48303 .70741 .47996 .70272 .47425 Metetra
.656 .751 .92 r
.70272 .47425 .70741 .47996 .7175 .47687 .71283 .47115 Metetra
.656 .751 .92 r
.71283 .47115 .7175 .47687 .72762 .47378 .72298 .46803 Metetra
.656 .751 .92 r
.72298 .46803 .72762 .47378 .73778 .47067 .73316 .46491 Metetra
.656 .751 .92 r
.73316 .46491 .73778 .47067 .74798 .46755 .74338 .46177 Metetra
.656 .751 .92 r
.74338 .46177 .74798 .46755 .75821 .46442 .75364 .45862 Metetra
.656 .751 .92 r
.75364 .45862 .75821 .46442 .76848 .46128 .76393 .45546 Metetra
.656 .751 .92 r
.76393 .45546 .76848 .46128 .77878 .45813 .77426 .45228 Metetra
.656 .751 .92 r
.77426 .45228 .77878 .45813 .78913 .45497 .78463 .4491 Metetra
.656 .751 .92 r
.78463 .4491 .78913 .45497 .7995 .45179 .79504 .4459 Metetra
.656 .751 .92 r
.79504 .4459 .7995 .45179 .80992 .44861 .80548 .4427 Metetra
.656 .751 .92 r
.80548 .4427 .80992 .44861 .82038 .44541 .81596 .43948 Metetra
.656 .751 .92 r
.81596 .43948 .82038 .44541 .83087 .4422 .82648 .43625 Metetra
.656 .751 .92 r
.82648 .43625 .83087 .4422 .8414 .43898 .83704 .43301 Metetra
.656 .751 .92 r
.83704 .43301 .8414 .43898 .85197 .43575 .84764 .42975 Metetra
.656 .751 .92 r
.84764 .42975 .85197 .43575 .86257 .43251 .85827 .42649 Metetra
.656 .751 .92 r
.85827 .42649 .86257 .43251 .87322 .42925 .86895 .42321 Metetra
.656 .751 .92 r
.86895 .42321 .87322 .42925 .88391 .42598 .87966 .41992 Metetra
.656 .751 .92 r
.87966 .41992 .88391 .42598 .89463 .4227 .89041 .41662 Metetra
.656 .751 .92 r
.89041 .41662 .89463 .4227 .90539 .41941 .9012 .4133 Metetra
.687 .823 .948 r
.28512 .59658 .29087 .59995 .29951 .59807 .29388 .59312 Metetra
.656 .751 .92 r
.29388 .59312 .29951 .59807 .30823 .59539 .30263 .59042 Metetra
.656 .751 .92 r
.30263 .59042 .30823 .59539 .31699 .5927 .3114 .58772 Metetra
.656 .751 .92 r
.3114 .58772 .31699 .5927 .32577 .59 .3202 .585 Metetra
.656 .751 .92 r
.3202 .585 .32577 .59 .33458 .5873 .32903 .58228 Metetra
.656 .751 .92 r
.32903 .58228 .33458 .5873 .34343 .58458 .33789 .57955 Metetra
.656 .751 .92 r
.33789 .57955 .34343 .58458 .3523 .58186 .34678 .57681 Metetra
.656 .751 .92 r
.34678 .57681 .3523 .58186 .3612 .57913 .3557 .57406 Metetra
.656 .751 .92 r
.3557 .57406 .3612 .57913 .37013 .57638 .36465 .5713 Metetra
.656 .751 .92 r
.36465 .5713 .37013 .57638 .37909 .57363 .37363 .56853 Metetra
.656 .751 .92 r
.37363 .56853 .37909 .57363 .38808 .57087 .38264 .56575 Metetra
.656 .751 .92 r
.38264 .56575 .38808 .57087 .3971 .5681 .39168 .56296 Metetra
.656 .751 .92 r
.39168 .56296 .3971 .5681 .40615 .56532 .40075 .56016 Metetra
.656 .751 .92 r
.40075 .56016 .40615 .56532 .41524 .56253 .40985 .55736 Metetra
.656 .751 .92 r
.40985 .55736 .41524 .56253 .42435 .55973 .41898 .55454 Metetra
.656 .751 .92 r
.41898 .55454 .42435 .55973 .43349 .55693 .42815 .55172 Metetra
.656 .751 .92 r
.42815 .55172 .43349 .55693 .44267 .55411 .43734 .54888 Metetra
.656 .751 .92 r
.43734 .54888 .44267 .55411 .45187 .55128 .44657 .54604 Metetra
.656 .751 .92 r
.44657 .54604 .45187 .55128 .46111 .54845 .45582 .54318 Metetra
.656 .751 .92 r
.45582 .54318 .46111 .54845 .47038 .5456 .46511 .54032 Metetra
.656 .751 .92 r
.46511 .54032 .47038 .5456 .47968 .54274 .47443 .53744 Metetra
.656 .751 .92 r
.47443 .53744 .47968 .54274 .48901 .53988 .48379 .53456 Metetra
.656 .751 .92 r
.48379 .53456 .48901 .53988 .49838 .537 .49317 .53167 Metetra
.656 .751 .92 r
.49317 .53167 .49838 .537 .50777 .53412 .50259 .52876 Metetra
.656 .751 .92 r
.50259 .52876 .50777 .53412 .5172 .53122 .51204 .52585 Metetra
.656 .751 .92 r
.51204 .52585 .5172 .53122 .52666 .52832 .52152 .52293 Metetra
.656 .751 .92 r
.52152 .52293 .52666 .52832 .53616 .5254 .53104 .51999 Metetra
.656 .751 .92 r
.53104 .51999 .53616 .5254 .54568 .52248 .54058 .51705 Metetra
.656 .751 .92 r
.54058 .51705 .54568 .52248 .55524 .51954 .55017 .51409 Metetra
.656 .751 .92 r
.55017 .51409 .55524 .51954 .56484 .51659 .55978 .51113 Metetra
.656 .751 .92 r
.55978 .51113 .56484 .51659 .57446 .51364 .56943 .50815 Metetra
.656 .751 .92 r
.56943 .50815 .57446 .51364 .58412 .51067 .57911 .50517 Metetra
.656 .751 .92 r
.57911 .50517 .58412 .51067 .59382 .50769 .58883 .50217 Metetra
.656 .751 .92 r
.58883 .50217 .59382 .50769 .60354 .50471 .59858 .49917 Metetra
.656 .751 .92 r
.59858 .49917 .60354 .50471 .6133 .50171 .60836 .49615 Metetra
.656 .751 .92 r
.60836 .49615 .6133 .50171 .6231 .4987 .61818 .49312 Metetra
.656 .751 .92 r
.61818 .49312 .6231 .4987 .63293 .49568 .62803 .49008 Metetra
.656 .751 .92 r
.62803 .49008 .63293 .49568 .64279 .49265 .63792 .48703 Metetra
.656 .751 .92 r
.63792 .48703 .64279 .49265 .65269 .48962 .64784 .48397 Metetra
.656 .751 .92 r
.64784 .48397 .65269 .48962 .66263 .48656 .6578 .4809 Metetra
.656 .751 .92 r
.6578 .4809 .66263 .48656 .6726 .4835 .6678 .47782 Metetra
.656 .751 .92 r
.6678 .47782 .6726 .4835 .6826 .48043 .67782 .47473 Metetra
.656 .751 .92 r
.67782 .47473 .6826 .48043 .69264 .47735 .68789 .47163 Metetra
.656 .751 .92 r
.68789 .47163 .69264 .47735 .70272 .47425 .69799 .46851 Metetra
.656 .751 .92 r
.69799 .46851 .70272 .47425 .71283 .47115 .70813 .46539 Metetra
.656 .751 .92 r
.70813 .46539 .71283 .47115 .72298 .46803 .7183 .46225 Metetra
.656 .751 .92 r
.7183 .46225 .72298 .46803 .73316 .46491 .72851 .4591 Metetra
.656 .751 .92 r
.72851 .4591 .73316 .46491 .74338 .46177 .73875 .45594 Metetra
.656 .751 .92 r
.73875 .45594 .74338 .46177 .75364 .45862 .74904 .45277 Metetra
.656 .751 .92 r
.74904 .45277 .75364 .45862 .76393 .45546 .75936 .44959 Metetra
.656 .751 .92 r
.75936 .44959 .76393 .45546 .77426 .45228 .76971 .4464 Metetra
.656 .751 .92 r
.76971 .4464 .77426 .45228 .78463 .4491 .78011 .44319 Metetra
.656 .751 .92 r
.78011 .44319 .78463 .4491 .79504 .4459 .79054 .43997 Metetra
.656 .751 .92 r
.79054 .43997 .79504 .4459 .80548 .4427 .80101 .43675 Metetra
.656 .751 .92 r
.80101 .43675 .80548 .4427 .81596 .43948 .81152 .43351 Metetra
.656 .751 .92 r
.81152 .43351 .81596 .43948 .82648 .43625 .82207 .43025 Metetra
.656 .751 .92 r
.82207 .43025 .82648 .43625 .83704 .43301 .83265 .42699 Metetra
.656 .751 .92 r
.83265 .42699 .83704 .43301 .84764 .42975 .84328 .42371 Metetra
.656 .751 .92 r
.84328 .42371 .84764 .42975 .85827 .42649 .85394 .42043 Metetra
.656 .751 .92 r
.85394 .42043 .85827 .42649 .86895 .42321 .86464 .41713 Metetra
.656 .751 .92 r
.86464 .41713 .86895 .42321 .87966 .41992 .87538 .41381 Metetra
.656 .751 .92 r
.87538 .41381 .87966 .41992 .89041 .41662 .88617 .41049 Metetra
.656 .751 .92 r
.88617 .41049 .89041 .41662 .9012 .4133 .89699 .40715 Metetra
.643 .707 .893 r
.27952 .59051 .28512 .59658 .29388 .59312 .28823 .58813 Metetra
.656 .751 .92 r
.28823 .58813 .29388 .59312 .30263 .59042 .29699 .58542 Metetra
.656 .751 .92 r
.29699 .58542 .30263 .59042 .3114 .58772 .30578 .5827 Metetra
.656 .751 .92 r
.30578 .5827 .3114 .58772 .3202 .585 .31459 .57997 Metetra
.656 .751 .92 r
.31459 .57997 .3202 .585 .32903 .58228 .32344 .57723 Metetra
.656 .751 .92 r
.32344 .57723 .32903 .58228 .33789 .57955 .33232 .57448 Metetra
.656 .751 .92 r
.33232 .57448 .33789 .57955 .34678 .57681 .34123 .57172 Metetra
.656 .751 .92 r
.34123 .57172 .34678 .57681 .3557 .57406 .35017 .56895 Metetra
.656 .751 .92 r
.35017 .56895 .3557 .57406 .36465 .5713 .35913 .56618 Metetra
.656 .751 .92 r
.35913 .56618 .36465 .5713 .37363 .56853 .36813 .56339 Metetra
.656 .751 .92 r
.36813 .56339 .37363 .56853 .38264 .56575 .37716 .5606 Metetra
.656 .751 .92 r
.37716 .5606 .38264 .56575 .39168 .56296 .38622 .55779 Metetra
.656 .751 .92 r
.38622 .55779 .39168 .56296 .40075 .56016 .39531 .55498 Metetra
.656 .751 .92 r
.39531 .55498 .40075 .56016 .40985 .55736 .40443 .55215 Metetra
.656 .751 .92 r
.40443 .55215 .40985 .55736 .41898 .55454 .41358 .54932 Metetra
.656 .751 .92 r
.41358 .54932 .41898 .55454 .42815 .55172 .42276 .54648 Metetra
.656 .751 .92 r
.42276 .54648 .42815 .55172 .43734 .54888 .43198 .54362 Metetra
.656 .751 .92 r
.43198 .54362 .43734 .54888 .44657 .54604 .44122 .54076 Metetra
.656 .751 .92 r
.44122 .54076 .44657 .54604 .45582 .54318 .4505 .53789 Metetra
.656 .751 .92 r
.4505 .53789 .45582 .54318 .46511 .54032 .45981 .53501 Metetra
.656 .751 .92 r
.45981 .53501 .46511 .54032 .47443 .53744 .46915 .53211 Metetra
.656 .751 .92 r
.46915 .53211 .47443 .53744 .48379 .53456 .47853 .52921 Metetra
.656 .751 .92 r
.47853 .52921 .48379 .53456 .49317 .53167 .48793 .5263 Metetra
.656 .751 .92 r
.48793 .5263 .49317 .53167 .50259 .52876 .49737 .52338 Metetra
.656 .751 .92 r
.49737 .52338 .50259 .52876 .51204 .52585 .50684 .52044 Metetra
.656 .751 .92 r
.50684 .52044 .51204 .52585 .52152 .52293 .51635 .5175 Metetra
.656 .751 .92 r
.51635 .5175 .52152 .52293 .53104 .51999 .52588 .51455 Metetra
.656 .751 .92 r
.52588 .51455 .53104 .51999 .54058 .51705 .53545 .51159 Metetra
.656 .751 .92 r
.53545 .51159 .54058 .51705 .55017 .51409 .54506 .50861 Metetra
.656 .751 .92 r
.54506 .50861 .55017 .51409 .55978 .51113 .55469 .50563 Metetra
.656 .751 .92 r
.55469 .50563 .55978 .51113 .56943 .50815 .56436 .50263 Metetra
.656 .751 .92 r
.56436 .50263 .56943 .50815 .57911 .50517 .57407 .49963 Metetra
.656 .751 .92 r
.57407 .49963 .57911 .50517 .58883 .50217 .58381 .49661 Metetra
.656 .751 .92 r
.58381 .49661 .58883 .50217 .59858 .49917 .59358 .49359 Metetra
.656 .751 .92 r
.59358 .49359 .59858 .49917 .60836 .49615 .60339 .49055 Metetra
.656 .751 .92 r
.60339 .49055 .60836 .49615 .61818 .49312 .61323 .4875 Metetra
.656 .751 .92 r
.61323 .4875 .61818 .49312 .62803 .49008 .6231 .48445 Metetra
.656 .751 .92 r
.6231 .48445 .62803 .49008 .63792 .48703 .63302 .48138 Metetra
.656 .751 .92 r
.63302 .48138 .63792 .48703 .64784 .48397 .64296 .4783 Metetra
.656 .751 .92 r
.64296 .4783 .64784 .48397 .6578 .4809 .65294 .47521 Metetra
.656 .751 .92 r
.65294 .47521 .6578 .4809 .6678 .47782 .66296 .47211 Metetra
.656 .751 .92 r
.66296 .47211 .6678 .47782 .67782 .47473 .67302 .46899 Metetra
.656 .751 .92 r
.67302 .46899 .67782 .47473 .68789 .47163 .6831 .46587 Metetra
.656 .751 .92 r
.6831 .46587 .68789 .47163 .69799 .46851 .69323 .46273 Metetra
.656 .751 .92 r
.69323 .46273 .69799 .46851 .70813 .46539 .70339 .45959 Metetra
.656 .751 .92 r
.70339 .45959 .70813 .46539 .7183 .46225 .71359 .45643 Metetra
.656 .751 .92 r
.71359 .45643 .7183 .46225 .72851 .4591 .72382 .45326 Metetra
.656 .751 .92 r
.72382 .45326 .72851 .4591 .73875 .45594 .7341 .45008 Metetra
.656 .751 .92 r
.7341 .45008 .73875 .45594 .74904 .45277 .74441 .44689 Metetra
.656 .751 .92 r
.74441 .44689 .74904 .45277 .75936 .44959 .75475 .44369 Metetra
.656 .751 .92 r
.75475 .44369 .75936 .44959 .76971 .4464 .76514 .44047 Metetra
.656 .751 .92 r
.76514 .44047 .76971 .4464 .78011 .44319 .77556 .43724 Metetra
.656 .751 .92 r
.77556 .43724 .78011 .44319 .79054 .43997 .78602 .43401 Metetra
.656 .751 .92 r
.78602 .43401 .79054 .43997 .80101 .43675 .79651 .43076 Metetra
.656 .751 .92 r
.79651 .43076 .80101 .43675 .81152 .43351 .80705 .42749 Metetra
.656 .751 .92 r
.80705 .42749 .81152 .43351 .82207 .43025 .81762 .42422 Metetra
.656 .751 .92 r
.81762 .42422 .82207 .43025 .83265 .42699 .82824 .42093 Metetra
.656 .751 .92 r
.82824 .42093 .83265 .42699 .84328 .42371 .83889 .41763 Metetra
.656 .751 .92 r
.83889 .41763 .84328 .42371 .85394 .42043 .84958 .41432 Metetra
.656 .751 .92 r
.84958 .41432 .85394 .42043 .86464 .41713 .86031 .411 Metetra
.656 .751 .92 r
.86031 .411 .86464 .41713 .87538 .41381 .87108 .40767 Metetra
.656 .751 .92 r
.87108 .40767 .87538 .41381 .88617 .41049 .88189 .40432 Metetra
.656 .751 .92 r
.88189 .40432 .88617 .41049 .89699 .40715 .89274 .40096 Metetra
.647 .755 .928 r
.2738 .58566 .27952 .59051 .28823 .58813 .28253 .58312 Metetra
.656 .751 .92 r
.28253 .58312 .28823 .58813 .29699 .58542 .29131 .58039 Metetra
.656 .751 .92 r
.29131 .58039 .29699 .58542 .30578 .5827 .30012 .57765 Metetra
.656 .751 .92 r
.30012 .57765 .30578 .5827 .31459 .57997 .30895 .5749 Metetra
.656 .751 .92 r
.30895 .5749 .31459 .57997 .32344 .57723 .31782 .57215 Metetra
.656 .751 .92 r
.31782 .57215 .32344 .57723 .33232 .57448 .32672 .56938 Metetra
.656 .751 .92 r
.32672 .56938 .33232 .57448 .34123 .57172 .33564 .56661 Metetra
.656 .751 .92 r
.33564 .56661 .34123 .57172 .35017 .56895 .3446 .56382 Metetra
.656 .751 .92 r
.3446 .56382 .35017 .56895 .35913 .56618 .35358 .56103 Metetra
.656 .751 .92 r
.35358 .56103 .35913 .56618 .36813 .56339 .3626 .55822 Metetra
.656 .751 .92 r
.3626 .55822 .36813 .56339 .37716 .5606 .37165 .55541 Metetra
.656 .751 .92 r
.37165 .55541 .37716 .5606 .38622 .55779 .38073 .55259 Metetra
.656 .751 .92 r
.38073 .55259 .38622 .55779 .39531 .55498 .38984 .54976 Metetra
.656 .751 .92 r
.38984 .54976 .39531 .55498 .40443 .55215 .39898 .54691 Metetra
.656 .751 .92 r
.39898 .54691 .40443 .55215 .41358 .54932 .40815 .54406 Metetra
.656 .751 .92 r
.40815 .54406 .41358 .54932 .42276 .54648 .41735 .5412 Metetra
.656 .751 .92 r
.41735 .5412 .42276 .54648 .43198 .54362 .42658 .53833 Metetra
.656 .751 .92 r
.42658 .53833 .43198 .54362 .44122 .54076 .43585 .53545 Metetra
.656 .751 .92 r
.43585 .53545 .44122 .54076 .4505 .53789 .44515 .53256 Metetra
.656 .751 .92 r
.44515 .53256 .4505 .53789 .45981 .53501 .45448 .52966 Metetra
.656 .751 .92 r
.45448 .52966 .45981 .53501 .46915 .53211 .46384 .52675 Metetra
.656 .751 .92 r
.46384 .52675 .46915 .53211 .47853 .52921 .47323 .52383 Metetra
.656 .751 .92 r
.47323 .52383 .47853 .52921 .48793 .5263 .48266 .5209 Metetra
.656 .751 .92 r
.48266 .5209 .48793 .5263 .49737 .52338 .49212 .51795 Metetra
.656 .751 .92 r
.49212 .51795 .49737 .52338 .50684 .52044 .50161 .515 Metetra
.656 .751 .92 r
.50161 .515 .50684 .52044 .51635 .5175 .51114 .51204 Metetra
.656 .751 .92 r
.51114 .51204 .51635 .5175 .52588 .51455 .52069 .50907 Metetra
.656 .751 .92 r
.52069 .50907 .52588 .51455 .53545 .51159 .53029 .50609 Metetra
.656 .751 .92 r
.53029 .50609 .53545 .51159 .54506 .50861 .53991 .5031 Metetra
.656 .751 .92 r
.53991 .5031 .54506 .50861 .55469 .50563 .54957 .50009 Metetra
.656 .751 .92 r
.54957 .50009 .55469 .50563 .56436 .50263 .55926 .49708 Metetra
.656 .751 .92 r
.55926 .49708 .56436 .50263 .57407 .49963 .56899 .49405 Metetra
.656 .751 .92 r
.56899 .49405 .57407 .49963 .58381 .49661 .57875 .49102 Metetra
.656 .751 .92 r
.57875 .49102 .58381 .49661 .59358 .49359 .58855 .48797 Metetra
.656 .751 .92 r
.58855 .48797 .59358 .49359 .60339 .49055 .59838 .48492 Metetra
.656 .751 .92 r
.59838 .48492 .60339 .49055 .61323 .4875 .60824 .48185 Metetra
.656 .751 .92 r
.60824 .48185 .61323 .4875 .6231 .48445 .61814 .47877 Metetra
.656 .751 .92 r
.61814 .47877 .6231 .48445 .63302 .48138 .62808 .47568 Metetra
.656 .751 .92 r
.62808 .47568 .63302 .48138 .64296 .4783 .63805 .47258 Metetra
.656 .751 .92 r
.63805 .47258 .64296 .4783 .65294 .47521 .64806 .46947 Metetra
.656 .751 .92 r
.64806 .46947 .65294 .47521 .66296 .47211 .6581 .46635 Metetra
.656 .751 .92 r
.6581 .46635 .66296 .47211 .67302 .46899 .66817 .46322 Metetra
.656 .751 .92 r
.66817 .46322 .67302 .46899 .6831 .46587 .67829 .46007 Metetra
.656 .751 .92 r
.67829 .46007 .6831 .46587 .69323 .46273 .68844 .45692 Metetra
.656 .751 .92 r
.68844 .45692 .69323 .46273 .70339 .45959 .69863 .45375 Metetra
.656 .751 .92 r
.69863 .45375 .70339 .45959 .71359 .45643 .70885 .45057 Metetra
.656 .751 .92 r
.70885 .45057 .71359 .45643 .72382 .45326 .71911 .44738 Metetra
.656 .751 .92 r
.71911 .44738 .72382 .45326 .7341 .45008 .72941 .44418 Metetra
.656 .751 .92 r
.72941 .44418 .7341 .45008 .74441 .44689 .73974 .44097 Metetra
.656 .751 .92 r
.73974 .44097 .74441 .44689 .75475 .44369 .75011 .43774 Metetra
.656 .751 .92 r
.75011 .43774 .75475 .44369 .76514 .44047 .76052 .4345 Metetra
.656 .751 .92 r
.76052 .4345 .76514 .44047 .77556 .43724 .77097 .43126 Metetra
.656 .751 .92 r
.77097 .43126 .77556 .43724 .78602 .43401 .78146 .428 Metetra
.656 .751 .92 r
.78146 .428 .78602 .43401 .79651 .43076 .79198 .42472 Metetra
.656 .751 .92 r
.79198 .42472 .79651 .43076 .80705 .42749 .80255 .42144 Metetra
.656 .751 .92 r
.80255 .42144 .80705 .42749 .81762 .42422 .81315 .41814 Metetra
.656 .751 .92 r
.81315 .41814 .81762 .42422 .82824 .42093 .82379 .41483 Metetra
.656 .751 .92 r
.82379 .41483 .82824 .42093 .83889 .41763 .83447 .41151 Metetra
.656 .751 .92 r
.83447 .41151 .83889 .41763 .84958 .41432 .84519 .40818 Metetra
.656 .751 .92 r
.84519 .40818 .84958 .41432 .86031 .411 .85595 .40484 Metetra
.656 .751 .92 r
.85595 .40484 .86031 .411 .87108 .40767 .86675 .40148 Metetra
.656 .751 .92 r
.86675 .40148 .87108 .40767 .88189 .40432 .87759 .39811 Metetra
.656 .751 .92 r
.87759 .39811 .88189 .40432 .89274 .40096 .88846 .39473 Metetra
.674 .779 .929 r
.26801 .58123 .2738 .58566 .28253 .58312 .2768 .57807 Metetra
.656 .751 .92 r
.2768 .57807 .28253 .58312 .29131 .58039 .2856 .57533 Metetra
.656 .751 .92 r
.2856 .57533 .29131 .58039 .30012 .57765 .29442 .57257 Metetra
.656 .751 .92 r
.29442 .57257 .30012 .57765 .30895 .5749 .30328 .56981 Metetra
.656 .751 .92 r
.30328 .56981 .30895 .5749 .31782 .57215 .31216 .56703 Metetra
.656 .751 .92 r
.31216 .56703 .31782 .57215 .32672 .56938 .32108 .56425 Metetra
.656 .751 .92 r
.32108 .56425 .32672 .56938 .33564 .56661 .33002 .56146 Metetra
.656 .751 .92 r
.33002 .56146 .33564 .56661 .3446 .56382 .33899 .55865 Metetra
.656 .751 .92 r
.33899 .55865 .3446 .56382 .35358 .56103 .348 .55584 Metetra
.656 .751 .92 r
.348 .55584 .35358 .56103 .3626 .55822 .35704 .55302 Metetra
.656 .751 .92 r
.35704 .55302 .3626 .55822 .37165 .55541 .3661 .55019 Metetra
.656 .751 .92 r
.3661 .55019 .37165 .55541 .38073 .55259 .3752 .54735 Metetra
.656 .751 .92 r
.3752 .54735 .38073 .55259 .38984 .54976 .38433 .5445 Metetra
.656 .751 .92 r
.38433 .5445 .38984 .54976 .39898 .54691 .39349 .54164 Metetra
.656 .751 .92 r
.39349 .54164 .39898 .54691 .40815 .54406 .40268 .53877 Metetra
.656 .751 .92 r
.40268 .53877 .40815 .54406 .41735 .5412 .4119 .53589 Metetra
.656 .751 .92 r
.4119 .53589 .41735 .5412 .42658 .53833 .42115 .533 Metetra
.656 .751 .92 r
.42115 .533 .42658 .53833 .43585 .53545 .43044 .5301 Metetra
.656 .751 .92 r
.43044 .5301 .43585 .53545 .44515 .53256 .43976 .5272 Metetra
.656 .751 .92 r
.43976 .5272 .44515 .53256 .45448 .52966 .44911 .52428 Metetra
.656 .751 .92 r
.44911 .52428 .45448 .52966 .46384 .52675 .45849 .52135 Metetra
.656 .751 .92 r
.45849 .52135 .46384 .52675 .47323 .52383 .46791 .51841 Metetra
.656 .751 .92 r
.46791 .51841 .47323 .52383 .48266 .5209 .47735 .51546 Metetra
.656 .751 .92 r
.47735 .51546 .48266 .5209 .49212 .51795 .48683 .5125 Metetra
.656 .751 .92 r
.48683 .5125 .49212 .51795 .50161 .515 .49635 .50953 Metetra
.656 .751 .92 r
.49635 .50953 .50161 .515 .51114 .51204 .50589 .50655 Metetra
.656 .751 .92 r
.50589 .50655 .51114 .51204 .52069 .50907 .51547 .50356 Metetra
.656 .751 .92 r
.51547 .50356 .52069 .50907 .53029 .50609 .52509 .50055 Metetra
.656 .751 .92 r
.52509 .50055 .53029 .50609 .53991 .5031 .53473 .49754 Metetra
.656 .751 .92 r
.53473 .49754 .53991 .5031 .54957 .50009 .54442 .49452 Metetra
.656 .751 .92 r
.54442 .49452 .54957 .50009 .55926 .49708 .55413 .49149 Metetra
.656 .751 .92 r
.55413 .49149 .55926 .49708 .56899 .49405 .56388 .48844 Metetra
.656 .751 .92 r
.56388 .48844 .56899 .49405 .57875 .49102 .57367 .48539 Metetra
.656 .751 .92 r
.57367 .48539 .57875 .49102 .58855 .48797 .58348 .48232 Metetra
.656 .751 .92 r
.58348 .48232 .58855 .48797 .59838 .48492 .59334 .47925 Metetra
.656 .751 .92 r
.59334 .47925 .59838 .48492 .60824 .48185 .60323 .47616 Metetra
.656 .751 .92 r
.60323 .47616 .60824 .48185 .61814 .47877 .61315 .47306 Metetra
.656 .751 .92 r
.61315 .47306 .61814 .47877 .62808 .47568 .62311 .46995 Metetra
.656 .751 .92 r
.62311 .46995 .62808 .47568 .63805 .47258 .6331 .46683 Metetra
.656 .751 .92 r
.6331 .46683 .63805 .47258 .64806 .46947 .64313 .4637 Metetra
.656 .751 .92 r
.64313 .4637 .64806 .46947 .6581 .46635 .6532 .46056 Metetra
.656 .751 .92 r
.6532 .46056 .6581 .46635 .66817 .46322 .6633 .4574 Metetra
.656 .751 .92 r
.6633 .4574 .66817 .46322 .67829 .46007 .67344 .45424 Metetra
.656 .751 .92 r
.67344 .45424 .67829 .46007 .68844 .45692 .68362 .45106 Metetra
.656 .751 .92 r
.68362 .45106 .68844 .45692 .69863 .45375 .69383 .44787 Metetra
.656 .751 .92 r
.69383 .44787 .69863 .45375 .70885 .45057 .70408 .44467 Metetra
.656 .751 .92 r
.70408 .44467 .70885 .45057 .71911 .44738 .71436 .44146 Metetra
.656 .751 .92 r
.71436 .44146 .71911 .44738 .72941 .44418 .72469 .43824 Metetra
.656 .751 .92 r
.72469 .43824 .72941 .44418 .73974 .44097 .73505 .435 Metetra
.656 .751 .92 r
.73505 .435 .73974 .44097 .75011 .43774 .74545 .43176 Metetra
.656 .751 .92 r
.74545 .43176 .75011 .43774 .76052 .4345 .75588 .4285 Metetra
.656 .751 .92 r
.75588 .4285 .76052 .4345 .77097 .43126 .76636 .42523 Metetra
.656 .751 .92 r
.76636 .42523 .77097 .43126 .78146 .428 .77687 .42195 Metetra
.656 .751 .92 r
.77687 .42195 .78146 .428 .79198 .42472 .78742 .41865 Metetra
.656 .751 .92 r
.78742 .41865 .79198 .42472 .80255 .42144 .79801 .41534 Metetra
.656 .751 .92 r
.79801 .41534 .80255 .42144 .81315 .41814 .80864 .41203 Metetra
.656 .751 .92 r
.80864 .41203 .81315 .41814 .82379 .41483 .81931 .4087 Metetra
.656 .751 .92 r
.81931 .4087 .82379 .41483 .83447 .41151 .83002 .40535 Metetra
.656 .751 .92 r
.83002 .40535 .83447 .41151 .84519 .40818 .84077 .402 Metetra
.656 .751 .92 r
.84077 .402 .84519 .40818 .85595 .40484 .85156 .39863 Metetra
.656 .751 .92 r
.85156 .39863 .85595 .40484 .86675 .40148 .86238 .39525 Metetra
.656 .751 .92 r
.86238 .39525 .86675 .40148 .87759 .39811 .87325 .39185 Metetra
.656 .751 .92 r
.87325 .39185 .87759 .39811 .88846 .39473 .88416 .38845 Metetra
.642 .719 .904 r
.26228 .57541 .26801 .58123 .2768 .57807 .27104 .573 Metetra
.656 .751 .92 r
.27104 .573 .2768 .57807 .2856 .57533 .27985 .57023 Metetra
.656 .751 .92 r
.27985 .57023 .2856 .57533 .29442 .57257 .28869 .56746 Metetra
.656 .751 .92 r
.28869 .56746 .29442 .57257 .30328 .56981 .29757 .56468 Metetra
.656 .751 .92 r
.29757 .56468 .30328 .56981 .31216 .56703 .30647 .56189 Metetra
.656 .751 .92 r
.30647 .56189 .31216 .56703 .32108 .56425 .3154 .55909 Metetra
.656 .751 .92 r
.3154 .55909 .32108 .56425 .33002 .56146 .32436 .55628 Metetra
.656 .751 .92 r
.32436 .55628 .33002 .56146 .33899 .55865 .33336 .55346 Metetra
.656 .751 .92 r
.33336 .55346 .33899 .55865 .348 .55584 .34238 .55063 Metetra
.656 .751 .92 r
.34238 .55063 .348 .55584 .35704 .55302 .35144 .54779 Metetra
.656 .751 .92 r
.35144 .54779 .35704 .55302 .3661 .55019 .36052 .54494 Metetra
.656 .751 .92 r
.36052 .54494 .3661 .55019 .3752 .54735 .36964 .54208 Metetra
.656 .751 .92 r
.36964 .54208 .3752 .54735 .38433 .5445 .37878 .53921 Metetra
.656 .751 .92 r
.37878 .53921 .38433 .5445 .39349 .54164 .38796 .53634 Metetra
.656 .751 .92 r
.38796 .53634 .39349 .54164 .40268 .53877 .39717 .53345 Metetra
.656 .751 .92 r
.39717 .53345 .40268 .53877 .4119 .53589 .40642 .53055 Metetra
.656 .751 .92 r
.40642 .53055 .4119 .53589 .42115 .533 .41569 .52764 Metetra
.656 .751 .92 r
.41569 .52764 .42115 .533 .43044 .5301 .425 .52473 Metetra
.656 .751 .92 r
.425 .52473 .43044 .5301 .43976 .5272 .43433 .5218 Metetra
.656 .751 .92 r
.43433 .5218 .43976 .5272 .44911 .52428 .4437 .51886 Metetra
.656 .751 .92 r
.4437 .51886 .44911 .52428 .45849 .52135 .45311 .51591 Metetra
.656 .751 .92 r
.45311 .51591 .45849 .52135 .46791 .51841 .46254 .51295 Metetra
.656 .751 .92 r
.46254 .51295 .46791 .51841 .47735 .51546 .47201 .50999 Metetra
.656 .751 .92 r
.47201 .50999 .47735 .51546 .48683 .5125 .48151 .50701 Metetra
.656 .751 .92 r
.48151 .50701 .48683 .5125 .49635 .50953 .49105 .50402 Metetra
.656 .751 .92 r
.49105 .50402 .49635 .50953 .50589 .50655 .50062 .50102 Metetra
.656 .751 .92 r
.50062 .50102 .50589 .50655 .51547 .50356 .51022 .49801 Metetra
.656 .751 .92 r
.51022 .49801 .51547 .50356 .52509 .50055 .51985 .49499 Metetra
.656 .751 .92 r
.51985 .49499 .52509 .50055 .53473 .49754 .52952 .49195 Metetra
.656 .751 .92 r
.52952 .49195 .53473 .49754 .54442 .49452 .53923 .48891 Metetra
.656 .751 .92 r
.53923 .48891 .54442 .49452 .55413 .49149 .54897 .48586 Metetra
.656 .751 .92 r
.54897 .48586 .55413 .49149 .56388 .48844 .55874 .4828 Metetra
.656 .751 .92 r
.55874 .4828 .56388 .48844 .57367 .48539 .56855 .47972 Metetra
.656 .751 .92 r
.56855 .47972 .57367 .48539 .58348 .48232 .57839 .47663 Metetra
.656 .751 .92 r
.57839 .47663 .58348 .48232 .59334 .47925 .58826 .47354 Metetra
.656 .751 .92 r
.58826 .47354 .59334 .47925 .60323 .47616 .59818 .47043 Metetra
.656 .751 .92 r
.59818 .47043 .60323 .47616 .61315 .47306 .60812 .46731 Metetra
.656 .751 .92 r
.60812 .46731 .61315 .47306 .62311 .46995 .61811 .46418 Metetra
.656 .751 .92 r
.61811 .46418 .62311 .46995 .6331 .46683 .62812 .46104 Metetra
.656 .751 .92 r
.62812 .46104 .6331 .46683 .64313 .4637 .63818 .45789 Metetra
.656 .751 .92 r
.63818 .45789 .64313 .4637 .6532 .46056 .64827 .45473 Metetra
.656 .751 .92 r
.64827 .45473 .6532 .46056 .6633 .4574 .6584 .45155 Metetra
.656 .751 .92 r
.6584 .45155 .6633 .4574 .67344 .45424 .66856 .44836 Metetra
.656 .751 .92 r
.66856 .44836 .67344 .45424 .68362 .45106 .67876 .44517 Metetra
.656 .751 .92 r
.67876 .44517 .68362 .45106 .69383 .44787 .689 .44196 Metetra
.656 .751 .92 r
.689 .44196 .69383 .44787 .70408 .44467 .69927 .43873 Metetra
.656 .751 .92 r
.69927 .43873 .70408 .44467 .71436 .44146 .70959 .4355 Metetra
.656 .751 .92 r
.70959 .4355 .71436 .44146 .72469 .43824 .71993 .43226 Metetra
.656 .751 .92 r
.71993 .43226 .72469 .43824 .73505 .435 .73032 .429 Metetra
.656 .751 .92 r
.73032 .429 .73505 .435 .74545 .43176 .74075 .42573 Metetra
.656 .751 .92 r
.74075 .42573 .74545 .43176 .75588 .4285 .75121 .42245 Metetra
.656 .751 .92 r
.75121 .42245 .75588 .4285 .76636 .42523 .76171 .41916 Metetra
.656 .751 .92 r
.76171 .41916 .76636 .42523 .77687 .42195 .77225 .41585 Metetra
.656 .751 .92 r
.77225 .41585 .77687 .42195 .78742 .41865 .78283 .41254 Metetra
.656 .751 .92 r
.78283 .41254 .78742 .41865 .79801 .41534 .79345 .40921 Metetra
.656 .751 .92 r
.79345 .40921 .79801 .41534 .80864 .41203 .80411 .40587 Metetra
.656 .751 .92 r
.80411 .40587 .80864 .41203 .81931 .4087 .8148 .40251 Metetra
.656 .751 .92 r
.8148 .40251 .81931 .4087 .83002 .40535 .82554 .39915 Metetra
.656 .751 .92 r
.82554 .39915 .83002 .40535 .84077 .402 .83632 .39577 Metetra
.656 .751 .92 r
.83632 .39577 .84077 .402 .85156 .39863 .84713 .39238 Metetra
.656 .751 .92 r
.84713 .39238 .85156 .39863 .86238 .39525 .85799 .38897 Metetra
.656 .751 .92 r
.85799 .38897 .86238 .39525 .87325 .39185 .86889 .38556 Metetra
.656 .751 .92 r
.86889 .38556 .87325 .39185 .88416 .38845 .87983 .38213 Metetra
.66 .769 .93 r
.25643 .57076 .26228 .57541 .27104 .573 .26524 .56789 Metetra
.656 .751 .92 r
.26524 .56789 .27104 .573 .27985 .57023 .27407 .56511 Metetra
.656 .751 .92 r
.27407 .56511 .27985 .57023 .28869 .56746 .28293 .56232 Metetra
.656 .751 .92 r
.28293 .56232 .28869 .56746 .29757 .56468 .29182 .55952 Metetra
.656 .751 .92 r
.29182 .55952 .29757 .56468 .30647 .56189 .30074 .55671 Metetra
.656 .751 .92 r
.30074 .55671 .30647 .56189 .3154 .55909 .30969 .55389 Metetra
.656 .751 .92 r
.30969 .55389 .3154 .55909 .32436 .55628 .31867 .55106 Metetra
.656 .751 .92 r
.31867 .55106 .32436 .55628 .33336 .55346 .32768 .54823 Metetra
.656 .751 .92 r
.32768 .54823 .33336 .55346 .34238 .55063 .33673 .54538 Metetra
.656 .751 .92 r
.33673 .54538 .34238 .55063 .35144 .54779 .3458 .54252 Metetra
.656 .751 .92 r
.3458 .54252 .35144 .54779 .36052 .54494 .3549 .53966 Metetra
.656 .751 .92 r
.3549 .53966 .36052 .54494 .36964 .54208 .36404 .53678 Metetra
.656 .751 .92 r
.36404 .53678 .36964 .54208 .37878 .53921 .37321 .53389 Metetra
.656 .751 .92 r
.37321 .53389 .37878 .53921 .38796 .53634 .3824 .531 Metetra
.656 .751 .92 r
.3824 .531 .38796 .53634 .39717 .53345 .39163 .52809 Metetra
.656 .751 .92 r
.39163 .52809 .39717 .53345 .40642 .53055 .4009 .52518 Metetra
.656 .751 .92 r
.4009 .52518 .40642 .53055 .41569 .52764 .41019 .52225 Metetra
.656 .751 .92 r
.41019 .52225 .41569 .52764 .425 .52473 .41952 .51931 Metetra
.656 .751 .92 r
.41952 .51931 .425 .52473 .43433 .5218 .42888 .51637 Metetra
.656 .751 .92 r
.42888 .51637 .43433 .5218 .4437 .51886 .43827 .51341 Metetra
.656 .751 .92 r
.43827 .51341 .4437 .51886 .45311 .51591 .44769 .51044 Metetra
.656 .751 .92 r
.44769 .51044 .45311 .51591 .46254 .51295 .45715 .50747 Metetra
.656 .751 .92 r
.45715 .50747 .46254 .51295 .47201 .50999 .46664 .50448 Metetra
.656 .751 .92 r
.46664 .50448 .47201 .50999 .48151 .50701 .47616 .50148 Metetra
.656 .751 .92 r
.47616 .50148 .48151 .50701 .49105 .50402 .48572 .49847 Metetra
.656 .751 .92 r
.48572 .49847 .49105 .50402 .50062 .50102 .49531 .49545 Metetra
.656 .751 .92 r
.49531 .49545 .50062 .50102 .51022 .49801 .50493 .49242 Metetra
.656 .751 .92 r
.50493 .49242 .51022 .49801 .51985 .49499 .51459 .48938 Metetra
.656 .751 .92 r
.51459 .48938 .51985 .49499 .52952 .49195 .52428 .48633 Metetra
.656 .751 .92 r
.52428 .48633 .52952 .49195 .53923 .48891 .53401 .48327 Metetra
.656 .751 .92 r
.53401 .48327 .53923 .48891 .54897 .48586 .54377 .48019 Metetra
.656 .751 .92 r
.54377 .48019 .54897 .48586 .55874 .4828 .55356 .47711 Metetra
.656 .751 .92 r
.55356 .47711 .55874 .4828 .56855 .47972 .56339 .47402 Metetra
.656 .751 .92 r
.56339 .47402 .56855 .47972 .57839 .47663 .57326 .47091 Metetra
.656 .751 .92 r
.57326 .47091 .57839 .47663 .58826 .47354 .58316 .46779 Metetra
.656 .751 .92 r
.58316 .46779 .58826 .47354 .59818 .47043 .59309 .46466 Metetra
.656 .751 .92 r
.59309 .46466 .59818 .47043 .60812 .46731 .60306 .46153 Metetra
.656 .751 .92 r
.60306 .46153 .60812 .46731 .61811 .46418 .61307 .45837 Metetra
.656 .751 .92 r
.61307 .45837 .61811 .46418 .62812 .46104 .62311 .45521 Metetra
.656 .751 .92 r
.62311 .45521 .62812 .46104 .63818 .45789 .63319 .45204 Metetra
.656 .751 .92 r
.63319 .45204 .63818 .45789 .64827 .45473 .64331 .44885 Metetra
.656 .751 .92 r
.64331 .44885 .64827 .45473 .6584 .45155 .65346 .44566 Metetra
.656 .751 .92 r
.65346 .44566 .6584 .45155 .66856 .44836 .66365 .44245 Metetra
.656 .751 .92 r
.66365 .44245 .66856 .44836 .67876 .44517 .67387 .43923 Metetra
.656 .751 .92 r
.67387 .43923 .67876 .44517 .689 .44196 .68414 .436 Metetra
.656 .751 .92 r
.68414 .436 .689 .44196 .69927 .43873 .69444 .43276 Metetra
.656 .751 .92 r
.69444 .43276 .69927 .43873 .70959 .4355 .70477 .4295 Metetra
.656 .751 .92 r
.70477 .4295 .70959 .4355 .71993 .43226 .71515 .42624 Metetra
.656 .751 .92 r
.71515 .42624 .71993 .43226 .73032 .429 .72556 .42296 Metetra
.656 .751 .92 r
.72556 .42296 .73032 .429 .74075 .42573 .73602 .41967 Metetra
.656 .751 .92 r
.73602 .41967 .74075 .42573 .75121 .42245 .74651 .41636 Metetra
.656 .751 .92 r
.74651 .41636 .75121 .42245 .76171 .41916 .75703 .41305 Metetra
.656 .751 .92 r
.75703 .41305 .76171 .41916 .77225 .41585 .7676 .40972 Metetra
.656 .751 .92 r
.7676 .40972 .77225 .41585 .78283 .41254 .77821 .40638 Metetra
.656 .751 .92 r
.77821 .40638 .78283 .41254 .79345 .40921 .78885 .40303 Metetra
.656 .751 .92 r
.78885 .40303 .79345 .40921 .80411 .40587 .79954 .39967 Metetra
.656 .751 .92 r
.79954 .39967 .80411 .40587 .8148 .40251 .81026 .39629 Metetra
.656 .751 .92 r
.81026 .39629 .8148 .40251 .82554 .39915 .82103 .3929 Metetra
.656 .751 .92 r
.82103 .3929 .82554 .39915 .83632 .39577 .83183 .3895 Metetra
.656 .751 .92 r
.83183 .3895 .83632 .39577 .84713 .39238 .84268 .38608 Metetra
.656 .751 .92 r
.84268 .38608 .84713 .39238 .85799 .38897 .85357 .38266 Metetra
.656 .751 .92 r
.85357 .38266 .85799 .38897 .86889 .38556 .86449 .37922 Metetra
.656 .751 .92 r
.86449 .37922 .86889 .38556 .87983 .38213 .87546 .37576 Metetra
.66 .751 .918 r
.25058 .56562 .25643 .57076 .26524 .56789 .2594 .56275 Metetra
.656 .751 .92 r
.2594 .56275 .26524 .56789 .27407 .56511 .26825 .55995 Metetra
.656 .751 .92 r
.26825 .55995 .27407 .56511 .28293 .56232 .27713 .55714 Metetra
.656 .751 .92 r
.27713 .55714 .28293 .56232 .29182 .55952 .28604 .55433 Metetra
.656 .751 .92 r
.28604 .55433 .29182 .55952 .30074 .55671 .29498 .5515 Metetra
.656 .751 .92 r
.29498 .5515 .30074 .55671 .30969 .55389 .30394 .54866 Metetra
.656 .751 .92 r
.30394 .54866 .30969 .55389 .31867 .55106 .31294 .54582 Metetra
.656 .751 .92 r
.31294 .54582 .31867 .55106 .32768 .54823 .32197 .54296 Metetra
.656 .751 .92 r
.32197 .54296 .32768 .54823 .33673 .54538 .33104 .5401 Metetra
.656 .751 .92 r
.33104 .5401 .33673 .54538 .3458 .54252 .34013 .53722 Metetra
.656 .751 .92 r
.34013 .53722 .3458 .54252 .3549 .53966 .34925 .53434 Metetra
.656 .751 .92 r
.34925 .53434 .3549 .53966 .36404 .53678 .35841 .53144 Metetra
.656 .751 .92 r
.35841 .53144 .36404 .53678 .37321 .53389 .36759 .52854 Metetra
.656 .751 .92 r
.36759 .52854 .37321 .53389 .3824 .531 .37681 .52563 Metetra
.656 .751 .92 r
.37681 .52563 .3824 .531 .39163 .52809 .38606 .5227 Metetra
.656 .751 .92 r
.38606 .5227 .39163 .52809 .4009 .52518 .39534 .51977 Metetra
.656 .751 .92 r
.39534 .51977 .4009 .52518 .41019 .52225 .40466 .51682 Metetra
.656 .751 .92 r
.40466 .51682 .41019 .52225 .41952 .51931 .414 .51387 Metetra
.656 .751 .92 r
.414 .51387 .41952 .51931 .42888 .51637 .42338 .5109 Metetra
.656 .751 .92 r
.42338 .5109 .42888 .51637 .43827 .51341 .43279 .50792 Metetra
.656 .751 .92 r
.43279 .50792 .43827 .51341 .44769 .51044 .44224 .50494 Metetra
.656 .751 .92 r
.44224 .50494 .44769 .51044 .45715 .50747 .45172 .50194 Metetra
.656 .751 .92 r
.45172 .50194 .45715 .50747 .46664 .50448 .46123 .49893 Metetra
.656 .751 .92 r
.46123 .49893 .46664 .50448 .47616 .50148 .47077 .49592 Metetra
.656 .751 .92 r
.47077 .49592 .47616 .50148 .48572 .49847 .48035 .49289 Metetra
.656 .751 .92 r
.48035 .49289 .48572 .49847 .49531 .49545 .48996 .48985 Metetra
.656 .751 .92 r
.48996 .48985 .49531 .49545 .50493 .49242 .49961 .4868 Metetra
.656 .751 .92 r
.49961 .4868 .50493 .49242 .51459 .48938 .50929 .48374 Metetra
.656 .751 .92 r
.50929 .48374 .51459 .48938 .52428 .48633 .519 .48067 Metetra
.656 .751 .92 r
.519 .48067 .52428 .48633 .53401 .48327 .52875 .47759 Metetra
.656 .751 .92 r
.52875 .47759 .53401 .48327 .54377 .48019 .53853 .47449 Metetra
.656 .751 .92 r
.53853 .47449 .54377 .48019 .55356 .47711 .54835 .47139 Metetra
.656 .751 .92 r
.54835 .47139 .55356 .47711 .56339 .47402 .5582 .46827 Metetra
.656 .751 .92 r
.5582 .46827 .56339 .47402 .57326 .47091 .56809 .46515 Metetra
.656 .751 .92 r
.56809 .46515 .57326 .47091 .58316 .46779 .57802 .46201 Metetra
.656 .751 .92 r
.57802 .46201 .58316 .46779 .59309 .46466 .58798 .45886 Metetra
.656 .751 .92 r
.58798 .45886 .59309 .46466 .60306 .46153 .59797 .4557 Metetra
.656 .751 .92 r
.59797 .4557 .60306 .46153 .61307 .45837 .608 .45253 Metetra
.656 .751 .92 r
.608 .45253 .61307 .45837 .62311 .45521 .61807 .44935 Metetra
.656 .751 .92 r
.61807 .44935 .62311 .45521 .63319 .45204 .62817 .44615 Metetra
.656 .751 .92 r
.62817 .44615 .63319 .45204 .64331 .44885 .63831 .44294 Metetra
.656 .751 .92 r
.63831 .44294 .64331 .44885 .65346 .44566 .64849 .43973 Metetra
.656 .751 .92 r
.64849 .43973 .65346 .44566 .66365 .44245 .6587 .4365 Metetra
.656 .751 .92 r
.6587 .4365 .66365 .44245 .67387 .43923 .66895 .43326 Metetra
.656 .751 .92 r
.66895 .43326 .67387 .43923 .68414 .436 .67924 .43 Metetra
.656 .751 .92 r
.67924 .43 .68414 .436 .69444 .43276 .68957 .42674 Metetra
.656 .751 .92 r
.68957 .42674 .69444 .43276 .70477 .4295 .69993 .42346 Metetra
.656 .751 .92 r
.69993 .42346 .70477 .4295 .71515 .42624 .71033 .42017 Metetra
.656 .751 .92 r
.71033 .42017 .71515 .42624 .72556 .42296 .72077 .41687 Metetra
.656 .751 .92 r
.72077 .41687 .72556 .42296 .73602 .41967 .73125 .41356 Metetra
.656 .751 .92 r
.73125 .41356 .73602 .41967 .74651 .41636 .74177 .41023 Metetra
.656 .751 .92 r
.74177 .41023 .74651 .41636 .75703 .41305 .75232 .4069 Metetra
.656 .751 .92 r
.75232 .4069 .75703 .41305 .7676 .40972 .76292 .40355 Metetra
.656 .751 .92 r
.76292 .40355 .7676 .40972 .77821 .40638 .77355 .40018 Metetra
.656 .751 .92 r
.77355 .40018 .77821 .40638 .78885 .40303 .78423 .39681 Metetra
.656 .751 .92 r
.78423 .39681 .78885 .40303 .79954 .39967 .79494 .39342 Metetra
.656 .751 .92 r
.79494 .39342 .79954 .39967 .81026 .39629 .80569 .39002 Metetra
.656 .751 .92 r
.80569 .39002 .81026 .39629 .82103 .3929 .81649 .38661 Metetra
.656 .751 .92 r
.81649 .38661 .82103 .3929 .83183 .3895 .82732 .38318 Metetra
.656 .751 .92 r
.82732 .38318 .83183 .3895 .84268 .38608 .8382 .37975 Metetra
.656 .751 .92 r
.8382 .37975 .84268 .38608 .85357 .38266 .84911 .37629 Metetra
.656 .751 .92 r
.84911 .37629 .85357 .38266 .86449 .37922 .86007 .37283 Metetra
.656 .751 .92 r
.86007 .37283 .86449 .37922 .87546 .37576 .87107 .36935 Metetra
.651 .742 .916 r
.2447 .56027 .25058 .56562 .2594 .56275 .25353 .55757 Metetra
.656 .751 .92 r
.25353 .55757 .2594 .56275 .26825 .55995 .26239 .55476 Metetra
.656 .751 .92 r
.26239 .55476 .26825 .55995 .27713 .55714 .27129 .55193 Metetra
.656 .751 .92 r
.27129 .55193 .27713 .55714 .28604 .55433 .28022 .5491 Metetra
.656 .751 .92 r
.28022 .5491 .28604 .55433 .29498 .5515 .28917 .54626 Metetra
.656 .751 .92 r
.28917 .54626 .29498 .5515 .30394 .54866 .29816 .5434 Metetra
.656 .751 .92 r
.29816 .5434 .30394 .54866 .31294 .54582 .30718 .54054 Metetra
.656 .751 .92 r
.30718 .54054 .31294 .54582 .32197 .54296 .31623 .53767 Metetra
.656 .751 .92 r
.31623 .53767 .32197 .54296 .33104 .5401 .32531 .53478 Metetra
.656 .751 .92 r
.32531 .53478 .33104 .5401 .34013 .53722 .33442 .53189 Metetra
.656 .751 .92 r
.33442 .53189 .34013 .53722 .34925 .53434 .34356 .52899 Metetra
.656 .751 .92 r
.34356 .52899 .34925 .53434 .35841 .53144 .35274 .52607 Metetra
.656 .751 .92 r
.35274 .52607 .35841 .53144 .36759 .52854 .36194 .52315 Metetra
.656 .751 .92 r
.36194 .52315 .36759 .52854 .37681 .52563 .37118 .52022 Metetra
.656 .751 .92 r
.37118 .52022 .37681 .52563 .38606 .5227 .38045 .51727 Metetra
.656 .751 .92 r
.38045 .51727 .38606 .5227 .39534 .51977 .38975 .51432 Metetra
.656 .751 .92 r
.38975 .51432 .39534 .51977 .40466 .51682 .39909 .51136 Metetra
.656 .751 .92 r
.39909 .51136 .40466 .51682 .414 .51387 .40845 .50838 Metetra
.656 .751 .92 r
.40845 .50838 .414 .51387 .42338 .5109 .41785 .5054 Metetra
.656 .751 .92 r
.41785 .5054 .42338 .5109 .43279 .50792 .42729 .5024 Metetra
.656 .751 .92 r
.42729 .5024 .43279 .50792 .44224 .50494 .43675 .4994 Metetra
.656 .751 .92 r
.43675 .4994 .44224 .50494 .45172 .50194 .44625 .49638 Metetra
.656 .751 .92 r
.44625 .49638 .45172 .50194 .46123 .49893 .45578 .49335 Metetra
.656 .751 .92 r
.45578 .49335 .46123 .49893 .47077 .49592 .46535 .49032 Metetra
.656 .751 .92 r
.46535 .49032 .47077 .49592 .48035 .49289 .47495 .48727 Metetra
.656 .751 .92 r
.47495 .48727 .48035 .49289 .48996 .48985 .48458 .48421 Metetra
.656 .751 .92 r
.48458 .48421 .48996 .48985 .49961 .4868 .49425 .48114 Metetra
.656 .751 .92 r
.49425 .48114 .49961 .4868 .50929 .48374 .50395 .47806 Metetra
.656 .751 .92 r
.50395 .47806 .50929 .48374 .519 .48067 .51369 .47497 Metetra
.656 .751 .92 r
.51369 .47497 .519 .48067 .52875 .47759 .52346 .47187 Metetra
.656 .751 .92 r
.52346 .47187 .52875 .47759 .53853 .47449 .53326 .46875 Metetra
.656 .751 .92 r
.53326 .46875 .53853 .47449 .54835 .47139 .54311 .46563 Metetra
.656 .751 .92 r
.54311 .46563 .54835 .47139 .5582 .46827 .55298 .46249 Metetra
.656 .751 .92 r
.55298 .46249 .5582 .46827 .56809 .46515 .56289 .45935 Metetra
.656 .751 .92 r
.56289 .45935 .56809 .46515 .57802 .46201 .57284 .45619 Metetra
.656 .751 .92 r
.57284 .45619 .57802 .46201 .58798 .45886 .58282 .45302 Metetra
.656 .751 .92 r
.58282 .45302 .58798 .45886 .59797 .4557 .59284 .44984 Metetra
.656 .751 .92 r
.59284 .44984 .59797 .4557 .608 .45253 .6029 .44664 Metetra
.656 .751 .92 r
.6029 .44664 .608 .45253 .61807 .44935 .61299 .44344 Metetra
.656 .751 .92 r
.61299 .44344 .61807 .44935 .62817 .44615 .62312 .44022 Metetra
.656 .751 .92 r
.62312 .44022 .62817 .44615 .63831 .44294 .63328 .437 Metetra
.656 .751 .92 r
.63328 .437 .63831 .44294 .64849 .43973 .64348 .43376 Metetra
.656 .751 .92 r
.64348 .43376 .64849 .43973 .6587 .4365 .65372 .4305 Metetra
.656 .751 .92 r
.65372 .4305 .6587 .4365 .66895 .43326 .664 .42724 Metetra
.656 .751 .92 r
.664 .42724 .66895 .43326 .67924 .43 .67431 .42397 Metetra
.656 .751 .92 r
.67431 .42397 .67924 .43 .68957 .42674 .68467 .42068 Metetra
.656 .751 .92 r
.68467 .42068 .68957 .42674 .69993 .42346 .69506 .41738 Metetra
.656 .751 .92 r
.69506 .41738 .69993 .42346 .71033 .42017 .70548 .41407 Metetra
.656 .751 .92 r
.70548 .41407 .71033 .42017 .72077 .41687 .71595 .41075 Metetra
.656 .751 .92 r
.71595 .41075 .72077 .41687 .73125 .41356 .72646 .40741 Metetra
.656 .751 .92 r
.72646 .40741 .73125 .41356 .74177 .41023 .737 .40406 Metetra
.656 .751 .92 r
.737 .40406 .74177 .41023 .75232 .4069 .74758 .4007 Metetra
.656 .751 .92 r
.74758 .4007 .75232 .4069 .76292 .40355 .75821 .39733 Metetra
.656 .751 .92 r
.75821 .39733 .76292 .40355 .77355 .40018 .76887 .39394 Metetra
.656 .751 .92 r
.76887 .39394 .77355 .40018 .78423 .39681 .77957 .39055 Metetra
.656 .751 .92 r
.77957 .39055 .78423 .39681 .79494 .39342 .79031 .38714 Metetra
.656 .751 .92 r
.79031 .38714 .79494 .39342 .80569 .39002 .80109 .38371 Metetra
.656 .751 .92 r
.80109 .38371 .80569 .39002 .81649 .38661 .81191 .38028 Metetra
.656 .751 .92 r
.81191 .38028 .81649 .38661 .82732 .38318 .82278 .37683 Metetra
.656 .751 .92 r
.82278 .37683 .82732 .38318 .8382 .37975 .83368 .37336 Metetra
.656 .751 .92 r
.83368 .37336 .8382 .37975 .84911 .37629 .84463 .36989 Metetra
.656 .751 .92 r
.84463 .36989 .84911 .37629 .86007 .37283 .85561 .3664 Metetra
.656 .751 .92 r
.85561 .3664 .86007 .37283 .87107 .36935 .86664 .3629 Metetra
.658 .758 .923 r
.23876 .55524 .2447 .56027 .25353 .55757 .24762 .55237 Metetra
.656 .751 .92 r
.24762 .55237 .25353 .55757 .26239 .55476 .2565 .54954 Metetra
.656 .751 .92 r
.2565 .54954 .26239 .55476 .27129 .55193 .26542 .54669 Metetra
.656 .751 .92 r
.26542 .54669 .27129 .55193 .28022 .5491 .27436 .54384 Metetra
.656 .751 .92 r
.27436 .54384 .28022 .5491 .28917 .54626 .28334 .54098 Metetra
.656 .751 .92 r
.28334 .54098 .28917 .54626 .29816 .5434 .29234 .53811 Metetra
.656 .751 .92 r
.29234 .53811 .29816 .5434 .30718 .54054 .30138 .53523 Metetra
.656 .751 .92 r
.30138 .53523 .30718 .54054 .31623 .53767 .31045 .53234 Metetra
.656 .751 .92 r
.31045 .53234 .31623 .53767 .32531 .53478 .31955 .52943 Metetra
.656 .751 .92 r
.31955 .52943 .32531 .53478 .33442 .53189 .32868 .52652 Metetra
.656 .751 .92 r
.32868 .52652 .33442 .53189 .34356 .52899 .33784 .5236 Metetra
.656 .751 .92 r
.33784 .5236 .34356 .52899 .35274 .52607 .34703 .52067 Metetra
.656 .751 .92 r
.34703 .52067 .35274 .52607 .36194 .52315 .35626 .51773 Metetra
.656 .751 .92 r
.35626 .51773 .36194 .52315 .37118 .52022 .36552 .51478 Metetra
.656 .751 .92 r
.36552 .51478 .37118 .52022 .38045 .51727 .3748 .51181 Metetra
.656 .751 .92 r
.3748 .51181 .38045 .51727 .38975 .51432 .38413 .50884 Metetra
.656 .751 .92 r
.38413 .50884 .38975 .51432 .39909 .51136 .39348 .50586 Metetra
.656 .751 .92 r
.39348 .50586 .39909 .51136 .40845 .50838 .40287 .50286 Metetra
.656 .751 .92 r
.40287 .50286 .40845 .50838 .41785 .5054 .41229 .49986 Metetra
.656 .751 .92 r
.41229 .49986 .41785 .5054 .42729 .5024 .42174 .49685 Metetra
.656 .751 .92 r
.42174 .49685 .42729 .5024 .43675 .4994 .43123 .49382 Metetra
.656 .751 .92 r
.43123 .49382 .43675 .4994 .44625 .49638 .44075 .49079 Metetra
.656 .751 .92 r
.44075 .49079 .44625 .49638 .45578 .49335 .4503 .48774 Metetra
.656 .751 .92 r
.4503 .48774 .45578 .49335 .46535 .49032 .45989 .48468 Metetra
.656 .751 .92 r
.45989 .48468 .46535 .49032 .47495 .48727 .46951 .48161 Metetra
.656 .751 .92 r
.46951 .48161 .47495 .48727 .48458 .48421 .47917 .47854 Metetra
.656 .751 .92 r
.47917 .47854 .48458 .48421 .49425 .48114 .48886 .47545 Metetra
.656 .751 .92 r
.48886 .47545 .49425 .48114 .50395 .47806 .49858 .47234 Metetra
.656 .751 .92 r
.49858 .47234 .50395 .47806 .51369 .47497 .50834 .46923 Metetra
.656 .751 .92 r
.50834 .46923 .51369 .47497 .52346 .47187 .51813 .46611 Metetra
.656 .751 .92 r
.51813 .46611 .52346 .47187 .53326 .46875 .52796 .46298 Metetra
.656 .751 .92 r
.52796 .46298 .53326 .46875 .54311 .46563 .53783 .45983 Metetra
.656 .751 .92 r
.53783 .45983 .54311 .46563 .55298 .46249 .54773 .45667 Metetra
.656 .751 .92 r
.54773 .45667 .55298 .46249 .56289 .45935 .55766 .45351 Metetra
.656 .751 .92 r
.55766 .45351 .56289 .45935 .57284 .45619 .56763 .45033 Metetra
.656 .751 .92 r
.56763 .45033 .57284 .45619 .58282 .45302 .57764 .44713 Metetra
.656 .751 .92 r
.57764 .44713 .58282 .45302 .59284 .44984 .58768 .44393 Metetra
.656 .751 .92 r
.58768 .44393 .59284 .44984 .6029 .44664 .59776 .44072 Metetra
.656 .751 .92 r
.59776 .44072 .6029 .44664 .61299 .44344 .60788 .43749 Metetra
.656 .751 .92 r
.60788 .43749 .61299 .44344 .62312 .44022 .61803 .43425 Metetra
.656 .751 .92 r
.61803 .43425 .62312 .44022 .63328 .437 .62822 .43101 Metetra
.656 .751 .92 r
.62822 .43101 .63328 .437 .64348 .43376 .63845 .42774 Metetra
.656 .751 .92 r
.63845 .42774 .64348 .43376 .65372 .4305 .64871 .42447 Metetra
.656 .751 .92 r
.64871 .42447 .65372 .4305 .664 .42724 .65901 .42119 Metetra
.656 .751 .92 r
.65901 .42119 .664 .42724 .67431 .42397 .66935 .41789 Metetra
.656 .751 .92 r
.66935 .41789 .67431 .42397 .68467 .42068 .67973 .41458 Metetra
.656 .751 .92 r
.67973 .41458 .68467 .42068 .69506 .41738 .69015 .41126 Metetra
.656 .751 .92 r
.69015 .41126 .69506 .41738 .70548 .41407 .7006 .40792 Metetra
.656 .751 .92 r
.7006 .40792 .70548 .41407 .71595 .41075 .7111 .40458 Metetra
.656 .751 .92 r
.7111 .40458 .71595 .41075 .72646 .40741 .72163 .40122 Metetra
.656 .751 .92 r
.72163 .40122 .72646 .40741 .737 .40406 .7322 .39785 Metetra
.656 .751 .92 r
.7322 .39785 .737 .40406 .74758 .4007 .74281 .39447 Metetra
.656 .751 .92 r
.74281 .39447 .74758 .4007 .75821 .39733 .75346 .39107 Metetra
.656 .751 .92 r
.75346 .39107 .75821 .39733 .76887 .39394 .76415 .38766 Metetra
.656 .751 .92 r
.76415 .38766 .76887 .39394 .77957 .39055 .77488 .38424 Metetra
.656 .751 .92 r
.77488 .38424 .77957 .39055 .79031 .38714 .78565 .38081 Metetra
.656 .751 .92 r
.78565 .38081 .79031 .38714 .80109 .38371 .79646 .37736 Metetra
.656 .751 .92 r
.79646 .37736 .80109 .38371 .81191 .38028 .80731 .3739 Metetra
.656 .751 .92 r
.80731 .3739 .81191 .38028 .82278 .37683 .8182 .37042 Metetra
.656 .751 .92 r
.8182 .37042 .82278 .37683 .83368 .37336 .82913 .36694 Metetra
.656 .751 .92 r
.82913 .36694 .83368 .37336 .84463 .36989 .84011 .36344 Metetra
.656 .751 .92 r
.84011 .36344 .84463 .36989 .85561 .3664 .85113 .35993 Metetra
.656 .751 .92 r
.85113 .35993 .85561 .3664 .86664 .3629 .86218 .3564 Metetra
.656 .749 .918 r
.2328 .54997 .23876 .55524 .24762 .55237 .24167 .54713 Metetra
.656 .751 .92 r
.24167 .54713 .24762 .55237 .2565 .54954 .25057 .54428 Metetra
.656 .751 .92 r
.25057 .54428 .2565 .54954 .26542 .54669 .25951 .54142 Metetra
.656 .751 .92 r
.25951 .54142 .26542 .54669 .27436 .54384 .26847 .53855 Metetra
.656 .751 .92 r
.26847 .53855 .27436 .54384 .28334 .54098 .27746 .53567 Metetra
.656 .751 .92 r
.27746 .53567 .28334 .54098 .29234 .53811 .28649 .53278 Metetra
.656 .751 .92 r
.28649 .53278 .29234 .53811 .30138 .53523 .29554 .52988 Metetra
.656 .751 .92 r
.29554 .52988 .30138 .53523 .31045 .53234 .30463 .52697 Metetra
.656 .751 .92 r
.30463 .52697 .31045 .53234 .31955 .52943 .31375 .52405 Metetra
.656 .751 .92 r
.31375 .52405 .31955 .52943 .32868 .52652 .3229 .52112 Metetra
.656 .751 .92 r
.3229 .52112 .32868 .52652 .33784 .5236 .33208 .51818 Metetra
.656 .751 .92 r
.33208 .51818 .33784 .5236 .34703 .52067 .34129 .51523 Metetra
.656 .751 .92 r
.34129 .51523 .34703 .52067 .35626 .51773 .35054 .51227 Metetra
.656 .751 .92 r
.35054 .51227 .35626 .51773 .36552 .51478 .35981 .5093 Metetra
.656 .751 .92 r
.35981 .5093 .36552 .51478 .3748 .51181 .36912 .50632 Metetra
.656 .751 .92 r
.36912 .50632 .3748 .51181 .38413 .50884 .37846 .50333 Metetra
.656 .751 .92 r
.37846 .50333 .38413 .50884 .39348 .50586 .38784 .50032 Metetra
.656 .751 .92 r
.38784 .50032 .39348 .50586 .40287 .50286 .39725 .49731 Metetra
.656 .751 .92 r
.39725 .49731 .40287 .50286 .41229 .49986 .40669 .49429 Metetra
.656 .751 .92 r
.40669 .49429 .41229 .49986 .42174 .49685 .41616 .49125 Metetra
.656 .751 .92 r
.41616 .49125 .42174 .49685 .43123 .49382 .42567 .48821 Metetra
.656 .751 .92 r
.42567 .48821 .43123 .49382 .44075 .49079 .43521 .48515 Metetra
.656 .751 .92 r
.43521 .48515 .44075 .49079 .4503 .48774 .44479 .48209 Metetra
.656 .751 .92 r
.44479 .48209 .4503 .48774 .45989 .48468 .4544 .47901 Metetra
.656 .751 .92 r
.4544 .47901 .45989 .48468 .46951 .48161 .46404 .47592 Metetra
.656 .751 .92 r
.46404 .47592 .46951 .48161 .47917 .47854 .47372 .47282 Metetra
.656 .751 .92 r
.47372 .47282 .47917 .47854 .48886 .47545 .48343 .46971 Metetra
.656 .751 .92 r
.48343 .46971 .48886 .47545 .49858 .47234 .49317 .46659 Metetra
.656 .751 .92 r
.49317 .46659 .49858 .47234 .50834 .46923 .50296 .46346 Metetra
.656 .751 .92 r
.50296 .46346 .50834 .46923 .51813 .46611 .51277 .46031 Metetra
.656 .751 .92 r
.51277 .46031 .51813 .46611 .52796 .46298 .52262 .45716 Metetra
.656 .751 .92 r
.52262 .45716 .52796 .46298 .53783 .45983 .53251 .45399 Metetra
.656 .751 .92 r
.53251 .45399 .53783 .45983 .54773 .45667 .54243 .45082 Metetra
.656 .751 .92 r
.54243 .45082 .54773 .45667 .55766 .45351 .55239 .44763 Metetra
.656 .751 .92 r
.55239 .44763 .55766 .45351 .56763 .45033 .56239 .44443 Metetra
.656 .751 .92 r
.56239 .44443 .56763 .45033 .57764 .44713 .57242 .44121 Metetra
.656 .751 .92 r
.57242 .44121 .57764 .44713 .58768 .44393 .58249 .43799 Metetra
.656 .751 .92 r
.58249 .43799 .58768 .44393 .59776 .44072 .59259 .43475 Metetra
.656 .751 .92 r
.59259 .43475 .59776 .44072 .60788 .43749 .60273 .43151 Metetra
.656 .751 .92 r
.60273 .43151 .60788 .43749 .61803 .43425 .61291 .42825 Metetra
.656 .751 .92 r
.61291 .42825 .61803 .43425 .62822 .43101 .62312 .42498 Metetra
.656 .751 .92 r
.62312 .42498 .62822 .43101 .63845 .42774 .63337 .42169 Metetra
.656 .751 .92 r
.63337 .42169 .63845 .42774 .64871 .42447 .64366 .4184 Metetra
.656 .751 .92 r
.64366 .4184 .64871 .42447 .65901 .42119 .65399 .41509 Metetra
.656 .751 .92 r
.65399 .41509 .65901 .42119 .66935 .41789 .66436 .41177 Metetra
.656 .751 .92 r
.66436 .41177 .66935 .41789 .67973 .41458 .67476 .40844 Metetra
.656 .751 .92 r
.67476 .40844 .67973 .41458 .69015 .41126 .6852 .40509 Metetra
.656 .751 .92 r
.6852 .40509 .69015 .41126 .7006 .40792 .69569 .40174 Metetra
.656 .751 .92 r
.69569 .40174 .7006 .40792 .7111 .40458 .70621 .39837 Metetra
.656 .751 .92 r
.70621 .39837 .7111 .40458 .72163 .40122 .71677 .39499 Metetra
.656 .751 .92 r
.71677 .39499 .72163 .40122 .7322 .39785 .72736 .39159 Metetra
.656 .751 .92 r
.72736 .39159 .7322 .39785 .74281 .39447 .738 .38819 Metetra
.656 .751 .92 r
.738 .38819 .74281 .39447 .75346 .39107 .74868 .38477 Metetra
.656 .751 .92 r
.74868 .38477 .75346 .39107 .76415 .38766 .7594 .38133 Metetra
.656 .751 .92 r
.7594 .38133 .76415 .38766 .77488 .38424 .77016 .37789 Metetra
.656 .751 .92 r
.77016 .37789 .77488 .38424 .78565 .38081 .78095 .37443 Metetra
.656 .751 .92 r
.78095 .37443 .78565 .38081 .79646 .37736 .79179 .37096 Metetra
.656 .751 .92 r
.79179 .37096 .79646 .37736 .80731 .3739 .80267 .36748 Metetra
.656 .751 .92 r
.80267 .36748 .80731 .3739 .8182 .37042 .81359 .36398 Metetra
.656 .751 .92 r
.81359 .36398 .8182 .37042 .82913 .36694 .82456 .36047 Metetra
.656 .751 .92 r
.82456 .36047 .82913 .36694 .84011 .36344 .83556 .35694 Metetra
.656 .751 .92 r
.83556 .35694 .84011 .36344 .85113 .35993 .84661 .35341 Metetra
.656 .751 .92 r
.84661 .35341 .85113 .35993 .86218 .3564 .85769 .34986 Metetra
.658 .753 .92 r
.2268 .54477 .2328 .54997 .24167 .54713 .23569 .54186 Metetra
.656 .751 .92 r
.23569 .54186 .24167 .54713 .25057 .54428 .24461 .53899 Metetra
.656 .751 .92 r
.24461 .53899 .25057 .54428 .25951 .54142 .25356 .53612 Metetra
.656 .751 .92 r
.25356 .53612 .25951 .54142 .26847 .53855 .26254 .53323 Metetra
.656 .751 .92 r
.26254 .53323 .26847 .53855 .27746 .53567 .27155 .53033 Metetra
.656 .751 .92 r
.27155 .53033 .27746 .53567 .28649 .53278 .28059 .52742 Metetra
.656 .751 .92 r
.28059 .52742 .28649 .53278 .29554 .52988 .28967 .5245 Metetra
.656 .751 .92 r
.28967 .5245 .29554 .52988 .30463 .52697 .29877 .52157 Metetra
.656 .751 .92 r
.29877 .52157 .30463 .52697 .31375 .52405 .30791 .51863 Metetra
.656 .751 .92 r
.30791 .51863 .31375 .52405 .3229 .52112 .31708 .51569 Metetra
.656 .751 .92 r
.31708 .51569 .3229 .52112 .33208 .51818 .32628 .51273 Metetra
.656 .751 .92 r
.32628 .51273 .33208 .51818 .34129 .51523 .33551 .50976 Metetra
.656 .751 .92 r
.33551 .50976 .34129 .51523 .35054 .51227 .34478 .50678 Metetra
.656 .751 .92 r
.34478 .50678 .35054 .51227 .35981 .5093 .35407 .50379 Metetra
.656 .751 .92 r
.35407 .50379 .35981 .5093 .36912 .50632 .3634 .50079 Metetra
.656 .751 .92 r
.3634 .50079 .36912 .50632 .37846 .50333 .37277 .49777 Metetra
.656 .751 .92 r
.37277 .49777 .37846 .50333 .38784 .50032 .38216 .49475 Metetra
.656 .751 .92 r
.38216 .49475 .38784 .50032 .39725 .49731 .39159 .49172 Metetra
.656 .751 .92 r
.39159 .49172 .39725 .49731 .40669 .49429 .40105 .48868 Metetra
.656 .751 .92 r
.40105 .48868 .40669 .49429 .41616 .49125 .41055 .48562 Metetra
.656 .751 .92 r
.41055 .48562 .41616 .49125 .42567 .48821 .42008 .48256 Metetra
.656 .751 .92 r
.42008 .48256 .42567 .48821 .43521 .48515 .42964 .47948 Metetra
.656 .751 .92 r
.42964 .47948 .43521 .48515 .44479 .48209 .43923 .4764 Metetra
.656 .751 .92 r
.43923 .4764 .44479 .48209 .4544 .47901 .44887 .4733 Metetra
.656 .751 .92 r
.44887 .4733 .4544 .47901 .46404 .47592 .45853 .47019 Metetra
.656 .751 .92 r
.45853 .47019 .46404 .47592 .47372 .47282 .46823 .46707 Metetra
.656 .751 .92 r
.46823 .46707 .47372 .47282 .48343 .46971 .47796 .46394 Metetra
.656 .751 .92 r
.47796 .46394 .48343 .46971 .49317 .46659 .48773 .4608 Metetra
.656 .751 .92 r
.48773 .4608 .49317 .46659 .50296 .46346 .49754 .45765 Metetra
.656 .751 .92 r
.49754 .45765 .50296 .46346 .51277 .46031 .50738 .45448 Metetra
.656 .751 .92 r
.50738 .45448 .51277 .46031 .52262 .45716 .51725 .45131 Metetra
.656 .751 .92 r
.51725 .45131 .52262 .45716 .53251 .45399 .52716 .44812 Metetra
.656 .751 .92 r
.52716 .44812 .53251 .45399 .54243 .45082 .53711 .44492 Metetra
.656 .751 .92 r
.53711 .44492 .54243 .45082 .55239 .44763 .54709 .44171 Metetra
.656 .751 .92 r
.54709 .44171 .55239 .44763 .56239 .44443 .55711 .43849 Metetra
.656 .751 .92 r
.55711 .43849 .56239 .44443 .57242 .44121 .56716 .43525 Metetra
.656 .751 .92 r
.56716 .43525 .57242 .44121 .58249 .43799 .57725 .43201 Metetra
.656 .751 .92 r
.57725 .43201 .58249 .43799 .59259 .43475 .58738 .42875 Metetra
.656 .751 .92 r
.58738 .42875 .59259 .43475 .60273 .43151 .59755 .42548 Metetra
.656 .751 .92 r
.59755 .42548 .60273 .43151 .61291 .42825 .60775 .4222 Metetra
.656 .751 .92 r
.60775 .4222 .61291 .42825 .62312 .42498 .61799 .4189 Metetra
.656 .751 .92 r
.61799 .4189 .62312 .42498 .63337 .42169 .62827 .4156 Metetra
.656 .751 .92 r
.62827 .4156 .63337 .42169 .64366 .4184 .63858 .41228 Metetra
.656 .751 .92 r
.63858 .41228 .64366 .4184 .65399 .41509 .64894 .40895 Metetra
.656 .751 .92 r
.64894 .40895 .65399 .41509 .66436 .41177 .65933 .40561 Metetra
.656 .751 .92 r
.65933 .40561 .66436 .41177 .67476 .40844 .66976 .40225 Metetra
.656 .751 .92 r
.66976 .40225 .67476 .40844 .6852 .40509 .68023 .39889 Metetra
.656 .751 .92 r
.68023 .39889 .6852 .40509 .69569 .40174 .69074 .39551 Metetra
.656 .751 .92 r
.69074 .39551 .69569 .40174 .70621 .39837 .70128 .39212 Metetra
.656 .751 .92 r
.70128 .39212 .70621 .39837 .71677 .39499 .71187 .38871 Metetra
.656 .751 .92 r
.71187 .38871 .71677 .39499 .72736 .39159 .7225 .38529 Metetra
.656 .751 .92 r
.7225 .38529 .72736 .39159 .738 .38819 .73316 .38186 Metetra
.656 .751 .92 r
.73316 .38186 .738 .38819 .74868 .38477 .74387 .37842 Metetra
.656 .751 .92 r
.74387 .37842 .74868 .38477 .7594 .38133 .75461 .37496 Metetra
.656 .751 .92 r
.75461 .37496 .7594 .38133 .77016 .37789 .7654 .37149 Metetra
.656 .751 .92 r
.7654 .37149 .77016 .37789 .78095 .37443 .77623 .36801 Metetra
.656 .751 .92 r
.77623 .36801 .78095 .37443 .79179 .37096 .78709 .36452 Metetra
.656 .751 .92 r
.78709 .36452 .79179 .37096 .80267 .36748 .798 .36101 Metetra
.656 .751 .92 r
.798 .36101 .80267 .36748 .81359 .36398 .80895 .35749 Metetra
.656 .751 .92 r
.80895 .35749 .81359 .36398 .82456 .36047 .81995 .35395 Metetra
.656 .751 .92 r
.81995 .35395 .82456 .36047 .83556 .35694 .83098 .3504 Metetra
.656 .751 .92 r
.83098 .3504 .83556 .35694 .84661 .35341 .84206 .34684 Metetra
.656 .751 .92 r
.84206 .34684 .84661 .35341 .85769 .34986 .85318 .34326 Metetra
.651 .744 .917 r
.22077 .53932 .2268 .54477 .23569 .54186 .22967 .53656 Metetra
.656 .751 .92 r
.22967 .53656 .23569 .54186 .24461 .53899 .2386 .53367 Metetra
.656 .751 .92 r
.2386 .53367 .24461 .53899 .25356 .53612 .24757 .53077 Metetra
.656 .751 .92 r
.24757 .53077 .25356 .53612 .26254 .53323 .25657 .52787 Metetra
.656 .751 .92 r
.25657 .52787 .26254 .53323 .27155 .53033 .2656 .52495 Metetra
.656 .751 .92 r
.2656 .52495 .27155 .53033 .28059 .52742 .27466 .52202 Metetra
.656 .751 .92 r
.27466 .52202 .28059 .52742 .28967 .5245 .28376 .51909 Metetra
.656 .751 .92 r
.28376 .51909 .28967 .5245 .29877 .52157 .29288 .51614 Metetra
.656 .751 .92 r
.29288 .51614 .29877 .52157 .30791 .51863 .30204 .51318 Metetra
.656 .751 .92 r
.30204 .51318 .30791 .51863 .31708 .51569 .31122 .51021 Metetra
.656 .751 .92 r
.31122 .51021 .31708 .51569 .32628 .51273 .32044 .50724 Metetra
.656 .751 .92 r
.32044 .50724 .32628 .51273 .33551 .50976 .3297 .50425 Metetra
.656 .751 .92 r
.3297 .50425 .33551 .50976 .34478 .50678 .33898 .50125 Metetra
.656 .751 .92 r
.33898 .50125 .34478 .50678 .35407 .50379 .3483 .49824 Metetra
.656 .751 .92 r
.3483 .49824 .35407 .50379 .3634 .50079 .35765 .49522 Metetra
.656 .751 .92 r
.35765 .49522 .3634 .50079 .37277 .49777 .36703 .49219 Metetra
.656 .751 .92 r
.36703 .49219 .37277 .49777 .38216 .49475 .37645 .48915 Metetra
.656 .751 .92 r
.37645 .48915 .38216 .49475 .39159 .49172 .3859 .48609 Metetra
.656 .751 .92 r
.3859 .48609 .39159 .49172 .40105 .48868 .39538 .48303 Metetra
.656 .751 .92 r
.39538 .48303 .40105 .48868 .41055 .48562 .40489 .47996 Metetra
.656 .751 .92 r
.40489 .47996 .41055 .48562 .42008 .48256 .41444 .47687 Metetra
.656 .751 .92 r
.41444 .47687 .42008 .48256 .42964 .47948 .42403 .47378 Metetra
.656 .751 .92 r
.42403 .47378 .42964 .47948 .43923 .4764 .43365 .47067 Metetra
.656 .751 .92 r
.43365 .47067 .43923 .4764 .44887 .4733 .4433 .46755 Metetra
.656 .751 .92 r
.4433 .46755 .44887 .4733 .45853 .47019 .45298 .46442 Metetra
.656 .751 .92 r
.45298 .46442 .45853 .47019 .46823 .46707 .46271 .46128 Metetra
.656 .751 .92 r
.46271 .46128 .46823 .46707 .47796 .46394 .47246 .45813 Metetra
.656 .751 .92 r
.47246 .45813 .47796 .46394 .48773 .4608 .48225 .45497 Metetra
.656 .751 .92 r
.48225 .45497 .48773 .4608 .49754 .45765 .49208 .45179 Metetra
.656 .751 .92 r
.49208 .45179 .49754 .45765 .50738 .45448 .50194 .44861 Metetra
.656 .751 .92 r
.50194 .44861 .50738 .45448 .51725 .45131 .51184 .44541 Metetra
.656 .751 .92 r
.51184 .44541 .51725 .45131 .52716 .44812 .52178 .4422 Metetra
.656 .751 .92 r
.52178 .4422 .52716 .44812 .53711 .44492 .53174 .43898 Metetra
.656 .751 .92 r
.53174 .43898 .53711 .44492 .54709 .44171 .54175 .43575 Metetra
.656 .751 .92 r
.54175 .43575 .54709 .44171 .55711 .43849 .55179 .43251 Metetra
.656 .751 .92 r
.55179 .43251 .55711 .43849 .56716 .43525 .56187 .42925 Metetra
.656 .751 .92 r
.56187 .42925 .56716 .43525 .57725 .43201 .57199 .42598 Metetra
.656 .751 .92 r
.57199 .42598 .57725 .43201 .58738 .42875 .58214 .4227 Metetra
.656 .751 .92 r
.58214 .4227 .58738 .42875 .59755 .42548 .59233 .41941 Metetra
.656 .751 .92 r
.59233 .41941 .59755 .42548 .60775 .4222 .60256 .41611 Metetra
.656 .751 .92 r
.60256 .41611 .60775 .4222 .61799 .4189 .61282 .41279 Metetra
.656 .751 .92 r
.61282 .41279 .61799 .4189 .62827 .4156 .62313 .40946 Metetra
.656 .751 .92 r
.62313 .40946 .62827 .4156 .63858 .41228 .63347 .40612 Metetra
.656 .751 .92 r
.63347 .40612 .63858 .41228 .64894 .40895 .64385 .40277 Metetra
.656 .751 .92 r
.64385 .40277 .64894 .40895 .65933 .40561 .65427 .39941 Metetra
.656 .751 .92 r
.65427 .39941 .65933 .40561 .66976 .40225 .66472 .39603 Metetra
.656 .751 .92 r
.66472 .39603 .66976 .40225 .68023 .39889 .67522 .39264 Metetra
.656 .751 .92 r
.67522 .39264 .68023 .39889 .69074 .39551 .68575 .38924 Metetra
.656 .751 .92 r
.68575 .38924 .69074 .39551 .70128 .39212 .69633 .38582 Metetra
.656 .751 .92 r
.69633 .38582 .70128 .39212 .71187 .38871 .70694 .38239 Metetra
.656 .751 .92 r
.70694 .38239 .71187 .38871 .7225 .38529 .71759 .37895 Metetra
.656 .751 .92 r
.71759 .37895 .7225 .38529 .73316 .38186 .72829 .3755 Metetra
.656 .751 .92 r
.72829 .3755 .73316 .38186 .74387 .37842 .73902 .37203 Metetra
.656 .751 .92 r
.73902 .37203 .74387 .37842 .75461 .37496 .7498 .36855 Metetra
.656 .751 .92 r
.7498 .36855 .75461 .37496 .7654 .37149 .76061 .36506 Metetra
.656 .751 .92 r
.76061 .36506 .7654 .37149 .77623 .36801 .77147 .36155 Metetra
.656 .751 .92 r
.77147 .36155 .77623 .36801 .78709 .36452 .78236 .35803 Metetra
.656 .751 .92 r
.78236 .35803 .78709 .36452 .798 .36101 .7933 .3545 Metetra
.656 .751 .92 r
.7933 .3545 .798 .36101 .80895 .35749 .80428 .35095 Metetra
.656 .751 .92 r
.80428 .35095 .80895 .35749 .81995 .35395 .8153 .34739 Metetra
.656 .751 .92 r
.8153 .34739 .81995 .35395 .83098 .3504 .82637 .34382 Metetra
.656 .751 .92 r
.82637 .34382 .83098 .3504 .84206 .34684 .83747 .34023 Metetra
.656 .751 .92 r
.83747 .34023 .84206 .34684 .85318 .34326 .84862 .33663 Metetra
.66 .76 .924 r
.21467 .5342 .22077 .53932 .22967 .53656 .22361 .53122 Metetra
.656 .751 .92 r
.22361 .53122 .22967 .53656 .2386 .53367 .23256 .52832 Metetra
.656 .751 .92 r
.23256 .52832 .2386 .53367 .24757 .53077 .24155 .5254 Metetra
.656 .751 .92 r
.24155 .5254 .24757 .53077 .25657 .52787 .25056 .52248 Metetra
.656 .751 .92 r
.25056 .52248 .25657 .52787 .2656 .52495 .25961 .51954 Metetra
.656 .751 .92 r
.25961 .51954 .2656 .52495 .27466 .52202 .26869 .51659 Metetra
.656 .751 .92 r
.26869 .51659 .27466 .52202 .28376 .51909 .2778 .51364 Metetra
.656 .751 .92 r
.2778 .51364 .28376 .51909 .29288 .51614 .28695 .51067 Metetra
.656 .751 .92 r
.28695 .51067 .29288 .51614 .30204 .51318 .29612 .50769 Metetra
.656 .751 .92 r
.29612 .50769 .30204 .51318 .31122 .51021 .30533 .50471 Metetra
.656 .751 .92 r
.30533 .50471 .31122 .51021 .32044 .50724 .31457 .50171 Metetra
.656 .751 .92 r
.31457 .50171 .32044 .50724 .3297 .50425 .32384 .4987 Metetra
.656 .751 .92 r
.32384 .4987 .3297 .50425 .33898 .50125 .33315 .49568 Metetra
.656 .751 .92 r
.33315 .49568 .33898 .50125 .3483 .49824 .34248 .49265 Metetra
.656 .751 .92 r
.34248 .49265 .3483 .49824 .35765 .49522 .35185 .48962 Metetra
.656 .751 .92 r
.35185 .48962 .35765 .49522 .36703 .49219 .36126 .48656 Metetra
.656 .751 .92 r
.36126 .48656 .36703 .49219 .37645 .48915 .37069 .4835 Metetra
.656 .751 .92 r
.37069 .4835 .37645 .48915 .3859 .48609 .38016 .48043 Metetra
.656 .751 .92 r
.38016 .48043 .3859 .48609 .39538 .48303 .38967 .47735 Metetra
.656 .751 .92 r
.38967 .47735 .39538 .48303 .40489 .47996 .3992 .47425 Metetra
.656 .751 .92 r
.3992 .47425 .40489 .47996 .41444 .47687 .40877 .47115 Metetra
.656 .751 .92 r
.40877 .47115 .41444 .47687 .42403 .47378 .41838 .46803 Metetra
.656 .751 .92 r
.41838 .46803 .42403 .47378 .43365 .47067 .42802 .46491 Metetra
.656 .751 .92 r
.42802 .46491 .43365 .47067 .4433 .46755 .43769 .46177 Metetra
.656 .751 .92 r
.43769 .46177 .4433 .46755 .45298 .46442 .4474 .45862 Metetra
.656 .751 .92 r
.4474 .45862 .45298 .46442 .46271 .46128 .45715 .45546 Metetra
.656 .751 .92 r
.45715 .45546 .46271 .46128 .47246 .45813 .46693 .45228 Metetra
.656 .751 .92 r
.46693 .45228 .47246 .45813 .48225 .45497 .47674 .4491 Metetra
.656 .751 .92 r
.47674 .4491 .48225 .45497 .49208 .45179 .48659 .4459 Metetra
.656 .751 .92 r
.48659 .4459 .49208 .45179 .50194 .44861 .49647 .4427 Metetra
.656 .751 .92 r
.49647 .4427 .50194 .44861 .51184 .44541 .5064 .43948 Metetra
.656 .751 .92 r
.5064 .43948 .51184 .44541 .52178 .4422 .51635 .43625 Metetra
.656 .751 .92 r
.51635 .43625 .52178 .4422 .53174 .43898 .52635 .43301 Metetra
.656 .751 .92 r
.52635 .43301 .53174 .43898 .54175 .43575 .53638 .42975 Metetra
.656 .751 .92 r
.53638 .42975 .54175 .43575 .55179 .43251 .54644 .42649 Metetra
.656 .751 .92 r
.54644 .42649 .55179 .43251 .56187 .42925 .55655 .42321 Metetra
.656 .751 .92 r
.55655 .42321 .56187 .42925 .57199 .42598 .56669 .41992 Metetra
.656 .751 .92 r
.56669 .41992 .57199 .42598 .58214 .4227 .57686 .41662 Metetra
.656 .751 .92 r
.57686 .41662 .58214 .4227 .59233 .41941 .58708 .4133 Metetra
.656 .751 .92 r
.58708 .4133 .59233 .41941 .60256 .41611 .59733 .40998 Metetra
.656 .751 .92 r
.59733 .40998 .60256 .41611 .61282 .41279 .60762 .40664 Metetra
.656 .751 .92 r
.60762 .40664 .61282 .41279 .62313 .40946 .61795 .40329 Metetra
.656 .751 .92 r
.61795 .40329 .62313 .40946 .63347 .40612 .62832 .39993 Metetra
.656 .751 .92 r
.62832 .39993 .63347 .40612 .64385 .40277 .63872 .39655 Metetra
.656 .751 .92 r
.63872 .39655 .64385 .40277 .65427 .39941 .64917 .39316 Metetra
.656 .751 .92 r
.64917 .39316 .65427 .39941 .66472 .39603 .65965 .38976 Metetra
.656 .751 .92 r
.65965 .38976 .66472 .39603 .67522 .39264 .67017 .38635 Metetra
.656 .751 .92 r
.67017 .38635 .67522 .39264 .68575 .38924 .68073 .38292 Metetra
.656 .751 .92 r
.68073 .38292 .68575 .38924 .69633 .38582 .69134 .37948 Metetra
.656 .751 .92 r
.69134 .37948 .69633 .38582 .70694 .38239 .70198 .37603 Metetra
.656 .751 .92 r
.70198 .37603 .70694 .38239 .71759 .37895 .71266 .37256 Metetra
.656 .751 .92 r
.71266 .37256 .71759 .37895 .72829 .3755 .72338 .36909 Metetra
.656 .751 .92 r
.72338 .36909 .72829 .3755 .73902 .37203 .73414 .36559 Metetra
.656 .751 .92 r
.73414 .36559 .73902 .37203 .7498 .36855 .74494 .36209 Metetra
.656 .751 .92 r
.74494 .36209 .7498 .36855 .76061 .36506 .75579 .35857 Metetra
.656 .751 .92 r
.75579 .35857 .76061 .36506 .77147 .36155 .76667 .35504 Metetra
.656 .751 .92 r
.76667 .35504 .77147 .36155 .78236 .35803 .7776 .3515 Metetra
.656 .751 .92 r
.7776 .3515 .78236 .35803 .7933 .3545 .78857 .34794 Metetra
.656 .751 .92 r
.78857 .34794 .7933 .3545 .80428 .35095 .79958 .34437 Metetra
.656 .751 .92 r
.79958 .34437 .80428 .35095 .8153 .34739 .81063 .34078 Metetra
.656 .751 .92 r
.81063 .34078 .8153 .34739 .82637 .34382 .82172 .33718 Metetra
.656 .751 .92 r
.82172 .33718 .82637 .34382 .83747 .34023 .83286 .33357 Metetra
.656 .751 .92 r
.83286 .33357 .83747 .34023 .84862 .33663 .84404 .32994 Metetra
.661 .753 .918 r
.20855 .52886 .21467 .5342 .22361 .53122 .21751 .52585 Metetra
.656 .751 .92 r
.21751 .52585 .22361 .53122 .23256 .52832 .22648 .52293 Metetra
.656 .751 .92 r
.22648 .52293 .23256 .52832 .24155 .5254 .23548 .51999 Metetra
.656 .751 .92 r
.23548 .51999 .24155 .5254 .25056 .52248 .24452 .51705 Metetra
.656 .751 .92 r
.24452 .51705 .25056 .52248 .25961 .51954 .25359 .51409 Metetra
.656 .751 .92 r
.25359 .51409 .25961 .51954 .26869 .51659 .26269 .51113 Metetra
.656 .751 .92 r
.26269 .51113 .26869 .51659 .2778 .51364 .27182 .50815 Metetra
.656 .751 .92 r
.27182 .50815 .2778 .51364 .28695 .51067 .28098 .50517 Metetra
.656 .751 .92 r
.28098 .50517 .28695 .51067 .29612 .50769 .29017 .50217 Metetra
.656 .751 .92 r
.29017 .50217 .29612 .50769 .30533 .50471 .2994 .49917 Metetra
.656 .751 .92 r
.2994 .49917 .30533 .50471 .31457 .50171 .30866 .49615 Metetra
.656 .751 .92 r
.30866 .49615 .31457 .50171 .32384 .4987 .31795 .49312 Metetra
.656 .751 .92 r
.31795 .49312 .32384 .4987 .33315 .49568 .32727 .49008 Metetra
.656 .751 .92 r
.32727 .49008 .33315 .49568 .34248 .49265 .33663 .48703 Metetra
.656 .751 .92 r
.33663 .48703 .34248 .49265 .35185 .48962 .34602 .48397 Metetra
.656 .751 .92 r
.34602 .48397 .35185 .48962 .36126 .48656 .35545 .4809 Metetra
.656 .751 .92 r
.35545 .4809 .36126 .48656 .37069 .4835 .3649 .47782 Metetra
.656 .751 .92 r
.3649 .47782 .37069 .4835 .38016 .48043 .37439 .47473 Metetra
.656 .751 .92 r
.37439 .47473 .38016 .48043 .38967 .47735 .38392 .47163 Metetra
.656 .751 .92 r
.38392 .47163 .38967 .47735 .3992 .47425 .39348 .46851 Metetra
.656 .751 .92 r
.39348 .46851 .3992 .47425 .40877 .47115 .40307 .46539 Metetra
.656 .751 .92 r
.40307 .46539 .40877 .47115 .41838 .46803 .4127 .46225 Metetra
.656 .751 .92 r
.4127 .46225 .41838 .46803 .42802 .46491 .42236 .4591 Metetra
.656 .751 .92 r
.42236 .4591 .42802 .46491 .43769 .46177 .43205 .45594 Metetra
.656 .751 .92 r
.43205 .45594 .43769 .46177 .4474 .45862 .44178 .45277 Metetra
.656 .751 .92 r
.44178 .45277 .4474 .45862 .45715 .45546 .45155 .44959 Metetra
.656 .751 .92 r
.45155 .44959 .45715 .45546 .46693 .45228 .46135 .4464 Metetra
.656 .751 .92 r
.46135 .4464 .46693 .45228 .47674 .4491 .47119 .44319 Metetra
.656 .751 .92 r
.47119 .44319 .47674 .4491 .48659 .4459 .48106 .43997 Metetra
.656 .751 .92 r
.48106 .43997 .48659 .4459 .49647 .4427 .49097 .43675 Metetra
.656 .751 .92 r
.49097 .43675 .49647 .4427 .5064 .43948 .50091 .43351 Metetra
.656 .751 .92 r
.50091 .43351 .5064 .43948 .51635 .43625 .51089 .43025 Metetra
.656 .751 .92 r
.51089 .43025 .51635 .43625 .52635 .43301 .52091 .42699 Metetra
.656 .751 .92 r
.52091 .42699 .52635 .43301 .53638 .42975 .53097 .42371 Metetra
.656 .751 .92 r
.53097 .42371 .53638 .42975 .54644 .42649 .54106 .42043 Metetra
.656 .751 .92 r
.54106 .42043 .54644 .42649 .55655 .42321 .55118 .41713 Metetra
.656 .751 .92 r
.55118 .41713 .55655 .42321 .56669 .41992 .56135 .41381 Metetra
.656 .751 .92 r
.56135 .41381 .56669 .41992 .57686 .41662 .57155 .41049 Metetra
.656 .751 .92 r
.57155 .41049 .57686 .41662 .58708 .4133 .58179 .40715 Metetra
.656 .751 .92 r
.58179 .40715 .58708 .4133 .59733 .40998 .59207 .4038 Metetra
.656 .751 .92 r
.59207 .4038 .59733 .40998 .60762 .40664 .60239 .40044 Metetra
.656 .751 .92 r
.60239 .40044 .60762 .40664 .61795 .40329 .61274 .39707 Metetra
.656 .751 .92 r
.61274 .39707 .61795 .40329 .62832 .39993 .62313 .39368 Metetra
.656 .751 .92 r
.62313 .39368 .62832 .39993 .63872 .39655 .63356 .39028 Metetra
.656 .751 .92 r
.63356 .39028 .63872 .39655 .64917 .39316 .64403 .38687 Metetra
.656 .751 .92 r
.64403 .38687 .64917 .39316 .65965 .38976 .65454 .38345 Metetra
.656 .751 .92 r
.65454 .38345 .65965 .38976 .67017 .38635 .66509 .38001 Metetra
.656 .751 .92 r
.66509 .38001 .67017 .38635 .68073 .38292 .67568 .37656 Metetra
.656 .751 .92 r
.67568 .37656 .68073 .38292 .69134 .37948 .68631 .3731 Metetra
.656 .751 .92 r
.68631 .3731 .69134 .37948 .70198 .37603 .69698 .36962 Metetra
.656 .751 .92 r
.69698 .36962 .70198 .37603 .71266 .37256 .70769 .36613 Metetra
.656 .751 .92 r
.70769 .36613 .71266 .37256 .72338 .36909 .71844 .36263 Metetra
.656 .751 .92 r
.71844 .36263 .72338 .36909 .73414 .36559 .72923 .35911 Metetra
.656 .751 .92 r
.72923 .35911 .73414 .36559 .74494 .36209 .74006 .35558 Metetra
.656 .751 .92 r
.74006 .35558 .74494 .36209 .75579 .35857 .75093 .35204 Metetra
.656 .751 .92 r
.75093 .35204 .75579 .35857 .76667 .35504 .76185 .34849 Metetra
.656 .751 .92 r
.76185 .34849 .76667 .35504 .7776 .3515 .7728 .34492 Metetra
.656 .751 .92 r
.7728 .34492 .7776 .3515 .78857 .34794 .7838 .34133 Metetra
.656 .751 .92 r
.7838 .34133 .78857 .34794 .79958 .34437 .79484 .33774 Metetra
.656 .751 .92 r
.79484 .33774 .79958 .34437 .81063 .34078 .80592 .33413 Metetra
.656 .751 .92 r
.80592 .33413 .81063 .34078 .82172 .33718 .81704 .3305 Metetra
.656 .751 .92 r
.81704 .3305 .82172 .33718 .83286 .33357 .82821 .32686 Metetra
.656 .751 .92 r
.82821 .32686 .83286 .33357 .84404 .32994 .83942 .32321 Metetra
.641 .731 .914 r
.20244 .52303 .20855 .52886 .21751 .52585 .21137 .52044 Metetra
.656 .751 .92 r
.21137 .52044 .21751 .52585 .22648 .52293 .22036 .5175 Metetra
.656 .751 .92 r
.22036 .5175 .22648 .52293 .23548 .51999 .22938 .51455 Metetra
.656 .751 .92 r
.22938 .51455 .23548 .51999 .24452 .51705 .23844 .51159 Metetra
.656 .751 .92 r
.23844 .51159 .24452 .51705 .25359 .51409 .24752 .50861 Metetra
.656 .751 .92 r
.24752 .50861 .25359 .51409 .26269 .51113 .25664 .50563 Metetra
.656 .751 .92 r
.25664 .50563 .26269 .51113 .27182 .50815 .26579 .50263 Metetra
.656 .751 .92 r
.26579 .50263 .27182 .50815 .28098 .50517 .27497 .49963 Metetra
.656 .751 .92 r
.27497 .49963 .28098 .50517 .29017 .50217 .28418 .49661 Metetra
.656 .751 .92 r
.28418 .49661 .29017 .50217 .2994 .49917 .29343 .49359 Metetra
.656 .751 .92 r
.29343 .49359 .2994 .49917 .30866 .49615 .30271 .49055 Metetra
.656 .751 .92 r
.30271 .49055 .30866 .49615 .31795 .49312 .31202 .4875 Metetra
.656 .751 .92 r
.31202 .4875 .31795 .49312 .32727 .49008 .32136 .48445 Metetra
.656 .751 .92 r
.32136 .48445 .32727 .49008 .33663 .48703 .33074 .48138 Metetra
.656 .751 .92 r
.33074 .48138 .33663 .48703 .34602 .48397 .34015 .4783 Metetra
.656 .751 .92 r
.34015 .4783 .34602 .48397 .35545 .4809 .3496 .47521 Metetra
.656 .751 .92 r
.3496 .47521 .35545 .4809 .3649 .47782 .35907 .47211 Metetra
.656 .751 .92 r
.35907 .47211 .3649 .47782 .37439 .47473 .36859 .46899 Metetra
.656 .751 .92 r
.36859 .46899 .37439 .47473 .38392 .47163 .37813 .46587 Metetra
.656 .751 .92 r
.37813 .46587 .38392 .47163 .39348 .46851 .38771 .46273 Metetra
.656 .751 .92 r
.38771 .46273 .39348 .46851 .40307 .46539 .39732 .45959 Metetra
.656 .751 .92 r
.39732 .45959 .40307 .46539 .4127 .46225 .40697 .45643 Metetra
.656 .751 .92 r
.40697 .45643 .4127 .46225 .42236 .4591 .41666 .45326 Metetra
.656 .751 .92 r
.41666 .45326 .42236 .4591 .43205 .45594 .42637 .45008 Metetra
.656 .751 .92 r
.42637 .45008 .43205 .45594 .44178 .45277 .43613 .44689 Metetra
.656 .751 .92 r
.43613 .44689 .44178 .45277 .45155 .44959 .44592 .44369 Metetra
.656 .751 .92 r
.44592 .44369 .45155 .44959 .46135 .4464 .45574 .44047 Metetra
.656 .751 .92 r
.45574 .44047 .46135 .4464 .47119 .44319 .4656 .43724 Metetra
.656 .751 .92 r
.4656 .43724 .47119 .44319 .48106 .43997 .4755 .43401 Metetra
.656 .751 .92 r
.4755 .43401 .48106 .43997 .49097 .43675 .48543 .43076 Metetra
.656 .751 .92 r
.48543 .43076 .49097 .43675 .50091 .43351 .49539 .42749 Metetra
.656 .751 .92 r
.49539 .42749 .50091 .43351 .51089 .43025 .5054 .42422 Metetra
.656 .751 .92 r
.5054 .42422 .51089 .43025 .52091 .42699 .51544 .42093 Metetra
.656 .751 .92 r
.51544 .42093 .52091 .42699 .53097 .42371 .52552 .41763 Metetra
.656 .751 .92 r
.52552 .41763 .53097 .42371 .54106 .42043 .53563 .41432 Metetra
.656 .751 .92 r
.53563 .41432 .54106 .42043 .55118 .41713 .54578 .411 Metetra
.656 .751 .92 r
.54578 .411 .55118 .41713 .56135 .41381 .55597 .40767 Metetra
.656 .751 .92 r
.55597 .40767 .56135 .41381 .57155 .41049 .5662 .40432 Metetra
.656 .751 .92 r
.5662 .40432 .57155 .41049 .58179 .40715 .57647 .40096 Metetra
.656 .751 .92 r
.57647 .40096 .58179 .40715 .59207 .4038 .58677 .39759 Metetra
.656 .751 .92 r
.58677 .39759 .59207 .4038 .60239 .40044 .59711 .3942 Metetra
.656 .751 .92 r
.59711 .3942 .60239 .40044 .61274 .39707 .60749 .39081 Metetra
.656 .751 .92 r
.60749 .39081 .61274 .39707 .62313 .39368 .61791 .3874 Metetra
.656 .751 .92 r
.61791 .3874 .62313 .39368 .63356 .39028 .62837 .38398 Metetra
.656 .751 .92 r
.62837 .38398 .63356 .39028 .64403 .38687 .63887 .38054 Metetra
.656 .751 .92 r
.63887 .38054 .64403 .38687 .65454 .38345 .6494 .37709 Metetra
.656 .751 .92 r
.6494 .37709 .65454 .38345 .66509 .38001 .65998 .37363 Metetra
.656 .751 .92 r
.65998 .37363 .66509 .38001 .67568 .37656 .67059 .37016 Metetra
.656 .751 .92 r
.67059 .37016 .67568 .37656 .68631 .3731 .68125 .36667 Metetra
.656 .751 .92 r
.68125 .36667 .68631 .3731 .69698 .36962 .69195 .36317 Metetra
.656 .751 .92 r
.69195 .36317 .69698 .36962 .70769 .36613 .70268 .35966 Metetra
.656 .751 .92 r
.70268 .35966 .70769 .36613 .71844 .36263 .71346 .35613 Metetra
.656 .751 .92 r
.71346 .35613 .71844 .36263 .72923 .35911 .72428 .35259 Metetra
.656 .751 .92 r
.72428 .35259 .72923 .35911 .74006 .35558 .73514 .34903 Metetra
.656 .751 .92 r
.73514 .34903 .74006 .35558 .75093 .35204 .74604 .34547 Metetra
.656 .751 .92 r
.74604 .34547 .75093 .35204 .76185 .34849 .75698 .34189 Metetra
.656 .751 .92 r
.75698 .34189 .76185 .34849 .7728 .34492 .76797 .33829 Metetra
.656 .751 .92 r
.76797 .33829 .7728 .34492 .7838 .34133 .779 .33468 Metetra
.656 .751 .92 r
.779 .33468 .7838 .34133 .79484 .33774 .79007 .33106 Metetra
.656 .751 .92 r
.79007 .33106 .79484 .33774 .80592 .33413 .80118 .32742 Metetra
.656 .751 .92 r
.80118 .32742 .80592 .33413 .81704 .3305 .81233 .32377 Metetra
.656 .751 .92 r
.81233 .32377 .81704 .3305 .82821 .32686 .82353 .32011 Metetra
.656 .751 .92 r
.82353 .32011 .82821 .32686 .83942 .32321 .83477 .31643 Metetra
.674 .784 .932 r
.19617 .51838 .20244 .52303 .21137 .52044 .20519 .515 Metetra
.656 .751 .92 r
.20519 .515 .21137 .52044 .22036 .5175 .2142 .51204 Metetra
.656 .751 .92 r
.2142 .51204 .22036 .5175 .22938 .51455 .22324 .50907 Metetra
.656 .751 .92 r
.22324 .50907 .22938 .51455 .23844 .51159 .23231 .50609 Metetra
.656 .751 .92 r
.23231 .50609 .23844 .51159 .24752 .50861 .24142 .5031 Metetra
.656 .751 .92 r
.24142 .5031 .24752 .50861 .25664 .50563 .25056 .50009 Metetra
.656 .751 .92 r
.25056 .50009 .25664 .50563 .26579 .50263 .25972 .49708 Metetra
.656 .751 .92 r
.25972 .49708 .26579 .50263 .27497 .49963 .26892 .49405 Metetra
.656 .751 .92 r
.26892 .49405 .27497 .49963 .28418 .49661 .27816 .49102 Metetra
.656 .751 .92 r
.27816 .49102 .28418 .49661 .29343 .49359 .28742 .48797 Metetra
.656 .751 .92 r
.28742 .48797 .29343 .49359 .30271 .49055 .29672 .48492 Metetra
.656 .751 .92 r
.29672 .48492 .30271 .49055 .31202 .4875 .30605 .48185 Metetra
.656 .751 .92 r
.30605 .48185 .31202 .4875 .32136 .48445 .31542 .47877 Metetra
.656 .751 .92 r
.31542 .47877 .32136 .48445 .33074 .48138 .32481 .47568 Metetra
.656 .751 .92 r
.32481 .47568 .33074 .48138 .34015 .4783 .33424 .47258 Metetra
.656 .751 .92 r
.33424 .47258 .34015 .4783 .3496 .47521 .34371 .46947 Metetra
.656 .751 .92 r
.34371 .46947 .3496 .47521 .35907 .47211 .35321 .46635 Metetra
.656 .751 .92 r
.35321 .46635 .35907 .47211 .36859 .46899 .36274 .46322 Metetra
.656 .751 .92 r
.36274 .46322 .36859 .46899 .37813 .46587 .37231 .46007 Metetra
.656 .751 .92 r
.37231 .46007 .37813 .46587 .38771 .46273 .38191 .45692 Metetra
.656 .751 .92 r
.38191 .45692 .38771 .46273 .39732 .45959 .39154 .45375 Metetra
.656 .751 .92 r
.39154 .45375 .39732 .45959 .40697 .45643 .40121 .45057 Metetra
.656 .751 .92 r
.40121 .45057 .40697 .45643 .41666 .45326 .41092 .44738 Metetra
.656 .751 .92 r
.41092 .44738 .41666 .45326 .42637 .45008 .42066 .44418 Metetra
.656 .751 .92 r
.42066 .44418 .42637 .45008 .43613 .44689 .43043 .44097 Metetra
.656 .751 .92 r
.43043 .44097 .43613 .44689 .44592 .44369 .44024 .43774 Metetra
.656 .751 .92 r
.44024 .43774 .44592 .44369 .45574 .44047 .45009 .4345 Metetra
.656 .751 .92 r
.45009 .4345 .45574 .44047 .4656 .43724 .45997 .43126 Metetra
.656 .751 .92 r
.45997 .43126 .4656 .43724 .4755 .43401 .46989 .428 Metetra
.656 .751 .92 r
.46989 .428 .4755 .43401 .48543 .43076 .47985 .42472 Metetra
.656 .751 .92 r
.47985 .42472 .48543 .43076 .49539 .42749 .48984 .42144 Metetra
.656 .751 .92 r
.48984 .42144 .49539 .42749 .5054 .42422 .49987 .41814 Metetra
.656 .751 .92 r
.49987 .41814 .5054 .42422 .51544 .42093 .50993 .41483 Metetra
.656 .751 .92 r
.50993 .41483 .51544 .42093 .52552 .41763 .52003 .41151 Metetra
.656 .751 .92 r
.52003 .41151 .52552 .41763 .53563 .41432 .53017 .40818 Metetra
.656 .751 .92 r
.53017 .40818 .53563 .41432 .54578 .411 .54035 .40484 Metetra
.656 .751 .92 r
.54035 .40484 .54578 .411 .55597 .40767 .55056 .40148 Metetra
.656 .751 .92 r
.55056 .40148 .55597 .40767 .5662 .40432 .56082 .39811 Metetra
.656 .751 .92 r
.56082 .39811 .5662 .40432 .57647 .40096 .57111 .39473 Metetra
.656 .751 .92 r
.57111 .39473 .57647 .40096 .58677 .39759 .58143 .39133 Metetra
.656 .751 .92 r
.58143 .39133 .58677 .39759 .59711 .3942 .5918 .38792 Metetra
.656 .751 .92 r
.5918 .38792 .59711 .3942 .60749 .39081 .60221 .3845 Metetra
.656 .751 .92 r
.60221 .3845 .60749 .39081 .61791 .3874 .61265 .38107 Metetra
.656 .751 .92 r
.61265 .38107 .61791 .3874 .62837 .38398 .62314 .37762 Metetra
.656 .751 .92 r
.62314 .37762 .62837 .38398 .63887 .38054 .63366 .37416 Metetra
.656 .751 .92 r
.63366 .37416 .63887 .38054 .6494 .37709 .64422 .37069 Metetra
.656 .751 .92 r
.64422 .37069 .6494 .37709 .65998 .37363 .65483 .36721 Metetra
.656 .751 .92 r
.65483 .36721 .65998 .37363 .67059 .37016 .66547 .36371 Metetra
.656 .751 .92 r
.66547 .36371 .67059 .37016 .68125 .36667 .67615 .3602 Metetra
.656 .751 .92 r
.67615 .3602 .68125 .36667 .69195 .36317 .68688 .35667 Metetra
.656 .751 .92 r
.68688 .35667 .69195 .36317 .70268 .35966 .69764 .35313 Metetra
.656 .751 .92 r
.69764 .35313 .70268 .35966 .71346 .35613 .70845 .34958 Metetra
.656 .751 .92 r
.70845 .34958 .71346 .35613 .72428 .35259 .7193 .34602 Metetra
.656 .751 .92 r
.7193 .34602 .72428 .35259 .73514 .34903 .73018 .34244 Metetra
.656 .751 .92 r
.73018 .34244 .73514 .34903 .74604 .34547 .74112 .33884 Metetra
.656 .751 .92 r
.74112 .33884 .74604 .34547 .75698 .34189 .75209 .33524 Metetra
.656 .751 .92 r
.75209 .33524 .75698 .34189 .76797 .33829 .7631 .33162 Metetra
.656 .751 .92 r
.7631 .33162 .76797 .33829 .779 .33468 .77416 .32798 Metetra
.656 .751 .92 r
.77416 .32798 .779 .33468 .79007 .33106 .78526 .32433 Metetra
.656 .751 .92 r
.78526 .32433 .79007 .33106 .80118 .32742 .7964 .32067 Metetra
.656 .751 .92 r
.7964 .32067 .80118 .32742 .81233 .32377 .80759 .31699 Metetra
.656 .751 .92 r
.80759 .31699 .81233 .32377 .82353 .32011 .81882 .3133 Metetra
.656 .751 .92 r
.81882 .3133 .82353 .32011 .83477 .31643 .83009 .3096 Metetra
.648 .727 .907 r
.19 .51232 .19617 .51838 .20519 .515 .19897 .50953 Metetra
.656 .751 .92 r
.19897 .50953 .20519 .515 .2142 .51204 .208 .50655 Metetra
.656 .751 .92 r
.208 .50655 .2142 .51204 .22324 .50907 .21706 .50356 Metetra
.656 .751 .92 r
.21706 .50356 .22324 .50907 .23231 .50609 .22615 .50055 Metetra
.656 .751 .92 r
.22615 .50055 .23231 .50609 .24142 .5031 .23528 .49754 Metetra
.656 .751 .92 r
.23528 .49754 .24142 .5031 .25056 .50009 .24443 .49452 Metetra
.656 .751 .92 r
.24443 .49452 .25056 .50009 .25972 .49708 .25362 .49149 Metetra
.656 .751 .92 r
.25362 .49149 .25972 .49708 .26892 .49405 .26284 .48844 Metetra
.656 .751 .92 r
.26284 .48844 .26892 .49405 .27816 .49102 .27209 .48539 Metetra
.656 .751 .92 r
.27209 .48539 .27816 .49102 .28742 .48797 .28137 .48232 Metetra
.656 .751 .92 r
.28137 .48232 .28742 .48797 .29672 .48492 .29069 .47925 Metetra
.656 .751 .92 r
.29069 .47925 .29672 .48492 .30605 .48185 .30004 .47616 Metetra
.656 .751 .92 r
.30004 .47616 .30605 .48185 .31542 .47877 .30943 .47306 Metetra
.656 .751 .92 r
.30943 .47306 .31542 .47877 .32481 .47568 .31885 .46995 Metetra
.656 .751 .92 r
.31885 .46995 .32481 .47568 .33424 .47258 .3283 .46683 Metetra
.656 .751 .92 r
.3283 .46683 .33424 .47258 .34371 .46947 .33778 .4637 Metetra
.656 .751 .92 r
.33778 .4637 .34371 .46947 .35321 .46635 .3473 .46056 Metetra
.656 .751 .92 r
.3473 .46056 .35321 .46635 .36274 .46322 .35686 .4574 Metetra
.656 .751 .92 r
.35686 .4574 .36274 .46322 .37231 .46007 .36644 .45424 Metetra
.656 .751 .92 r
.36644 .45424 .37231 .46007 .38191 .45692 .37607 .45106 Metetra
.656 .751 .92 r
.37607 .45106 .38191 .45692 .39154 .45375 .38572 .44787 Metetra
.656 .751 .92 r
.38572 .44787 .39154 .45375 .40121 .45057 .39541 .44467 Metetra
.656 .751 .92 r
.39541 .44467 .40121 .45057 .41092 .44738 .40514 .44146 Metetra
.656 .751 .92 r
.40514 .44146 .41092 .44738 .42066 .44418 .4149 .43824 Metetra
.656 .751 .92 r
.4149 .43824 .42066 .44418 .43043 .44097 .4247 .435 Metetra
.656 .751 .92 r
.4247 .435 .43043 .44097 .44024 .43774 .43453 .43176 Metetra
.656 .751 .92 r
.43453 .43176 .44024 .43774 .45009 .4345 .4444 .4285 Metetra
.656 .751 .92 r
.4444 .4285 .45009 .4345 .45997 .43126 .45431 .42523 Metetra
.656 .751 .92 r
.45431 .42523 .45997 .43126 .46989 .428 .46425 .42195 Metetra
.656 .751 .92 r
.46425 .42195 .46989 .428 .47985 .42472 .47423 .41865 Metetra
.656 .751 .92 r
.47423 .41865 .47985 .42472 .48984 .42144 .48424 .41534 Metetra
.656 .751 .92 r
.48424 .41534 .48984 .42144 .49987 .41814 .4943 .41203 Metetra
.656 .751 .92 r
.4943 .41203 .49987 .41814 .50993 .41483 .50438 .4087 Metetra
.656 .751 .92 r
.50438 .4087 .50993 .41483 .52003 .41151 .51451 .40535 Metetra
.656 .751 .92 r
.51451 .40535 .52003 .41151 .53017 .40818 .52467 .402 Metetra
.656 .751 .92 r
.52467 .402 .53017 .40818 .54035 .40484 .53488 .39863 Metetra
.656 .751 .92 r
.53488 .39863 .54035 .40484 .55056 .40148 .54512 .39525 Metetra
.656 .751 .92 r
.54512 .39525 .55056 .40148 .56082 .39811 .55539 .39185 Metetra
.656 .751 .92 r
.55539 .39185 .56082 .39811 .57111 .39473 .56571 .38845 Metetra
.656 .751 .92 r
.56571 .38845 .57111 .39473 .58143 .39133 .57606 .38503 Metetra
.656 .751 .92 r
.57606 .38503 .58143 .39133 .5918 .38792 .58646 .3816 Metetra
.656 .751 .92 r
.58646 .3816 .5918 .38792 .60221 .3845 .59689 .37815 Metetra
.656 .751 .92 r
.59689 .37815 .60221 .3845 .61265 .38107 .60736 .3747 Metetra
.656 .751 .92 r
.60736 .3747 .61265 .38107 .62314 .37762 .61787 .37123 Metetra
.656 .751 .92 r
.61787 .37123 .62314 .37762 .63366 .37416 .62842 .36774 Metetra
.656 .751 .92 r
.62842 .36774 .63366 .37416 .64422 .37069 .63901 .36425 Metetra
.656 .751 .92 r
.63901 .36425 .64422 .37069 .65483 .36721 .64964 .36074 Metetra
.656 .751 .92 r
.64964 .36074 .65483 .36721 .66547 .36371 .66031 .35722 Metetra
.656 .751 .92 r
.66031 .35722 .66547 .36371 .67615 .3602 .67102 .35368 Metetra
.656 .751 .92 r
.67102 .35368 .67615 .3602 .68688 .35667 .68177 .35013 Metetra
.656 .751 .92 r
.68177 .35013 .68688 .35667 .69764 .35313 .69257 .34657 Metetra
.656 .751 .92 r
.69257 .34657 .69764 .35313 .70845 .34958 .7034 .34299 Metetra
.656 .751 .92 r
.7034 .34299 .70845 .34958 .7193 .34602 .71428 .3394 Metetra
.656 .751 .92 r
.71428 .3394 .7193 .34602 .73018 .34244 .7252 .33579 Metetra
.656 .751 .92 r
.7252 .33579 .73018 .34244 .74112 .33884 .73615 .33217 Metetra
.656 .751 .92 r
.73615 .33217 .74112 .33884 .75209 .33524 .74716 .32854 Metetra
.656 .751 .92 r
.74716 .32854 .75209 .33524 .7631 .33162 .7582 .3249 Metetra
.656 .751 .92 r
.7582 .3249 .7631 .33162 .77416 .32798 .76929 .32124 Metetra
.656 .751 .92 r
.76929 .32124 .77416 .32798 .78526 .32433 .78042 .31756 Metetra
.656 .751 .92 r
.78042 .31756 .78526 .32433 .7964 .32067 .79159 .31387 Metetra
.656 .751 .92 r
.79159 .31387 .7964 .32067 .80759 .31699 .80281 .31017 Metetra
.656 .751 .92 r
.80281 .31017 .80759 .31699 .81882 .3133 .81407 .30645 Metetra
.656 .751 .92 r
.81407 .30645 .81882 .3133 .83009 .3096 .82537 .30272 Metetra
.641 .742 .922 r
.18374 .50668 .19 .51232 .19897 .50953 .19272 .50402 Metetra
.656 .751 .92 r
.19272 .50402 .19897 .50953 .208 .50655 .20176 .50102 Metetra
.656 .751 .92 r
.20176 .50102 .208 .50655 .21706 .50356 .21084 .49801 Metetra
.656 .751 .92 r
.21084 .49801 .21706 .50356 .22615 .50055 .21995 .49499 Metetra
.656 .751 .92 r
.21995 .49499 .22615 .50055 .23528 .49754 .22909 .49195 Metetra
.656 .751 .92 r
.22909 .49195 .23528 .49754 .24443 .49452 .23827 .48891 Metetra
.656 .751 .92 r
.23827 .48891 .24443 .49452 .25362 .49149 .24747 .48586 Metetra
.656 .751 .92 r
.24747 .48586 .25362 .49149 .26284 .48844 .25671 .4828 Metetra
.656 .751 .92 r
.25671 .4828 .26284 .48844 .27209 .48539 .26598 .47972 Metetra
.656 .751 .92 r
.26598 .47972 .27209 .48539 .28137 .48232 .27529 .47663 Metetra
.656 .751 .92 r
.27529 .47663 .28137 .48232 .29069 .47925 .28463 .47354 Metetra
.656 .751 .92 r
.28463 .47354 .29069 .47925 .30004 .47616 .294 .47043 Metetra
.656 .751 .92 r
.294 .47043 .30004 .47616 .30943 .47306 .3034 .46731 Metetra
.656 .751 .92 r
.3034 .46731 .30943 .47306 .31885 .46995 .31284 .46418 Metetra
.656 .751 .92 r
.31284 .46418 .31885 .46995 .3283 .46683 .32231 .46104 Metetra
.656 .751 .92 r
.32231 .46104 .3283 .46683 .33778 .4637 .33182 .45789 Metetra
.656 .751 .92 r
.33182 .45789 .33778 .4637 .3473 .46056 .34136 .45473 Metetra
.656 .751 .92 r
.34136 .45473 .3473 .46056 .35686 .4574 .35093 .45155 Metetra
.656 .751 .92 r
.35093 .45155 .35686 .4574 .36644 .45424 .36054 .44836 Metetra
.656 .751 .92 r
.36054 .44836 .36644 .45424 .37607 .45106 .37018 .44517 Metetra
.656 .751 .92 r
.37018 .44517 .37607 .45106 .38572 .44787 .37986 .44196 Metetra
.656 .751 .92 r
.37986 .44196 .38572 .44787 .39541 .44467 .38958 .43873 Metetra
.656 .751 .92 r
.38958 .43873 .39541 .44467 .40514 .44146 .39933 .4355 Metetra
.656 .751 .92 r
.39933 .4355 .40514 .44146 .4149 .43824 .40911 .43226 Metetra
.656 .751 .92 r
.40911 .43226 .4149 .43824 .4247 .435 .41893 .429 Metetra
.656 .751 .92 r
.41893 .429 .4247 .435 .43453 .43176 .42879 .42573 Metetra
.656 .751 .92 r
.42879 .42573 .43453 .43176 .4444 .4285 .43868 .42245 Metetra
.656 .751 .92 r
.43868 .42245 .4444 .4285 .45431 .42523 .44861 .41916 Metetra
.656 .751 .92 r
.44861 .41916 .45431 .42523 .46425 .42195 .45857 .41585 Metetra
.656 .751 .92 r
.45857 .41585 .46425 .42195 .47423 .41865 .46857 .41254 Metetra
.656 .751 .92 r
.46857 .41254 .47423 .41865 .48424 .41534 .47861 .40921 Metetra
.656 .751 .92 r
.47861 .40921 .48424 .41534 .4943 .41203 .48869 .40587 Metetra
.656 .751 .92 r
.48869 .40587 .4943 .41203 .50438 .4087 .4988 .40251 Metetra
.656 .751 .92 r
.4988 .40251 .50438 .4087 .51451 .40535 .50895 .39915 Metetra
.656 .751 .92 r
.50895 .39915 .51451 .40535 .52467 .402 .51914 .39577 Metetra
.656 .751 .92 r
.51914 .39577 .52467 .402 .53488 .39863 .52937 .39238 Metetra
.656 .751 .92 r
.52937 .39238 .53488 .39863 .54512 .39525 .53963 .38897 Metetra
.656 .751 .92 r
.53963 .38897 .54512 .39525 .55539 .39185 .54993 .38556 Metetra
.656 .751 .92 r
.54993 .38556 .55539 .39185 .56571 .38845 .56027 .38213 Metetra
.656 .751 .92 r
.56027 .38213 .56571 .38845 .57606 .38503 .57065 .37869 Metetra
.656 .751 .92 r
.57065 .37869 .57606 .38503 .58646 .3816 .58107 .37523 Metetra
.656 .751 .92 r
.58107 .37523 .58646 .3816 .59689 .37815 .59153 .37176 Metetra
.656 .751 .92 r
.59153 .37176 .59689 .37815 .60736 .3747 .60203 .36828 Metetra
.656 .751 .92 r
.60203 .36828 .60736 .3747 .61787 .37123 .61257 .36479 Metetra
.656 .751 .92 r
.61257 .36479 .61787 .37123 .62842 .36774 .62314 .36128 Metetra
.656 .751 .92 r
.62314 .36128 .62842 .36774 .63901 .36425 .63376 .35776 Metetra
.656 .751 .92 r
.63376 .35776 .63901 .36425 .64964 .36074 .64442 .35422 Metetra
.656 .751 .92 r
.64442 .35422 .64964 .36074 .66031 .35722 .65512 .35068 Metetra
.656 .751 .92 r
.65512 .35068 .66031 .35722 .67102 .35368 .66585 .34711 Metetra
.656 .751 .92 r
.66585 .34711 .67102 .35368 .68177 .35013 .67663 .34354 Metetra
.656 .751 .92 r
.67663 .34354 .68177 .35013 .69257 .34657 .68746 .33995 Metetra
.656 .751 .92 r
.68746 .33995 .69257 .34657 .7034 .34299 .69832 .33635 Metetra
.656 .751 .92 r
.69832 .33635 .7034 .34299 .71428 .3394 .70922 .33273 Metetra
.656 .751 .92 r
.70922 .33273 .71428 .3394 .7252 .33579 .72017 .3291 Metetra
.656 .751 .92 r
.72017 .3291 .7252 .33579 .73615 .33217 .73116 .32546 Metetra
.656 .751 .92 r
.73116 .32546 .73615 .33217 .74716 .32854 .74219 .3218 Metetra
.656 .751 .92 r
.74219 .3218 .74716 .32854 .7582 .3249 .75326 .31813 Metetra
.656 .751 .92 r
.75326 .31813 .7582 .3249 .76929 .32124 .76438 .31444 Metetra
.656 .751 .92 r
.76438 .31444 .76929 .32124 .78042 .31756 .77554 .31074 Metetra
.656 .751 .92 r
.77554 .31074 .78042 .31756 .79159 .31387 .78675 .30702 Metetra
.656 .751 .92 r
.78675 .30702 .79159 .31387 .80281 .31017 .79799 .30329 Metetra
.656 .751 .92 r
.79799 .30329 .80281 .31017 .81407 .30645 .80929 .29955 Metetra
.656 .751 .92 r
.80929 .29955 .81407 .30645 .82537 .30272 .82062 .29579 Metetra
.691 .8 .933 r
.1773 .50227 .18374 .50668 .19272 .50402 .18642 .49847 Metetra
.656 .751 .92 r
.18642 .49847 .19272 .50402 .20176 .50102 .19548 .49545 Metetra
.656 .751 .92 r
.19548 .49545 .20176 .50102 .21084 .49801 .20458 .49242 Metetra
.656 .751 .92 r
.20458 .49242 .21084 .49801 .21995 .49499 .21371 .48938 Metetra
.656 .751 .92 r
.21371 .48938 .21995 .49499 .22909 .49195 .22287 .48633 Metetra
.656 .751 .92 r
.22287 .48633 .22909 .49195 .23827 .48891 .23206 .48327 Metetra
.656 .751 .92 r
.23206 .48327 .23827 .48891 .24747 .48586 .24129 .48019 Metetra
.656 .751 .92 r
.24129 .48019 .24747 .48586 .25671 .4828 .25055 .47711 Metetra
.656 .751 .92 r
.25055 .47711 .25671 .4828 .26598 .47972 .25984 .47402 Metetra
.656 .751 .92 r
.25984 .47402 .26598 .47972 .27529 .47663 .26916 .47091 Metetra
.656 .751 .92 r
.26916 .47091 .27529 .47663 .28463 .47354 .27852 .46779 Metetra
.656 .751 .92 r
.27852 .46779 .28463 .47354 .294 .47043 .28791 .46466 Metetra
.656 .751 .92 r
.28791 .46466 .294 .47043 .3034 .46731 .29733 .46153 Metetra
.656 .751 .92 r
.29733 .46153 .3034 .46731 .31284 .46418 .30679 .45837 Metetra
.656 .751 .92 r
.30679 .45837 .31284 .46418 .32231 .46104 .31628 .45521 Metetra
.656 .751 .92 r
.31628 .45521 .32231 .46104 .33182 .45789 .32581 .45204 Metetra
.656 .751 .92 r
.32581 .45204 .33182 .45789 .34136 .45473 .33537 .44885 Metetra
.656 .751 .92 r
.33537 .44885 .34136 .45473 .35093 .45155 .34497 .44566 Metetra
.656 .751 .92 r
.34497 .44566 .35093 .45155 .36054 .44836 .3546 .44245 Metetra
.656 .751 .92 r
.3546 .44245 .36054 .44836 .37018 .44517 .36426 .43923 Metetra
.656 .751 .92 r
.36426 .43923 .37018 .44517 .37986 .44196 .37396 .436 Metetra
.656 .751 .92 r
.37396 .436 .37986 .44196 .38958 .43873 .3837 .43276 Metetra
.656 .751 .92 r
.3837 .43276 .38958 .43873 .39933 .4355 .39347 .4295 Metetra
.656 .751 .92 r
.39347 .4295 .39933 .4355 .40911 .43226 .40328 .42624 Metetra
.656 .751 .92 r
.40328 .42624 .40911 .43226 .41893 .429 .41312 .42296 Metetra
.656 .751 .92 r
.41312 .42296 .41893 .429 .42879 .42573 .423 .41967 Metetra
.656 .751 .92 r
.423 .41967 .42879 .42573 .43868 .42245 .43291 .41636 Metetra
.656 .751 .92 r
.43291 .41636 .43868 .42245 .44861 .41916 .44287 .41305 Metetra
.656 .751 .92 r
.44287 .41305 .44861 .41916 .45857 .41585 .45285 .40972 Metetra
.656 .751 .92 r
.45285 .40972 .45857 .41585 .46857 .41254 .46288 .40638 Metetra
.656 .751 .92 r
.46288 .40638 .46857 .41254 .47861 .40921 .47294 .40303 Metetra
.656 .751 .92 r
.47294 .40303 .47861 .40921 .48869 .40587 .48304 .39967 Metetra
.656 .751 .92 r
.48304 .39967 .48869 .40587 .4988 .40251 .49318 .39629 Metetra
.656 .751 .92 r
.49318 .39629 .4988 .40251 .50895 .39915 .50335 .3929 Metetra
.656 .751 .92 r
.50335 .3929 .50895 .39915 .51914 .39577 .51357 .3895 Metetra
.656 .751 .92 r
.51357 .3895 .51914 .39577 .52937 .39238 .52382 .38608 Metetra
.656 .751 .92 r
.52382 .38608 .52937 .39238 .53963 .38897 .53411 .38266 Metetra
.656 .751 .92 r
.53411 .38266 .53963 .38897 .54993 .38556 .54443 .37922 Metetra
.656 .751 .92 r
.54443 .37922 .54993 .38556 .56027 .38213 .5548 .37576 Metetra
.656 .751 .92 r
.5548 .37576 .56027 .38213 .57065 .37869 .56521 .3723 Metetra
.656 .751 .92 r
.56521 .3723 .57065 .37869 .58107 .37523 .57565 .36882 Metetra
.656 .751 .92 r
.57565 .36882 .58107 .37523 .59153 .37176 .58614 .36532 Metetra
.656 .751 .92 r
.58614 .36532 .59153 .37176 .60203 .36828 .59666 .36182 Metetra
.656 .751 .92 r
.59666 .36182 .60203 .36828 .61257 .36479 .60722 .3583 Metetra
.656 .751 .92 r
.60722 .3583 .61257 .36479 .62314 .36128 .61783 .35477 Metetra
.656 .751 .92 r
.61783 .35477 .62314 .36128 .63376 .35776 .62847 .35122 Metetra
.656 .751 .92 r
.62847 .35122 .63376 .35776 .64442 .35422 .63916 .34766 Metetra
.656 .751 .92 r
.63916 .34766 .64442 .35422 .65512 .35068 .64988 .34409 Metetra
.656 .751 .92 r
.64988 .34409 .65512 .35068 .66585 .34711 .66065 .3405 Metetra
.656 .751 .92 r
.66065 .3405 .66585 .34711 .67663 .34354 .67146 .3369 Metetra
.656 .751 .92 r
.67146 .3369 .67663 .34354 .68746 .33995 .68231 .33329 Metetra
.656 .751 .92 r
.68231 .33329 .68746 .33995 .69832 .33635 .6932 .32966 Metetra
.656 .751 .92 r
.6932 .32966 .69832 .33635 .70922 .33273 .70413 .32602 Metetra
.656 .751 .92 r
.70413 .32602 .70922 .33273 .72017 .3291 .71511 .32236 Metetra
.656 .751 .92 r
.71511 .32236 .72017 .3291 .73116 .32546 .72613 .31869 Metetra
.656 .751 .92 r
.72613 .31869 .73116 .32546 .74219 .3218 .73719 .31501 Metetra
.656 .751 .92 r
.73719 .31501 .74219 .3218 .75326 .31813 .74829 .31131 Metetra
.656 .751 .92 r
.74829 .31131 .75326 .31813 .76438 .31444 .75944 .3076 Metetra
.656 .751 .92 r
.75944 .3076 .76438 .31444 .77554 .31074 .77063 .30387 Metetra
.656 .751 .92 r
.77063 .30387 .77554 .31074 .78675 .30702 .78187 .30013 Metetra
.656 .751 .92 r
.78187 .30013 .78675 .30702 .79799 .30329 .79314 .29637 Metetra
.656 .751 .92 r
.79314 .29637 .79799 .30329 .80929 .29955 .80447 .2926 Metetra
.656 .751 .92 r
.80447 .2926 .80929 .29955 .82062 .29579 .81584 .28881 Metetra
.621 .687 .89 r
.17112 .4951 .1773 .50227 .18642 .49847 .18008 .49289 Metetra
.656 .751 .92 r
.18008 .49289 .18642 .49847 .19548 .49545 .18916 .48985 Metetra
.656 .751 .92 r
.18916 .48985 .19548 .49545 .20458 .49242 .19828 .4868 Metetra
.656 .751 .92 r
.19828 .4868 .20458 .49242 .21371 .48938 .20742 .48374 Metetra
.656 .751 .92 r
.20742 .48374 .21371 .48938 .22287 .48633 .2166 .48067 Metetra
.656 .751 .92 r
.2166 .48067 .22287 .48633 .23206 .48327 .22582 .47759 Metetra
.656 .751 .92 r
.22582 .47759 .23206 .48327 .24129 .48019 .23506 .47449 Metetra
.656 .751 .92 r
.23506 .47449 .24129 .48019 .25055 .47711 .24434 .47139 Metetra
.656 .751 .92 r
.24434 .47139 .25055 .47711 .25984 .47402 .25365 .46827 Metetra
.656 .751 .92 r
.25365 .46827 .25984 .47402 .26916 .47091 .26299 .46515 Metetra
.656 .751 .92 r
.26299 .46515 .26916 .47091 .27852 .46779 .27237 .46201 Metetra
.656 .751 .92 r
.27237 .46201 .27852 .46779 .28791 .46466 .28178 .45886 Metetra
.656 .751 .92 r
.28178 .45886 .28791 .46466 .29733 .46153 .29123 .4557 Metetra
.656 .751 .92 r
.29123 .4557 .29733 .46153 .30679 .45837 .30071 .45253 Metetra
.656 .751 .92 r
.30071 .45253 .30679 .45837 .31628 .45521 .31022 .44935 Metetra
.656 .751 .92 r
.31022 .44935 .31628 .45521 .32581 .45204 .31977 .44615 Metetra
.656 .751 .92 r
.31977 .44615 .32581 .45204 .33537 .44885 .32935 .44294 Metetra
.656 .751 .92 r
.32935 .44294 .33537 .44885 .34497 .44566 .33896 .43973 Metetra
.656 .751 .92 r
.33896 .43973 .34497 .44566 .3546 .44245 .34862 .4365 Metetra
.656 .751 .92 r
.34862 .4365 .3546 .44245 .36426 .43923 .3583 .43326 Metetra
.656 .751 .92 r
.3583 .43326 .36426 .43923 .37396 .436 .36803 .43 Metetra
.656 .751 .92 r
.36803 .43 .37396 .436 .3837 .43276 .37778 .42674 Metetra
.656 .751 .92 r
.37778 .42674 .3837 .43276 .39347 .4295 .38758 .42346 Metetra
.656 .751 .92 r
.38758 .42346 .39347 .4295 .40328 .42624 .39741 .42017 Metetra
.656 .751 .92 r
.39741 .42017 .40328 .42624 .41312 .42296 .40727 .41687 Metetra
.656 .751 .92 r
.40727 .41687 .41312 .42296 .423 .41967 .41717 .41356 Metetra
.656 .751 .92 r
.41717 .41356 .423 .41967 .43291 .41636 .42711 .41023 Metetra
.656 .751 .92 r
.42711 .41023 .43291 .41636 .44287 .41305 .43709 .4069 Metetra
.656 .751 .92 r
.43709 .4069 .44287 .41305 .45285 .40972 .4471 .40355 Metetra
.656 .751 .92 r
.4471 .40355 .45285 .40972 .46288 .40638 .45715 .40018 Metetra
.656 .751 .92 r
.45715 .40018 .46288 .40638 .47294 .40303 .46723 .39681 Metetra
.656 .751 .92 r
.46723 .39681 .47294 .40303 .48304 .39967 .47736 .39342 Metetra
.656 .751 .92 r
.47736 .39342 .48304 .39967 .49318 .39629 .48752 .39002 Metetra
.656 .751 .92 r
.48752 .39002 .49318 .39629 .50335 .3929 .49772 .38661 Metetra
.656 .751 .92 r
.49772 .38661 .50335 .3929 .51357 .3895 .50795 .38318 Metetra
.656 .751 .92 r
.50795 .38318 .51357 .3895 .52382 .38608 .51823 .37975 Metetra
.656 .751 .92 r
.51823 .37975 .52382 .38608 .53411 .38266 .52854 .37629 Metetra
.656 .751 .92 r
.52854 .37629 .53411 .38266 .54443 .37922 .5389 .37283 Metetra
.656 .751 .92 r
.5389 .37283 .54443 .37922 .5548 .37576 .54929 .36935 Metetra
.656 .751 .92 r
.54929 .36935 .5548 .37576 .56521 .3723 .55972 .36586 Metetra
.656 .751 .92 r
.55972 .36586 .56521 .3723 .57565 .36882 .57019 .36236 Metetra
.656 .751 .92 r
.57019 .36236 .57565 .36882 .58614 .36532 .5807 .35884 Metetra
.656 .751 .92 r
.5807 .35884 .58614 .36532 .59666 .36182 .59125 .35531 Metetra
.656 .751 .92 r
.59125 .35531 .59666 .36182 .60722 .3583 .60184 .35177 Metetra
.656 .751 .92 r
.60184 .35177 .60722 .3583 .61783 .35477 .61248 .34821 Metetra
.656 .751 .92 r
.61248 .34821 .61783 .35477 .62847 .35122 .62315 .34464 Metetra
.656 .751 .92 r
.62315 .34464 .62847 .35122 .63916 .34766 .63386 .34106 Metetra
.656 .751 .92 r
.63386 .34106 .63916 .34766 .64988 .34409 .64461 .33746 Metetra
.656 .751 .92 r
.64461 .33746 .64988 .34409 .66065 .3405 .65541 .33385 Metetra
.656 .751 .92 r
.65541 .33385 .66065 .3405 .67146 .3369 .66625 .33022 Metetra
.656 .751 .92 r
.66625 .33022 .67146 .3369 .68231 .33329 .67712 .32658 Metetra
.656 .751 .92 r
.67712 .32658 .68231 .33329 .6932 .32966 .68804 .32293 Metetra
.656 .751 .92 r
.68804 .32293 .6932 .32966 .70413 .32602 .69901 .31926 Metetra
.656 .751 .92 r
.69901 .31926 .70413 .32602 .71511 .32236 .71001 .31558 Metetra
.656 .751 .92 r
.71001 .31558 .71511 .32236 .72613 .31869 .72106 .31188 Metetra
.656 .751 .92 r
.72106 .31188 .72613 .31869 .73719 .31501 .73215 .30817 Metetra
.656 .751 .92 r
.73215 .30817 .73719 .31501 .74829 .31131 .74329 .30444 Metetra
.656 .751 .92 r
.74329 .30444 .74829 .31131 .75944 .3076 .75446 .3007 Metetra
.656 .751 .92 r
.75446 .3007 .75944 .3076 .77063 .30387 .76569 .29695 Metetra
.656 .751 .92 r
.76569 .29695 .77063 .30387 .78187 .30013 .77695 .29318 Metetra
.656 .751 .92 r
.77695 .29318 .78187 .30013 .79314 .29637 .78826 .2894 Metetra
.656 .751 .92 r
.78826 .2894 .79314 .29637 .80447 .2926 .79962 .2856 Metetra
.656 .751 .92 r
.79962 .2856 .80447 .2926 .81584 .28881 .81101 .28178 Metetra
.664 .791 .943 r
.16461 .49052 .17112 .4951 .18008 .49289 .1737 .48727 Metetra
.656 .751 .92 r
.1737 .48727 .18008 .49289 .18916 .48985 .1828 .48421 Metetra
.656 .751 .92 r
.1828 .48421 .18916 .48985 .19828 .4868 .19193 .48114 Metetra
.656 .751 .92 r
.19193 .48114 .19828 .4868 .20742 .48374 .2011 .47806 Metetra
.656 .751 .92 r
.2011 .47806 .20742 .48374 .2166 .48067 .2103 .47497 Metetra
.656 .751 .92 r
.2103 .47497 .2166 .48067 .22582 .47759 .21953 .47187 Metetra
.656 .751 .92 r
.21953 .47187 .22582 .47759 .23506 .47449 .22879 .46875 Metetra
.656 .751 .92 r
.22879 .46875 .23506 .47449 .24434 .47139 .23809 .46563 Metetra
.656 .751 .92 r
.23809 .46563 .24434 .47139 .25365 .46827 .24742 .46249 Metetra
.656 .751 .92 r
.24742 .46249 .25365 .46827 .26299 .46515 .25678 .45935 Metetra
.656 .751 .92 r
.25678 .45935 .26299 .46515 .27237 .46201 .26618 .45619 Metetra
.656 .751 .92 r
.26618 .45619 .27237 .46201 .28178 .45886 .27561 .45302 Metetra
.656 .751 .92 r
.27561 .45302 .28178 .45886 .29123 .4557 .28508 .44984 Metetra
.656 .751 .92 r
.28508 .44984 .29123 .4557 .30071 .45253 .29458 .44664 Metetra
.656 .751 .92 r
.29458 .44664 .30071 .45253 .31022 .44935 .30411 .44344 Metetra
.656 .751 .92 r
.30411 .44344 .31022 .44935 .31977 .44615 .31368 .44022 Metetra
.656 .751 .92 r
.31368 .44022 .31977 .44615 .32935 .44294 .32328 .437 Metetra
.656 .751 .92 r
.32328 .437 .32935 .44294 .33896 .43973 .33292 .43376 Metetra
.656 .751 .92 r
.33292 .43376 .33896 .43973 .34862 .4365 .34259 .4305 Metetra
.656 .751 .92 r
.34259 .4305 .34862 .4365 .3583 .43326 .3523 .42724 Metetra
.656 .751 .92 r
.3523 .42724 .3583 .43326 .36803 .43 .36205 .42397 Metetra
.656 .751 .92 r
.36205 .42397 .36803 .43 .37778 .42674 .37183 .42068 Metetra
.656 .751 .92 r
.37183 .42068 .37778 .42674 .38758 .42346 .38164 .41738 Metetra
.656 .751 .92 r
.38164 .41738 .38758 .42346 .39741 .42017 .39149 .41407 Metetra
.656 .751 .92 r
.39149 .41407 .39741 .42017 .40727 .41687 .40138 .41075 Metetra
.656 .751 .92 r
.40138 .41075 .40727 .41687 .41717 .41356 .41131 .40741 Metetra
.656 .751 .92 r
.41131 .40741 .41717 .41356 .42711 .41023 .42127 .40406 Metetra
.656 .751 .92 r
.42127 .40406 .42711 .41023 .43709 .4069 .43127 .4007 Metetra
.656 .751 .92 r
.43127 .4007 .43709 .4069 .4471 .40355 .4413 .39733 Metetra
.656 .751 .92 r
.4413 .39733 .4471 .40355 .45715 .40018 .45137 .39394 Metetra
.656 .751 .92 r
.45137 .39394 .45715 .40018 .46723 .39681 .46148 .39055 Metetra
.656 .751 .92 r
.46148 .39055 .46723 .39681 .47736 .39342 .47163 .38714 Metetra
.656 .751 .92 r
.47163 .38714 .47736 .39342 .48752 .39002 .48182 .38371 Metetra
.656 .751 .92 r
.48182 .38371 .48752 .39002 .49772 .38661 .49204 .38028 Metetra
.656 .751 .92 r
.49204 .38028 .49772 .38661 .50795 .38318 .5023 .37683 Metetra
.656 .751 .92 r
.5023 .37683 .50795 .38318 .51823 .37975 .5126 .37336 Metetra
.656 .751 .92 r
.5126 .37336 .51823 .37975 .52854 .37629 .52294 .36989 Metetra
.656 .751 .92 r
.52294 .36989 .52854 .37629 .5389 .37283 .53332 .3664 Metetra
.656 .751 .92 r
.53332 .3664 .5389 .37283 .54929 .36935 .54374 .3629 Metetra
.656 .751 .92 r
.54374 .3629 .54929 .36935 .55972 .36586 .5542 .35938 Metetra
.656 .751 .92 r
.5542 .35938 .55972 .36586 .57019 .36236 .5647 .35586 Metetra
.656 .751 .92 r
.5647 .35586 .57019 .36236 .5807 .35884 .57523 .35232 Metetra
.656 .751 .92 r
.57523 .35232 .5807 .35884 .59125 .35531 .58581 .34876 Metetra
.656 .751 .92 r
.58581 .34876 .59125 .35531 .60184 .35177 .59643 .34519 Metetra
.656 .751 .92 r
.59643 .34519 .60184 .35177 .61248 .34821 .60709 .34161 Metetra
.656 .751 .92 r
.60709 .34161 .61248 .34821 .62315 .34464 .61779 .33801 Metetra
.656 .751 .92 r
.61779 .33801 .62315 .34464 .63386 .34106 .62853 .3344 Metetra
.656 .751 .92 r
.62853 .3344 .63386 .34106 .64461 .33746 .63931 .33078 Metetra
.656 .751 .92 r
.63931 .33078 .64461 .33746 .65541 .33385 .65013 .32714 Metetra
.656 .751 .92 r
.65013 .32714 .65541 .33385 .66625 .33022 .661 .32349 Metetra
.656 .751 .92 r
.661 .32349 .66625 .33022 .67712 .32658 .6719 .31982 Metetra
.656 .751 .92 r
.6719 .31982 .67712 .32658 .68804 .32293 .68285 .31614 Metetra
.656 .751 .92 r
.68285 .31614 .68804 .32293 .69901 .31926 .69384 .31245 Metetra
.656 .751 .92 r
.69384 .31245 .69901 .31926 .71001 .31558 .70488 .30874 Metetra
.656 .751 .92 r
.70488 .30874 .71001 .31558 .72106 .31188 .71596 .30502 Metetra
.656 .751 .92 r
.71596 .30502 .72106 .31188 .73215 .30817 .72708 .30128 Metetra
.656 .751 .92 r
.72708 .30128 .73215 .30817 .74329 .30444 .73824 .29753 Metetra
.656 .751 .92 r
.73824 .29753 .74329 .30444 .75446 .3007 .74945 .29376 Metetra
.656 .751 .92 r
.74945 .29376 .75446 .3007 .76569 .29695 .7607 .28998 Metetra
.656 .751 .92 r
.7607 .28998 .76569 .29695 .77695 .29318 .772 .28618 Metetra
.656 .751 .92 r
.772 .28618 .77695 .29318 .78826 .2894 .78334 .28237 Metetra
.656 .751 .92 r
.78334 .28237 .78826 .2894 .79962 .2856 .79473 .27854 Metetra
.656 .751 .92 r
.79473 .27854 .79962 .2856 .81101 .28178 .80616 .2747 Metetra
.69 .779 .919 r
.1581 .48547 .16461 .49052 .1737 .48727 .16728 .48161 Metetra
.656 .751 .92 r
.16728 .48161 .1737 .48727 .1828 .48421 .1764 .47854 Metetra
.656 .751 .92 r
.1764 .47854 .1828 .48421 .19193 .48114 .18555 .47545 Metetra
.656 .751 .92 r
.18555 .47545 .19193 .48114 .2011 .47806 .19473 .47234 Metetra
.656 .751 .92 r
.19473 .47234 .2011 .47806 .2103 .47497 .20395 .46923 Metetra
.656 .751 .92 r
.20395 .46923 .2103 .47497 .21953 .47187 .2132 .46611 Metetra
.656 .751 .92 r
.2132 .46611 .21953 .47187 .22879 .46875 .22249 .46298 Metetra
.656 .751 .92 r
.22249 .46298 .22879 .46875 .23809 .46563 .2318 .45983 Metetra
.656 .751 .92 r
.2318 .45983 .23809 .46563 .24742 .46249 .24115 .45667 Metetra
.656 .751 .92 r
.24115 .45667 .24742 .46249 .25678 .45935 .25053 .45351 Metetra
.656 .751 .92 r
.25053 .45351 .25678 .45935 .26618 .45619 .25995 .45033 Metetra
.656 .751 .92 r
.25995 .45033 .26618 .45619 .27561 .45302 .2694 .44713 Metetra
.656 .751 .92 r
.2694 .44713 .27561 .45302 .28508 .44984 .27889 .44393 Metetra
.656 .751 .92 r
.27889 .44393 .28508 .44984 .29458 .44664 .28841 .44072 Metetra
.656 .751 .92 r
.28841 .44072 .29458 .44664 .30411 .44344 .29796 .43749 Metetra
.656 .751 .92 r
.29796 .43749 .30411 .44344 .31368 .44022 .30755 .43425 Metetra
.656 .751 .92 r
.30755 .43425 .31368 .44022 .32328 .437 .31718 .43101 Metetra
.656 .751 .92 r
.31718 .43101 .32328 .437 .33292 .43376 .32684 .42774 Metetra
.656 .751 .92 r
.32684 .42774 .33292 .43376 .34259 .4305 .33653 .42447 Metetra
.656 .751 .92 r
.33653 .42447 .34259 .4305 .3523 .42724 .34626 .42119 Metetra
.656 .751 .92 r
.34626 .42119 .3523 .42724 .36205 .42397 .35603 .41789 Metetra
.656 .751 .92 r
.35603 .41789 .36205 .42397 .37183 .42068 .36583 .41458 Metetra
.656 .751 .92 r
.36583 .41458 .37183 .42068 .38164 .41738 .37567 .41126 Metetra
.656 .751 .92 r
.37567 .41126 .38164 .41738 .39149 .41407 .38554 .40792 Metetra
.656 .751 .92 r
.38554 .40792 .39149 .41407 .40138 .41075 .39545 .40458 Metetra
.656 .751 .92 r
.39545 .40458 .40138 .41075 .41131 .40741 .4054 .40122 Metetra
.656 .751 .92 r
.4054 .40122 .41131 .40741 .42127 .40406 .41538 .39785 Metetra
.656 .751 .92 r
.41538 .39785 .42127 .40406 .43127 .4007 .42541 .39447 Metetra
.656 .751 .92 r
.42541 .39447 .43127 .4007 .4413 .39733 .43546 .39107 Metetra
.656 .751 .92 r
.43546 .39107 .4413 .39733 .45137 .39394 .44556 .38766 Metetra
.656 .751 .92 r
.44556 .38766 .45137 .39394 .46148 .39055 .45569 .38424 Metetra
.656 .751 .92 r
.45569 .38424 .46148 .39055 .47163 .38714 .46587 .38081 Metetra
.656 .751 .92 r
.46587 .38081 .47163 .38714 .48182 .38371 .47608 .37736 Metetra
.656 .751 .92 r
.47608 .37736 .48182 .38371 .49204 .38028 .48633 .3739 Metetra
.656 .751 .92 r
.48633 .3739 .49204 .38028 .5023 .37683 .49661 .37042 Metetra
.656 .751 .92 r
.49661 .37042 .5023 .37683 .5126 .37336 .50694 .36694 Metetra
.656 .751 .92 r
.50694 .36694 .5126 .37336 .52294 .36989 .5173 .36344 Metetra
.656 .751 .92 r
.5173 .36344 .52294 .36989 .53332 .3664 .52771 .35993 Metetra
.656 .751 .92 r
.52771 .35993 .53332 .3664 .54374 .3629 .53815 .3564 Metetra
.656 .751 .92 r
.53815 .3564 .54374 .3629 .5542 .35938 .54864 .35286 Metetra
.656 .751 .92 r
.54864 .35286 .5542 .35938 .5647 .35586 .55916 .34931 Metetra
.656 .751 .92 r
.55916 .34931 .5647 .35586 .57523 .35232 .56972 .34574 Metetra
.656 .751 .92 r
.56972 .34574 .57523 .35232 .58581 .34876 .58033 .34216 Metetra
.656 .751 .92 r
.58033 .34216 .58581 .34876 .59643 .34519 .59097 .33857 Metetra
.656 .751 .92 r
.59097 .33857 .59643 .34519 .60709 .34161 .60166 .33496 Metetra
.656 .751 .92 r
.60166 .33496 .60709 .34161 .61779 .33801 .61238 .33134 Metetra
.656 .751 .92 r
.61238 .33134 .61779 .33801 .62853 .3344 .62315 .3277 Metetra
.656 .751 .92 r
.62315 .3277 .62853 .3344 .63931 .33078 .63396 .32405 Metetra
.656 .751 .92 r
.63396 .32405 .63931 .33078 .65013 .32714 .64481 .32039 Metetra
.656 .751 .92 r
.64481 .32039 .65013 .32714 .661 .32349 .65571 .31671 Metetra
.656 .751 .92 r
.65571 .31671 .661 .32349 .6719 .31982 .66664 .31302 Metetra
.656 .751 .92 r
.66664 .31302 .6719 .31982 .68285 .31614 .67762 .30931 Metetra
.656 .751 .92 r
.67762 .30931 .68285 .31614 .69384 .31245 .68864 .30559 Metetra
.656 .751 .92 r
.68864 .30559 .69384 .31245 .70488 .30874 .69971 .30186 Metetra
.656 .751 .92 r
.69971 .30186 .70488 .30874 .71596 .30502 .71082 .29811 Metetra
.656 .751 .92 r
.71082 .29811 .71596 .30502 .72708 .30128 .72197 .29434 Metetra
.656 .751 .92 r
.72197 .29434 .72708 .30128 .73824 .29753 .73316 .29056 Metetra
.656 .751 .92 r
.73316 .29056 .73824 .29753 .74945 .29376 .7444 .28677 Metetra
.656 .751 .92 r
.7444 .28677 .74945 .29376 .7607 .28998 .75568 .28296 Metetra
.656 .751 .92 r
.75568 .28296 .7607 .28998 .772 .28618 .76701 .27913 Metetra
.656 .751 .92 r
.76701 .27913 .772 .28618 .78334 .28237 .77839 .27529 Metetra
.656 .751 .92 r
.77839 .27529 .78334 .28237 .79473 .27854 .7898 .27144 Metetra
.656 .751 .92 r
.7898 .27144 .79473 .27854 .80616 .2747 .80127 .26757 Metetra
.589 .654 .882 r
.15188 .47747 .1581 .48547 .16728 .48161 .16082 .47592 Metetra
.656 .751 .92 r
.16082 .47592 .16728 .48161 .1764 .47854 .16995 .47282 Metetra
.656 .751 .92 r
.16995 .47282 .1764 .47854 .18555 .47545 .17912 .46971 Metetra
.656 .751 .92 r
.17912 .46971 .18555 .47545 .19473 .47234 .18833 .46659 Metetra
.656 .751 .92 r
.18833 .46659 .19473 .47234 .20395 .46923 .19756 .46346 Metetra
.656 .751 .92 r
.19756 .46346 .20395 .46923 .2132 .46611 .20683 .46031 Metetra
.656 .751 .92 r
.20683 .46031 .2132 .46611 .22249 .46298 .21613 .45716 Metetra
.656 .751 .92 r
.21613 .45716 .22249 .46298 .2318 .45983 .22547 .45399 Metetra
.656 .751 .92 r
.22547 .45399 .2318 .45983 .24115 .45667 .23484 .45082 Metetra
.656 .751 .92 r
.23484 .45082 .24115 .45667 .25053 .45351 .24424 .44763 Metetra
.656 .751 .92 r
.24424 .44763 .25053 .45351 .25995 .45033 .25368 .44443 Metetra
.656 .751 .92 r
.25368 .44443 .25995 .45033 .2694 .44713 .26315 .44121 Metetra
.656 .751 .92 r
.26315 .44121 .2694 .44713 .27889 .44393 .27266 .43799 Metetra
.656 .751 .92 r
.27266 .43799 .27889 .44393 .28841 .44072 .2822 .43475 Metetra
.656 .751 .92 r
.2822 .43475 .28841 .44072 .29796 .43749 .29177 .43151 Metetra
.656 .751 .92 r
.29177 .43151 .29796 .43749 .30755 .43425 .30138 .42825 Metetra
.656 .751 .92 r
.30138 .42825 .30755 .43425 .31718 .43101 .31103 .42498 Metetra
.656 .751 .92 r
.31103 .42498 .31718 .43101 .32684 .42774 .32071 .42169 Metetra
.656 .751 .92 r
.32071 .42169 .32684 .42774 .33653 .42447 .33043 .4184 Metetra
.656 .751 .92 r
.33043 .4184 .33653 .42447 .34626 .42119 .34018 .41509 Metetra
.656 .751 .92 r
.34018 .41509 .34626 .42119 .35603 .41789 .34997 .41177 Metetra
.656 .751 .92 r
.34997 .41177 .35603 .41789 .36583 .41458 .35979 .40844 Metetra
.656 .751 .92 r
.35979 .40844 .36583 .41458 .37567 .41126 .36965 .40509 Metetra
.656 .751 .92 r
.36965 .40509 .37567 .41126 .38554 .40792 .37955 .40174 Metetra
.656 .751 .92 r
.37955 .40174 .38554 .40792 .39545 .40458 .38948 .39837 Metetra
.656 .751 .92 r
.38948 .39837 .39545 .40458 .4054 .40122 .39945 .39499 Metetra
.656 .751 .92 r
.39945 .39499 .4054 .40122 .41538 .39785 .40946 .39159 Metetra
.656 .751 .92 r
.40946 .39159 .41538 .39785 .42541 .39447 .41951 .38819 Metetra
.656 .751 .92 r
.41951 .38819 .42541 .39447 .43546 .39107 .42959 .38477 Metetra
.656 .751 .92 r
.42959 .38477 .43546 .39107 .44556 .38766 .43971 .38133 Metetra
.656 .751 .92 r
.43971 .38133 .44556 .38766 .45569 .38424 .44987 .37789 Metetra
.656 .751 .92 r
.44987 .37789 .45569 .38424 .46587 .38081 .46006 .37443 Metetra
.656 .751 .92 r
.46006 .37443 .46587 .38081 .47608 .37736 .4703 .37096 Metetra
.656 .751 .92 r
.4703 .37096 .47608 .37736 .48633 .3739 .48057 .36748 Metetra
.656 .751 .92 r
.48057 .36748 .48633 .3739 .49661 .37042 .49088 .36398 Metetra
.656 .751 .92 r
.49088 .36398 .49661 .37042 .50694 .36694 .50123 .36047 Metetra
.656 .751 .92 r
.50123 .36047 .50694 .36694 .5173 .36344 .51163 .35694 Metetra
.656 .751 .92 r
.51163 .35694 .5173 .36344 .52771 .35993 .52206 .35341 Metetra
.656 .751 .92 r
.52206 .35341 .52771 .35993 .53815 .3564 .53253 .34986 Metetra
.656 .751 .92 r
.53253 .34986 .53815 .3564 .54864 .35286 .54303 .34629 Metetra
.656 .751 .92 r
.54303 .34629 .54864 .35286 .55916 .34931 .55358 .34271 Metetra
.656 .751 .92 r
.55358 .34271 .55916 .34931 .56972 .34574 .56418 .33912 Metetra
.656 .751 .92 r
.56418 .33912 .56972 .34574 .58033 .34216 .57481 .33552 Metetra
.656 .751 .92 r
.57481 .33552 .58033 .34216 .59097 .33857 .58548 .3319 Metetra
.656 .751 .92 r
.58548 .3319 .59097 .33857 .60166 .33496 .59619 .32826 Metetra
.656 .751 .92 r
.59619 .32826 .60166 .33496 .61238 .33134 .60695 .32462 Metetra
.656 .751 .92 r
.60695 .32462 .61238 .33134 .62315 .3277 .61774 .32095 Metetra
.656 .751 .92 r
.61774 .32095 .62315 .3277 .63396 .32405 .62858 .31728 Metetra
.656 .751 .92 r
.62858 .31728 .63396 .32405 .64481 .32039 .63946 .31359 Metetra
.656 .751 .92 r
.63946 .31359 .64481 .32039 .65571 .31671 .65038 .30988 Metetra
.656 .751 .92 r
.65038 .30988 .65571 .31671 .66664 .31302 .66135 .30617 Metetra
.656 .751 .92 r
.66135 .30617 .66664 .31302 .67762 .30931 .67235 .30243 Metetra
.656 .751 .92 r
.67235 .30243 .67762 .30931 .68864 .30559 .68341 .29868 Metetra
.656 .751 .92 r
.68341 .29868 .68864 .30559 .69971 .30186 .6945 .29492 Metetra
.656 .751 .92 r
.6945 .29492 .69971 .30186 .71082 .29811 .70564 .29114 Metetra
.656 .751 .92 r
.70564 .29114 .71082 .29811 .72197 .29434 .71682 .28735 Metetra
.656 .751 .92 r
.71682 .28735 .72197 .29434 .73316 .29056 .72804 .28354 Metetra
.656 .751 .92 r
.72804 .28354 .73316 .29056 .7444 .28677 .73931 .27972 Metetra
.656 .751 .92 r
.73931 .27972 .7444 .28677 .75568 .28296 .75063 .27588 Metetra
.656 .751 .92 r
.75063 .27588 .75568 .28296 .76701 .27913 .76199 .27203 Metetra
.656 .751 .92 r
.76199 .27203 .76701 .27913 .77839 .27529 .77339 .26816 Metetra
.656 .751 .92 r
.77339 .26816 .77839 .27529 .7898 .27144 .78484 .26428 Metetra
.656 .751 .92 r
.78484 .26428 .7898 .27144 .80127 .26757 .79634 .26038 Metetra
.712 .872 .957 r
.14502 .47469 .15188 .47747 .16082 .47592 .15431 .47019 Metetra
.656 .751 .92 r
.15431 .47019 .16082 .47592 .16995 .47282 .16347 .46707 Metetra
.656 .751 .92 r
.16347 .46707 .16995 .47282 .17912 .46971 .17265 .46394 Metetra
.656 .751 .92 r
.17265 .46394 .17912 .46971 .18833 .46659 .18188 .4608 Metetra
.656 .751 .92 r
.18188 .4608 .18833 .46659 .19756 .46346 .19113 .45765 Metetra
.656 .751 .92 r
.19113 .45765 .19756 .46346 .20683 .46031 .20042 .45448 Metetra
.656 .751 .92 r
.20042 .45448 .20683 .46031 .21613 .45716 .20974 .45131 Metetra
.656 .751 .92 r
.20974 .45131 .21613 .45716 .22547 .45399 .2191 .44812 Metetra
.656 .751 .92 r
.2191 .44812 .22547 .45399 .23484 .45082 .22849 .44492 Metetra
.656 .751 .92 r
.22849 .44492 .23484 .45082 .24424 .44763 .23791 .44171 Metetra
.656 .751 .92 r
.23791 .44171 .24424 .44763 .25368 .44443 .24737 .43849 Metetra
.656 .751 .92 r
.24737 .43849 .25368 .44443 .26315 .44121 .25686 .43525 Metetra
.656 .751 .92 r
.25686 .43525 .26315 .44121 .27266 .43799 .26639 .43201 Metetra
.656 .751 .92 r
.26639 .43201 .27266 .43799 .2822 .43475 .27595 .42875 Metetra
.656 .751 .92 r
.27595 .42875 .2822 .43475 .29177 .43151 .28554 .42548 Metetra
.656 .751 .92 r
.28554 .42548 .29177 .43151 .30138 .42825 .29518 .4222 Metetra
.656 .751 .92 r
.29518 .4222 .30138 .42825 .31103 .42498 .30484 .4189 Metetra
.656 .751 .92 r
.30484 .4189 .31103 .42498 .32071 .42169 .31454 .4156 Metetra
.656 .751 .92 r
.31454 .4156 .32071 .42169 .33043 .4184 .32428 .41228 Metetra
.656 .751 .92 r
.32428 .41228 .33043 .4184 .34018 .41509 .33406 .40895 Metetra
.656 .751 .92 r
.33406 .40895 .34018 .41509 .34997 .41177 .34387 .40561 Metetra
.656 .751 .92 r
.34387 .40561 .34997 .41177 .35979 .40844 .35371 .40225 Metetra
.656 .751 .92 r
.35371 .40225 .35979 .40844 .36965 .40509 .36359 .39889 Metetra
.656 .751 .92 r
.36359 .39889 .36965 .40509 .37955 .40174 .37351 .39551 Metetra
.656 .751 .92 r
.37351 .39551 .37955 .40174 .38948 .39837 .38347 .39212 Metetra
.656 .751 .92 r
.38347 .39212 .38948 .39837 .39945 .39499 .39346 .38871 Metetra
.656 .751 .92 r
.39346 .38871 .39945 .39499 .40946 .39159 .4035 .38529 Metetra
.656 .751 .92 r
.4035 .38529 .40946 .39159 .41951 .38819 .41356 .38186 Metetra
.656 .751 .92 r
.41356 .38186 .41951 .38819 .42959 .38477 .42367 .37842 Metetra
.656 .751 .92 r
.42367 .37842 .42959 .38477 .43971 .38133 .43381 .37496 Metetra
.656 .751 .92 r
.43381 .37496 .43971 .38133 .44987 .37789 .444 .37149 Metetra
.656 .751 .92 r
.444 .37149 .44987 .37789 .46006 .37443 .45422 .36801 Metetra
.656 .751 .92 r
.45422 .36801 .46006 .37443 .4703 .37096 .46448 .36452 Metetra
.656 .751 .92 r
.46448 .36452 .4703 .37096 .48057 .36748 .47478 .36101 Metetra
.656 .751 .92 r
.47478 .36101 .48057 .36748 .49088 .36398 .48511 .35749 Metetra
.656 .751 .92 r
.48511 .35749 .49088 .36398 .50123 .36047 .49549 .35395 Metetra
.656 .751 .92 r
.49549 .35395 .50123 .36047 .51163 .35694 .50591 .3504 Metetra
.656 .751 .92 r
.50591 .3504 .51163 .35694 .52206 .35341 .51636 .34684 Metetra
.656 .751 .92 r
.51636 .34684 .52206 .35341 .53253 .34986 .52686 .34326 Metetra
.656 .751 .92 r
.52686 .34326 .53253 .34986 .54303 .34629 .53739 .33967 Metetra
.656 .751 .92 r
.53739 .33967 .54303 .34629 .55358 .34271 .54797 .33607 Metetra
.656 .751 .92 r
.54797 .33607 .55358 .34271 .56418 .33912 .55859 .33245 Metetra
.656 .751 .92 r
.55859 .33245 .56418 .33912 .57481 .33552 .56925 .32882 Metetra
.656 .751 .92 r
.56925 .32882 .57481 .33552 .58548 .3319 .57995 .32518 Metetra
.656 .751 .92 r
.57995 .32518 .58548 .3319 .59619 .32826 .59069 .32152 Metetra
.656 .751 .92 r
.59069 .32152 .59619 .32826 .60695 .32462 .60147 .31784 Metetra
.656 .751 .92 r
.60147 .31784 .60695 .32462 .61774 .32095 .61229 .31416 Metetra
.656 .751 .92 r
.61229 .31416 .61774 .32095 .62858 .31728 .62316 .31045 Metetra
.656 .751 .92 r
.62316 .31045 .62858 .31728 .63946 .31359 .63407 .30674 Metetra
.656 .751 .92 r
.63407 .30674 .63946 .31359 .65038 .30988 .64502 .30301 Metetra
.656 .751 .92 r
.64502 .30301 .65038 .30988 .66135 .30617 .65601 .29926 Metetra
.656 .751 .92 r
.65601 .29926 .66135 .30617 .67235 .30243 .66705 .2955 Metetra
.656 .751 .92 r
.66705 .2955 .67235 .30243 .68341 .29868 .67813 .29173 Metetra
.656 .751 .92 r
.67813 .29173 .68341 .29868 .6945 .29492 .68925 .28794 Metetra
.656 .751 .92 r
.68925 .28794 .6945 .29492 .70564 .29114 .70042 .28413 Metetra
.656 .751 .92 r
.70042 .28413 .70564 .29114 .71682 .28735 .71163 .28031 Metetra
.656 .751 .92 r
.71163 .28031 .71682 .28735 .72804 .28354 .72289 .27648 Metetra
.656 .751 .92 r
.72289 .27648 .72804 .28354 .73931 .27972 .73419 .27263 Metetra
.656 .751 .92 r
.73419 .27263 .73931 .27972 .75063 .27588 .74554 .26876 Metetra
.656 .751 .92 r
.74554 .26876 .75063 .27588 .76199 .27203 .75693 .26488 Metetra
.656 .751 .92 r
.75693 .26488 .76199 .27203 .77339 .26816 .76837 .26098 Metetra
.656 .751 .92 r
.76837 .26098 .77339 .26816 .78484 .26428 .77985 .25707 Metetra
.656 .751 .92 r
.77985 .25707 .78484 .26428 .79634 .26038 .79138 .25314 Metetra
.648 .699 .883 r
.13863 .46741 .14502 .47469 .15431 .47019 .14776 .46442 Metetra
.656 .751 .92 r
.14776 .46442 .15431 .47019 .16347 .46707 .15693 .46128 Metetra
.656 .751 .92 r
.15693 .46128 .16347 .46707 .17265 .46394 .16614 .45813 Metetra
.656 .751 .92 r
.16614 .45813 .17265 .46394 .18188 .4608 .17538 .45497 Metetra
.656 .751 .92 r
.17538 .45497 .18188 .4608 .19113 .45765 .18466 .45179 Metetra
.656 .751 .92 r
.18466 .45179 .19113 .45765 .20042 .45448 .19397 .44861 Metetra
.656 .751 .92 r
.19397 .44861 .20042 .45448 .20974 .45131 .20331 .44541 Metetra
.656 .751 .92 r
.20331 .44541 .20974 .45131 .2191 .44812 .21268 .4422 Metetra
.656 .751 .92 r
.21268 .4422 .2191 .44812 .22849 .44492 .22209 .43898 Metetra
.656 .751 .92 r
.22209 .43898 .22849 .44492 .23791 .44171 .23153 .43575 Metetra
.656 .751 .92 r
.23153 .43575 .23791 .44171 .24737 .43849 .24101 .43251 Metetra
.656 .751 .92 r
.24101 .43251 .24737 .43849 .25686 .43525 .25052 .42925 Metetra
.656 .751 .92 r
.25052 .42925 .25686 .43525 .26639 .43201 .26007 .42598 Metetra
.656 .751 .92 r
.26007 .42598 .26639 .43201 .27595 .42875 .26965 .4227 Metetra
.656 .751 .92 r
.26965 .4227 .27595 .42875 .28554 .42548 .27927 .41941 Metetra
.656 .751 .92 r
.27927 .41941 .28554 .42548 .29518 .4222 .28892 .41611 Metetra
.656 .751 .92 r
.28892 .41611 .29518 .4222 .30484 .4189 .29861 .41279 Metetra
.656 .751 .92 r
.29861 .41279 .30484 .4189 .31454 .4156 .30833 .40946 Metetra
.656 .751 .92 r
.30833 .40946 .31454 .4156 .32428 .41228 .31809 .40612 Metetra
.656 .751 .92 r
.31809 .40612 .32428 .41228 .33406 .40895 .32789 .40277 Metetra
.656 .751 .92 r
.32789 .40277 .33406 .40895 .34387 .40561 .33772 .39941 Metetra
.656 .751 .92 r
.33772 .39941 .34387 .40561 .35371 .40225 .34759 .39603 Metetra
.656 .751 .92 r
.34759 .39603 .35371 .40225 .36359 .39889 .3575 .39264 Metetra
.656 .751 .92 r
.3575 .39264 .36359 .39889 .37351 .39551 .36744 .38924 Metetra
.656 .751 .92 r
.36744 .38924 .37351 .39551 .38347 .39212 .37742 .38582 Metetra
.656 .751 .92 r
.37742 .38582 .38347 .39212 .39346 .38871 .38744 .38239 Metetra
.656 .751 .92 r
.38744 .38239 .39346 .38871 .4035 .38529 .39749 .37895 Metetra
.656 .751 .92 r
.39749 .37895 .4035 .38529 .41356 .38186 .40758 .3755 Metetra
.656 .751 .92 r
.40758 .3755 .41356 .38186 .42367 .37842 .41771 .37203 Metetra
.656 .751 .92 r
.41771 .37203 .42367 .37842 .43381 .37496 .42788 .36855 Metetra
.656 .751 .92 r
.42788 .36855 .43381 .37496 .444 .37149 .43809 .36506 Metetra
.656 .751 .92 r
.43809 .36506 .444 .37149 .45422 .36801 .44833 .36155 Metetra
.656 .751 .92 r
.44833 .36155 .45422 .36801 .46448 .36452 .45862 .35803 Metetra
.656 .751 .92 r
.45862 .35803 .46448 .36452 .47478 .36101 .46894 .3545 Metetra
.656 .751 .92 r
.46894 .3545 .47478 .36101 .48511 .35749 .4793 .35095 Metetra
.656 .751 .92 r
.4793 .35095 .48511 .35749 .49549 .35395 .4897 .34739 Metetra
.656 .751 .92 r
.4897 .34739 .49549 .35395 .50591 .3504 .50015 .34382 Metetra
.656 .751 .92 r
.50015 .34382 .50591 .3504 .51636 .34684 .51063 .34023 Metetra
.656 .751 .92 r
.51063 .34023 .51636 .34684 .52686 .34326 .52115 .33663 Metetra
.656 .751 .92 r
.52115 .33663 .52686 .34326 .53739 .33967 .53171 .33301 Metetra
.656 .751 .92 r
.53171 .33301 .53739 .33967 .54797 .33607 .54232 .32938 Metetra
.656 .751 .92 r
.54232 .32938 .54797 .33607 .55859 .33245 .55296 .32574 Metetra
.656 .751 .92 r
.55296 .32574 .55859 .33245 .56925 .32882 .56365 .32208 Metetra
.656 .751 .92 r
.56365 .32208 .56925 .32882 .57995 .32518 .57437 .31841 Metetra
.656 .751 .92 r
.57437 .31841 .57995 .32518 .59069 .32152 .58514 .31473 Metetra
.656 .751 .92 r
.58514 .31473 .59069 .32152 .60147 .31784 .59595 .31103 Metetra
.656 .751 .92 r
.59595 .31103 .60147 .31784 .61229 .31416 .6068 .30731 Metetra
.656 .751 .92 r
.6068 .30731 .61229 .31416 .62316 .31045 .6177 .30358 Metetra
.656 .751 .92 r
.6177 .30358 .62316 .31045 .63407 .30674 .62864 .29984 Metetra
.656 .751 .92 r
.62864 .29984 .63407 .30674 .64502 .30301 .63962 .29608 Metetra
.656 .751 .92 r
.63962 .29608 .64502 .30301 .65601 .29926 .65064 .29231 Metetra
.656 .751 .92 r
.65064 .29231 .65601 .29926 .66705 .2955 .66171 .28852 Metetra
.656 .751 .92 r
.66171 .28852 .66705 .2955 .67813 .29173 .67282 .28472 Metetra
.656 .751 .92 r
.67282 .28472 .67813 .29173 .68925 .28794 .68397 .2809 Metetra
.656 .751 .92 r
.68397 .2809 .68925 .28794 .70042 .28413 .69517 .27707 Metetra
.656 .751 .92 r
.69517 .27707 .70042 .28413 .71163 .28031 .70641 .27322 Metetra
.656 .751 .92 r
.70641 .27322 .71163 .28031 .72289 .27648 .7177 .26936 Metetra
.656 .751 .92 r
.7177 .26936 .72289 .27648 .73419 .27263 .72903 .26548 Metetra
.656 .751 .92 r
.72903 .26548 .73419 .27263 .74554 .26876 .74041 .26158 Metetra
.656 .751 .92 r
.74041 .26158 .74554 .26876 .75693 .26488 .75183 .25767 Metetra
.656 .751 .92 r
.75183 .25767 .75693 .26488 .76837 .26098 .7633 .25375 Metetra
.656 .751 .92 r
.7633 .25375 .76837 .26098 .77985 .25707 .77481 .24981 Metetra
.656 .751 .92 r
.77481 .24981 .77985 .25707 .79138 .25314 .78638 .24585 Metetra
.58 .676 .906 r
.13221 .4601 .13863 .46741 .14776 .46442 .14117 .45862 Metetra
.656 .751 .92 r
.14117 .45862 .14776 .46442 .15693 .46128 .15036 .45546 Metetra
.656 .751 .92 r
.15036 .45546 .15693 .46128 .16614 .45813 .15959 .45228 Metetra
.656 .751 .92 r
.15959 .45228 .16614 .45813 .17538 .45497 .16885 .4491 Metetra
.656 .751 .92 r
.16885 .4491 .17538 .45497 .18466 .45179 .17814 .4459 Metetra
.656 .751 .92 r
.17814 .4459 .18466 .45179 .19397 .44861 .18747 .4427 Metetra
.656 .751 .92 r
.18747 .4427 .19397 .44861 .20331 .44541 .19683 .43948 Metetra
.656 .751 .92 r
.19683 .43948 .20331 .44541 .21268 .4422 .20622 .43625 Metetra
.656 .751 .92 r
.20622 .43625 .21268 .4422 .22209 .43898 .21565 .43301 Metetra
.656 .751 .92 r
.21565 .43301 .22209 .43898 .23153 .43575 .22512 .42975 Metetra
.656 .751 .92 r
.22512 .42975 .23153 .43575 .24101 .43251 .23461 .42649 Metetra
.656 .751 .92 r
.23461 .42649 .24101 .43251 .25052 .42925 .24415 .42321 Metetra
.656 .751 .92 r
.24415 .42321 .25052 .42925 .26007 .42598 .25371 .41992 Metetra
.656 .751 .92 r
.25371 .41992 .26007 .42598 .26965 .4227 .26332 .41662 Metetra
.656 .751 .92 r
.26332 .41662 .26965 .4227 .27927 .41941 .27296 .4133 Metetra
.656 .751 .92 r
.27296 .4133 .27927 .41941 .28892 .41611 .28263 .40998 Metetra
.656 .751 .92 r
.28263 .40998 .28892 .41611 .29861 .41279 .29234 .40664 Metetra
.656 .751 .92 r
.29234 .40664 .29861 .41279 .30833 .40946 .30208 .40329 Metetra
.656 .751 .92 r
.30208 .40329 .30833 .40946 .31809 .40612 .31186 .39993 Metetra
.656 .751 .92 r
.31186 .39993 .31809 .40612 .32789 .40277 .32168 .39655 Metetra
.656 .751 .92 r
.32168 .39655 .32789 .40277 .33772 .39941 .33154 .39316 Metetra
.656 .751 .92 r
.33154 .39316 .33772 .39941 .34759 .39603 .34143 .38976 Metetra
.656 .751 .92 r
.34143 .38976 .34759 .39603 .3575 .39264 .35136 .38635 Metetra
.656 .751 .92 r
.35136 .38635 .3575 .39264 .36744 .38924 .36132 .38292 Metetra
.656 .751 .92 r
.36132 .38292 .36744 .38924 .37742 .38582 .37132 .37948 Metetra
.656 .751 .92 r
.37132 .37948 .37742 .38582 .38744 .38239 .38136 .37603 Metetra
.656 .751 .92 r
.38136 .37603 .38744 .38239 .39749 .37895 .39144 .37256 Metetra
.656 .751 .92 r
.39144 .37256 .39749 .37895 .40758 .3755 .40156 .36909 Metetra
.656 .751 .92 r
.40156 .36909 .40758 .3755 .41771 .37203 .41171 .36559 Metetra
.656 .751 .92 r
.41171 .36559 .41771 .37203 .42788 .36855 .4219 .36209 Metetra
.656 .751 .92 r
.4219 .36209 .42788 .36855 .43809 .36506 .43214 .35857 Metetra
.656 .751 .92 r
.43214 .35857 .43809 .36506 .44833 .36155 .44241 .35504 Metetra
.656 .751 .92 r
.44241 .35504 .44833 .36155 .45862 .35803 .45271 .3515 Metetra
.656 .751 .92 r
.45271 .3515 .45862 .35803 .46894 .3545 .46306 .34794 Metetra
.656 .751 .92 r
.46306 .34794 .46894 .3545 .4793 .35095 .47345 .34437 Metetra
.656 .751 .92 r
.47345 .34437 .4793 .35095 .4897 .34739 .48388 .34078 Metetra
.656 .751 .92 r
.48388 .34078 .4897 .34739 .50015 .34382 .49435 .33718 Metetra
.656 .751 .92 r
.49435 .33718 .50015 .34382 .51063 .34023 .50485 .33357 Metetra
.656 .751 .92 r
.50485 .33357 .51063 .34023 .52115 .33663 .5154 .32994 Metetra
.656 .751 .92 r
.5154 .32994 .52115 .33663 .53171 .33301 .52599 .3263 Metetra
.656 .751 .92 r
.52599 .3263 .53171 .33301 .54232 .32938 .53662 .32265 Metetra
.656 .751 .92 r
.53662 .32265 .54232 .32938 .55296 .32574 .54729 .31898 Metetra
.656 .751 .92 r
.54729 .31898 .55296 .32574 .56365 .32208 .55801 .31529 Metetra
.656 .751 .92 r
.55801 .31529 .56365 .32208 .57437 .31841 .56876 .3116 Metetra
.656 .751 .92 r
.56876 .3116 .57437 .31841 .58514 .31473 .57956 .30788 Metetra
.656 .751 .92 r
.57956 .30788 .58514 .31473 .59595 .31103 .59039 .30416 Metetra
.656 .751 .92 r
.59039 .30416 .59595 .31103 .6068 .30731 .60127 .30042 Metetra
.656 .751 .92 r
.60127 .30042 .6068 .30731 .6177 .30358 .6122 .29666 Metetra
.656 .751 .92 r
.6122 .29666 .6177 .30358 .62864 .29984 .62316 .29289 Metetra
.656 .751 .92 r
.62316 .29289 .62864 .29984 .63962 .29608 .63417 .2891 Metetra
.656 .751 .92 r
.63417 .2891 .63962 .29608 .65064 .29231 .64523 .2853 Metetra
.656 .751 .92 r
.64523 .2853 .65064 .29231 .66171 .28852 .65632 .28149 Metetra
.656 .751 .92 r
.65632 .28149 .66171 .28852 .67282 .28472 .66746 .27766 Metetra
.656 .751 .92 r
.66746 .27766 .67282 .28472 .68397 .2809 .67865 .27381 Metetra
.656 .751 .92 r
.67865 .27381 .68397 .2809 .69517 .27707 .68988 .26995 Metetra
.656 .751 .92 r
.68988 .26995 .69517 .27707 .70641 .27322 .70115 .26608 Metetra
.656 .751 .92 r
.70115 .26608 .70641 .27322 .7177 .26936 .71247 .26218 Metetra
.656 .751 .92 r
.71247 .26218 .7177 .26936 .72903 .26548 .72383 .25828 Metetra
.656 .751 .92 r
.72383 .25828 .72903 .26548 .74041 .26158 .73524 .25435 Metetra
.656 .751 .92 r
.73524 .25435 .74041 .26158 .75183 .25767 .74669 .25041 Metetra
.656 .751 .92 r
.74669 .25041 .75183 .25767 .7633 .25375 .7582 .24646 Metetra
.656 .751 .92 r
.7582 .24646 .7633 .25375 .77481 .24981 .76974 .24249 Metetra
.656 .751 .92 r
.76974 .24249 .77481 .24981 .78638 .24585 .78134 .2385 Metetra
.767 .929 .939 r
.125 .45885 .13221 .4601 .14117 .45862 .13453 .45277 Metetra
.656 .751 .92 r
.13453 .45277 .14117 .45862 .15036 .45546 .14374 .44959 Metetra
.656 .751 .92 r
.14374 .44959 .15036 .45546 .15959 .45228 .15299 .4464 Metetra
.656 .751 .92 r
.15299 .4464 .15959 .45228 .16885 .4491 .16227 .44319 Metetra
.656 .751 .92 r
.16227 .44319 .16885 .4491 .17814 .4459 .17158 .43997 Metetra
.656 .751 .92 r
.17158 .43997 .17814 .4459 .18747 .4427 .18093 .43675 Metetra
.656 .751 .92 r
.18093 .43675 .18747 .4427 .19683 .43948 .19031 .43351 Metetra
.656 .751 .92 r
.19031 .43351 .19683 .43948 .20622 .43625 .19972 .43025 Metetra
.656 .751 .92 r
.19972 .43025 .20622 .43625 .21565 .43301 .20917 .42699 Metetra
.656 .751 .92 r
.20917 .42699 .21565 .43301 .22512 .42975 .21865 .42371 Metetra
.656 .751 .92 r
.21865 .42371 .22512 .42975 .23461 .42649 .22817 .42043 Metetra
.656 .751 .92 r
.22817 .42043 .23461 .42649 .24415 .42321 .23772 .41713 Metetra
.656 .751 .92 r
.23772 .41713 .24415 .42321 .25371 .41992 .24731 .41381 Metetra
.656 .751 .92 r
.24731 .41381 .25371 .41992 .26332 .41662 .25694 .41049 Metetra
.656 .751 .92 r
.25694 .41049 .26332 .41662 .27296 .4133 .2666 .40715 Metetra
.656 .751 .92 r
.2666 .40715 .27296 .4133 .28263 .40998 .27629 .4038 Metetra
.656 .751 .92 r
.27629 .4038 .28263 .40998 .29234 .40664 .28602 .40044 Metetra
.656 .751 .92 r
.28602 .40044 .29234 .40664 .30208 .40329 .29579 .39707 Metetra
.656 .751 .92 r
.29579 .39707 .30208 .40329 .31186 .39993 .30559 .39368 Metetra
.656 .751 .92 r
.30559 .39368 .31186 .39993 .32168 .39655 .31543 .39028 Metetra
.656 .751 .92 r
.31543 .39028 .32168 .39655 .33154 .39316 .32531 .38687 Metetra
.656 .751 .92 r
.32531 .38687 .33154 .39316 .34143 .38976 .33522 .38345 Metetra
.656 .751 .92 r
.33522 .38345 .34143 .38976 .35136 .38635 .34517 .38001 Metetra
.656 .751 .92 r
.34517 .38001 .35136 .38635 .36132 .38292 .35516 .37656 Metetra
.656 .751 .92 r
.35516 .37656 .36132 .38292 .37132 .37948 .36519 .3731 Metetra
.656 .751 .92 r
.36519 .3731 .37132 .37948 .38136 .37603 .37525 .36962 Metetra
.656 .751 .92 r
.37525 .36962 .38136 .37603 .39144 .37256 .38535 .36613 Metetra
.656 .751 .92 r
.38535 .36613 .39144 .37256 .40156 .36909 .39549 .36263 Metetra
.656 .751 .92 r
.39549 .36263 .40156 .36909 .41171 .36559 .40567 .35911 Metetra
.656 .751 .92 r
.40567 .35911 .41171 .36559 .4219 .36209 .41589 .35558 Metetra
.656 .751 .92 r
.41589 .35558 .4219 .36209 .43214 .35857 .42614 .35204 Metetra
.656 .751 .92 r
.42614 .35204 .43214 .35857 .44241 .35504 .43644 .34849 Metetra
.656 .751 .92 r
.43644 .34849 .44241 .35504 .45271 .3515 .44677 .34492 Metetra
.656 .751 .92 r
.44677 .34492 .45271 .3515 .46306 .34794 .45714 .34133 Metetra
.656 .751 .92 r
.45714 .34133 .46306 .34794 .47345 .34437 .46756 .33774 Metetra
.656 .751 .92 r
.46756 .33774 .47345 .34437 .48388 .34078 .47801 .33413 Metetra
.656 .751 .92 r
.47801 .33413 .48388 .34078 .49435 .33718 .48851 .3305 Metetra
.656 .751 .92 r
.48851 .3305 .49435 .33718 .50485 .33357 .49904 .32686 Metetra
.656 .751 .92 r
.49904 .32686 .50485 .33357 .5154 .32994 .50961 .32321 Metetra
.656 .751 .92 r
.50961 .32321 .5154 .32994 .52599 .3263 .52023 .31954 Metetra
.656 .751 .92 r
.52023 .31954 .52599 .3263 .53662 .32265 .53089 .31586 Metetra
.656 .751 .92 r
.53089 .31586 .53662 .32265 .54729 .31898 .54158 .31217 Metetra
.656 .751 .92 r
.54158 .31217 .54729 .31898 .55801 .31529 .55232 .30846 Metetra
.656 .751 .92 r
.55232 .30846 .55801 .31529 .56876 .3116 .56311 .30473 Metetra
.656 .751 .92 r
.56311 .30473 .56876 .3116 .57956 .30788 .57393 .30099 Metetra
.656 .751 .92 r
.57393 .30099 .57956 .30788 .59039 .30416 .5848 .29724 Metetra
.656 .751 .92 r
.5848 .29724 .59039 .30416 .60127 .30042 .59571 .29347 Metetra
.656 .751 .92 r
.59571 .29347 .60127 .30042 .6122 .29666 .60666 .28969 Metetra
.656 .751 .92 r
.60666 .28969 .6122 .29666 .62316 .29289 .61765 .28589 Metetra
.656 .751 .92 r
.61765 .28589 .62316 .29289 .63417 .2891 .62869 .28208 Metetra
.656 .751 .92 r
.62869 .28208 .63417 .2891 .64523 .2853 .63977 .27825 Metetra
.656 .751 .92 r
.63977 .27825 .64523 .2853 .65632 .28149 .6509 .2744 Metetra
.656 .751 .92 r
.6509 .2744 .65632 .28149 .66746 .27766 .66207 .27055 Metetra
.656 .751 .92 r
.66207 .27055 .66746 .27766 .67865 .27381 .67328 .26667 Metetra
.656 .751 .92 r
.67328 .26667 .67865 .27381 .68988 .26995 .68454 .26278 Metetra
.656 .751 .92 r
.68454 .26278 .68988 .26995 .70115 .26608 .69585 .25888 Metetra
.656 .751 .92 r
.69585 .25888 .70115 .26608 .71247 .26218 .7072 .25496 Metetra
.656 .751 .92 r
.7072 .25496 .71247 .26218 .72383 .25828 .71859 .25102 Metetra
.656 .751 .92 r
.71859 .25102 .72383 .25828 .73524 .25435 .73003 .24707 Metetra
.656 .751 .92 r
.73003 .24707 .73524 .25435 .74669 .25041 .74152 .2431 Metetra
.656 .751 .92 r
.74152 .2431 .74669 .25041 .7582 .24646 .75305 .23912 Metetra
.656 .751 .92 r
.75305 .23912 .7582 .24646 .76974 .24249 .76463 .23512 Metetra
.656 .751 .92 r
.76463 .23512 .76974 .24249 .78134 .2385 .77626 .2311 Metetra
.554 .567 .822 r
.11896 .44762 .125 .45885 .13453 .45277 .12785 .44689 Metetra
.656 .751 .92 r
.12785 .44689 .13453 .45277 .14374 .44959 .13708 .44369 Metetra
.656 .751 .92 r
.13708 .44369 .14374 .44959 .15299 .4464 .14635 .44047 Metetra
.656 .751 .92 r
.14635 .44047 .15299 .4464 .16227 .44319 .15564 .43724 Metetra
.656 .751 .92 r
.15564 .43724 .16227 .44319 .17158 .43997 .16497 .43401 Metetra
.656 .751 .92 r
.16497 .43401 .17158 .43997 .18093 .43675 .17434 .43076 Metetra
.656 .751 .92 r
.17434 .43076 .18093 .43675 .19031 .43351 .18374 .42749 Metetra
.656 .751 .92 r
.18374 .42749 .19031 .43351 .19972 .43025 .19318 .42422 Metetra
.656 .751 .92 r
.19318 .42422 .19972 .43025 .20917 .42699 .20264 .42093 Metetra
.656 .751 .92 r
.20264 .42093 .20917 .42699 .21865 .42371 .21215 .41763 Metetra
.656 .751 .92 r
.21215 .41763 .21865 .42371 .22817 .42043 .22169 .41432 Metetra
.656 .751 .92 r
.22169 .41432 .22817 .42043 .23772 .41713 .23126 .411 Metetra
.656 .751 .92 r
.23126 .411 .23772 .41713 .24731 .41381 .24087 .40767 Metetra
.656 .751 .92 r
.24087 .40767 .24731 .41381 .25694 .41049 .25051 .40432 Metetra
.656 .751 .92 r
.25051 .40432 .25694 .41049 .2666 .40715 .26019 .40096 Metetra
.656 .751 .92 r
.26019 .40096 .2666 .40715 .27629 .4038 .26991 .39759 Metetra
.656 .751 .92 r
.26991 .39759 .27629 .4038 .28602 .40044 .27966 .3942 Metetra
.656 .751 .92 r
.27966 .3942 .28602 .40044 .29579 .39707 .28945 .39081 Metetra
.656 .751 .92 r
.28945 .39081 .29579 .39707 .30559 .39368 .29928 .3874 Metetra
.656 .751 .92 r
.29928 .3874 .30559 .39368 .31543 .39028 .30914 .38398 Metetra
.656 .751 .92 r
.30914 .38398 .31543 .39028 .32531 .38687 .31904 .38054 Metetra
.656 .751 .92 r
.31904 .38054 .32531 .38687 .33522 .38345 .32897 .37709 Metetra
.656 .751 .92 r
.32897 .37709 .33522 .38345 .34517 .38001 .33895 .37363 Metetra
.656 .751 .92 r
.33895 .37363 .34517 .38001 .35516 .37656 .34896 .37016 Metetra
.656 .751 .92 r
.34896 .37016 .35516 .37656 .36519 .3731 .35901 .36667 Metetra
.656 .751 .92 r
.35901 .36667 .36519 .3731 .37525 .36962 .36909 .36317 Metetra
.656 .751 .92 r
.36909 .36317 .37525 .36962 .38535 .36613 .37922 .35966 Metetra
.656 .751 .92 r
.37922 .35966 .38535 .36613 .39549 .36263 .38938 .35613 Metetra
.656 .751 .92 r
.38938 .35613 .39549 .36263 .40567 .35911 .39959 .35259 Metetra
.656 .751 .92 r
.39959 .35259 .40567 .35911 .41589 .35558 .40983 .34903 Metetra
.656 .751 .92 r
.40983 .34903 .41589 .35558 .42614 .35204 .42011 .34547 Metetra
.656 .751 .92 r
.42011 .34547 .42614 .35204 .43644 .34849 .43043 .34189 Metetra
.656 .751 .92 r
.43043 .34189 .43644 .34849 .44677 .34492 .44079 .33829 Metetra
.656 .751 .92 r
.44079 .33829 .44677 .34492 .45714 .34133 .45118 .33468 Metetra
.656 .751 .92 r
.45118 .33468 .45714 .34133 .46756 .33774 .46162 .33106 Metetra
.656 .751 .92 r
.46162 .33106 .46756 .33774 .47801 .33413 .4721 .32742 Metetra
.656 .751 .92 r
.4721 .32742 .47801 .33413 .48851 .3305 .48262 .32377 Metetra
.656 .751 .92 r
.48262 .32377 .48851 .3305 .49904 .32686 .49318 .32011 Metetra
.656 .751 .92 r
.49318 .32011 .49904 .32686 .50961 .32321 .50378 .31643 Metetra
.656 .751 .92 r
.50378 .31643 .50961 .32321 .52023 .31954 .51443 .31273 Metetra
.656 .751 .92 r
.51443 .31273 .52023 .31954 .53089 .31586 .52511 .30903 Metetra
.656 .751 .92 r
.52511 .30903 .53089 .31586 .54158 .31217 .53584 .3053 Metetra
.656 .751 .92 r
.53584 .3053 .54158 .31217 .55232 .30846 .5466 .30157 Metetra
.656 .751 .92 r
.5466 .30157 .55232 .30846 .56311 .30473 .55741 .29782 Metetra
.656 .751 .92 r
.55741 .29782 .56311 .30473 .57393 .30099 .56826 .29405 Metetra
.656 .751 .92 r
.56826 .29405 .57393 .30099 .5848 .29724 .57916 .29027 Metetra
.656 .751 .92 r
.57916 .29027 .5848 .29724 .59571 .29347 .5901 .28647 Metetra
.656 .751 .92 r
.5901 .28647 .59571 .29347 .60666 .28969 .60108 .28266 Metetra
.656 .751 .92 r
.60108 .28266 .60666 .28969 .61765 .28589 .6121 .27884 Metetra
.656 .751 .92 r
.6121 .27884 .61765 .28589 .62869 .28208 .62317 .275 Metetra
.656 .751 .92 r
.62317 .275 .62869 .28208 .63977 .27825 .63428 .27114 Metetra
.656 .751 .92 r
.63428 .27114 .63977 .27825 .6509 .2744 .64544 .26727 Metetra
.656 .751 .92 r
.64544 .26727 .6509 .2744 .66207 .27055 .65664 .26338 Metetra
.656 .751 .92 r
.65664 .26338 .66207 .27055 .67328 .26667 .66788 .25948 Metetra
.656 .751 .92 r
.66788 .25948 .67328 .26667 .68454 .26278 .67917 .25556 Metetra
.656 .751 .92 r
.67917 .25556 .68454 .26278 .69585 .25888 .69051 .25163 Metetra
.656 .751 .92 r
.69051 .25163 .69585 .25888 .7072 .25496 .70189 .24768 Metetra
.656 .751 .92 r
.70189 .24768 .7072 .25496 .71859 .25102 .71332 .24371 Metetra
.656 .751 .92 r
.71332 .24371 .71859 .25102 .73003 .24707 .72479 .23973 Metetra
.656 .751 .92 r
.72479 .23973 .73003 .24707 .74152 .2431 .73631 .23573 Metetra
.656 .751 .92 r
.73631 .23573 .74152 .2431 .75305 .23912 .74787 .23172 Metetra
.656 .751 .92 r
.74787 .23172 .75305 .23912 .76463 .23512 .75949 .22769 Metetra
.656 .751 .92 r
.75949 .22769 .76463 .23512 .77626 .2311 .77115 .22364 Metetra
.643 .842 .977 r
.11191 .4442 .11896 .44762 .12785 .44689 .12112 .44097 Metetra
.656 .751 .92 r
.12112 .44097 .12785 .44689 .13708 .44369 .13037 .43774 Metetra
.656 .751 .92 r
.13037 .43774 .13708 .44369 .14635 .44047 .13966 .4345 Metetra
.656 .751 .92 r
.13966 .4345 .14635 .44047 .15564 .43724 .14897 .43126 Metetra
.656 .751 .92 r
.14897 .43126 .15564 .43724 .16497 .43401 .15833 .428 Metetra
.656 .751 .92 r
.15833 .428 .16497 .43401 .17434 .43076 .16771 .42472 Metetra
.656 .751 .92 r
.16771 .42472 .17434 .43076 .18374 .42749 .17713 .42144 Metetra
.656 .751 .92 r
.17713 .42144 .18374 .42749 .19318 .42422 .18658 .41814 Metetra
.656 .751 .92 r
.18658 .41814 .19318 .42422 .20264 .42093 .19607 .41483 Metetra
.656 .751 .92 r
.19607 .41483 .20264 .42093 .21215 .41763 .2056 .41151 Metetra
.656 .751 .92 r
.2056 .41151 .21215 .41763 .22169 .41432 .21516 .40818 Metetra
.656 .751 .92 r
.21516 .40818 .22169 .41432 .23126 .411 .22475 .40484 Metetra
.656 .751 .92 r
.22475 .40484 .23126 .411 .24087 .40767 .23438 .40148 Metetra
.656 .751 .92 r
.23438 .40148 .24087 .40767 .25051 .40432 .24405 .39811 Metetra
.656 .751 .92 r
.24405 .39811 .25051 .40432 .26019 .40096 .25375 .39473 Metetra
.656 .751 .92 r
.25375 .39473 .26019 .40096 .26991 .39759 .26349 .39133 Metetra
.656 .751 .92 r
.26349 .39133 .26991 .39759 .27966 .3942 .27326 .38792 Metetra
.656 .751 .92 r
.27326 .38792 .27966 .3942 .28945 .39081 .28307 .3845 Metetra
.656 .751 .92 r
.28307 .3845 .28945 .39081 .29928 .3874 .29292 .38107 Metetra
.656 .751 .92 r
.29292 .38107 .29928 .3874 .30914 .38398 .3028 .37762 Metetra
.656 .751 .92 r
.3028 .37762 .30914 .38398 .31904 .38054 .31272 .37416 Metetra
.656 .751 .92 r
.31272 .37416 .31904 .38054 .32897 .37709 .32268 .37069 Metetra
.656 .751 .92 r
.32268 .37069 .32897 .37709 .33895 .37363 .33268 .36721 Metetra
.656 .751 .92 r
.33268 .36721 .33895 .37363 .34896 .37016 .34271 .36371 Metetra
.656 .751 .92 r
.34271 .36371 .34896 .37016 .35901 .36667 .35278 .3602 Metetra
.656 .751 .92 r
.35278 .3602 .35901 .36667 .36909 .36317 .3629 .35667 Metetra
.656 .751 .92 r
.3629 .35667 .36909 .36317 .37922 .35966 .37304 .35313 Metetra
.656 .751 .92 r
.37304 .35313 .37922 .35966 .38938 .35613 .38323 .34958 Metetra
.656 .751 .92 r
.38323 .34958 .38938 .35613 .39959 .35259 .39346 .34602 Metetra
.656 .751 .92 r
.39346 .34602 .39959 .35259 .40983 .34903 .40372 .34244 Metetra
.656 .751 .92 r
.40372 .34244 .40983 .34903 .42011 .34547 .41403 .33884 Metetra
.656 .751 .92 r
.41403 .33884 .42011 .34547 .43043 .34189 .42437 .33524 Metetra
.656 .751 .92 r
.42437 .33524 .43043 .34189 .44079 .33829 .43476 .33162 Metetra
.656 .751 .92 r
.43476 .33162 .44079 .33829 .45118 .33468 .44518 .32798 Metetra
.656 .751 .92 r
.44518 .32798 .45118 .33468 .46162 .33106 .45565 .32433 Metetra
.656 .751 .92 r
.45565 .32433 .46162 .33106 .4721 .32742 .46615 .32067 Metetra
.656 .751 .92 r
.46615 .32067 .4721 .32742 .48262 .32377 .4767 .31699 Metetra
.656 .751 .92 r
.4767 .31699 .48262 .32377 .49318 .32011 .48728 .3133 Metetra
.656 .751 .92 r
.48728 .3133 .49318 .32011 .50378 .31643 .49791 .3096 Metetra
.656 .751 .92 r
.49791 .3096 .50378 .31643 .51443 .31273 .50858 .30588 Metetra
.656 .751 .92 r
.50858 .30588 .51443 .31273 .52511 .30903 .51929 .30214 Metetra
.656 .751 .92 r
.51929 .30214 .52511 .30903 .53584 .3053 .53004 .29839 Metetra
.656 .751 .92 r
.53004 .29839 .53584 .3053 .5466 .30157 .54084 .29463 Metetra
.656 .751 .92 r
.54084 .29463 .5466 .30157 .55741 .29782 .55168 .29085 Metetra
.656 .751 .92 r
.55168 .29085 .55741 .29782 .56826 .29405 .56256 .28706 Metetra
.656 .751 .92 r
.56256 .28706 .56826 .29405 .57916 .29027 .57348 .28325 Metetra
.656 .751 .92 r
.57348 .28325 .57916 .29027 .5901 .28647 .58445 .27943 Metetra
.656 .751 .92 r
.58445 .27943 .5901 .28647 .60108 .28266 .59546 .27559 Metetra
.656 .751 .92 r
.59546 .27559 .60108 .28266 .6121 .27884 .60651 .27174 Metetra
.656 .751 .92 r
.60651 .27174 .6121 .27884 .62317 .275 .61761 .26787 Metetra
.656 .751 .92 r
.61761 .26787 .62317 .275 .63428 .27114 .62875 .26398 Metetra
.656 .751 .92 r
.62875 .26398 .63428 .27114 .64544 .26727 .63993 .26008 Metetra
.656 .751 .92 r
.63993 .26008 .64544 .26727 .65664 .26338 .65117 .25617 Metetra
.656 .751 .92 r
.65117 .25617 .65664 .26338 .66788 .25948 .66244 .25223 Metetra
.656 .751 .92 r
.66244 .25223 .66788 .25948 .67917 .25556 .67376 .24829 Metetra
.656 .751 .92 r
.67376 .24829 .67917 .25556 .69051 .25163 .68513 .24432 Metetra
.656 .751 .92 r
.68513 .24432 .69051 .25163 .70189 .24768 .69654 .24035 Metetra
.656 .751 .92 r
.69654 .24035 .70189 .24768 .71332 .24371 .708 .23635 Metetra
.656 .751 .92 r
.708 .23635 .71332 .24371 .72479 .23973 .71951 .23234 Metetra
.656 .751 .92 r
.71951 .23234 .72479 .23973 .73631 .23573 .73106 .22831 Metetra
.656 .751 .92 r
.73106 .22831 .73631 .23573 .74787 .23172 .74266 .22427 Metetra
.656 .751 .92 r
.74266 .22427 .74787 .23172 .75949 .22769 .7543 .22021 Metetra
.656 .751 .92 r
.7543 .22021 .75949 .22769 .77115 .22364 .766 .21613 Metetra
.788 .883 .915 r
.10468 .44166 .11191 .4442 .12112 .44097 .11435 .435 Metetra
.656 .751 .92 r
.11435 .435 .12112 .44097 .13037 .43774 .12362 .43176 Metetra
.656 .751 .92 r
.12362 .43176 .13037 .43774 .13966 .4345 .13292 .4285 Metetra
.656 .751 .92 r
.13292 .4285 .13966 .4345 .14897 .43126 .14226 .42523 Metetra
.656 .751 .92 r
.14226 .42523 .14897 .43126 .15833 .428 .15163 .42195 Metetra
.656 .751 .92 r
.15163 .42195 .15833 .428 .16771 .42472 .16104 .41865 Metetra
.656 .751 .92 r
.16104 .41865 .16771 .42472 .17713 .42144 .17048 .41534 Metetra
.656 .751 .92 r
.17048 .41534 .17713 .42144 .18658 .41814 .17995 .41203 Metetra
.656 .751 .92 r
.17995 .41203 .18658 .41814 .19607 .41483 .18946 .4087 Metetra
.656 .751 .92 r
.18946 .4087 .19607 .41483 .2056 .41151 .199 .40535 Metetra
.656 .751 .92 r
.199 .40535 .2056 .41151 .21516 .40818 .20858 .402 Metetra
.656 .751 .92 r
.20858 .402 .21516 .40818 .22475 .40484 .2182 .39863 Metetra
.656 .751 .92 r
.2182 .39863 .22475 .40484 .23438 .40148 .22785 .39525 Metetra
.656 .751 .92 r
.22785 .39525 .23438 .40148 .24405 .39811 .23753 .39185 Metetra
.656 .751 .92 r
.23753 .39185 .24405 .39811 .25375 .39473 .24726 .38845 Metetra
.656 .751 .92 r
.24726 .38845 .25375 .39473 .26349 .39133 .25702 .38503 Metetra
.656 .751 .92 r
.25702 .38503 .26349 .39133 .27326 .38792 .26681 .3816 Metetra
.656 .751 .92 r
.26681 .3816 .27326 .38792 .28307 .3845 .27664 .37815 Metetra
.656 .751 .92 r
.27664 .37815 .28307 .3845 .29292 .38107 .28651 .3747 Metetra
.656 .751 .92 r
.28651 .3747 .29292 .38107 .3028 .37762 .29642 .37123 Metetra
.656 .751 .92 r
.29642 .37123 .3028 .37762 .31272 .37416 .30636 .36774 Metetra
.656 .751 .92 r
.30636 .36774 .31272 .37416 .32268 .37069 .31635 .36425 Metetra
.656 .751 .92 r
.31635 .36425 .32268 .37069 .33268 .36721 .32637 .36074 Metetra
.656 .751 .92 r
.32637 .36074 .33268 .36721 .34271 .36371 .33642 .35722 Metetra
.656 .751 .92 r
.33642 .35722 .34271 .36371 .35278 .3602 .34652 .35368 Metetra
.656 .751 .92 r
.34652 .35368 .35278 .3602 .3629 .35667 .35665 .35013 Metetra
.656 .751 .92 r
.35665 .35013 .3629 .35667 .37304 .35313 .36683 .34657 Metetra
.656 .751 .92 r
.36683 .34657 .37304 .35313 .38323 .34958 .37704 .34299 Metetra
.656 .751 .92 r
.37704 .34299 .38323 .34958 .39346 .34602 .38729 .3394 Metetra
.656 .751 .92 r
.38729 .3394 .39346 .34602 .40372 .34244 .39758 .33579 Metetra
.656 .751 .92 r
.39758 .33579 .40372 .34244 .41403 .33884 .40791 .33217 Metetra
.656 .751 .92 r
.40791 .33217 .41403 .33884 .42437 .33524 .41828 .32854 Metetra
.656 .751 .92 r
.41828 .32854 .42437 .33524 .43476 .33162 .42869 .3249 Metetra
.656 .751 .92 r
.42869 .3249 .43476 .33162 .44518 .32798 .43914 .32124 Metetra
.656 .751 .92 r
.43914 .32124 .44518 .32798 .45565 .32433 .44963 .31756 Metetra
.656 .751 .92 r
.44963 .31756 .45565 .32433 .46615 .32067 .46016 .31387 Metetra
.656 .751 .92 r
.46016 .31387 .46615 .32067 .4767 .31699 .47073 .31017 Metetra
.656 .751 .92 r
.47073 .31017 .4767 .31699 .48728 .3133 .48134 .30645 Metetra
.656 .751 .92 r
.48134 .30645 .48728 .3133 .49791 .3096 .492 .30272 Metetra
.656 .751 .92 r
.492 .30272 .49791 .3096 .50858 .30588 .50269 .29897 Metetra
.656 .751 .92 r
.50269 .29897 .50858 .30588 .51929 .30214 .51343 .29521 Metetra
.656 .751 .92 r
.51343 .29521 .51929 .30214 .53004 .29839 .52421 .29144 Metetra
.656 .751 .92 r
.52421 .29144 .53004 .29839 .54084 .29463 .53503 .28764 Metetra
.656 .751 .92 r
.53503 .28764 .54084 .29463 .55168 .29085 .5459 .28384 Metetra
.656 .751 .92 r
.5459 .28384 .55168 .29085 .56256 .28706 .55681 .28002 Metetra
.656 .751 .92 r
.55681 .28002 .56256 .28706 .57348 .28325 .56776 .27618 Metetra
.656 .751 .92 r
.56776 .27618 .57348 .28325 .58445 .27943 .57876 .27233 Metetra
.656 .751 .92 r
.57876 .27233 .58445 .27943 .59546 .27559 .58979 .26846 Metetra
.656 .751 .92 r
.58979 .26846 .59546 .27559 .60651 .27174 .60088 .26458 Metetra
.656 .751 .92 r
.60088 .26458 .60651 .27174 .61761 .26787 .612 .26068 Metetra
.656 .751 .92 r
.612 .26068 .61761 .26787 .62875 .26398 .62318 .25677 Metetra
.656 .751 .92 r
.62318 .25677 .62875 .26398 .63993 .26008 .63439 .25284 Metetra
.656 .751 .92 r
.63439 .25284 .63993 .26008 .65117 .25617 .64565 .2489 Metetra
.656 .751 .92 r
.64565 .2489 .65117 .25617 .66244 .25223 .65696 .24494 Metetra
.656 .751 .92 r
.65696 .24494 .66244 .25223 .67376 .24829 .66831 .24096 Metetra
.656 .751 .92 r
.66831 .24096 .67376 .24829 .68513 .24432 .67971 .23697 Metetra
.656 .751 .92 r
.67971 .23697 .68513 .24432 .69654 .24035 .69115 .23296 Metetra
.656 .751 .92 r
.69115 .23296 .69654 .24035 .708 .23635 .70264 .22893 Metetra
.656 .751 .92 r
.70264 .22893 .708 .23635 .71951 .23234 .71418 .22489 Metetra
.656 .751 .92 r
.71418 .22489 .71951 .23234 .73106 .22831 .72577 .22083 Metetra
.656 .751 .92 r
.72577 .22083 .73106 .22831 .74266 .22427 .7374 .21676 Metetra
.656 .751 .92 r
.7374 .21676 .74266 .22427 .7543 .22021 .74908 .21267 Metetra
.656 .751 .92 r
.74908 .21267 .7543 .22021 .766 .21613 .7608 .20856 Metetra
.429 .433 .762 r
.09905 .42646 .10468 .44166 .11435 .435 .10754 .429 Metetra
.656 .751 .92 r
.10754 .429 .11435 .435 .12362 .43176 .11683 .42573 Metetra
.656 .751 .92 r
.11683 .42573 .12362 .43176 .13292 .4285 .12615 .42245 Metetra
.656 .751 .92 r
.12615 .42245 .13292 .4285 .14226 .42523 .1355 .41916 Metetra
.656 .751 .92 r
.1355 .41916 .14226 .42523 .15163 .42195 .14489 .41585 Metetra
.656 .751 .92 r
.14489 .41585 .15163 .42195 .16104 .41865 .15432 .41254 Metetra
.656 .751 .92 r
.15432 .41254 .16104 .41865 .17048 .41534 .16377 .40921 Metetra
.656 .751 .92 r
.16377 .40921 .17048 .41534 .17995 .41203 .17327 .40587 Metetra
.656 .751 .92 r
.17327 .40587 .17995 .41203 .18946 .4087 .1828 .40251 Metetra
.656 .751 .92 r
.1828 .40251 .18946 .4087 .199 .40535 .19236 .39915 Metetra
.656 .751 .92 r
.19236 .39915 .199 .40535 .20858 .402 .20196 .39577 Metetra
.656 .751 .92 r
.20196 .39577 .20858 .402 .2182 .39863 .2116 .39238 Metetra
.656 .751 .92 r
.2116 .39238 .2182 .39863 .22785 .39525 .22127 .38897 Metetra
.656 .751 .92 r
.22127 .38897 .22785 .39525 .23753 .39185 .23098 .38556 Metetra
.656 .751 .92 r
.23098 .38556 .23753 .39185 .24726 .38845 .24072 .38213 Metetra
.656 .751 .92 r
.24072 .38213 .24726 .38845 .25702 .38503 .2505 .37869 Metetra
.656 .751 .92 r
.2505 .37869 .25702 .38503 .26681 .3816 .26032 .37523 Metetra
.656 .751 .92 r
.26032 .37523 .26681 .3816 .27664 .37815 .27017 .37176 Metetra
.656 .751 .92 r
.27017 .37176 .27664 .37815 .28651 .3747 .28007 .36828 Metetra
.656 .751 .92 r
.28007 .36828 .28651 .3747 .29642 .37123 .29 .36479 Metetra
.656 .751 .92 r
.29 .36479 .29642 .37123 .30636 .36774 .29996 .36128 Metetra
.656 .751 .92 r
.29996 .36128 .30636 .36774 .31635 .36425 .30997 .35776 Metetra
.656 .751 .92 r
.30997 .35776 .31635 .36425 .32637 .36074 .32001 .35422 Metetra
.656 .751 .92 r
.32001 .35422 .32637 .36074 .33642 .35722 .33009 .35068 Metetra
.656 .751 .92 r
.33009 .35068 .33642 .35722 .34652 .35368 .34021 .34711 Metetra
.656 .751 .92 r
.34021 .34711 .34652 .35368 .35665 .35013 .35037 .34354 Metetra
.656 .751 .92 r
.35037 .34354 .35665 .35013 .36683 .34657 .36056 .33995 Metetra
.656 .751 .92 r
.36056 .33995 .36683 .34657 .37704 .34299 .3708 .33635 Metetra
.656 .751 .92 r
.3708 .33635 .37704 .34299 .38729 .3394 .38107 .33273 Metetra
.656 .751 .92 r
.38107 .33273 .38729 .3394 .39758 .33579 .39139 .3291 Metetra
.656 .751 .92 r
.39139 .3291 .39758 .33579 .40791 .33217 .40174 .32546 Metetra
.656 .751 .92 r
.40174 .32546 .40791 .33217 .41828 .32854 .41214 .3218 Metetra
.656 .751 .92 r
.41214 .3218 .41828 .32854 .42869 .3249 .42257 .31813 Metetra
.656 .751 .92 r
.42257 .31813 .42869 .3249 .43914 .32124 .43305 .31444 Metetra
.656 .751 .92 r
.43305 .31444 .43914 .32124 .44963 .31756 .44356 .31074 Metetra
.656 .751 .92 r
.44356 .31074 .44963 .31756 .46016 .31387 .45412 .30702 Metetra
.656 .751 .92 r
.45412 .30702 .46016 .31387 .47073 .31017 .46472 .30329 Metetra
.656 .751 .92 r
.46472 .30329 .47073 .31017 .48134 .30645 .47536 .29955 Metetra
.656 .751 .92 r
.47536 .29955 .48134 .30645 .492 .30272 .48604 .29579 Metetra
.656 .751 .92 r
.48604 .29579 .492 .30272 .50269 .29897 .49676 .29202 Metetra
.656 .751 .92 r
.49676 .29202 .50269 .29897 .51343 .29521 .50753 .28823 Metetra
.656 .751 .92 r
.50753 .28823 .51343 .29521 .52421 .29144 .51834 .28442 Metetra
.656 .751 .92 r
.51834 .28442 .52421 .29144 .53503 .28764 .52919 .28061 Metetra
.656 .751 .92 r
.52919 .28061 .53503 .28764 .5459 .28384 .54008 .27677 Metetra
.656 .751 .92 r
.54008 .27677 .5459 .28384 .55681 .28002 .55102 .27292 Metetra
.656 .751 .92 r
.55102 .27292 .55681 .28002 .56776 .27618 .562 .26906 Metetra
.656 .751 .92 r
.562 .26906 .56776 .27618 .57876 .27233 .57302 .26518 Metetra
.656 .751 .92 r
.57302 .26518 .57876 .27233 .58979 .26846 .58409 .26128 Metetra
.656 .751 .92 r
.58409 .26128 .58979 .26846 .60088 .26458 .5952 .25737 Metetra
.656 .751 .92 r
.5952 .25737 .60088 .26458 .612 .26068 .60636 .25345 Metetra
.656 .751 .92 r
.60636 .25345 .612 .26068 .62318 .25677 .61756 .2495 Metetra
.656 .751 .92 r
.61756 .2495 .62318 .25677 .63439 .25284 .62881 .24555 Metetra
.656 .751 .92 r
.62881 .24555 .63439 .25284 .64565 .2489 .6401 .24157 Metetra
.656 .751 .92 r
.6401 .24157 .64565 .2489 .65696 .24494 .65144 .23758 Metetra
.656 .751 .92 r
.65144 .23758 .65696 .24494 .66831 .24096 .66282 .23358 Metetra
.656 .751 .92 r
.66282 .23358 .66831 .24096 .67971 .23697 .67425 .22955 Metetra
.656 .751 .92 r
.67425 .22955 .67971 .23697 .69115 .23296 .68573 .22551 Metetra
.656 .751 .92 r
.68573 .22551 .69115 .23296 .70264 .22893 .69725 .22146 Metetra
.656 .751 .92 r
.69725 .22146 .70264 .22893 .71418 .22489 .70882 .21739 Metetra
.656 .751 .92 r
.70882 .21739 .71418 .22489 .72577 .22083 .72044 .2133 Metetra
.656 .751 .92 r
.72044 .2133 .72577 .22083 .7374 .21676 .7321 .20919 Metetra
.656 .751 .92 r
.7321 .20919 .7374 .21676 .74908 .21267 .74381 .20507 Metetra
.656 .751 .92 r
.74381 .20507 .74908 .21267 .7608 .20856 .75557 .20093 Metetra
.65 .953 .74 r
.09074 .43125 .09905 .42646 .10754 .429 .10068 .42296 Metetra
.656 .751 .92 r
.10068 .42296 .10754 .429 .11683 .42573 .10998 .41967 Metetra
.656 .751 .92 r
.10998 .41967 .11683 .42573 .12615 .42245 .11932 .41636 Metetra
.656 .751 .92 r
.11932 .41636 .12615 .42245 .1355 .41916 .1287 .41305 Metetra
.656 .751 .92 r
.1287 .41305 .1355 .41916 .14489 .41585 .13811 .40972 Metetra
.656 .751 .92 r
.13811 .40972 .14489 .41585 .15432 .41254 .14755 .40638 Metetra
.656 .751 .92 r
.14755 .40638 .15432 .41254 .16377 .40921 .15703 .40303 Metetra
.656 .751 .92 r
.15703 .40303 .16377 .40921 .17327 .40587 .16654 .39967 Metetra
.656 .751 .92 r
.16654 .39967 .17327 .40587 .1828 .40251 .17609 .39629 Metetra
.656 .751 .92 r
.17609 .39629 .1828 .40251 .19236 .39915 .18568 .3929 Metetra
.656 .751 .92 r
.18568 .3929 .19236 .39915 .20196 .39577 .1953 .3895 Metetra
.656 .751 .92 r
.1953 .3895 .20196 .39577 .2116 .39238 .20495 .38608 Metetra
.656 .751 .92 r
.20495 .38608 .2116 .39238 .22127 .38897 .21465 .38266 Metetra
.656 .751 .92 r
.21465 .38266 .22127 .38897 .23098 .38556 .22438 .37922 Metetra
.656 .751 .92 r
.22438 .37922 .23098 .38556 .24072 .38213 .23414 .37576 Metetra
.656 .751 .92 r
.23414 .37576 .24072 .38213 .2505 .37869 .24394 .3723 Metetra
.656 .751 .92 r
.24394 .3723 .2505 .37869 .26032 .37523 .25378 .36882 Metetra
.656 .751 .92 r
.25378 .36882 .26032 .37523 .27017 .37176 .26366 .36532 Metetra
.656 .751 .92 r
.26366 .36532 .27017 .37176 .28007 .36828 .27357 .36182 Metetra
.656 .751 .92 r
.27357 .36182 .28007 .36828 .29 .36479 .28352 .3583 Metetra
.656 .751 .92 r
.28352 .3583 .29 .36479 .29996 .36128 .29351 .35477 Metetra
.656 .751 .92 r
.29351 .35477 .29996 .36128 .30997 .35776 .30354 .35122 Metetra
.656 .751 .92 r
.30354 .35122 .30997 .35776 .32001 .35422 .31361 .34766 Metetra
.656 .751 .92 r
.31361 .34766 .32001 .35422 .33009 .35068 .32371 .34409 Metetra
.656 .751 .92 r
.32371 .34409 .33009 .35068 .34021 .34711 .33385 .3405 Metetra
.656 .751 .92 r
.33385 .3405 .34021 .34711 .35037 .34354 .34403 .3369 Metetra
.656 .751 .92 r
.34403 .3369 .35037 .34354 .36056 .33995 .35426 .33329 Metetra
.656 .751 .92 r
.35426 .33329 .36056 .33995 .3708 .33635 .36452 .32966 Metetra
.656 .751 .92 r
.36452 .32966 .3708 .33635 .38107 .33273 .37481 .32602 Metetra
.656 .751 .92 r
.37481 .32602 .38107 .33273 .39139 .3291 .38515 .32236 Metetra
.656 .751 .92 r
.38515 .32236 .39139 .3291 .40174 .32546 .39553 .31869 Metetra
.656 .751 .92 r
.39553 .31869 .40174 .32546 .41214 .3218 .40595 .31501 Metetra
.656 .751 .92 r
.40595 .31501 .41214 .3218 .42257 .31813 .41641 .31131 Metetra
.656 .751 .92 r
.41641 .31131 .42257 .31813 .43305 .31444 .42691 .3076 Metetra
.656 .751 .92 r
.42691 .3076 .43305 .31444 .44356 .31074 .43746 .30387 Metetra
.656 .751 .92 r
.43746 .30387 .44356 .31074 .45412 .30702 .44804 .30013 Metetra
.656 .751 .92 r
.44804 .30013 .45412 .30702 .46472 .30329 .45866 .29637 Metetra
.656 .751 .92 r
.45866 .29637 .46472 .30329 .47536 .29955 .46933 .2926 Metetra
.656 .751 .92 r
.46933 .2926 .47536 .29955 .48604 .29579 .48004 .28881 Metetra
.656 .751 .92 r
.48004 .28881 .48604 .29579 .49676 .29202 .49079 .28501 Metetra
.656 .751 .92 r
.49079 .28501 .49676 .29202 .50753 .28823 .50158 .28119 Metetra
.656 .751 .92 r
.50158 .28119 .50753 .28823 .51834 .28442 .51242 .27736 Metetra
.656 .751 .92 r
.51242 .27736 .51834 .28442 .52919 .28061 .5233 .27352 Metetra
.656 .751 .92 r
.5233 .27352 .52919 .28061 .54008 .27677 .53422 .26965 Metetra
.656 .751 .92 r
.53422 .26965 .54008 .27677 .55102 .27292 .54518 .26578 Metetra
.656 .751 .92 r
.54518 .26578 .55102 .27292 .562 .26906 .55619 .26188 Metetra
.656 .751 .92 r
.55619 .26188 .562 .26906 .57302 .26518 .56725 .25798 Metetra
.656 .751 .92 r
.56725 .25798 .57302 .26518 .58409 .26128 .57834 .25405 Metetra
.656 .751 .92 r
.57834 .25405 .58409 .26128 .5952 .25737 .58949 .25011 Metetra
.656 .751 .92 r
.58949 .25011 .5952 .25737 .60636 .25345 .60067 .24616 Metetra
.656 .751 .92 r
.60067 .24616 .60636 .25345 .61756 .2495 .6119 .24218 Metetra
.656 .751 .92 r
.6119 .24218 .61756 .2495 .62881 .24555 .62318 .2382 Metetra
.656 .751 .92 r
.62318 .2382 .62881 .24555 .6401 .24157 .6345 .23419 Metetra
.656 .751 .92 r
.6345 .23419 .6401 .24157 .65144 .23758 .64587 .23017 Metetra
.656 .751 .92 r
.64587 .23017 .65144 .23758 .66282 .23358 .65729 .22614 Metetra
.656 .751 .92 r
.65729 .22614 .66282 .23358 .67425 .22955 .66875 .22208 Metetra
.656 .751 .92 r
.66875 .22208 .67425 .22955 .68573 .22551 .68026 .21801 Metetra
.656 .751 .92 r
.68026 .21801 .68573 .22551 .69725 .22146 .69181 .21393 Metetra
.656 .751 .92 r
.69181 .21393 .69725 .22146 .70882 .21739 .70341 .20983 Metetra
.656 .751 .92 r
.70341 .20983 .70882 .21739 .72044 .2133 .71506 .20571 Metetra
.656 .751 .92 r
.71506 .20571 .72044 .2133 .7321 .20919 .72676 .20157 Metetra
.656 .751 .92 r
.72676 .20157 .7321 .20919 .74381 .20507 .73851 .19742 Metetra
.656 .751 .92 r
.73851 .19742 .74381 .20507 .75557 .20093 .7503 .19325 Metetra
.631 .609 .81 r
.0845 .42 .09074 .43125 .10068 .42296 .09377 .41687 Metetra
.656 .751 .92 r
.09377 .41687 .10068 .42296 .10998 .41967 .10309 .41356 Metetra
.656 .751 .92 r
.10309 .41356 .10998 .41967 .11932 .41636 .11245 .41023 Metetra
.656 .751 .92 r
.11245 .41023 .11932 .41636 .1287 .41305 .12185 .4069 Metetra
.656 .751 .92 r
.12185 .4069 .1287 .41305 .13811 .40972 .13127 .40355 Metetra
.656 .751 .92 r
.13127 .40355 .13811 .40972 .14755 .40638 .14074 .40018 Metetra
.656 .751 .92 r
.14074 .40018 .14755 .40638 .15703 .40303 .15024 .39681 Metetra
.656 .751 .92 r
.15024 .39681 .15703 .40303 .16654 .39967 .15977 .39342 Metetra
.656 .751 .92 r
.15977 .39342 .16654 .39967 .17609 .39629 .16934 .39002 Metetra
.656 .751 .92 r
.16934 .39002 .17609 .39629 .18568 .3929 .17895 .38661 Metetra
.656 .751 .92 r
.17895 .38661 .18568 .3929 .1953 .3895 .18859 .38318 Metetra
.656 .751 .92 r
.18859 .38318 .1953 .3895 .20495 .38608 .19826 .37975 Metetra
.656 .751 .92 r
.19826 .37975 .20495 .38608 .21465 .38266 .20798 .37629 Metetra
.656 .751 .92 r
.20798 .37629 .21465 .38266 .22438 .37922 .21773 .37283 Metetra
.656 .751 .92 r
.21773 .37283 .22438 .37922 .23414 .37576 .22751 .36935 Metetra
.656 .751 .92 r
.22751 .36935 .23414 .37576 .24394 .3723 .23734 .36586 Metetra
.656 .751 .92 r
.23734 .36586 .24394 .3723 .25378 .36882 .2472 .36236 Metetra
.656 .751 .92 r
.2472 .36236 .25378 .36882 .26366 .36532 .2571 .35884 Metetra
.656 .751 .92 r
.2571 .35884 .26366 .36532 .27357 .36182 .26703 .35531 Metetra
.656 .751 .92 r
.26703 .35531 .27357 .36182 .28352 .3583 .27701 .35177 Metetra
.656 .751 .92 r
.27701 .35177 .28352 .3583 .29351 .35477 .28702 .34821 Metetra
.656 .751 .92 r
.28702 .34821 .29351 .35477 .30354 .35122 .29707 .34464 Metetra
.656 .751 .92 r
.29707 .34464 .30354 .35122 .31361 .34766 .30716 .34106 Metetra
.656 .751 .92 r
.30716 .34106 .31361 .34766 .32371 .34409 .31729 .33746 Metetra
.656 .751 .92 r
.31729 .33746 .32371 .34409 .33385 .3405 .32745 .33385 Metetra
.656 .751 .92 r
.32745 .33385 .33385 .3405 .34403 .3369 .33766 .33022 Metetra
.656 .751 .92 r
.33766 .33022 .34403 .3369 .35426 .33329 .3479 .32658 Metetra
.656 .751 .92 r
.3479 .32658 .35426 .33329 .36452 .32966 .35819 .32293 Metetra
.656 .751 .92 r
.35819 .32293 .36452 .32966 .37481 .32602 .36851 .31926 Metetra
.656 .751 .92 r
.36851 .31926 .37481 .32602 .38515 .32236 .37888 .31558 Metetra
.656 .751 .92 r
.37888 .31558 .38515 .32236 .39553 .31869 .38928 .31188 Metetra
.656 .751 .92 r
.38928 .31188 .39553 .31869 .40595 .31501 .39972 .30817 Metetra
.656 .751 .92 r
.39972 .30817 .40595 .31501 .41641 .31131 .41021 .30444 Metetra
.656 .751 .92 r
.41021 .30444 .41641 .31131 .42691 .3076 .42074 .3007 Metetra
.656 .751 .92 r
.42074 .3007 .42691 .3076 .43746 .30387 .43131 .29695 Metetra
.656 .751 .92 r
.43131 .29695 .43746 .30387 .44804 .30013 .44191 .29318 Metetra
.656 .751 .92 r
.44191 .29318 .44804 .30013 .45866 .29637 .45257 .2894 Metetra
.656 .751 .92 r
.45257 .2894 .45866 .29637 .46933 .2926 .46326 .2856 Metetra
.656 .751 .92 r
.46326 .2856 .46933 .2926 .48004 .28881 .47399 .28178 Metetra
.656 .751 .92 r
.47399 .28178 .48004 .28881 .49079 .28501 .48477 .27795 Metetra
.656 .751 .92 r
.48477 .27795 .49079 .28501 .50158 .28119 .49559 .27411 Metetra
.656 .751 .92 r
.49559 .27411 .50158 .28119 .51242 .27736 .50646 .27025 Metetra
.656 .751 .92 r
.50646 .27025 .51242 .27736 .5233 .27352 .51736 .26637 Metetra
.656 .751 .92 r
.51736 .26637 .5233 .27352 .53422 .26965 .52831 .26248 Metetra
.656 .751 .92 r
.52831 .26248 .53422 .26965 .54518 .26578 .53931 .25858 Metetra
.656 .751 .92 r
.53931 .25858 .54518 .26578 .55619 .26188 .55035 .25466 Metetra
.656 .751 .92 r
.55035 .25466 .55619 .26188 .56725 .25798 .56143 .25072 Metetra
.656 .751 .92 r
.56143 .25072 .56725 .25798 .57834 .25405 .57255 .24677 Metetra
.656 .751 .92 r
.57255 .24677 .57834 .25405 .58949 .25011 .58373 .2428 Metetra
.656 .751 .92 r
.58373 .2428 .58949 .25011 .60067 .24616 .59494 .23881 Metetra
.656 .751 .92 r
.59494 .23881 .60067 .24616 .6119 .24218 .60621 .23481 Metetra
.656 .751 .92 r
.60621 .23481 .6119 .24218 .62318 .2382 .61751 .23079 Metetra
.656 .751 .92 r
.61751 .23079 .62318 .2382 .6345 .23419 .62887 .22676 Metetra
.656 .751 .92 r
.62887 .22676 .6345 .23419 .64587 .23017 .64027 .22271 Metetra
.656 .751 .92 r
.64027 .22271 .64587 .23017 .65729 .22614 .65171 .21864 Metetra
.656 .751 .92 r
.65171 .21864 .65729 .22614 .66875 .22208 .66321 .21456 Metetra
.656 .751 .92 r
.66321 .21456 .66875 .22208 .68026 .21801 .67475 .21046 Metetra
.656 .751 .92 r
.67475 .21046 .68026 .21801 .69181 .21393 .68633 .20634 Metetra
.656 .751 .92 r
.68633 .20634 .69181 .21393 .70341 .20983 .69797 .20221 Metetra
.656 .751 .92 r
.69797 .20221 .70341 .20983 .71506 .20571 .70965 .19806 Metetra
.656 .751 .92 r
.70965 .19806 .71506 .20571 .72676 .20157 .72138 .19389 Metetra
.656 .751 .92 r
.72138 .19389 .72676 .20157 .73851 .19742 .73316 .1897 Metetra
.656 .751 .92 r
.73316 .1897 .73851 .19742 .7503 .19325 .74499 .1855 Metetra
.316 .405 .795 r
.07849 .40693 .0845 .42 .09377 .41687 .08681 .41075 Metetra
.656 .751 .92 r
.08681 .41075 .09377 .41687 .10309 .41356 .09616 .40741 Metetra
.656 .751 .92 r
.09616 .40741 .10309 .41356 .11245 .41023 .10553 .40406 Metetra
.656 .751 .92 r
.10553 .40406 .11245 .41023 .12185 .4069 .11495 .4007 Metetra
.656 .751 .92 r
.11495 .4007 .12185 .4069 .13127 .40355 .1244 .39733 Metetra
.656 .751 .92 r
.1244 .39733 .13127 .40355 .14074 .40018 .13388 .39394 Metetra
.656 .751 .92 r
.13388 .39394 .14074 .40018 .15024 .39681 .1434 .39055 Metetra
.656 .751 .92 r
.1434 .39055 .15024 .39681 .15977 .39342 .15295 .38714 Metetra
.656 .751 .92 r
.15295 .38714 .15977 .39342 .16934 .39002 .16254 .38371 Metetra
.656 .751 .92 r
.16254 .38371 .16934 .39002 .17895 .38661 .17217 .38028 Metetra
.656 .751 .92 r
.17217 .38028 .17895 .38661 .18859 .38318 .18183 .37683 Metetra
.656 .751 .92 r
.18183 .37683 .18859 .38318 .19826 .37975 .19153 .37336 Metetra
.656 .751 .92 r
.19153 .37336 .19826 .37975 .20798 .37629 .20126 .36989 Metetra
.656 .751 .92 r
.20126 .36989 .20798 .37629 .21773 .37283 .21103 .3664 Metetra
.656 .751 .92 r
.21103 .3664 .21773 .37283 .22751 .36935 .22084 .3629 Metetra
.656 .751 .92 r
.22084 .3629 .22751 .36935 .23734 .36586 .23069 .35938 Metetra
.656 .751 .92 r
.23069 .35938 .23734 .36586 .2472 .36236 .24057 .35586 Metetra
.656 .751 .92 r
.24057 .35586 .2472 .36236 .2571 .35884 .25049 .35232 Metetra
.656 .751 .92 r
.25049 .35232 .2571 .35884 .26703 .35531 .26045 .34876 Metetra
.656 .751 .92 r
.26045 .34876 .26703 .35531 .27701 .35177 .27045 .34519 Metetra
.656 .751 .92 r
.27045 .34519 .27701 .35177 .28702 .34821 .28048 .34161 Metetra
.656 .751 .92 r
.28048 .34161 .28702 .34821 .29707 .34464 .29055 .33801 Metetra
.656 .751 .92 r
.29055 .33801 .29707 .34464 .30716 .34106 .30067 .3344 Metetra
.656 .751 .92 r
.30067 .3344 .30716 .34106 .31729 .33746 .31082 .33078 Metetra
.656 .751 .92 r
.31082 .33078 .31729 .33746 .32745 .33385 .32101 .32714 Metetra
.656 .751 .92 r
.32101 .32714 .32745 .33385 .33766 .33022 .33124 .32349 Metetra
.656 .751 .92 r
.33124 .32349 .33766 .33022 .3479 .32658 .34151 .31982 Metetra
.656 .751 .92 r
.34151 .31982 .3479 .32658 .35819 .32293 .35181 .31614 Metetra
.656 .751 .92 r
.35181 .31614 .35819 .32293 .36851 .31926 .36216 .31245 Metetra
.656 .751 .92 r
.36216 .31245 .36851 .31926 .37888 .31558 .37255 .30874 Metetra
.656 .751 .92 r
.37255 .30874 .37888 .31558 .38928 .31188 .38298 .30502 Metetra
.656 .751 .92 r
.38298 .30502 .38928 .31188 .39972 .30817 .39345 .30128 Metetra
.656 .751 .92 r
.39345 .30128 .39972 .30817 .41021 .30444 .40396 .29753 Metetra
.656 .751 .92 r
.40396 .29753 .41021 .30444 .42074 .3007 .41452 .29376 Metetra
.656 .751 .92 r
.41452 .29376 .42074 .3007 .43131 .29695 .42511 .28998 Metetra
.656 .751 .92 r
.42511 .28998 .43131 .29695 .44191 .29318 .43575 .28618 Metetra
.656 .751 .92 r
.43575 .28618 .44191 .29318 .45257 .2894 .44642 .28237 Metetra
.656 .751 .92 r
.44642 .28237 .45257 .2894 .46326 .2856 .45714 .27854 Metetra
.656 .751 .92 r
.45714 .27854 .46326 .2856 .47399 .28178 .46791 .2747 Metetra
.656 .751 .92 r
.46791 .2747 .47399 .28178 .48477 .27795 .47871 .27084 Metetra
.656 .751 .92 r
.47871 .27084 .48477 .27795 .49559 .27411 .48956 .26697 Metetra
.656 .751 .92 r
.48956 .26697 .49559 .27411 .50646 .27025 .50045 .26308 Metetra
.656 .751 .92 r
.50045 .26308 .50646 .27025 .51736 .26637 .51139 .25918 Metetra
.656 .751 .92 r
.51139 .25918 .51736 .26637 .52831 .26248 .52236 .25526 Metetra
.656 .751 .92 r
.52236 .25526 .52831 .26248 .53931 .25858 .53339 .25133 Metetra
.656 .751 .92 r
.53339 .25133 .53931 .25858 .55035 .25466 .54445 .24737 Metetra
.656 .751 .92 r
.54445 .24737 .55035 .25466 .56143 .25072 .55557 .24341 Metetra
.656 .751 .92 r
.55557 .24341 .56143 .25072 .57255 .24677 .56672 .23942 Metetra
.656 .751 .92 r
.56672 .23942 .57255 .24677 .58373 .2428 .57792 .23543 Metetra
.656 .751 .92 r
.57792 .23543 .58373 .2428 .59494 .23881 .58917 .23141 Metetra
.656 .751 .92 r
.58917 .23141 .59494 .23881 .60621 .23481 .60046 .22738 Metetra
.656 .751 .92 r
.60046 .22738 .60621 .23481 .61751 .23079 .6118 .22333 Metetra
.656 .751 .92 r
.6118 .22333 .61751 .23079 .62887 .22676 .62319 .21927 Metetra
.656 .751 .92 r
.62319 .21927 .62887 .22676 .64027 .22271 .63462 .21519 Metetra
.656 .751 .92 r
.63462 .21519 .64027 .22271 .65171 .21864 .6461 .21109 Metetra
.656 .751 .92 r
.6461 .21109 .65171 .21864 .66321 .21456 .65762 .20698 Metetra
.656 .751 .92 r
.65762 .20698 .66321 .21456 .67475 .21046 .66919 .20284 Metetra
.656 .751 .92 r
.66919 .20284 .67475 .21046 .68633 .20634 .68081 .1987 Metetra
.656 .751 .92 r
.68081 .1987 .68633 .20634 .69797 .20221 .69248 .19453 Metetra
.656 .751 .92 r
.69248 .19453 .69797 .20221 .70965 .19806 .7042 .19035 Metetra
.656 .751 .92 r
.7042 .19035 .70965 .19806 .72138 .19389 .71596 .18615 Metetra
.656 .751 .92 r
.71596 .18615 .72138 .19389 .73316 .1897 .72778 .18193 Metetra
.656 .751 .92 r
.72778 .18193 .73316 .1897 .74499 .1855 .73964 .1777 Metetra
.615 .824 .423 r
.06863 .42105 .07849 .40693 .08681 .41075 .07981 .40458 Metetra
.656 .751 .92 r
.07981 .40458 .08681 .41075 .09616 .40741 .08917 .40122 Metetra
.656 .751 .92 r
.08917 .40122 .09616 .40741 .10553 .40406 .09857 .39785 Metetra
.656 .751 .92 r
.09857 .39785 .10553 .40406 .11495 .4007 .108 .39447 Metetra
.656 .751 .92 r
.108 .39447 .11495 .4007 .1244 .39733 .11747 .39107 Metetra
.656 .751 .92 r
.11747 .39107 .1244 .39733 .13388 .39394 .12697 .38766 Metetra
.656 .751 .92 r
.12697 .38766 .13388 .39394 .1434 .39055 .13651 .38424 Metetra
.656 .751 .92 r
.13651 .38424 .1434 .39055 .15295 .38714 .14608 .38081 Metetra
.656 .751 .92 r
.14608 .38081 .15295 .38714 .16254 .38371 .1557 .37736 Metetra
.656 .751 .92 r
.1557 .37736 .16254 .38371 .17217 .38028 .16534 .3739 Metetra
.656 .751 .92 r
.16534 .3739 .17217 .38028 .18183 .37683 .17502 .37042 Metetra
.656 .751 .92 r
.17502 .37042 .18183 .37683 .19153 .37336 .18474 .36694 Metetra
.656 .751 .92 r
.18474 .36694 .19153 .37336 .20126 .36989 .1945 .36344 Metetra
.656 .751 .92 r
.1945 .36344 .20126 .36989 .21103 .3664 .20429 .35993 Metetra
.656 .751 .92 r
.20429 .35993 .21103 .3664 .22084 .3629 .21412 .3564 Metetra
.656 .751 .92 r
.21412 .3564 .22084 .3629 .23069 .35938 .22399 .35286 Metetra
.656 .751 .92 r
.22399 .35286 .23069 .35938 .24057 .35586 .23389 .34931 Metetra
.656 .751 .92 r
.23389 .34931 .24057 .35586 .25049 .35232 .24384 .34574 Metetra
.656 .751 .92 r
.24384 .34574 .25049 .35232 .26045 .34876 .25382 .34216 Metetra
.656 .751 .92 r
.25382 .34216 .26045 .34876 .27045 .34519 .26384 .33857 Metetra
.656 .751 .92 r
.26384 .33857 .27045 .34519 .28048 .34161 .2739 .33496 Metetra
.656 .751 .92 r
.2739 .33496 .28048 .34161 .29055 .33801 .28399 .33134 Metetra
.656 .751 .92 r
.28399 .33134 .29055 .33801 .30067 .3344 .29413 .3277 Metetra
.656 .751 .92 r
.29413 .3277 .30067 .3344 .31082 .33078 .3043 .32405 Metetra
.656 .751 .92 r
.3043 .32405 .31082 .33078 .32101 .32714 .31452 .32039 Metetra
.656 .751 .92 r
.31452 .32039 .32101 .32714 .33124 .32349 .32477 .31671 Metetra
.656 .751 .92 r
.32477 .31671 .33124 .32349 .34151 .31982 .33506 .31302 Metetra
.656 .751 .92 r
.33506 .31302 .34151 .31982 .35181 .31614 .34539 .30931 Metetra
.656 .751 .92 r
.34539 .30931 .35181 .31614 .36216 .31245 .35577 .30559 Metetra
.656 .751 .92 r
.35577 .30559 .36216 .31245 .37255 .30874 .36618 .30186 Metetra
.656 .751 .92 r
.36618 .30186 .37255 .30874 .38298 .30502 .37664 .29811 Metetra
.656 .751 .92 r
.37664 .29811 .38298 .30502 .39345 .30128 .38713 .29434 Metetra
.656 .751 .92 r
.38713 .29434 .39345 .30128 .40396 .29753 .39767 .29056 Metetra
.656 .751 .92 r
.39767 .29056 .40396 .29753 .41452 .29376 .40825 .28677 Metetra
.656 .751 .92 r
.40825 .28677 .41452 .29376 .42511 .28998 .41887 .28296 Metetra
.656 .751 .92 r
.41887 .28296 .42511 .28998 .43575 .28618 .42953 .27913 Metetra
.656 .751 .92 r
.42953 .27913 .43575 .28618 .44642 .28237 .44024 .27529 Metetra
.656 .751 .92 r
.44024 .27529 .44642 .28237 .45714 .27854 .45098 .27144 Metetra
.656 .751 .92 r
.45098 .27144 .45714 .27854 .46791 .2747 .46177 .26757 Metetra
.656 .751 .92 r
.46177 .26757 .46791 .2747 .47871 .27084 .47261 .26368 Metetra
.656 .751 .92 r
.47261 .26368 .47871 .27084 .48956 .26697 .48348 .25978 Metetra
.656 .751 .92 r
.48348 .25978 .48956 .26697 .50045 .26308 .4944 .25586 Metetra
.656 .751 .92 r
.4944 .25586 .50045 .26308 .51139 .25918 .50536 .25193 Metetra
.656 .751 .92 r
.50536 .25193 .51139 .25918 .52236 .25526 .51637 .24798 Metetra
.656 .751 .92 r
.51637 .24798 .52236 .25526 .53339 .25133 .52742 .24402 Metetra
.656 .751 .92 r
.52742 .24402 .53339 .25133 .54445 .24737 .53852 .24004 Metetra
.656 .751 .92 r
.53852 .24004 .54445 .24737 .55557 .24341 .54966 .23604 Metetra
.656 .751 .92 r
.54966 .23604 .55557 .24341 .56672 .23942 .56085 .23203 Metetra
.656 .751 .92 r
.56085 .23203 .56672 .23942 .57792 .23543 .57208 .228 Metetra
.656 .751 .92 r
.57208 .228 .57792 .23543 .58917 .23141 .58336 .22396 Metetra
.656 .751 .92 r
.58336 .22396 .58917 .23141 .60046 .22738 .59468 .21989 Metetra
.656 .751 .92 r
.59468 .21989 .60046 .22738 .6118 .22333 .60605 .21582 Metetra
.656 .751 .92 r
.60605 .21582 .6118 .22333 .62319 .21927 .61746 .21172 Metetra
.656 .751 .92 r
.61746 .21172 .62319 .21927 .63462 .21519 .62893 .20761 Metetra
.656 .751 .92 r
.62893 .20761 .63462 .21519 .6461 .21109 .64044 .20348 Metetra
.656 .751 .92 r
.64044 .20348 .6461 .21109 .65762 .20698 .65199 .19934 Metetra
.656 .751 .92 r
.65199 .19934 .65762 .20698 .66919 .20284 .6636 .19517 Metetra
.656 .751 .92 r
.6636 .19517 .66919 .20284 .68081 .1987 .67525 .19099 Metetra
.656 .751 .92 r
.67525 .19099 .68081 .1987 .69248 .19453 .68695 .1868 Metetra
.656 .751 .92 r
.68695 .1868 .69248 .19453 .7042 .19035 .6987 .18258 Metetra
.656 .751 .92 r
.6987 .18258 .7042 .19035 .71596 .18615 .7105 .17835 Metetra
.656 .751 .92 r
.7105 .17835 .71596 .18615 .72778 .18193 .72235 .1741 Metetra
.656 .751 .92 r
.72235 .1741 .72778 .18193 .73964 .1777 .73425 .16983 Metetra
.323 .237 .602 r
.06519 .38929 .06863 .42105 .07981 .40458 .07276 .39837 Metetra
.656 .751 .92 r
.07276 .39837 .07981 .40458 .08917 .40122 .08214 .39499 Metetra
.656 .751 .92 r
.08214 .39499 .08917 .40122 .09857 .39785 .09156 .39159 Metetra
.656 .751 .92 r
.09156 .39159 .09857 .39785 .108 .39447 .10101 .38819 Metetra
.656 .751 .92 r
.10101 .38819 .108 .39447 .11747 .39107 .1105 .38477 Metetra
.656 .751 .92 r
.1105 .38477 .11747 .39107 .12697 .38766 .12002 .38133 Metetra
.656 .751 .92 r
.12002 .38133 .12697 .38766 .13651 .38424 .12958 .37789 Metetra
.656 .751 .92 r
.12958 .37789 .13651 .38424 .14608 .38081 .13917 .37443 Metetra
.656 .751 .92 r
.13917 .37443 .14608 .38081 .1557 .37736 .1488 .37096 Metetra
.656 .751 .92 r
.1488 .37096 .1557 .37736 .16534 .3739 .15847 .36748 Metetra
.656 .751 .92 r
.15847 .36748 .16534 .3739 .17502 .37042 .16817 .36398 Metetra
.656 .751 .92 r
.16817 .36398 .17502 .37042 .18474 .36694 .17791 .36047 Metetra
.656 .751 .92 r
.17791 .36047 .18474 .36694 .1945 .36344 .18769 .35694 Metetra
.656 .751 .92 r
.18769 .35694 .1945 .36344 .20429 .35993 .1975 .35341 Metetra
.656 .751 .92 r
.1975 .35341 .20429 .35993 .21412 .3564 .20736 .34986 Metetra
.656 .751 .92 r
.20736 .34986 .21412 .3564 .22399 .35286 .21724 .34629 Metetra
.656 .751 .92 r
.21724 .34629 .22399 .35286 .23389 .34931 .22717 .34271 Metetra
.656 .751 .92 r
.22717 .34271 .23389 .34931 .24384 .34574 .23714 .33912 Metetra
.656 .751 .92 r
.23714 .33912 .24384 .34574 .25382 .34216 .24714 .33552 Metetra
.656 .751 .92 r
.24714 .33552 .25382 .34216 .26384 .33857 .25718 .3319 Metetra
.656 .751 .92 r
.25718 .3319 .26384 .33857 .2739 .33496 .26726 .32826 Metetra
.656 .751 .92 r
.26726 .32826 .2739 .33496 .28399 .33134 .27738 .32462 Metetra
.656 .751 .92 r
.27738 .32462 .28399 .33134 .29413 .3277 .28754 .32095 Metetra
.656 .751 .92 r
.28754 .32095 .29413 .3277 .3043 .32405 .29774 .31728 Metetra
.656 .751 .92 r
.29774 .31728 .3043 .32405 .31452 .32039 .30798 .31359 Metetra
.656 .751 .92 r
.30798 .31359 .31452 .32039 .32477 .31671 .31825 .30988 Metetra
.656 .751 .92 r
.31825 .30988 .32477 .31671 .33506 .31302 .32857 .30617 Metetra
.656 .751 .92 r
.32857 .30617 .33506 .31302 .34539 .30931 .33893 .30243 Metetra
.656 .751 .92 r
.33893 .30243 .34539 .30931 .35577 .30559 .34933 .29868 Metetra
.656 .751 .92 r
.34933 .29868 .35577 .30559 .36618 .30186 .35977 .29492 Metetra
.656 .751 .92 r
.35977 .29492 .36618 .30186 .37664 .29811 .37025 .29114 Metetra
.656 .751 .92 r
.37025 .29114 .37664 .29811 .38713 .29434 .38077 .28735 Metetra
.656 .751 .92 r
.38077 .28735 .38713 .29434 .39767 .29056 .39133 .28354 Metetra
.656 .751 .92 r
.39133 .28354 .39767 .29056 .40825 .28677 .40194 .27972 Metetra
.656 .751 .92 r
.40194 .27972 .40825 .28677 .41887 .28296 .41258 .27588 Metetra
.656 .751 .92 r
.41258 .27588 .41887 .28296 .42953 .27913 .42327 .27203 Metetra
.656 .751 .92 r
.42327 .27203 .42953 .27913 .44024 .27529 .434 .26816 Metetra
.656 .751 .92 r
.434 .26816 .44024 .27529 .45098 .27144 .44478 .26428 Metetra
.656 .751 .92 r
.44478 .26428 .45098 .27144 .46177 .26757 .45559 .26038 Metetra
.656 .751 .92 r
.45559 .26038 .46177 .26757 .47261 .26368 .46645 .25647 Metetra
.656 .751 .92 r
.46645 .25647 .47261 .26368 .48348 .25978 .47736 .25254 Metetra
.656 .751 .92 r
.47736 .25254 .48348 .25978 .4944 .25586 .48831 .24859 Metetra
.656 .751 .92 r
.48831 .24859 .4944 .25586 .50536 .25193 .4993 .24463 Metetra
.656 .751 .92 r
.4993 .24463 .50536 .25193 .51637 .24798 .51033 .24065 Metetra
.656 .751 .92 r
.51033 .24065 .51637 .24798 .52742 .24402 .52141 .23666 Metetra
.656 .751 .92 r
.52141 .23666 .52742 .24402 .53852 .24004 .53254 .23265 Metetra
.656 .751 .92 r
.53254 .23265 .53852 .24004 .54966 .23604 .54371 .22862 Metetra
.656 .751 .92 r
.54371 .22862 .54966 .23604 .56085 .23203 .55493 .22458 Metetra
.656 .751 .92 r
.55493 .22458 .56085 .23203 .57208 .228 .56619 .22052 Metetra
.656 .751 .92 r
.56619 .22052 .57208 .228 .58336 .22396 .5775 .21644 Metetra
.656 .751 .92 r
.5775 .21644 .58336 .22396 .59468 .21989 .58885 .21235 Metetra
.656 .751 .92 r
.58885 .21235 .59468 .21989 .60605 .21582 .60025 .20824 Metetra
.656 .751 .92 r
.60025 .20824 .60605 .21582 .61746 .21172 .6117 .20412 Metetra
.656 .751 .92 r
.6117 .20412 .61746 .21172 .62893 .20761 .62319 .19997 Metetra
.656 .751 .92 r
.62319 .19997 .62893 .20761 .64044 .20348 .63473 .19581 Metetra
.656 .751 .92 r
.63473 .19581 .64044 .20348 .65199 .19934 .64632 .19164 Metetra
.656 .751 .92 r
.64632 .19164 .65199 .19934 .6636 .19517 .65796 .18744 Metetra
.656 .751 .92 r
.65796 .18744 .6636 .19517 .67525 .19099 .66965 .18323 Metetra
.656 .751 .92 r
.66965 .18323 .67525 .19099 .68695 .1868 .68138 .179 Metetra
.656 .751 .92 r
.68138 .179 .68695 .1868 .6987 .18258 .69317 .17475 Metetra
.656 .751 .92 r
.69317 .17475 .6987 .18258 .7105 .17835 .705 .17049 Metetra
.656 .751 .92 r
.705 .17049 .7105 .17835 .72235 .1741 .71688 .16621 Metetra
.656 .751 .92 r
.71688 .16621 .72235 .1741 .73425 .16983 .72881 .16191 Metetra
.05609 .39689 .06519 .38929 .07276 .39837 .06566 .39212 Metetra
.656 .751 .92 r
.06566 .39212 .07276 .39837 .08214 .39499 .07506 .38871 Metetra
.656 .751 .92 r
.07506 .38871 .08214 .39499 .09156 .39159 .0845 .38529 Metetra
.656 .751 .92 r
.0845 .38529 .09156 .39159 .10101 .38819 .09397 .38186 Metetra
.656 .751 .92 r
.09397 .38186 .10101 .38819 .1105 .38477 .10347 .37842 Metetra
.656 .751 .92 r
.10347 .37842 .1105 .38477 .12002 .38133 .11302 .37496 Metetra
.656 .751 .92 r
.11302 .37496 .12002 .38133 .12958 .37789 .12259 .37149 Metetra
.656 .751 .92 r
.12259 .37149 .12958 .37789 .13917 .37443 .13221 .36801 Metetra
.656 .751 .92 r
.13221 .36801 .13917 .37443 .1488 .37096 .14186 .36452 Metetra
.656 .751 .92 r
.14186 .36452 .1488 .37096 .15847 .36748 .15155 .36101 Metetra
.656 .751 .92 r
.15155 .36101 .15847 .36748 .16817 .36398 .16127 .35749 Metetra
.656 .751 .92 r
.16127 .35749 .16817 .36398 .17791 .36047 .17103 .35395 Metetra
.656 .751 .92 r
.17103 .35395 .17791 .36047 .18769 .35694 .18083 .3504 Metetra
.656 .751 .92 r
.18083 .3504 .18769 .35694 .1975 .35341 .19067 .34684 Metetra
.656 .751 .92 r
.19067 .34684 .1975 .35341 .20736 .34986 .20054 .34326 Metetra
.656 .751 .92 r
.20054 .34326 .20736 .34986 .21724 .34629 .21045 .33967 Metetra
.656 .751 .92 r
.21045 .33967 .21724 .34629 .22717 .34271 .2204 .33607 Metetra
.656 .751 .92 r
.2204 .33607 .22717 .34271 .23714 .33912 .23039 .33245 Metetra
.656 .751 .92 r
.23039 .33245 .23714 .33912 .24714 .33552 .24041 .32882 Metetra
.656 .751 .92 r
.24041 .32882 .24714 .33552 .25718 .3319 .25048 .32518 Metetra
.656 .751 .92 r
.25048 .32518 .25718 .3319 .26726 .32826 .26058 .32152 Metetra
.656 .751 .92 r
.26058 .32152 .26726 .32826 .27738 .32462 .27073 .31784 Metetra
.656 .751 .92 r
.27073 .31784 .27738 .32462 .28754 .32095 .28091 .31416 Metetra
.656 .751 .92 r
.28091 .31416 .28754 .32095 .29774 .31728 .29113 .31045 Metetra
.656 .751 .92 r
.29113 .31045 .29774 .31728 .30798 .31359 .30139 .30674 Metetra
.656 .751 .92 r
.30139 .30674 .30798 .31359 .31825 .30988 .31169 .30301 Metetra
.656 .751 .92 r
.31169 .30301 .31825 .30988 .32857 .30617 .32203 .29926 Metetra
.656 .751 .92 r
.32203 .29926 .32857 .30617 .33893 .30243 .33242 .2955 Metetra
.656 .751 .92 r
.33242 .2955 .33893 .30243 .34933 .29868 .34284 .29173 Metetra
.656 .751 .92 r
.34284 .29173 .34933 .29868 .35977 .29492 .3533 .28794 Metetra
.656 .751 .92 r
.3533 .28794 .35977 .29492 .37025 .29114 .36381 .28413 Metetra
.656 .751 .92 r
.36381 .28413 .37025 .29114 .38077 .28735 .37436 .28031 Metetra
.656 .751 .92 r
.37436 .28031 .38077 .28735 .39133 .28354 .38495 .27648 Metetra
.656 .751 .92 r
.38495 .27648 .39133 .28354 .40194 .27972 .39558 .27263 Metetra
.656 .751 .92 r
.39558 .27263 .40194 .27972 .41258 .27588 .40625 .26876 Metetra
.656 .751 .92 r
.40625 .26876 .41258 .27588 .42327 .27203 .41697 .26488 Metetra
.656 .751 .92 r
.41697 .26488 .42327 .27203 .434 .26816 .42772 .26098 Metetra
.656 .751 .92 r
.42772 .26098 .434 .26816 .44478 .26428 .43853 .25707 Metetra
.656 .751 .92 r
.43853 .25707 .44478 .26428 .45559 .26038 .44937 .25314 Metetra
.656 .751 .92 r
.44937 .25314 .45559 .26038 .46645 .25647 .46026 .2492 Metetra
.656 .751 .92 r
.46026 .2492 .46645 .25647 .47736 .25254 .47119 .24524 Metetra
.656 .751 .92 r
.47119 .24524 .47736 .25254 .48831 .24859 .48217 .24127 Metetra
.656 .751 .92 r
.48217 .24127 .48831 .24859 .4993 .24463 .49319 .23727 Metetra
.656 .751 .92 r
.49319 .23727 .4993 .24463 .51033 .24065 .50425 .23327 Metetra
.656 .751 .92 r
.50425 .23327 .51033 .24065 .52141 .23666 .51536 .22924 Metetra
.656 .751 .92 r
.51536 .22924 .52141 .23666 .53254 .23265 .52652 .2252 Metetra
.656 .751 .92 r
.52652 .2252 .53254 .23265 .54371 .22862 .53772 .22115 Metetra
.656 .751 .92 r
.53772 .22115 .54371 .22862 .55493 .22458 .54896 .21707 Metetra
.656 .751 .92 r
.54896 .21707 .55493 .22458 .56619 .22052 .56026 .21298 Metetra
.656 .751 .92 r
.56026 .21298 .56619 .22052 .5775 .21644 .57159 .20888 Metetra
.656 .751 .92 r
.57159 .20888 .5775 .21644 .58885 .21235 .58298 .20475 Metetra
.656 .751 .92 r
.58298 .20475 .58885 .21235 .60025 .20824 .59441 .20061 Metetra
.656 .751 .92 r
.59441 .20061 .60025 .20824 .6117 .20412 .60589 .19646 Metetra
.656 .751 .92 r
.60589 .19646 .6117 .20412 .62319 .19997 .61742 .19228 Metetra
.656 .751 .92 r
.61742 .19228 .62319 .19997 .63473 .19581 .62899 .18809 Metetra
.656 .751 .92 r
.62899 .18809 .63473 .19581 .64632 .19164 .64061 .18388 Metetra
.656 .751 .92 r
.64061 .18388 .64632 .19164 .65796 .18744 .65228 .17965 Metetra
.656 .751 .92 r
.65228 .17965 .65796 .18744 .66965 .18323 .664 .17541 Metetra
.656 .751 .92 r
.664 .17541 .66965 .18323 .68138 .179 .67577 .17115 Metetra
.656 .751 .92 r
.67577 .17115 .68138 .179 .69317 .17475 .68759 .16687 Metetra
.656 .751 .92 r
.68759 .16687 .69317 .17475 .705 .17049 .69945 .16257 Metetra
.656 .751 .92 r
.69945 .16257 .705 .17049 .71688 .16621 .71137 .15825 Metetra
.656 .751 .92 r
.71137 .15825 .71688 .16621 .72881 .16191 .72333 .15392 Metetra
.917 .943 .589 r
.04597 .41053 .05609 .39689 .06566 .39212 .05851 .38582 Metetra
.656 .751 .92 r
.05851 .38582 .06566 .39212 .07506 .38871 .06793 .38239 Metetra
.656 .751 .92 r
.06793 .38239 .07506 .38871 .0845 .38529 .07738 .37895 Metetra
.656 .751 .92 r
.07738 .37895 .0845 .38529 .09397 .38186 .08688 .3755 Metetra
.656 .751 .92 r
.08688 .3755 .09397 .38186 .10347 .37842 .0964 .37203 Metetra
.656 .751 .92 r
.0964 .37203 .10347 .37842 .11302 .37496 .10596 .36855 Metetra
.656 .751 .92 r
.10596 .36855 .11302 .37496 .12259 .37149 .11556 .36506 Metetra
.656 .751 .92 r
.11556 .36506 .12259 .37149 .13221 .36801 .1252 .36155 Metetra
.656 .751 .92 r
.1252 .36155 .13221 .36801 .14186 .36452 .13487 .35803 Metetra
.656 .751 .92 r
.13487 .35803 .14186 .36452 .15155 .36101 .14458 .3545 Metetra
.656 .751 .92 r
.14458 .3545 .15155 .36101 .16127 .35749 .15432 .35095 Metetra
.656 .751 .92 r
.15432 .35095 .16127 .35749 .17103 .35395 .16411 .34739 Metetra
.656 .751 .92 r
.16411 .34739 .17103 .35395 .18083 .3504 .17393 .34382 Metetra
.656 .751 .92 r
.17393 .34382 .18083 .3504 .19067 .34684 .18378 .34023 Metetra
.656 .751 .92 r
.18378 .34023 .19067 .34684 .20054 .34326 .19368 .33663 Metetra
.656 .751 .92 r
.19368 .33663 .20054 .34326 .21045 .33967 .20361 .33301 Metetra
.656 .751 .92 r
.20361 .33301 .21045 .33967 .2204 .33607 .21358 .32938 Metetra
.656 .751 .92 r
.21358 .32938 .2204 .33607 .23039 .33245 .22359 .32574 Metetra
.656 .751 .92 r
.22359 .32574 .23039 .33245 .24041 .32882 .23364 .32208 Metetra
.656 .751 .92 r
.23364 .32208 .24041 .32882 .25048 .32518 .24373 .31841 Metetra
.656 .751 .92 r
.24373 .31841 .25048 .32518 .26058 .32152 .25386 .31473 Metetra
.656 .751 .92 r
.25386 .31473 .26058 .32152 .27073 .31784 .26402 .31103 Metetra
.656 .751 .92 r
.26402 .31103 .27073 .31784 .28091 .31416 .27423 .30731 Metetra
.656 .751 .92 r
.27423 .30731 .28091 .31416 .29113 .31045 .28447 .30358 Metetra
.656 .751 .92 r
.28447 .30358 .29113 .31045 .30139 .30674 .29476 .29984 Metetra
.656 .751 .92 r
.29476 .29984 .30139 .30674 .31169 .30301 .30508 .29608 Metetra
.656 .751 .92 r
.30508 .29608 .31169 .30301 .32203 .29926 .31545 .29231 Metetra
.656 .751 .92 r
.31545 .29231 .32203 .29926 .33242 .2955 .32586 .28852 Metetra
.656 .751 .92 r
.32586 .28852 .33242 .2955 .34284 .29173 .33631 .28472 Metetra
.656 .751 .92 r
.33631 .28472 .34284 .29173 .3533 .28794 .3468 .2809 Metetra
.656 .751 .92 r
.3468 .2809 .3533 .28794 .36381 .28413 .35733 .27707 Metetra
.656 .751 .92 r
.35733 .27707 .36381 .28413 .37436 .28031 .3679 .27322 Metetra
.656 .751 .92 r
.3679 .27322 .37436 .28031 .38495 .27648 .37851 .26936 Metetra
.656 .751 .92 r
.37851 .26936 .38495 .27648 .39558 .27263 .38917 .26548 Metetra
.656 .751 .92 r
.38917 .26548 .39558 .27263 .40625 .26876 .39987 .26158 Metetra
.656 .751 .92 r
.39987 .26158 .40625 .26876 .41697 .26488 .41061 .25767 Metetra
.656 .751 .92 r
.41061 .25767 .41697 .26488 .42772 .26098 .4214 .25375 Metetra
.656 .751 .92 r
.4214 .25375 .42772 .26098 .43853 .25707 .43223 .24981 Metetra
.656 .751 .92 r
.43223 .24981 .43853 .25707 .44937 .25314 .4431 .24585 Metetra
.656 .751 .92 r
.4431 .24585 .44937 .25314 .46026 .2492 .45402 .24188 Metetra
.656 .751 .92 r
.45402 .24188 .46026 .2492 .47119 .24524 .46498 .23789 Metetra
.656 .751 .92 r
.46498 .23789 .47119 .24524 .48217 .24127 .47598 .23388 Metetra
.656 .751 .92 r
.47598 .23388 .48217 .24127 .49319 .23727 .48703 .22986 Metetra
.656 .751 .92 r
.48703 .22986 .49319 .23727 .50425 .23327 .49812 .22582 Metetra
.656 .751 .92 r
.49812 .22582 .50425 .23327 .51536 .22924 .50926 .22177 Metetra
.656 .751 .92 r
.50926 .22177 .51536 .22924 .52652 .2252 .52045 .2177 Metetra
.656 .751 .92 r
.52045 .2177 .52652 .2252 .53772 .22115 .53168 .21361 Metetra
.656 .751 .92 r
.53168 .21361 .53772 .22115 .54896 .21707 .54295 .20951 Metetra
.656 .751 .92 r
.54295 .20951 .54896 .21707 .56026 .21298 .55428 .20539 Metetra
.656 .751 .92 r
.55428 .20539 .56026 .21298 .57159 .20888 .56565 .20125 Metetra
.656 .751 .92 r
.56565 .20125 .57159 .20888 .58298 .20475 .57706 .1971 Metetra
.656 .751 .92 r
.57706 .1971 .58298 .20475 .59441 .20061 .58852 .19292 Metetra
.656 .751 .92 r
.58852 .19292 .59441 .20061 .60589 .19646 .60003 .18873 Metetra
.656 .751 .92 r
.60003 .18873 .60589 .19646 .61742 .19228 .61159 .18453 Metetra
.656 .751 .92 r
.61159 .18453 .61742 .19228 .62899 .18809 .6232 .1803 Metetra
.656 .751 .92 r
.6232 .1803 .62899 .18809 .64061 .18388 .63485 .17606 Metetra
.656 .751 .92 r
.63485 .17606 .64061 .18388 .65228 .17965 .64656 .1718 Metetra
.656 .751 .92 r
.64656 .1718 .65228 .17965 .664 .17541 .65831 .16753 Metetra
.656 .751 .92 r
.65831 .16753 .664 .17541 .67577 .17115 .67011 .16323 Metetra
.656 .751 .92 r
.67011 .16323 .67577 .17115 .68759 .16687 .68196 .15892 Metetra
.656 .751 .92 r
.68196 .15892 .68759 .16687 .69945 .16257 .69386 .15459 Metetra
.656 .751 .92 r
.69386 .15459 .69945 .16257 .71137 .15825 .70581 .15024 Metetra
.656 .751 .92 r
.70581 .15024 .71137 .15825 .72333 .15392 .71781 .14587 Metetra
0 0 .348 r
.04957 .33205 .04597 .41053 .05851 .38582 .05131 .37948 Metetra
.656 .751 .92 r
.05131 .37948 .05851 .38582 .06793 .38239 .06075 .37603 Metetra
.656 .751 .92 r
.06075 .37603 .06793 .38239 .07738 .37895 .07023 .37256 Metetra
.656 .751 .92 r
.07023 .37256 .07738 .37895 .08688 .3755 .07974 .36909 Metetra
.656 .751 .92 r
.07974 .36909 .08688 .3755 .0964 .37203 .08928 .36559 Metetra
.656 .751 .92 r
.08928 .36559 .0964 .37203 .10596 .36855 .09886 .36209 Metetra
.656 .751 .92 r
.09886 .36209 .10596 .36855 .11556 .36506 .10848 .35857 Metetra
.656 .751 .92 r
.10848 .35857 .11556 .36506 .1252 .36155 .11814 .35504 Metetra
.656 .751 .92 r
.11814 .35504 .1252 .36155 .13487 .35803 .12783 .3515 Metetra
.656 .751 .92 r
.12783 .3515 .13487 .35803 .14458 .3545 .13756 .34794 Metetra
.656 .751 .92 r
.13756 .34794 .14458 .3545 .15432 .35095 .14733 .34437 Metetra
.656 .751 .92 r
.14733 .34437 .15432 .35095 .16411 .34739 .15713 .34078 Metetra
.656 .751 .92 r
.15713 .34078 .16411 .34739 .17393 .34382 .16697 .33718 Metetra
.656 .751 .92 r
.16697 .33718 .17393 .34382 .18378 .34023 .17685 .33357 Metetra
.656 .751 .92 r
.17685 .33357 .18378 .34023 .19368 .33663 .18677 .32994 Metetra
.656 .751 .92 r
.18677 .32994 .19368 .33663 .20361 .33301 .19672 .3263 Metetra
.656 .751 .92 r
.19672 .3263 .20361 .33301 .21358 .32938 .20672 .32265 Metetra
.656 .751 .92 r
.20672 .32265 .21358 .32938 .22359 .32574 .21675 .31898 Metetra
.656 .751 .92 r
.21675 .31898 .22359 .32574 .23364 .32208 .22682 .31529 Metetra
.656 .751 .92 r
.22682 .31529 .23364 .32208 .24373 .31841 .23693 .3116 Metetra
.656 .751 .92 r
.23693 .3116 .24373 .31841 .25386 .31473 .24708 .30788 Metetra
.656 .751 .92 r
.24708 .30788 .25386 .31473 .26402 .31103 .25727 .30416 Metetra
.656 .751 .92 r
.25727 .30416 .26402 .31103 .27423 .30731 .2675 .30042 Metetra
.656 .751 .92 r
.2675 .30042 .27423 .30731 .28447 .30358 .27777 .29666 Metetra
.656 .751 .92 r
.27777 .29666 .28447 .30358 .29476 .29984 .28808 .29289 Metetra
.656 .751 .92 r
.28808 .29289 .29476 .29984 .30508 .29608 .29843 .2891 Metetra
.656 .751 .92 r
.29843 .2891 .30508 .29608 .31545 .29231 .30882 .2853 Metetra
.656 .751 .92 r
.30882 .2853 .31545 .29231 .32586 .28852 .31925 .28149 Metetra
.656 .751 .92 r
.31925 .28149 .32586 .28852 .33631 .28472 .32972 .27766 Metetra
.656 .751 .92 r
.32972 .27766 .33631 .28472 .3468 .2809 .34024 .27381 Metetra
.656 .751 .92 r
.34024 .27381 .3468 .2809 .35733 .27707 .3508 .26995 Metetra
.656 .751 .92 r
.3508 .26995 .35733 .27707 .3679 .27322 .36139 .26608 Metetra
.656 .751 .92 r
.36139 .26608 .3679 .27322 .37851 .26936 .37204 .26218 Metetra
.656 .751 .92 r
.37204 .26218 .37851 .26936 .38917 .26548 .38272 .25828 Metetra
.656 .751 .92 r
.38272 .25828 .38917 .26548 .39987 .26158 .39344 .25435 Metetra
.656 .751 .92 r
.39344 .25435 .39987 .26158 .41061 .25767 .40421 .25041 Metetra
.656 .751 .92 r
.40421 .25041 .41061 .25767 .4214 .25375 .41503 .24646 Metetra
.656 .751 .92 r
.41503 .24646 .4214 .25375 .43223 .24981 .42588 .24249 Metetra
.656 .751 .92 r
.42588 .24249 .43223 .24981 .4431 .24585 .43678 .2385 Metetra
.656 .751 .92 r
.43678 .2385 .4431 .24585 .45402 .24188 .44773 .2345 Metetra
.656 .751 .92 r
.44773 .2345 .45402 .24188 .46498 .23789 .45872 .23048 Metetra
.656 .751 .92 r
.45872 .23048 .46498 .23789 .47598 .23388 .46975 .22645 Metetra
.656 .751 .92 r
.46975 .22645 .47598 .23388 .48703 .22986 .48083 .2224 Metetra
.656 .751 .92 r
.48083 .2224 .48703 .22986 .49812 .22582 .49195 .21833 Metetra
.656 .751 .92 r
.49195 .21833 .49812 .22582 .50926 .22177 .50312 .21424 Metetra
.656 .751 .92 r
.50312 .21424 .50926 .22177 .52045 .2177 .51433 .21014 Metetra
.656 .751 .92 r
.51433 .21014 .52045 .2177 .53168 .21361 .52559 .20602 Metetra
.656 .751 .92 r
.52559 .20602 .53168 .21361 .54295 .20951 .5369 .20189 Metetra
.656 .751 .92 r
.5369 .20189 .54295 .20951 .55428 .20539 .54825 .19774 Metetra
.656 .751 .92 r
.54825 .19774 .55428 .20539 .56565 .20125 .55965 .19357 Metetra
.656 .751 .92 r
.55965 .19357 .56565 .20125 .57706 .1971 .5711 .18938 Metetra
.656 .751 .92 r
.5711 .18938 .57706 .1971 .58852 .19292 .58259 .18518 Metetra
.656 .751 .92 r
.58259 .18518 .58852 .19292 .60003 .18873 .59414 .18096 Metetra
.656 .751 .92 r
.59414 .18096 .60003 .18873 .61159 .18453 .60573 .17672 Metetra
.656 .751 .92 r
.60573 .17672 .61159 .18453 .6232 .1803 .61736 .17246 Metetra
.656 .751 .92 r
.61736 .17246 .6232 .1803 .63485 .17606 .62905 .16819 Metetra
.656 .751 .92 r
.62905 .16819 .63485 .17606 .64656 .1718 .64079 .16389 Metetra
.656 .751 .92 r
.64079 .16389 .64656 .1718 .65831 .16753 .65257 .15958 Metetra
.656 .751 .92 r
.65257 .15958 .65831 .16753 .67011 .16323 .66441 .15525 Metetra
.656 .751 .92 r
.66441 .15525 .67011 .16323 .68196 .15892 .67629 .15091 Metetra
.656 .751 .92 r
.67629 .15091 .68196 .15892 .69386 .15459 .68823 .14654 Metetra
.656 .751 .92 r
.68823 .14654 .69386 .15459 .70581 .15024 .70022 .14216 Metetra
.656 .751 .92 r
.70022 .14216 .70581 .15024 .71781 .14587 .71225 .13776 Metetra
0 0 .16 r
.02157 .46184 .04957 .33205 .05131 .37948 .04406 .3731 Metetra
.656 .751 .92 r
.04406 .3731 .05131 .37948 .06075 .37603 .05352 .36962 Metetra
.656 .751 .92 r
.05352 .36962 .06075 .37603 .07023 .37256 .06302 .36613 Metetra
.656 .751 .92 r
.06302 .36613 .07023 .37256 .07974 .36909 .07255 .36263 Metetra
.656 .751 .92 r
.07255 .36263 .07974 .36909 .08928 .36559 .08211 .35911 Metetra
.656 .751 .92 r
.08211 .35911 .08928 .36559 .09886 .36209 .09171 .35558 Metetra
.656 .751 .92 r
.09171 .35558 .09886 .36209 .10848 .35857 .10135 .35204 Metetra
.656 .751 .92 r
.10135 .35204 .10848 .35857 .11814 .35504 .11103 .34849 Metetra
.656 .751 .92 r
.11103 .34849 .11814 .35504 .12783 .3515 .12074 .34492 Metetra
.656 .751 .92 r
.12074 .34492 .12783 .3515 .13756 .34794 .13049 .34133 Metetra
.656 .751 .92 r
.13049 .34133 .13756 .34794 .14733 .34437 .14028 .33774 Metetra
.656 .751 .92 r
.14028 .33774 .14733 .34437 .15713 .34078 .1501 .33413 Metetra
.656 .751 .92 r
.1501 .33413 .15713 .34078 .16697 .33718 .15997 .3305 Metetra
.656 .751 .92 r
.15997 .3305 .16697 .33718 .17685 .33357 .16987 .32686 Metetra
.656 .751 .92 r
.16987 .32686 .17685 .33357 .18677 .32994 .17981 .32321 Metetra
.656 .751 .92 r
.17981 .32321 .18677 .32994 .19672 .3263 .18978 .31954 Metetra
.656 .751 .92 r
.18978 .31954 .19672 .3263 .20672 .32265 .1998 .31586 Metetra
.656 .751 .92 r
.1998 .31586 .20672 .32265 .21675 .31898 .20985 .31217 Metetra
.656 .751 .92 r
.20985 .31217 .21675 .31898 .22682 .31529 .21995 .30846 Metetra
.656 .751 .92 r
.21995 .30846 .22682 .31529 .23693 .3116 .23008 .30473 Metetra
.656 .751 .92 r
.23008 .30473 .23693 .3116 .24708 .30788 .24025 .30099 Metetra
.656 .751 .92 r
.24025 .30099 .24708 .30788 .25727 .30416 .25047 .29724 Metetra
.656 .751 .92 r
.25047 .29724 .25727 .30416 .2675 .30042 .26072 .29347 Metetra
.656 .751 .92 r
.26072 .29347 .2675 .30042 .27777 .29666 .27101 .28969 Metetra
.656 .751 .92 r
.27101 .28969 .27777 .29666 .28808 .29289 .28135 .28589 Metetra
.656 .751 .92 r
.28135 .28589 .28808 .29289 .29843 .2891 .29172 .28208 Metetra
.656 .751 .92 r
.29172 .28208 .29843 .2891 .30882 .2853 .30214 .27825 Metetra
.656 .751 .92 r
.30214 .27825 .30882 .2853 .31925 .28149 .3126 .2744 Metetra
.656 .751 .92 r
.3126 .2744 .31925 .28149 .32972 .27766 .32309 .27055 Metetra
.656 .751 .92 r
.32309 .27055 .32972 .27766 .34024 .27381 .33363 .26667 Metetra
.656 .751 .92 r
.33363 .26667 .34024 .27381 .3508 .26995 .34422 .26278 Metetra
.656 .751 .92 r
.34422 .26278 .3508 .26995 .36139 .26608 .35484 .25888 Metetra
.656 .751 .92 r
.35484 .25888 .36139 .26608 .37204 .26218 .36551 .25496 Metetra
.656 .751 .92 r
.36551 .25496 .37204 .26218 .38272 .25828 .37622 .25102 Metetra
.656 .751 .92 r
.37622 .25102 .38272 .25828 .39344 .25435 .38697 .24707 Metetra
.656 .751 .92 r
.38697 .24707 .39344 .25435 .40421 .25041 .39777 .2431 Metetra
.656 .751 .92 r
.39777 .2431 .40421 .25041 .41503 .24646 .40861 .23912 Metetra
.656 .751 .92 r
.40861 .23912 .41503 .24646 .42588 .24249 .41949 .23512 Metetra
.656 .751 .92 r
.41949 .23512 .42588 .24249 .43678 .2385 .43042 .2311 Metetra
.656 .751 .92 r
.43042 .2311 .43678 .2385 .44773 .2345 .44139 .22707 Metetra
.656 .751 .92 r
.44139 .22707 .44773 .2345 .45872 .23048 .45241 .22302 Metetra
.656 .751 .92 r
.45241 .22302 .45872 .23048 .46975 .22645 .46347 .21895 Metetra
.656 .751 .92 r
.46347 .21895 .46975 .22645 .48083 .2224 .47458 .21487 Metetra
.656 .751 .92 r
.47458 .21487 .48083 .2224 .49195 .21833 .48573 .21077 Metetra
.656 .751 .92 r
.48573 .21077 .49195 .21833 .50312 .21424 .49693 .20666 Metetra
.656 .751 .92 r
.49693 .20666 .50312 .21424 .51433 .21014 .50817 .20253 Metetra
.656 .751 .92 r
.50817 .20253 .51433 .21014 .52559 .20602 .51946 .19838 Metetra
.656 .751 .92 r
.51946 .19838 .52559 .20602 .5369 .20189 .5308 .19421 Metetra
.656 .751 .92 r
.5308 .19421 .5369 .20189 .54825 .19774 .54218 .19003 Metetra
.656 .751 .92 r
.54218 .19003 .54825 .19774 .55965 .19357 .55361 .18582 Metetra
.656 .751 .92 r
.55361 .18582 .55965 .19357 .5711 .18938 .56509 .18161 Metetra
.656 .751 .92 r
.56509 .18161 .5711 .18938 .58259 .18518 .57662 .17737 Metetra
.656 .751 .92 r
.57662 .17737 .58259 .18518 .59414 .18096 .58819 .17312 Metetra
.656 .751 .92 r
.58819 .17312 .59414 .18096 .60573 .17672 .59981 .16884 Metetra
.656 .751 .92 r
.59981 .16884 .60573 .17672 .61736 .17246 .61149 .16455 Metetra
.656 .751 .92 r
.61149 .16455 .61736 .17246 .62905 .16819 .62321 .16025 Metetra
.656 .751 .92 r
.62321 .16025 .62905 .16819 .64079 .16389 .63498 .15592 Metetra
.656 .751 .92 r
.63498 .15592 .64079 .16389 .65257 .15958 .64679 .15158 Metetra
.656 .751 .92 r
.64679 .15158 .65257 .15958 .66441 .15525 .65866 .14722 Metetra
.656 .751 .92 r
.65866 .14722 .66441 .15525 .67629 .15091 .67058 .14283 Metetra
.656 .751 .92 r
.67058 .14283 .67629 .15091 .68823 .14654 .68255 .13844 Metetra
.656 .751 .92 r
.68255 .13844 .68823 .14654 .70022 .14216 .69457 .13402 Metetra
.656 .751 .92 r
.69457 .13402 .70022 .14216 .71225 .13776 .70665 .12958 Metetra
.02 0 .339 r
.04341 .26692 .02157 .46184 .04406 .3731 .03677 .36667 Metetra
.656 .751 .92 r
.03677 .36667 .04406 .3731 .05352 .36962 .04624 .36317 Metetra
.656 .751 .92 r
.04624 .36317 .05352 .36962 .06302 .36613 .05576 .35966 Metetra
.656 .751 .92 r
.05576 .35966 .06302 .36613 .07255 .36263 .06531 .35613 Metetra
.656 .751 .92 r
.06531 .35613 .07255 .36263 .08211 .35911 .07489 .35259 Metetra
.656 .751 .92 r
.07489 .35259 .08211 .35911 .09171 .35558 .08451 .34903 Metetra
.656 .751 .92 r
.08451 .34903 .09171 .35558 .10135 .35204 .09417 .34547 Metetra
.656 .751 .92 r
.09417 .34547 .10135 .35204 .11103 .34849 .10387 .34189 Metetra
.656 .751 .92 r
.10387 .34189 .11103 .34849 .12074 .34492 .1136 .33829 Metetra
.656 .751 .92 r
.1136 .33829 .12074 .34492 .13049 .34133 .12337 .33468 Metetra
.656 .751 .92 r
.12337 .33468 .13049 .34133 .14028 .33774 .13318 .33106 Metetra
.656 .751 .92 r
.13318 .33106 .14028 .33774 .1501 .33413 .14303 .32742 Metetra
.656 .751 .92 r
.14303 .32742 .1501 .33413 .15997 .3305 .15291 .32377 Metetra
.656 .751 .92 r
.15291 .32377 .15997 .3305 .16987 .32686 .16283 .32011 Metetra
.656 .751 .92 r
.16283 .32011 .16987 .32686 .17981 .32321 .17279 .31643 Metetra
.656 .751 .92 r
.17279 .31643 .17981 .32321 .18978 .31954 .18279 .31273 Metetra
.656 .751 .92 r
.18279 .31273 .18978 .31954 .1998 .31586 .19283 .30903 Metetra
.656 .751 .92 r
.19283 .30903 .1998 .31586 .20985 .31217 .20291 .3053 Metetra
.656 .751 .92 r
.20291 .3053 .20985 .31217 .21995 .30846 .21303 .30157 Metetra
.656 .751 .92 r
.21303 .30157 .21995 .30846 .23008 .30473 .22318 .29782 Metetra
.656 .751 .92 r
.22318 .29782 .23008 .30473 .24025 .30099 .23338 .29405 Metetra
.656 .751 .92 r
.23338 .29405 .24025 .30099 .25047 .29724 .24362 .29027 Metetra
.656 .751 .92 r
.24362 .29027 .25047 .29724 .26072 .29347 .25389 .28647 Metetra
.656 .751 .92 r
.25389 .28647 .26072 .29347 .27101 .28969 .26421 .28266 Metetra
.656 .751 .92 r
.26421 .28266 .27101 .28969 .28135 .28589 .27457 .27884 Metetra
.656 .751 .92 r
.27457 .27884 .28135 .28589 .29172 .28208 .28497 .275 Metetra
.656 .751 .92 r
.28497 .275 .29172 .28208 .30214 .27825 .29541 .27114 Metetra
.656 .751 .92 r
.29541 .27114 .30214 .27825 .3126 .2744 .30589 .26727 Metetra
.656 .751 .92 r
.30589 .26727 .3126 .2744 .32309 .27055 .31641 .26338 Metetra
.656 .751 .92 r
.31641 .26338 .32309 .27055 .33363 .26667 .32698 .25948 Metetra
.656 .751 .92 r
.32698 .25948 .33363 .26667 .34422 .26278 .33759 .25556 Metetra
.656 .751 .92 r
.33759 .25556 .34422 .26278 .35484 .25888 .34824 .25163 Metetra
.656 .751 .92 r
.34824 .25163 .35484 .25888 .36551 .25496 .35893 .24768 Metetra
.656 .751 .92 r
.35893 .24768 .36551 .25496 .37622 .25102 .36967 .24371 Metetra
.656 .751 .92 r
.36967 .24371 .37622 .25102 .38697 .24707 .38045 .23973 Metetra
.656 .751 .92 r
.38045 .23973 .38697 .24707 .39777 .2431 .39127 .23573 Metetra
.656 .751 .92 r
.39127 .23573 .39777 .2431 .40861 .23912 .40214 .23172 Metetra
.656 .751 .92 r
.40214 .23172 .40861 .23912 .41949 .23512 .41305 .22769 Metetra
.656 .751 .92 r
.41305 .22769 .41949 .23512 .43042 .2311 .42401 .22364 Metetra
.656 .751 .92 r
.42401 .22364 .43042 .2311 .44139 .22707 .43501 .21958 Metetra
.656 .751 .92 r
.43501 .21958 .44139 .22707 .45241 .22302 .44605 .2155 Metetra
.656 .751 .92 r
.44605 .2155 .45241 .22302 .46347 .21895 .45714 .21141 Metetra
.656 .751 .92 r
.45714 .21141 .46347 .21895 .47458 .21487 .46828 .20729 Metetra
.656 .751 .92 r
.46828 .20729 .47458 .21487 .48573 .21077 .47946 .20316 Metetra
.656 .751 .92 r
.47946 .20316 .48573 .21077 .49693 .20666 .49069 .19902 Metetra
.656 .751 .92 r
.49069 .19902 .49693 .20666 .50817 .20253 .50196 .19485 Metetra
.656 .751 .92 r
.50196 .19485 .50817 .20253 .51946 .19838 .51328 .19067 Metetra
.656 .751 .92 r
.51328 .19067 .51946 .19838 .5308 .19421 .52465 .18647 Metetra
.656 .751 .92 r
.52465 .18647 .5308 .19421 .54218 .19003 .53606 .18226 Metetra
.656 .751 .92 r
.53606 .18226 .54218 .19003 .55361 .18582 .54753 .17802 Metetra
.656 .751 .92 r
.54753 .17802 .55361 .18582 .56509 .18161 .55904 .17377 Metetra
.656 .751 .92 r
.55904 .17377 .56509 .18161 .57662 .17737 .57059 .1695 Metetra
.656 .751 .92 r
.57059 .1695 .57662 .17737 .58819 .17312 .5822 .16522 Metetra
.656 .751 .92 r
.5822 .16522 .58819 .17312 .59981 .16884 .59386 .16091 Metetra
.656 .751 .92 r
.59386 .16091 .59981 .16884 .61149 .16455 .60556 .15659 Metetra
.656 .751 .92 r
.60556 .15659 .61149 .16455 .62321 .16025 .61731 .15225 Metetra
.656 .751 .92 r
.61731 .15225 .62321 .16025 .63498 .15592 .62912 .14789 Metetra
.656 .751 .92 r
.62912 .14789 .63498 .15592 .64679 .15158 .64097 .14351 Metetra
.656 .751 .92 r
.64097 .14351 .64679 .15158 .65866 .14722 .65287 .13911 Metetra
.656 .751 .92 r
.65287 .13911 .65866 .14722 .67058 .14283 .66483 .1347 Metetra
.656 .751 .92 r
.66483 .1347 .67058 .14283 .68255 .13844 .67683 .13026 Metetra
.656 .751 .92 r
.67683 .13026 .68255 .13844 .69457 .13402 .68889 .12581 Metetra
.656 .751 .92 r
.68889 .12581 .69457 .13402 .70665 .12958 .70099 .12134 Metetra
0 0 .252 r
.00095 .48363 .04341 .26692 .03677 .36667 .02942 .3602 Metetra
.656 .751 .92 r
.02942 .3602 .03677 .36667 .04624 .36317 .03891 .35667 Metetra
.656 .751 .92 r
.03891 .35667 .04624 .36317 .05576 .35966 .04845 .35313 Metetra
.656 .751 .92 r
.04845 .35313 .05576 .35966 .06531 .35613 .05801 .34958 Metetra
.656 .751 .92 r
.05801 .34958 .06531 .35613 .07489 .35259 .06762 .34602 Metetra
.656 .751 .92 r
.06762 .34602 .07489 .35259 .08451 .34903 .07726 .34244 Metetra
.656 .751 .92 r
.07726 .34244 .08451 .34903 .09417 .34547 .08694 .33884 Metetra
.656 .751 .92 r
.08694 .33884 .09417 .34547 .10387 .34189 .09666 .33524 Metetra
.656 .751 .92 r
.09666 .33524 .10387 .34189 .1136 .33829 .10641 .33162 Metetra
.656 .751 .92 r
.10641 .33162 .1136 .33829 .12337 .33468 .1162 .32798 Metetra
.656 .751 .92 r
.1162 .32798 .12337 .33468 .13318 .33106 .12603 .32433 Metetra
.656 .751 .92 r
.12603 .32433 .13318 .33106 .14303 .32742 .1359 .32067 Metetra
.656 .751 .92 r
.1359 .32067 .14303 .32742 .15291 .32377 .14581 .31699 Metetra
.656 .751 .92 r
.14581 .31699 .15291 .32377 .16283 .32011 .15575 .3133 Metetra
.656 .751 .92 r
.15575 .3133 .16283 .32011 .17279 .31643 .16573 .3096 Metetra
.656 .751 .92 r
.16573 .3096 .17279 .31643 .18279 .31273 .17576 .30588 Metetra
.656 .751 .92 r
.17576 .30588 .18279 .31273 .19283 .30903 .18582 .30214 Metetra
.656 .751 .92 r
.18582 .30214 .19283 .30903 .20291 .3053 .19592 .29839 Metetra
.656 .751 .92 r
.19592 .29839 .20291 .3053 .21303 .30157 .20606 .29463 Metetra
.656 .751 .92 r
.20606 .29463 .21303 .30157 .22318 .29782 .21624 .29085 Metetra
.656 .751 .92 r
.21624 .29085 .22318 .29782 .23338 .29405 .22646 .28706 Metetra
.656 .751 .92 r
.22646 .28706 .23338 .29405 .24362 .29027 .23672 .28325 Metetra
.656 .751 .92 r
.23672 .28325 .24362 .29027 .25389 .28647 .24702 .27943 Metetra
.656 .751 .92 r
.24702 .27943 .25389 .28647 .26421 .28266 .25736 .27559 Metetra
.656 .751 .92 r
.25736 .27559 .26421 .28266 .27457 .27884 .26774 .27174 Metetra
.656 .751 .92 r
.26774 .27174 .27457 .27884 .28497 .275 .27816 .26787 Metetra
.656 .751 .92 r
.27816 .26787 .28497 .275 .29541 .27114 .28863 .26398 Metetra
.656 .751 .92 r
.28863 .26398 .29541 .27114 .30589 .26727 .29914 .26008 Metetra
.656 .751 .92 r
.29914 .26008 .30589 .26727 .31641 .26338 .30969 .25617 Metetra
.656 .751 .92 r
.30969 .25617 .31641 .26338 .32698 .25948 .32028 .25223 Metetra
.656 .751 .92 r
.32028 .25223 .32698 .25948 .33759 .25556 .33091 .24829 Metetra
.656 .751 .92 r
.33091 .24829 .33759 .25556 .34824 .25163 .34159 .24432 Metetra
.656 .751 .92 r
.34159 .24432 .34824 .25163 .35893 .24768 .35231 .24035 Metetra
.656 .751 .92 r
.35231 .24035 .35893 .24768 .36967 .24371 .36307 .23635 Metetra
.656 .751 .92 r
.36307 .23635 .36967 .24371 .38045 .23973 .37388 .23234 Metetra
.656 .751 .92 r
.37388 .23234 .38045 .23973 .39127 .23573 .38473 .22831 Metetra
.656 .751 .92 r
.38473 .22831 .39127 .23573 .40214 .23172 .39562 .22427 Metetra
.656 .751 .92 r
.39562 .22427 .40214 .23172 .41305 .22769 .40656 .22021 Metetra
.656 .751 .92 r
.40656 .22021 .41305 .22769 .42401 .22364 .41755 .21613 Metetra
.656 .751 .92 r
.41755 .21613 .42401 .22364 .43501 .21958 .42857 .21204 Metetra
.656 .751 .92 r
.42857 .21204 .43501 .21958 .44605 .2155 .43965 .20793 Metetra
.656 .751 .92 r
.43965 .20793 .44605 .2155 .45714 .21141 .45077 .2038 Metetra
.656 .751 .92 r
.45077 .2038 .45714 .21141 .46828 .20729 .46193 .19965 Metetra
.656 .751 .92 r
.46193 .19965 .46828 .20729 .47946 .20316 .47314 .19549 Metetra
.656 .751 .92 r
.47314 .19549 .47946 .20316 .49069 .19902 .4844 .19131 Metetra
.656 .751 .92 r
.4844 .19131 .49069 .19902 .50196 .19485 .49571 .18712 Metetra
.656 .751 .92 r
.49571 .18712 .50196 .19485 .51328 .19067 .50706 .18291 Metetra
.656 .751 .92 r
.50706 .18291 .51328 .19067 .52465 .18647 .51845 .17867 Metetra
.656 .751 .92 r
.51845 .17867 .52465 .18647 .53606 .18226 .5299 .17443 Metetra
.656 .751 .92 r
.5299 .17443 .53606 .18226 .54753 .17802 .54139 .17016 Metetra
.656 .751 .92 r
.54139 .17016 .54753 .17802 .55904 .17377 .55294 .16588 Metetra
.656 .751 .92 r
.55294 .16588 .55904 .17377 .57059 .1695 .56453 .16157 Metetra
.656 .751 .92 r
.56453 .16157 .57059 .1695 .5822 .16522 .57616 .15725 Metetra
.656 .751 .92 r
.57616 .15725 .5822 .16522 .59386 .16091 .58785 .15292 Metetra
.656 .751 .92 r
.58785 .15292 .59386 .16091 .60556 .15659 .59959 .14856 Metetra
.656 .751 .92 r
.59959 .14856 .60556 .15659 .61731 .15225 .61138 .14418 Metetra
.656 .751 .92 r
.61138 .14418 .61731 .15225 .62912 .14789 .62321 .13979 Metetra
.656 .751 .92 r
.62321 .13979 .62912 .14789 .64097 .14351 .6351 .13538 Metetra
.656 .751 .92 r
.6351 .13538 .64097 .14351 .65287 .13911 .64704 .13095 Metetra
.656 .751 .92 r
.64704 .13095 .65287 .13911 .66483 .1347 .65902 .1265 Metetra
.656 .751 .92 r
.65902 .1265 .66483 .1347 .67683 .13026 .67106 .12203 Metetra
.656 .751 .92 r
.67106 .12203 .67683 .13026 .68889 .12581 .68316 .11754 Metetra
.656 .751 .92 r
.68316 .11754 .68889 .12581 .70099 .12134 .6953 .11303 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 233.562},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GQ000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOol<Ool01W>L8@P00000:DYcW0Aoo`04F]H8
@P00>LjGOol00?moo`aoo`06:DXicWooOolicRU:0goo00IS61S6LiacW124DYBFOol00?moo`aoo`03
249oogoo009oo`06001oogooOolQ25:D0Woo00=BU1S6Ool0UGoo003oOol<Ool00`00Liaoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol0U7oo003oOol<Ool01P00:DYcW7oo>LhYBP=oo`03001oogoo
009oo`03001oogoo09Aoo`00ogoo37oo00H@Q3W>000002U:Li`3Ool00`00Oomoo`02Ool00`00Oomo
o`2DOol00?moo`aoo`03@Q0aS7oo00Ioo`068@QBU7ooOomBU248UWoo003oOol=Ool00aS6<Ha[FP05
Ool01V<H6<IcW7>L6<IS61Aoo`80081oo`00ogoo3Woo00@icPQ2000@Q0Aoo`04F]H8@PQ2HaPBOol3
00000goo001oo`1oOol00?moobYoo`8000Aoo`8007moo`00ogoo9goo0`001Woo00<007oo0000OWoo
003oOolUOol20009Ool00`00Ool0001nOol00?moob9oo`<000]oo`04001oogoo001mOol00?mooamo
o`<000ioo`05001oogooOol0001lOol00?mooaeoo`80015oo`05001oogooOol0001lOol00?mooaYo
o`@0019oo`03001oogoo009oo`03001oogoo07Uoo`00ogoo67oo0P0017oo00<007ooOol03goo00<0
07ooOol00goo00<007ooOol0N7oo003oOolEOol30007Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`1hOol00?mooa=oo`8001aoo`03001oogoo00=oo`03001oogoo07Moo`00ogoo47oo0`00
7Woo00<007ooOol00goo00<007ooOol0Mgoo003oOol>Ool2000QOol00`00Oomoo`04Ool00`00Oomo
o`1fOol00?moo`]oo`<002=oo`03001oogoo00=oo`03001oo`0007Moo`00ogoo2Goo0P009Woo00<0
07ooOol01Goo00<007ooOol0MGoo003oOol6Ool3000XOol00`00Oomoo`06Ool00`00Oomoo`1dOol0
0?moo`=oo`<0009oo`03001oogoo02Ioo`03001oogoo00Moo`03001oogoo07=oo`00ogoo0Goo0P00
;Woo00<007ooOol01goo00<007ooOol0Lgoo003mOol3000`Ool00`00Oomoo`08Ool00`00Oomoo`1b
Ool00?]oo`8003=oo`03001oogoo00Uoo`03001oogoo075oo`00n7oo0`00=Goo00<007ooOol02Goo
00<007ooOol0LGoo003fOol2000hOol00`00Oomoo`0:Ool00`00Oomoo`1`Ool00?=oo`<003Yoo`03
001oogoo00]oo`03001oogoo06moo`00lGoo0P00?Goo00<007ooOol02goo00<007ooOol0Kgoo003^
Ool3000oOol00`00Oomoo`0<Ool00`00Oomoo`1^Ool00>aoo`8000=oo`03001oogoo03aoo`03001o
ogoo00eoo`03001oogoo06eoo`00]Woo0P0000<8@WooOol00Woo00AJePQ2000icRQoo`<004Aoo`03
001oogoo00eoo`03001oogoo06eoo`00]goo00<007ooOol00Woo00IS61S6LiacW124DY@TOol30017
Ool00`00Oomoo`0>Ool00`00Oomoo`1/Ool00;=oo`H000=oo`068@QBU7ooOomBU1S68Woo0P00BWoo
00<007ooOol03Woo0P00KGoo002cOol01CW>DYAoogoo000017oo00<007ooOol00Woo00<007ooOol0
7Goo0`00CGoo00<007ooOol037oo00<007oo0000KGoo002cOol01G>L6<IcW7oo000017oo00<007oo
Ool00Woo00<007ooOol06goo0P00D7oo00<007ooOol03goo00<007ooOol0JWoo002dOol015:D<Hao
o`0017oo00<007ooOol00Woo00<007ooOol067oo0`00DWoo00<007ooOol047oo00<007ooOol0JGoo
002eOol00b48HaP00004Ool01R48DYAoogooDY@Q21Qoo`8005Eoo`03001oogoo011oo`03001oogoo
06Uoo`00]Goo00=[FR48000017oo00IS61S6LiacW1S6HaPEOol300000goo001oo`1DOol00`00Oomo
o`0AOol00`00Oomoo`1XOol00;Ioo`03>Lh8@Woo00Aoo`04F]H8@PQ2HaPDOol2001JOol00`00Oomo
o`0AOol00`00Oomoo`1XOol00=9oo`<005aoo`03001oogoo019oo`03001oogoo06Moo`00d7oo0P00
Ggoo00<007ooOol04goo00<007ooOol0IWoo003=Ool3001QOol00`00Oomoo`0COol00`00Oomoo`1V
Ool00<Yoo`<006Aoo`03001oogoo01Aoo`03001oogoo06Eoo`00b7oo0P00Igoo00<007ooOol05Goo
00<007ooOol0I7oo0035Ool3001YOol00`00Oomoo`0EOol00`00Oomoo`1TOol00<=oo`800003Ool0
07oo06Uoo`03001oogoo01Ioo`03001oogoo06=oo`00`7oo0`0017oo00<007ooOol0Igoo00<007oo
Ool05goo00<007ooOol0HWoo002nOol2001aOol00`00Oomoo`0GOol2001SOol00;]oo`<0079oo`80
01Qoo`03001oo`0006=oo`00^Goo0P00LWoo0`0000=C7@00Ool06Woo00<007ooOol0H7oo002fOol3
001aOol30004Dad2000JOol00`00Oomoo`1POol00;Aoo`80075oo`<000=C7@04001C7E<MDad3000J
Ool00`00Oomoo`1OOol00;5oo`<0071oo`<00003Dad005<M00AC7@03001C7@0000800003Dad007oo
01Uoo`03001oogoo05ioo`00[Woo1000L7oo0P001E<M00<005<MDad00U<M0P000U<M00@005<MDad0
01Uoo`03001oogoo05ioo`00[7oo0P0017oo00<007ooOol0JWoo0`0000=C7@00Dad015<M00<005<M
00000P0000EC7@00DaeC7@00009C7@8001Uoo`03001oogoo05eoo`00ZGoo0`00LGoo0P001E<M00@0
05<MDaeC7@<000EC7@03001C7@0000800003Dad007oo01Uoo`03001oogoo00Moo`H000Aoo`04F]H8
@P00>Li7Ool00:Moo`80075oo`<00003Dad005<M00AC7@@0009C7@03001C7E<M00=C7@<000AC7@03
001oogoo01Moo`03001oogoo00Moo`03BU8006<H009oo`06249oogooOomS61S60W>L00<@Q5:DOol0
AGoo002TOol3001`Ool30005Dad00`00Dad0000200000e<M001C7@04Dad00`00Dad0000200000e<M
00000004Dad00`00Oomoo`0HOol00`00Oomoo`07Ool00dYB001S6005Ool01R48DYAoogooDY@HaTIo
o`00XWoo0P00L7oo0`000e<M00<005<MDad00U<M0P001E<M00<005<MDad00U<M0P001E<M00@005<M
DaeC7@<001Uoo`03001oogoo00Qoo`03DY@8@V<H00Aoo`03001oogoo009oo`03001oogoo04Aoo`00
Wgoo0`00Kgoo0`0000=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C7@03001C7@000080
0003Dad005<M00AC7@@0009C7@03001oogoo01Qoo`03001oogoo00Qoo`03HaP8@V<H00=oo`03001o
ogoo009oo`03001oogoo04Aoo`00WGoo0P00L7oo0P001E<M00<005<MDad00U<M0P001E<M00<005<M
Dad00`001E<M00<005<M000010001E<M00<007ooOol067oo00<007ooOol027oo00=BU1S6Ool00Woo
00<007ooOol00Woo00<007ooOol0A7oo002JOol3001_Ool300000e<M001C7@04Dad00`00Dad00002
00000e<M001C7@04Dad30003Dad00`00DaeC7@02Dad20003Dad00`00Dad00003Dad3000IOol00`00
Oomoo`09Ool01P00Oomoogoo8@QBU09oo`03DY@Q27oo04Eoo`00HGoo1P0017oo00AJePQ2000icRUo
o`8000=oo`03001oogoo06Yoo`8000EC7@04001C7E<MDad30005Dad00`00Dad0000200000e<M001C
7@04Dad01000Dad000000U<M00D005<MDad005<M00@0009C7@03001oogoo01Moo`8000Eoo`060012
47>LOolicQS60goo00IS61S6LiacW1S6HaQ6Ool0065oo`03BU8006<H009oo`06249oogooOomS61S6
0W>L00<@Q5:DOol097oo0`00L7oo0P000U<M00<005<MDad00U<M10000U<M00<005<MDad00e<M0P00
1E<M00@005<MDaeC7@<000EC7@06001C7@00001C7@001E<M00<007ooOol05Goo00@007ooOol000Ao
o`06DY@HaP00000YBW>L17oo00AJePQ2249S64Moo`00HWoo00=:DP00HaP01Goo00HQ25:DOomooe:D
6<HSOol2001`Ool30005Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00
Dad015<M10000U<M00<005<MDad00e<M0`000e<M00<005<MDad00U<M0P006Goo00<007ooOol0Egoo
001SOol00e:D249S6004Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001^Ool40002Dad00`00DaeC
7@03Dad20005Dad00`00DaeC7@030005Dad00`00Dad0000200000e<M001C7@04Dad00`00Dad00002
00000e<M00000004Dad01P00Dad00000Dad001Yoo`03001oogoo05Ioo`00I7oo00=S60Q2HaP00goo
00<007ooOol00Woo00<007ooOol06goo0`00Kgoo0P000U<M00<005<MDad00U<M00<005<M00000P00
00=C7@00Dad015<M0`000e<M00<005<MDad00U<M0P001E<M00<005<MDad00U<M0P001E<M00@005<M
DaeC7@<000AC7@03001oogoo01Qoo`03001oogoo05Eoo`00IGoo00=BU1S6Ool00Woo00<007ooOol0
0Woo00<007ooOol06Goo0P00L7oo0P001E<M00<005<MDad00`001E<M00<005<M00000P0000=C7@00
Dad015<M00@005<M0000009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00AC7@@0009C
7@03001C7E<M009C7@8001Uoo`03001oogoo05Eoo`00IWoo00H007ooOomoob48DY@2Ool00e:D8@Qo
o`0GOol3001_Ool300000e<M001C7@04Dad30003Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@02
Dad20005Dad00`00DaeC7@030005Dad00`00Dad000040005Dad01000Dad000000U<M00<007ooOol0
5goo00<007ooOol0E7oo001QOol01P00@Q1cW7oo>LhHaP=oo`06HaPHaW>LLi`HaV<H5Woo0`00KWoo
0`001E<M00<005<M00000P0000=C7@00Dad015<M00H005<M000005<M0005Dad00`00Dad000020000
0e<M001C7@04Dad30003Dad00`00DaeC7@02Dad20003Dad00`00Dad00003Dad30005Dad00`00Oomo
o`0GOol00`00Oomoo`1COol0065oo`06DY@HaP00000YBW>L17oo00AJePQ2249S61Aoo`<000=oo`03
001oogoo06Qoo`<0009C7@03001C7E<M00=C7@8000EC7@04001C7E<MDad30004Dad01000DaeC7E<M
0`001E<M00<005<M00000P0000=C7@00Dad015<M00H005<M000005<M0003Dad00`00Dad000030002
Dad00`00DaeC7@03Dad2000HOol00`00Oomoo`1COol0085oo`8006ioo`<00003Dad005<M00=C7@03
001C7@0000800003Dad005<M00AC7@@0009C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@80
00EC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M001C7@04Dad00`00Dad0000200000e<M
001oo`0HOol00`00Oomoo`1BOol007ioo`<006ioo`8000EC7@03001C7E<M00<000EC7@03001C7@00
00800003Dad005<M00AC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C
7@04Dad40002Dad00`00DaeC7@02Dad20002Dad01000DaeC7@0015<M0P001E<M00<007ooOol05goo
00<007ooOol0DGoo001lOol2001^Ool300000e<M001C7@04Dad30003Dad00`00DaeC7@02Dad20005
Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@030005Dad00`00Dad0000200000e<M001C7@04Dad0
1000Dad000000U<M00<005<M00000U<M00<005<M00000P0000=C7@00Dad015<M0P0067oo00<007oo
Ool0DGoo001iOol3001]Ool30005Dad00`00Dad0000200000e<M001C7@04Dad01000Dad000000U<M
00<005<MDad00U<M00<005<M00000P0000=C7@00Dad015<M0`000e<M00<005<MDad00U<M0P001E<M
00@005<MDaeC7@<000EC7@800004Dad000000005Dad00`00Dad0000200000e<M001oo`0HOol00`00
Oomoo`1@Ool007Moo`8006eoo`<000=C7@03001C7E<M009C7@8000EC7@04001C7E<MDad30005Dad0
0`00DaeC7@030005Dad00`00Dad0000200000e<M001C7@04Dad01P00Dad00000Dad000EC7@@0009C
7@03001C7E<M00=C7@<0009C7@03001C7E<M00=C7@8000EC7@03001oogoo01Moo`03001oogoo04mo
o`00M7oo0`00KGoo0P0000=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03
001C7E<M00=C7@<000=C7@03001C7E<M009C7@8000EC7@04001C7E<MDad30004Dad00`00Dad00002
00000e<M001C7@04Dad00`00Dad0000200000e<M001C7@03Dad00`00Dad0000200000e<M001C7@04
Dad2000HOol2001@Ool0075oo`<0009oo`03001oogoo06Uoo`8000AC7@04001C7E<MDad30005Dad0
1P00Dad00000Dad000EC7@03001C7@0000800003Dad005<M00AC7@04001C7@000002Dad00`00DaeC
7@02Dad40002Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@02Dad20004Dad20002Dad30005Dad0
0`00Dad0000200000e<M001oo`0FOol00`00Ool0001@Ool006moo`8000Ioo`03001oogoo06Eoo`<0
0003Dad005<M00=C7@@0009C7@03001C7E<M00=C7@8000AC7@03001C7E<M009C7@8000EC7@04001C
7E<MDad30005Dad01P00Dad00000Dad000EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0
000200000e<M001C7@03Dad40003Dad00`00DaeC7@02Dad20005Dad00`00Oomoo`0FOol00`00Oomo
o`1>Ool006aoo`<006eoo`<000EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad000020000
0e<M001C7@04Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<005<MDad00e<M0P0015<M
00@005<MDaeC7@<000EC7@03001C7E<M00<000EC7@03001C7@0000800003Dad005<M00AC7@06001C
7@00001C7@001E<M0P0067oo00<007ooOol0CGoo001ZOol2001]Ool30003Dad00`00DaeC7@02Dad2
0005Dad00`00DaeC7@030005Dad01000DaeC7E<M0`001E<M00H005<M000005<M0005Dad00`00Dad0
000200000e<M001C7@03Dad40002Dad00`00DaeC7@03Dad30003Dad00`00DaeC7@02Dad20002Dad0
1000DaeC7@000e<M0`0015<M00<005<M00000P0000=C7@00Ool067oo00<007ooOol0C7oo001WOol3
001/Ool300000e<M001C7@04Dad01P00Dad00000Dad000EC7@<000=C7@03001C7E<M009C7@@0009C
7@03001C7E<M00=C7@8000AC7@04001C7E<MDad30005Dad01000Dad000000U<M00<005<MDad00U<M
00<005<M00000P0000=C7@00Dad015<M00H005<M000005<M0002Dad00`00DaeC7@040002Dad00`00
DaeC7@02Dad20005Dad00`00Oomoo`0FOol00`00Oomoo`1<Ool006Eoo`8006eoo`8000EC7@04001C
7E<MDad30004Dad00`00Dad0000200000e<M001C7@04Dad01000Dad000000U<M00<005<MDad00U<M
00<005<M00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00e<M0P001E<M00<005<MDad00`00
1E<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad005<M00AC7@06001C7@00001C7@001E<M
0P0067oo00<007ooOol0Bgoo001ROol3001]Ool20002Dad00`00DaeC7@02Dad40002Dad00`00DaeC
7@02Dad20005Dad01000DaeC7E<M0`001E<M00<005<MDad00`001E<M00@005<M0000009C7@03001C
7E<M009C7@03001C7@0000800003Dad005<M00AC7@<0009C7@03001C7E<M00=C7@@0009C7@03001C
7E<M009C7@<000AC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M001oo`0HOol00`00Oomo
o`1:Ool0061oo`<006aoo`<000EC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M
00<005<MDad00U<M10000U<M00<005<MDad00e<M0`000U<M00<005<MDad00e<M0P001E<M00<005<M
Dad00`001E<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad015<M00D0
05<M000005<M008000AC7@@0009C7@03001C7E<M009C7@8000EC7@03001oogoo01Ioo`03001oogoo
04Yoo`00GGoo0`000goo00<007ooOol0IGoo10000U<M00<005<MDad00e<M0P001E<M00<005<MDad0
0`001E<M00@005<M0000009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00=C7@03001C
7@0000800003Dad005<M00AC7@<000=C7@03001C7E<M009C7@8000EC7@03001C7E<M00<000EC7@04
001C7E<MDad30004Dad00`00Dad0000200000e<M001C7@04Dad01P00Dad00000Dad000EC7@8001Qo
o`03001oogoo04Uoo`00Fgoo0P00K7oo0P000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00
Dad015<M0`000U<M00<005<MDad00e<M0P001E<M00<005<MDad00`001E<M00<005<MDad00`001E<M
00<005<M00000P0000=C7@00Dad015<M00H005<M000005<M0005Dad30003Dad00`00DaeC7@02Dad4
0002Dad00`00DaeC7@02Dad20005Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Ool0
67oo00<007ooOol0B7oo001HOol3001[Ool30005Dad00`00DaeC7@030005Dad00`00Dad000020000
0e<M001C7@03Dad00`00Dad0000200000e<M001C7@04Dad30003Dad00`00DaeC7@02Dad30003Dad0
0`00DaeC7@02Dad20005Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad015<M00H0
05<M000005<M0005Dad00`00Dad0000200000e<M001C7@03Dad40002Dad00`00DaeC7@02Dad20005
Dad00`00Oomoo`0FOol00`00Oomoo`18Ool005Eoo`<006]oo`<000=C7@03001C7E<M009C7@<000=C
7@03001C7E<M009C7@8000EC7@03001C7E<M00<000EC7@03001C7@0000800003Dad005<M00AC7@06
001C7@00001C7@001E<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C7E<M009C7@80
00EC7@04001C7E<MDad30004Dad01000DaeC7E<M0`000U<M00D005<MDad005<M00800003Dad005<M
00AC7@06001C7@00001C7@001E<M0P0067oo00<007ooOol0Agoo001COol2001[Ool300000e<M001C
7@04Dad01P00Dad00000Dad000EC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC
7@02Dad20005Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000EC7@06001C7@00001C7@001E<M
00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C7E<M009C7@@0009C7@04001C7E<M0002
Dad20004Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Ool067oo00<007ooOol0AWoo
001@Ool3001[Ool20005Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000EC7@06001C7@00001C
7@001E<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C7E<M009C7@@0009C7@03001C
7E<M00=C7@8000AC7@04001C7E<MDad30005Dad01P00Dad00000Dad000EC7@06001C7@00001C7@00
1E<M00<005<M00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00U<M0P001E<M00<007ooOol0
5Woo0P00Agoo001>Ool2001/Ool20002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@02Dad40002
Dad00`00DaeC7@03Dad20004Dad01000DaeC7E<M0`001E<M00H005<M000005<M0005Dad01000Dad0
00000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00e<M
0P0015<M00@005<MDaeC7@<000AC7@04001C7E<MDad300000e<M001C7@02Dad01P00Dad00000Dad0
00EC7@04001C7@000002Dad00`00DaeC7@02Dad2000FOol00`00Ool00017Ool004]oo`<0009oo`03
001oogoo06Ioo`<000EC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<M
Dad00U<M00<005<M00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00e<M0P0015<M00@005<M
DaeC7@<000EC7@03001C7E<M00<000EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad00002
00000e<M001C7@03Dad40002Dad00`00DaeC7@02Dad40003Dad20002Dad30004Dad01000DaeC7E<M
0`001E<M00H005<M000005<M000IOol00`00Oomoo`14Ool004Uoo`8006]oo`<000=C7@03001C7E<M
009C7@8000EC7@03001C7E<M00<000EC7@03001C7E<M00@000AC7@04001C7@000002Dad00`00DaeC
7@02Dad00`00Dad0000200000e<M001C7@03Dad40002Dad00`00DaeC7@03Dad30003Dad01000DaeC
7E<M0`001E<M00<005<MDad00`001E<M00H005<M000005<M0005Dad01000Dad000000U<M00<005<M
Dad00U<M10000U<M00<005<MDad00U<M10000U<M00<005<MDad00e<M0P0015<M00<007ooOol05Woo
00<007ooOol0A7oo0016Ool3001ZOol300000e<M001C7@04Dad01P00Dad00000Dad000EC7@<000=C
7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC7@03001C7E<M00<000EC7@04001C7@000002
Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@03Dad40002Dad00`00DaeC7@03Dad30002
Dad00`00DaeC7@03Dad20004Dad01000DaeC7E<M0`001E<M00H005<M000005<M0005Dad01P00Dad0
0000Dad000EC7@03001C7@0000800003Dad005<M00=C7@8001Qoo`03001oogoo04=oo`00A7oo0P00
JWoo0`001E<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad005<M00AC7@06001C7@00001C
7@001E<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0P001E<M00<005<MDad00`00
1E<M00@005<M0000009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00=C7@03001C7@00
00800003Dad005<M00=C7@@0009C7@03001C7E<M00=C7@8000=C7@8000=C7@<000AC7@04001C7E<M
Dad30005Dad01P00Dad00000Dad001Uoo`03001oogoo049oo`00@Goo0`00JGoo0`000e<M00<005<M
Dad00U<M10000U<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@<000AC7@03001C7@0000800003
Dad005<M00AC7@06001C7@00001C7@001E<M00H005<M000005<M0005Dad30003Dad00`00DaeC7@02
Dad20005Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad01000Dad000000U<M00<005<MDad0
0U<M00<005<M00000P0000=C7@00Dad00U<M1@000U<M00<005<MDad00U<M10000U<M00<005<MDad0
0e<M0P0015<M00<007ooOol05Woo00<007ooOol0@Woo000oOol2001ZOol20002Dad00`00DaeC7@02
Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03
001C7E<M009C7@8000EC7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00<005<M00000P00
00=C7@00Dad015<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@03Dad30003Dad01000DaeC
7E<M0`001E<M00<005<MDad00`001E<M00H005<M000005<M0005Dad01P00Dad00000Dad000EC7@03
001C7@0000800003Dad005<M00=C7@8001Qoo`03001oogoo045oo`00?7oo0`00JWoo0P001E<M00<0
05<MDad00`001E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@00
0002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad01000
DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad00e<M
10000U<M00<005<MDad00e<M0`000U<M00<005<MDad00e<M0P0000EC7@00DaeC7@0000=C7@<000AC
7@04001C7E<MDad30005Dad01P00Dad00000Dad001Uoo`03001oogoo041oo`00>Goo0`0000=oo`00
Ool0J7oo0P000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad00`00
1E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@03
0005Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad00e<M00<005<M
00000P0000AC7@00Dad0009C7@@0009C7@03001C7E<M009C7@@000=C7@04001C7E<MDad30004Dad0
0`00Oomoo`0FOol00`00Oomoo`10Ool003Moo`8006]oo`<000EC7@06001C7@00001C7@001E<M00H0
05<M000005<M0005Dad30002Dad00`00DaeC7@03Dad30004Dad00`00DaeC7@030005Dad00`00DaeC
7@030005Dad01P00Dad00000Dad000EC7@06001C7@00001C7@001E<M00H005<M000005<M0005Dad3
0003Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad400000e<M
001C7@04Dad01P00Dad00000Dad000EC7@@0009C7@03001C7E<M009C7@8001Qoo`03001oogoo03mo
o`00=7oo0`00JWoo0`000e<M00@005<MDaeC7@<000AC7@04001C7E<MDad30004Dad00`00Dad00002
00000e<M001C7@03Dad00`00Dad0000200000e<M001C7@04Dad30002Dad00`00DaeC7@03Dad30002
Dad00`00DaeC7@03Dad20004Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000AC7@03001C7@00
00800003Dad005<M00AC7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00e<M0`000e<M00<0
05<M0000100015<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad005<M00AC7@06001C7@00
001C7@0067oo00<007ooOol0?goo000bOol2001ZOol300000e<M001C7@03Dad40002Dad00`00DaeC
7@02Dad40002Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@030005Dad00`00Dad0000200000e<M
001C7@03Dad00`00Dad0000200000e<M001C7@03Dad00`00Dad0000200000e<M001C7@03Dad40002
Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad01000DaeC7E<M0`0015<M00<005<M0000
0P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad00U<M1@000U<M0P000e<M10000U<M00<0
05<MDad00U<M0P001E<M00@005<MDaeC7@<000AC7@03001oogoo01Ioo`03001oogoo03ioo`00;goo
0`00JGoo0`001E<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02
Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0P001E<M00<005<MDad0
0`001E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad0
0`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad00`00DaeC7@03
0005Dad400000e<M001C7@04Dad400000e<M001C7@04Dad01000Dad000000U<M00<005<MDad00U<M
10000U<M00<005<MDad00U<M0P0067oo00<007ooOol0?Goo000^Ool2001XOol30003Dad00`00DaeC
7@02Dad20005Dad00`00DaeC7@030005Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<M
Dad00U<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C
7E<M00<000EC7@03001C7E<M00<000EC7@06001C7@00001C7@001E<M00H005<M000005<M0005Dad3
0002Dad00`00DaeC7@03Dad30002Dad00`00DaeC7@050004Dad01000DaeC7E<M10000e<M00@005<M
DaeC7@<000EC7@06001C7@00001C7@001E<M00H005<M000005<M000GOol2000oOol002ioo`03001o
o`0006Eoo`80009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00
DaeC7@02Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad01P00Dad00000Dad000EC
7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00e<M0`000e<M00@005<MDaeC7@<000AC7@04
001C7E<MDad30004Dad00`00Dad0000200000e<M001C7@03Dad00`00Dad0000200000e<M001C7@02
Dad600000e<M001C7@03Dad40002Dad20003Dad40003Dad01000DaeC7E<M0`0015<M00@005<MDaeC
7@<000AC7@03001oogoo01Ioo`03001oogoo03aoo`00;Woo00@007ooOol0065oo`<000EC7@03001C
7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M
0`000U<M00<005<MDad00e<M0`000e<M00@005<MDaeC7@<000AC7@04001C7E<MDad30004Dad00`00
Dad0000200000e<M001C7@03Dad00`00Dad0000200000e<M001C7@03Dad40002Dad00`00DaeC7@02
Dad40002Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@030005Dad70004Dad01000Dad000000U<M
00<005<MDad00U<M10000U<M00<005<MDad00U<M10000U<M00<005<MDad00U<M10000e<M00<005<M
Dad00`0067oo00<007ooOol0>goo000^Ool01@00Oomoogoo0000GGoo0`000e<M00<005<MDad00U<M
0`0015<M00<005<MDad00`001E<M00<005<MDad00`001E<M00H005<M000005<M0004Dad00`00Dad0
000200000e<M001C7@03Dad40002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad00`00
DaeC7@030005Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C
7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00Dad000050004Dad00`00DaeC7@030005
Dad00`00DaeC7@040004Dad01P00Dad00000Dad000EC7@06001C7@00001C7@001E<M0`000U<M00<0
07ooOol05Woo00<007ooOol0>goo000]Ool01000Oomoo`000Woo00<007ooOol0F7oo0P000U<M00<0
05<MDad00U<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@03Dad30003Dad01000DaeC7E<M
0`0015<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad0
0`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad20005Dad00`00DaeC
7@030005Dad00`00DaeC7@030005Dad01P00Dad00000Dad000=C7@<00005Dad00000Dad00005Dad3
0002Dad00`00DaeC7@03Dad30003Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000AC7@03001C
7@0000800003Dad005<M00=C7@03001oogoo01Ioo`03001oogoo03Yoo`00;Goo00@007ooOol000=o
o`03001oogoo05Aoo`<000EC7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C7@03
001C7@0000800003Dad005<M00=C7@@0009C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC
7@03001C7E<M00<000EC7@06001C7@00001C7@001E<M00H005<M000005<M0005Dad01P00Dad00000
Dad000EC7@<0009C7@03001C7E<M00=C7@<000=C7@04001C7E<MDad30004Dad3000015<M00000000
15<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad00e<M10000U<M00<0
05<MDad00U<M10000e<M00<005<MDad00`001E<M00<005<MDad00`0067oo00<007ooOol0>Goo000]
Ool01000Oomoo`0017oo00<007ooOol0D7oo0`000U<M00<005<MDad00e<M0`000e<M00<005<MDad0
0`001E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad0
0`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad20004Dad01000DaeC
7E<M0`0015<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad005<M00=C7@03001C7@000080
0003Dad005<M00=C7@@0009C7@03001C7E<M00H000=C7@03001C7E<M00<000EC7@03001C7E<M00<0
00EC7@05001C7@00001C7@020004Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M009C7@@0
009C7@03001oogoo01Ioo`03001oogoo00]oo`800003249oogoo009oo`04F]H8@P00>LhSOol002eo
o`04001oogoo0005Ool00`00Oomoo`1=Ool200000e<M001C7@03Dad00`00Dad0000200000e<M001C
7@03Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad0
1P00Dad00000Dad000EC7@06001C7@00001C7@001E<M00H005<M000005<M0004Dad40002Dad00`00
DaeC7@02Dad40003Dad00`00DaeC7@030005Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC
7@D00003Dad005<M00AC7@<0009C7@03001C7E<M00=C7@<000=C7@04001C7E<MDad30004Dad20002
Dad30004Dad00`00Dad0000200000e<M001C7@03Dad01P00Dad00000Dad000EC7@03001oogoo01Io
o`03001oogoo00]oo`03001oogoo009oo`06HaPHaW>LLi`@Q5:D8Woo000]Ool01000Ool000001Woo
00<007ooOol0BGoo0`0015<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04
001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad2
0004Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000AC7@04001C7@000002Dad00`00DaeC7@02
Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad0
0`0015<M1`0015<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad00e<M
10000U<M00<005<MDad00U<M10000U<M00<005<MDad00U<M0P001E<M00<005<MDad00`0015<M00@0
05<MDaeC7@<001Qoo`03001oogoo00Ioo`H000=oo`068@QBU7ooOomBU1S68Woo000/Ool50007Ool0
0`00Oomoo`14Ool40002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@04
0004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0005Dad01P00Dad00000Dad0
00AC7@@0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00<000EC7@03001C7E<M00<000EC7@06
001C7@00001C7@001E<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@060003Dad00`00DaeC
7@030005Dad00`00DaeC7@030005Dad01P00Dad00000Dad000EC7@05001C7@00001C7@020004Dad0
1P00Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@@000=C7@03001oogoo01Eoo`03001oogoo
00Ioo`05>LiBU7ooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`0POol002aoo`03001oogoo0080
00Qoo`03001oogoo045oo`80009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad3
0003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad01000DaeC
7E<M0`0015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad3
0003Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000AC7@03001C
7@0000800003Dad005<M009C7@D0009C7@03001C7E<M009C7@<0009C7@03001C7E<M00=C7@<000=C
7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M0P000U<M0`0015<M00H005<M000005<M0005
Dad01P00Dad00000Dad000EC7@8001Moo`03001oogoo00Eoo`05Li`HaW>LOol00004Ool00`00Oomo
o`02Ool00`00Oomoo`0POol002aoo`03001oogoo008000Uoo`03001oogoo03eoo`<000EC7@03001C
7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M
0`000U<M00<005<MDad00e<M0`000U<M00<005<MDad00U<M10000e<M00<005<MDad00`001E<M00<0
05<MDad0100015<M00H005<M000005<M0005Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M
009C7@@000=C7@03001C7E<M00<000EC7@H000EC7@06001C7@00001C7@0015<M00<005<M00000P00
00=C7@00Dad00e<M10000U<M00<005<MDad00U<M10000U<M00<005<MDad00U<M10000e<M00<005<M
Dad00`0015<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad007oo01Moo`03001oogoo00Eo
o`04DY@aS7oo0004Ool00`00Oomoo`02Ool00`00Oomoo`0POol002aoo`03001oogoo008000Yoo`03
001oogoo03Uoo`<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC7@03001C7E<M00<0
00EC7@06001C7@00001C7@0015<M00<005<M00000P0000=C7@00Dad00e<M00@005<M0000009C7@03
001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@04001C7E<MDad3
0004Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<0009C
7@03001C7E<M00H000=C7@04001C7E<MDad30004Dad00`00DaeC7@040004Dad01P00Dad00000Dad0
00EC7@06001C7@00001C7@001E<M00D005<M000005<M008000AC7@<0009C7@03001C7E<M009C7@@0
00=C7@03001C7E<M00<000EC7@03001oogoo01Eoo`8000Moo`038@QS600000Aoo`068@QBU7ooOomB
U2488Woo000/Ool01@00Ool0000800002goo0P00=goo0P000U<M00<005<MDad00U<M00@005<M0000
009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000=C7@04001C7E<MDad30004Dad00`00
DaeC7@030005Dad00`00DaeC7@040004Dad01P00Dad00000Dad000EC7@06001C7@00001C7@001E<M
0`000U<M00<005<MDad00U<M10000e<M00<005<MDad00`001E<M00<005<MDad00`001E<M00H005<M
000005<M0004Dad500000e<M001C7@03Dad40002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@03
0004Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000AC7@D00003Dad005<M00=C7@06001C7@00
001C7@001E<M0`000U<M00<005<MDad00e<M0P0057oo0P0000=oo`00Ool01Woo00=[FR48000017oo
00IS61S6LiacW1S6HaPROol002aoo`<0000300P007oo00aoo`03001oogoo035oo`<000EC7@03001C
7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@@0009C7@03
001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@04001C7E<MDad3
0004Dad00`00Dad0000200000e<M001C7@03Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M
00<005<MDad00U<M0`000e<M00@005<MDaeC7@<000AC7@L000AC7@06001C7@00001C7@001E<M00H0
05<M000005<M0005Dad30002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@02Dad40003Dad00`00
DaeC7@040004Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M001C7@03Dad00`00Dad00002
00000e<M001oo`0GOol00`00Oomoo`05Ool00cW>249oo`04Ool015[F2488@V<H8goo000[Ool20000
0goo0000000?Ool00`00Oomoo`0]Ool30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005
Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C
7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad40003Dad00`00
DaeC7@030005Dad00`00DaeC7@030005Dad01P00Dad00000Dad000EC7@06001C7@00001C7@0015<M
10000U<M00<005<MDad01@0015<M00<005<MDad00`0015<M00@005<MDaeC7@<000AC7@03001C7@00
00800003Dad005<M00=C7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000EC7@<0
009C7@8000AC7@<000=C7@03001C7E<M00<000EC7@03001C7E<M00<000EC7@03001oogoo01Eoo`03
001oogoo03=oo`00:goo00<007ooOol00P0047oo00<007ooOol0:Woo0P000U<M00<005<MDad00U<M
00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00<0
00EC7@03001C7E<M00@000AC7@03001C7E<M00<000EC7@06001C7@00001C7@0015<M00@005<M0000
009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000=C7@04001C7E<MDad30004Dad01000
DaeC7E<M0`0015<M00@005<M0000009C7@04001C7E<MDad500000e<M001C7@04Dad30002Dad00`00
DaeC7@02Dad40003Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad0
0`00Dad0000200000e<M001C7@03Dad500000e<M001C7@03Dad30002Dad00`00DaeC7@03Dad30003
Dad01000DaeC7E<M0`005goo00<007ooOol0<Woo000[Ool00`00Oomoo`02000AOol00`00Oomoo`0V
Ool30005Dad00`00DaeC7@040004Dad01P00Dad00000Dad000EC7@06001C7@00001C7@0015<M0`00
0e<M00<005<MDad00U<M0`0015<M00<005<MDad010000e<M00@005<MDaeC7@<000AC7@03001C7E<M
00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@@0009C7@03001C
7E<M009C7@@000=C7@03001C7E<M00<000EC7@H000AC7@03001C7@0000800003Dad005<M00=C7@04
001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@03Dad30003Dad01000DaeC7E<M1000
0e<M00<005<MDad00`001E<M00<005<MDad0100015<M00H005<M000005<M0004Dad00`00Dad00002
00000e<M001C7@03Dad40002Dad00`00Oomoo`0EOol00`00Oomoo`0bOol002]oo`05001oo`0000P0
000BOol00`00Oomoo`0ROol30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030004Dad01000
DaeC7E<M0`0015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02
Dad30002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@040004Dad00`00DaeC7@030005Dad00`00
DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C
7@<0009C7@03001C7E<M00H000=C7@03001C7E<M00<000EC7@03001C7E<M00<000EC7@06001C7@00
001C7@0015<M00<005<M00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00U<M0`000e<M00@0
05<MDaeC7@@000=C7@80009C7@<000AC7@03001C7E<M00<000EC7@06001C7@00001C7@001E<M00<0
07ooOol05Goo00<007ooOol0<Goo000[Ool300000`08001oo`0BOol00`00Oomoo`0OOol20002Dad0
0`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M10000e<M
00<005<MDad00`001E<M00<005<MDad0100015<M00H005<M000005<M0004Dad01000Dad000000U<M
00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`000U<M00<005<MDad00e<M0`000e<M00<005<M
Dad00`001E<M00<005<MDad00`001E<M00H005<M000005<M0003Dad600000e<M001C7@03Dad30003
Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad0100015<M00H005<M0000
05<M0005Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@@0009C7@03001C7E<M009C
7@<000=C7@04001C7E<MDad30004Dad01000DaeC7E<M0`005goo00<007ooOol0<7oo000ZOol20000
17oo0000200057oo00<007ooOol06goo0`001E<M00<005<MDad0100015<M00H005<M000005<M0004
Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad0
0`0015<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@00
15<M00<005<M00000P0000=C7@00Dad00e<M0`000e<M00<005<MDad00U<M0`000e<M00@005<MDaeC
7@<000AC7@L000AC7@06001C7@00001C7@001E<M00H005<M000005<M0004Dad40002Dad00`00DaeC
7@02Dad30004Dad00`00DaeC7@030004Dad01000DaeC7E<M0`0015<M00H005<M000005<M0005Dad0
1@00Dad00000Dad00P0015<M00H005<M000005<M0004Dad40002Dad00`00DaeC7@02Dad40002Dad0
0`00Oomoo`0EOol00`00Oomoo`0`Ool002]oo`05001oo`0000P0000EOol00`00Oomoo`0GOol30003
Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01000Dad00000
0U<M00<005<MDad00U<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@02Dad30004Dad00`00
DaeC7@030005Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000EC7@06
001C7@00001C7@0015<M10000U<M00<005<M00001@0015<M00<005<MDad00`0015<M00@005<MDaeC
7@<000AC7@06001C7@00001C7@001E<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@02Dad4
0003Dad00`00DaeC7@030004Dad01000DaeC7E<M0`0015<M0P000U<M0`0015<M00H005<M000005<M
0005Dad01P00Dad00000Dad000AC7@8001Moo`03001oogoo02moo`0037oo1P0017oo00AJePQ2000i
cPEoo`04F]H8@P00>Lh7Ool01P00Oomoo`0000P001Ioo`03001oogoo01Aoo`80009C7@03001C7E<M
009C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC
7@030005Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M001C7@03Dad01000Dad000000U<M
00<005<MDad00U<M0`000U<M00<005<MDad00e<M0`000e<M00<005<MDad0100015<M00<005<MDad0
0`0015<M00@005<MDaeC7@<000AC7@04001C7@000002Dad01000DaeC7E<M0P0000EC7@00001C7@00
00EC7@<0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad0
0`00Dad0000200000e<M001C7@03Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M009C7@@0
00=C7@03001C7E<M00D0009C7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00H005<M0000
05<M000HOol00`00Oomoo`0^Ool000aoo`03BU8006<H009oo`06249oogooOomS61S60W>L00<@Q5:D
Ool00Woo00IS61S6LiacW124DY@6Ool00`00Ool0000200P00`00Oomoo`0EOol00`00Oomoo`0AOol3
0004Dad00`00DaeC7@040004Dad01000Dad000000U<M00H005<MDaeC7@00Dad20002Dad00`00DaeC
7@02Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@030005Dad00`00DaeC7@040004Dad0
1P00Dad00000Dad000AC7@03001C7@0000800003Dad005<M00=C7@<000=C7@03001C7E<M009C7@<0
00=C7@03001C7E<M00D000=C7@03001C7E<M00@000AC7@H000AC7@03001C7@0000800003Dad005<M
00=C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad40003Dad00`00DaeC
7@030005Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M001C7@03Dad01P00Dad00000Dad0
00EC7@<0009C7@8000=C7@@000=C7@03001C7E<M00D000=C7@03001C7E<M00<000AC7@03001oogoo
01Eoo`03001oogoo02ioo`003Goo00=:DP00HaP01Goo00HQ25:DOomooe:D6<H3Ool01R48DYAoogoo
DY@HaPIoo`03001oo`0000802003001oogoo01Ioo`03001oogoo00eoo`<000=C7@03001C7E<M00@0
00AC7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad0
1P00Dad00000Dad000AC7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@03001C
7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03
001C7E<M009C7@<000AC7@L000=C7@03001C7E<M00@000AC7@03001C7E<M00<000EC7@06001C7@00
001C7@0015<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M00=C7@<000=C7@03
001C7E<M00<000EC7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C7@@00003Dad0
05<M00AC7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00<001Moo`03001oogoo02eoo`00
0goo1`0017oo00=BU0Q2HaP017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`<000802003001oogoo01Moo`03001oogoo00Yoo`800003Dad005<M00=C7@<000=C7@03001C7E<M
009C7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@04001C
7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad0
0U<M0`0015<M00<005<MDad00`001E<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M
009C7@06001C7@00001C7@000e<M1@000U<M00<005<MDad00U<M0`0015<M00<005<MDad010000e<M
00@005<MDaeC7@<000AC7@03001C7E<M00<000EC7@06001C7@00001C7@0015<M00<005<M00000P00
00=C7@00Dad00e<M0`000U<M00<005<MDad00e<M0`000e<M00<005<MDad00`001E<M00<005<MDad0
10000e<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad00e<M0`000U<M
00<007ooOol057oo0`00;Woo000?Ool00f<H249S6003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007oo00000P0800<007ooOol067oo00<007ooOol01Woo0`0015<M00@0
05<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC
7@02Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@040004Dad01P00
Dad00000Dad000AC7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@03Dad30003
Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad500000e<M001C7@03Dad01P00Dad00000Dad0
00EC7@<0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00@000=C7@04001C7E<MDad30004Dad0
0`00DaeC7@030005Dad01P00Dad00000Dad000AC7@03001C7@0000800003Dad005<M00=C7@<0009C
7@03001C7E<M00=C7@<000=C7@03001C7E<M00<000EC7@03001C7E<M00<000EC7@@00003Dad005<M
00=C7@03001oogoo01Eoo`03001oogoo02aoo`0047oo00=BU1S6Ool00Woo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0000802003001oogoo01Uoo`8000=oo`<000=C
7@03001C7E<M00<000EC7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00@005<M0000009C
7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000AC7@03001C7E<M00@000AC7@03001C7E<M
00<000AC7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00<005<M00000P0000=C7@00Dad0
0e<M0`000e<M00<005<MDad00U<M0`000e<M1P001E<M00<005<MDad00`0015<M00<005<M00000P00
00=C7@00Dad00e<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@@000=C
7@03001C7E<M00@000=C7@04001C7E<MDad30004Dad00`00DaeC7@030005Dad01P00Dad00000Dad0
00AC7@03001C7@0000800003Dad005<M00=C7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M
00<000EC7@03001C7E<M00<001Moo`03001oogoo02]oo`004Goo00H007ooOomoob48DY@2Ool00e:D
8@Qoo`02Ool01R48DYAoogooDY@Q20Ioo`8000<02003001oogoo01]oo`<0009C7@04001C7E<MDad3
0003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad0
0000Dad000AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30003Dad0
0`00DaeC7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000EC
7@06001C7@00001C7@000U<M1@000e<M00<005<MDad00U<M0`000e<M00<005<MDad00`001E<M00<0
05<MDad00`001E<M00H005<M000005<M0004Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M
00<005<MDad00U<M10000e<M00<005<MDad010000e<M00@005<MDaeC7@<000AC7@03001C7E<M00<0
00EC7@05001C7@00001C7@020003Dad00`00Dad0000200000e<M001C7@03Dad30002Dad00`00DaeC
7@03Dad30003Dad00`00Oomoo`0EOol00`00Oomoo`0ZOol000aoo`06001247>LOolicQS60goo00IS
61S6LiacW1S6HaP3Ool01V<H6<IcW7>L6<IS60Eoo`03001oo`0000<02003001oogoo01Uoo`@000AC
7@03001C7@00009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00
DaeC7@02Dad30004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01000Dad000000U<M00<0
05<MDad00U<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@04
0004Dad00`00DaeC7@030004Dad01000DaeC7E<M0`000e<M1@000U<M00<005<MDad00U<M00H005<M
000005<M0004Dad30003Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad0
0`001E<M00H005<M000005<M0004Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M009C7@@0
00=C7@03001C7E<M00@000=C7@04001C7E<MDad30004Dad2000015<M000000001E<M00H005<M0000
05<M0004Dad00`00Dad0000200000e<M001C7@03Dad2000FOol00`00Oomoo`0ZOol000aoo`06DY@H
aP00000YBW>L17oo00AJePQ2249S60Eoo`04F]H8@PQ2HaP6Ool00`00Ool0000300P01@00Oomoogoo
00004goo100015<M00<005<MDad00`0015<M00<005<MDad0100015<M00H005<M000005<M0004Dad0
1000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M0`0015<M00<005<MDad00`00
1E<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad01@000e<M1P001E<M00<005<MDad00`0015<M
00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@0015<M10000U<M00<005<MDad00U<M
0`000e<M00@005<MDaeC7@<000AC7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C
7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M10000e<M00<005<MDad010000e<M00@0
05<MDaeC7@<000AC7@03001C7E<M00<000EC7@@00003Dad007oo01Ioo`03001oogoo02Uoo`00:Goo
0`000`0800D007ooOomoo`00011oo`<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC
7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@04001C7@000002Dad01P00DaeC7E<M001C7@80
009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C
7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03
001C7E<M00D000=C7@04001C7E<MDad40003Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad0
1000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004Dad40002Dad00`00DaeC7@02Dad3
0003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M001C7@03Dad0
1P00Dad00000Dad000EC7@<0009C7@8000=C7@@0009C7@04001C7E<MDad40003Dad00`00DaeC7@03
0005Dad00`00Oomoo`0EOol00`00Oomoo`0XOol002Uoo`03001oo`0000<02005001oogooOol0000>
Ool20002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M009C7@<000AC
7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@04001C7@000002Dad0
0`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@0
00AC7@03001C7E<M00<000AC7@04001C7@000002Dad01000DaeC7E<M1@0000=C7@00Dad00e<M1000
0U<M00<005<MDad00U<M0`000e<M00@005<MDaeC7@@000=C7@03001C7E<M00<000EC7@03001C7E<M
00<000AC7@06001C7@00001C7@001E<M00H005<M000005<M0004Dad30004Dad00`00DaeC7@040003
Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M001C7@03Dad40000
0e<M001C7@03Dad40002Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M0`005Woo00<007ooOol0
:7oo000YOol2000400P00`00Oomoo`02000<Ool30004Dad00`00DaeC7@040003Dad01000Dad00000
0U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<0
00AC7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@04001C7@000002
Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad00`00DaeC
7@040004Dad60004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004Dad40002
Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M10000e<M00<005<MDad00`0015<M00@005<MDaeC
7@<000AC7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M0`000e<M00@005<MDaeC7@@0
00=C7@03001C7E<M00<000EC7@03001C7E<M00@000=C7@06001C7@00001C7@001E<M00H005<M0000
05<M0004Dad40002Dad00`00Oomoo`0EOol00`00Oomoo`0WOol002Uoo`8000@02003001oogoo0080
00Uoo`<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@06001C
7@00001C7@0015<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000AC
7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00@005<M0000009C
7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000AC7@L000=C7@03001C7E<M00@000AC7@03
001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@@0009C
7@03001C7E<M009C7@<000=C7@03001C7E<M00D000=C7@03001C7E<M00<000AC7@03001C7@000080
0003Dad005<M00=C7@06001C7@00001C7@0015<M10000U<M00<005<MDad00U<M0`000e<M00@005<M
DaeC7@@000=C7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad01P00Dad00000Dad000EC7@03
001oogoo01Eoo`03001oogoo02Ioo`00:7oo00<007oo00000`0800@007ooOomoo`8000Moo`800003
Dad005<M00=C7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<0
00AC7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@03001C7E<M009C
7@<0009C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@06001C
7@00001C7@0015<M00@005<M0000009C7@03001C7E<M00D0009C7@03001C7E<M009C7@<000AC7@03
001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00
DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00<0
00EC7@03001C7E<M00<000AC7@06001C7@00001C7@001E<M00H005<M000005<M0004Dad40002Dad0
0`00DaeC7@02Dad30003Dad00`00DaeC7@050003Dad00`00DaeC7@030004Dad00`00DaeC7@03000G
Ool00`00Oomoo`0VOol002Qoo`<000<02004001oogooOol20004Ool40003Dad01000Dad000000U<M
00<005<MDad00U<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC
7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@04001C
7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030004Dad0
0`00DaeC7@040003Dad500000e<M001C7@03Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M
00<005<MDad00U<M0`0015<M00<005<MDad010000e<M00<005<MDad00`001E<M00<005<MDad00`00
15<M00H005<M000005<M0005Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00=C7@<000=C
7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad01P00Dad00000Dad000EC7@@00003Dad00000
00=C7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00@000=C7@03001oogoo01Eoo`03001o
ogoo02Eoo`00:7oo00<007oo00000`0800@007ooOomoo`H000AC7@03001C7E<M00<000AC7@03001C
7E<M00@000=C7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03
001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC
7@06001C7@00001C7@0015<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@0
00AC7@H000AC7@03001C7E<M00<000EC7@06001C7@00001C7@0015<M00H005<M000005<M0005Dad3
0002Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M10000e<M00<005<MDad00`0015<M00@005<M
DaeC7@<000AC7@06001C7@00001C7@0015<M00<005<M00000P0000=C7@00Dad00e<M0`000e<M00<0
05<MDad01@000e<M00<005<MDad00`0015<M00<005<MDad00`001E<M00H005<M000005<M0004Dad0
0`00Dad0000200000e<M001C7@03Dad30002Dad00`00DaeC7@02Dad2000EOol3000VOol002Qoo`80
00@02003001oogoo00<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M
00<000AC7@03001C7E<M00@000=C7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03
001C7E<M00@000AC7@06001C7@00001C7@0015<M0`000e<M00<005<M00001@000e<M00<005<MDad0
10000e<M00@005<MDaeC7@<000AC7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C
7@06001C7@00001C7@0015<M10000U<M00<005<MDad00U<M0`000e<M00<005<MDad01@000e<M00<0
05<MDad00`0015<M00<005<MDad00`001E<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@03
Dad30003Dad00`00DaeC7@040003Dad01000DaeC7E<M0`0015<M00<005<MDad00`001E<M100000=C
7@00Dad00e<M00H005<M000005<M000GOol00`00Oomoo`0TOol002Qoo`8000@020<0009C7@03001C
7E<M009C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad01000
15<M00<005<MDad00`0015<M00<005<MDad010000e<M00@005<M0000009C7@03001C7E<M009C7@06
001C7@00001C7@0015<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad0100015<M00<005<M
Dad00`0015<M00@005<M0000009C7@03001C7E<M00<00005Dad00000Dad00004Dad30002Dad00`00
DaeC7@02Dad40003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad0
1000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@03Dad3
0003Dad00`00DaeC7@040003Dad01000DaeC7E<M0`0015<M00H005<M000005<M0004Dad00`00Dad0
000200000e<M001C7@03Dad30002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@040003Dad00`00
DaeC7@030005Dad00`00DaeC7@030004Dad00`00Oomoo`0EOol00`00Oomoo`0SOol002Qoo`8000<0
20<000AC7@03001C7E<M00@000=C7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03
001C7E<M00@000=C7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000AC
7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@800004Dad000000004Dad01P00Dad00000Dad0
00AC7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC
7@040003Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@03001C
7@0000800003Dad005<M00=C7@<000=C7@03001C7E<M00D000=C7@03001C7E<M00<000AC7@03001C
7E<M00<000EC7@06001C7@00001C7@0015<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@02
Dad30003Dad01000DaeC7E<M10000e<M00<005<MDad00`005Woo00<007ooOol08goo000WOol01000
Ool000080P000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<MDad010000e<M00@0
05<M0000009C7@03001C7E<M009C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00U<M0`00
0e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00@005<M0000009C
7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000AC7@L000=C7@03001C7E<M00<000AC7@03
001C7E<M00@000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@03001C7E<M009C7@<0009C
7@03001C7E<M009C7@<000=C7@04001C7E<MDad40003Dad00`00DaeC7@030004Dad00`00DaeC7@04
0004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00@000=C
7@04001C7E<MDad30004Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M001C7@03Dad01P00
Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@<000=C7@03001oogoo01Aoo`03001oogoo029o
o`009goo0`0000<0200000000e<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad0100015<M
00<005<MDad00`0015<M00<005<MDad010000e<M00@005<M0000009C7@03001C7E<M009C7@06001C
7@00001C7@0015<M0`0015<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad01000
15<M00H005<M000005<M0004Dad01000Dad000000U<M00<005<MDad01@000U<M00<005<MDad00U<M
0`000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<MDad0100015<M00H005<M0000
05<M0004Dad01P00Dad00000Dad000AC7@@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00<005<M00000P0000=C7@00Dad00e<M0`00
0U<M00<005<MDad00U<M10000e<M00<005<MDad010000e<M00<005<MDad00`001E<M00<005<MDad0
0`0015<M00H005<M000005<M0005Dad400000e<M001C7@03Dad2000FOol00`00Oomoo`0QOol002Mo
o`80008020<00005Dad005<MDad00004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M009C
7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@04001C7@00
0002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040004Dad00`00
DaeC7@030004Dad00`00DaeC7@040003Dad500000e<M001C7@03Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M
00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30003Dad01000
DaeC7E<M10000e<M00<005<MDad00`0015<M00<005<MDad00`001E<M00H005<M000005<M0004Dad0
1P00Dad00000Dad000EC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00D000=C7@03001C
7E<M00<000AC7@03001C7E<M00<000EC7@@00003Dad007oo01Eoo`03001oogoo025oo`009goo0P00
00H02000Ool0000:0004Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<MDad00U<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040004Dad01P00Dad00000Dad000AC7@04001C7@000002Dad01000DaeC7E<M0`000e<M00<005<M
Dad00U<M0`000e<M00<005<MDad0100015<M1P0015<M00<005<MDad00`0015<M00@005<M0000009C
7@03001C7E<M009C7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00e<M0`000e<M00<005<M
Dad010000e<M00<005<MDad0100015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@@0
009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@04001C7E<MDad30004Dad00`00DaeC
7@030004Dad00`00Dad0000200000e<M001C7@03Dad01P00Dad00000Dad000AC7@<0009C7@03001C
7@0000=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000EC7@03001oogoo01Aoo`03001o
ogoo021oo`006goo00AJePQ2000icPQoo`80000400P007oo000200X00`00DaeC7@040004Dad00`00
DaeC7@030004Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<MDad00U<M00H005<M0000
05<M0004Dad30004Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad0
0`00Dad00002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03001C7@0000D000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@00
15<M00<005<M00000P0000=C7@00Dad00e<M0`000e<M00<005<MDad0100015<M00<005<MDad00`00
15<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@0015<M
0`000U<M00<005<MDad00U<M10000e<M00<005<MDad010000e<M00<005<MDad00`001E<M00<005<M
Dad00`0015<M00H005<M000005<M0004Dad500000e<M001C7@03Dad30003Dad00`00DaeC7@040003
Dad01000DaeC7E<M0`005Woo00<007ooOol07goo000JOol01V<H6<IcW7>L48ABU0Moo`80000400P0
07oo000300X20003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@030004
Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M
0`000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00@005<M0000
009C7@03001C7E<M00<00005Dad00000Dad00004Dad30002Dad00`00DaeC7@02Dad30004Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@<0
009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000EC7@03001C7E<M
00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@02Dad3
0003Dad00`00DaeC7@050003Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad400000e<M001C
7@03Dad30002Dad00`00DaeC7@02Dad40002Dad00`00Oomoo`0DOol00`00Oomoo`0OOol001Yoo`06
8@QBU7ooOomBU1S61Woo00L007oo00002000Ool0000300X20004Dad01000Dad000000U<M00@005<M
DaeC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@06001C
7@00001C7@0015<M00@005<M0000009C7@04001C7E<MDad30003Dad00`00DaeC7@02Dad30003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad3000015<M0000000015<M00H005<M000005<M0004
Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad01000
15<M00<005<MDad00`0015<M00H005<M000005<M0004Dad00`00Dad0000200000e<M001C7@03Dad3
0002Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M10000e<M00<005<MDad00`0015<M00<005<M
Dad00`0015<M00<005<M00000P0000=C7@00Dad00e<M00H005<M000005<M0004Dad30003Dad01000
DaeC7E<M10000e<M00<005<MDad010000e<M0P0000AC7@00000000EC7@@00003Dad005<M00=C7@06
001C7@00001C7@0015<M0P005Woo00<007ooOol07Woo000JOol00`00Oomoo`02Ool00`00Oomoo`04
Ool200001008001oo`00100:00<007oo00000U<M100015<M00<005<M00000U<M00<005<MDad00U<M
0`000U<M00<005<MDad00U<M0`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<M
Dad0100015<M00<005<M00000U<M00<005<MDad00U<M00H005<M000005<M0004Dad30004Dad00`00
DaeC7@030004Dad70003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad01P00Dad00000Dad0
00AC7@<0009C7@03001C7E<M009C7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03
001C7E<M00@000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad40003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad01P00Dad0
0000Dad000AC7@@0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00EC7@03001C7E<M00<000AC7@06001C7@00001C7@005goo00<007ooOol07Goo000JOol00`00Oomo
o`02Ool00`00Oomoo`04Ool200001008001oo`000`0:00<007ooOol00`0015<M00<005<MDad00`00
15<M00@005<M0000009C7@06001C7E<MDad005<M0P000U<M00<005<MDad00U<M0`000U<M00<005<M
Dad00U<M0`000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00@0
05<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M00D000=C7@03001C7E<M00@000AC7@03
001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@03
001C7E<M009C7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<0
00AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02
Dad30003Dad00`00DaeC7@040003Dad01000DaeC7E<M10000e<M00<005<MDad00`0015<M00H005<M
000005<M0005Dad400000e<M001C7@03Dad30002Dad20003Dad30003Dad01000DaeC7E<M10000e<M
00<005<MDad00`0015<M00<007ooOol04goo0P007goo000JOol00`00Oomoo`02Ool00`00Oomoo`04
Ool200001008001oo`000`0:00@007ooOol000802`03001C7E<M00@000=C7@03001C7E<M00@000AC
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@04001C7E<MDad30004
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad01P00Dad00000Dad0
00=C7@D00003Dad005<M00=C7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000AC7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004
Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030005Dad01P00Dad0
0000Dad000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M10000e<M00<005<MDad0
10000e<M00<005<MDad00`0015<M00<005<MDad00`001E<M00H005<M000005<M0004Dad400000e<M
001C7@03Dad40002Dad01000DaeC7E<M10000e<M00<005<MDad00`005Woo00<007ooOol077oo000J
Ool01R48DYAoogooDY@Q20Ioo`80000400P007oo000300X01000Oomoo`000`0;0P000e<M00@005<M
DaeC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C
7@00009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@03
001C7E<M00<000AC7@H000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC
7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C
7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30003Dad0
0`00DaeC7@040003Dad01000DaeC7E<M0`0015<M00<005<MDad00`0015<M00H005<M000005<M0004
Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@04
001C7E<MDad30004Dad00`00DaeC7@040003Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M
009C7@<000=C7@03001oogoo01Aoo`03001oogoo01]oo`006Woo00IS61S6LiacW1S6HaP6Ool30002
Ool01@0000X02P0:00000Woo00@0000;00/02`8000AC7@03001C7@00009C7@03001C7E<M009C7@<0
00=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C
7@0015<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000=C7@L000=C
7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00@005<M0000009C
7@04001C7E<MDad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004
Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M10000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<M00000P0000=C
7@00Dad00e<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@050002Dad01000DaeC7E<M1000
0e<M00<005<MDad00`0015<M00H005<M000005<M0005Dad400000e<M001C7@03Dad2000EOol00`00
Oomoo`0KOol001]oo`04F]H8@PQ2HaP6Ool200001@08001oogoo00000`0:00@007ooOol000802`04
001gdWOB0002Dad30004Dad01000Dad000000U<M00@005<MDaeC7@<000=C7@03001C7E<M009C7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@06001C7@00001C
7@0015<M00H005<M000005<M0002Dad50004Dad00`00DaeC7@030004Dad00`00DaeC7@040003Dad0
0`00DaeC7@030004Dad00`00DaeC7@040004Dad00`00Dad00002Dad00`00DaeC7@02Dad30002Dad0
0`00DaeC7@02Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@030004
Dad01P00Dad00000Dad000AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad01P00Dad00000
Dad000AC7@<0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@03001C7E<M00<000EC7@@00003Dad007oo01Eoo`03001oogoo00Qoo`06Li`Q2000000YBW>L17oo
00AJePQ2000icPAoo`009Goo0P0000D02000Oomoo`0000802P04001oogoo000300/00`00Mm9gdP03
0003Dad00`00DaeC7@040004Dad00`00Dad00002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC
7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@03001C7E<M
00<000=C7@D0009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M0000
05<M0004Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
0`00DaeC7@030005Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@<000=C7@03001C
7E<M00@000=C7@04001C7E<MDad40003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06
001C7@00001C7@001E<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
0`001E<M00<007ooOol057oo00<007ooOol01goo00HYBSW>OomoocW>:DX3Ool01V<H6<IcW7>L48AB
U0=oo`009Goo0P0000D02000Oomoo`0000802P04001oogoo000200/02000Mm800000Ool002Sc0002
Dad30004Dad00`00DaeC7@030004Dad00`00DaeC7@040003Dad01000Dad000000U<M00@005<MDaeC
7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@L000AC
7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30004Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01000Dad000000U<M00<0
05<MDad00U<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00@005<MDaeC7@<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30002Dad0
0`00DaeC7@02Dad40003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004
Dad00`00Dad0000200000e<M001C7@03Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@04
0003Dad00`00DaeC7@03000FOol00`00Oomoo`07Ool00`Q2Oomoo`02Ool01P00Oomoogoo8@QBU09o
o`03DY@HaWoo009oo`009Goo0`000goo00@0000:00X0009oo`0300002`0;008000=oo`03000XlbSc
008000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7@00
009C7@03001C7E<M009C7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`0015<M1P00
15<M00<005<MDad00`0015<M00<005<MDad00`0015<M00@005<M0000009C7@06001C7E<MDad005<M
0P000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad0100015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C
7@<000=C7@03001C7E<M00D000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00
001C7@0015<M00H005<M000005<M0005Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030005Dad400000e<M001C7@03Dad01P00Dad00000Dad000AC7@<0009C7@03001C
7E<M009C7@<000=C7@03001oogoo01Aoo`03001oogoo00Ioo`03001cW7oo009oo`05001oogooOol0
0004Ool00`00Oomoo`01Ool002Eoo`<000=oo`0400002P0:0002Ool01@0000/007OB00000goo00D0
02Sc:?<Xl`0000=C7@<000=C7@04001C7E<MDad30004Dad00`00DaeC7@040003Dad00`00DaeC7@03
0004Dad00`00DaeC7@040003Dad01000Dad000000U<M00H005<MDaeC7@00Dad20002Dad00`00DaeC
7@050003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@0
00AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M0000
05<M0004Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
0`00DaeC7@030004Dad00`00Dad0000200000e<M001C7@03Dad30002Dad00`00DaeC7@02Dad30003
Dad00`00DaeC7@040003Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00AC7@06001C7@00001C7@0015<M0P005Woo00<007ooOol01Goo00H002U:LiaoocW>:DX3Ool00`00
Oomoo`02Ool00`00Oomoo`01Ool002Eoo`0300002000009oo`0400002P0:0003Ool0100000/00000
17oo00<002Sc:?<00RSc00<005<M00000U<M00<005<MDad00U<M00<005<M00000U<M00<005<MDad0
0U<M0`000e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<M
Dad00`000e<M1@0000=C7@00Dad00e<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad01000
15<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00Dad00000
Dad000AC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03
001C7E<M00<000AC7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M0`000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad00`001E<M100000=C7@00Dad00e<M00H005<M
000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@050002Dad01000DaeC7E<M0`00
15<M00<005<MDad00`0015<M00H005<M000005<M000FOol00`00Oomoo`05Ool01Q24>Lh00000:DYc
W0=oo`03001oogoo009oo`03001oogoo005oo`0097oo0P0000D02000Oomoo`0000802P04001oogoo
Ool30005Ool00`00:?<Xl`03:?<00`00DaeC7@02Dad00`00DaeC7@030004Dad01000Dad000000U<M
00@005<MDaeC7@<000=C7@04001C7E<MDad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad60004Dad01P00Dad00000Dad000AC7@04001C7@000002Dad01000DaeC7E<M0`0015<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00@005<M
0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C7@06001C7@00
001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`001E<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00
DaeC7@050002Dad01000DaeC7E<M10000e<M00<005<MDad00`0015<M00<007ooOol057oo00<007oo
Ool017oo00=2436<Ool01Woo00HQ25:DOomooe:D8@P3Ool002Aoo`<000=oo`0400002P0:0003Ool2
0007Ool00`00:?<Xl`02:?<20002Dad40003Dad00`00DaeC7@040004Dad00`00Dad00002Dad00`00
DaeC7@02Dad00`00Dad00002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad70003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00Dad00002Dad00`00DaeC7@02Dad30002Dad0
0`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004
Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad3
0002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad01000DaeC7E<M10000e<M00<005<M
Dad00`0015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00D0
009C7@04001C7E<MDad40002Dad01000DaeC7E<M0`004goo10001Woo00<HaS6<JeX01Goo00IS61S6
LiacW1S6HaP3Ool002Aoo`<000=oo`0400002P0:0003Ool00`00Oomoo`06Ool01@00:?<XlbSc0000
0RVI0P0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M
000005<M0004Dad30002Dad00`00DaeC7@050004Dad00`00DaeC7@030004Dad00`00DaeC7@030004
Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000U<M00<0
05<MDad00U<M0`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040004Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M
0`000U<M00<005<MDad00U<M10000U<M00@005<MDaeC7@@000=C7@03001C7E<M00<000AC7@03001C
7E<M00<000AC7@05001C7@00001C7@020003Dad30002Dad00`00DaeC7@02Dad40002Dad00`00DaeC
7@050002Dad00`00Oomoo`0DOol00`00Oomoo`05Ool013W>2480012417oo00AJePQ2249S60Aoo`00
97oo0`000goo00<0000:00003Goo00H002Sc:?<007oo0002:IT00`00DaeC7@02Dad30003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<M
Dad01@000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M
00<005<MDad00`0015<M00<005<MDad00`0015<M00@005<M0000009C7@06001C7E<MDad005<M0P00
0U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M009C7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C
7@0015<M00H005<M000005<M0004Dad40002Dad01000DaeC7E<M10000e<M00<005<MDad010000e<M
00<005<MDad00`0015<M100000=C7@00Dad00e<M00H005<M000005<M0004Dad30002Dad00`00DaeC
7@02Dad2000FOol00`00Oomoo`0DOol002Aoo`030000200000=oo`0300002P0000eoo`03000Xl`00
009oo`06000YVBVI:IT005<M0P0000=C7@00Dad00e<M0`000U<M00<005<MDad00U<M0`0015<M00<0
05<MDad00`0015<M00<005<MDad00`000e<M0`0000AC7@00000000AC7@06001C7@00001C7@0015<M
00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@040004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@04001C7@000002
Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M10000U<M
00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad01P00Dad00000Dad001Ioo`03001oogoo01Aoo`0097oo0P0017oo
00<0000:00003Goo0P000goo00<002VI:IT010000e<M00@005<M0000009C7@06001C7E<MDad005<M
0P000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M1`000e<M00<005<MDad00`0015<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad01000DaeC7E<M0`0015<M00<005<M
Dad00`0015<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00
Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0005
Dad400000e<M001C7@03Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004Dad00`00DaeC7@030004Dad00`00Oomoo`0DOol00`00Oomoo`0COol002=oo`@000=oo`03
00002P0000eoo`03001oogoo00=oo`8000ABN@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06
001C7@00001C7@0015<M0`000U<M00<005<M00001@000e<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00@005<M0000009C7@03001C7E<M009C7@03001C7@00009C7@03
001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`000e<M00<0
05<MDad0100015<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad0
1P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000AC7@03001C7E<M00<000EC7@@00003Dad005<M00=C7@<0009C7@03001C7E<M009C7@<000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<001Ioo`03001oogoo019oo`00
8goo0`0017oo00<0000:00004goo00<0059iDWT00e9i0`000e<M00<005<MDad010000e<M00<005<M
Dad00`0015<M00H005<M000005<M0003Dad200000e<M00000002Dad01000DaeC7E<M0`0015<M00<0
05<MDad00`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`0015<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030005Dad400000e<M001C7@03Dad400000e<M00000003Dad30002Dad0
1000DaeC7E<M10000e<M00<005<MDad010000e<M00<007ooOol04goo00<007ooOol04Woo000SOol3
0004Ool2000EOol01000DWUBNE9i10000U<M10000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M1`0015<M00<005<M00000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002
Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0004Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030005Dad00`00Dad000020005Dad400000e<M001C7@02Dad40002Dad01000DaeC
7E<M10000U<M00@005<MDaeC7@<001Eoo`03001oogoo015oo`0017oo1P0017oo00AJePQ2000icPEo
o`04F]H8@P00>Lh8Ool00`0000P00003Ool00`0000X0000FOol01@00DWT007oo00000SFh0P0015<M
00<005<MDad00`0015<M00<005<MDad00`0015<M1P0015<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad01000
15<M0`0000=C7@00Dad00e<M10000U<M00@005<MDaeC7@@0009C7@03001oogoo019oo`<0019oo`00
17oo00=:DP00HaP00Woo00H8@WooOomoof<H6<H2Li`00a24DYAoo`02Ool01V<H6<IcW7>L48ABU0Mo
o`8000Aoo`0300002P0001Moo`05001oogooOol00002=KP00`00DaeC7@02Dad30002Dad00`00DaeC
7@02Dad30003Dad70003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00@005<M0000009C7@04001C7E<MDad30003Dad01000
DaeC7E<M0`0015<M00<005<MDad00`0015<M00<005<MDad010000e<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M
00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M0P0000AC7@000000
00AC7@06001C7@00001C7@001E<M0`0000=C7@00Dad00e<M0P0047oo0`000Woo00<007ooOol047oo
0005Ool00dYB001S6005Ool01R48DYAoogooDY@HaP=oo`068@QBU7ooOomBU1S61goo0P0017oo00<0
000:00006goo00H003Fh=KPe^000Dad200000e<M001C7@03Dad01P00Dad00000Dad0009C7@D000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@04001C7@000002Dad01000DaeC7E<M0`000e<M00@005<MDaeC7@<000AC7@03001C7E<M00<000AC
7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@03001C7@00009C7@03001C7E<M009C7@03001C
7@00009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@003Goo0`001Goo00<007oo
Ool047oo0006Ool00e:D249S6004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
1Goo0P0017oo0P0077oo00@003Fh=KPe^0<000=C7@03001C7E<M00@0009C7@D0009C7@04001C7E<M
Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<M
Dad00`0015<M00<005<M00000U<M00<005<MDad00U<M00<005<M00000U<M00<005<MDad00U<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@00
15<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M
Dad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Oomoo`06Ool40008Ool00`00Oomo
o`0@Ool000Moo`03HaP8@V<H00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04
Ool30004Ool2000MOol30003Iid00`00DaeC7@030003Dad3000015<M0000000015<M00<005<M0000
0U<M00<005<MDad00U<M00<005<M00000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004
Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0017oo0`0037oo00<007ooOol047oo
0008Ool00e:D6<Ioo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo0P00
1Goo0P007Goo0`000VNM10000e<M1`000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`00
15<M00D005<M000005<M008000=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@@0
011oo`03001oogoo00moo`002Goo00H007ooOomoob48DY@2Ool00e:D8@Qoo`02Ool01R48DYAoogoo
DY@Q20Ioo`8000Eoo`80021oo`8000=CG`L000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@<000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC
7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad3
0002Dad01000DaeC7E<M0`004Woo00<007ooOol03goo0004Ool01P00@Q1cW7oo>LhHaP=oo`06HaPH
aW>LLi`HaV<H0goo00IS61S6LiacW1S6HaP6Ool20005Ool00`00Oomoo`0QOol00`00Del000030003
Dad01000DaeC7E<M0`0015<M00<005<MDad00`0015<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00@005<M0000009C7@06001C7E<MDad005<M0P0000=C7@00Dad00e<M0`000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30002Dad01000DaeC7E<M10000U<M00@005<M
DaeC7@@0009C7@04001C7E<MDad30004Dad400000e<M001C7@03Dad400000e<M001C7@02Dad40002
Dad00`00Oomoo`0@Ool00`00Oomoo`0?Ool000Aoo`06DY@HaP00000YBW>L17oo00AJePQ2249S60Eo
o`04F]H8@PQ2HaP7Ool20005Ool00`00Oomoo`0POol40002AUX00`00DaeC7@02Dad00`00Dad00002
Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@03
0004Dad00`00DaeC7@030003Dad01000Dad000000U<M00@005<MDaeC7@<000AC7@03001C7E<M00<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C
7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00
001C7@0015<M100000=C7@00Dad00U<M10000U<M00<005<MDad01@000U<M00<005<MDad01@000U<M
0P0000AC7@00000000EC7@03001C7@00008000EC7@<00003Dad005<M00=C7@80015oo`03001oogoo
00moo`008Woo0P0017oo0P007goo0`000Woo00<004IJAUX00TIJ00<005<MDad00`0015<M00H005<M
000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030004Dad00`00Dad00002Dad00`00DaeC7@02Dad30002Dad01000DaeC7E<M0`00
15<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C
7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@04001C7E<MDad30004Dad00`00Dad0
00020005Dad300000e<M001C7@03Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad0015oo`03001oogoo00moo`00
8Goo0P001Goo0P0077oo0`001Woo00@004IJAUY6FP<000=C7@03001C7E<M00@000=C7@06001C7@00
001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad00`00Dad00002Dad00`00DaeC7@02Dad30003
Dad00`00DaeC7@030004Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030004
Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad3
0003Dad00`00DaeC7@040002Dad00`00DaeC7@050002Dad00`00DaeC7@040003Dad00`00DaeC7@03
0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000AC7@03001oogoo00ioo`03001oogoo00moo`008Goo0P00
1Goo0P006Goo0`002Goo00@004IJ000000=S_P03001C7E<M00<000AC7@03001C7E<M00<000=C7@04
001C7@000002Dad01000DaeC7E<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004
Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C
7@0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03000?Ool00`00Oomoo`0?Ool0025oo`8000Eo
o`03001oogoo01Eoo`<000eoo`<0009S_P@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@03001C7@00009C7@06001C7E<MDad005<M0P000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C
7@0015<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad00`0015<M00<005<MDad00`000e<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C
7@00001C7@000e<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01@00Dad00000Dad00P000e<M0`00
0U<M00@005<MDaeC7@@0009C7@04001C7E<MDad40002Dad00`00Oomoo`0>Ool00`00Oomoo`0>Ool0
025oo`03001oogoo00Aoo`03001oogoo019oo`<001=oo`8000=:_003001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@03001C7@00009C7@04001C7E<M
Dad30004Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01000
0e<M00<005<MDad00`000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M
0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@030004Dad300000e<M001C7@03Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C
7@000e<M10000U<M00<005<MDad01@000U<M00<005<MDad00`003goo00<007ooOol03Woo000QOol0
0`00Oomoo`0FOol3000GOol01000B[a:_4Zl0`0015<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M00000U<M00<005<MDad00U<M0`00
0e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
15<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00
DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<0
00AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad010000U<M00@005<MDaeC7@<000AC7@<00003Dad005<M00=C7@<0
00=C7@03001C7E<M00@000=C7@03001oogoo00aoo`03001oogoo00ioo`0087oo0`005Goo0P006goo
00<004Zl00000U;L00<005<MDad00U<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad01000DaeC
7E<M0`0015<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C
7E<M009C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad0
10000U<M00<005<MDad01@000U<M0P0000AC7@00000000AC7@06001C7@00001C7@0015<M0`000U<M
00<005<MDad00U<M0P003Goo00<007ooOol03Woo000POol2000COol3000NOol00`00D]aBg002D]`0
1P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<000AC7@03001C7E<M00<000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00<005<M00000U<M00<005<MDad0
0U<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C
7@0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad00`0015<M00H005<M000005<M0004Dad30002Dad01000DaeC7E<M10000U<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00Dad0
0000Dad000eoo`03001oogoo00ioo`0087oo00<007ooOol03goo0`008Woo00<005;LD]`00`0015<M
00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@030004Dad00`00
DaeC7@030003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@06001C7@00001C7@0015<M0`000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@000e<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00H005<M000005<M0003Dad40002Dad01000DaeC7E<M0`000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<007ooOol02Woo00<0
07ooOol03Woo000POol00`00Oomoo`0<Ool3000VOol20003Fgh00`00DaeC7@040003Dad01P00Dad0
0000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00
DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00
Dad00000Dad000AC7@03001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01@00Dad005<M000015<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
15<M0`0000=C7@00Dad015<M0`0000=C7@00Dad00e<M0`000e<M00<005<MDad010000e<M00<005<M
Dad010000U<M00@005<MDaeC7@@0009C7@03001C7E<M00<000aoo`03001oogoo00ioo`0087oo00<0
07ooOol02Goo0`00:goo00<005]nFgh00`0015<M00<005<MDad00`000e<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC
7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC
7@05001C7@00Dad00004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@03001C7E<M00<000AC
7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000U<M00<005<MDad01@000U<M00<005<M
Dad010000e<M00<007ooOol02Goo00<007ooOol03Woo000OOol20008Ool3000_Ool20003BY`00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@06001C7@00001C7@0015<M0`000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040002
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000]oo`03001o
ogoo00eoo`007goo10000goo0`00<Woo00<004ZLBY`00TZL0`000e<M00<005<MDad010000e<M00<0
05<MDad00`0015<M00<005<MDad00`000e<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000
Dad000AC7@03001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@06
001C7@00001C7@0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad400000e<M001C7@02Dad30003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00Oomoo`08Ool00`00Oomoo`0=Ool001moo`80
009oo`<003Ioo`04001:W0000003Fad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC
7@03001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@020004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M
00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M
00<000AC7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000U<M00<005<MDad00`001E<M0`0000=C7@00Dad00e<M0`000e<M00<005<MDad0
10000U<M00@005<MDaeC7@<000Uoo`03001oogoo00eoo`007goo1000>Woo0P0015/M0`000e<M00<0
05<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad00002Dad01000DaeC7E<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad300000e<M001C7@03Dad30003
Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00D0009C7@03001oogoo00Moo`03001oogoo
00eoo`0017oo0P0000<8@WooOol00Woo00AJePQ2000icPEoo`04F]H8@P00>Lh7Ool2000nOol01P00
Fad00000Ech000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<0
05<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00D0
05<M001C7@0000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000=C7@<000=C7@03001C7E<M00<000Qoo`03
001oogoo00eoo`001Goo00<007ooOol00Woo00IS61S6LiacW124DY@3Ool01V<H6<IcW7>L48ABU0Qo
o`03001oogoo03aoo`<0009G?P06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00H005<M000005<M0004Dad3
0002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C
7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@00
15<M0`0000=C7@00Dad00e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad01000DaeC7E<M0`0015<M0`0000=C7@00Dad0
0e<M0`000U<M00<007ooOol01Woo00<007ooOol03Goo00000goo000000040003Ool01R48DYAoogoo
DY@HaP=oo`068@QBU7ooOomBU1S62Goo00<007ooOol0?Woo1@000e<M00H005<M000005<M0004Dad3
0003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0003Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00H005<M000005<M0004
Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000=C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01000
0U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M
0003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad200000e<M000000030002Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000AC7@03001oogoo00Eoo`03001oogoo00eoo`0000=o
ocW>DY@00Woo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Qo
o`03001oogoo03eoo`03001>_4jl009>_003001C7E<M00<000=C7@06001C7@00001C7@0015<M0`00
0e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@030003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@03001C7@00008000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M0`0000=C7@00Dad00e<M0`00
0e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
15<M00<005<MDad00`001goo00<007ooOol037oo00001WooLi`HaW>LOol000Aoo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`09Ool2000nOol00`00C[a>_0040003Dad00`00DaeC7@03
0003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC
7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M
00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000U<M00<005<MDad01@000U<M00<007ooOol01Goo00<007ooOol037oo0002Ool0
15:D<Haoo`0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00]oo`03001oogoo
03aoo`8000=K?@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`00
0e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0
009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<0
05<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0003Dad3
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@03
0006Ool00`00Oomoo`0<Ool000=oo`038@QS600000Aoo`068@QBU7ooOomBU2480goo00HQ25:DOomo
oe:D8@P>Ool00`00Oomoo`0lOol00`00FceK?@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@06001C7@00001C7@000e<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad0
0`0015<M00H005<M000005<M0003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad300000e<M001C7@03Dad3
0003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0004Dad300000e<M001C7@03Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00Oomoo`03Ool00`00Oomoo`0<Ool000=oo`03JeXQ200000Aoo`06HaPHaW>L
Li`HaV<H0goo00IS61S6LiacW1S6HaP?Ool00`00Oomoo`0lOol20003D_d00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M
00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M
00<000AC7@03001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01@00Dad005<M000015<M0`000e<M00<0
05<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<0
05<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03
001C7E<M00@000=C7@03001C7E<M00@0009C7@04001C7E<MDad30004Ool00`00Oomoo`0<Ool000Ao
o`03>Lh8@Woo00Aoo`04F]H8@PQ2HaP5Ool015[F2488@V<H4Goo0P00?Woo00<005;mD_d00`0015<M
00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00H005<M000005<M0004
Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC
7@040003Dad00`00DaeC7@030004Dad00`00Dad00002Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000
Dad000AC7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000=C7@03001C7E<M00<000AC7@06001C7@00001C7@000U<M10000e<M00<005<MDad0
10000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M0000
05<M0003Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@050002Dad00`00Oomoo`02Ool00`00
Oomoo`0<Ool002]oo`03001oogoo03aoo`8000=Bo@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`000e<M00<005<M
Dad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<M
Dad00`000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00P0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC
7@030003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad300000e<M001C7@03Dad30002Dad00`00DaeC7@04
0003Dad00`00DaeC7@030003Ool00`00Oomoo`0<Ool002aoo`03001oogoo03]oo`03001BoE;m009B
o@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
008000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M
00<005<MDad00`000e<M00<005<MDad010000e<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03
001C7E<M00<000AC7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad0
10000U<M00<005<MDad010000e<M00<005<MDad010000e<M00D005<M001C7@0000AC7@<000=C7@03
001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03
001C7E<M00@000=C7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00D007ooOomo
o`0000eoo`00;Goo00<007ooOol0>goo00@005;m0000009G?@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00
001C7@0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M
00<005<MDad00`0015<M00D005<M001C7@0000AC7@<000=C7@03001C7E<M00@0009C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@05001C7@00
Dad00004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@<00003Dad0
05<M00=C7@<0009C7@04001C7E<MDad30002Ool00`00Oomoo`0;Ool002ioo`03001oogoo03]oo`<0
009G?@<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000=C7@03001C7E<M00<000AC7@06001C7@00001C7@000e<M0`000e<M00<005<MDad01000
0e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00H005<M000005<M
0004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00001C
7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<0
05<MDad010000U<M00<005<MDad00`0015<M00H005<M000005<M0003Dad40002Dad01000Oomoo`00
3Goo000_Ool2000nOol20002D_d01000DaeC7E<M0`000e<M00<005<MDad010000e<M00<005<MDad0
0`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`0015<M00<005<M0000
0e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00<005<MDad00P0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad01000
Dad000000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00`0015<M0`0000=C7@00Dad00e<M0`000e<M00<005<MDad010000U<M
00<005<MDad010000e<M00<005<MDad010000U<M0P0000=C7@0000000P000e<M00<005<MDad00`00
15<M0`000U<M00<005<MDad00`0000=oo`00Ool037oo000aOol00`00Oomoo`0kOol00`00D_eBo@02
D_d00`00Dad00002Dad01000DaeC7E<M0`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`0015<M0`000U<M00<005<MDad0
10000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad0
0`0015<M00H005<M000005<M0003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad0
0`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad30002Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@02
0004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03
001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@<0009C7@03001oo`0000eo
o`00<Woo00<007ooOol0>goo00<005;mD_d00`0015<M00<005<M00000U<M00@005<MDaeC7@<000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C
7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad00`0015<M00D005<M001C7@0000AC7@<000=C
7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M00H005<M000005<M0003Dad30003
Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003
Dad01P00Dad00000Dad000=C7@<000eoo`00<goo00<007ooOol0>goo0P000eLM00<005<MDad00`00
15<M00<005<M00000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000e<M
00<005<MDad010000U<M00<005<MDad00`0015<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03
001C7E<M00<000=C7@04001C7@000002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004Dad01@00Dad005<M000015<M0`00
0e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad01000
0e<M00<005<MDad00`0015<M0`000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<M
Dad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M0`0000=C7@0000003Goo000dOol2
000mOol00`00EaeG7@030003Dad00`00DaeC7@030004Dad30002Dad00`00DaeC7@040003Dad00`00
DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004Dad01@00
Dad005<M000015<M0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad01000
0U<M00<005<MDad010000e<M00<005<MDad00P0015<M0`000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00H005<M
000005<M0004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003
Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC
7@040002Dad200000e<M000000020003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad00`00
Oomoo`0;Ool003Ioo`03001oogoo03]oo`8000=G7@03001C7E<M00<000=C7@06001C7@00001C7@00
0e<M0`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<M
Dad00`000e<M00<005<MDad00`000e<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@030003
Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C
7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00001C7@000e<M0`000e<M00<005<MDad01000
0U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00H005<M000005<M
0003Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad00`00DaeC7@03000<Ool003Moo`03001oogoo03]oo`03001G7ELM00@0009C7@03
001C7E<M00<000AC7@03001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00
DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01000
Dad000000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00P0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@040003
Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004
Dad00`00Dad00002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@030004Dad300000e<M001C7@03Dad30002Dad00`00DaeC7@04
0003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Ool00`00Oomoo`0:
Ool003Qoo`03001oogoo03]oo`8000=Bo@03001C7E<M00<000=C7@03001C7E<M00<000AC7@03001C
7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC
7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad30003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03
001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M008000AC7@06
001C7@00001C7@000e<M0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad0
10001Woo00<007ooOol02Woo000iOol2000lOol00`00D_eBo@040003Dad00`00DaeC7@030003Dad0
0`00DaeC7@030004Dad00`00Dad00002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<0
00=C7@03001C7E<M00<000AC7@03001C7@00009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C
7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@06001C7@00001C7@00
15<M0`000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<M
Dad010000U<M00<005<MDad00`0015<M0`000U<M00<005<MDad010000U<M0P0000=C7@0000000P00
0e<M00<005<MDad010002Woo00<007ooOol02Woo000kOol00`00Oomoo`0jOol20003Ead00`00DaeC
7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad0
1000Dad000000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<0
05<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M0`000e<M00<005<MDad01000
0U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad00`00
15<M00H005<M000005<M0002Dad40003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00
DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad30002Dad00`00DaeC7@040003
Dad00`00DaeC7@04000>Ool00`00Oomoo`0:Ool003aoo`03001oogoo03]oo`03001G7ELM00<000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7@00009C7@04001C7E<MDad30003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad0
0`00DaeC7@030004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad01P00Dad00000Dad000AC7@<0009C7@03
001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03
001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0
009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@06001C7@00001C7@000e<M0`000e<M00<0
05<MDad010004Woo00<007ooOol02Woo000mOol00`00Oomoo`0kOol20003D_d00`00DaeC7@030003
Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad00`00Dad00002Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad0
1P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M008000AC7@04001C7@000002Dad00`00DaeC7@03
0003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0003Dad01@00Dad005<M000015<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<0
05<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M00<005<M00000U<M00<005<M
Dad010005Woo00<007ooOol02Woo000nOol2000lOol00`00D_eBo@040003Dad00`00DaeC7@030003
Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad01000Dad0
00000U<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad0
0`000e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000U<M00<005<MDad010000e<M00<0
05<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00@0
05<M0000009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C
7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=oo`03001oogoo01Eoo`03
001oogoo00Uoo`00@7oo00<007ooOol0>Woo0P000eLM00<005<MDad010000U<M00<005<MDad01000
0e<M00<005<MDad00`000e<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC
7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000U<M
00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad00`0015<M
0`000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad0
10000e<M00<005<MDad010000U<M00@005<M000000Ioo`03001oogoo01Eoo`03001oogoo00Uoo`00
@Goo00<007ooOol0>goo00<005LMEad00`000e<M00<005<MDad00`000e<M00<005<MDad010000U<M
00<005<MDad00`0015<M00<005<M00000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<0
05<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00H005<M000005<M0003Dad3
0003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@04
0002Dad00`00DaeC7@030004Dad00`00Dad00002Dad00`00DaeC7@040003Dad00`00DaeC7@030003
Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad0
00=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C
7E<M00@0009C7@03001C7E<M00<000Uoo`03001oogoo01Aoo`03001oogoo00Uoo`00@Woo00<007oo
Ool0>goo0P000U;m00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<0
05<MDad00`000e<M0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad010000U<M00<005<MDad00`0015<M00<005<M00000U<M00<005<MDad010000e<M
00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M
00<005<MDad00`000e<M0`000e<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad0
10000e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000U<M00<005<MDad010000U<M00<0
05<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010003Goo00<0
07ooOol04goo00<007ooOol02Goo0013Ool00`00Oomoo`0kOol00`00D_eBo@030003Dad00`00DaeC
7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00Dad00003Dad00`00DaeC7@03
0003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@03
0003Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00
DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad01000Dad000000U<M00<005<M
Dad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00P0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000U<M
00<005<MDad010000U<M00<005<MDad010004Goo00<007ooOol04goo00<007ooOol02Goo0014Ool2
000lOol20003Ead00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00
DaeC7@030004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003
Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00Dad00002Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad0
0`00DaeC7@020004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad01000Dad000000U<M00<005<MDad00`00
0e<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010005Woo00<007ooOol04Woo
00<007ooOol02Goo0016Ool00`00Oomoo`0jOol00`00EaeG7@040002Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000=C7@<000=C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M
00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03
001C7E<M00<000=C7@03001C7E<M00@0009C7@06001C7@00001C7@0015<M0`000U<M00<005<MDad0
10000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad0
0`0015<M0`000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`006goo00<0
07ooOol04Goo00<007ooOol02Goo0017Ool00`00Oomoo`0jOol20003Ead00`00DaeC7@030003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad00`00Dad00003Dad00`00
DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad01@00Dad005<M000015<M0`000e<M00<005<MDad00`000e<M00<005<MDad00`00
0e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00P0015<M00H005<M000005<M
0002Dad40003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad01P00Dad00000Dad000=C7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@0
01moo`03001oogoo011oo`03001oogoo00Uoo`00B7oo00<007ooOol0>Woo00<005LMEad010000e<M
00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad00`0015<M
0`000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad0
0`000e<M00<005<MDad00`000e<M00@005<M0000009C7@03001C7E<M00@0009C7@03001C7E<M00@0
009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00<0
00=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C
7E<M00<000=C7@03001C7E<M00<000AC7@<0009C7@03001C7E<M00<000=C7@03001C7E<M00@002=o
o`03001oogoo015oo`03001oogoo00Qoo`00BGoo0P00>goo0P000e;l00<005<MDad010000U<M00<0
05<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00@005<M0000009C7@03001C
7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C
7E<M00@000=C7@03001C7E<M008000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C
7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7@00009C7@03
001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03
001C7E<M00@0009C7@03001C7E<M00<000AC7@<0009C7@03001C7E<M00@002Qoo`03001oogoo011o
o`03001oogoo00Qoo`00Bgoo00<007ooOol0>Woo00<005;lD_`00`000e<M00<005<MDad00`000e<M
00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000U<M00<005<MDad0
10000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad0
10000U<M00@005<M0000009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0
00=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@<000=C7@03001C
7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C
7E<M00<000=C7@06001C7@00001C7@000U<M1000;Goo00<007ooOol03goo00<007ooOol027oo001<
Ool00`00Oomoo`0jOol20002Ead00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@03
0003Dad00`00DaeC7@030003Dad01000Dad000000U<M00<005<MDad00`000e<M00<005<MDad01000
0U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`00
0U<M10000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<M
Dad010000U<M00<005<MDad010000U<M00@005<M0000009C7@03001C7E<M00@0009C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M
00<0009C7@@0039oo`03001oogoo00ioo`03001oogoo00Qoo`00CGoo00<007ooOol0>Woo00<005LM
Ead00`000e<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<M
Dad00`000U<M10000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M
00<005<MDad010000U<M00<005<MDad010000U<M0`000e<M00<005<MDad00`000e<M00<005<MDad0
10000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad0
0`000U<M10000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<0
05<MDad010000U<M00<005<MDad010000U<M0`00=Woo00<007ooOol03Woo00<007ooOol027oo001>
Ool2000kOol20003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00Dad00002Dad00`00DaeC7@040002
Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002
Dad00`00DaeC7@040002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC
7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00Dad0000jOol00`00Oomoo`0=
Ool00`00Oomoo`08Ool0051oo`03001oogoo03Uoo`03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7@00009C7@03001C7E<M00@000=C7@03
001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03
001C7E<M00<000=C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7@00009C7@03001C7E<M00@0009C
7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C
7@03001C7E<M00<003aoo`03001oogoo00aoo`03001oogoo00Qoo`00DGoo00<007ooOol0>Goo0P00
0e;L00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad00`00
0e<M0`000e<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<M00000U<M00<005<MDad010000U<M00<005<MDad0
10000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad0
0`000e<M0`000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<0
05<MDad010000U<M00<005<MDad01000?goo00<007ooOol03Goo00<007ooOol01goo001BOol00`00
Oomoo`0iOol00`00D]aBg0040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC
7@030003Dad00`00Dad00003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@03
0003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad30003Dad00`00
DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00
DaeC7@040002Dad01000Dad000000U<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<M
Dad010000U<M00<005<MDad010000U<M00<005<MDad01000A7oo00<007ooOol037oo00<007ooOol0
1goo001COol2000jOol20003Eeh00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040002Dad40002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00
DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad30002Dad00`00DaeC7@040002
Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003
Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC
7@040003Dad00`00DaeC7@030019Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool005Eoo`03001oogoo
03Uoo`03001GGUMN00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<0
00=C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C
7E<M00<000=C7@03001C7E<M00<000=C7@04001C7@000002Dad00`00DaeC7@030003Dad00`00DaeC
7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC
7@040002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad0
0`00DaeC7@04001=Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool005Ioo`03001oogoo03Uoo`80009>
g003001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7@00009C7@03
001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03
001C7E<M00@0009C7@03001C7E<M00@0009C7@@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0
009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@04001C7@000002
Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@04001A
Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool005Moo`03001oogoo03Uoo`03001>g4kL00<000=C7@03
001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@<000=C7@03001C7E<M00<0
00=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<0
00=C7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C
7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<0009C7@@0009C7@03001C7E<M00@0009C
7@03001C7E<M00@0009C7@03001C7E<M00@005Ioo`03001oogoo00Uoo`03001oogoo00Moo`00F7oo
00<007ooOol0>Goo0P000eKl00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`00
0U<M10000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<M
Dad010000U<M00<005<MDad010000U<M00@005<M0000009C7@03001C7E<M00<000=C7@03001C7E<M
00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M
00@0009C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<005]oo`03
001oogoo00Qoo`03001oogoo00Moo`00FGoo0P00>Woo00<005KlE_`010000U<M00<005<MDad01000
0U<M00<005<MDad010000U<M0`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<M
Dad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000U<M10000U<M
00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000e<M
00<005<MDad00`000e<M0`000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad0
1000Ggoo00<007ooOol027oo00<007ooOol01Woo001KOol00`00Oomoo`0hOol20003Egh00`00DaeC
7@030003Dad00`00DaeC7@030003Dad00`00Dad00002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00
DaeC7@030003Dad00`00DaeC7@040002Dad01P00Dad00000Dad0009C7@@0009C7@03001C7E<M00@0
009C7@03001C7E<M00@006=oo`03001oogoo00Qoo`03001oogoo00Ioo`00G7oo00<007ooOol0>Goo
1P000U<M00<005<MDad010000U<M00<005<MDad010000U<M0`000e<M00<005<MDad00`000e<M00<0
05<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M0`00
0U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad01000
0U<M00<005<MDad010000U<M00<005<MDad010000U<M0`000e<M00<005<MDad00`000e<M00<005<M
Dad00`00J7oo00<007ooOol01goo00<007ooOol01Woo001MOol00`00Oomoo`0hOol00`00CY]>V`02
CY/00`00DaeC7@030003Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@040002Dad00`00DaeC
7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad01000Dad0
00000U<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad0
0`000e<M00<005<MDad00`000e<M00<005<MDad00`000U<M10000U<M00<005<MDad010000U<M00<0
05<MDad01000K7oo00<007ooOol01Woo00<007ooOol01Woo001NOol2000iOol00`00CY]>V`040002
Dad00`00DaeC7@040002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC
7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad40002Dad0
0`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad0
0`00DaeC7@040002Dad30003Dad00`00DaeC7@030002Dad00`00DaeC7@04001`Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool0061oo`03001oogoo03Moo`8000=KG@03001C7E<M00<000=C7@<000=C7@03
001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03
001C7E<M00@0009C7@03001C7E<M00@0009C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00<0
00=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@<0009C7@03001C
7E<M00@0009C7@03001C7E<M00<007Eoo`03001oogoo00Eoo`03001oogoo00Ioo`00HGoo00<007oo
Ool0>7oo00<005]MFed00`000e<M00<005<M00000U<M00<005<MDad010000U<M00<005<MDad00`00
0e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`00
0U<M10000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<M
Dad010000U<M00<005<MDad010000U<M00H005<M000005<M0002Dad40002Dad00`00DaeC7@04001i
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0069oo`03001oogoo03Qoo`80009C?P03001C7E<M00@0
009C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C
7E<M00@0009C7@03001C7E<M00@0009C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C
7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C
7@<000=C7@03001C7E<M00<007ioo`03001oogoo00=oo`03001oogoo00Ioo`00Hgoo0P00>Woo1@00
0U<M10000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad00`000e<M00<005<M
Dad00`000e<M00<005<MDad00`000U<M10000U<M00<005<MDad010000U<M00<005<MDad010000U<M
00<005<MDad010000U<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000U<M
10000U<M00<005<MDad01000PGoo00<007ooOol017oo00<007ooOol01Goo001UOol00`00Oomoo`0g
Ool00`00CWY>NP02CWX20003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@03
0002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad30003Dad00`00DaeC7@030003Dad00`00
DaeC7@030003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00
DaeC7@040002Dad30003Dad00`00DaeC7@030026Ool00`00Oomoo`03Ool00`00Oomoo`05Ool006Io
o`03001oogoo03Moo`06001>NTij001Ko@000U<M10000U<M00<005<MDad010000U<M00<005<MDad0
10000U<M00<005<MDad00`000e<M00<005<MDad00`000U<M10000U<M00<005<MDad010000U<M00<0
05<MDad010000U<M00<005<MDad010000U<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<0
05<MDad00`000U<M10000U<M00<005<MDad01000RWoo00<007ooOol00Woo00<007ooOol01Goo001W
Ool00`00Oomoo`0fOol00`00CWX000050003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad0
0`00DaeC7@030002Dad00`00DaeC7@040002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@03
0003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad30002Dad00`00DaeC7@04002?Ool01@00Oomoogoo00001goo001XOol2000gOol00`00Ool0
0004AY`00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@03
0003Dad00`00Dad00002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002
Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad40002Dad00`00DaeC
7@03002COol01@00Oomoogoo00001goo001ZOol00`00Oomoo`0gOol00`00AYa6W0040002Dad00`00
DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad30003
Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002
Dad00`00DaeC7@0400000e<M000000020002Dad00`00DaeC7@04002GOol01000Oomoo`001goo001[
Ool00`00Oomoo`0gOol20003DYX00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad60002Dad40002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@030003
Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad30003Dad00`00DaeC7@03002LOol00`00Ool0
0007Ool006aoo`03001oogoo03Ioo`03001BVU:J009BVP<0009C7@03001C7E<M00<000=C7@03001C
7E<M00<0009C7@@0009C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C
7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00@00003Dad000000080009C7@03
001C7E<M00@009moo`04001oogoo0006Ool006eoo`8003Moo`03001BVP0000@0009C7@<0009C7@03
001C7E<M00@0009C7@<000=C7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00@0
009C7@03001C7E<M00@0009C7@03001C7E<M00<000=C7@03001C7E<M00<0009C7@<000=C7@03001C
7E<M00<00:Aoo`03001oo`0000Ioo`00Kgoo00<007ooOol0=Goo00<007oo00000SgG0`000U<M00<0
05<MDad010000U<M0`000U<M00<005<MDad010000U<M00<005<MDad00`000e<M00<005<MDad00`00
0e<M00<005<MDad00`000U<M00<005<MDad010000U<M00<005<MDad010000U<M0`000U<M00<005<M
Dad01000Z7oo0P001Woo001`Ool00`00Oomoo`0gOol01@00?MLmecgG00000U<M0`000U<M10000U<M
00<005<MDad00`000e<M00<005<MDad00`000U<M00<005<MDad010000U<M00<005<MDad010000U<M
00<005<MDad00`000e<M00<005<MDad00`000U<M10000U<M00<005<MDad00`00Zgoo0`001Woo001a
Ool00`00Oomoo`0fOol01000?MLmecgG0`000U<M0`000e<M00<005<MDad00`000U<M00<005<MDad0
10000U<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000U<M00<005<MDad0
10000U<M0`000U<M00<005<MDad01000ZWoo10002Goo001bOol00`00Oomoo`0eOol01@00?ML00000
Jm`010000U<M00<005<MDad010000U<M00<005<MDad00`000e<M00<005<MDad00`000U<M00<005<M
Dad010000U<M00<005<MDad0100000=C7@0000001@000U<M10000U<M00<005<MDad00`00ZWoo1000
3Goo001cOol2000fOol80002Dad30003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00
DaeC7@030003Dad00`00DaeC7@030002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@03002Z
Ool3000AOol007Eoo`03001oogoo03Qoo`030011UD6E0080009C7@03001C7E<M00@0009C7@03001C
7E<M00<000=C7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@<0009C7@03001C7E<M00@0009C
7@03001C7E<M00@00:Uoo`@001Aoo`00MWoo00<007ooOol0=goo00D0046E@IE1U@00009C7@<000=C
7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00<0009C7@@0009C7@03001C7E<M
00<000=C7@03001C7E<M00<00:Uoo`@001Qoo`00Mgoo00<007ooOol0=Woo00<0046E@ID00T6E0P00
0U<M00<005<MDad010000U<M00<005<MDad00`000e<M00<005<MDad00`000U<M0`000e<M00<005<M
Dad00`000U<M00<005<MDad01000Z7oo100077oo001hOol2000fOol00`00@IE1U@02@ID20002Dad3
0003Dad00`00DaeC7@030002Dad70002Dad30002Dad00`00DaeC7@040002Dad00`00DaeC7@03002X
Ool4000POol007Yoo`03001oogoo03Aoo`030011UD6E00800003:CH00000009C7@03001C7E<M00@0
009C7@<0009C7@03001C7E<M00@0009C7@03001C7E<M00<0009C7@03001C7E<M00@00:Qoo`<002Ao
o`00Ngoo00<007ooOol0<goo00D0046E001oo`00008Y=P03001C7E<M00<0009C7@@0009C7@03001C
7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00<00:Qoo`@002Moo`00O7oo00<007ooOol0
<Woo00<0046E00000Woo00<002Tf00000P000U<M0`000U<M00<005<MDad010000U<M00<005<MDad0
0`000e<M00<005<MDad00`00Ygoo1000:goo001mOol2000bOol20003Ool20003DOD20002Dad00`00
DaeC7@030003Dad00`00DaeC7@030002Dad00`00DaeC7@04002VOol4000_Ool007moo`03001oogoo
02moo`03001oogoo009oo`03001AmE7e009Am@80009C7@<0009C7@03001C7E<M00@0009C7@03001C
7E<M00<00:Ioo`@003=oo`00P7oo00<007ooOol0<goo00D0057eDOEAm@00008e4@80009C7@03001C
7E<M00<000=C7@03001C7E<M00<00:Eoo`@003Moo`00PGoo00<007ooOol0<Woo00D0057eDOEAm@00
00<e4@03001C7E<M00<0009C7@03001C7E<M00@00:Eoo`<003]oo`00PWoo0P00<Woo00<0057eDOD0
0P0013DA0P000U<M00<005<MDad00`00YGoo1000?Woo0024Ool00`00Oomoo`0`Ool01000DOD00000
13DA00<007oo00001000Y7oo1000@Woo0025Ool00`00Oomoo`0_Ool01000DOD0000013DA00<007oo
Ool0Y7oo1000AWoo0026Ool00`00Oomoo`0^Ool200000goo000e4@03=A400`00Oomoo`2POol4001:
Ool008Moo`03001oogoo02eoo`800003Ool003DA008e4@03001oogoo09eoo`@004ioo`00R7oo0P00
;Goo00@007ooOol000<e4@03001oogoo09Yoo`<0059oo`00RWoo00<007ooOol0;Goo00D003DA=A4e
4@0009Qoo`@005Eoo`00Rgoo00<007ooOol0;7oo00D003DA=A4e4@0009Aoo`@005Uoo`00S7oo00<0
07ooOol0:goo00D003DA=A4e4@00091oo`@005eoo`00SGoo0P00:goo00D003DA=A4e4@0008aoo`@0
065oo`00Sgoo00<007ooOol0:7oo00@003DA=A4008Yoo`<006Eoo`00T7oo00<007ooOol09goo00@0
03DA=A4008Ioo`@006Qoo`00TGoo00<007ooOol09Woo00@003DA=A40089oo`@006aoo`00TWoo0P00
9Woo00@003DA=A4007ioo`@0071oo`00U7oo00<007ooOol08goo00@003DA=A4007Yoo`@007Aoo`00
UGoo00<007ooOol08Woo00@003DA=A4007Ioo`@007Qoo`00UWoo00<007ooOol08Goo00@003DA0000
07=oo`<007aoo`00Ugoo0P008Goo00@003DA000006moo`@007moo`00VGoo00<007ooOol07Woo00@0
03DA000006]oo`@008=oo`00VWoo00<007ooOol07Goo00@003DA000006Moo`@008Moo`00Vgoo00<0
07ooOol077oo00@003DA000006=oo`@008]oo`00W7oo00<007ooOol06goo00@003DA000005moo`@0
08moo`00WGoo0P006goo00@003DA000005aoo`<009=oo`00Wgoo00<007ooOol067oo0P0000=oo`00
Ool0Egoo1000UWoo002POol00`00Oomoo`0GOol200000goo001oo`1COol4002JOol00:5oo`03001o
ogoo01Ioo`800003Ool007oo04moo`@009ioo`00XWoo0P005Woo0P0000=oo`00Ool0Bgoo1000XWoo
002TOol00`00Oomoo`0COol200000goo001oo`18Ool3002VOol00:Eoo`03001oogoo019oo`800003
Ool007oo04Aoo`@00:Uoo`00YWoo00<007ooOol04Goo00@007ooOol0045oo`@00:eoo`00Ygoo0P00
4Goo00@007ooOol003eoo`@00;5oo`00ZGoo00<007ooOol03Woo00@007ooOol003Uoo`@00;Eoo`00
ZWoo00<007ooOol047oo00<007ooOol0<goo1000^Goo002[Ool00`00Oomoo`0?Ool00`00Oomoo`0`
Ool3002mOol00:aoo`8000ioo`03001oogoo02eoo`@00<1oo`00[Woo00<007ooOol02goo00<007oo
Ool0:Goo1000a7oo002_Ool00`00Oomoo`0:Ool00`00Oomoo`0UOol40038Ool00;1oo`03001oogoo
00Uoo`03001oogoo025oo`@00<aoo`00/Goo00<007ooOol027oo00<007ooOol07Goo1000d7oo002b
Ool20008Ool00`00Oomoo`0JOol3003DOol00;Aoo`03001oogoo00Eoo`03001oogoo01Ioo`@00=Mo
o`00]Goo00<007ooOol017oo00<007ooOol04Woo1000fgoo002fOol00`00Oomoo`03Ool00`00Oomo
o`0>Ool4003OOol00;Moo`8000=oo`03001oogoo00Yoo`@00>=oo`00^Goo00@007ooOol000Uoo`<0
0>Moo`00^Woo00<007oo00001Goo1000jWoo002kOol200000goo00000002003^Ool00;aoo`800?9o
o`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003o
OonaOol00?mook5oo`00\
\>"],
   ImageRangeCache->{{{0, 431}, {349.312, 0}} -> {-0.0761827, 0.0163412,
   0.00362352, 0.00362352}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
     \(\(\(Filt =
       Table[If[x <= 32\  && y <= 32, \ Sqrt[x^2 + y^2],
           \[IndentingNewLine]\t\t\t
           If[x <= 32\  && y > 32, \ Sqrt[x^2\  + \ \((65 - y)\)^2],
             \[IndentingNewLine]\t\t\t\t
             If[x > 32\  && \ y <= 32, \ Sqrt[\((65 - x)\)^2 + y^2],
               \[IndentingNewLine]\t\t\t\t\t
               If[x > 32\  && \ y > 32, \
                 Sqrt[\((65 - x)\)^2 + \((65 - y)\)^2]]]]], {x, 0, 63}, {y, 0,
           63}]; \)\[IndentingNewLine]\)\)], "Input"],

Cell[BoxData[
     \(General::"spell" \( : \ \)
       "Possible spelling error: new symbol name \"\!\(Filt\)\" is similar to \
existing symbols \!\({File, Fit}\)."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
     \(ListPlot3D[Filt]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.2083 .17506 -11.6698 -9 ]
[.2083 .17506 .33019 0 ]
[.41321 .09446 -10.8756 -9 ]
[.41321 .09446 1.12444 0 ]
[.63499 .00731 -10.0813 -9 ]
[.63499 .00731 1.9187 0 ]
[.79894 .14525 0 -6.11522 ]
[.79894 .14525 12 2.88478 ]
[.88874 .28276 0 -5.98496 ]
[.88874 .28276 12 3.01504 ]
[.96735 .40315 0 -5.87414 ]
[.96735 .40315 12 3.12586 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01668 .31172 -12 -2.78172 ]
[.01668 .31172 0 6.21828 ]
[.00901 .35977 -12 -2.82246 ]
[.00901 .35977 0 6.17754 ]
[.0011 .40931 -12 -2.8646 ]
[.0011 .40931 0 6.1354 ]
[-0.00705 .46043 -12 -2.90822 ]
[-0.00705 .46043 0 6.09178 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78659 .14969 m
.78042 .1519 L
s
[(20)] .79894 .14525 -1 .35894 Mshowa
.87628 .28687 m
.87005 .28893 L
s
[(40)] .88874 .28276 -1 .32999 Mshowa
.9548 .40699 m
.94853 .4089 L
s
[(60)] .96735 .40315 -1 .30537 Mshowa
.125 Mabswid
.7105 .03329 m
.70682 .0347 L
s
.7368 .07352 m
.73311 .0749 L
s
.76215 .11229 m
.75845 .11365 L
s
.81019 .18578 m
.80647 .18708 L
s
.83297 .22063 m
.82925 .22191 L
s
.85499 .25431 m
.85126 .25557 L
s
.89687 .31837 m
.89312 .31958 L
s
.9168 .34886 m
.91305 .35005 L
s
.9361 .37838 m
.93234 .37955 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02893 .30704 m
.03506 .3047 L
s
[(10)] .01668 .31172 1 -0.38184 Mshowa
.02131 .35518 m
.02745 .35289 L
s
[(20)] .00901 .35977 1 -0.37279 Mshowa
.01344 .40483 m
.0196 .40259 L
s
[(30)] .0011 .40931 1 -0.36342 Mshowa
.00532 .45606 m
.01151 .45387 L
s
[(40)] -0.00705 .46043 1 -0.35373 Mshowa
.125 Mabswid
.03487 .26956 m
.03854 .26814 L
s
.0334 .27885 m
.03707 .27743 L
s
.03192 .28819 m
.0356 .28677 L
s
.03043 .29759 m
.03411 .29618 L
s
.02743 .31655 m
.03111 .31515 L
s
.02591 .32612 m
.02959 .32473 L
s
.02439 .33575 m
.02807 .33436 L
s
.02285 .34544 m
.02654 .34406 L
s
.01975 .36499 m
.02344 .36362 L
s
.01819 .37486 m
.02188 .3735 L
s
.01661 .38479 m
.02031 .38343 L
s
.01503 .39478 m
.01873 .39343 L
s
.01183 .41495 m
.01554 .41361 L
s
.01022 .42513 m
.01393 .4238 L
s
.0086 .43537 m
.0123 .43405 L
s
.00696 .44568 m
.01067 .44436 L
s
.00367 .4665 m
.00738 .46519 L
s
.002 .477 m
.00572 .4757 L
s
.00032 .48758 m
.00404 .48629 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.381 .835 .92 r
.39982 .61192 .40483 .61217 .41294 .61074 .40797 .61017 Metetra
.214 .729 .876 r
.40797 .61017 .41294 .61074 .42104 .61082 .41611 .60961 Metetra
.164 .679 .892 r
.41611 .60961 .42104 .61082 .42915 .61168 .42425 .60988 Metetra
.166 .658 .919 r
.42425 .60988 .42915 .61168 .43729 .61294 .43243 .61067 Metetra
.182 .647 .937 r
.43243 .61067 .43729 .61294 .44547 .6144 .44063 .61177 Metetra
.2 .64 .947 r
.44063 .61177 .44547 .6144 .4537 .61598 .44887 .61308 Metetra
.215 .635 .953 r
.44887 .61308 .4537 .61598 .46196 .61764 .45716 .61453 Metetra
.228 .632 .956 r
.45716 .61453 .46196 .61764 .47027 .61935 .46549 .61608 Metetra
.239 .629 .958 r
.46549 .61608 .47027 .61935 .47863 .62111 .47386 .6177 Metetra
.247 .627 .959 r
.47386 .6177 .47863 .62111 .48703 .6229 .48227 .61938 Metetra
.255 .625 .96 r
.48227 .61938 .48703 .6229 .49548 .62471 .49074 .62109 Metetra
.261 .623 .96 r
.49074 .62109 .49548 .62471 .50398 .62655 .49925 .62285 Metetra
.267 .622 .96 r
.49925 .62285 .50398 .62655 .51252 .62841 .50781 .62464 Metetra
.271 .621 .96 r
.50781 .62464 .51252 .62841 .52111 .63028 .51641 .62645 Metetra
.276 .62 .959 r
.51641 .62645 .52111 .63028 .52975 .63218 .52507 .62829 Metetra
.279 .62 .959 r
.52507 .62829 .52975 .63218 .53844 .63409 .53377 .63015 Metetra
.282 .619 .959 r
.53377 .63015 .53844 .63409 .54719 .63601 .54253 .63203 Metetra
.285 .619 .959 r
.54253 .63203 .54719 .63601 .55598 .63795 .55133 .63392 Metetra
.288 .618 .958 r
.55133 .63392 .55598 .63795 .56482 .6399 .56019 .63584 Metetra
.29 .618 .958 r
.56019 .63584 .56482 .6399 .57371 .64187 .56909 .63777 Metetra
.292 .617 .958 r
.56909 .63777 .57371 .64187 .58265 .64385 .57805 .63972 Metetra
.294 .617 .958 r
.57805 .63972 .58265 .64385 .59165 .64584 .58706 .64168 Metetra
.296 .617 .957 r
.58706 .64168 .59165 .64584 .6007 .64785 .59613 .64366 Metetra
.297 .616 .957 r
.59613 .64366 .6007 .64785 .6098 .64987 .60524 .64566 Metetra
.299 .616 .957 r
.60524 .64566 .6098 .64987 .61896 .6519 .61441 .64767 Metetra
.3 .616 .957 r
.61441 .64767 .61896 .6519 .62817 .65395 .62364 .64969 Metetra
.301 .616 .957 r
.62364 .64969 .62817 .65395 .63743 .65601 .63292 .65173 Metetra
.303 .616 .957 r
.63292 .65173 .63743 .65601 .64675 .65808 .64225 .65378 Metetra
.304 .615 .956 r
.64225 .65378 .64675 .65808 .65612 .66017 .65164 .65584 Metetra
.305 .615 .956 r
.65164 .65584 .65612 .66017 .66555 .66227 .66109 .65792 Metetra
.306 .615 .956 r
.66109 .65792 .66555 .66227 .67504 .66438 .67059 .66002 Metetra
.307 .615 .956 r
.67059 .66002 .67504 .66438 .68458 .66651 .68015 .66213 Metetra
.649 .771 .938 r
.68015 .66213 .68458 .66651 .69396 .66394 .68954 .65954 Metetra
.801 .804 .854 r
.68954 .65954 .69396 .66394 .70312 .65666 .69873 .65225 Metetra
.801 .805 .854 r
.69873 .65225 .70312 .65666 .71229 .64938 .70793 .64496 Metetra
.801 .805 .855 r
.70793 .64496 .71229 .64938 .72146 .6421 .71713 .63766 Metetra
.801 .806 .855 r
.71713 .63766 .72146 .6421 .73064 .63481 .72634 .63037 Metetra
.802 .806 .855 r
.72634 .63037 .73064 .63481 .73983 .62752 .73556 .62306 Metetra
.802 .807 .856 r
.73556 .62306 .73983 .62752 .74902 .62022 .74478 .61576 Metetra
.802 .808 .856 r
.74478 .61576 .74902 .62022 .75822 .61292 .75401 .60845 Metetra
.802 .808 .856 r
.75401 .60845 .75822 .61292 .76742 .60562 .76324 .60115 Metetra
.802 .809 .857 r
.76324 .60115 .76742 .60562 .77663 .59832 .77248 .59384 Metetra
.803 .81 .857 r
.77248 .59384 .77663 .59832 .78584 .59101 .78172 .58653 Metetra
.803 .811 .858 r
.78172 .58653 .78584 .59101 .79506 .5837 .79097 .57921 Metetra
.803 .812 .858 r
.79097 .57921 .79506 .5837 .80429 .57638 .80023 .5719 Metetra
.803 .813 .859 r
.80023 .5719 .80429 .57638 .81352 .56907 .80949 .56459 Metetra
.803 .814 .86 r
.80949 .56459 .81352 .56907 .82276 .56175 .81876 .55728 Metetra
.804 .816 .861 r
.81876 .55728 .82276 .56175 .83201 .55443 .82804 .54997 Metetra
.804 .817 .861 r
.82804 .54997 .83201 .55443 .84126 .54711 .83732 .54267 Metetra
.804 .819 .863 r
.83732 .54267 .84126 .54711 .85051 .53979 .84661 .53536 Metetra
.805 .821 .864 r
.84661 .53536 .85051 .53979 .85978 .53247 .85591 .52807 Metetra
.805 .823 .865 r
.85591 .52807 .85978 .53247 .86905 .52515 .86522 .52079 Metetra
.805 .826 .867 r
.86522 .52079 .86905 .52515 .87832 .51783 .87453 .51351 Metetra
.806 .829 .868 r
.87453 .51351 .87832 .51783 .88761 .51052 .88385 .50626 Metetra
.806 .832 .871 r
.88385 .50626 .88761 .51052 .8969 .50322 .89319 .49903 Metetra
.806 .836 .873 r
.89319 .49903 .8969 .50322 .9062 .49593 .90253 .49182 Metetra
.806 .841 .877 r
.90253 .49182 .9062 .49593 .91551 .48866 .91188 .48466 Metetra
.806 .847 .881 r
.91188 .48466 .91551 .48866 .92483 .48142 .92126 .47756 Metetra
.806 .855 .887 r
.92126 .47756 .92483 .48142 .93416 .47422 .93065 .47055 Metetra
.804 .865 .894 r
.93065 .47055 .93416 .47422 .9435 .46708 .94006 .46367 Metetra
.799 .878 .904 r
.94006 .46367 .9435 .46708 .95287 .46006 .94951 .45699 Metetra
.79 .895 .918 r
.94951 .45699 .95287 .46006 .96228 .45324 .95902 .45063 Metetra
.767 .916 .938 r
.95902 .45063 .96228 .45324 .97175 .44682 .96861 .44481 Metetra
.409 .85 .929 r
.39477 .61167 .39982 .61192 .40797 .61017 .40295 .60975 Metetra
.265 .765 .889 r
.40295 .60975 .40797 .61017 .41611 .60961 .41112 .60878 Metetra
.188 .706 .881 r
.41112 .60878 .41611 .60961 .42425 .60988 .41931 .60858 Metetra
.162 .675 .895 r
.41931 .60858 .42425 .60988 .43243 .61067 .42751 .60893 Metetra
.161 .659 .914 r
.42751 .60893 .43243 .61067 .44063 .61177 .43574 .60968 Metetra
.171 .649 .928 r
.43574 .60968 .44063 .61177 .44887 .61308 .44401 .61069 Metetra
.183 .643 .939 r
.44401 .61069 .44887 .61308 .45716 .61453 .45231 .61189 Metetra
.196 .638 .946 r
.45231 .61189 .45716 .61453 .46549 .61608 .46066 .61323 Metetra
.207 .635 .951 r
.46066 .61323 .46549 .61608 .47386 .6177 .46905 .61468 Metetra
.218 .632 .954 r
.46905 .61468 .47386 .6177 .48227 .61938 .47748 .61622 Metetra
.227 .63 .956 r
.47748 .61622 .48227 .61938 .49074 .62109 .48596 .61781 Metetra
.235 .628 .957 r
.48596 .61781 .49074 .62109 .49925 .62285 .49449 .61946 Metetra
.242 .626 .958 r
.49449 .61946 .49925 .62285 .50781 .62464 .50306 .62116 Metetra
.248 .625 .959 r
.50306 .62116 .50781 .62464 .51641 .62645 .51168 .62289 Metetra
.253 .624 .959 r
.51168 .62289 .51641 .62645 .52507 .62829 .52035 .62465 Metetra
.258 .623 .959 r
.52035 .62465 .52507 .62829 .53377 .63015 .52907 .62645 Metetra
.262 .622 .959 r
.52907 .62645 .53377 .63015 .54253 .63203 .53784 .62827 Metetra
.266 .621 .959 r
.53784 .62827 .54253 .63203 .55133 .63392 .54666 .63011 Metetra
.27 .621 .959 r
.54666 .63011 .55133 .63392 .56019 .63584 .55553 .63198 Metetra
.273 .62 .959 r
.55553 .63198 .56019 .63584 .56909 .63777 .56445 .63387 Metetra
.276 .62 .959 r
.56445 .63387 .56909 .63777 .57805 .63972 .57342 .63578 Metetra
.278 .619 .959 r
.57342 .63578 .57805 .63972 .58706 .64168 .58245 .6377 Metetra
.281 .619 .959 r
.58245 .6377 .58706 .64168 .59613 .64366 .59153 .63964 Metetra
.283 .619 .959 r
.59153 .63964 .59613 .64366 .60524 .64566 .60066 .6416 Metetra
.285 .618 .958 r
.60066 .6416 .60524 .64566 .61441 .64767 .60984 .64358 Metetra
.287 .618 .958 r
.60984 .64358 .61441 .64767 .62364 .64969 .61908 .64558 Metetra
.289 .618 .958 r
.61908 .64558 .62364 .64969 .63292 .65173 .62838 .64758 Metetra
.29 .617 .958 r
.62838 .64758 .63292 .65173 .64225 .65378 .63773 .64961 Metetra
.292 .617 .958 r
.63773 .64961 .64225 .65378 .65164 .65584 .64713 .65165 Metetra
.293 .617 .958 r
.64713 .65165 .65164 .65584 .66109 .65792 .6566 .65371 Metetra
.294 .617 .958 r
.6566 .65371 .66109 .65792 .67059 .66002 .66612 .65578 Metetra
.296 .616 .957 r
.66612 .65578 .67059 .66002 .68015 .66213 .67569 .65786 Metetra
.648 .778 .943 r
.67569 .65786 .68015 .66213 .68954 .65954 .68511 .65526 Metetra
.803 .81 .857 r
.68511 .65526 .68954 .65954 .69873 .65225 .69433 .64796 Metetra
.803 .811 .858 r
.69433 .64796 .69873 .65225 .70793 .64496 .70356 .64066 Metetra
.803 .812 .858 r
.70356 .64066 .70793 .64496 .71713 .63766 .71279 .63336 Metetra
.803 .812 .859 r
.71279 .63336 .71713 .63766 .72634 .63037 .72203 .62606 Metetra
.803 .813 .859 r
.72203 .62606 .72634 .63037 .73556 .62306 .73127 .61875 Metetra
.804 .814 .859 r
.73127 .61875 .73556 .62306 .74478 .61576 .74052 .61145 Metetra
.804 .815 .86 r
.74052 .61145 .74478 .61576 .75401 .60845 .74978 .60414 Metetra
.804 .816 .861 r
.74978 .60414 .75401 .60845 .76324 .60115 .75904 .59683 Metetra
.804 .817 .861 r
.75904 .59683 .76324 .60115 .77248 .59384 .76831 .58953 Metetra
.804 .818 .862 r
.76831 .58953 .77248 .59384 .78172 .58653 .77759 .58222 Metetra
.805 .819 .863 r
.77759 .58222 .78172 .58653 .79097 .57921 .78687 .57492 Metetra
.805 .821 .864 r
.78687 .57492 .79097 .57921 .80023 .5719 .79616 .56762 Metetra
.805 .822 .864 r
.79616 .56762 .80023 .5719 .80949 .56459 .80546 .56032 Metetra
.805 .824 .865 r
.80546 .56032 .80949 .56459 .81876 .55728 .81476 .55303 Metetra
.806 .826 .867 r
.81476 .55303 .81876 .55728 .82804 .54997 .82407 .54574 Metetra
.806 .828 .868 r
.82407 .54574 .82804 .54997 .83732 .54267 .83339 .53847 Metetra
.806 .831 .869 r
.83339 .53847 .83732 .54267 .84661 .53536 .84272 .5312 Metetra
.807 .833 .871 r
.84272 .5312 .84661 .53536 .85591 .52807 .85205 .52395 Metetra
.807 .836 .873 r
.85205 .52395 .85591 .52807 .86522 .52079 .8614 .51672 Metetra
.807 .84 .875 r
.8614 .51672 .86522 .52079 .87453 .51351 .87075 .50951 Metetra
.807 .844 .878 r
.87075 .50951 .87453 .51351 .88385 .50626 .88011 .50234 Metetra
.807 .849 .881 r
.88011 .50234 .88385 .50626 .89319 .49903 .88949 .4952 Metetra
.807 .854 .885 r
.88949 .4952 .89319 .49903 .90253 .49182 .89888 .48811 Metetra
.806 .861 .889 r
.89888 .48811 .90253 .49182 .91188 .48466 .90829 .4811 Metetra
.805 .869 .895 r
.90829 .4811 .91188 .48466 .92126 .47756 .91772 .47418 Metetra
.802 .879 .902 r
.91772 .47418 .92126 .47756 .93065 .47055 .92717 .4674 Metetra
.797 .891 .911 r
.92717 .4674 .93065 .47055 .94006 .46367 .93666 .4608 Metetra
.788 .905 .923 r
.93666 .4608 .94006 .46367 .94951 .45699 .9462 .45448 Metetra
.769 .921 .938 r
.9462 .45448 .94951 .45699 .95902 .45063 .9558 .44854 Metetra
.733 .936 .954 r
.9558 .44854 .95902 .45063 .96861 .44481 .96549 .44318 Metetra
.426 .858 .934 r
.38968 .61142 .39477 .61167 .40295 .60975 .39789 .60939 Metetra
.304 .79 .9 r
.39789 .60939 .40295 .60975 .41112 .60878 .40609 .60815 Metetra
.221 .733 .884 r
.40609 .60815 .41112 .60878 .41931 .60858 .41431 .60759 Metetra
.178 .695 .886 r
.41431 .60759 .41931 .60858 .42751 .60893 .42254 .60758 Metetra
.161 .673 .897 r
.42254 .60758 .42751 .60893 .43574 .60968 .4308 .60798 Metetra
.159 .659 .911 r
.4308 .60798 .43574 .60968 .44401 .61069 .4391 .60869 Metetra
.165 .65 .923 r
.4391 .60869 .44401 .61069 .45231 .61189 .44742 .60963 Metetra
.174 .644 .933 r
.44742 .60963 .45231 .61189 .46066 .61323 .45579 .61076 Metetra
.184 .64 .94 r
.45579 .61076 .46066 .61323 .46905 .61468 .4642 .61202 Metetra
.194 .637 .945 r
.4642 .61202 .46905 .61468 .47748 .61622 .47265 .61339 Metetra
.203 .634 .949 r
.47265 .61339 .47748 .61622 .48596 .61781 .48115 .61484 Metetra
.211 .632 .952 r
.48115 .61484 .48596 .61781 .49449 .61946 .48969 .61637 Metetra
.219 .63 .954 r
.48969 .61637 .49449 .61946 .50306 .62116 .49828 .61795 Metetra
.226 .629 .956 r
.49828 .61795 .50306 .62116 .51168 .62289 .50692 .61959 Metetra
.233 .627 .957 r
.50692 .61959 .51168 .62289 .52035 .62465 .5156 .62127 Metetra
.238 .626 .958 r
.5156 .62127 .52035 .62465 .52907 .62645 .52434 .62298 Metetra
.243 .625 .958 r
.52434 .62298 .52907 .62645 .53784 .62827 .53312 .62473 Metetra
.248 .624 .959 r
.53312 .62473 .53784 .62827 .54666 .63011 .54196 .62651 Metetra
.252 .623 .959 r
.54196 .62651 .54666 .63011 .55553 .63198 .55084 .62832 Metetra
.256 .623 .959 r
.55084 .62832 .55553 .63198 .56445 .63387 .55978 .63015 Metetra
.26 .622 .959 r
.55978 .63015 .56445 .63387 .57342 .63578 .56877 .63201 Metetra
.263 .622 .959 r
.56877 .63201 .57342 .63578 .58245 .6377 .57781 .63389 Metetra
.266 .621 .959 r
.57781 .63389 .58245 .6377 .59153 .63964 .5869 .63579 Metetra
.269 .621 .959 r
.5869 .63579 .59153 .63964 .60066 .6416 .59605 .63771 Metetra
.271 .62 .959 r
.59605 .63771 .60066 .6416 .60984 .64358 .60525 .63965 Metetra
.274 .62 .959 r
.60525 .63965 .60984 .64358 .61908 .64558 .61451 .64161 Metetra
.276 .619 .959 r
.61451 .64161 .61908 .64558 .62838 .64758 .62382 .64358 Metetra
.278 .619 .959 r
.62382 .64358 .62838 .64758 .63773 .64961 .63318 .64558 Metetra
.28 .619 .959 r
.63318 .64558 .63773 .64961 .64713 .65165 .6426 .64759 Metetra
.282 .618 .959 r
.6426 .64759 .64713 .65165 .6566 .65371 .65208 .64961 Metetra
.283 .618 .959 r
.65208 .64961 .6566 .65371 .66612 .65578 .66162 .65166 Metetra
.285 .618 .958 r
.66162 .65166 .66612 .65578 .67569 .65786 .67121 .65371 Metetra
.647 .784 .947 r
.67121 .65371 .67569 .65786 .68511 .65526 .68065 .6511 Metetra
.804 .816 .861 r
.68065 .6511 .68511 .65526 .69433 .64796 .6899 .6438 Metetra
.804 .817 .861 r
.6899 .6438 .69433 .64796 .70356 .64066 .69916 .63649 Metetra
.804 .818 .862 r
.69916 .63649 .70356 .64066 .71279 .63336 .70842 .62919 Metetra
.805 .819 .862 r
.70842 .62919 .71279 .63336 .72203 .62606 .71769 .62189 Metetra
.805 .82 .863 r
.71769 .62189 .72203 .62606 .73127 .61875 .72697 .61458 Metetra
.805 .821 .863 r
.72697 .61458 .73127 .61875 .74052 .61145 .73625 .60728 Metetra
.805 .822 .864 r
.73625 .60728 .74052 .61145 .74978 .60414 .74554 .59998 Metetra
.806 .823 .865 r
.74554 .59998 .74978 .60414 .75904 .59683 .75483 .59268 Metetra
.806 .825 .866 r
.75483 .59268 .75904 .59683 .76831 .58953 .76413 .58538 Metetra
.806 .826 .867 r
.76413 .58538 .76831 .58953 .77759 .58222 .77344 .57809 Metetra
.806 .828 .868 r
.77344 .57809 .77759 .58222 .78687 .57492 .78276 .5708 Metetra
.807 .83 .869 r
.78276 .5708 .78687 .57492 .79616 .56762 .79208 .56352 Metetra
.807 .832 .87 r
.79208 .56352 .79616 .56762 .80546 .56032 .80141 .55625 Metetra
.807 .834 .871 r
.80141 .55625 .80546 .56032 .81476 .55303 .81075 .54899 Metetra
.807 .836 .873 r
.81075 .54899 .81476 .55303 .82407 .54574 .8201 .54174 Metetra
.807 .839 .874 r
.8201 .54174 .82407 .54574 .83339 .53847 .82945 .5345 Metetra
.808 .842 .876 r
.82945 .5345 .83339 .53847 .84272 .5312 .83882 .52729 Metetra
.808 .846 .879 r
.83882 .52729 .84272 .5312 .85205 .52395 .84819 .5201 Metetra
.808 .849 .881 r
.84819 .5201 .85205 .52395 .8614 .51672 .85758 .51293 Metetra
.808 .854 .884 r
.85758 .51293 .8614 .51672 .87075 .50951 .86698 .50581 Metetra
.807 .859 .887 r
.86698 .50581 .87075 .50951 .88011 .50234 .87639 .49873 Metetra
.807 .864 .891 r
.87639 .49873 .88011 .50234 .88949 .4952 .88581 .49171 Metetra
.806 .871 .896 r
.88581 .49171 .88949 .4952 .89888 .48811 .89525 .48477 Metetra
.804 .879 .901 r
.89525 .48477 .89888 .48811 .90829 .4811 .90472 .47792 Metetra
.8 .888 .908 r
.90472 .47792 .90829 .4811 .91772 .47418 .91421 .4712 Metetra
.795 .899 .916 r
.91421 .4712 .91772 .47418 .92717 .4674 .92373 .46466 Metetra
.786 .911 .926 r
.92373 .46466 .92717 .4674 .93666 .4608 .93329 .45834 Metetra
.771 .924 .937 r
.93329 .45834 .93666 .4608 .9462 .45448 .94291 .45234 Metetra
.745 .936 .949 r
.94291 .45234 .9462 .45448 .9558 .44854 .9526 .44677 Metetra
.701 .943 .96 r
.9526 .44677 .9558 .44854 .96549 .44318 .96238 .44175 Metetra
.437 .864 .937 r
.38455 .61117 .38968 .61142 .39789 .60939 .39278 .60906 Metetra
.333 .807 .909 r
.39278 .60906 .39789 .60939 .40609 .60815 .40102 .60762 Metetra
.253 .755 .89 r
.40102 .60762 .40609 .60815 .41431 .60759 .40927 .60679 Metetra
.201 .716 .884 r
.40927 .60679 .41431 .60759 .42254 .60758 .41753 .60647 Metetra
.172 .689 .889 r
.41753 .60647 .42254 .60758 .4308 .60798 .42582 .60658 Metetra
.16 .671 .898 r
.42582 .60658 .4308 .60798 .4391 .60869 .43414 .60701 Metetra
.158 .66 .909 r
.43414 .60701 .4391 .60869 .44742 .60963 .44249 .6077 Metetra
.162 .652 .919 r
.44249 .6077 .44742 .60963 .45579 .61076 .45088 .6086 Metetra
.168 .646 .928 r
.45088 .6086 .45579 .61076 .4642 .61202 .45931 .60966 Metetra
.176 .642 .935 r
.45931 .60966 .4642 .61202 .47265 .61339 .46779 .61085 Metetra
.184 .639 .941 r
.46779 .61085 .47265 .61339 .48115 .61484 .4763 .61215 Metetra
.192 .636 .945 r
.4763 .61215 .48115 .61484 .48969 .61637 .48486 .61354 Metetra
.2 .634 .948 r
.48486 .61354 .48969 .61637 .49828 .61795 .49347 .615 Metetra
.207 .632 .951 r
.49347 .615 .49828 .61795 .50692 .61959 .50212 .61653 Metetra
.214 .63 .953 r
.50212 .61653 .50692 .61959 .5156 .62127 .51083 .61811 Metetra
.22 .629 .954 r
.51083 .61811 .5156 .62127 .52434 .62298 .51958 .61974 Metetra
.226 .628 .956 r
.51958 .61974 .52434 .62298 .53312 .62473 .52838 .62141 Metetra
.231 .627 .957 r
.52838 .62141 .53312 .62473 .54196 .62651 .53723 .62311 Metetra
.236 .626 .957 r
.53723 .62311 .54196 .62651 .55084 .62832 .54613 .62485 Metetra
.24 .625 .958 r
.54613 .62485 .55084 .62832 .55978 .63015 .55508 .62662 Metetra
.245 .624 .958 r
.55508 .62662 .55978 .63015 .56877 .63201 .56408 .62842 Metetra
.248 .624 .959 r
.56408 .62842 .56877 .63201 .57781 .63389 .57314 .63025 Metetra
.252 .623 .959 r
.57314 .63025 .57781 .63389 .5869 .63579 .58225 .6321 Metetra
.255 .623 .959 r
.58225 .6321 .5869 .63579 .59605 .63771 .59141 .63397 Metetra
.258 .622 .959 r
.59141 .63397 .59605 .63771 .60525 .63965 .60063 .63587 Metetra
.261 .622 .959 r
.60063 .63587 .60525 .63965 .61451 .64161 .6099 .63778 Metetra
.263 .621 .959 r
.6099 .63778 .61451 .64161 .62382 .64358 .61923 .63972 Metetra
.266 .621 .959 r
.61923 .63972 .62382 .64358 .63318 .64558 .62861 .64168 Metetra
.268 .62 .959 r
.62861 .64168 .63318 .64558 .6426 .64759 .63805 .64365 Metetra
.27 .62 .959 r
.63805 .64365 .6426 .64759 .65208 .64961 .64755 .64564 Metetra
.272 .62 .959 r
.64755 .64564 .65208 .64961 .66162 .65166 .6571 .64765 Metetra
.274 .619 .959 r
.6571 .64765 .66162 .65166 .67121 .65371 .66671 .64968 Metetra
.645 .79 .952 r
.66671 .64968 .67121 .65371 .68065 .6511 .67617 .64705 Metetra
.805 .822 .864 r
.67617 .64705 .68065 .6511 .6899 .6438 .68545 .63975 Metetra
.806 .823 .865 r
.68545 .63975 .6899 .6438 .69916 .63649 .69474 .63245 Metetra
.806 .824 .865 r
.69474 .63245 .69916 .63649 .70842 .62919 .70403 .62515 Metetra
.806 .825 .866 r
.70403 .62515 .70842 .62919 .71769 .62189 .71334 .61785 Metetra
.806 .826 .867 r
.71334 .61785 .71769 .62189 .72697 .61458 .72264 .61055 Metetra
.806 .828 .867 r
.72264 .61055 .72697 .61458 .73625 .60728 .73196 .60325 Metetra
.807 .829 .868 r
.73196 .60325 .73625 .60728 .74554 .59998 .74128 .59596 Metetra
.807 .831 .869 r
.74128 .59596 .74554 .59998 .75483 .59268 .7506 .58868 Metetra
.807 .833 .87 r
.7506 .58868 .75483 .59268 .76413 .58538 .75994 .5814 Metetra
.807 .834 .871 r
.75994 .5814 .76413 .58538 .77344 .57809 .76928 .57413 Metetra
.807 .836 .873 r
.76928 .57413 .77344 .57809 .78276 .5708 .77863 .56686 Metetra
.808 .839 .874 r
.77863 .56686 .78276 .5708 .79208 .56352 .78799 .55961 Metetra
.808 .841 .875 r
.78799 .55961 .79208 .56352 .80141 .55625 .79736 .55237 Metetra
.808 .844 .877 r
.79736 .55237 .80141 .55625 .81075 .54899 .80673 .54515 Metetra
.808 .847 .879 r
.80673 .54515 .81075 .54899 .8201 .54174 .81612 .53794 Metetra
.808 .85 .881 r
.81612 .53794 .8201 .54174 .82945 .5345 .82551 .53076 Metetra
.808 .853 .883 r
.82551 .53076 .82945 .5345 .83882 .52729 .83492 .52361 Metetra
.808 .857 .886 r
.83492 .52361 .83882 .52729 .84819 .5201 .84433 .51649 Metetra
.808 .862 .889 r
.84433 .51649 .84819 .5201 .85758 .51293 .85376 .50941 Metetra
.807 .867 .892 r
.85376 .50941 .85758 .51293 .86698 .50581 .8632 .50238 Metetra
.806 .873 .896 r
.8632 .50238 .86698 .50581 .87639 .49873 .87266 .49541 Metetra
.805 .879 .901 r
.87266 .49541 .87639 .49873 .88581 .49171 .88214 .48852 Metetra
.802 .887 .906 r
.88214 .48852 .88581 .49171 .89525 .48477 .89164 .48173 Metetra
.799 .895 .912 r
.89164 .48173 .89525 .48477 .90472 .47792 .90116 .47506 Metetra
.793 .904 .919 r
.90116 .47506 .90472 .47792 .91421 .4712 .91071 .46855 Metetra
.785 .915 .927 r
.91071 .46855 .91421 .4712 .92373 .46466 .9203 .46224 Metetra
.771 .926 .937 r
.9203 .46224 .92373 .46466 .93329 .45834 .92993 .45619 Metetra
.751 .936 .946 r
.92993 .45619 .93329 .45834 .94291 .45234 .93963 .45048 Metetra
.72 .944 .955 r
.93963 .45048 .94291 .45234 .9526 .44677 .94939 .44519 Metetra
.673 .944 .961 r
.94939 .44519 .9526 .44677 .96238 .44175 .95925 .44043 Metetra
.445 .868 .939 r
.37938 .61092 .38455 .61117 .39278 .60906 .38764 .60874 Metetra
.355 .82 .915 r
.38764 .60874 .39278 .60906 .40102 .60762 .39591 .60716 Metetra
.28 .773 .896 r
.39591 .60716 .40102 .60762 .40927 .60679 .40418 .60612 Metetra
.225 .734 .887 r
.40418 .60612 .40927 .60679 .41753 .60647 .41248 .60555 Metetra
.189 .705 .886 r
.41248 .60555 .41753 .60647 .42582 .60658 .4208 .60539 Metetra
.169 .685 .891 r
.4208 .60539 .42582 .60658 .43414 .60701 .42914 .60557 Metetra
.16 .67 .899 r
.42914 .60557 .43414 .60701 .44249 .6077 .43752 .60603 Metetra
.157 .66 .908 r
.43752 .60603 .44249 .6077 .45088 .6086 .44593 .6067 Metetra
.16 .653 .917 r
.44593 .6067 .45088 .6086 .45931 .60966 .45439 .60757 Metetra
.164 .648 .924 r
.45439 .60757 .45931 .60966 .46779 .61085 .46288 .60858 Metetra
.171 .643 .931 r
.46288 .60858 .46779 .61085 .4763 .61215 .47142 .60972 Metetra
.177 .64 .936 r
.47142 .60972 .4763 .61215 .48486 .61354 .48 .61096 Metetra
.184 .638 .941 r
.48 .61096 .48486 .61354 .49347 .615 .48862 .61229 Metetra
.191 .635 .945 r
.48862 .61229 .49347 .615 .50212 .61653 .49729 .6137 Metetra
.198 .634 .947 r
.49729 .6137 .50212 .61653 .51083 .61811 .50601 .61517 Metetra
.204 .632 .95 r
.50601 .61517 .51083 .61811 .51958 .61974 .51478 .6167 Metetra
.21 .631 .952 r
.51478 .6167 .51958 .61974 .52838 .62141 .5236 .61828 Metetra
.216 .629 .953 r
.5236 .61828 .52838 .62141 .53723 .62311 .53246 .6199 Metetra
.221 .628 .955 r
.53246 .6199 .53723 .62311 .54613 .62485 .54138 .62157 Metetra
.226 .627 .956 r
.54138 .62157 .54613 .62485 .55508 .62662 .55035 .62327 Metetra
.23 .627 .956 r
.55035 .62327 .55508 .62662 .56408 .62842 .55937 .625 Metetra
.234 .626 .957 r
.55937 .625 .56408 .62842 .57314 .63025 .56844 .62677 Metetra
.238 .625 .958 r
.56844 .62677 .57314 .63025 .58225 .6321 .57757 .62856 Metetra
.242 .625 .958 r
.57757 .62856 .58225 .6321 .59141 .63397 .58675 .63038 Metetra
.245 .624 .958 r
.58675 .63038 .59141 .63397 .60063 .63587 .59598 .63223 Metetra
.248 .623 .959 r
.59598 .63223 .60063 .63587 .6099 .63778 .60527 .6341 Metetra
.251 .623 .959 r
.60527 .6341 .6099 .63778 .61923 .63972 .61461 .63599 Metetra
.254 .622 .959 r
.61461 .63599 .61923 .63972 .62861 .64168 .62401 .6379 Metetra
.257 .622 .959 r
.62401 .6379 .62861 .64168 .63805 .64365 .63347 .63984 Metetra
.259 .622 .959 r
.63347 .63984 .63805 .64365 .64755 .64564 .64298 .6418 Metetra
.262 .621 .959 r
.64298 .6418 .64755 .64564 .6571 .64765 .65255 .64377 Metetra
.264 .621 .959 r
.65255 .64377 .6571 .64765 .66671 .64968 .66218 .64577 Metetra
.643 .797 .956 r
.66218 .64577 .66671 .64968 .67617 .64705 .67167 .64312 Metetra
.806 .828 .867 r
.67167 .64312 .67617 .64705 .68545 .63975 .68098 .63582 Metetra
.807 .829 .868 r
.68098 .63582 .68545 .63975 .69474 .63245 .6903 .62852 Metetra
.807 .83 .869 r
.6903 .62852 .69474 .63245 .70403 .62515 .69963 .62123 Metetra
.807 .832 .87 r
.69963 .62123 .70403 .62515 .71334 .61785 .70896 .61394 Metetra
.807 .833 .871 r
.70896 .61394 .71334 .61785 .72264 .61055 .7183 .60665 Metetra
.807 .835 .872 r
.7183 .60665 .72264 .61055 .73196 .60325 .72764 .59937 Metetra
.808 .836 .873 r
.72764 .59937 .73196 .60325 .74128 .59596 .737 .59209 Metetra
.808 .838 .874 r
.737 .59209 .74128 .59596 .7506 .58868 .74636 .58483 Metetra
.808 .84 .875 r
.74636 .58483 .7506 .58868 .75994 .5814 .75573 .57757 Metetra
.808 .842 .876 r
.75573 .57757 .75994 .5814 .76928 .57413 .76511 .57033 Metetra
.808 .845 .878 r
.76511 .57033 .76928 .57413 .77863 .56686 .77449 .56309 Metetra
.808 .847 .879 r
.77449 .56309 .77863 .56686 .78799 .55961 .78389 .55588 Metetra
.808 .85 .881 r
.78389 .55588 .78799 .55961 .79736 .55237 .79329 .54868 Metetra
.808 .853 .883 r
.79329 .54868 .79736 .55237 .80673 .54515 .8027 .5415 Metetra
.808 .856 .885 r
.8027 .5415 .80673 .54515 .81612 .53794 .81213 .53435 Metetra
.808 .86 .887 r
.81213 .53435 .81612 .53794 .82551 .53076 .82156 .52723 Metetra
.808 .864 .89 r
.82156 .52723 .82551 .53076 .83492 .52361 .83101 .52015 Metetra
.807 .869 .893 r
.83101 .52015 .83492 .52361 .84433 .51649 .84047 .51311 Metetra
.806 .874 .896 r
.84047 .51311 .84433 .51649 .85376 .50941 .84994 .50612 Metetra
.805 .879 .9 r
.84994 .50612 .85376 .50941 .8632 .50238 .85943 .4992 Metetra
.803 .886 .905 r
.85943 .4992 .8632 .50238 .87266 .49541 .86894 .49235 Metetra
.801 .892 .909 r
.86894 .49235 .87266 .49541 .88214 .48852 .87847 .4856 Metetra
.797 .9 .915 r
.87847 .4856 .88214 .48852 .89164 .48173 .88802 .47896 Metetra
.791 .909 .921 r
.88802 .47896 .89164 .48173 .90116 .47506 .8976 .47247 Metetra
.784 .918 .929 r
.8976 .47247 .90116 .47506 .91071 .46855 .90722 .46616 Metetra
.772 .927 .936 r
.90722 .46616 .91071 .46855 .9203 .46224 .91687 .46007 Metetra
.755 .936 .945 r
.91687 .46007 .9203 .46224 .92993 .45619 .92658 .45426 Metetra
.731 .943 .952 r
.92658 .45426 .92993 .45619 .93963 .45048 .93634 .44879 Metetra
.697 .946 .958 r
.93634 .44879 .93963 .45048 .94939 .44519 .94618 .44373 Metetra
.65 .942 .961 r
.94618 .44373 .94939 .44519 .95925 .44043 .95611 .43917 Metetra
.451 .871 .94 r
.37416 .61066 .37938 .61092 .38764 .60874 .38245 .60844 Metetra
.372 .829 .92 r
.38245 .60844 .38764 .60874 .39591 .60716 .39075 .60674 Metetra
.302 .787 .902 r
.39075 .60674 .39591 .60716 .40418 .60612 .39905 .60553 Metetra
.248 .751 .891 r
.39905 .60553 .40418 .60612 .41248 .60555 .40738 .60476 Metetra
.208 .721 .886 r
.40738 .60476 .41248 .60555 .4208 .60539 .41572 .60438 Metetra
.182 .698 .888 r
.41572 .60438 .4208 .60539 .42914 .60557 .4241 .60433 Metetra
.167 .682 .893 r
.4241 .60433 .42914 .60557 .43752 .60603 .4325 .60456 Metetra
.159 .669 .9 r
.4325 .60456 .43752 .60603 .44593 .6067 .44094 .60503 Metetra
.157 .661 .907 r
.44094 .60503 .44593 .6067 .45439 .60757 .44942 .6057 Metetra
.158 .654 .915 r
.44942 .6057 .45439 .60757 .46288 .60858 .45793 .60653 Metetra
.162 .649 .922 r
.45793 .60653 .46288 .60858 .47142 .60972 .46649 .60751 Metetra
.167 .645 .928 r
.46649 .60751 .47142 .60972 .48 .61096 .47509 .6086 Metetra
.173 .642 .933 r
.47509 .6086 .48 .61096 .48862 .61229 .48373 .6098 Metetra
.179 .639 .937 r
.48373 .6098 .48862 .61229 .49729 .6137 .49243 .61108 Metetra
.185 .637 .941 r
.49243 .61108 .49729 .6137 .50601 .61517 .50116 .61244 Metetra
.191 .635 .944 r
.50116 .61244 .50601 .61517 .51478 .6167 .50995 .61386 Metetra
.196 .633 .947 r
.50995 .61386 .51478 .6167 .5236 .61828 .51878 .61534 Metetra
.202 .632 .949 r
.51878 .61534 .5236 .61828 .53246 .6199 .52767 .61688 Metetra
.207 .631 .951 r
.52767 .61688 .53246 .6199 .54138 .62157 .5366 .61846 Metetra
.212 .63 .952 r
.5366 .61846 .54138 .62157 .55035 .62327 .54559 .62008 Metetra
.217 .629 .954 r
.54559 .62008 .55035 .62327 .55937 .625 .55463 .62175 Metetra
.221 .628 .955 r
.55463 .62175 .55937 .625 .56844 .62677 .56372 .62345 Metetra
.226 .627 .955 r
.56372 .62345 .56844 .62677 .57757 .62856 .57286 .62518 Metetra
.229 .626 .956 r
.57286 .62518 .57757 .62856 .58675 .63038 .58206 .62694 Metetra
.233 .626 .957 r
.58206 .62694 .58675 .63038 .59598 .63223 .59131 .62873 Metetra
.237 .625 .957 r
.59131 .62873 .59598 .63223 .60527 .6341 .60061 .63055 Metetra
.24 .625 .958 r
.60061 .63055 .60527 .6341 .61461 .63599 .60997 .63239 Metetra
.243 .624 .958 r
.60997 .63239 .61461 .63599 .62401 .6379 .61939 .63426 Metetra
.246 .624 .958 r
.61939 .63426 .62401 .6379 .63347 .63984 .62886 .63615 Metetra
.249 .623 .958 r
.62886 .63615 .63347 .63984 .64298 .6418 .63839 .63807 Metetra
.251 .623 .959 r
.63839 .63807 .64298 .6418 .65255 .64377 .64798 .64 Metetra
.254 .622 .959 r
.64798 .64 .65255 .64377 .66218 .64577 .65763 .64196 Metetra
.641 .803 .96 r
.65763 .64196 .66218 .64577 .67167 .64312 .66714 .6393 Metetra
.807 .834 .871 r
.66714 .6393 .67167 .64312 .68098 .63582 .67649 .63201 Metetra
.807 .835 .872 r
.67649 .63201 .68098 .63582 .6903 .62852 .68584 .62472 Metetra
.808 .837 .872 r
.68584 .62472 .6903 .62852 .69963 .62123 .69519 .61743 Metetra
.808 .838 .873 r
.69519 .61743 .69963 .62123 .70896 .61394 .70456 .61016 Metetra
.808 .84 .874 r
.70456 .61016 .70896 .61394 .7183 .60665 .71393 .60288 Metetra
.808 .842 .876 r
.71393 .60288 .7183 .60665 .72764 .59937 .72331 .59562 Metetra
.808 .844 .877 r
.72331 .59562 .72764 .59937 .737 .59209 .7327 .58837 Metetra
.808 .846 .878 r
.7327 .58837 .737 .59209 .74636 .58483 .7421 .58113 Metetra
.808 .848 .879 r
.7421 .58113 .74636 .58483 .75573 .57757 .7515 .5739 Metetra
.809 .85 .881 r
.7515 .5739 .75573 .57757 .76511 .57033 .76092 .56668 Metetra
.809 .853 .883 r
.76092 .56668 .76511 .57033 .77449 .56309 .77034 .55949 Metetra
.809 .856 .884 r
.77034 .55949 .77449 .56309 .78389 .55588 .77977 .55231 Metetra
.808 .859 .886 r
.77977 .55231 .78389 .55588 .79329 .54868 .78921 .54516 Metetra
.808 .862 .889 r
.78921 .54516 .79329 .54868 .8027 .5415 .79866 .53804 Metetra
.808 .866 .891 r
.79866 .53804 .8027 .5415 .81213 .53435 .80813 .53095 Metetra
.807 .87 .894 r
.80813 .53095 .81213 .53435 .82156 .52723 .8176 .5239 Metetra
.807 .875 .897 r
.8176 .5239 .82156 .52723 .83101 .52015 .82709 .51689 Metetra
.806 .879 .9 r
.82709 .51689 .83101 .52015 .84047 .51311 .8366 .50994 Metetra
.804 .885 .904 r
.8366 .50994 .84047 .51311 .84994 .50612 .84612 .50305 Metetra
.802 .891 .908 r
.84612 .50305 .84994 .50612 .85943 .4992 .85566 .49624 Metetra
.799 .897 .912 r
.85566 .49624 .85943 .4992 .86894 .49235 .86522 .48952 Metetra
.795 .904 .917 r
.86522 .48952 .86894 .49235 .87847 .4856 .8748 .48291 Metetra
.79 .912 .923 r
.8748 .48291 .87847 .4856 .88802 .47896 .88441 .47643 Metetra
.783 .92 .929 r
.88441 .47643 .88802 .47896 .8976 .47247 .89404 .47011 Metetra
.772 .928 .936 r
.89404 .47011 .8976 .47247 .90722 .46616 .90372 .46399 Metetra
.758 .936 .943 r
.90372 .46399 .90722 .46616 .91687 .46007 .91344 .4581 Metetra
.739 .943 .95 r
.91344 .4581 .91687 .46007 .92658 .45426 .92321 .45249 Metetra
.712 .947 .956 r
.92321 .45249 .92658 .45426 .93634 .44879 .93305 .44723 Metetra
.677 .946 .959 r
.93305 .44723 .93634 .44879 .94618 .44373 .94295 .44236 Metetra
.632 .939 .96 r
.94295 .44236 .94618 .44373 .95611 .43917 .95294 .43794 Metetra
.455 .873 .941 r
.3689 .6104 .37416 .61066 .38245 .60844 .37722 .60814 Metetra
.385 .836 .924 r
.37722 .60814 .38245 .60844 .39075 .60674 .38554 .60635 Metetra
.321 .799 .907 r
.38554 .60635 .39075 .60674 .39905 .60553 .39388 .605 Metetra
.268 .765 .895 r
.39388 .605 .39905 .60553 .40738 .60476 .40223 .60405 Metetra
.227 .735 .888 r
.40223 .60405 .40738 .60476 .41572 .60438 .41061 .60348 Metetra
.197 .712 .887 r
.41061 .60348 .41572 .60438 .4241 .60433 .41901 .60323 Metetra
.178 .693 .889 r
.41901 .60323 .4241 .60433 .4325 .60456 .42744 .60327 Metetra
.165 .679 .894 r
.42744 .60327 .4325 .60456 .44094 .60503 .43591 .60354 Metetra
.159 .669 .9 r
.43591 .60354 .44094 .60503 .44942 .6057 .44441 .60402 Metetra
.157 .661 .907 r
.44441 .60402 .44942 .6057 .45793 .60653 .45294 .60468 Metetra
.158 .655 .913 r
.45294 .60468 .45793 .60653 .46649 .60751 .46152 .6055 Metetra
.16 .65 .92 r
.46152 .6055 .46649 .60751 .47509 .6086 .47015 .60644 Metetra
.164 .646 .925 r
.47015 .60644 .47509 .6086 .48373 .6098 .47881 .60749 Metetra
.169 .643 .93 r
.47881 .60749 .48373 .6098 .49243 .61108 .48752 .60865 Metetra
.174 .64 .934 r
.48752 .60865 .49243 .61108 .50116 .61244 .49628 .60989 Metetra
.179 .638 .938 r
.49628 .60989 .50116 .61244 .50995 .61386 .50508 .6112 Metetra
.185 .636 .941 r
.50508 .6112 .50995 .61386 .51878 .61534 .51394 .61258 Metetra
.19 .635 .944 r
.51394 .61258 .51878 .61534 .52767 .61688 .52284 .61402 Metetra
.195 .633 .946 r
.52284 .61402 .52767 .61688 .5366 .61846 .53179 .61552 Metetra
.2 .632 .948 r
.53179 .61552 .5366 .61846 .54559 .62008 .5408 .61706 Metetra
.205 .631 .95 r
.5408 .61706 .54559 .62008 .55463 .62175 .54985 .61865 Metetra
.209 .63 .952 r
.54985 .61865 .55463 .62175 .56372 .62345 .55896 .62028 Metetra
.214 .629 .953 r
.55896 .62028 .56372 .62345 .57286 .62518 .56812 .62194 Metetra
.218 .628 .954 r
.56812 .62194 .57286 .62518 .58206 .62694 .57733 .62364 Metetra
.222 .628 .955 r
.57733 .62364 .58206 .62694 .59131 .62873 .5866 .62537 Metetra
.225 .627 .955 r
.5866 .62537 .59131 .62873 .60061 .63055 .59592 .62713 Metetra
.229 .626 .956 r
.59592 .62713 .60061 .63055 .60997 .63239 .6053 .62893 Metetra
.232 .626 .957 r
.6053 .62893 .60997 .63239 .61939 .63426 .61474 .63074 Metetra
.235 .625 .957 r
.61474 .63074 .61939 .63426 .62886 .63615 .62423 .63259 Metetra
.238 .625 .957 r
.62423 .63259 .62886 .63615 .63839 .63807 .63378 .63446 Metetra
.241 .624 .958 r
.63378 .63446 .63839 .63807 .64798 .64 .64338 .63635 Metetra
.244 .624 .958 r
.64338 .63635 .64798 .64 .65763 .64196 .65305 .63827 Metetra
.639 .809 .964 r
.65305 .63827 .65763 .64196 .66714 .6393 .66259 .63559 Metetra
.808 .839 .874 r
.66259 .63559 .66714 .6393 .67649 .63201 .67196 .62831 Metetra
.808 .841 .875 r
.67196 .62831 .67649 .63201 .68584 .62472 .68135 .62103 Metetra
.808 .843 .876 r
.68135 .62103 .68584 .62472 .69519 .61743 .69074 .61376 Metetra
.808 .844 .877 r
.69074 .61376 .69519 .61743 .70456 .61016 .70014 .6065 Metetra
.809 .846 .878 r
.70014 .6065 .70456 .61016 .71393 .60288 .70954 .59925 Metetra
.809 .848 .88 r
.70954 .59925 .71393 .60288 .72331 .59562 .71896 .59201 Metetra
.809 .851 .881 r
.71896 .59201 .72331 .59562 .7327 .58837 .72838 .58478 Metetra
.809 .853 .882 r
.72838 .58478 .7327 .58837 .7421 .58113 .73781 .57756 Metetra
.809 .855 .884 r
.73781 .57756 .7421 .58113 .7515 .5739 .74726 .57037 Metetra
.809 .858 .886 r
.74726 .57037 .7515 .5739 .76092 .56668 .75671 .56319 Metetra
.808 .861 .888 r
.75671 .56319 .76092 .56668 .77034 .55949 .76617 .55604 Metetra
.808 .864 .89 r
.76617 .55604 .77034 .55949 .77977 .55231 .77564 .54891 Metetra
.808 .867 .892 r
.77564 .54891 .77977 .55231 .78921 .54516 .78512 .54181 Metetra
.807 .871 .894 r
.78512 .54181 .78921 .54516 .79866 .53804 .79461 .53475 Metetra
.807 .875 .897 r
.79461 .53475 .79866 .53804 .80813 .53095 .80412 .52772 Metetra
.806 .879 .9 r
.80412 .52772 .80813 .53095 .8176 .5239 .81364 .52075 Metetra
.805 .884 .903 r
.81364 .52075 .8176 .5239 .82709 .51689 .82317 .51382 Metetra
.803 .889 .906 r
.82317 .51382 .82709 .51689 .8366 .50994 .83272 .50696 Metetra
.801 .895 .91 r
.83272 .50696 .8366 .50994 .84612 .50305 .84229 .50018 Metetra
.798 .901 .915 r
.84229 .50018 .84612 .50305 .85566 .49624 .85187 .49348 Metetra
.794 .907 .919 r
.85187 .49348 .85566 .49624 .86522 .48952 .86148 .48688 Metetra
.789 .914 .925 r
.86148 .48688 .86522 .48952 .8748 .48291 .87112 .48041 Metetra
.782 .921 .93 r
.87112 .48041 .8748 .48291 .88441 .47643 .88078 .47409 Metetra
.773 .929 .936 r
.88078 .47409 .88441 .47643 .89404 .47011 .89048 .46793 Metetra
.761 .936 .942 r
.89048 .46793 .89404 .47011 .90372 .46399 .90022 .46198 Metetra
.744 .942 .948 r
.90022 .46198 .90372 .46399 .91344 .4581 .91 .45627 Metetra
.723 .946 .953 r
.91 .45627 .91344 .4581 .92321 .45249 .91984 .45085 Metetra
.695 .948 .958 r
.91984 .45085 .92321 .45249 .93305 .44723 .92973 .44575 Metetra
.659 .945 .96 r
.92973 .44575 .93305 .44723 .94295 .44236 .9397 .44104 Metetra
.616 .936 .959 r
.9397 .44104 .94295 .44236 .95294 .43794 .94975 .43674 Metetra
.459 .874 .942 r
.3636 .61014 .3689 .6104 .37722 .60814 .37194 .60785 Metetra
.395 .842 .926 r
.37194 .60785 .37722 .60814 .38554 .60635 .38029 .60597 Metetra
.337 .809 .911 r
.38029 .60597 .38554 .60635 .39388 .605 .38866 .60451 Metetra
.286 .777 .899 r
.38866 .60451 .39388 .605 .40223 .60405 .39704 .60342 Metetra
.245 .748 .891 r
.39704 .60342 .40223 .60405 .41061 .60348 .40545 .60268 Metetra
.213 .724 .888 r
.40545 .60268 .41061 .60348 .41901 .60323 .41388 .60226 Metetra
.19 .705 .888 r
.41388 .60226 .41901 .60323 .42744 .60327 .42234 .60211 Metetra
.174 .69 .891 r
.42234 .60211 .42744 .60327 .43591 .60354 .43083 .6022 Metetra
.164 .678 .895 r
.43083 .6022 .43591 .60354 .44441 .60402 .43935 .60251 Metetra
.159 .668 .901 r
.43935 .60251 .44441 .60402 .45294 .60468 .44791 .603 Metetra
.157 .661 .906 r
.44791 .603 .45294 .60468 .46152 .6055 .45652 .60366 Metetra
.157 .655 .912 r
.45652 .60366 .46152 .6055 .47015 .60644 .46516 .60445 Metetra
.159 .651 .918 r
.46516 .60445 .47015 .60644 .47881 .60749 .47385 .60537 Metetra
.162 .647 .923 r
.47385 .60537 .47881 .60749 .48752 .60865 .48258 .60639 Metetra
.166 .644 .928 r
.48258 .60639 .48752 .60865 .49628 .60989 .49136 .60751 Metetra
.171 .641 .932 r
.49136 .60751 .49628 .60989 .50508 .6112 .50018 .60871 Metetra
.175 .639 .935 r
.50018 .60871 .50508 .6112 .51394 .61258 .50905 .60999 Metetra
.18 .637 .939 r
.50905 .60999 .51394 .61258 .52284 .61402 .51798 .61133 Metetra
.185 .636 .942 r
.51798 .61133 .52284 .61402 .53179 .61552 .52695 .61273 Metetra
.19 .634 .944 r
.52695 .61273 .53179 .61552 .5408 .61706 .53597 .61419 Metetra
.194 .633 .946 r
.53597 .61419 .5408 .61706 .54985 .61865 .54504 .6157 Metetra
.199 .632 .948 r
.54504 .6157 .54985 .61865 .55896 .62028 .55417 .61725 Metetra
.203 .631 .949 r
.55417 .61725 .55896 .62028 .56812 .62194 .56335 .61884 Metetra
.207 .63 .951 r
.56335 .61884 .56812 .62194 .57733 .62364 .57258 .62048 Metetra
.211 .629 .952 r
.57258 .62048 .57733 .62364 .5866 .62537 .58187 .62214 Metetra
.215 .629 .953 r
.58187 .62214 .5866 .62537 .59592 .62713 .59121 .62385 Metetra
.219 .628 .954 r
.59121 .62385 .59592 .62713 .6053 .62893 .6006 .62558 Metetra
.222 .627 .955 r
.6006 .62558 .6053 .62893 .61474 .63074 .61006 .62735 Metetra
.225 .627 .955 r
.61006 .62735 .61474 .63074 .62423 .63259 .61957 .62914 Metetra
.228 .626 .956 r
.61957 .62914 .62423 .63259 .63378 .63446 .62913 .63096 Metetra
.231 .626 .956 r
.62913 .63096 .63378 .63446 .64338 .63635 .63876 .63281 Metetra
.234 .625 .957 r
.63876 .63281 .64338 .63635 .65305 .63827 .64844 .63468 Metetra
.637 .814 .968 r
.64844 .63468 .65305 .63827 .66259 .63559 .65801 .63199 Metetra
.809 .845 .878 r
.65801 .63199 .66259 .63559 .67196 .62831 .66742 .62472 Metetra
.809 .847 .879 r
.66742 .62472 .67196 .62831 .68135 .62103 .67683 .61745 Metetra
.809 .849 .88 r
.67683 .61745 .68135 .62103 .69074 .61376 .68626 .6102 Metetra
.809 .851 .881 r
.68626 .6102 .69074 .61376 .70014 .6065 .69569 .60296 Metetra
.809 .853 .882 r
.69569 .60296 .70014 .6065 .70954 .59925 .70513 .59573 Metetra
.809 .855 .884 r
.70513 .59573 .70954 .59925 .71896 .59201 .71458 .58852 Metetra
.809 .857 .885 r
.71458 .58852 .71896 .59201 .72838 .58478 .72404 .58132 Metetra
.809 .86 .887 r
.72404 .58132 .72838 .58478 .73781 .57756 .73351 .57414 Metetra
.809 .863 .888 r
.73351 .57414 .73781 .57756 .74726 .57037 .74299 .56698 Metetra
.808 .865 .89 r
.74299 .56698 .74726 .57037 .75671 .56319 .75248 .55985 Metetra
.808 .869 .892 r
.75248 .55985 .75671 .56319 .76617 .55604 .76198 .55274 Metetra
.807 .872 .895 r
.76198 .55274 .76617 .55604 .77564 .54891 .77148 .54566 Metetra
.807 .876 .897 r
.77148 .54566 .77564 .54891 .78512 .54181 .78101 .53862 Metetra
.806 .879 .9 r
.78101 .53862 .78512 .54181 .79461 .53475 .79054 .53162 Metetra
.805 .884 .902 r
.79054 .53162 .79461 .53475 .80412 .52772 .80009 .52466 Metetra
.804 .888 .905 r
.80009 .52466 .80412 .52772 .81364 .52075 .80965 .51776 Metetra
.802 .893 .909 r
.80965 .51776 .81364 .52075 .82317 .51382 .81923 .51093 Metetra
.8 .898 .913 r
.81923 .51093 .82317 .51382 .83272 .50696 .82883 .50416 Metetra
.797 .904 .917 r
.82883 .50416 .83272 .50696 .84229 .50018 .83844 .49748 Metetra
.793 .91 .921 r
.83844 .49748 .84229 .50018 .85187 .49348 .84808 .4909 Metetra
.788 .916 .926 r
.84808 .4909 .85187 .49348 .86148 .48688 .85774 .48443 Metetra
.781 .923 .931 r
.85774 .48443 .86148 .48688 .87112 .48041 .86743 .47809 Metetra
.773 .929 .936 r
.86743 .47809 .87112 .48041 .88078 .47409 .87715 .47191 Metetra
.762 .936 .941 r
.87715 .47191 .88078 .47409 .89048 .46793 .88691 .4659 Metetra
.748 .941 .947 r
.88691 .4659 .89048 .46793 .90022 .46198 .8967 .46011 Metetra
.73 .946 .952 r
.8967 .46011 .90022 .46198 .91 .45627 .90655 .45456 Metetra
.707 .948 .956 r
.90655 .45456 .91 .45627 .91984 .45085 .91644 .4493 Metetra
.679 .947 .958 r
.91644 .4493 .91984 .45085 .92973 .44575 .9264 .44435 Metetra
.644 .942 .959 r
.9264 .44435 .92973 .44575 .9397 .44104 .93643 .43975 Metetra
.604 .933 .958 r
.93643 .43975 .9397 .44104 .94975 .43674 .94654 .43555 Metetra
.462 .876 .943 r
.35825 .60988 .3636 .61014 .37194 .60785 .36662 .60756 Metetra
.404 .847 .929 r
.36662 .60756 .37194 .60785 .38029 .60597 .375 .60562 Metetra
.35 .816 .915 r
.375 .60562 .38029 .60597 .38866 .60451 .3834 .60405 Metetra
.302 .787 .903 r
.3834 .60405 .38866 .60451 .39704 .60342 .39181 .60284 Metetra
.261 .76 .895 r
.39181 .60284 .39704 .60342 .40545 .60268 .40024 .60196 Metetra
.228 .736 .89 r
.40024 .60196 .40545 .60268 .41388 .60226 .4087 .60137 Metetra
.203 .716 .888 r
.4087 .60137 .41388 .60226 .42234 .60211 .41719 .60106 Metetra
.185 .7 .889 r
.41719 .60106 .42234 .60211 .43083 .6022 .4257 .60099 Metetra
.172 .687 .892 r
.4257 .60099 .43083 .6022 .43935 .60251 .43425 .60114 Metetra
.163 .676 .896 r
.43425 .60114 .43935 .60251 .44791 .603 .44284 .60147 Metetra
.159 .668 .901 r
.44284 .60147 .44791 .603 .45652 .60366 .45147 .60197 Metetra
.157 .661 .906 r
.45147 .60197 .45652 .60366 .46516 .60445 .46013 .60262 Metetra
.157 .656 .911 r
.46013 .60262 .46516 .60445 .47385 .60537 .46884 .6034 Metetra
.158 .652 .916 r
.46884 .6034 .47385 .60537 .48258 .60639 .4776 .60429 Metetra
.161 .648 .921 r
.4776 .60429 .48258 .60639 .49136 .60751 .4864 .60529 Metetra
.164 .645 .926 r
.4864 .60529 .49136 .60751 .50018 .60871 .49524 .60638 Metetra
.168 .642 .93 r
.49524 .60638 .50018 .60871 .50905 .60999 .50413 .60754 Metetra
.172 .64 .933 r
.50413 .60754 .50905 .60999 .51798 .61133 .51308 .60879 Metetra
.176 .639 .936 r
.51308 .60879 .51798 .61133 .52695 .61273 .52207 .61009 Metetra
.181 .637 .939 r
.52207 .61009 .52695 .61273 .53597 .61419 .53111 .61146 Metetra
.185 .635 .942 r
.53111 .61146 .53597 .61419 .54504 .6157 .5402 .61289 Metetra
.189 .634 .944 r
.5402 .61289 .54504 .6157 .55417 .61725 .54935 .61436 Metetra
.194 .633 .946 r
.54935 .61436 .55417 .61725 .56335 .61884 .55854 .61588 Metetra
.198 .632 .947 r
.55854 .61588 .56335 .61884 .57258 .62048 .56779 .61744 Metetra
.202 .631 .949 r
.56779 .61744 .57258 .62048 .58187 .62214 .5771 .61904 Metetra
.205 .63 .95 r
.5771 .61904 .58187 .62214 .59121 .62385 .58646 .62068 Metetra
.209 .63 .951 r
.58646 .62068 .59121 .62385 .6006 .62558 .59587 .62236 Metetra
.213 .629 .952 r
.59587 .62236 .6006 .62558 .61006 .62735 .60535 .62407 Metetra
.216 .628 .953 r
.60535 .62407 .61006 .62735 .61957 .62914 .61487 .62581 Metetra
.219 .628 .954 r
.61487 .62581 .61957 .62914 .62913 .63096 .62446 .62757 Metetra
.222 .627 .955 r
.62446 .62757 .62913 .63096 .63876 .63281 .6341 .62937 Metetra
.225 .627 .955 r
.6341 .62937 .63876 .63281 .64844 .63468 .64381 .6312 Metetra
.634 .82 .972 r
.64381 .6312 .64844 .63468 .65801 .63199 .6534 .62849 Metetra
.809 .851 .881 r
.6534 .62849 .65801 .63199 .66742 .62472 .66284 .62123 Metetra
.809 .853 .882 r
.66284 .62123 .66742 .62472 .67683 .61745 .67229 .61399 Metetra
.809 .855 .883 r
.67229 .61399 .67683 .61745 .68626 .6102 .68175 .60676 Metetra
.809 .857 .885 r
.68175 .60676 .68626 .6102 .69569 .60296 .69122 .59954 Metetra
.809 .859 .886 r
.69122 .59954 .69569 .60296 .70513 .59573 .7007 .59234 Metetra
.809 .861 .888 r
.7007 .59234 .70513 .59573 .71458 .58852 .71018 .58515 Metetra
.809 .864 .889 r
.71018 .58515 .71458 .58852 .72404 .58132 .71968 .57799 Metetra
.808 .867 .891 r
.71968 .57799 .72404 .58132 .73351 .57414 .72918 .57085 Metetra
.808 .87 .893 r
.72918 .57085 .73351 .57414 .74299 .56698 .7387 .56373 Metetra
.808 .873 .895 r
.7387 .56373 .74299 .56698 .75248 .55985 .74823 .55664 Metetra
.807 .876 .897 r
.74823 .55664 .75248 .55985 .76198 .55274 .75776 .54958 Metetra
.806 .88 .899 r
.75776 .54958 .76198 .55274 .77148 .54566 .76731 .54255 Metetra
.805 .883 .902 r
.76731 .54255 .77148 .54566 .78101 .53862 .77688 .53557 Metetra
.804 .887 .905 r
.77688 .53557 .78101 .53862 .79054 .53162 .78645 .52864 Metetra
.803 .892 .908 r
.78645 .52864 .79054 .53162 .80009 .52466 .79604 .52176 Metetra
.801 .896 .911 r
.79604 .52176 .80009 .52466 .80965 .51776 .80565 .51494 Metetra
.798 .901 .914 r
.80565 .51494 .80965 .51776 .81923 .51093 .81528 .50819 Metetra
.795 .907 .918 r
.81528 .50819 .81923 .51093 .82883 .50416 .82492 .50152 Metetra
.792 .912 .922 r
.82492 .50152 .82883 .50416 .83844 .49748 .83458 .49494 Metetra
.787 .918 .926 r
.83458 .49494 .83844 .49748 .84808 .4909 .84427 .48847 Metetra
.781 .924 .931 r
.84427 .48847 .84808 .4909 .85774 .48443 .85399 .48212 Metetra
.773 .93 .936 r
.85399 .48212 .85774 .48443 .86743 .47809 .86373 .47591 Metetra
.764 .935 .941 r
.86373 .47591 .86743 .47809 .87715 .47191 .8735 .46986 Metetra
.751 .941 .945 r
.8735 .46986 .87715 .47191 .88691 .4659 .88332 .464 Metetra
.736 .945 .95 r
.88332 .464 .88691 .4659 .8967 .46011 .89317 .45835 Metetra
.717 .948 .954 r
.89317 .45835 .8967 .46011 .90655 .45456 .90307 .45294 Metetra
.693 .948 .957 r
.90307 .45294 .90655 .45456 .91644 .4493 .91303 .44781 Metetra
.665 .946 .959 r
.91303 .44781 .91644 .4493 .9264 .44435 .92305 .44299 Metetra
.631 .94 .959 r
.92305 .44299 .9264 .44435 .93643 .43975 .93313 .4385 Metetra
.594 .93 .957 r
.93313 .4385 .93643 .43975 .94654 .43555 .94329 .43437 Metetra
.464 .877 .943 r
.35286 .60962 .35825 .60988 .36662 .60756 .36126 .60726 Metetra
.411 .851 .931 r
.36126 .60726 .36662 .60756 .375 .60562 .36967 .60527 Metetra
.361 .823 .918 r
.36967 .60527 .375 .60562 .3834 .60405 .37809 .60362 Metetra
.315 .795 .907 r
.37809 .60362 .3834 .60405 .39181 .60284 .38653 .6023 Metetra
.276 .77 .898 r
.38653 .6023 .39181 .60284 .40024 .60196 .39499 .60129 Metetra
.243 .747 .892 r
.39499 .60129 .40024 .60196 .4087 .60137 .40348 .60056 Metetra
.216 .727 .889 r
.40348 .60056 .4087 .60137 .41719 .60106 .41199 .6001 Metetra
.196 .71 .888 r
.41199 .6001 .41719 .60106 .4257 .60099 .42053 .59988 Metetra
.181 .696 .89 r
.42053 .59988 .4257 .60099 .43425 .60114 .42911 .59988 Metetra
.17 .685 .893 r
.42911 .59988 .43425 .60114 .44284 .60147 .43773 .60006 Metetra
.163 .675 .897 r
.43773 .60006 .44284 .60147 .45147 .60197 .44638 .60042 Metetra
.159 .668 .901 r
.44638 .60042 .45147 .60197 .46013 .60262 .45507 .60093 Metetra
.157 .662 .906 r
.45507 .60093 .46013 .60262 .46884 .6034 .4638 .60157 Metetra
.156 .657 .911 r
.4638 .60157 .46884 .6034 .4776 .60429 .47258 .60234 Metetra
.158 .652 .915 r
.47258 .60234 .4776 .60429 .4864 .60529 .4814 .60321 Metetra
.16 .649 .92 r
.4814 .60321 .4864 .60529 .49524 .60638 .49026 .60418 Metetra
.162 .646 .924 r
.49026 .60418 .49524 .60638 .50413 .60754 .49918 .60524 Metetra
.166 .643 .928 r
.49918 .60524 .50413 .60754 .51308 .60879 .50814 .60638 Metetra
.169 .641 .931 r
.50814 .60638 .51308 .60879 .52207 .61009 .51715 .60759 Metetra
.173 .64 .934 r
.51715 .60759 .52207 .61009 .53111 .61146 .52621 .60887 Metetra
.177 .638 .937 r
.52621 .60887 .53111 .61146 .5402 .61289 .53532 .61021 Metetra
.181 .636 .939 r
.53532 .61021 .5402 .61289 .54935 .61436 .54449 .6116 Metetra
.185 .635 .942 r
.54449 .6116 .54935 .61436 .55854 .61588 .55371 .61304 Metetra
.189 .634 .944 r
.55371 .61304 .55854 .61588 .56779 .61744 .56298 .61453 Metetra
.193 .633 .946 r
.56298 .61453 .56779 .61744 .5771 .61904 .5723 .61606 Metetra
.197 .632 .947 r
.5723 .61606 .5771 .61904 .58646 .62068 .58168 .61764 Metetra
.2 .631 .948 r
.58168 .61764 .58646 .62068 .59587 .62236 .59111 .61925 Metetra
.204 .631 .95 r
.59111 .61925 .59587 .62236 .60535 .62407 .6006 .6209 Metetra
.207 .63 .951 r
.6006 .6209 .60535 .62407 .61487 .62581 .61015 .62258 Metetra
.211 .629 .952 r
.61015 .62258 .61487 .62581 .62446 .62757 .61976 .6243 Metetra
.214 .629 .953 r
.61976 .6243 .62446 .62757 .6341 .62937 .62942 .62604 Metetra
.217 .628 .953 r
.62942 .62604 .6341 .62937 .64381 .6312 .63914 .62782 Metetra
.631 .826 .975 r
.63914 .62782 .64381 .6312 .6534 .62849 .64876 .62509 Metetra
.809 .856 .884 r
.64876 .62509 .6534 .62849 .66284 .62123 .65824 .61786 Metetra
.809 .858 .886 r
.65824 .61786 .66284 .62123 .67229 .61399 .66773 .61063 Metetra
.809 .86 .887 r
.66773 .61063 .67229 .61399 .68175 .60676 .67722 .60343 Metetra
.809 .863 .888 r
.67722 .60343 .68175 .60676 .69122 .59954 .68672 .59624 Metetra
.809 .865 .89 r
.68672 .59624 .69122 .59954 .7007 .59234 .69624 .58906 Metetra
.808 .868 .892 r
.69624 .58906 .7007 .59234 .71018 .58515 .70576 .58191 Metetra
.808 .87 .893 r
.70576 .58191 .71018 .58515 .71968 .57799 .71529 .57478 Metetra
.808 .873 .895 r
.71529 .57478 .71968 .57799 .72918 .57085 .72484 .56767 Metetra
.807 .876 .897 r
.72484 .56767 .72918 .57085 .7387 .56373 .73439 .5606 Metetra
.806 .88 .899 r
.73439 .5606 .7387 .56373 .74823 .55664 .74395 .55356 Metetra
.806 .883 .902 r
.74395 .55356 .74823 .55664 .75776 .54958 .75353 .54655 Metetra
.805 .887 .904 r
.75353 .54655 .75776 .54958 .76731 .54255 .76312 .53958 Metetra
.803 .891 .907 r
.76312 .53958 .76731 .54255 .77688 .53557 .77273 .53267 Metetra
.802 .895 .91 r
.77273 .53267 .77688 .53557 .78645 .52864 .78235 .5258 Metetra
.8 .899 .913 r
.78235 .5258 .78645 .52864 .79604 .52176 .79198 .51899 Metetra
.797 .904 .916 r
.79198 .51899 .79604 .52176 .80565 .51494 .80163 .51225 Metetra
.794 .909 .919 r
.80163 .51225 .80565 .51494 .81528 .50819 .81131 .50559 Metetra
.791 .914 .923 r
.81131 .50559 .81528 .50819 .82492 .50152 .821 .49902 Metetra
.786 .919 .927 r
.821 .49902 .82492 .50152 .83458 .49494 .83071 .49254 Metetra
.78 .925 .931 r
.83071 .49254 .83458 .49494 .84427 .48847 .84045 .48618 Metetra
.773 .93 .936 r
.84045 .48618 .84427 .48847 .85399 .48212 .85021 .47994 Metetra
.765 .935 .94 r
.85021 .47994 .85399 .48212 .86373 .47591 .86001 .47385 Metetra
.754 .94 .944 r
.86001 .47385 .86373 .47591 .8735 .46986 .86984 .46793 Metetra
.74 .944 .949 r
.86984 .46793 .8735 .46986 .88332 .464 .87971 .4622 Metetra
.724 .947 .952 r
.87971 .4622 .88332 .464 .89317 .45835 .88962 .45668 Metetra
.704 .949 .956 r
.88962 .45668 .89317 .45835 .90307 .45294 .89958 .4514 Metetra
.68 .948 .958 r
.89958 .4514 .90307 .45294 .91303 .44781 .90959 .44638 Metetra
.652 .944 .959 r
.90959 .44638 .91303 .44781 .92305 .44299 .91967 .44166 Metetra
.62 .938 .958 r
.91967 .44166 .92305 .44299 .93313 .4385 .92981 .43725 Metetra
.585 .927 .956 r
.92981 .43725 .93313 .4385 .94329 .43437 .94002 .43319 Metetra
.466 .878 .944 r
.34742 .60935 .35286 .60962 .36126 .60726 .35585 .60697 Metetra
.417 .854 .932 r
.35585 .60697 .36126 .60726 .36967 .60527 .36428 .60493 Metetra
.371 .828 .921 r
.36428 .60493 .36967 .60527 .37809 .60362 .37273 .6032 Metetra
.327 .803 .91 r
.37273 .6032 .37809 .60362 .38653 .6023 .3812 .60178 Metetra
.289 .778 .901 r
.3812 .60178 .38653 .6023 .39499 .60129 .38969 .60066 Metetra
.256 .756 .894 r
.38969 .60066 .39499 .60129 .40348 .60056 .39821 .59982 Metetra
.229 .736 .89 r
.39821 .59982 .40348 .60056 .41199 .6001 .40675 .59922 Metetra
.207 .719 .889 r
.40675 .59922 .41199 .6001 .42053 .59988 .41532 .59886 Metetra
.19 .705 .889 r
.41532 .59886 .42053 .59988 .42911 .59988 .42393 .59871 Metetra
.178 .693 .89 r
.42393 .59871 .42911 .59988 .43773 .60006 .43257 .59876 Metetra
.168 .683 .893 r
.43257 .59876 .43773 .60006 .44638 .60042 .44124 .59898 Metetra
.162 .674 .897 r
.44124 .59898 .44638 .60042 .45507 .60093 .44996 .59935 Metetra
.158 .667 .901 r
.44996 .59935 .45507 .60093 .4638 .60157 .45871 .59987 Metetra
.157 .662 .906 r
.45871 .59987 .4638 .60157 .47258 .60234 .46751 .60051 Metetra
.156 .657 .91 r
.46751 .60051 .47258 .60234 .4814 .60321 .47636 .60126 Metetra
.157 .653 .914 r
.47636 .60126 .4814 .60321 .49026 .60418 .48525 .60212 Metetra
.159 .65 .918 r
.48525 .60212 .49026 .60418 .49918 .60524 .49418 .60307 Metetra
.161 .647 .922 r
.49418 .60307 .49918 .60524 .50814 .60638 .50316 .60411 Metetra
.164 .644 .926 r
.50316 .60411 .50814 .60638 .51715 .60759 .5122 .60522 Metetra
.167 .642 .929 r
.5122 .60522 .51715 .60759 .52621 .60887 .52128 .60641 Metetra
.171 .64 .932 r
.52128 .60641 .52621 .60887 .53532 .61021 .53041 .60766 Metetra
.174 .639 .935 r
.53041 .60766 .53532 .61021 .54449 .6116 .5396 .60896 Metetra
.178 .637 .938 r
.5396 .60896 .54449 .6116 .55371 .61304 .54883 .61033 Metetra
.182 .636 .94 r
.54883 .61033 .55371 .61304 .56298 .61453 .55812 .61174 Metetra
.185 .635 .942 r
.55812 .61174 .56298 .61453 .5723 .61606 .56747 .6132 Metetra
.189 .634 .944 r
.56747 .6132 .5723 .61606 .58168 .61764 .57687 .61471 Metetra
.192 .633 .945 r
.57687 .61471 .58168 .61764 .59111 .61925 .58632 .61626 Metetra
.196 .632 .947 r
.58632 .61626 .59111 .61925 .6006 .6209 .59583 .61784 Metetra
.199 .631 .948 r
.59583 .61784 .6006 .6209 .61015 .62258 .6054 .61946 Metetra
.203 .631 .949 r
.6054 .61946 .61015 .62258 .61976 .6243 .61502 .62112 Metetra
.206 .63 .95 r
.61502 .62112 .61976 .6243 .62942 .62604 .62471 .62281 Metetra
.209 .629 .951 r
.62471 .62281 .62942 .62604 .63914 .62782 .63445 .62454 Metetra
.629 .831 .978 r
.63445 .62454 .63914 .62782 .64876 .62509 .6441 .6218 Metetra
.809 .862 .888 r
.6441 .6218 .64876 .62509 .65824 .61786 .65361 .61458 Metetra
.809 .864 .889 r
.65361 .61458 .65824 .61786 .66773 .61063 .66313 .60738 Metetra
.809 .866 .891 r
.66313 .60738 .66773 .61063 .67722 .60343 .67266 .6002 Metetra
.808 .869 .892 r
.67266 .6002 .67722 .60343 .68672 .59624 .6822 .59304 Metetra
.808 .871 .894 r
.6822 .59304 .68672 .59624 .69624 .58906 .69175 .58589 Metetra
.808 .874 .895 r
.69175 .58589 .69624 .58906 .70576 .58191 .70131 .57878 Metetra
.807 .877 .897 r
.70131 .57878 .70576 .58191 .71529 .57478 .71088 .57168 Metetra
.807 .88 .899 r
.71088 .57168 .71529 .57478 .72484 .56767 .72046 .56462 Metetra
.806 .883 .901 r
.72046 .56462 .72484 .56767 .73439 .5606 .73005 .55759 Metetra
.805 .886 .904 r
.73005 .55759 .73439 .5606 .74395 .55356 .73966 .5506 Metetra
.804 .89 .906 r
.73966 .5506 .74395 .55356 .75353 .54655 .74928 .54365 Metetra
.802 .893 .909 r
.74928 .54365 .75353 .54655 .76312 .53958 .75891 .53674 Metetra
.801 .897 .911 r
.75891 .53674 .76312 .53958 .77273 .53267 .76856 .52989 Metetra
.799 .902 .914 r
.76856 .52989 .77273 .53267 .78235 .5258 .77822 .52309 Metetra
.796 .906 .917 r
.77822 .52309 .78235 .5258 .79198 .51899 .7879 .51636 Metetra
.793 .911 .921 r
.7879 .51636 .79198 .51899 .80163 .51225 .7976 .5097 Metetra
.79 .915 .924 r
.7976 .5097 .80163 .51225 .81131 .50559 .80731 .50312 Metetra
.785 .92 .928 r
.80731 .50312 .81131 .50559 .821 .49902 .81705 .49664 Metetra
.78 .925 .932 r
.81705 .49664 .821 .49902 .83071 .49254 .82682 .49026 Metetra
.774 .93 .936 r
.82682 .49026 .83071 .49254 .84045 .48618 .8366 .484 Metetra
.766 .935 .94 r
.8366 .484 .84045 .48618 .85021 .47994 .84642 .47788 Metetra
.756 .94 .944 r
.84642 .47788 .85021 .47994 .86001 .47385 .85627 .4719 Metetra
.744 .944 .948 r
.85627 .4719 .86001 .47385 .86984 .46793 .86616 .4661 Metetra
.73 .947 .951 r
.86616 .4661 .86984 .46793 .87971 .4622 .87608 .46048 Metetra
.712 .949 .954 r
.87608 .46048 .87971 .4622 .88962 .45668 .88605 .45508 Metetra
.692 .949 .957 r
.88605 .45508 .88962 .45668 .89958 .4514 .89606 .44991 Metetra
.668 .947 .958 r
.89606 .44991 .89958 .4514 .90959 .44638 .90613 .44499 Metetra
.641 .943 .958 r
.90613 .44499 .90959 .44638 .91967 .44166 .91626 .44036 Metetra
.61 .935 .958 r
.91626 .44036 .91967 .44166 .92981 .43725 .92646 .43602 Metetra
.577 .925 .956 r
.92646 .43602 .92981 .43725 .94002 .43319 .93672 .43201 Metetra
.468 .879 .944 r
.34194 .60908 .34742 .60935 .35585 .60697 .35039 .60668 Metetra
.423 .857 .934 r
.35039 .60668 .35585 .60697 .36428 .60493 .35885 .60459 Metetra
.379 .833 .923 r
.35885 .60459 .36428 .60493 .37273 .6032 .36733 .6028 Metetra
.338 .809 .913 r
.36733 .6028 .37273 .6032 .3812 .60178 .37583 .6013 Metetra
.301 .786 .904 r
.37583 .6013 .3812 .60178 .38969 .60066 .38435 .60007 Metetra
.269 .765 .897 r
.38435 .60007 .38969 .60066 .39821 .59982 .3929 .59912 Metetra
.241 .745 .892 r
.3929 .59912 .39821 .59982 .40675 .59922 .40147 .5984 Metetra
.219 .728 .89 r
.40147 .5984 .40675 .59922 .41532 .59886 .41006 .59791 Metetra
.2 .713 .889 r
.41006 .59791 .41532 .59886 .42393 .59871 .4187 .59764 Metetra
.186 .701 .889 r
.4187 .59764 .42393 .59871 .43257 .59876 .42736 .59755 Metetra
.175 .69 .891 r
.42736 .59755 .43257 .59876 .44124 .59898 .43606 .59764 Metetra
.167 .681 .894 r
.43606 .59764 .44124 .59898 .44996 .59935 .4448 .59788 Metetra
.162 .674 .898 r
.4448 .59788 .44996 .59935 .45871 .59987 .45359 .59827 Metetra
.158 .667 .901 r
.45359 .59827 .45871 .59987 .46751 .60051 .46241 .59879 Metetra
.157 .662 .905 r
.46241 .59879 .46751 .60051 .47636 .60126 .47127 .59943 Metetra
.156 .657 .909 r
.47127 .59943 .47636 .60126 .48525 .60212 .48019 .60018 Metetra
.157 .654 .913 r
.48019 .60018 .48525 .60212 .49418 .60307 .48914 .60102 Metetra
.158 .65 .917 r
.48914 .60102 .49418 .60307 .50316 .60411 .49815 .60195 Metetra
.16 .648 .921 r
.49815 .60195 .50316 .60411 .5122 .60522 .5072 .60297 Metetra
.163 .645 .924 r
.5072 .60297 .5122 .60522 .52128 .60641 .51631 .60406 Metetra
.165 .643 .928 r
.51631 .60406 .52128 .60641 .53041 .60766 .52546 .60522 Metetra
.168 .641 .931 r
.52546 .60522 .53041 .60766 .5396 .60896 .53467 .60644 Metetra
.172 .64 .933 r
.53467 .60644 .5396 .60896 .54883 .61033 .54392 .60773 Metetra
.175 .638 .936 r
.54392 .60773 .54883 .61033 .55812 .61174 .55323 .60906 Metetra
.178 .637 .938 r
.55323 .60906 .55812 .61174 .56747 .6132 .5626 .61045 Metetra
.182 .636 .94 r
.5626 .61045 .56747 .6132 .57687 .61471 .57202 .61189 Metetra
.185 .635 .942 r
.57202 .61189 .57687 .61471 .58632 .61626 .58149 .61337 Metetra
.189 .634 .944 r
.58149 .61337 .58632 .61626 .59583 .61784 .59102 .61489 Metetra
.192 .633 .945 r
.59102 .61489 .59583 .61784 .6054 .61946 .60061 .61645 Metetra
.195 .632 .946 r
.60061 .61645 .6054 .61946 .61502 .62112 .61026 .61805 Metetra
.198 .631 .948 r
.61026 .61805 .61502 .62112 .62471 .62281 .61996 .61968 Metetra
.201 .631 .949 r
.61996 .61968 .62471 .62281 .63445 .62454 .62972 .62135 Metetra
.626 .836 .981 r
.62972 .62135 .63445 .62454 .6441 .6218 .6394 .6186 Metetra
.809 .867 .891 r
.6394 .6186 .6441 .6218 .65361 .61458 .64895 .6114 Metetra
.808 .869 .892 r
.64895 .6114 .65361 .61458 .66313 .60738 .6585 .60423 Metetra
.808 .872 .894 r
.6585 .60423 .66313 .60738 .67266 .6002 .66807 .59708 Metetra
.808 .874 .896 r
.66807 .59708 .67266 .6002 .6822 .59304 .67765 .58994 Metetra
.807 .877 .897 r
.67765 .58994 .6822 .59304 .69175 .58589 .68723 .58283 Metetra
.807 .88 .899 r
.68723 .58283 .69175 .58589 .70131 .57878 .69683 .57575 Metetra
.806 .883 .901 r
.69683 .57575 .70131 .57878 .71088 .57168 .70644 .5687 Metetra
.805 .886 .903 r
.70644 .5687 .71088 .57168 .72046 .56462 .71606 .56168 Metetra
.804 .889 .905 r
.71606 .56168 .72046 .56462 .73005 .55759 .72569 .5547 Metetra
.803 .892 .908 r
.72569 .5547 .73005 .55759 .73966 .5506 .73534 .54776 Metetra
.802 .896 .91 r
.73534 .54776 .73966 .5506 .74928 .54365 .745 .54086 Metetra
.8 .9 .913 r
.745 .54086 .74928 .54365 .75891 .53674 .75467 .53401 Metetra
.798 .904 .915 r
.75467 .53401 .75891 .53674 .76856 .52989 .76436 .52722 Metetra
.796 .908 .918 r
.76436 .52722 .76856 .52989 .77822 .52309 .77407 .5205 Metetra
.793 .912 .922 r
.77407 .5205 .77822 .52309 .7879 .51636 .78379 .51384 Metetra
.789 .917 .925 r
.78379 .51384 .7879 .51636 .7976 .5097 .79354 .50726 Metetra
.785 .921 .928 r
.79354 .50726 .7976 .5097 .80731 .50312 .8033 .50077 Metetra
.78 .926 .932 r
.8033 .50077 .80731 .50312 .81705 .49664 .81309 .49438 Metetra
.774 .931 .936 r
.81309 .49438 .81705 .49664 .82682 .49026 .8229 .4881 Metetra
.766 .935 .939 r
.8229 .4881 .82682 .49026 .8366 .484 .83274 .48194 Metetra
.757 .939 .943 r
.83274 .48194 .8366 .484 .84642 .47788 .84261 .47591 Metetra
.747 .943 .947 r
.84261 .47591 .84642 .47788 .85627 .4719 .85251 .47004 Metetra
.734 .946 .95 r
.85251 .47004 .85627 .4719 .86616 .4661 .86245 .46435 Metetra
.719 .949 .953 r
.86245 .46435 .86616 .4661 .87608 .46048 .87243 .45884 Metetra
.702 .949 .955 r
.87243 .45884 .87608 .46048 .88605 .45508 .88245 .45353 Metetra
.681 .949 .957 r
.88245 .45353 .88605 .45508 .89606 .44991 .89252 .44846 Metetra
.657 .946 .958 r
.89252 .44846 .89606 .44991 .90613 .44499 .90265 .44363 Metetra
.631 .941 .958 r
.90265 .44363 .90613 .44499 .91626 .44036 .91283 .43907 Metetra
.602 .933 .957 r
.91283 .43907 .91626 .44036 .92646 .43602 .92307 .4348 Metetra
.571 .923 .955 r
.92307 .4348 .92646 .43602 .93672 .43201 .93339 .43083 Metetra
.47 .879 .944 r
.33641 .60881 .34194 .60908 .35039 .60668 .34489 .60639 Metetra
.427 .859 .935 r
.34489 .60639 .35039 .60668 .35885 .60459 .35338 .60426 Metetra
.386 .837 .925 r
.35338 .60426 .35885 .60459 .36733 .6028 .36189 .6024 Metetra
.347 .815 .915 r
.36189 .6024 .36733 .6028 .37583 .6013 .37042 .60083 Metetra
.312 .793 .907 r
.37042 .60083 .37583 .6013 .38435 .60007 .37896 .59952 Metetra
.28 .773 .9 r
.37896 .59952 .38435 .60007 .3929 .59912 .38754 .59846 Metetra
.253 .754 .894 r
.38754 .59846 .3929 .59912 .40147 .5984 .39613 .59763 Metetra
.23 .737 .891 r
.39613 .59763 .40147 .5984 .41006 .59791 .40476 .59703 Metetra
.211 .722 .889 r
.40476 .59703 .41006 .59791 .4187 .59764 .41342 .59663 Metetra
.195 .709 .889 r
.41342 .59663 .4187 .59764 .42736 .59755 .42211 .59642 Metetra
.183 .698 .89 r
.42211 .59642 .42736 .59755 .43606 .59764 .43084 .59638 Metetra
.173 .688 .892 r
.43084 .59638 .43606 .59764 .4448 .59788 .43961 .59651 Metetra
.166 .68 .895 r
.43961 .59651 .4448 .59788 .45359 .59827 .44841 .59678 Metetra
.161 .673 .898 r
.44841 .59678 .45359 .59827 .46241 .59879 .45726 .59718 Metetra
.158 .667 .902 r
.45726 .59718 .46241 .59879 .47127 .59943 .46615 .5977 Metetra
.157 .662 .905 r
.46615 .5977 .47127 .59943 .48019 .60018 .47509 .59834 Metetra
.156 .658 .909 r
.47509 .59834 .48019 .60018 .48914 .60102 .48407 .59908 Metetra
.156 .654 .913 r
.48407 .59908 .48914 .60102 .49815 .60195 .4931 .59991 Metetra
.158 .651 .916 r
.4931 .59991 .49815 .60195 .5072 .60297 .50217 .60083 Metetra
.159 .648 .92 r
.50217 .60083 .5072 .60297 .51631 .60406 .5113 .60183 Metetra
.161 .646 .923 r
.5113 .60183 .51631 .60406 .52546 .60522 .52047 .6029 Metetra
.164 .644 .926 r
.52047 .6029 .52546 .60522 .53467 .60644 .5297 .60403 Metetra
.167 .642 .929 r
.5297 .60403 .53467 .60644 .54392 .60773 .53898 .60523 Metetra
.17 .64 .932 r
.53898 .60523 .54392 .60773 .55323 .60906 .54831 .60649 Metetra
.173 .639 .934 r
.54831 .60649 .55323 .60906 .5626 .61045 .5577 .6078 Metetra
.176 .638 .936 r
.5577 .6078 .5626 .61045 .57202 .61189 .56714 .60917 Metetra
.179 .637 .938 r
.56714 .60917 .57202 .61189 .58149 .61337 .57663 .61058 Metetra
.182 .636 .94 r
.57663 .61058 .58149 .61337 .59102 .61489 .58618 .61203 Metetra
.185 .635 .942 r
.58618 .61203 .59102 .61489 .60061 .61645 .59579 .61353 Metetra
.188 .634 .944 r
.59579 .61353 .60061 .61645 .61026 .61805 .60546 .61507 Metetra
.192 .633 .945 r
.60546 .61507 .61026 .61805 .61996 .61968 .61518 .61665 Metetra
.195 .632 .946 r
.61518 .61665 .61996 .61968 .62972 .62135 .62497 .61826 Metetra
.622 .841 .983 r
.62497 .61826 .62972 .62135 .6394 .6186 .63467 .61549 Metetra
.808 .872 .894 r
.63467 .61549 .6394 .6186 .64895 .6114 .64425 .60832 Metetra
.808 .875 .896 r
.64425 .60832 .64895 .6114 .6585 .60423 .65385 .60117 Metetra
.807 .877 .897 r
.65385 .60117 .6585 .60423 .66807 .59708 .66345 .59405 Metetra
.807 .88 .899 r
.66345 .59405 .66807 .59708 .67765 .58994 .67306 .58695 Metetra
.806 .882 .901 r
.67306 .58695 .67765 .58994 .68723 .58283 .68269 .57988 Metetra
.805 .885 .903 r
.68269 .57988 .68723 .58283 .69683 .57575 .69232 .57283 Metetra
.805 .888 .905 r
.69232 .57283 .69683 .57575 .70644 .5687 .70197 .56582 Metetra
.804 .891 .907 r
.70197 .56582 .70644 .5687 .71606 .56168 .71163 .55885 Metetra
.802 .895 .909 r
.71163 .55885 .71606 .56168 .72569 .5547 .72131 .55191 Metetra
.801 .898 .912 r
.72131 .55191 .72569 .5547 .73534 .54776 .73099 .54502 Metetra
.799 .902 .914 r
.73099 .54502 .73534 .54776 .745 .54086 .74069 .53818 Metetra
.797 .906 .917 r
.74069 .53818 .745 .54086 .75467 .53401 .75041 .5314 Metetra
.795 .91 .919 r
.75041 .5314 .75467 .53401 .76436 .52722 .76014 .52467 Metetra
.792 .914 .922 r
.76014 .52467 .76436 .52722 .77407 .5205 .76989 .51801 Metetra
.788 .918 .926 r
.76989 .51801 .77407 .5205 .78379 .51384 .77966 .51143 Metetra
.784 .922 .929 r
.77966 .51143 .78379 .51384 .79354 .50726 .78945 .50493 Metetra
.78 .927 .932 r
.78945 .50493 .79354 .50726 .8033 .50077 .79927 .49852 Metetra
.774 .931 .935 r
.79927 .49852 .8033 .50077 .81309 .49438 .8091 .49222 Metetra
.767 .935 .939 r
.8091 .49222 .81309 .49438 .8229 .4881 .81896 .48602 Metetra
.759 .939 .942 r
.81896 .48602 .8229 .4881 .83274 .48194 .82885 .47996 Metetra
.749 .943 .946 r
.82885 .47996 .83274 .48194 .84261 .47591 .83877 .47403 Metetra
.738 .946 .949 r
.83877 .47403 .84261 .47591 .85251 .47004 .84873 .46826 Metetra
.725 .948 .952 r
.84873 .46826 .85251 .47004 .86245 .46435 .85872 .46266 Metetra
.709 .949 .954 r
.85872 .46266 .86245 .46435 .87243 .45884 .86875 .45725 Metetra
.691 .949 .956 r
.86875 .45725 .87243 .45884 .88245 .45353 .87883 .45204 Metetra
.671 .948 .958 r
.87883 .45204 .88245 .45353 .89252 .44846 .88895 .44705 Metetra
.648 .944 .958 r
.88895 .44705 .89252 .44846 .90265 .44363 .89913 .4423 Metetra
.622 .939 .958 r
.89913 .4423 .90265 .44363 .91283 .43907 .90937 .4378 Metetra
.595 .931 .956 r
.90937 .4378 .91283 .43907 .92307 .4348 .91966 .43358 Metetra
.565 .921 .955 r
.91966 .43358 .92307 .4348 .93339 .43083 .93003 .42964 Metetra
.471 .88 .945 r
.33083 .60854 .33641 .60881 .34489 .60639 .33934 .6061 Metetra
.431 .861 .936 r
.33934 .6061 .34489 .60639 .35338 .60426 .34786 .60392 Metetra
.393 .841 .926 r
.34786 .60392 .35338 .60426 .36189 .6024 .3564 .60202 Metetra
.356 .82 .917 r
.3564 .60202 .36189 .6024 .37042 .60083 .36495 .60038 Metetra
.322 .799 .909 r
.36495 .60038 .37042 .60083 .37896 .59952 .37353 .59898 Metetra
.291 .78 .902 r
.37353 .59898 .37896 .59952 .38754 .59846 .38213 .59783 Metetra
.264 .761 .896 r
.38213 .59783 .38754 .59846 .39613 .59763 .39076 .5969 Metetra
.24 .745 .892 r
.39076 .5969 .39613 .59763 .40476 .59703 .39941 .59619 Metetra
.221 .73 .89 r
.39941 .59619 .40476 .59703 .41342 .59663 .4081 .59568 Metetra
.204 .716 .889 r
.4081 .59568 .41342 .59663 .42211 .59642 .41682 .59536 Metetra
.191 .705 .889 r
.41682 .59536 .42211 .59642 .43084 .59638 .42557 .59521 Metetra
.18 .695 .891 r
.42557 .59521 .43084 .59638 .43961 .59651 .43436 .59521 Metetra
.172 .686 .893 r
.43436 .59521 .43961 .59651 .44841 .59678 .4432 .59537 Metetra
.165 .679 .895 r
.4432 .59537 .44841 .59678 .45726 .59718 .45207 .59566 Metetra
.161 .672 .898 r
.45207 .59566 .45726 .59718 .46615 .5977 .46098 .59607 Metetra
.158 .667 .902 r
.46098 .59607 .46615 .5977 .47509 .59834 .46994 .5966 Metetra
.157 .662 .905 r
.46994 .5966 .47509 .59834 .48407 .59908 .47895 .59724 Metetra
.156 .658 .909 r
.47895 .59724 .48407 .59908 .4931 .59991 .488 .59797 Metetra
.156 .655 .912 r
.488 .59797 .4931 .59991 .50217 .60083 .4971 .59879 Metetra
.157 .652 .916 r
.4971 .59879 .50217 .60083 .5113 .60183 .50625 .59969 Metetra
.159 .649 .919 r
.50625 .59969 .5113 .60183 .52047 .6029 .51544 .60067 Metetra
.16 .647 .922 r
.51544 .60067 .52047 .6029 .5297 .60403 .52469 .60172 Metetra
.163 .645 .925 r
.52469 .60172 .5297 .60403 .53898 .60523 .53399 .60284 Metetra
.165 .643 .928 r
.53399 .60284 .53898 .60523 .54831 .60649 .54335 .60402 Metetra
.168 .641 .93 r
.54335 .60402 .54831 .60649 .5577 .6078 .55276 .60526 Metetra
.171 .64 .932 r
.55276 .60526 .5577 .6078 .56714 .60917 .56222 .60655 Metetra
.174 .639 .935 r
.56222 .60655 .56714 .60917 .57663 .61058 .57173 .60789 Metetra
.176 .637 .937 r
.57173 .60789 .57663 .61058 .58618 .61203 .58131 .60928 Metetra
.179 .636 .939 r
.58131 .60928 .58618 .61203 .59579 .61353 .59094 .61071 Metetra
.182 .635 .94 r
.59094 .61071 .59579 .61353 .60546 .61507 .60063 .61219 Metetra
.185 .634 .942 r
.60063 .61219 .60546 .61507 .61518 .61665 .61037 .6137 Metetra
.188 .634 .943 r
.61037 .6137 .61518 .61665 .62497 .61826 .62018 .61526 Metetra
.619 .845 .986 r
.62018 .61526 .62497 .61826 .63467 .61549 .62991 .61247 Metetra
.807 .877 .897 r
.62991 .61247 .63467 .61549 .64425 .60832 .63953 .60533 Metetra
.807 .88 .899 r
.63953 .60533 .64425 .60832 .65385 .60117 .64916 .59821 Metetra
.806 .882 .901 r
.64916 .59821 .65385 .60117 .66345 .59405 .6588 .59112 Metetra
.806 .885 .902 r
.6588 .59112 .66345 .59405 .67306 .58695 .66845 .58405 Metetra
.805 .888 .904 r
.66845 .58405 .67306 .58695 .68269 .57988 .67811 .57701 Metetra
.804 .891 .906 r
.67811 .57701 .68269 .57988 .69232 .57283 .68779 .57001 Metetra
.803 .894 .908 r
.68779 .57001 .69232 .57283 .70197 .56582 .69748 .56304 Metetra
.802 .897 .91 r
.69748 .56304 .70197 .56582 .71163 .55885 .70718 .55611 Metetra
.8 .9 .913 r
.70718 .55611 .71163 .55885 .72131 .55191 .71689 .54923 Metetra
.798 .904 .915 r
.71689 .54923 .72131 .55191 .73099 .54502 .72662 .54239 Metetra
.796 .907 .918 r
.72662 .54239 .73099 .54502 .74069 .53818 .73636 .53561 Metetra
.794 .911 .92 r
.73636 .53561 .74069 .53818 .75041 .5314 .74612 .52888 Metetra
.791 .915 .923 r
.74612 .52888 .75041 .5314 .76014 .52467 .7559 .52222 Metetra
.788 .919 .926 r
.7559 .52222 .76014 .52467 .76989 .51801 .76569 .51563 Metetra
.784 .923 .929 r
.76569 .51563 .76989 .51801 .77966 .51143 .77551 .50912 Metetra
.779 .927 .932 r
.77551 .50912 .77966 .51143 .78945 .50493 .78535 .5027 Metetra
.774 .931 .935 r
.78535 .5027 .78945 .50493 .79927 .49852 .79521 .49637 Metetra
.768 .935 .939 r
.79521 .49637 .79927 .49852 .8091 .49222 .80509 .49014 Metetra
.76 .939 .942 r
.80509 .49014 .8091 .49222 .81896 .48602 .815 .48404 Metetra
.751 .942 .945 r
.815 .48404 .81896 .48602 .82885 .47996 .82494 .47806 Metetra
.741 .945 .948 r
.82494 .47806 .82885 .47996 .83877 .47403 .83491 .47222 Metetra
.729 .948 .951 r
.83491 .47222 .83877 .47403 .84873 .46826 .84492 .46654 Metetra
.716 .949 .953 r
.84492 .46654 .84873 .46826 .85872 .46266 .85496 .46103 Metetra
.7 .95 .955 r
.85496 .46103 .85872 .46266 .86875 .45725 .86505 .4557 Metetra
.682 .949 .957 r
.86505 .4557 .86875 .45725 .87883 .45204 .87518 .45057 Metetra
.661 .947 .958 r
.87518 .45057 .87883 .45204 .88895 .44705 .88535 .44566 Metetra
.639 .943 .958 r
.88535 .44566 .88895 .44705 .89913 .4423 .89559 .44098 Metetra
.614 .937 .957 r
.89559 .44098 .89913 .4423 .90937 .4378 .90587 .43654 Metetra
.588 .929 .956 r
.90587 .43654 .90937 .4378 .91966 .43358 .91622 .43236 Metetra
.561 .919 .954 r
.91622 .43236 .91966 .43358 .93003 .42964 .92663 .42845 Metetra
.472 .88 .945 r
.3252 .60826 .33083 .60854 .33934 .6061 .33374 .6058 Metetra
.435 .863 .937 r
.33374 .6058 .33934 .6061 .34786 .60392 .34229 .60359 Metetra
.398 .844 .928 r
.34229 .60359 .34786 .60392 .3564 .60202 .35085 .60164 Metetra
.363 .824 .919 r
.35085 .60164 .3564 .60202 .36495 .60038 .35944 .59993 Metetra
.331 .805 .911 r
.35944 .59993 .36495 .60038 .37353 .59898 .36804 .59847 Metetra
.301 .786 .904 r
.36804 .59847 .37353 .59898 .38213 .59783 .37667 .59723 Metetra
.274 .768 .899 r
.37667 .59723 .38213 .59783 .39076 .5969 .38533 .59621 Metetra
.251 .752 .894 r
.38533 .59621 .39076 .5969 .39941 .59619 .39401 .5954 Metetra
.23 .737 .891 r
.39401 .5954 .39941 .59619 .4081 .59568 .40273 .59479 Metetra
.213 .724 .89 r
.40273 .59479 .4081 .59568 .41682 .59536 .41148 .59436 Metetra
.199 .712 .889 r
.41148 .59436 .41682 .59536 .42557 .59521 .42026 .59409 Metetra
.187 .701 .89 r
.42026 .59409 .42557 .59521 .43436 .59521 .42908 .59399 Metetra
.178 .692 .891 r
.42908 .59399 .43436 .59521 .4432 .59537 .43794 .59404 Metetra
.17 .685 .893 r
.43794 .59404 .4432 .59537 .45207 .59566 .44683 .59422 Metetra
.165 .678 .896 r
.44683 .59422 .45207 .59566 .46098 .59607 .45577 .59453 Metetra
.161 .672 .899 r
.45577 .59453 .46098 .59607 .46994 .5966 .46476 .59495 Metetra
.158 .667 .902 r
.46476 .59495 .46994 .5966 .47895 .59724 .47379 .59548 Metetra
.157 .662 .905 r
.47379 .59548 .47895 .59724 .488 .59797 .48286 .59612 Metetra
.156 .658 .908 r
.48286 .59612 .488 .59797 .4971 .59879 .49199 .59684 Metetra
.156 .655 .912 r
.49199 .59684 .4971 .59879 .50625 .59969 .50116 .59765 Metetra
.157 .652 .915 r
.50116 .59765 .50625 .59969 .51544 .60067 .51038 .59854 Metetra
.158 .65 .918 r
.51038 .59854 .51544 .60067 .52469 .60172 .51965 .59951 Metetra
.16 .647 .921 r
.51965 .59951 .52469 .60172 .53399 .60284 .52897 .60054 Metetra
.162 .645 .924 r
.52897 .60054 .53399 .60284 .54335 .60402 .53835 .60164 Metetra
.164 .644 .926 r
.53835 .60164 .54335 .60402 .55276 .60526 .54778 .6028 Metetra
.166 .642 .929 r
.54778 .6028 .55276 .60526 .56222 .60655 .55726 .60402 Metetra
.169 .641 .931 r
.55726 .60402 .56222 .60655 .57173 .60789 .5668 .60529 Metetra
.172 .639 .933 r
.5668 .60529 .57173 .60789 .58131 .60928 .5764 .60661 Metetra
.174 .638 .935 r
.5764 .60661 .58131 .60928 .59094 .61071 .58605 .60798 Metetra
.177 .637 .937 r
.58605 .60798 .59094 .61071 .60063 .61219 .59576 .60939 Metetra
.18 .636 .939 r
.59576 .60939 .60063 .61219 .61037 .6137 .60553 .61085 Metetra
.183 .635 .941 r
.60553 .61085 .61037 .6137 .62018 .61526 .61535 .61234 Metetra
.616 .849 .987 r
.61535 .61234 .62018 .61526 .62991 .61247 .62511 .60954 Metetra
.806 .882 .901 r
.62511 .60954 .62991 .61247 .63953 .60533 .63477 .60242 Metetra
.806 .885 .902 r
.63477 .60242 .63953 .60533 .64916 .59821 .64444 .59534 Metetra
.805 .887 .904 r
.64444 .59534 .64916 .59821 .6588 .59112 .65412 .58827 Metetra
.804 .89 .906 r
.65412 .58827 .6588 .59112 .66845 .58405 .66381 .58124 Metetra
.803 .893 .908 r
.66381 .58124 .66845 .58405 .67811 .57701 .67351 .57424 Metetra
.802 .896 .91 r
.67351 .57424 .67811 .57701 .68779 .57001 .68322 .56728 Metetra
.801 .899 .912 r
.68322 .56728 .68779 .57001 .69748 .56304 .69295 .56035 Metetra
.799 .902 .914 r
.69295 .56035 .69748 .56304 .70718 .55611 .70269 .55347 Metetra
.798 .905 .916 r
.70269 .55347 .70718 .55611 .71689 .54923 .71245 .54664 Metetra
.796 .909 .919 r
.71245 .54664 .71689 .54923 .72662 .54239 .72222 .53985 Metetra
.793 .912 .921 r
.72222 .53985 .72662 .54239 .73636 .53561 .732 .53312 Metetra
.79 .916 .924 r
.732 .53312 .73636 .53561 .74612 .52888 .74181 .52646 Metetra
.787 .92 .927 r
.74181 .52646 .74612 .52888 .7559 .52222 .75163 .51986 Metetra
.783 .924 .929 r
.75163 .51986 .7559 .52222 .76569 .51563 .76147 .51334 Metetra
.779 .927 .932 r
.76147 .51334 .76569 .51563 .77551 .50912 .77133 .5069 Metetra
.774 .931 .935 r
.77133 .5069 .77551 .50912 .78535 .5027 .78121 .50055 Metetra
.768 .935 .938 r
.78121 .50055 .78535 .5027 .79521 .49637 .79112 .4943 Metetra
.761 .939 .941 r
.79112 .4943 .79521 .49637 .80509 .49014 .80105 .48815 Metetra
.753 .942 .944 r
.80105 .48815 .80509 .49014 .815 .48404 .81101 .48213 Metetra
.744 .945 .947 r
.81101 .48213 .815 .48404 .82494 .47806 .821 .47623 Metetra
.733 .947 .95 r
.821 .47623 .82494 .47806 .83491 .47222 .83102 .47048 Metetra
.721 .949 .952 r
.83102 .47048 .83491 .47222 .84492 .46654 .84108 .46488 Metetra
.707 .95 .954 r
.84108 .46488 .84492 .46654 .85496 .46103 .85118 .45945 Metetra
.691 .95 .956 r
.85118 .45945 .85496 .46103 .86505 .4557 .86131 .4542 Metetra
.673 .948 .957 r
.86131 .4542 .86505 .4557 .87518 .45057 .8715 .44914 Metetra
.653 .945 .958 r
.8715 .44914 .87518 .45057 .88535 .44566 .88173 .4443 Metetra
.631 .941 .958 r
.88173 .4443 .88535 .44566 .89559 .44098 .89201 .43967 Metetra
.607 .935 .957 r
.89201 .43967 .89559 .44098 .90587 .43654 .90235 .43528 Metetra
.582 .927 .955 r
.90235 .43528 .90587 .43654 .91622 .43236 .91275 .43114 Metetra
.556 .917 .954 r
.91275 .43114 .91622 .43236 .92663 .42845 .92321 .42725 Metetra
.473 .881 .945 r
.31953 .60798 .3252 .60826 .33374 .6058 .32809 .6055 Metetra
.438 .864 .937 r
.32809 .6055 .33374 .6058 .34229 .60359 .33667 .60327 Metetra
.403 .846 .929 r
.33667 .60327 .34229 .60359 .35085 .60164 .34527 .60127 Metetra
.37 .828 .921 r
.34527 .60127 .35085 .60164 .35944 .59993 .35388 .5995 Metetra
.339 .81 .913 r
.35388 .5995 .35944 .59993 .36804 .59847 .36251 .59797 Metetra
.31 .792 .906 r
.36251 .59797 .36804 .59847 .37667 .59723 .37117 .59665 Metetra
.284 .775 .901 r
.37117 .59665 .37667 .59723 .38533 .59621 .37986 .59555 Metetra
.26 .759 .896 r
.37986 .59555 .38533 .59621 .39401 .5954 .38857 .59465 Metetra
.24 .744 .893 r
.38857 .59465 .39401 .5954 .40273 .59479 .39731 .59394 Metetra
.222 .731 .891 r
.39731 .59394 .40273 .59479 .41148 .59436 .40609 .5934 Metetra
.207 .719 .889 r
.40609 .5934 .41148 .59436 .42026 .59409 .4149 .59304 Metetra
.194 .708 .889 r
.4149 .59304 .42026 .59409 .42908 .59399 .42374 .59283 Metetra
.184 .699 .89 r
.42374 .59283 .42908 .59399 .43794 .59404 .43263 .59278 Metetra
.176 .69 .892 r
.43263 .59278 .43794 .59404 .44683 .59422 .44155 .59285 Metetra
.169 .683 .894 r
.44155 .59285 .44683 .59422 .45577 .59453 .45052 .59306 Metetra
.164 .677 .896 r
.45052 .59306 .45577 .59453 .46476 .59495 .45953 .59338 Metetra
.161 .671 .899 r
.45953 .59338 .46476 .59495 .47379 .59548 .46858 .59382 Metetra
.158 .667 .902 r
.46858 .59382 .47379 .59548 .48286 .59612 .47768 .59435 Metetra
.157 .662 .905 r
.47768 .59435 .48286 .59612 .49199 .59684 .48683 .59498 Metetra
.156 .659 .908 r
.48683 .59498 .49199 .59684 .50116 .59765 .49602 .5957 Metetra
.156 .656 .911 r
.49602 .5957 .50116 .59765 .51038 .59854 .50527 .59651 Metetra
.157 .653 .914 r
.50527 .59651 .51038 .59854 .51965 .59951 .51456 .59739 Metetra
.158 .65 .917 r
.51456 .59739 .51965 .59951 .52897 .60054 .52391 .59834 Metetra
.159 .648 .92 r
.52391 .59834 .52897 .60054 .53835 .60164 .53331 .59936 Metetra
.161 .646 .923 r
.53331 .59936 .53835 .60164 .54778 .6028 .54276 .60044 Metetra
.163 .644 .925 r
.54276 .60044 .54778 .6028 .55726 .60402 .55227 .60158 Metetra
.165 .643 .928 r
.55227 .60158 .55726 .60402 .5668 .60529 .56183 .60278 Metetra
.167 .641 .93 r
.56183 .60278 .5668 .60529 .5764 .60661 .57145 .60403 Metetra
.17 .64 .932 r
.57145 .60403 .5764 .60661 .58605 .60798 .58112 .60533 Metetra
.172 .639 .934 r
.58112 .60533 .58605 .60798 .59576 .60939 .59085 .60668 Metetra
.175 .638 .936 r
.59085 .60668 .59576 .60939 .60553 .61085 .60065 .60807 Metetra
.178 .637 .938 r
.60065 .60807 .60553 .61085 .61535 .61234 .6105 .60951 Metetra
.612 .853 .989 r
.6105 .60951 .61535 .61234 .62511 .60954 .62029 .60669 Metetra
.805 .887 .904 r
.62029 .60669 .62511 .60954 .63477 .60242 .62998 .5996 Metetra
.805 .889 .905 r
.62998 .5996 .63477 .60242 .64444 .59534 .63968 .59255 Metetra
.804 .892 .907 r
.63968 .59255 .64444 .59534 .65412 .58827 .6494 .58552 Metetra
.803 .895 .909 r
.6494 .58552 .65412 .58827 .66381 .58124 .65913 .57852 Metetra
.802 .898 .911 r
.65913 .57852 .66381 .58124 .67351 .57424 .66887 .57156 Metetra
.8 .9 .913 r
.66887 .57156 .67351 .57424 .68322 .56728 .67862 .56464 Metetra
.799 .904 .915 r
.67862 .56464 .68322 .56728 .69295 .56035 .68839 .55775 Metetra
.797 .907 .917 r
.68839 .55775 .69295 .56035 .70269 .55347 .69817 .55092 Metetra
.795 .91 .919 r
.69817 .55092 .70269 .55347 .71245 .54664 .70797 .54413 Metetra
.793 .913 .922 r
.70797 .54413 .71245 .54664 .72222 .53985 .71778 .5374 Metetra
.79 .917 .924 r
.71778 .5374 .72222 .53985 .732 .53312 .72761 .53073 Metetra
.787 .921 .927 r
.72761 .53073 .732 .53312 .74181 .52646 .73746 .52412 Metetra
.783 .924 .93 r
.73746 .52412 .74181 .52646 .75163 .51986 .74732 .51759 Metetra
.779 .928 .933 r
.74732 .51759 .75163 .51986 .76147 .51334 .75721 .51113 Metetra
.774 .931 .935 r
.75721 .51113 .76147 .51334 .77133 .5069 .76712 .50476 Metetra
.768 .935 .938 r
.76712 .50476 .77133 .5069 .78121 .50055 .77705 .49848 Metetra
.762 .938 .941 r
.77705 .49848 .78121 .50055 .79112 .4943 .787 .4923 Metetra
.755 .941 .944 r
.787 .4923 .79112 .4943 .80105 .48815 .79698 .48623 Metetra
.746 .944 .947 r
.79698 .48623 .80105 .48815 .81101 .48213 .80699 .48028 Metetra
.736 .947 .949 r
.80699 .48028 .81101 .48213 .821 .47623 .81703 .47446 Metetra
.725 .949 .952 r
.81703 .47446 .821 .47623 .83102 .47048 .82711 .46879 Metetra
.713 .95 .954 r
.82711 .46879 .83102 .47048 .84108 .46488 .83721 .46326 Metetra
.698 .95 .955 r
.83721 .46326 .84108 .46488 .85118 .45945 .84736 .45791 Metetra
.682 .949 .957 r
.84736 .45791 .85118 .45945 .86131 .4542 .85755 .45273 Metetra
.664 .947 .957 r
.85755 .45273 .86131 .4542 .8715 .44914 .86779 .44774 Metetra
.645 .944 .958 r
.86779 .44774 .8715 .44914 .88173 .4443 .87807 .44295 Metetra
.624 .939 .957 r
.87807 .44295 .88173 .4443 .89201 .43967 .8884 .43838 Metetra
.601 .933 .956 r
.8884 .43838 .89201 .43967 .90235 .43528 .89879 .43403 Metetra
.577 .925 .955 r
.89879 .43403 .90235 .43528 .91275 .43114 .90924 .42991 Metetra
.552 .916 .953 r
.90924 .42991 .91275 .43114 .92321 .42725 .91975 .42604 Metetra
.474 .881 .945 r
.31381 .6077 .31953 .60798 .32809 .6055 .3224 .60521 Metetra
.441 .866 .938 r
.3224 .60521 .32809 .6055 .33667 .60327 .331 .60294 Metetra
.408 .849 .93 r
.331 .60294 .33667 .60327 .34527 .60127 .33963 .6009 Metetra
.376 .831 .923 r
.33963 .6009 .34527 .60127 .35388 .5995 .34827 .59908 Metetra
.346 .814 .915 r
.34827 .59908 .35388 .5995 .36251 .59797 .35693 .59748 Metetra
.318 .797 .909 r
.35693 .59748 .36251 .59797 .37117 .59665 .36562 .5961 Metetra
.293 .78 .903 r
.36562 .5961 .37117 .59665 .37986 .59555 .37434 .59492 Metetra
.269 .765 .898 r
.37434 .59492 .37986 .59555 .38857 .59465 .38308 .59393 Metetra
.249 .75 .894 r
.38308 .59393 .38857 .59465 .39731 .59394 .39185 .59313 Metetra
.231 .737 .892 r
.39185 .59313 .39731 .59394 .40609 .5934 .40065 .5925 Metetra
.215 .725 .89 r
.40065 .5925 .40609 .5934 .4149 .59304 .40949 .59204 Metetra
.202 .714 .889 r
.40949 .59204 .4149 .59304 .42374 .59283 .41836 .59173 Metetra
.191 .705 .89 r
.41836 .59173 .42374 .59283 .43263 .59278 .42728 .59157 Metetra
.182 .696 .891 r
.42728 .59157 .43263 .59278 .44155 .59285 .43623 .59155 Metetra
.174 .689 .892 r
.43623 .59155 .44155 .59285 .45052 .59306 .44522 .59166 Metetra
.168 .682 .894 r
.44522 .59166 .45052 .59306 .45953 .59338 .45425 .59189 Metetra
.164 .676 .897 r
.45425 .59189 .45953 .59338 .46858 .59382 .46333 .59222 Metetra
.16 .671 .899 r
.46333 .59222 .46858 .59382 .47768 .59435 .47246 .59267 Metetra
.158 .666 .902 r
.47246 .59267 .47768 .59435 .48683 .59498 .48163 .5932 Metetra
.157 .662 .905 r
.48163 .5932 .48683 .59498 .49602 .5957 .49085 .59383 Metetra
.156 .659 .908 r
.49085 .59383 .49602 .5957 .50527 .59651 .50012 .59455 Metetra
.156 .656 .911 r
.50012 .59455 .50527 .59651 .51456 .59739 .50944 .59535 Metetra
.156 .653 .913 r
.50944 .59535 .51456 .59739 .52391 .59834 .51881 .59622 Metetra
.157 .651 .916 r
.51881 .59622 .52391 .59834 .53331 .59936 .52823 .59715 Metetra
.158 .649 .919 r
.52823 .59715 .53331 .59936 .54276 .60044 .53771 .59816 Metetra
.16 .647 .922 r
.53771 .59816 .54276 .60044 .55227 .60158 .54724 .59923 Metetra
.162 .645 .924 r
.54724 .59923 .55227 .60158 .56183 .60278 .55682 .60035 Metetra
.164 .643 .926 r
.55682 .60035 .56183 .60278 .57145 .60403 .56646 .60153 Metetra
.166 .642 .929 r
.56646 .60153 .57145 .60403 .58112 .60533 .57616 .60277 Metetra
.168 .641 .931 r
.57616 .60277 .58112 .60533 .59085 .60668 .58591 .60405 Metetra
.171 .639 .933 r
.58591 .60405 .59085 .60668 .60065 .60807 .59573 .60538 Metetra
.173 .638 .935 r
.59573 .60538 .60065 .60807 .6105 .60951 .6056 .60675 Metetra
.609 .857 .99 r
.6056 .60675 .6105 .60951 .62029 .60669 .61542 .60392 Metetra
.804 .891 .906 r
.61542 .60392 .62029 .60669 .62998 .5996 .62515 .59686 Metetra
.803 .894 .908 r
.62515 .59686 .62998 .5996 .63968 .59255 .6349 .58984 Metetra
.802 .896 .91 r
.6349 .58984 .63968 .59255 .6494 .58552 .64465 .58284 Metetra
.801 .899 .912 r
.64465 .58284 .6494 .58552 .65913 .57852 .65442 .57588 Metetra
.8 .902 .914 r
.65442 .57588 .65913 .57852 .66887 .57156 .6642 .56896 Metetra
.798 .905 .916 r
.6642 .56896 .66887 .57156 .67862 .56464 .67399 .56208 Metetra
.796 .908 .918 r
.67399 .56208 .67862 .56464 .68839 .55775 .6838 .55524 Metetra
.794 .911 .92 r
.6838 .55524 .68839 .55775 .69817 .55092 .69363 .54845 Metetra
.792 .915 .923 r
.69363 .54845 .69817 .55092 .70797 .54413 .70346 .54171 Metetra
.789 .918 .925 r
.70346 .54171 .70797 .54413 .71778 .5374 .71332 .53503 Metetra
.786 .921 .927 r
.71332 .53503 .71778 .5374 .72761 .53073 .72319 .52842 Metetra
.783 .925 .93 r
.72319 .52842 .72761 .53073 .73746 .52412 .73308 .52187 Metetra
.779 .928 .933 r
.73308 .52187 .73746 .52412 .74732 .51759 .74299 .51539 Metetra
.774 .931 .935 r
.74299 .51539 .74732 .51759 .75721 .51113 .75292 .509 Metetra
.769 .935 .938 r
.75292 .509 .75721 .51113 .76712 .50476 .76288 .50269 Metetra
.763 .938 .941 r
.76288 .50269 .76712 .50476 .77705 .49848 .77285 .49648 Metetra
.756 .941 .943 r
.77285 .49648 .77705 .49848 .787 .4923 .78286 .49037 Metetra
.748 .944 .946 r
.78286 .49037 .787 .4923 .79698 .48623 .79289 .48437 Metetra
.739 .946 .948 r
.79289 .48437 .79698 .48623 .80699 .48028 .80294 .47849 Metetra
.729 .948 .951 r
.80294 .47849 .80699 .48028 .81703 .47446 .81303 .47275 Metetra
.718 .95 .953 r
.81303 .47275 .81703 .47446 .82711 .46879 .82316 .46714 Metetra
.705 .95 .955 r
.82316 .46714 .82711 .46879 .83721 .46326 .83332 .46169 Metetra
.69 .95 .956 r
.83332 .46169 .83721 .46326 .84736 .45791 .84352 .4564 Metetra
.674 .949 .957 r
.84352 .4564 .84736 .45791 .85755 .45273 .85376 .45128 Metetra
.657 .946 .957 r
.85376 .45128 .85755 .45273 .86779 .44774 .86404 .44635 Metetra
.638 .942 .957 r
.86404 .44635 .86779 .44774 .87807 .44295 .87438 .44162 Metetra
.617 .937 .957 r
.87438 .44162 .87807 .44295 .8884 .43838 .88476 .43709 Metetra
.595 .931 .956 r
.88476 .43709 .8884 .43838 .89879 .43403 .8952 .43277 Metetra
.572 .924 .955 r
.8952 .43277 .89879 .43403 .90924 .42991 .9057 .42868 Metetra
.549 .915 .953 r
.9057 .42868 .90924 .42991 .91975 .42604 .91626 .42482 Metetra
.475 .882 .946 r
.30804 .60742 .31381 .6077 .3224 .60521 .31665 .60491 Metetra
.443 .867 .939 r
.31665 .60491 .3224 .60521 .331 .60294 .32529 .60261 Metetra
.412 .851 .931 r
.32529 .60261 .331 .60294 .33963 .6009 .33394 .60053 Metetra
.382 .835 .924 r
.33394 .60053 .33963 .6009 .34827 .59908 .34261 .59867 Metetra
.353 .818 .917 r
.34261 .59867 .34827 .59908 .35693 .59748 .35131 .59701 Metetra
.326 .802 .91 r
.35131 .59701 .35693 .59748 .36562 .5961 .36002 .59556 Metetra
.301 .786 .905 r
.36002 .59556 .36562 .5961 .37434 .59492 .36877 .5943 Metetra
.278 .771 .9 r
.36877 .5943 .37434 .59492 .38308 .59393 .37754 .59323 Metetra
.257 .756 .896 r
.37754 .59323 .38308 .59393 .39185 .59313 .38634 .59235 Metetra
.239 .743 .893 r
.38634 .59235 .39185 .59313 .40065 .5925 .39517 .59163 Metetra
.223 .731 .891 r
.39517 .59163 .40065 .5925 .40949 .59204 .40403 .59108 Metetra
.209 .72 .89 r
.40403 .59108 .40949 .59204 .41836 .59173 .41294 .59068 Metetra
.198 .711 .89 r
.41294 .59068 .41836 .59173 .42728 .59157 .42188 .59043 Metetra
.188 .702 .89 r
.42188 .59043 .42728 .59157 .43623 .59155 .43085 .59031 Metetra
.179 .694 .891 r
.43085 .59031 .43623 .59155 .44522 .59166 .43987 .59032 Metetra
.173 .687 .893 r
.43987 .59032 .44522 .59166 .45425 .59189 .44893 .59045 Metetra
.167 .681 .895 r
.44893 .59045 .45425 .59189 .46333 .59222 .45804 .5907 Metetra
.163 .675 .897 r
.45804 .5907 .46333 .59222 .47246 .59267 .46719 .59105 Metetra
.16 .671 .899 r
.46719 .59105 .47246 .59267 .48163 .5932 .47639 .5915 Metetra
.158 .666 .902 r
.47639 .5915 .48163 .5932 .49085 .59383 .48563 .59204 Metetra
.157 .663 .905 r
.48563 .59204 .49085 .59383 .50012 .59455 .49493 .59267 Metetra
.156 .659 .907 r
.49493 .59267 .50012 .59455 .50944 .59535 .50427 .59338 Metetra
.156 .656 .91 r
.50427 .59338 .50944 .59535 .51881 .59622 .51366 .59417 Metetra
.156 .654 .913 r
.51366 .59417 .51881 .59622 .52823 .59715 .52311 .59503 Metetra
.157 .651 .916 r
.52311 .59503 .52823 .59715 .53771 .59816 .53261 .59596 Metetra
.158 .649 .918 r
.53261 .59596 .53771 .59816 .54724 .59923 .54216 .59695 Metetra
.159 .647 .921 r
.54216 .59695 .54724 .59923 .55682 .60035 .55177 .59801 Metetra
.161 .645 .923 r
.55177 .59801 .55682 .60035 .56646 .60153 .56144 .59912 Metetra
.163 .644 .925 r
.56144 .59912 .56646 .60153 .57616 .60277 .57116 .60028 Metetra
.165 .642 .927 r
.57116 .60028 .57616 .60277 .58591 .60405 .58094 .6015 Metetra
.167 .641 .93 r
.58094 .6015 .58591 .60405 .59573 .60538 .59077 .60276 Metetra
.169 .64 .931 r
.59077 .60276 .59573 .60538 .6056 .60675 .60067 .60408 Metetra
.605 .86 .992 r
.60067 .60408 .6056 .60675 .61542 .60392 .61052 .60123 Metetra
.803 .895 .909 r
.61052 .60123 .61542 .60392 .62515 .59686 .62029 .5942 Metetra
.801 .898 .911 r
.62029 .5942 .62515 .59686 .6349 .58984 .63007 .5872 Metetra
.8 .901 .913 r
.63007 .5872 .6349 .58984 .64465 .58284 .63987 .58024 Metetra
.799 .904 .915 r
.63987 .58024 .64465 .58284 .65442 .57588 .64967 .57332 Metetra
.797 .906 .917 r
.64967 .57332 .65442 .57588 .6642 .56896 .6595 .56643 Metetra
.796 .909 .919 r
.6595 .56643 .6642 .56896 .67399 .56208 .66933 .55959 Metetra
.794 .912 .921 r
.66933 .55959 .67399 .56208 .6838 .55524 .67918 .5528 Metetra
.791 .915 .923 r
.67918 .5528 .6838 .55524 .69363 .54845 .68904 .54606 Metetra
.789 .919 .925 r
.68904 .54606 .69363 .54845 .70346 .54171 .69892 .53937 Metetra
.786 .922 .928 r
.69892 .53937 .70346 .54171 .71332 .53503 .70882 .53274 Metetra
.782 .925 .93 r
.70882 .53274 .71332 .53503 .72319 .52842 .71874 .52618 Metetra
.779 .928 .933 r
.71874 .52618 .72319 .52842 .73308 .52187 .72867 .51968 Metetra
.774 .932 .935 r
.72867 .51968 .73308 .52187 .74299 .51539 .73863 .51327 Metetra
.769 .935 .938 r
.73863 .51327 .74299 .51539 .75292 .509 .74861 .50693 Metetra
.764 .938 .94 r
.74861 .50693 .75292 .509 .76288 .50269 .75861 .50069 Metetra
.757 .941 .943 r
.75861 .50069 .76288 .50269 .77285 .49648 .76863 .49454 Metetra
.75 .943 .945 r
.76863 .49454 .77285 .49648 .78286 .49037 .77868 .4885 Metetra
.742 .946 .948 r
.77868 .4885 .78286 .49037 .79289 .48437 .78876 .48256 Metetra
.732 .948 .95 r
.78876 .48256 .79289 .48437 .80294 .47849 .79887 .47675 Metetra
.722 .949 .952 r
.79887 .47675 .80294 .47849 .81303 .47275 .80901 .47108 Metetra
.71 .95 .954 r
.80901 .47108 .81303 .47275 .82316 .46714 .81918 .46554 Metetra
.697 .95 .955 r
.81918 .46554 .82316 .46714 .83332 .46169 .82939 .46015 Metetra
.683 .95 .956 r
.82939 .46015 .83332 .46169 .84352 .4564 .83964 .45492 Metetra
.667 .948 .957 r
.83964 .45492 .84352 .4564 .85376 .45128 .84993 .44986 Metetra
.649 .945 .957 r
.84993 .44986 .85376 .45128 .86404 .44635 .86027 .44498 Metetra
.631 .941 .957 r
.86027 .44498 .86404 .44635 .87438 .44162 .87066 .44029 Metetra
.611 .936 .957 r
.87066 .44029 .87438 .44162 .88476 .43709 .88109 .4358 Metetra
.59 .93 .956 r
.88109 .4358 .88476 .43709 .8952 .43277 .89158 .43152 Metetra
.568 .922 .954 r
.89158 .43152 .8952 .43277 .9057 .42868 .90213 .42745 Metetra
.546 .913 .953 r
.90213 .42745 .9057 .42868 .91626 .42482 .91274 .4236 Metetra
.476 .882 .946 r
.30221 .60713 .30804 .60742 .31665 .60491 .31086 .6046 Metetra
.446 .868 .939 r
.31086 .6046 .31665 .60491 .32529 .60261 .31952 .60228 Metetra
.416 .853 .932 r
.31952 .60228 .32529 .60261 .33394 .60053 .3282 .60016 Metetra
.387 .837 .925 r
.3282 .60016 .33394 .60053 .34261 .59867 .33691 .59825 Metetra
.359 .822 .918 r
.33691 .59825 .34261 .59867 .35131 .59701 .34563 .59654 Metetra
.333 .806 .912 r
.34563 .59654 .35131 .59701 .36002 .59556 .35437 .59503 Metetra
.308 .791 .906 r
.35437 .59503 .36002 .59556 .36877 .5943 .36315 .59371 Metetra
.286 .776 .901 r
.36315 .59371 .36877 .5943 .37754 .59323 .37195 .59256 Metetra
.266 .762 .897 r
.37195 .59256 .37754 .59323 .38634 .59235 .38077 .5916 Metetra
.247 .749 .894 r
.38077 .5916 .38634 .59235 .39517 .59163 .38964 .5908 Metetra
.231 .737 .892 r
.38964 .5908 .39517 .59163 .40403 .59108 .39853 .59016 Metetra
.217 .726 .89 r
.39853 .59016 .40403 .59108 .41294 .59068 .40746 .58967 Metetra
.205 .716 .89 r
.40746 .58967 .41294 .59068 .42188 .59043 .41643 .58933 Metetra
.194 .707 .89 r
.41643 .58933 .42188 .59043 .43085 .59031 .42543 .58912 Metetra
.185 .699 .89 r
.42543 .58912 .43085 .59031 .43987 .59032 .43448 .58904 Metetra
.178 .692 .892 r
.43448 .58904 .43987 .59032 .44893 .59045 .44357 .58908 Metetra
.172 .686 .893 r
.44357 .58908 .44893 .59045 .45804 .5907 .4527 .58924 Metetra
.167 .68 .895 r
.4527 .58924 .45804 .5907 .46719 .59105 .46188 .5895 Metetra
.163 .675 .897 r
.46188 .5895 .46719 .59105 .47639 .5915 .4711 .58986 Metetra
.16 .67 .9 r
.4711 .58986 .47639 .5915 .48563 .59204 .48037 .59032 Metetra
.158 .666 .902 r
.48037 .59032 .48563 .59204 .49493 .59267 .48969 .59086 Metetra
.157 .663 .905 r
.48969 .59086 .49493 .59267 .50427 .59338 .49906 .59149 Metetra
.156 .659 .907 r
.49906 .59149 .50427 .59338 .51366 .59417 .50848 .5922 Metetra
.156 .657 .91 r
.50848 .5922 .51366 .59417 .52311 .59503 .51795 .59298 Metetra
.156 .654 .912 r
.51795 .59298 .52311 .59503 .53261 .59596 .52747 .59383 Metetra
.157 .652 .915 r
.52747 .59383 .53261 .59596 .54216 .59695 .53705 .59475 Metetra
.158 .65 .917 r
.53705 .59475 .54216 .59695 .55177 .59801 .54668 .59573 Metetra
.159 .648 .92 r
.54668 .59573 .55177 .59801 .56144 .59912 .55637 .59677 Metetra
.16 .646 .922 r
.55637 .59677 .56144 .59912 .57116 .60028 .56612 .59787 Metetra
.162 .644 .924 r
.56612 .59787 .57116 .60028 .58094 .6015 .57592 .59902 Metetra
.164 .643 .926 r
.57592 .59902 .58094 .6015 .59077 .60276 .58578 .60022 Metetra
.166 .642 .928 r
.58578 .60022 .59077 .60276 .60067 .60408 .5957 .60147 Metetra
.602 .863 .992 r
.5957 .60147 .60067 .60408 .61052 .60123 .60558 .5986 Metetra
.801 .9 .912 r
.60558 .5986 .61052 .60123 .62029 .5942 .61539 .59161 Metetra
.8 .902 .914 r
.61539 .59161 .62029 .5942 .63007 .5872 .62521 .58464 Metetra
.798 .905 .916 r
.62521 .58464 .63007 .5872 .63987 .58024 .63505 .57772 Metetra
.797 .908 .918 r
.63505 .57772 .63987 .58024 .64967 .57332 .64489 .57083 Metetra
.795 .91 .92 r
.64489 .57083 .64967 .57332 .6595 .56643 .65475 .56399 Metetra
.793 .913 .922 r
.65475 .56399 .6595 .56643 .66933 .55959 .66463 .55719 Metetra
.791 .916 .924 r
.66463 .55719 .66933 .55959 .67918 .5528 .67452 .55043 Metetra
.788 .919 .926 r
.67452 .55043 .67918 .5528 .68904 .54606 .68443 .54374 Metetra
.785 .922 .928 r
.68443 .54374 .68904 .54606 .69892 .53937 .69435 .5371 Metetra
.782 .926 .93 r
.69435 .5371 .69892 .53937 .70882 .53274 .70429 .53052 Metetra
.778 .929 .933 r
.70429 .53052 .70882 .53274 .71874 .52618 .71425 .52401 Metetra
.774 .932 .935 r
.71425 .52401 .71874 .52618 .72867 .51968 .72423 .51757 Metetra
.769 .935 .938 r
.72423 .51757 .72867 .51968 .73863 .51327 .73423 .51121 Metetra
.764 .938 .94 r
.73423 .51121 .73863 .51327 .74861 .50693 .74426 .50493 Metetra
.758 .94 .942 r
.74426 .50493 .74861 .50693 .75861 .50069 .7543 .49875 Metetra
.751 .943 .945 r
.7543 .49875 .75861 .50069 .76863 .49454 .76437 .49266 Metetra
.744 .945 .947 r
.76437 .49266 .76863 .49454 .77868 .4885 .77447 .48668 Metetra
.735 .947 .949 r
.77447 .48668 .77868 .4885 .78876 .48256 .7846 .48081 Metetra
.726 .949 .951 r
.7846 .48081 .78876 .48256 .79887 .47675 .79476 .47506 Metetra
.715 .95 .953 r
.79476 .47506 .79887 .47675 .80901 .47108 .80495 .46944 Metetra
.703 .95 .955 r
.80495 .46944 .80901 .47108 .81918 .46554 .81517 .46397 Metetra
.69 .95 .956 r
.81517 .46397 .81918 .46554 .82939 .46015 .82543 .45864 Metetra
.675 .949 .957 r
.82543 .45864 .82939 .46015 .83964 .45492 .83573 .45346 Metetra
.66 .947 .957 r
.83573 .45346 .83964 .45492 .84993 .44986 .84608 .44846 Metetra
.643 .944 .957 r
.84608 .44846 .84993 .44986 .86027 .44498 .85646 .44362 Metetra
.625 .94 .957 r
.85646 .44362 .86027 .44498 .87066 .44029 .8669 .43897 Metetra
.605 .934 .956 r
.8669 .43897 .87066 .44029 .88109 .4358 .87739 .43452 Metetra
.585 .928 .955 r
.87739 .43452 .88109 .4358 .89158 .43152 .88793 .43026 Metetra
.564 .921 .954 r
.88793 .43026 .89158 .43152 .90213 .42745 .89853 .42621 Metetra
.543 .912 .952 r
.89853 .42621 .90213 .42745 .91274 .4236 .90918 .42236 Metetra
.476 .882 .946 r
.29634 .60685 .30221 .60713 .31086 .6046 .30502 .6043 Metetra
.448 .869 .94 r
.30502 .6043 .31086 .6046 .31952 .60228 .31371 .60195 Metetra
.419 .855 .933 r
.31371 .60195 .31952 .60228 .3282 .60016 .32242 .5998 Metetra
.392 .84 .926 r
.32242 .5998 .3282 .60016 .33691 .59825 .33115 .59785 Metetra
.365 .825 .92 r
.33115 .59785 .33691 .59825 .34563 .59654 .3399 .59609 Metetra
.339 .81 .914 r
.3399 .59609 .34563 .59654 .35437 .59503 .34867 .59452 Metetra
.316 .795 .908 r
.34867 .59452 .35437 .59503 .36315 .59371 .35748 .59313 Metetra
.294 .781 .903 r
.35748 .59313 .36315 .59371 .37195 .59256 .3663 .59192 Metetra
.273 .767 .899 r
.3663 .59192 .37195 .59256 .38077 .5916 .37516 .59087 Metetra
.255 .755 .896 r
.37516 .59087 .38077 .5916 .38964 .5908 .38405 .59 Metetra
.239 .743 .893 r
.38405 .59 .38964 .5908 .39853 .59016 .39298 .58928 Metetra
.224 .732 .891 r
.39298 .58928 .39853 .59016 .40746 .58967 .40194 .58871 Metetra
.211 .722 .89 r
.40194 .58871 .40746 .58967 .41643 .58933 .41093 .58828 Metetra
.2 .713 .89 r
.41093 .58828 .41643 .58933 .42543 .58912 .41997 .58798 Metetra
.191 .705 .89 r
.41997 .58798 .42543 .58912 .43448 .58904 .42904 .58781 Metetra
.183 .697 .891 r
.42904 .58781 .43448 .58904 .44357 .58908 .43815 .58777 Metetra
.176 .691 .892 r
.43815 .58777 .44357 .58908 .4527 .58924 .44731 .58784 Metetra
.171 .685 .894 r
.44731 .58784 .4527 .58924 .46188 .5895 .45652 .58801 Metetra
.166 .679 .895 r
.45652 .58801 .46188 .5895 .4711 .58986 .46577 .58829 Metetra
.163 .674 .897 r
.46577 .58829 .4711 .58986 .48037 .59032 .47506 .58866 Metetra
.16 .67 .9 r
.47506 .58866 .48037 .59032 .48969 .59086 .48441 .58912 Metetra
.158 .666 .902 r
.48441 .58912 .48969 .59086 .49906 .59149 .4938 .58967 Metetra
.157 .663 .905 r
.4938 .58967 .49906 .59149 .50848 .5922 .50325 .5903 Metetra
.156 .66 .907 r
.50325 .5903 .50848 .5922 .51795 .59298 .51274 .591 Metetra
.156 .657 .91 r
.51274 .591 .51795 .59298 .52747 .59383 .52229 .59178 Metetra
.156 .654 .912 r
.52229 .59178 .52747 .59383 .53705 .59475 .53189 .59262 Metetra
.156 .652 .914 r
.53189 .59262 .53705 .59475 .54668 .59573 .54155 .59353 Metetra
.157 .65 .917 r
.54155 .59353 .54668 .59573 .55637 .59677 .55127 .5945 Metetra
.158 .648 .919 r
.55127 .5945 .55637 .59677 .56612 .59787 .56104 .59553 Metetra
.16 .647 .921 r
.56104 .59553 .56612 .59787 .57592 .59902 .57086 .59661 Metetra
.161 .645 .923 r
.57086 .59661 .57592 .59902 .58578 .60022 .58075 .59775 Metetra
.163 .644 .926 r
.58075 .59775 .58578 .60022 .5957 .60147 .59069 .59894 Metetra
.598 .866 .993 r
.59069 .59894 .5957 .60147 .60558 .5986 .60061 .59605 Metetra
.799 .904 .915 r
.60061 .59605 .60558 .5986 .61539 .59161 .61046 .58909 Metetra
.798 .906 .916 r
.61046 .58909 .61539 .59161 .62521 .58464 .62032 .58216 Metetra
.796 .909 .918 r
.62032 .58216 .62521 .58464 .63505 .57772 .63019 .57526 Metetra
.794 .911 .92 r
.63019 .57526 .63505 .57772 .64489 .57083 .64008 .56841 Metetra
.792 .914 .922 r
.64008 .56841 .64489 .57083 .65475 .56399 .64998 .56161 Metetra
.79 .917 .924 r
.64998 .56161 .65475 .56399 .66463 .55719 .65989 .55485 Metetra
.788 .92 .926 r
.65989 .55485 .66463 .55719 .67452 .55043 .66983 .54814 Metetra
.785 .923 .928 r
.66983 .54814 .67452 .55043 .68443 .54374 .67978 .54148 Metetra
.782 .926 .931 r
.67978 .54148 .68443 .54374 .69435 .5371 .68974 .53489 Metetra
.778 .929 .933 r
.68974 .53489 .69435 .5371 .70429 .53052 .69973 .52836 Metetra
.774 .932 .935 r
.69973 .52836 .70429 .53052 .71425 .52401 .70973 .5219 Metetra
.77 .935 .938 r
.70973 .5219 .71425 .52401 .72423 .51757 .71976 .51552 Metetra
.765 .938 .94 r
.71976 .51552 .72423 .51757 .73423 .51121 .7298 .50921 Metetra
.759 .94 .942 r
.7298 .50921 .73423 .51121 .74426 .50493 .73987 .50299 Metetra
.753 .943 .944 r
.73987 .50299 .74426 .50493 .7543 .49875 .74997 .49686 Metetra
.746 .945 .947 r
.74997 .49686 .7543 .49875 .76437 .49266 .76008 .49083 Metetra
.738 .947 .949 r
.76008 .49083 .76437 .49266 .77447 .48668 .77023 .48491 Metetra
.729 .949 .951 r
.77023 .48491 .77447 .48668 .7846 .48081 .78041 .4791 Metetra
.719 .95 .952 r
.78041 .4791 .7846 .48081 .79476 .47506 .79061 .47341 Metetra
.708 .95 .954 r
.79061 .47341 .79476 .47506 .80495 .46944 .80085 .46785 Metetra
.696 .95 .955 r
.80085 .46785 .80495 .46944 .81517 .46397 .81113 .46243 Metetra
.683 .95 .956 r
.81113 .46243 .81517 .46397 .82543 .45864 .82144 .45715 Metetra
.669 .948 .957 r
.82144 .45715 .82543 .45864 .83573 .45346 .83179 .45203 Metetra
.653 .946 .957 r
.83179 .45203 .83573 .45346 .84608 .44846 .84218 .44706 Metetra
.637 .942 .957 r
.84218 .44706 .84608 .44846 .85646 .44362 .85262 .44227 Metetra
.619 .938 .957 r
.85262 .44227 .85646 .44362 .8669 .43897 .86311 .43766 Metetra
.6 .933 .956 r
.86311 .43766 .8669 .43897 .87739 .43452 .87365 .43323 Metetra
.581 .927 .955 r
.87365 .43323 .87739 .43452 .88793 .43026 .88424 .429 Metetra
.561 .919 .954 r
.88424 .429 .88793 .43026 .89853 .42621 .89489 .42496 Metetra
.541 .911 .952 r
.89489 .42496 .89853 .42621 .90918 .42236 .90559 .42112 Metetra
.477 .883 .946 r
.29041 .60656 .29634 .60685 .30502 .6043 .29912 .60399 Metetra
.45 .87 .94 r
.29912 .60399 .30502 .6043 .31371 .60195 .30784 .60162 Metetra
.422 .856 .934 r
.30784 .60162 .31371 .60195 .32242 .5998 .31658 .59944 Metetra
.396 .842 .928 r
.31658 .59944 .32242 .5998 .33115 .59785 .32534 .59744 Metetra
.37 .828 .921 r
.32534 .59744 .33115 .59785 .3399 .59609 .33412 .59564 Metetra
.346 .813 .915 r
.33412 .59564 .3399 .59609 .34867 .59452 .34292 .59401 Metetra
.322 .799 .91 r
.34292 .59401 .34867 .59452 .35748 .59313 .35176 .59256 Metetra
.301 .786 .905 r
.35176 .59256 .35748 .59313 .3663 .59192 .36061 .59128 Metetra
.281 .772 .901 r
.36061 .59128 .3663 .59192 .37516 .59087 .3695 .59017 Metetra
.263 .76 .897 r
.3695 .59017 .37516 .59087 .38405 .59 .37842 .58922 Metetra
.246 .748 .894 r
.37842 .58922 .38405 .59 .39298 .58928 .38737 .58842 Metetra
.231 .737 .892 r
.38737 .58842 .39298 .58928 .40194 .58871 .39636 .58777 Metetra
.218 .727 .891 r
.39636 .58777 .40194 .58871 .41093 .58828 .40539 .58726 Metetra
.207 .718 .89 r
.40539 .58726 .41093 .58828 .41997 .58798 .41445 .58688 Metetra
.197 .71 .89 r
.41445 .58688 .41997 .58798 .42904 .58781 .42355 .58663 Metetra
.188 .702 .89 r
.42355 .58663 .42904 .58781 .43815 .58777 .43269 .5865 Metetra
.181 .695 .891 r
.43269 .5865 .43815 .58777 .44731 .58784 .44188 .58648 Metetra
.175 .689 .892 r
.44188 .58648 .44731 .58784 .45652 .58801 .45111 .58657 Metetra
.17 .683 .894 r
.45111 .58657 .45652 .58801 .46577 .58829 .46039 .58677 Metetra
.165 .678 .896 r
.46039 .58677 .46577 .58829 .47506 .58866 .46971 .58706 Metetra
.162 .674 .898 r
.46971 .58706 .47506 .58866 .48441 .58912 .47908 .58744 Metetra
.16 .67 .9 r
.47908 .58744 .48441 .58912 .4938 .58967 .4885 .58791 Metetra
.158 .666 .902 r
.4885 .58791 .4938 .58967 .50325 .5903 .49797 .58846 Metetra
.157 .663 .905 r
.49797 .58846 .50325 .5903 .51274 .591 .50749 .58908 Metetra
.156 .66 .907 r
.50749 .58908 .51274 .591 .52229 .59178 .51707 .58978 Metetra
.156 .657 .909 r
.51707 .58978 .52229 .59178 .53189 .59262 .5267 .59055 Metetra
.156 .655 .912 r
.5267 .59055 .53189 .59262 .54155 .59353 .53638 .59139 Metetra
.156 .653 .914 r
.53638 .59139 .54155 .59353 .55127 .5945 .54612 .59229 Metetra
.157 .651 .916 r
.54612 .59229 .55127 .5945 .56104 .59553 .55591 .59325 Metetra
.158 .649 .918 r
.55591 .59325 .56104 .59553 .57086 .59661 .56577 .59427 Metetra
.159 .647 .921 r
.56577 .59427 .57086 .59661 .58075 .59775 .57568 .59534 Metetra
.161 .646 .923 r
.57568 .59534 .58075 .59775 .59069 .59894 .58565 .59647 Metetra
.594 .869 .994 r
.58565 .59647 .59069 .59894 .60061 .59605 .59559 .59357 Metetra
.797 .907 .917 r
.59559 .59357 .60061 .59605 .61046 .58909 .60548 .58663 Metetra
.796 .91 .919 r
.60548 .58663 .61046 .58909 .62032 .58216 .61538 .57973 Metetra
.794 .912 .921 r
.61538 .57973 .62032 .58216 .63019 .57526 .62529 .57287 Metetra
.792 .915 .923 r
.62529 .57287 .63019 .57526 .64008 .56841 .63522 .56606 Metetra
.79 .918 .925 r
.63522 .56606 .64008 .56841 .64998 .56161 .64516 .55929 Metetra
.787 .921 .927 r
.64516 .55929 .64998 .56161 .65989 .55485 .65512 .55257 Metetra
.785 .923 .929 r
.65512 .55257 .65989 .55485 .66983 .54814 .6651 .5459 Metetra
.782 .926 .931 r
.6651 .5459 .66983 .54814 .67978 .54148 .67509 .5393 Metetra
.778 .929 .933 r
.67509 .5393 .67978 .54148 .68974 .53489 .6851 .53275 Metetra
.774 .932 .935 r
.6851 .53275 .68974 .53489 .69973 .52836 .69513 .52627 Metetra
.77 .935 .937 r
.69513 .52627 .69973 .52836 .70973 .5219 .70518 .51985 Metetra
.765 .937 .94 r
.70518 .51985 .70973 .5219 .71976 .51552 .71525 .51352 Metetra
.76 .94 .942 r
.71525 .51352 .71976 .51552 .7298 .50921 .72534 .50726 Metetra
.754 .942 .944 r
.72534 .50726 .7298 .50921 .73987 .50299 .73545 .5011 Metetra
.747 .945 .946 r
.73545 .5011 .73987 .50299 .74997 .49686 .74559 .49502 Metetra
.74 .947 .948 r
.74559 .49502 .74997 .49686 .76008 .49083 .75576 .48905 Metetra
.732 .948 .95 r
.75576 .48905 .76008 .49083 .77023 .48491 .76595 .48318 Metetra
.723 .949 .952 r
.76595 .48318 .77023 .48491 .78041 .4791 .77618 .47742 Metetra
.713 .95 .953 r
.77618 .47742 .78041 .4791 .79061 .47341 .78643 .47179 Metetra
.702 .951 .955 r
.78643 .47179 .79061 .47341 .80085 .46785 .79672 .46628 Metetra
.69 .95 .956 r
.79672 .46628 .80085 .46785 .81113 .46243 .80705 .46091 Metetra
.676 .949 .957 r
.80705 .46091 .81113 .46243 .82144 .45715 .81741 .45568 Metetra
.662 .947 .957 r
.81741 .45568 .82144 .45715 .83179 .45203 .82781 .4506 Metetra
.647 .945 .957 r
.82781 .4506 .83179 .45203 .84218 .44706 .83826 .44568 Metetra
.631 .941 .957 r
.83826 .44568 .84218 .44706 .85262 .44227 .84875 .44093 Metetra
.614 .937 .956 r
.84875 .44093 .85262 .44227 .86311 .43766 .85928 .43635 Metetra
.596 .931 .956 r
.85928 .43635 .86311 .43766 .87365 .43323 .86987 .43195 Metetra
.577 .925 .955 r
.86987 .43195 .87365 .43323 .88424 .429 .88051 .42773 Metetra
.558 .918 .953 r
.88051 .42773 .88424 .429 .89489 .42496 .89121 .4237 Metetra
.539 .91 .952 r
.89121 .4237 .89489 .42496 .90559 .42112 .90197 .41986 Metetra
.478 .883 .946 r
.28444 .60626 .29041 .60656 .29912 .60399 .29317 .60368 Metetra
.451 .871 .941 r
.29317 .60368 .29912 .60399 .30784 .60162 .30192 .60129 Metetra
.425 .858 .935 r
.30192 .60129 .30784 .60162 .31658 .59944 .31069 .59907 Metetra
.4 .844 .928 r
.31069 .59907 .31658 .59944 .32534 .59744 .31948 .59704 Metetra
.375 .831 .922 r
.31948 .59704 .32534 .59744 .33412 .59564 .32829 .59519 Metetra
.351 .817 .917 r
.32829 .59519 .33412 .59564 .34292 .59401 .33712 .59351 Metetra
.329 .803 .911 r
.33712 .59351 .34292 .59401 .35176 .59256 .34598 .59201 Metetra
.307 .79 .906 r
.34598 .59201 .35176 .59256 .36061 .59128 .35487 .59067 Metetra
.288 .777 .902 r
.35487 .59067 .36061 .59128 .3695 .59017 .36379 .58949 Metetra
.27 .765 .898 r
.36379 .58949 .3695 .59017 .37842 .58922 .37274 .58847 Metetra
.253 .753 .895 r
.37274 .58847 .37842 .58922 .38737 .58842 .38172 .5876 Metetra
.238 .743 .893 r
.38172 .5876 .38737 .58842 .39636 .58777 .39074 .58687 Metetra
.225 .733 .891 r
.39074 .58687 .39636 .58777 .40539 .58726 .39979 .58628 Metetra
.213 .723 .89 r
.39979 .58628 .40539 .58726 .41445 .58688 .40888 .58582 Metetra
.203 .715 .89 r
.40888 .58582 .41445 .58688 .42355 .58663 .41801 .58549 Metetra
.194 .707 .89 r
.41801 .58549 .42355 .58663 .43269 .5865 .42718 .58528 Metetra
.186 .7 .891 r
.42718 .58528 .43269 .5865 .44188 .58648 .4364 .58518 Metetra
.179 .694 .891 r
.4364 .58518 .44188 .58648 .45111 .58657 .44566 .58519 Metetra
.174 .688 .893 r
.44566 .58519 .45111 .58657 .46039 .58677 .45496 .5853 Metetra
.169 .682 .894 r
.45496 .5853 .46039 .58677 .46971 .58706 .46431 .58551 Metetra
.165 .678 .896 r
.46431 .58551 .46971 .58706 .47908 .58744 .47371 .58581 Metetra
.162 .673 .898 r
.47371 .58581 .47908 .58744 .4885 .58791 .48315 .5862 Metetra
.16 .67 .9 r
.48315 .5862 .4885 .58791 .49797 .58846 .49265 .58667 Metetra
.158 .666 .902 r
.49265 .58667 .49797 .58846 .50749 .58908 .5022 .58723 Metetra
.157 .663 .904 r
.5022 .58723 .50749 .58908 .51707 .58978 .5118 .58785 Metetra
.156 .66 .907 r
.5118 .58785 .51707 .58978 .5267 .59055 .52145 .58855 Metetra
.156 .657 .909 r
.52145 .58855 .5267 .59055 .53638 .59139 .53116 .58932 Metetra
.156 .655 .911 r
.53116 .58932 .53638 .59139 .54612 .59229 .54093 .59015 Metetra
.156 .653 .913 r
.54093 .59015 .54612 .59229 .55591 .59325 .55075 .59104 Metetra
.157 .651 .916 r
.55075 .59104 .55591 .59325 .56577 .59427 .56063 .59199 Metetra
.158 .649 .918 r
.56063 .59199 .56577 .59427 .57568 .59534 .57056 .593 Metetra
.159 .648 .92 r
.57056 .593 .57568 .59534 .58565 .59647 .58056 .59406 Metetra
.591 .871 .994 r
.58056 .59406 .58565 .59647 .59559 .59357 .59054 .59114 Metetra
.795 .911 .92 r
.59054 .59114 .59559 .59357 .60548 .58663 .60046 .58424 Metetra
.793 .913 .921 r
.60046 .58424 .60548 .58663 .61538 .57973 .6104 .57737 Metetra
.791 .916 .923 r
.6104 .57737 .61538 .57973 .62529 .57287 .62036 .57055 Metetra
.789 .919 .925 r
.62036 .57055 .62529 .57287 .63522 .56606 .63033 .56377 Metetra
.787 .921 .927 r
.63033 .56377 .63522 .56606 .64516 .55929 .64031 .55704 Metetra
.784 .924 .929 r
.64031 .55704 .64516 .55929 .65512 .55257 .65031 .55036 Metetra
.781 .927 .931 r
.65031 .55036 .65512 .55257 .6651 .5459 .66033 .54373 Metetra
.778 .929 .933 r
.66033 .54373 .6651 .5459 .67509 .5393 .67036 .53716 Metetra
.774 .932 .935 r
.67036 .53716 .67509 .5393 .6851 .53275 .68042 .53066 Metetra
.77 .935 .937 r
.68042 .53066 .6851 .53275 .69513 .52627 .69049 .52422 Metetra
.766 .937 .939 r
.69049 .52422 .69513 .52627 .70518 .51985 .70058 .51786 Metetra
.761 .94 .941 r
.70058 .51786 .70518 .51985 .71525 .51352 .7107 .51157 Metetra
.755 .942 .944 r
.7107 .51157 .71525 .51352 .72534 .50726 .72084 .50537 Metetra
.749 .944 .946 r
.72084 .50537 .72534 .50726 .73545 .5011 .731 .49925 Metetra
.742 .946 .947 r
.731 .49925 .73545 .5011 .74559 .49502 .74119 .49323 Metetra
.734 .948 .949 r
.74119 .49323 .74559 .49502 .75576 .48905 .7514 .4873 Metetra
.726 .949 .951 r
.7514 .4873 .75576 .48905 .76595 .48318 .76164 .48149 Metetra
.717 .95 .953 r
.76164 .48149 .76595 .48318 .77618 .47742 .77192 .47578 Metetra
.706 .951 .954 r
.77192 .47578 .77618 .47742 .78643 .47179 .78222 .4702 Metetra
.695 .951 .955 r
.78222 .4702 .78643 .47179 .79672 .46628 .79256 .46474 Metetra
.683 .95 .956 r
.79256 .46474 .79672 .46628 .80705 .46091 .80293 .45942 Metetra
.67 .949 .957 r
.80293 .45942 .80705 .46091 .81741 .45568 .81335 .45423 Metetra
.656 .946 .957 r
.81335 .45423 .81741 .45568 .82781 .4506 .8238 .44919 Metetra
.641 .944 .957 r
.8238 .44919 .82781 .4506 .83826 .44568 .83429 .44431 Metetra
.625 .94 .957 r
.83429 .44431 .83826 .44568 .84875 .44093 .84483 .43959 Metetra
.609 .935 .956 r
.84483 .43959 .84875 .44093 .85928 .43635 .85542 .43504 Metetra
.591 .93 .955 r
.85542 .43504 .85928 .43635 .86987 .43195 .86606 .43066 Metetra
.573 .924 .954 r
.86606 .43066 .86987 .43195 .88051 .42773 .87675 .42645 Metetra
.555 .917 .953 r
.87675 .42645 .88051 .42773 .89121 .4237 .8875 .42243 Metetra
.536 .91 .952 r
.8875 .42243 .89121 .4237 .90197 .41986 .8983 .4186 Metetra
.478 .883 .946 r
.27841 .60597 .28444 .60626 .29317 .60368 .28717 .60337 Metetra
.453 .871 .941 r
.28717 .60337 .29317 .60368 .30192 .60129 .29595 .60095 Metetra
.428 .859 .935 r
.29595 .60095 .30192 .60129 .31069 .59907 .30474 .59871 Metetra
.403 .846 .929 r
.30474 .59871 .31069 .59907 .31948 .59704 .31356 .59664 Metetra
.379 .833 .924 r
.31356 .59664 .31948 .59704 .32829 .59519 .3224 .59475 Metetra
.356 .82 .918 r
.3224 .59475 .32829 .59519 .33712 .59351 .33127 .59302 Metetra
.334 .807 .913 r
.33127 .59302 .33712 .59351 .34598 .59201 .34016 .59146 Metetra
.314 .794 .908 r
.34016 .59146 .34598 .59201 .35487 .59067 .34908 .59006 Metetra
.294 .781 .904 r
.34908 .59006 .35487 .59067 .36379 .58949 .35803 .58882 Metetra
.276 .769 .9 r
.35803 .58882 .36379 .58949 .37274 .58847 .367 .58774 Metetra
.26 .758 .897 r
.367 .58774 .37274 .58847 .38172 .5876 .37602 .58679 Metetra
.245 .747 .894 r
.37602 .58679 .38172 .5876 .39074 .58687 .38506 .586 Metetra
.232 .738 .892 r
.38506 .586 .39074 .58687 .39979 .58628 .39414 .58533 Metetra
.219 .728 .891 r
.39414 .58533 .39979 .58628 .40888 .58582 .40326 .5848 Metetra
.209 .72 .89 r
.40326 .5848 .40888 .58582 .41801 .58549 .41242 .58439 Metetra
.199 .712 .89 r
.41242 .58439 .41801 .58549 .42718 .58528 .42162 .5841 Metetra
.191 .705 .89 r
.42162 .5841 .42718 .58528 .4364 .58518 .43087 .58392 Metetra
.184 .698 .891 r
.43087 .58392 .4364 .58518 .44566 .58519 .44015 .58385 Metetra
.178 .692 .892 r
.44015 .58385 .44566 .58519 .45496 .5853 .44948 .58388 Metetra
.172 .687 .893 r
.44948 .58388 .45496 .5853 .46431 .58551 .45886 .58401 Metetra
.168 .682 .895 r
.45886 .58401 .46431 .58551 .47371 .58581 .46829 .58424 Metetra
.165 .677 .896 r
.46829 .58424 .47371 .58581 .48315 .5862 .47776 .58455 Metetra
.162 .673 .898 r
.47776 .58455 .48315 .5862 .49265 .58667 .48728 .58495 Metetra
.159 .669 .9 r
.48728 .58495 .49265 .58667 .5022 .58723 .49686 .58543 Metetra
.158 .666 .902 r
.49686 .58543 .5022 .58723 .5118 .58785 .50649 .58598 Metetra
.157 .663 .904 r
.50649 .58598 .5118 .58785 .52145 .58855 .51617 .58661 Metetra
.156 .66 .907 r
.51617 .58661 .52145 .58855 .53116 .58932 .5259 .5873 Metetra
.156 .658 .909 r
.5259 .5873 .53116 .58932 .54093 .59015 .53569 .58806 Metetra
.156 .655 .911 r
.53569 .58806 .54093 .59015 .55075 .59104 .54554 .58889 Metetra
.156 .653 .913 r
.54554 .58889 .55075 .59104 .56063 .59199 .55545 .58977 Metetra
.157 .651 .915 r
.55545 .58977 .56063 .59199 .57056 .593 .56541 .59072 Metetra
.157 .65 .917 r
.56541 .59072 .57056 .593 .58056 .59406 .57543 .59171 Metetra
.587 .874 .994 r
.57543 .59171 .58056 .59406 .59054 .59114 .58544 .58878 Metetra
.793 .914 .922 r
.58544 .58878 .59054 .59114 .60046 .58424 .59541 .58191 Metetra
.791 .917 .924 r
.59541 .58191 .60046 .58424 .6104 .57737 .60539 .57507 Metetra
.789 .919 .925 r
.60539 .57507 .6104 .57737 .62036 .57055 .61538 .56828 Metetra
.787 .922 .927 r
.61538 .56828 .62036 .57055 .63033 .56377 .62539 .56154 Metetra
.784 .924 .929 r
.62539 .56154 .63033 .56377 .64031 .55704 .63542 .55484 Metetra
.781 .927 .931 r
.63542 .55484 .64031 .55704 .65031 .55036 .64546 .5482 Metetra
.778 .929 .933 r
.64546 .5482 .65031 .55036 .66033 .54373 .65552 .54161 Metetra
.774 .932 .935 r
.65552 .54161 .66033 .54373 .67036 .53716 .6656 .53509 Metetra
.77 .935 .937 r
.6656 .53509 .67036 .53716 .68042 .53066 .6757 .52863 Metetra
.766 .937 .939 r
.6757 .52863 .68042 .53066 .69049 .52422 .68582 .52224 Metetra
.761 .939 .941 r
.68582 .52224 .69049 .52422 .70058 .51786 .69596 .51592 Metetra
.756 .942 .943 r
.69596 .51592 .70058 .51786 .7107 .51157 .70612 .50968 Metetra
.75 .944 .945 r
.70612 .50968 .7107 .51157 .72084 .50537 .7163 .50352 Metetra
.744 .946 .947 r
.7163 .50352 .72084 .50537 .731 .49925 .72651 .49745 Metetra
.737 .947 .949 r
.72651 .49745 .731 .49925 .74119 .49323 .73674 .49147 Metetra
.729 .949 .95 r
.73674 .49147 .74119 .49323 .7514 .4873 .747 .4856 Metetra
.72 .95 .952 r
.747 .4856 .7514 .4873 .76164 .48149 .7573 .47983 Metetra
.711 .951 .953 r
.7573 .47983 .76164 .48149 .77192 .47578 .76762 .47417 Metetra
.701 .951 .955 r
.76762 .47417 .77192 .47578 .78222 .4702 .77797 .46863 Metetra
.689 .95 .956 r
.77797 .46863 .78222 .4702 .79256 .46474 .78836 .46322 Metetra
.677 .949 .956 r
.78836 .46322 .79256 .46474 .80293 .45942 .79878 .45794 Metetra
.664 .948 .957 r
.79878 .45794 .80293 .45942 .81335 .45423 .80925 .4528 Metetra
.651 .945 .957 r
.80925 .4528 .81335 .45423 .8238 .44919 .81975 .4478 Metetra
.636 .942 .957 r
.81975 .4478 .8238 .44919 .83429 .44431 .83029 .44295 Metetra
.62 .939 .957 r
.83029 .44295 .83429 .44431 .84483 .43959 .84089 .43825 Metetra
.604 .934 .956 r
.84089 .43825 .84483 .43959 .85542 .43504 .85153 .43372 Metetra
.587 .929 .955 r
.85153 .43372 .85542 .43504 .86606 .43066 .86221 .42936 Metetra
.57 .923 .954 r
.86221 .42936 .86606 .43066 .87675 .42645 .87296 .42517 Metetra
.552 .916 .953 r
.87296 .42517 .87675 .42645 .8875 .42243 .88375 .42116 Metetra
.535 .909 .952 r
.88375 .42116 .8875 .42243 .8983 .4186 .89461 .41732 Metetra
.479 .883 .946 r
.27232 .60567 .27841 .60597 .28717 .60337 .28111 .60306 Metetra
.454 .872 .941 r
.28111 .60306 .28717 .60337 .29595 .60095 .28992 .60062 Metetra
.43 .86 .936 r
.28992 .60062 .29595 .60095 .30474 .59871 .29875 .59834 Metetra
.407 .848 .93 r
.29875 .59834 .30474 .59871 .31356 .59664 .3076 .59624 Metetra
.384 .835 .925 r
.3076 .59624 .31356 .59664 .3224 .59475 .31647 .59431 Metetra
.361 .823 .919 r
.31647 .59431 .3224 .59475 .33127 .59302 .32536 .59254 Metetra
.34 .81 .914 r
.32536 .59254 .33127 .59302 .34016 .59146 .33428 .59093 Metetra
.32 .798 .909 r
.33428 .59093 .34016 .59146 .34908 .59006 .34323 .58947 Metetra
.301 .785 .905 r
.34323 .58947 .34908 .59006 .35803 .58882 .35221 .58817 Metetra
.283 .774 .901 r
.35221 .58817 .35803 .58882 .367 .58774 .36122 .58702 Metetra
.267 .763 .898 r
.36122 .58702 .367 .58774 .37602 .58679 .37026 .58601 Metetra
.252 .752 .895 r
.37026 .58601 .37602 .58679 .38506 .586 .37934 .58514 Metetra
.238 .742 .893 r
.37934 .58514 .38506 .586 .39414 .58533 .38845 .58441 Metetra
.226 .733 .892 r
.38845 .58441 .39414 .58533 .40326 .5848 .3976 .5838 Metetra
.215 .724 .891 r
.3976 .5838 .40326 .5848 .41242 .58439 .40679 .58332 Metetra
.205 .717 .89 r
.40679 .58332 .41242 .58439 .42162 .5841 .41601 .58295 Metetra
.196 .709 .89 r
.41601 .58295 .42162 .5841 .43087 .58392 .42529 .5827 Metetra
.189 .702 .89 r
.42529 .5827 .43087 .58392 .44015 .58385 .4346 .58255 Metetra
.182 .696 .891 r
.4346 .58255 .44015 .58385 .44948 .58388 .44396 .58251 Metetra
.176 .691 .892 r
.44396 .58251 .44948 .58388 .45886 .58401 .45337 .58256 Metetra
.172 .686 .893 r
.45337 .58256 .45886 .58401 .46829 .58424 .46282 .58271 Metetra
.167 .681 .895 r
.46282 .58271 .46829 .58424 .47776 .58455 .47232 .58295 Metetra
.164 .677 .897 r
.47232 .58295 .47776 .58455 .48728 .58495 .48187 .58327 Metetra
.161 .673 .898 r
.48187 .58327 .48728 .58495 .49686 .58543 .49147 .58368 Metetra
.159 .669 .9 r
.49147 .58368 .49686 .58543 .50649 .58598 .50113 .58416 Metetra
.158 .666 .902 r
.50113 .58416 .50649 .58598 .51617 .58661 .51084 .58472 Metetra
.157 .663 .904 r
.51084 .58472 .51617 .58661 .5259 .5873 .5206 .58534 Metetra
.156 .66 .906 r
.5206 .58534 .5259 .5873 .53569 .58806 .53042 .58604 Metetra
.156 .658 .909 r
.53042 .58604 .53569 .58806 .54554 .58889 .54029 .58679 Metetra
.156 .656 .911 r
.54029 .58679 .54554 .58889 .55545 .58977 .55022 .58761 Metetra
.156 .654 .913 r
.55022 .58761 .55545 .58977 .56541 .59072 .56021 .58849 Metetra
.156 .652 .915 r
.56021 .58849 .56541 .59072 .57543 .59171 .57026 .58943 Metetra
.584 .876 .994 r
.57026 .58943 .57543 .59171 .58544 .58878 .5803 .58648 Metetra
.791 .917 .924 r
.5803 .58648 .58544 .58878 .59541 .58191 .59031 .57963 Metetra
.788 .92 .926 r
.59031 .57963 .59541 .58191 .60539 .57507 .60033 .57283 Metetra
.786 .922 .928 r
.60033 .57283 .60539 .57507 .61538 .56828 .61037 .56607 Metetra
.784 .925 .929 r
.61037 .56607 .61538 .56828 .62539 .56154 .62042 .55936 Metetra
.781 .927 .931 r
.62042 .55936 .62539 .56154 .63542 .55484 .63049 .5527 Metetra
.778 .93 .933 r
.63049 .5527 .63542 .55484 .64546 .5482 .64057 .5461 Metetra
.774 .932 .935 r
.64057 .5461 .64546 .5482 .65552 .54161 .65068 .53955 Metetra
.771 .935 .937 r
.65068 .53955 .65552 .54161 .6656 .53509 .6608 .53306 Metetra
.767 .937 .939 r
.6608 .53306 .6656 .53509 .6757 .52863 .67094 .52664 Metetra
.762 .939 .941 r
.67094 .52664 .6757 .52863 .68582 .52224 .6811 .52029 Metetra
.757 .941 .943 r
.6811 .52029 .68582 .52224 .69596 .51592 .69129 .51402 Metetra
.751 .944 .945 r
.69129 .51402 .69596 .51592 .70612 .50968 .70149 .50782 Metetra
.745 .945 .947 r
.70149 .50782 .70612 .50968 .7163 .50352 .71172 .50171 Metetra
.739 .947 .948 r
.71172 .50171 .7163 .50352 .72651 .49745 .72198 .49568 Metetra
.731 .949 .95 r
.72198 .49568 .72651 .49745 .73674 .49147 .73226 .48976 Metetra
.723 .95 .951 r
.73226 .48976 .73674 .49147 .747 .4856 .74257 .48393 Metetra
.715 .95 .953 r
.74257 .48393 .747 .4856 .7573 .47983 .75291 .4782 Metetra
.705 .951 .954 r
.75291 .4782 .7573 .47983 .76762 .47417 .76328 .47259 Metetra
.695 .951 .955 r
.76328 .47259 .76762 .47417 .77797 .46863 .77368 .46709 Metetra
.684 .95 .956 r
.77368 .46709 .77797 .46863 .78836 .46322 .78412 .46172 Metetra
.672 .949 .957 r
.78412 .46172 .78836 .46322 .79878 .45794 .7946 .45648 Metetra
.659 .947 .957 r
.7946 .45648 .79878 .45794 .80925 .4528 .80511 .45137 Metetra
.645 .944 .957 r
.80511 .45137 .80925 .4528 .81975 .4478 .81566 .4464 Metetra
.631 .941 .957 r
.81566 .4464 .81975 .4478 .83029 .44295 .82626 .44159 Metetra
.616 .937 .956 r
.82626 .44159 .83029 .44295 .84089 .43825 .8369 .43692 Metetra
.6 .933 .956 r
.8369 .43692 .84089 .43825 .85153 .43372 .84759 .43241 Metetra
.584 .928 .955 r
.84759 .43241 .85153 .43372 .86221 .42936 .85833 .42806 Metetra
.567 .922 .954 r
.85833 .42806 .86221 .42936 .87296 .42517 .86912 .42388 Metetra
.55 .915 .953 r
.86912 .42388 .87296 .42517 .88375 .42116 .87997 .41987 Metetra
.533 .908 .952 r
.87997 .41987 .88375 .42116 .89461 .41732 .89087 .41603 Metetra
.479 .884 .947 r
.26618 .60537 .27232 .60567 .28111 .60306 .275 .60274 Metetra
.456 .873 .942 r
.275 .60274 .28111 .60306 .28992 .60062 .28384 .60028 Metetra
.433 .861 .936 r
.28384 .60028 .28992 .60062 .29875 .59834 .2927 .59798 Metetra
.41 .85 .931 r
.2927 .59798 .29875 .59834 .3076 .59624 .30158 .59584 Metetra
.387 .837 .926 r
.30158 .59584 .3076 .59624 .31647 .59431 .31048 .59387 Metetra
.366 .825 .92 r
.31048 .59387 .31647 .59431 .32536 .59254 .3194 .59205 Metetra
.345 .813 .915 r
.3194 .59205 .32536 .59254 .33428 .59093 .32835 .5904 Metetra
.325 .801 .911 r
.32835 .5904 .33428 .59093 .34323 .58947 .33733 .58889 Metetra
.307 .789 .906 r
.33733 .58889 .34323 .58947 .35221 .58817 .34634 .58753 Metetra
.289 .778 .903 r
.34634 .58753 .35221 .58817 .36122 .58702 .35538 .58632 Metetra
.273 .767 .899 r
.35538 .58632 .36122 .58702 .37026 .58601 .36445 .58525 Metetra
.258 .757 .896 r
.36445 .58525 .37026 .58601 .37934 .58514 .37356 .58432 Metetra
.244 .747 .894 r
.37356 .58432 .37934 .58514 .38845 .58441 .3827 .58351 Metetra
.232 .738 .892 r
.3827 .58351 .38845 .58441 .3976 .5838 .39188 .58283 Metetra
.22 .729 .891 r
.39188 .58283 .3976 .5838 .40679 .58332 .4011 .58228 Metetra
.21 .721 .89 r
.4011 .58228 .40679 .58332 .41601 .58295 .41035 .58184 Metetra
.201 .714 .89 r
.41035 .58184 .41601 .58295 .42529 .5827 .41965 .58151 Metetra
.193 .707 .89 r
.41965 .58151 .42529 .5827 .4346 .58255 .429 .58129 Metetra
.186 .7 .891 r
.429 .58129 .4346 .58255 .44396 .58251 .43839 .58118 Metetra
.18 .695 .891 r
.43839 .58118 .44396 .58251 .45337 .58256 .44782 .58116 Metetra
.175 .689 .892 r
.44782 .58116 .45337 .58256 .46282 .58271 .4573 .58123 Metetra
.171 .685 .894 r
.4573 .58123 .46282 .58271 .47232 .58295 .46683 .5814 Metetra
.167 .68 .895 r
.46683 .5814 .47232 .58295 .48187 .58327 .47641 .58165 Metetra
.164 .676 .897 r
.47641 .58165 .48187 .58327 .49147 .58368 .48604 .58198 Metetra
.161 .672 .899 r
.48604 .58198 .49147 .58368 .50113 .58416 .49572 .58239 Metetra
.159 .669 .9 r
.49572 .58239 .50113 .58416 .51084 .58472 .50546 .58288 Metetra
.158 .666 .902 r
.50546 .58288 .51084 .58472 .5206 .58534 .51525 .58343 Metetra
.157 .663 .904 r
.51525 .58343 .5206 .58534 .53042 .58604 .52509 .58406 Metetra
.156 .66 .906 r
.52509 .58406 .53042 .58604 .54029 .58679 .53499 .58475 Metetra
.156 .658 .908 r
.53499 .58475 .54029 .58679 .55022 .58761 .54495 .5855 Metetra
.156 .656 .91 r
.54495 .5855 .55022 .58761 .56021 .58849 .55497 .58632 Metetra
.156 .654 .912 r
.55497 .58632 .56021 .58849 .57026 .58943 .56504 .58719 Metetra
.58 .877 .993 r
.56504 .58719 .57026 .58943 .5803 .58648 .57512 .58422 Metetra
.788 .92 .926 r
.57512 .58422 .5803 .58648 .59031 .57963 .58517 .57741 Metetra
.786 .923 .928 r
.58517 .57741 .59031 .57963 .60033 .57283 .59523 .57064 Metetra
.783 .925 .93 r
.59523 .57064 .60033 .57283 .61037 .56607 .60531 .56391 Metetra
.781 .927 .931 r
.60531 .56391 .61037 .56607 .62042 .55936 .6154 .55723 Metetra
.778 .93 .933 r
.6154 .55723 .62042 .55936 .63049 .5527 .62551 .55061 Metetra
.774 .932 .935 r
.62551 .55061 .63049 .5527 .64057 .5461 .63564 .54404 Metetra
.771 .935 .937 r
.63564 .54404 .64057 .5461 .65068 .53955 .64579 .53753 Metetra
.767 .937 .939 r
.64579 .53753 .65068 .53955 .6608 .53306 .65596 .53108 Metetra
.763 .939 .941 r
.65596 .53108 .6608 .53306 .67094 .52664 .66614 .5247 Metetra
.758 .941 .943 r
.66614 .5247 .67094 .52664 .6811 .52029 .67635 .5184 Metetra
.753 .943 .944 r
.67635 .5184 .6811 .52029 .69129 .51402 .68658 .51216 Metetra
.747 .945 .946 r
.68658 .51216 .69129 .51402 .70149 .50782 .69683 .50601 Metetra
.74 .947 .948 r
.69683 .50601 .70149 .50782 .71172 .50171 .70711 .49994 Metetra
.734 .948 .949 r
.70711 .49994 .71172 .50171 .72198 .49568 .71741 .49396 Metetra
.726 .949 .951 r
.71741 .49396 .72198 .49568 .73226 .48976 .72774 .48807 Metetra
.718 .95 .952 r
.72774 .48807 .73226 .48976 .74257 .48393 .7381 .48228 Metetra
.709 .951 .954 r
.7381 .48228 .74257 .48393 .75291 .4782 .74849 .4766 Metetra
.7 .951 .955 r
.74849 .4766 .75291 .4782 .76328 .47259 .7589 .47103 Metetra
.689 .95 .956 r
.7589 .47103 .76328 .47259 .77368 .46709 .76936 .46557 Metetra
.678 .95 .956 r
.76936 .46557 .77368 .46709 .78412 .46172 .77985 .46024 Metetra
.666 .948 .957 r
.77985 .46024 .78412 .46172 .7946 .45648 .79037 .45503 Metetra
.653 .946 .957 r
.79037 .45503 .7946 .45648 .80511 .45137 .80093 .44996 Metetra
.64 .943 .957 r
.80093 .44996 .80511 .45137 .81566 .4464 .81154 .44502 Metetra
.626 .94 .957 r
.81154 .44502 .81566 .4464 .82626 .44159 .82218 .44023 Metetra
.611 .936 .956 r
.82218 .44023 .82626 .44159 .8369 .43692 .83288 .43558 Metetra
.596 .932 .955 r
.83288 .43558 .8369 .43692 .84759 .43241 .84362 .43109 Metetra
.58 .926 .955 r
.84362 .43109 .84759 .43241 .85833 .42806 .85441 .42676 Metetra
.564 .921 .954 r
.85441 .42676 .85833 .42806 .86912 .42388 .86525 .42258 Metetra
.548 .914 .953 r
.86525 .42258 .86912 .42388 .87997 .41987 .87615 .41857 Metetra
.531 .907 .951 r
.87615 .41857 .87997 .41987 .89087 .41603 .8871 .41473 Metetra
.479 .884 .947 r
.25999 .60506 .26618 .60537 .275 .60274 .26884 .60242 Metetra
.457 .873 .942 r
.26884 .60242 .275 .60274 .28384 .60028 .27771 .59994 Metetra
.435 .862 .937 r
.27771 .59994 .28384 .60028 .2927 .59798 .28659 .59761 Metetra
.413 .851 .932 r
.28659 .59761 .2927 .59798 .30158 .59584 .2955 .59544 Metetra
.391 .839 .926 r
.2955 .59544 .30158 .59584 .31048 .59387 .30443 .59343 Metetra
.37 .828 .921 r
.30443 .59343 .31048 .59387 .3194 .59205 .31339 .59158 Metetra
.35 .816 .917 r
.31339 .59158 .3194 .59205 .32835 .5904 .32237 .58987 Metetra
.33 .804 .912 r
.32237 .58987 .32835 .5904 .33733 .58889 .33138 .58832 Metetra
.312 .793 .908 r
.33138 .58832 .33733 .58889 .34634 .58753 .34042 .58691 Metetra
.295 .782 .904 r
.34042 .58691 .34634 .58753 .35538 .58632 .34949 .58564 Metetra
.279 .771 .901 r
.34949 .58564 .35538 .58632 .36445 .58525 .35859 .5845 Metetra
.264 .761 .898 r
.35859 .5845 .36445 .58525 .37356 .58432 .36773 .58351 Metetra
.25 .751 .895 r
.36773 .58351 .37356 .58432 .3827 .58351 .3769 .58264 Metetra
.238 .742 .893 r
.3769 .58264 .3827 .58351 .39188 .58283 .38611 .58189 Metetra
.226 .733 .892 r
.38611 .58189 .39188 .58283 .4011 .58228 .39535 .58127 Metetra
.216 .725 .891 r
.39535 .58127 .4011 .58228 .41035 .58184 .40464 .58076 Metetra
.207 .718 .89 r
.40464 .58076 .41035 .58184 .41965 .58151 .41397 .58036 Metetra
.198 .711 .89 r
.41397 .58036 .41965 .58151 .429 .58129 .42334 .58007 Metetra
.191 .705 .89 r
.42334 .58007 .429 .58129 .43839 .58118 .43276 .57988 Metetra
.185 .699 .891 r
.43276 .57988 .43839 .58118 .44782 .58116 .44222 .57979 Metetra
.179 .693 .892 r
.44222 .57979 .44782 .58116 .4573 .58123 .45173 .57979 Metetra
.174 .688 .893 r
.45173 .57979 .4573 .58123 .46683 .5814 .46129 .57989 Metetra
.17 .684 .894 r
.46129 .57989 .46683 .5814 .47641 .58165 .4709 .58007 Metetra
.166 .679 .895 r
.4709 .58007 .47641 .58165 .48604 .58198 .48056 .58033 Metetra
.163 .676 .897 r
.48056 .58033 .48604 .58198 .49572 .58239 .49027 .58067 Metetra
.161 .672 .899 r
.49027 .58067 .49572 .58239 .50546 .58288 .50003 .58108 Metetra
.159 .669 .901 r
.50003 .58108 .50546 .58288 .51525 .58343 .50985 .58157 Metetra
.158 .666 .902 r
.50985 .58157 .51525 .58343 .52509 .58406 .51972 .58213 Metetra
.157 .663 .904 r
.51972 .58213 .52509 .58406 .53499 .58475 .52965 .58276 Metetra
.156 .661 .906 r
.52965 .58276 .53499 .58475 .54495 .5855 .53964 .58345 Metetra
.156 .658 .908 r
.53964 .58345 .54495 .5855 .55497 .58632 .54968 .5842 Metetra
.155 .656 .91 r
.54968 .5842 .55497 .58632 .56504 .58719 .55978 .58501 Metetra
.577 .879 .993 r
.55978 .58501 .56504 .58719 .57512 .58422 .5699 .58202 Metetra
.786 .923 .928 r
.5699 .58202 .57512 .58422 .58517 .57741 .57999 .57524 Metetra
.783 .925 .93 r
.57999 .57524 .58517 .57741 .59523 .57064 .59009 .5685 Metetra
.78 .928 .932 r
.59009 .5685 .59523 .57064 .60531 .56391 .60021 .5618 Metetra
.778 .93 .933 r
.60021 .5618 .60531 .56391 .6154 .55723 .61035 .55516 Metetra
.774 .932 .935 r
.61035 .55516 .6154 .55723 .62551 .55061 .6205 .54857 Metetra
.771 .935 .937 r
.6205 .54857 .62551 .55061 .63564 .54404 .63067 .54203 Metetra
.767 .937 .939 r
.63067 .54203 .63564 .54404 .64579 .53753 .64086 .53556 Metetra
.763 .939 .94 r
.64086 .53556 .64579 .53753 .65596 .53108 .65107 .52915 Metetra
.759 .941 .942 r
.65107 .52915 .65596 .53108 .66614 .5247 .6613 .52281 Metetra
.754 .943 .944 r
.6613 .52281 .66614 .5247 .67635 .5184 .67156 .51654 Metetra
.748 .945 .946 r
.67156 .51654 .67635 .5184 .68658 .51216 .68183 .51034 Metetra
.742 .946 .947 r
.68183 .51034 .68658 .51216 .69683 .50601 .69213 .50423 Metetra
.736 .948 .949 r
.69213 .50423 .69683 .50601 .70711 .49994 .70245 .4982 Metetra
.729 .949 .95 r
.70245 .4982 .70711 .49994 .71741 .49396 .7128 .49226 Metetra
.721 .95 .952 r
.7128 .49226 .71741 .49396 .72774 .48807 .72318 .48641 Metetra
.713 .951 .953 r
.72318 .48641 .72774 .48807 .7381 .48228 .73359 .48066 Metetra
.704 .951 .954 r
.73359 .48066 .7381 .48228 .74849 .4766 .74402 .47502 Metetra
.694 .951 .955 r
.74402 .47502 .74849 .4766 .7589 .47103 .75449 .46949 Metetra
.684 .95 .956 r
.75449 .46949 .7589 .47103 .76936 .46557 .76499 .46407 Metetra
.673 .949 .956 r
.76499 .46407 .76936 .46557 .77985 .46024 .77553 .45877 Metetra
.661 .947 .957 r
.77553 .45877 .77985 .46024 .79037 .45503 .7861 .45359 Metetra
.648 .945 .957 r
.7861 .45359 .79037 .45503 .80093 .44996 .79672 .44855 Metetra
.635 .942 .957 r
.79672 .44855 .80093 .44996 .81154 .44502 .80737 .44364 Metetra
.621 .939 .956 r
.80737 .44364 .81154 .44502 .82218 .44023 .81807 .43887 Metetra
.607 .935 .956 r
.81807 .43887 .82218 .44023 .83288 .43558 .82882 .43424 Metetra
.592 .93 .955 r
.82882 .43424 .83288 .43558 .84362 .43109 .83961 .42977 Metetra
.577 .925 .954 r
.83961 .42977 .84362 .43109 .85441 .42676 .85045 .42544 Metetra
.561 .92 .953 r
.85045 .42544 .85441 .42676 .86525 .42258 .86134 .42128 Metetra
.545 .913 .952 r
.86134 .42128 .86525 .42258 .87615 .41857 .87229 .41727 Metetra
.53 .907 .951 r
.87229 .41727 .87615 .41857 .8871 .41473 .88329 .41342 Metetra
.48 .884 .947 r
.25374 .60476 .25999 .60506 .26884 .60242 .26262 .6021 Metetra
.458 .874 .942 r
.26262 .6021 .26884 .60242 .27771 .59994 .27152 .59959 Metetra
.437 .863 .937 r
.27152 .59959 .27771 .59994 .28659 .59761 .28043 .59724 Metetra
.415 .852 .932 r
.28043 .59724 .28659 .59761 .2955 .59544 .28937 .59505 Metetra
.394 .841 .927 r
.28937 .59505 .2955 .59544 .30443 .59343 .29833 .593 Metetra
.374 .83 .922 r
.29833 .593 .30443 .59343 .31339 .59158 .30732 .5911 Metetra
.354 .819 .918 r
.30732 .5911 .31339 .59158 .32237 .58987 .31633 .58935 Metetra
.335 .807 .913 r
.31633 .58935 .32237 .58987 .33138 .58832 .32537 .58775 Metetra
.318 .796 .909 r
.32537 .58775 .33138 .58832 .34042 .58691 .33444 .58629 Metetra
.301 .785 .905 r
.33444 .58629 .34042 .58691 .34949 .58564 .34354 .58496 Metetra
.285 .775 .902 r
.34354 .58496 .34949 .58564 .35859 .5845 .35267 .58377 Metetra
.27 .765 .899 r
.35267 .58377 .35859 .5845 .36773 .58351 .36184 .58271 Metetra
.256 .755 .896 r
.36184 .58271 .36773 .58351 .3769 .58264 .37104 .58178 Metetra
.243 .746 .894 r
.37104 .58178 .3769 .58264 .38611 .58189 .38028 .58097 Metetra
.232 .738 .893 r
.38028 .58097 .38611 .58189 .39535 .58127 .38956 .58028 Metetra
.221 .73 .891 r
.38956 .58028 .39535 .58127 .40464 .58076 .39888 .5797 Metetra
.212 .722 .891 r
.39888 .5797 .40464 .58076 .41397 .58036 .40824 .57924 Metetra
.203 .715 .89 r
.40824 .57924 .41397 .58036 .42334 .58007 .41764 .57888 Metetra
.196 .709 .89 r
.41764 .57888 .42334 .58007 .43276 .57988 .42709 .57862 Metetra
.189 .703 .891 r
.42709 .57862 .43276 .57988 .44222 .57979 .43658 .57846 Metetra
.183 .697 .891 r
.43658 .57846 .44222 .57979 .45173 .57979 .44612 .57839 Metetra
.178 .692 .892 r
.44612 .57839 .45173 .57979 .46129 .57989 .4557 .57841 Metetra
.173 .687 .893 r
.4557 .57841 .46129 .57989 .4709 .58007 .46534 .57852 Metetra
.169 .683 .894 r
.46534 .57852 .4709 .58007 .48056 .58033 .47503 .57872 Metetra
.166 .679 .896 r
.47503 .57872 .48056 .58033 .49027 .58067 .48477 .57899 Metetra
.163 .675 .897 r
.48477 .57899 .49027 .58067 .50003 .58108 .49456 .57934 Metetra
.161 .672 .899 r
.49456 .57934 .50003 .58108 .50985 .58157 .5044 .57976 Metetra
.159 .669 .901 r
.5044 .57976 .50985 .58157 .51972 .58213 .51431 .58025 Metetra
.158 .666 .902 r
.51431 .58025 .51972 .58213 .52965 .58276 .52426 .58081 Metetra
.157 .663 .904 r
.52426 .58081 .52965 .58276 .53964 .58345 .53428 .58144 Metetra
.156 .661 .906 r
.53428 .58144 .53964 .58345 .54968 .5842 .54435 .58213 Metetra
.156 .658 .908 r
.54435 .58213 .54968 .5842 .55978 .58501 .55448 .58287 Metetra
.573 .88 .992 r
.55448 .58287 .55978 .58501 .5699 .58202 .56463 .57987 Metetra
.783 .926 .93 r
.56463 .57987 .5699 .58202 .57999 .57524 .57476 .57311 Metetra
.78 .928 .932 r
.57476 .57311 .57999 .57524 .59009 .5685 .5849 .5664 Metetra
.778 .93 .933 r
.5849 .5664 .59009 .5685 .60021 .5618 .59506 .55974 Metetra
.774 .932 .935 r
.59506 .55974 .60021 .5618 .61035 .55516 .60524 .55313 Metetra
.771 .935 .937 r
.60524 .55313 .61035 .55516 .6205 .54857 .61544 .54657 Metetra
.768 .937 .939 r
.61544 .54657 .6205 .54857 .63067 .54203 .62566 .54007 Metetra
.764 .939 .94 r
.62566 .54007 .63067 .54203 .64086 .53556 .63589 .53363 Metetra
.759 .941 .942 r
.63589 .53363 .64086 .53556 .65107 .52915 .64615 .52726 Metetra
.754 .943 .944 r
.64615 .52726 .65107 .52915 .6613 .52281 .65642 .52095 Metetra
.749 .944 .945 r
.65642 .52095 .6613 .52281 .67156 .51654 .66672 .51472 Metetra
.744 .946 .947 r
.66672 .51472 .67156 .51654 .68183 .51034 .67704 .50856 Metetra
.738 .948 .948 r
.67704 .50856 .68183 .51034 .69213 .50423 .68739 .50248 Metetra
.731 .949 .95 r
.68739 .50248 .69213 .50423 .70245 .4982 .69776 .49649 Metetra
.724 .95 .951 r
.69776 .49649 .70245 .4982 .7128 .49226 .70815 .49059 Metetra
.716 .95 .953 r
.70815 .49059 .7128 .49226 .72318 .48641 .71858 .48478 Metetra
.708 .951 .954 r
.71858 .48478 .72318 .48641 .73359 .48066 .72903 .47907 Metetra
.699 .951 .955 r
.72903 .47907 .73359 .48066 .74402 .47502 .73952 .47346 Metetra
.689 .95 .955 r
.73952 .47346 .74402 .47502 .75449 .46949 .75004 .46796 Metetra
.679 .95 .956 r
.75004 .46796 .75449 .46949 .76499 .46407 .76059 .46258 Metetra
.668 .948 .957 r
.76059 .46258 .76499 .46407 .77553 .45877 .77118 .45731 Metetra
.656 .947 .957 r
.77118 .45731 .77553 .45877 .7861 .45359 .7818 .45216 Metetra
.644 .944 .957 r
.7818 .45216 .7861 .45359 .79672 .44855 .79246 .44714 Metetra
.631 .941 .957 r
.79246 .44714 .79672 .44855 .80737 .44364 .80317 .44226 Metetra
.617 .938 .956 r
.80317 .44226 .80737 .44364 .81807 .43887 .81392 .43751 Metetra
.603 .934 .956 r
.81392 .43751 .81807 .43887 .82882 .43424 .82471 .4329 Metetra
.589 .929 .955 r
.82471 .4329 .82882 .43424 .83961 .42977 .83556 .42844 Metetra
.574 .924 .954 r
.83556 .42844 .83961 .42977 .85045 .42544 .84645 .42412 Metetra
.559 .919 .953 r
.84645 .42412 .85045 .42544 .86134 .42128 .85739 .41996 Metetra
.544 .913 .952 r
.85739 .41996 .86134 .42128 .87229 .41727 .86839 .41595 Metetra
.528 .906 .951 r
.86839 .41595 .87229 .41727 .88329 .41342 .87944 .4121 Metetra
.48 .884 .947 r
.24743 .60445 .25374 .60476 .26262 .6021 .25634 .60177 Metetra
.459 .874 .942 r
.25634 .60177 .26262 .6021 .27152 .59959 .26527 .59925 Metetra
.438 .864 .938 r
.26527 .59925 .27152 .59959 .28043 .59724 .27422 .59687 Metetra
.418 .854 .933 r
.27422 .59687 .28043 .59724 .28937 .59505 .28318 .59465 Metetra
.397 .843 .928 r
.28318 .59465 .28937 .59505 .29833 .593 .29218 .59257 Metetra
.378 .832 .923 r
.29218 .59257 .29833 .593 .30732 .5911 .30119 .59063 Metetra
.359 .821 .919 r
.30119 .59063 .30732 .5911 .31633 .58935 .31024 .58884 Metetra
.34 .81 .914 r
.31024 .58884 .31633 .58935 .32537 .58775 .31931 .58719 Metetra
.323 .799 .91 r
.31931 .58719 .32537 .58775 .33444 .58629 .32841 .58568 Metetra
.306 .789 .906 r
.32841 .58568 .33444 .58629 .34354 .58496 .33754 .5843 Metetra
.29 .779 .903 r
.33754 .5843 .34354 .58496 .35267 .58377 .3467 .58306 Metetra
.275 .769 .9 r
.3467 .58306 .35267 .58377 .36184 .58271 .3559 .58194 Metetra
.262 .759 .897 r
.3559 .58194 .36184 .58271 .37104 .58178 .36513 .58094 Metetra
.249 .75 .895 r
.36513 .58094 .37104 .58178 .38028 .58097 .3744 .58007 Metetra
.237 .742 .893 r
.3744 .58007 .38028 .58097 .38956 .58028 .38371 .57932 Metetra
.227 .734 .892 r
.38371 .57932 .38956 .58028 .39888 .5797 .39306 .57868 Metetra
.217 .726 .891 r
.39306 .57868 .39888 .5797 .40824 .57924 .40245 .57814 Metetra
.208 .719 .891 r
.40245 .57814 .40824 .57924 .41764 .57888 .41188 .57771 Metetra
.2 .713 .89 r
.41188 .57771 .41764 .57888 .42709 .57862 .42136 .57739 Metetra
.193 .707 .89 r
.42136 .57739 .42709 .57862 .43658 .57846 .43088 .57716 Metetra
.187 .701 .891 r
.43088 .57716 .43658 .57846 .44612 .57839 .44045 .57702 Metetra
.181 .696 .891 r
.44045 .57702 .44612 .57839 .4557 .57841 .45007 .57698 Metetra
.176 .691 .892 r
.45007 .57698 .4557 .57841 .46534 .57852 .45973 .57702 Metetra
.172 .686 .893 r
.45973 .57702 .46534 .57852 .47503 .57872 .46945 .57715 Metetra
.169 .682 .895 r
.46945 .57715 .47503 .57872 .48477 .57899 .47922 .57735 Metetra
.166 .678 .896 r
.47922 .57735 .48477 .57899 .49456 .57934 .48904 .57763 Metetra
.163 .675 .897 r
.48904 .57763 .49456 .57934 .5044 .57976 .49891 .57799 Metetra
.161 .671 .899 r
.49891 .57799 .5044 .57976 .51431 .58025 .50884 .57842 Metetra
.159 .668 .901 r
.50884 .57842 .51431 .58025 .52426 .58081 .51883 .57891 Metetra
.158 .666 .902 r
.51883 .57891 .52426 .58081 .53428 .58144 .52887 .57947 Metetra
.157 .663 .904 r
.52887 .57947 .53428 .58144 .54435 .58213 .53897 .5801 Metetra
.156 .661 .906 r
.53897 .5801 .54435 .58213 .55448 .58287 .54913 .58078 Metetra
.57 .882 .992 r
.54913 .58078 .55448 .58287 .56463 .57987 .55931 .57777 Metetra
.78 .928 .932 r
.55931 .57777 .56463 .57987 .57476 .57311 .56948 .57104 Metetra
.777 .93 .933 r
.56948 .57104 .57476 .57311 .5849 .5664 .57967 .56435 Metetra
.775 .932 .935 r
.57967 .56435 .5849 .5664 .59506 .55974 .58988 .55772 Metetra
.771 .934 .937 r
.58988 .55772 .59506 .55974 .60524 .55313 .6001 .55114 Metetra
.768 .937 .938 r
.6001 .55114 .60524 .55313 .61544 .54657 .61034 .54461 Metetra
.764 .939 .94 r
.61034 .54461 .61544 .54657 .62566 .54007 .6206 .53814 Metetra
.76 .941 .942 r
.6206 .53814 .62566 .54007 .63589 .53363 .63088 .53174 Metetra
.755 .942 .943 r
.63088 .53174 .63589 .53363 .64615 .52726 .64118 .5254 Metetra
.75 .944 .945 r
.64118 .5254 .64615 .52726 .65642 .52095 .6515 .51913 Metetra
.745 .946 .946 r
.6515 .51913 .65642 .52095 .66672 .51472 .66184 .51293 Metetra
.739 .947 .948 r
.66184 .51293 .66672 .51472 .67704 .50856 .67221 .50681 Metetra
.733 .948 .949 r
.67221 .50681 .67704 .50856 .68739 .50248 .6826 .50077 Metetra
.726 .949 .951 r
.6826 .50077 .68739 .50248 .69776 .49649 .69302 .49481 Metetra
.719 .95 .952 r
.69302 .49481 .69776 .49649 .70815 .49059 .70346 .48894 Metetra
.711 .951 .953 r
.70346 .48894 .70815 .49059 .71858 .48478 .71394 .48317 Metetra
.703 .951 .954 r
.71394 .48317 .71858 .48478 .72903 .47907 .72444 .47749 Metetra
.694 .951 .955 r
.72444 .47749 .72903 .47907 .73952 .47346 .73497 .47192 Metetra
.684 .95 .956 r
.73497 .47192 .73952 .47346 .75004 .46796 .74554 .46645 Metetra
.674 .949 .956 r
.74554 .46645 .75004 .46796 .76059 .46258 .75614 .4611 Metetra
.663 .948 .957 r
.75614 .4611 .76059 .46258 .77118 .45731 .76678 .45586 Metetra
.651 .946 .957 r
.76678 .45586 .77118 .45731 .7818 .45216 .77745 .45074 Metetra
.639 .943 .957 r
.77745 .45074 .7818 .45216 .79246 .44714 .78817 .44575 Metetra
.626 .94 .957 r
.78817 .44575 .79246 .44714 .80317 .44226 .79893 .44088 Metetra
.613 .937 .956 r
.79893 .44088 .80317 .44226 .81392 .43751 .80973 .43615 Metetra
.6 .933 .956 r
.80973 .43615 .81392 .43751 .82471 .4329 .82057 .43156 Metetra
.585 .928 .955 r
.82057 .43156 .82471 .4329 .83556 .42844 .83146 .4271 Metetra
.571 .923 .954 r
.83146 .4271 .83556 .42844 .84645 .42412 .84241 .42279 Metetra
.556 .918 .953 r
.84241 .42279 .84645 .42412 .85739 .41996 .8534 .41863 Metetra
.542 .912 .952 r
.8534 .41863 .85739 .41996 .86839 .41595 .86445 .41462 Metetra
.527 .906 .951 r
.86445 .41462 .86839 .41595 .87944 .4121 .87556 .41076 Metetra
.481 .884 .947 r
.24107 .60414 .24743 .60445 .25634 .60177 .25001 .60145 Metetra
.46 .875 .943 r
.25001 .60145 .25634 .60177 .26527 .59925 .25896 .5989 Metetra
.44 .865 .938 r
.25896 .5989 .26527 .59925 .27422 .59687 .26794 .5965 Metetra
.42 .855 .933 r
.26794 .5965 .27422 .59687 .28318 .59465 .27694 .59425 Metetra
.4 .845 .929 r
.27694 .59425 .28318 .59465 .29218 .59257 .28596 .59213 Metetra
.381 .834 .924 r
.28596 .59213 .29218 .59257 .30119 .59063 .29501 .59016 Metetra
.363 .823 .92 r
.29501 .59016 .30119 .59063 .31024 .58884 .30409 .58833 Metetra
.345 .813 .915 r
.30409 .58833 .31024 .58884 .31931 .58719 .31319 .58664 Metetra
.327 .802 .911 r
.31319 .58664 .31931 .58719 .32841 .58568 .32232 .58508 Metetra
.311 .792 .908 r
.32232 .58508 .32841 .58568 .33754 .5843 .33148 .58365 Metetra
.295 .782 .904 r
.33148 .58365 .33754 .5843 .3467 .58306 .34068 .58235 Metetra
.281 .772 .901 r
.34068 .58235 .3467 .58306 .3559 .58194 .3499 .58117 Metetra
.267 .763 .898 r
.3499 .58117 .3559 .58194 .36513 .58094 .35917 .58012 Metetra
.255 .754 .896 r
.35917 .58012 .36513 .58094 .3744 .58007 .36847 .57919 Metetra
.243 .746 .894 r
.36847 .57919 .3744 .58007 .38371 .57932 .37781 .57837 Metetra
.232 .738 .893 r
.37781 .57837 .38371 .57932 .39306 .57868 .38719 .57767 Metetra
.222 .73 .892 r
.38719 .57767 .39306 .57868 .40245 .57814 .39661 .57707 Metetra
.213 .723 .891 r
.39661 .57707 .40245 .57814 .41188 .57771 .40607 .57658 Metetra
.205 .717 .89 r
.40607 .57658 .41188 .57771 .42136 .57739 .41558 .57619 Metetra
.198 .71 .89 r
.41558 .57619 .42136 .57739 .43088 .57716 .42513 .57589 Metetra
.191 .705 .891 r
.42513 .57589 .43088 .57716 .44045 .57702 .43473 .57569 Metetra
.185 .699 .891 r
.43473 .57569 .44045 .57702 .45007 .57698 .44437 .57558 Metetra
.18 .694 .892 r
.44437 .57558 .45007 .57698 .45973 .57702 .45407 .57555 Metetra
.175 .69 .893 r
.45407 .57555 .45973 .57702 .46945 .57715 .46382 .57561 Metetra
.171 .685 .894 r
.46382 .57561 .46945 .57715 .47922 .57735 .47361 .57575 Metetra
.168 .681 .895 r
.47361 .57575 .47922 .57735 .48904 .57763 .48346 .57597 Metetra
.165 .678 .896 r
.48346 .57597 .48904 .57763 .49891 .57799 .49337 .57626 Metetra
.163 .674 .898 r
.49337 .57626 .49891 .57799 .50884 .57842 .50333 .57662 Metetra
.161 .671 .899 r
.50333 .57662 .50884 .57842 .51883 .57891 .51334 .57705 Metetra
.159 .668 .901 r
.51334 .57705 .51883 .57891 .52887 .57947 .52341 .57755 Metetra
.158 .666 .902 r
.52341 .57755 .52887 .57947 .53897 .5801 .53354 .57812 Metetra
.157 .663 .904 r
.53354 .57812 .53897 .5801 .54913 .58078 .54373 .57874 Metetra
.566 .883 .991 r
.54373 .57874 .54913 .58078 .55931 .57777 .55395 .57571 Metetra
.777 .93 .933 r
.55395 .57571 .55931 .57777 .56948 .57104 .56416 .569 Metetra
.775 .932 .935 r
.56416 .569 .56948 .57104 .57967 .56435 .57439 .56235 Metetra
.771 .934 .937 r
.57439 .56235 .57967 .56435 .58988 .55772 .58464 .55574 Metetra
.768 .936 .938 r
.58464 .55574 .58988 .55772 .6001 .55114 .59491 .54919 Metetra
.764 .938 .94 r
.59491 .54919 .6001 .55114 .61034 .54461 .60519 .54269 Metetra
.76 .94 .941 r
.60519 .54269 .61034 .54461 .6206 .53814 .61549 .53626 Metetra
.756 .942 .943 r
.61549 .53626 .6206 .53814 .63088 .53174 .62582 .52988 Metetra
.751 .944 .945 r
.62582 .52988 .63088 .53174 .64118 .5254 .63616 .52358 Metetra
.746 .945 .946 r
.63616 .52358 .64118 .5254 .6515 .51913 .64653 .51734 Metetra
.741 .947 .948 r
.64653 .51734 .6515 .51913 .66184 .51293 .65692 .51117 Metetra
.735 .948 .949 r
.65692 .51117 .66184 .51293 .67221 .50681 .66733 .50509 Metetra
.729 .949 .95 r
.66733 .50509 .67221 .50681 .6826 .50077 .67777 .49908 Metetra
.722 .95 .952 r
.67777 .49908 .6826 .50077 .69302 .49481 .68824 .49316 Metetra
.714 .951 .953 r
.68824 .49316 .69302 .49481 .70346 .48894 .69873 .48732 Metetra
.706 .951 .954 r
.69873 .48732 .70346 .48894 .71394 .48317 .70925 .48158 Metetra
.698 .951 .955 r
.70925 .48158 .71394 .48317 .72444 .47749 .7198 .47594 Metetra
.689 .951 .955 r
.7198 .47594 .72444 .47749 .73497 .47192 .73039 .47039 Metetra
.679 .95 .956 r
.73039 .47039 .73497 .47192 .74554 .46645 .741 .46496 Metetra
.669 .949 .956 r
.741 .46496 .74554 .46645 .75614 .4611 .75165 .45963 Metetra
.658 .947 .957 r
.75165 .45963 .75614 .4611 .76678 .45586 .76234 .45442 Metetra
.647 .945 .957 r
.76234 .45442 .76678 .45586 .77745 .45074 .77307 .44932 Metetra
.635 .942 .957 r
.77307 .44932 .77745 .45074 .78817 .44575 .78383 .44435 Metetra
.622 .939 .956 r
.78383 .44435 .78817 .44575 .79893 .44088 .79464 .4395 Metetra
.609 .936 .956 r
.79464 .4395 .79893 .44088 .80973 .43615 .80549 .43479 Metetra
.596 .932 .955 r
.80549 .43479 .80973 .43615 .82057 .43156 .81639 .43021 Metetra
.582 .927 .955 r
.81639 .43021 .82057 .43156 .83146 .4271 .82733 .42576 Metetra
.568 .922 .954 r
.82733 .42576 .83146 .4271 .84241 .42279 .83833 .42146 Metetra
.554 .917 .953 r
.83833 .42146 .84241 .42279 .8534 .41863 .84937 .41729 Metetra
.54 .911 .952 r
.84937 .41729 .8534 .41863 .86445 .41462 .86047 .41328 Metetra
.526 .905 .951 r
.86047 .41328 .86445 .41462 .87556 .41076 .87163 .40941 Metetra
.481 .884 .947 r
.23465 .60382 .24107 .60414 .25001 .60145 .24361 .60112 Metetra
.461 .875 .943 r
.24361 .60112 .25001 .60145 .25896 .5989 .2526 .59855 Metetra
.442 .866 .938 r
.2526 .59855 .25896 .5989 .26794 .5965 .26161 .59613 Metetra
.422 .856 .934 r
.26161 .59613 .26794 .5965 .27694 .59425 .27064 .59385 Metetra
.403 .846 .929 r
.27064 .59385 .27694 .59425 .28596 .59213 .27969 .5917 Metetra
.385 .836 .925 r
.27969 .5917 .28596 .59213 .29501 .59016 .28877 .58969 Metetra
.366 .826 .921 r
.28877 .58969 .29501 .59016 .30409 .58833 .29788 .58782 Metetra
.349 .815 .916 r
.29788 .58782 .30409 .58833 .31319 .58664 .30701 .58608 Metetra
.332 .805 .912 r
.30701 .58608 .31319 .58664 .32232 .58508 .31617 .58448 Metetra
.316 .795 .909 r
.31617 .58448 .32232 .58508 .33148 .58365 .32537 .583 Metetra
.301 .785 .905 r
.32537 .583 .33148 .58365 .34068 .58235 .33459 .58165 Metetra
.286 .776 .902 r
.33459 .58165 .34068 .58235 .3499 .58117 .34385 .58042 Metetra
.273 .767 .899 r
.34385 .58042 .3499 .58117 .35917 .58012 .35315 .57932 Metetra
.26 .758 .897 r
.35315 .57932 .35917 .58012 .36847 .57919 .36248 .57833 Metetra
.248 .75 .895 r
.36248 .57833 .36847 .57919 .37781 .57837 .37185 .57745 Metetra
.237 .742 .893 r
.37185 .57745 .37781 .57837 .38719 .57767 .38126 .57668 Metetra
.227 .734 .892 r
.38126 .57668 .38719 .57767 .39661 .57707 .39071 .57602 Metetra
.218 .727 .891 r
.39071 .57602 .39661 .57707 .40607 .57658 .40021 .57547 Metetra
.21 .72 .891 r
.40021 .57547 .40607 .57658 .41558 .57619 .40974 .57501 Metetra
.202 .714 .89 r
.40974 .57501 .41558 .57619 .42513 .57589 .41933 .57465 Metetra
.195 .708 .89 r
.41933 .57465 .42513 .57589 .43473 .57569 .42895 .57438 Metetra
.189 .703 .891 r
.42895 .57438 .43473 .57569 .44437 .57558 .43863 .57421 Metetra
.184 .698 .891 r
.43863 .57421 .44437 .57558 .45407 .57555 .44836 .57412 Metetra
.179 .693 .892 r
.44836 .57412 .45407 .57555 .46382 .57561 .45813 .57411 Metetra
.174 .689 .893 r
.45813 .57411 .46382 .57561 .47361 .57575 .46796 .57419 Metetra
.171 .685 .894 r
.46796 .57419 .47361 .57575 .48346 .57597 .47784 .57434 Metetra
.168 .681 .895 r
.47784 .57434 .48346 .57597 .49337 .57626 .48777 .57457 Metetra
.165 .677 .896 r
.48777 .57457 .49337 .57626 .50333 .57662 .49776 .57487 Metetra
.162 .674 .898 r
.49776 .57487 .50333 .57662 .51334 .57705 .50781 .57524 Metetra
.16 .671 .899 r
.50781 .57524 .51334 .57705 .52341 .57755 .51791 .57567 Metetra
.159 .668 .901 r
.51791 .57567 .52341 .57755 .53354 .57812 .52807 .57617 Metetra
.158 .666 .903 r
.52807 .57617 .53354 .57812 .54373 .57874 .53829 .57674 Metetra
.563 .884 .99 r
.53829 .57674 .54373 .57874 .55395 .57571 .54854 .57369 Metetra
.775 .932 .935 r
.54854 .57369 .55395 .57571 .56416 .569 .5588 .56701 Metetra
.772 .934 .937 r
.5588 .56701 .56416 .569 .57439 .56235 .56907 .56038 Metetra
.768 .936 .938 r
.56907 .56038 .57439 .56235 .58464 .55574 .57936 .5538 Metetra
.765 .938 .94 r
.57936 .5538 .58464 .55574 .59491 .54919 .58967 .54728 Metetra
.761 .94 .941 r
.58967 .54728 .59491 .54919 .60519 .54269 .6 .54081 Metetra
.757 .942 .943 r
.6 .54081 .60519 .54269 .61549 .53626 .61034 .5344 Metetra
.752 .944 .944 r
.61034 .5344 .61549 .53626 .62582 .52988 .62071 .52806 Metetra
.748 .945 .946 r
.62071 .52806 .62582 .52988 .63616 .52358 .6311 .52179 Metetra
.742 .947 .947 r
.6311 .52179 .63616 .52358 .64653 .51734 .64152 .51558 Metetra
.737 .948 .949 r
.64152 .51558 .64653 .51734 .65692 .51117 .65195 .50945 Metetra
.731 .949 .95 r
.65195 .50945 .65692 .51117 .66733 .50509 .66241 .50339 Metetra
.724 .95 .951 r
.66241 .50339 .66733 .50509 .67777 .49908 .6729 .49741 Metetra
.717 .951 .952 r
.6729 .49741 .67777 .49908 .68824 .49316 .68341 .49152 Metetra
.71 .951 .953 r
.68341 .49152 .68824 .49316 .69873 .48732 .69395 .48572 Metetra
.702 .951 .954 r
.69395 .48572 .69873 .48732 .70925 .48158 .70452 .48001 Metetra
.693 .951 .955 r
.70452 .48001 .70925 .48158 .7198 .47594 .71512 .47439 Metetra
.684 .95 .956 r
.71512 .47439 .7198 .47594 .73039 .47039 .72576 .46888 Metetra
.675 .949 .956 r
.72576 .46888 .73039 .47039 .741 .46496 .73642 .46347 Metetra
.664 .948 .957 r
.73642 .46347 .741 .46496 .75165 .45963 .74712 .45817 Metetra
.654 .946 .957 r
.74712 .45817 .75165 .45963 .76234 .45442 .75786 .45298 Metetra
.642 .944 .957 r
.75786 .45298 .76234 .45442 .77307 .44932 .76864 .44791 Metetra
.631 .941 .957 r
.76864 .44791 .77307 .44932 .78383 .44435 .77946 .44295 Metetra
.618 .938 .956 r
.77946 .44295 .78383 .44435 .79464 .4395 .79031 .43812 Metetra
.606 .935 .956 r
.79031 .43812 .79464 .4395 .80549 .43479 .80122 .43342 Metetra
.593 .931 .955 r
.80122 .43342 .80549 .43479 .81639 .43021 .81217 .42885 Metetra
.58 .926 .954 r
.81217 .42885 .81639 .43021 .82733 .42576 .82316 .42441 Metetra
.566 .921 .954 r
.82316 .42441 .82733 .42576 .83833 .42146 .83421 .42011 Metetra
.552 .916 .953 r
.83421 .42011 .83833 .42146 .84937 .41729 .8453 .41595 Metetra
.538 .911 .952 r
.8453 .41595 .84937 .41729 .86047 .41328 .85646 .41192 Metetra
.525 .905 .951 r
.85646 .41192 .86047 .41328 .87163 .40941 .86766 .40804 Metetra
.648 .755 .927 r
.22858 .59868 .23465 .60382 .24361 .60112 .23757 .59596 Metetra
.641 .753 .93 r
.23757 .59596 .24361 .60112 .2526 .59855 .24657 .59338 Metetra
.634 .751 .933 r
.24657 .59338 .2526 .59855 .26161 .59613 .2556 .59094 Metetra
.626 .749 .935 r
.2556 .59094 .26161 .59613 .27064 .59385 .26465 .58864 Metetra
.618 .747 .938 r
.26465 .58864 .27064 .59385 .27969 .5917 .27372 .58647 Metetra
.61 .745 .94 r
.27372 .58647 .27969 .5917 .28877 .58969 .28282 .58445 Metetra
.602 .742 .943 r
.28282 .58445 .28877 .58969 .29788 .58782 .29194 .58256 Metetra
.594 .739 .945 r
.29194 .58256 .29788 .58782 .30701 .58608 .30109 .58081 Metetra
.586 .737 .947 r
.30109 .58081 .30701 .58608 .31617 .58448 .31027 .57919 Metetra
.578 .734 .949 r
.31027 .57919 .31617 .58448 .32537 .583 .31948 .57769 Metetra
.57 .731 .951 r
.31948 .57769 .32537 .583 .33459 .58165 .32872 .57633 Metetra
.561 .728 .953 r
.32872 .57633 .33459 .58165 .34385 .58042 .338 .57508 Metetra
.553 .725 .954 r
.338 .57508 .34385 .58042 .35315 .57932 .34731 .57396 Metetra
.545 .722 .956 r
.34731 .57396 .35315 .57932 .36248 .57833 .35666 .57295 Metetra
.537 .719 .957 r
.35666 .57295 .36248 .57833 .37185 .57745 .36605 .57206 Metetra
.53 .716 .958 r
.36605 .57206 .37185 .57745 .38126 .57668 .37547 .57128 Metetra
.522 .713 .959 r
.37547 .57128 .38126 .57668 .39071 .57602 .38494 .5706 Metetra
.514 .71 .96 r
.38494 .5706 .39071 .57602 .40021 .57547 .39445 .57003 Metetra
.507 .707 .961 r
.39445 .57003 .40021 .57547 .40974 .57501 .40401 .56956 Metetra
.5 .704 .961 r
.40401 .56956 .40974 .57501 .41933 .57465 .41361 .56919 Metetra
.493 .701 .962 r
.41361 .56919 .41933 .57465 .42895 .57438 .42325 .5689 Metetra
.486 .698 .962 r
.42325 .5689 .42895 .57438 .43863 .57421 .43295 .56871 Metetra
.48 .695 .963 r
.43295 .56871 .43863 .57421 .44836 .57412 .44269 .56861 Metetra
.473 .692 .963 r
.44269 .56861 .44836 .57412 .45813 .57411 .45248 .56859 Metetra
.467 .689 .963 r
.45248 .56859 .45813 .57411 .46796 .57419 .46233 .56865 Metetra
.461 .687 .963 r
.46233 .56865 .46796 .57419 .47784 .57434 .47223 .56878 Metetra
.456 .684 .963 r
.47223 .56878 .47784 .57434 .48777 .57457 .48218 .569 Metetra
.45 .681 .964 r
.48218 .569 .48777 .57457 .49776 .57487 .49218 .56928 Metetra
.445 .679 .964 r
.49218 .56928 .49776 .57487 .50781 .57524 .50225 .56964 Metetra
.44 .676 .964 r
.50225 .56964 .50781 .57524 .51791 .57567 .51237 .57006 Metetra
.435 .674 .964 r
.51237 .57006 .51791 .57567 .52807 .57617 .52255 .57054 Metetra
.431 .672 .963 r
.52255 .57054 .52807 .57617 .53829 .57674 .53278 .57109 Metetra
.646 .762 .934 r
.53278 .57109 .53829 .57674 .54854 .57369 .54306 .56802 Metetra
.766 .793 .875 r
.54306 .56802 .54854 .57369 .5588 .56701 .55335 .56132 Metetra
.764 .793 .876 r
.55335 .56132 .5588 .56701 .56907 .56038 .56365 .55466 Metetra
.763 .793 .877 r
.56365 .55466 .56907 .56038 .57936 .5538 .57397 .54805 Metetra
.761 .792 .879 r
.57397 .54805 .57936 .5538 .58967 .54728 .58431 .5415 Metetra
.759 .792 .88 r
.58431 .5415 .58967 .54728 .6 .54081 .59467 .53501 Metetra
.757 .792 .881 r
.59467 .53501 .6 .54081 .61034 .5344 .60505 .52858 Metetra
.755 .791 .882 r
.60505 .52858 .61034 .5344 .62071 .52806 .61545 .52221 Metetra
.753 .791 .883 r
.61545 .52221 .62071 .52806 .6311 .52179 .62587 .5159 Metetra
.751 .79 .885 r
.62587 .5159 .6311 .52179 .64152 .51558 .63632 .50967 Metetra
.749 .79 .886 r
.63632 .50967 .64152 .51558 .65195 .50945 .64678 .50351 Metetra
.746 .789 .887 r
.64678 .50351 .65195 .50945 .66241 .50339 .65728 .49742 Metetra
.744 .788 .889 r
.65728 .49742 .66241 .50339 .6729 .49741 .66779 .49142 Metetra
.741 .788 .89 r
.66779 .49142 .6729 .49741 .68341 .49152 .67834 .4855 Metetra
.738 .787 .892 r
.67834 .4855 .68341 .49152 .69395 .48572 .68891 .47967 Metetra
.735 .786 .894 r
.68891 .47967 .69395 .48572 .70452 .48001 .69951 .47393 Metetra
.732 .785 .895 r
.69951 .47393 .70452 .48001 .71512 .47439 .71014 .46829 Metetra
.729 .784 .897 r
.71014 .46829 .71512 .47439 .72576 .46888 .72081 .46275 Metetra
.725 .783 .899 r
.72081 .46275 .72576 .46888 .73642 .46347 .7315 .45732 Metetra
.721 .782 .9 r
.7315 .45732 .73642 .46347 .74712 .45817 .74224 .45199 Metetra
.717 .781 .902 r
.74224 .45199 .74712 .45817 .75786 .45298 .75301 .44677 Metetra
.713 .779 .904 r
.75301 .44677 .75786 .45298 .76864 .44791 .76381 .44167 Metetra
.709 .778 .906 r
.76381 .44167 .76864 .44791 .77946 .44295 .77466 .43669 Metetra
.704 .776 .908 r
.77466 .43669 .77946 .44295 .79031 .43812 .78555 .43184 Metetra
.699 .775 .91 r
.78555 .43184 .79031 .43812 .80122 .43342 .79649 .42711 Metetra
.694 .773 .912 r
.79649 .42711 .80122 .43342 .81217 .42885 .80747 .42251 Metetra
.689 .771 .914 r
.80747 .42251 .81217 .42885 .82316 .42441 .81849 .41805 Metetra
.684 .769 .916 r
.81849 .41805 .82316 .42441 .83421 .42011 .82957 .41372 Metetra
.678 .767 .918 r
.82957 .41372 .83421 .42011 .8453 .41595 .8407 .40953 Metetra
.673 .765 .92 r
.8407 .40953 .8453 .41595 .85646 .41192 .85188 .40548 Metetra
.667 .762 .921 r
.85188 .40548 .85646 .41192 .86766 .40804 .86312 .40158 Metetra
.638 .616 .812 r
.22291 .58869 .22858 .59868 .23757 .59596 .2319 .58595 Metetra
.634 .614 .813 r
.2319 .58595 .23757 .59596 .24657 .59338 .24091 .58335 Metetra
.629 .613 .815 r
.24091 .58335 .24657 .59338 .2556 .59094 .24994 .5809 Metetra
.625 .611 .816 r
.24994 .5809 .2556 .59094 .26465 .58864 .25899 .57859 Metetra
.62 .609 .818 r
.25899 .57859 .26465 .58864 .27372 .58647 .26807 .57643 Metetra
.615 .607 .82 r
.26807 .57643 .27372 .58647 .28282 .58445 .27717 .57441 Metetra
.611 .606 .821 r
.27717 .57441 .28282 .58445 .29194 .58256 .28629 .57253 Metetra
.606 .604 .823 r
.28629 .57253 .29194 .58256 .30109 .58081 .29545 .57078 Metetra
.601 .603 .825 r
.29545 .57078 .30109 .58081 .31027 .57919 .30463 .56917 Metetra
.597 .601 .827 r
.30463 .56917 .31027 .57919 .31948 .57769 .31384 .5677 Metetra
.592 .6 .829 r
.31384 .5677 .31948 .57769 .32872 .57633 .32309 .56635 Metetra
.587 .599 .831 r
.32309 .56635 .32872 .57633 .338 .57508 .33236 .56513 Metetra
.583 .597 .833 r
.33236 .56513 .338 .57508 .34731 .57396 .34168 .56403 Metetra
.578 .596 .835 r
.34168 .56403 .34731 .57396 .35666 .57295 .35103 .56305 Metetra
.574 .595 .837 r
.35103 .56305 .35666 .57295 .36605 .57206 .36042 .56218 Metetra
.569 .594 .839 r
.36042 .56218 .36605 .57206 .37547 .57128 .36985 .56143 Metetra
.565 .593 .841 r
.36985 .56143 .37547 .57128 .38494 .5706 .37932 .56079 Metetra
.56 .593 .843 r
.37932 .56079 .38494 .5706 .39445 .57003 .38883 .56025 Metetra
.556 .592 .845 r
.38883 .56025 .39445 .57003 .40401 .56956 .39839 .55981 Metetra
.552 .591 .847 r
.39839 .55981 .40401 .56956 .41361 .56919 .40799 .55947 Metetra
.547 .59 .849 r
.40799 .55947 .41361 .56919 .42325 .5689 .41764 .55923 Metetra
.543 .59 .851 r
.41764 .55923 .42325 .5689 .43295 .56871 .42734 .55907 Metetra
.539 .589 .853 r
.42734 .55907 .43295 .56871 .44269 .56861 .43709 .559 Metetra
.535 .589 .855 r
.43709 .559 .44269 .56861 .45248 .56859 .44689 .55901 Metetra
.531 .588 .857 r
.44689 .55901 .45248 .56859 .46233 .56865 .45674 .55911 Metetra
.528 .588 .858 r
.45674 .55911 .46233 .56865 .47223 .56878 .46664 .55928 Metetra
.524 .587 .86 r
.46664 .55928 .47223 .56878 .48218 .569 .4766 .55953 Metetra
.52 .587 .862 r
.4766 .55953 .48218 .569 .49218 .56928 .48661 .55985 Metetra
.517 .587 .864 r
.48661 .55985 .49218 .56928 .50225 .56964 .49668 .56024 Metetra
.513 .587 .866 r
.49668 .56024 .50225 .56964 .51237 .57006 .50681 .56069 Metetra
.51 .586 .867 r
.50681 .56069 .51237 .57006 .52255 .57054 .51699 .56121 Metetra
.507 .586 .869 r
.51699 .56121 .52255 .57054 .53278 .57109 .52724 .56179 Metetra
.643 .652 .844 r
.52724 .56179 .53278 .57109 .54306 .56802 .53753 .55869 Metetra
.731 .688 .808 r
.53753 .55869 .54306 .56802 .55335 .56132 .54784 .55191 Metetra
.73 .686 .808 r
.54784 .55191 .55335 .56132 .56365 .55466 .55816 .54517 Metetra
.728 .684 .808 r
.55816 .54517 .56365 .55466 .57397 .54805 .5685 .53848 Metetra
.726 .682 .807 r
.5685 .53848 .57397 .54805 .58431 .5415 .57886 .53185 Metetra
.724 .68 .807 r
.57886 .53185 .58431 .5415 .59467 .53501 .58924 .52527 Metetra
.722 .678 .807 r
.58924 .52527 .59467 .53501 .60505 .52858 .59963 .51875 Metetra
.72 .676 .807 r
.59963 .51875 .60505 .52858 .61545 .52221 .61005 .51229 Metetra
.718 .674 .806 r
.61005 .51229 .61545 .52221 .62587 .5159 .62049 .5059 Metetra
.716 .672 .806 r
.62049 .5059 .62587 .5159 .63632 .50967 .63095 .49958 Metetra
.714 .67 .806 r
.63095 .49958 .63632 .50967 .64678 .50351 .64143 .49334 Metetra
.712 .668 .806 r
.64143 .49334 .64678 .50351 .65728 .49742 .65194 .48717 Metetra
.709 .666 .805 r
.65194 .48717 .65728 .49742 .66779 .49142 .66247 .48108 Metetra
.707 .664 .805 r
.66247 .48108 .66779 .49142 .67834 .4855 .67303 .47507 Metetra
.704 .661 .805 r
.67303 .47507 .67834 .4855 .68891 .47967 .68362 .46916 Metetra
.701 .659 .805 r
.68362 .46916 .68891 .47967 .69951 .47393 .69423 .46334 Metetra
.698 .657 .805 r
.69423 .46334 .69951 .47393 .71014 .46829 .70488 .45761 Metetra
.696 .654 .805 r
.70488 .45761 .71014 .46829 .72081 .46275 .71555 .45199 Metetra
.693 .652 .805 r
.71555 .45199 .72081 .46275 .7315 .45732 .72626 .44647 Metetra
.69 .649 .805 r
.72626 .44647 .7315 .45732 .74224 .45199 .73701 .44106 Metetra
.686 .647 .805 r
.73701 .44106 .74224 .45199 .75301 .44677 .74779 .43577 Metetra
.683 .644 .805 r
.74779 .43577 .75301 .44677 .76381 .44167 .75861 .4306 Metetra
.68 .642 .805 r
.75861 .4306 .76381 .44167 .77466 .43669 .76947 .42555 Metetra
.676 .64 .806 r
.76947 .42555 .77466 .43669 .78555 .43184 .78037 .42062 Metetra
.673 .637 .806 r
.78037 .42062 .78555 .43184 .79649 .42711 .79132 .41583 Metetra
.669 .635 .806 r
.79132 .41583 .79649 .42711 .80747 .42251 .80231 .41117 Metetra
.666 .632 .807 r
.80231 .41117 .80747 .42251 .81849 .41805 .81335 .40664 Metetra
.662 .63 .807 r
.81335 .40664 .81849 .41805 .82957 .41372 .82443 .40226 Metetra
.658 .627 .808 r
.82443 .40226 .82957 .41372 .8407 .40953 .83557 .39802 Metetra
.654 .625 .808 r
.83557 .39802 .8407 .40953 .85188 .40548 .84677 .39393 Metetra
.65 .623 .809 r
.84677 .39393 .85188 .40548 .86312 .40158 .85802 .38998 Metetra
.638 .616 .812 r
.21721 .57867 .22291 .58869 .2319 .58595 .22621 .5759 Metetra
.634 .614 .813 r
.22621 .5759 .2319 .58595 .24091 .58335 .23522 .57329 Metetra
.629 .612 .815 r
.23522 .57329 .24091 .58335 .24994 .5809 .24426 .57083 Metetra
.624 .611 .816 r
.24426 .57083 .24994 .5809 .25899 .57859 .25332 .56852 Metetra
.619 .609 .818 r
.25332 .56852 .25899 .57859 .26807 .57643 .26239 .56635 Metetra
.615 .607 .82 r
.26239 .56635 .26807 .57643 .27717 .57441 .2715 .56433 Metetra
.61 .605 .822 r
.2715 .56433 .27717 .57441 .28629 .57253 .28063 .56246 Metetra
.605 .604 .824 r
.28063 .56246 .28629 .57253 .29545 .57078 .28978 .56073 Metetra
.6 .602 .825 r
.28978 .56073 .29545 .57078 .30463 .56917 .29897 .55913 Metetra
.595 .601 .827 r
.29897 .55913 .30463 .56917 .31384 .5677 .30818 .55767 Metetra
.59 .599 .829 r
.30818 .55767 .31384 .5677 .32309 .56635 .31743 .55635 Metetra
.586 .598 .832 r
.31743 .55635 .32309 .56635 .33236 .56513 .32671 .55515 Metetra
.581 .597 .834 r
.32671 .55515 .33236 .56513 .34168 .56403 .33603 .55408 Metetra
.576 .596 .836 r
.33603 .55408 .34168 .56403 .35103 .56305 .34538 .55313 Metetra
.571 .595 .838 r
.34538 .55313 .35103 .56305 .36042 .56218 .35477 .5523 Metetra
.567 .594 .84 r
.35477 .5523 .36042 .56218 .36985 .56143 .3642 .55158 Metetra
.562 .593 .842 r
.3642 .55158 .36985 .56143 .37932 .56079 .37367 .55097 Metetra
.558 .592 .844 r
.37367 .55097 .37932 .56079 .38883 .56025 .38319 .55046 Metetra
.553 .591 .846 r
.38319 .55046 .38883 .56025 .39839 .55981 .39275 .55006 Metetra
.549 .591 .848 r
.39275 .55006 .39839 .55981 .40799 .55947 .40236 .54976 Metetra
.545 .59 .85 r
.40236 .54976 .40799 .55947 .41764 .55923 .41201 .54955 Metetra
.54 .589 .852 r
.41201 .54955 .41764 .55923 .42734 .55907 .42171 .54943 Metetra
.536 .589 .854 r
.42171 .54943 .42734 .55907 .43709 .559 .43146 .5494 Metetra
.532 .588 .856 r
.43146 .5494 .43709 .559 .44689 .55901 .44127 .54945 Metetra
.528 .588 .858 r
.44127 .54945 .44689 .55901 .45674 .55911 .45112 .54958 Metetra
.525 .587 .86 r
.45112 .54958 .45674 .55911 .46664 .55928 .46103 .54979 Metetra
.521 .587 .862 r
.46103 .54979 .46664 .55928 .4766 .55953 .47099 .55007 Metetra
.517 .587 .864 r
.47099 .55007 .4766 .55953 .48661 .55985 .48101 .55043 Metetra
.514 .587 .865 r
.48101 .55043 .48661 .55985 .49668 .56024 .49109 .55085 Metetra
.51 .586 .867 r
.49109 .55085 .49668 .56024 .50681 .56069 .50122 .55134 Metetra
.507 .586 .869 r
.50122 .55134 .50681 .56069 .51699 .56121 .51142 .55189 Metetra
.503 .586 .871 r
.51142 .55189 .51699 .56121 .52724 .56179 .52167 .5525 Metetra
.643 .654 .845 r
.52167 .5525 .52724 .56179 .53753 .55869 .53198 .54938 Metetra
.733 .69 .809 r
.53198 .54938 .53753 .55869 .54784 .55191 .5423 .54251 Metetra
.732 .688 .808 r
.5423 .54251 .54784 .55191 .55816 .54517 .55265 .53569 Metetra
.73 .686 .808 r
.55265 .53569 .55816 .54517 .5685 .53848 .56301 .52892 Metetra
.728 .684 .808 r
.56301 .52892 .5685 .53848 .57886 .53185 .57338 .5222 Metetra
.726 .682 .807 r
.57338 .5222 .57886 .53185 .58924 .52527 .58378 .51553 Metetra
.724 .68 .807 r
.58378 .51553 .58924 .52527 .59963 .51875 .59419 .50893 Metetra
.722 .678 .807 r
.59419 .50893 .59963 .51875 .61005 .51229 .60463 .50239 Metetra
.72 .676 .806 r
.60463 .50239 .61005 .51229 .62049 .5059 .61508 .49591 Metetra
.718 .674 .806 r
.61508 .49591 .62049 .5059 .63095 .49958 .62556 .4895 Metetra
.716 .672 .806 r
.62556 .4895 .63095 .49958 .64143 .49334 .63606 .48317 Metetra
.713 .67 .806 r
.63606 .48317 .64143 .49334 .65194 .48717 .64658 .47691 Metetra
.711 .667 .805 r
.64658 .47691 .65194 .48717 .66247 .48108 .65713 .47073 Metetra
.708 .665 .805 r
.65713 .47073 .66247 .48108 .67303 .47507 .6677 .46464 Metetra
.706 .663 .805 r
.6677 .46464 .67303 .47507 .68362 .46916 .6783 .45864 Metetra
.703 .66 .805 r
.6783 .45864 .68362 .46916 .69423 .46334 .68893 .45273 Metetra
.7 .658 .805 r
.68893 .45273 .69423 .46334 .70488 .45761 .69959 .44691 Metetra
.697 .655 .805 r
.69959 .44691 .70488 .45761 .71555 .45199 .71028 .44121 Metetra
.694 .653 .805 r
.71028 .44121 .71555 .45199 .72626 .44647 .721 .43561 Metetra
.691 .65 .805 r
.721 .43561 .72626 .44647 .73701 .44106 .73176 .43012 Metetra
.688 .648 .805 r
.73176 .43012 .73701 .44106 .74779 .43577 .74255 .42474 Metetra
.684 .645 .805 r
.74255 .42474 .74779 .43577 .75861 .4306 .75339 .41949 Metetra
.681 .643 .805 r
.75339 .41949 .75861 .4306 .76947 .42555 .76426 .41437 Metetra
.677 .64 .805 r
.76426 .41437 .76947 .42555 .78037 .42062 .77517 .40937 Metetra
.674 .638 .806 r
.77517 .40937 .78037 .42062 .79132 .41583 .78613 .40451 Metetra
.67 .635 .806 r
.78613 .40451 .79132 .41583 .80231 .41117 .79713 .39978 Metetra
.666 .633 .807 r
.79713 .39978 .80231 .41117 .81335 .40664 .80818 .3952 Metetra
.663 .63 .807 r
.80818 .3952 .81335 .40664 .82443 .40226 .81928 .39076 Metetra
.659 .628 .808 r
.81928 .39076 .82443 .40226 .83557 .39802 .83043 .38647 Metetra
.655 .625 .808 r
.83043 .38647 .83557 .39802 .84677 .39393 .84164 .38233 Metetra
.651 .623 .809 r
.84164 .38233 .84677 .39393 .85802 .38998 .8529 .37834 Metetra
.638 .616 .812 r
.21149 .56861 .21721 .57867 .22621 .5759 .2205 .56582 Metetra
.633 .614 .813 r
.2205 .56582 .22621 .5759 .23522 .57329 .22952 .5632 Metetra
.629 .612 .815 r
.22952 .5632 .23522 .57329 .24426 .57083 .23856 .56072 Metetra
.624 .61 .817 r
.23856 .56072 .24426 .57083 .25332 .56852 .24762 .55841 Metetra
.619 .608 .818 r
.24762 .55841 .25332 .56852 .26239 .56635 .2567 .55624 Metetra
.614 .607 .82 r
.2567 .55624 .26239 .56635 .2715 .56433 .26581 .55423 Metetra
.609 .605 .822 r
.26581 .55423 .2715 .56433 .28063 .56246 .27494 .55236 Metetra
.604 .603 .824 r
.27494 .55236 .28063 .56246 .28978 .56073 .28409 .55064 Metetra
.599 .602 .826 r
.28409 .55064 .28978 .56073 .29897 .55913 .29328 .54907 Metetra
.594 .6 .828 r
.29328 .54907 .29897 .55913 .30818 .55767 .3025 .54763 Metetra
.589 .599 .83 r
.3025 .54763 .30818 .55767 .31743 .55635 .31175 .54633 Metetra
.584 .598 .832 r
.31175 .54633 .31743 .55635 .32671 .55515 .32103 .54516 Metetra
.579 .596 .834 r
.32103 .54516 .32671 .55515 .33603 .55408 .33035 .54412 Metetra
.574 .595 .837 r
.33035 .54412 .33603 .55408 .34538 .55313 .3397 .5432 Metetra
.569 .594 .839 r
.3397 .5432 .34538 .55313 .35477 .5523 .3491 .5424 Metetra
.564 .593 .841 r
.3491 .5424 .35477 .5523 .3642 .55158 .35853 .54171 Metetra
.56 .592 .843 r
.35853 .54171 .3642 .55158 .37367 .55097 .368 .54114 Metetra
.555 .592 .845 r
.368 .54114 .37367 .55097 .38319 .55046 .37752 .54067 Metetra
.551 .591 .847 r
.37752 .54067 .38319 .55046 .39275 .55006 .38709 .54031 Metetra
.546 .59 .849 r
.38709 .54031 .39275 .55006 .40236 .54976 .3967 .54004 Metetra
.542 .589 .852 r
.3967 .54004 .40236 .54976 .41201 .54955 .40635 .53987 Metetra
.537 .589 .854 r
.40635 .53987 .41201 .54955 .42171 .54943 .41606 .53979 Metetra
.533 .588 .856 r
.41606 .53979 .42171 .54943 .43146 .5494 .42581 .5398 Metetra
.529 .588 .858 r
.42581 .5398 .43146 .5494 .44127 .54945 .43562 .53989 Metetra
.525 .587 .86 r
.43562 .53989 .44127 .54945 .45112 .54958 .44548 .54006 Metetra
.521 .587 .862 r
.44548 .54006 .45112 .54958 .46103 .54979 .45539 .54031 Metetra
.517 .587 .863 r
.45539 .54031 .46103 .54979 .47099 .55007 .46536 .54063 Metetra
.514 .587 .865 r
.46536 .54063 .47099 .55007 .48101 .55043 .47539 .54102 Metetra
.51 .586 .867 r
.47539 .54102 .48101 .55043 .49109 .55085 .48547 .54148 Metetra
.507 .586 .869 r
.48547 .54148 .49109 .55085 .50122 .55134 .49561 .542 Metetra
.503 .586 .871 r
.49561 .542 .50122 .55134 .51142 .55189 .50581 .54259 Metetra
.5 .586 .872 r
.50581 .54259 .51142 .55189 .52167 .5525 .51607 .54323 Metetra
.644 .655 .847 r
.51607 .54323 .52167 .5525 .53198 .54938 .52639 .54009 Metetra
.735 .692 .809 r
.52639 .54009 .53198 .54938 .5423 .54251 .53674 .53313 Metetra
.733 .69 .809 r
.53674 .53313 .5423 .54251 .55265 .53569 .5471 .52623 Metetra
.732 .688 .808 r
.5471 .52623 .55265 .53569 .56301 .52892 .55748 .51937 Metetra
.73 .686 .808 r
.55748 .51937 .56301 .52892 .57338 .5222 .56788 .51256 Metetra
.728 .684 .808 r
.56788 .51256 .57338 .5222 .58378 .51553 .5783 .50581 Metetra
.726 .682 .807 r
.5783 .50581 .58378 .51553 .59419 .50893 .58873 .49912 Metetra
.724 .68 .807 r
.58873 .49912 .59419 .50893 .60463 .50239 .59918 .49249 Metetra
.722 .678 .807 r
.59918 .49249 .60463 .50239 .61508 .49591 .60965 .48592 Metetra
.72 .676 .806 r
.60965 .48592 .61508 .49591 .62556 .4895 .62015 .47942 Metetra
.717 .673 .806 r
.62015 .47942 .62556 .4895 .63606 .48317 .63066 .473 Metetra
.715 .671 .806 r
.63066 .473 .63606 .48317 .64658 .47691 .6412 .46665 Metetra
.713 .669 .806 r
.6412 .46665 .64658 .47691 .65713 .47073 .65177 .46038 Metetra
.71 .667 .805 r
.65177 .46038 .65713 .47073 .6677 .46464 .66235 .4542 Metetra
.707 .664 .805 r
.66235 .4542 .6677 .46464 .6783 .45864 .67297 .4481 Metetra
.705 .662 .805 r
.67297 .4481 .6783 .45864 .68893 .45273 .68361 .44211 Metetra
.702 .659 .805 r
.68361 .44211 .68893 .45273 .69959 .44691 .69428 .43621 Metetra
.699 .657 .805 r
.69428 .43621 .69959 .44691 .71028 .44121 .70499 .43041 Metetra
.696 .654 .805 r
.70499 .43041 .71028 .44121 .721 .43561 .71572 .42472 Metetra
.692 .652 .805 r
.71572 .42472 .721 .43561 .73176 .43012 .72649 .41915 Metetra
.689 .649 .805 r
.72649 .41915 .73176 .43012 .74255 .42474 .7373 .41369 Metetra
.686 .646 .805 r
.7373 .41369 .74255 .42474 .75339 .41949 .74814 .40836 Metetra
.682 .644 .805 r
.74814 .40836 .75339 .41949 .76426 .41437 .75902 .40316 Metetra
.679 .641 .805 r
.75902 .40316 .76426 .41437 .77517 .40937 .76995 .39809 Metetra
.675 .639 .806 r
.76995 .39809 .77517 .40937 .78613 .40451 .78092 .39316 Metetra
.671 .636 .806 r
.78092 .39316 .78613 .40451 .79713 .39978 .79193 .38836 Metetra
.667 .633 .806 r
.79193 .38836 .79713 .39978 .80818 .3952 .80299 .38372 Metetra
.663 .631 .807 r
.80299 .38372 .80818 .3952 .81928 .39076 .8141 .37922 Metetra
.659 .628 .807 r
.8141 .37922 .81928 .39076 .83043 .38647 .82526 .37488 Metetra
.655 .626 .808 r
.82526 .37488 .83043 .38647 .84164 .38233 .83648 .37069 Metetra
.651 .623 .809 r
.83648 .37069 .84164 .38233 .8529 .37834 .84776 .36665 Metetra
.638 .616 .812 r
.20576 .55851 .21149 .56861 .2205 .56582 .21477 .55571 Metetra
.633 .614 .813 r
.21477 .55571 .2205 .56582 .22952 .5632 .22379 .55306 Metetra
.628 .612 .815 r
.22379 .55306 .22952 .5632 .23856 .56072 .23284 .55058 Metetra
.623 .61 .817 r
.23284 .55058 .23856 .56072 .24762 .55841 .2419 .54826 Metetra
.618 .608 .819 r
.2419 .54826 .24762 .55841 .2567 .55624 .25098 .5461 Metetra
.613 .606 .821 r
.25098 .5461 .2567 .55624 .26581 .55423 .26009 .54409 Metetra
.608 .605 .823 r
.26009 .54409 .26581 .55423 .27494 .55236 .26923 .54224 Metetra
.602 .603 .825 r
.26923 .54224 .27494 .55236 .28409 .55064 .27839 .54054 Metetra
.597 .601 .827 r
.27839 .54054 .28409 .55064 .29328 .54907 .28757 .53898 Metetra
.592 .6 .829 r
.28757 .53898 .29328 .54907 .3025 .54763 .29679 .53757 Metetra
.587 .598 .831 r
.29679 .53757 .3025 .54763 .31175 .54633 .30604 .53629 Metetra
.582 .597 .833 r
.30604 .53629 .31175 .54633 .32103 .54516 .31533 .53515 Metetra
.577 .596 .835 r
.31533 .53515 .32103 .54516 .33035 .54412 .32465 .53414 Metetra
.572 .595 .838 r
.32465 .53414 .33035 .54412 .3397 .5432 .334 .53326 Metetra
.567 .594 .84 r
.334 .53326 .3397 .5432 .3491 .5424 .3434 .53249 Metetra
.562 .593 .842 r
.3434 .53249 .3491 .5424 .35853 .54171 .35283 .53185 Metetra
.557 .592 .844 r
.35283 .53185 .35853 .54171 .368 .54114 .36231 .53131 Metetra
.552 .591 .847 r
.36231 .53131 .368 .54114 .37752 .54067 .37183 .53088 Metetra
.548 .59 .849 r
.37183 .53088 .37752 .54067 .38709 .54031 .3814 .53056 Metetra
.543 .59 .851 r
.3814 .53056 .38709 .54031 .3967 .54004 .39101 .53034 Metetra
.539 .589 .853 r
.39101 .53034 .3967 .54004 .40635 .53987 .40067 .53021 Metetra
.534 .588 .855 r
.40067 .53021 .40635 .53987 .41606 .53979 .41038 .53017 Metetra
.53 .588 .857 r
.41038 .53017 .41606 .53979 .42581 .5398 .42014 .53021 Metetra
.526 .588 .859 r
.42014 .53021 .42581 .5398 .43562 .53989 .42995 .53034 Metetra
.522 .587 .861 r
.42995 .53034 .43562 .53989 .44548 .54006 .43981 .53055 Metetra
.518 .587 .863 r
.43981 .53055 .44548 .54006 .45539 .54031 .44973 .53084 Metetra
.514 .586 .865 r
.44973 .53084 .45539 .54031 .46536 .54063 .4597 .5312 Metetra
.51 .586 .867 r
.4597 .5312 .46536 .54063 .47539 .54102 .46973 .53163 Metetra
.507 .586 .869 r
.46973 .53163 .47539 .54102 .48547 .54148 .47982 .53212 Metetra
.503 .586 .871 r
.47982 .53212 .48547 .54148 .49561 .542 .48997 .53268 Metetra
.5 .586 .872 r
.48997 .53268 .49561 .542 .50581 .54259 .50018 .5333 Metetra
.496 .586 .874 r
.50018 .5333 .50581 .54259 .51607 .54323 .51045 .53398 Metetra
.644 .657 .848 r
.51045 .53398 .51607 .54323 .52639 .54009 .52078 .53081 Metetra
.737 .694 .81 r
.52078 .53081 .52639 .54009 .53674 .53313 .53115 .52378 Metetra
.735 .692 .809 r
.53115 .52378 .53674 .53313 .5471 .52623 .54154 .51678 Metetra
.733 .69 .809 r
.54154 .51678 .5471 .52623 .55748 .51937 .55194 .50984 Metetra
.732 .688 .808 r
.55194 .50984 .55748 .51937 .56788 .51256 .56235 .50295 Metetra
.73 .686 .808 r
.56235 .50295 .56788 .51256 .5783 .50581 .57279 .49611 Metetra
.728 .684 .808 r
.57279 .49611 .5783 .50581 .58873 .49912 .58324 .48932 Metetra
.726 .682 .807 r
.58324 .48932 .58873 .49912 .59918 .49249 .59371 .4826 Metetra
.724 .68 .807 r
.59371 .4826 .59918 .49249 .60965 .48592 .6042 .47594 Metetra
.721 .678 .807 r
.6042 .47594 .60965 .48592 .62015 .47942 .61471 .46935 Metetra
.719 .675 .806 r
.61471 .46935 .62015 .47942 .63066 .473 .62524 .46283 Metetra
.717 .673 .806 r
.62524 .46283 .63066 .473 .6412 .46665 .6358 .45639 Metetra
.714 .671 .806 r
.6358 .45639 .6412 .46665 .65177 .46038 .64638 .45003 Metetra
.712 .668 .806 r
.64638 .45003 .65177 .46038 .66235 .4542 .65698 .44375 Metetra
.709 .666 .805 r
.65698 .44375 .66235 .4542 .67297 .4481 .66761 .43757 Metetra
.706 .663 .805 r
.66761 .43757 .67297 .4481 .68361 .44211 .67827 .43148 Metetra
.703 .661 .805 r
.67827 .43148 .68361 .44211 .69428 .43621 .68896 .42549 Metetra
.7 .658 .805 r
.68896 .42549 .69428 .43621 .70499 .43041 .69967 .4196 Metetra
.697 .656 .805 r
.69967 .4196 .70499 .43041 .71572 .42472 .71042 .41382 Metetra
.694 .653 .805 r
.71042 .41382 .71572 .42472 .72649 .41915 .7212 .40816 Metetra
.691 .65 .805 r
.7212 .40816 .72649 .41915 .7373 .41369 .73202 .40262 Metetra
.687 .648 .805 r
.73202 .40262 .7373 .41369 .74814 .40836 .74288 .39721 Metetra
.684 .645 .805 r
.74288 .39721 .74814 .40836 .75902 .40316 .75377 .39192 Metetra
.68 .642 .805 r
.75377 .39192 .75902 .40316 .76995 .39809 .76471 .38678 Metetra
.676 .639 .806 r
.76471 .38678 .76995 .39809 .78092 .39316 .77568 .38177 Metetra
.672 .637 .806 r
.77568 .38177 .78092 .39316 .79193 .38836 .78671 .37691 Metetra
.668 .634 .806 r
.78671 .37691 .79193 .38836 .80299 .38372 .79778 .3722 Metetra
.664 .631 .807 r
.79778 .3722 .80299 .38372 .8141 .37922 .8089 .36764 Metetra
.66 .629 .807 r
.8089 .36764 .8141 .37922 .82526 .37488 .82008 .36324 Metetra
.656 .626 .808 r
.82008 .36324 .82526 .37488 .83648 .37069 .83131 .359 Metetra
.651 .623 .809 r
.83131 .359 .83648 .37069 .84776 .36665 .84259 .35492 Metetra
.638 .616 .812 r
.2 .54837 .20576 .55851 .21477 .55571 .20901 .54555 Metetra
.633 .614 .813 r
.20901 .54555 .21477 .55571 .22379 .55306 .21804 .5429 Metetra
.628 .612 .815 r
.21804 .5429 .22379 .55306 .23284 .55058 .22709 .54041 Metetra
.622 .61 .817 r
.22709 .54041 .23284 .55058 .2419 .54826 .23616 .53809 Metetra
.617 .608 .819 r
.23616 .53809 .2419 .54826 .25098 .5461 .24525 .53593 Metetra
.612 .606 .821 r
.24525 .53593 .25098 .5461 .26009 .54409 .25436 .53393 Metetra
.606 .604 .823 r
.25436 .53393 .26009 .54409 .26923 .54224 .26349 .53209 Metetra
.601 .602 .825 r
.26349 .53209 .26923 .54224 .27839 .54054 .27266 .5304 Metetra
.596 .601 .827 r
.27266 .5304 .27839 .54054 .28757 .53898 .28185 .52887 Metetra
.59 .599 .83 r
.28185 .52887 .28757 .53898 .29679 .53757 .29106 .52748 Metetra
.585 .598 .832 r
.29106 .52748 .29679 .53757 .30604 .53629 .30032 .52624 Metetra
.58 .597 .834 r
.30032 .52624 .30604 .53629 .31533 .53515 .3096 .52513 Metetra
.574 .595 .836 r
.3096 .52513 .31533 .53515 .32465 .53414 .31892 .52415 Metetra
.569 .594 .839 r
.31892 .52415 .32465 .53414 .334 .53326 .32828 .52331 Metetra
.564 .593 .841 r
.32828 .52331 .334 .53326 .3434 .53249 .33767 .52258 Metetra
.559 .592 .843 r
.33767 .52258 .3434 .53249 .35283 .53185 .34711 .52197 Metetra
.554 .591 .846 r
.34711 .52197 .35283 .53185 .36231 .53131 .35659 .52148 Metetra
.549 .59 .848 r
.35659 .52148 .36231 .53131 .37183 .53088 .36611 .5211 Metetra
.544 .59 .85 r
.36611 .5211 .37183 .53088 .3814 .53056 .37568 .52082 Metetra
.54 .589 .852 r
.37568 .52082 .3814 .53056 .39101 .53034 .38529 .52063 Metetra
.535 .589 .855 r
.38529 .52063 .39101 .53034 .40067 .53021 .39496 .52055 Metetra
.531 .588 .857 r
.39496 .52055 .40067 .53021 .41038 .53017 .40467 .52055 Metetra
.526 .588 .859 r
.40467 .52055 .41038 .53017 .42014 .53021 .41443 .52064 Metetra
.522 .587 .861 r
.41443 .52064 .42014 .53021 .42995 .53034 .42425 .52081 Metetra
.518 .587 .863 r
.42425 .52081 .42995 .53034 .43981 .53055 .43411 .52106 Metetra
.514 .586 .865 r
.43411 .52106 .43981 .53055 .44973 .53084 .44404 .52139 Metetra
.51 .586 .867 r
.44404 .52139 .44973 .53084 .4597 .5312 .45402 .52179 Metetra
.506 .586 .869 r
.45402 .52179 .4597 .5312 .46973 .53163 .46405 .52226 Metetra
.503 .586 .871 r
.46405 .52226 .46973 .53163 .47982 .53212 .47415 .52279 Metetra
.499 .586 .873 r
.47415 .52279 .47982 .53212 .48997 .53268 .4843 .52339 Metetra
.496 .586 .874 r
.4843 .52339 .48997 .53268 .50018 .5333 .49452 .52404 Metetra
.492 .585 .876 r
.49452 .52404 .50018 .5333 .51045 .53398 .5048 .52476 Metetra
.644 .659 .85 r
.5048 .52476 .51045 .53398 .52078 .53081 .51515 .52156 Metetra
.739 .696 .81 r
.51515 .52156 .52078 .53081 .53115 .52378 .52554 .51444 Metetra
.737 .694 .81 r
.52554 .51444 .53115 .52378 .54154 .51678 .53594 .50736 Metetra
.735 .692 .809 r
.53594 .50736 .54154 .51678 .55194 .50984 .54636 .50033 Metetra
.733 .69 .809 r
.54636 .50033 .55194 .50984 .56235 .50295 .5568 .49335 Metetra
.732 .688 .808 r
.5568 .49335 .56235 .50295 .57279 .49611 .56725 .48642 Metetra
.73 .686 .808 r
.56725 .48642 .57279 .49611 .58324 .48932 .57772 .47954 Metetra
.728 .684 .808 r
.57772 .47954 .58324 .48932 .59371 .4826 .58821 .47273 Metetra
.726 .682 .807 r
.58821 .47273 .59371 .4826 .6042 .47594 .59872 .46598 Metetra
.723 .679 .807 r
.59872 .46598 .6042 .47594 .61471 .46935 .60925 .45929 Metetra
.721 .677 .807 r
.60925 .45929 .61471 .46935 .62524 .46283 .6198 .45268 Metetra
.719 .675 .806 r
.6198 .45268 .62524 .46283 .6358 .45639 .63037 .44614 Metetra
.716 .672 .806 r
.63037 .44614 .6358 .45639 .64638 .45003 .64097 .43968 Metetra
.714 .67 .806 r
.64097 .43968 .64638 .45003 .65698 .44375 .65159 .43331 Metetra
.711 .667 .806 r
.65159 .43331 .65698 .44375 .66761 .43757 .66224 .42703 Metetra
.708 .665 .805 r
.66224 .42703 .66761 .43757 .67827 .43148 .67291 .42084 Metetra
.705 .662 .805 r
.67291 .42084 .67827 .43148 .68896 .42549 .68361 .41476 Metetra
.702 .66 .805 r
.68361 .41476 .68896 .42549 .69967 .4196 .69434 .40878 Metetra
.699 .657 .805 r
.69434 .40878 .69967 .4196 .71042 .41382 .7051 .40291 Metetra
.696 .654 .805 r
.7051 .40291 .71042 .41382 .7212 .40816 .71589 .39716 Metetra
.692 .651 .805 r
.71589 .39716 .7212 .40816 .73202 .40262 .72672 .39153 Metetra
.689 .649 .805 r
.72672 .39153 .73202 .40262 .74288 .39721 .73759 .38603 Metetra
.685 .646 .805 r
.73759 .38603 .74288 .39721 .75377 .39192 .7485 .38066 Metetra
.681 .643 .805 r
.7485 .38066 .75377 .39192 .76471 .38678 .75944 .37543 Metetra
.677 .64 .805 r
.75944 .37543 .76471 .38678 .77568 .38177 .77043 .37035 Metetra
.673 .637 .806 r
.77043 .37035 .77568 .38177 .78671 .37691 .78147 .36541 Metetra
.669 .635 .806 r
.78147 .36541 .78671 .37691 .79778 .3722 .79255 .36064 Metetra
.665 .632 .807 r
.79255 .36064 .79778 .3722 .8089 .36764 .80369 .35601 Metetra
.661 .629 .807 r
.80369 .35601 .8089 .36764 .82008 .36324 .81487 .35156 Metetra
.656 .626 .808 r
.81487 .35156 .82008 .36324 .83131 .359 .82611 .34727 Metetra
.652 .624 .809 r
.82611 .34727 .83131 .359 .84259 .35492 .83741 .34314 Metetra
.638 .616 .812 r
.19422 .5382 .2 .54837 .20901 .54555 .20324 .53536 Metetra
.633 .614 .813 r
.20324 .53536 .20901 .54555 .21804 .5429 .21228 .53269 Metetra
.627 .612 .815 r
.21228 .53269 .21804 .5429 .22709 .54041 .22133 .5302 Metetra
.622 .61 .817 r
.22133 .5302 .22709 .54041 .23616 .53809 .2304 .52788 Metetra
.616 .607 .819 r
.2304 .52788 .23616 .53809 .24525 .53593 .23949 .52572 Metetra
.611 .606 .821 r
.23949 .52572 .24525 .53593 .25436 .53393 .2486 .52373 Metetra
.605 .604 .824 r
.2486 .52373 .25436 .53393 .26349 .53209 .25774 .52191 Metetra
.599 .602 .826 r
.25774 .52191 .26349 .53209 .27266 .5304 .2669 .52025 Metetra
.594 .6 .828 r
.2669 .52025 .27266 .5304 .28185 .52887 .27609 .51874 Metetra
.588 .599 .83 r
.27609 .51874 .28185 .52887 .29106 .52748 .28531 .51738 Metetra
.583 .597 .833 r
.28531 .51738 .29106 .52748 .30032 .52624 .29456 .51616 Metetra
.577 .596 .835 r
.29456 .51616 .30032 .52624 .3096 .52513 .30385 .51509 Metetra
.572 .595 .837 r
.30385 .51509 .3096 .52513 .31892 .52415 .31317 .51416 Metetra
.566 .594 .84 r
.31317 .51416 .31892 .52415 .32828 .52331 .32253 .51335 Metetra
.561 .593 .842 r
.32253 .51335 .32828 .52331 .33767 .52258 .33193 .51267 Metetra
.556 .592 .845 r
.33193 .51267 .33767 .52258 .34711 .52197 .34136 .5121 Metetra
.551 .591 .847 r
.34136 .5121 .34711 .52197 .35659 .52148 .35084 .51165 Metetra
.546 .59 .849 r
.35084 .51165 .35659 .52148 .36611 .5211 .36037 .51131 Metetra
.541 .589 .852 r
.36037 .51131 .36611 .5211 .37568 .52082 .36994 .51108 Metetra
.536 .589 .854 r
.36994 .51108 .37568 .52082 .38529 .52063 .37955 .51094 Metetra
.532 .588 .856 r
.37955 .51094 .38529 .52063 .39496 .52055 .38922 .5109 Metetra
.527 .588 .858 r
.38922 .5109 .39496 .52055 .40467 .52055 .39893 .51095 Metetra
.523 .587 .861 r
.39893 .51095 .40467 .52055 .41443 .52064 .4087 .51108 Metetra
.519 .587 .863 r
.4087 .51108 .41443 .52064 .42425 .52081 .41852 .5113 Metetra
.514 .586 .865 r
.41852 .5113 .42425 .52081 .43411 .52106 .42839 .51159 Metetra
.51 .586 .867 r
.42839 .51159 .43411 .52106 .44404 .52139 .43832 .51196 Metetra
.506 .586 .869 r
.43832 .51196 .44404 .52139 .45402 .52179 .4483 .5124 Metetra
.503 .586 .871 r
.4483 .5124 .45402 .52179 .46405 .52226 .45834 .51291 Metetra
.499 .586 .873 r
.45834 .51291 .46405 .52226 .47415 .52279 .46845 .51348 Metetra
.495 .585 .874 r
.46845 .51348 .47415 .52279 .4843 .52339 .47861 .51411 Metetra
.492 .585 .876 r
.47861 .51411 .4843 .52339 .49452 .52404 .48883 .51481 Metetra
.488 .585 .878 r
.48883 .51481 .49452 .52404 .5048 .52476 .49911 .51556 Metetra
.644 .661 .851 r
.49911 .51556 .5048 .52476 .51515 .52156 .50948 .51234 Metetra
.74 .698 .811 r
.50948 .51234 .51515 .52156 .52554 .51444 .51989 .50513 Metetra
.739 .696 .81 r
.51989 .50513 .52554 .51444 .53594 .50736 .53032 .49796 Metetra
.737 .694 .81 r
.53032 .49796 .53594 .50736 .54636 .50033 .54076 .49084 Metetra
.735 .692 .809 r
.54076 .49084 .54636 .50033 .5568 .49335 .55122 .48377 Metetra
.734 .69 .809 r
.55122 .48377 .5568 .49335 .56725 .48642 .56169 .47675 Metetra
.732 .688 .808 r
.56169 .47675 .56725 .48642 .57772 .47954 .57218 .46978 Metetra
.73 .686 .808 r
.57218 .46978 .57772 .47954 .58821 .47273 .58269 .46287 Metetra
.728 .684 .808 r
.58269 .46287 .58821 .47273 .59872 .46598 .59322 .45602 Metetra
.725 .681 .807 r
.59322 .45602 .59872 .46598 .60925 .45929 .60377 .44924 Metetra
.723 .679 .807 r
.60377 .44924 .60925 .45929 .6198 .45268 .61434 .44253 Metetra
.721 .677 .807 r
.61434 .44253 .6198 .45268 .63037 .44614 .62493 .4359 Metetra
.718 .674 .806 r
.62493 .4359 .63037 .44614 .64097 .43968 .63554 .42934 Metetra
.716 .672 .806 r
.63554 .42934 .64097 .43968 .65159 .43331 .64617 .42287 Metetra
.713 .669 .806 r
.64617 .42287 .65159 .43331 .66224 .42703 .65684 .41649 Metetra
.71 .667 .805 r
.65684 .41649 .66224 .42703 .67291 .42084 .66752 .41021 Metetra
.707 .664 .805 r
.66752 .41021 .67291 .42084 .68361 .41476 .67824 .40402 Metetra
.704 .661 .805 r
.67824 .40402 .68361 .41476 .69434 .40878 .68898 .39795 Metetra
.701 .659 .805 r
.68898 .39795 .69434 .40878 .7051 .40291 .69976 .39198 Metetra
.697 .656 .805 r
.69976 .39198 .7051 .40291 .71589 .39716 .71056 .38614 Metetra
.694 .653 .805 r
.71056 .38614 .71589 .39716 .72672 .39153 .72141 .38041 Metetra
.69 .65 .805 r
.72141 .38041 .72672 .39153 .73759 .38603 .73229 .37482 Metetra
.686 .647 .805 r
.73229 .37482 .73759 .38603 .7485 .38066 .7432 .36937 Metetra
.683 .644 .805 r
.7432 .36937 .7485 .38066 .75944 .37543 .75416 .36406 Metetra
.679 .641 .805 r
.75416 .36406 .75944 .37543 .77043 .37035 .76516 .35889 Metetra
.674 .638 .806 r
.76516 .35889 .77043 .37035 .78147 .36541 .77621 .35388 Metetra
.67 .635 .806 r
.77621 .35388 .78147 .36541 .79255 .36064 .7873 .34904 Metetra
.666 .632 .807 r
.7873 .34904 .79255 .36064 .80369 .35601 .79845 .34435 Metetra
.661 .629 .807 r
.79845 .34435 .80369 .35601 .81487 .35156 .80964 .33983 Metetra
.657 .627 .808 r
.80964 .33983 .81487 .35156 .82611 .34727 .8209 .33549 Metetra
.652 .624 .809 r
.8209 .33549 .82611 .34727 .83741 .34314 .83221 .33132 Metetra
.638 .616 .812 r
.18842 .528 .19422 .5382 .20324 .53536 .19745 .52514 Metetra
.632 .614 .814 r
.19745 .52514 .20324 .53536 .21228 .53269 .20649 .52246 Metetra
.627 .611 .816 r
.20649 .52246 .21228 .53269 .22133 .5302 .21554 .51996 Metetra
.621 .609 .818 r
.21554 .51996 .22133 .5302 .2304 .52788 .22462 .51763 Metetra
.615 .607 .82 r
.22462 .51763 .2304 .52788 .23949 .52572 .23371 .51549 Metetra
.609 .605 .822 r
.23371 .51549 .23949 .52572 .2486 .52373 .24282 .51351 Metetra
.603 .603 .824 r
.24282 .51351 .2486 .52373 .25774 .52191 .25196 .51171 Metetra
.598 .601 .826 r
.25196 .51171 .25774 .52191 .2669 .52025 .26113 .51007 Metetra
.592 .6 .829 r
.26113 .51007 .2669 .52025 .27609 .51874 .27032 .50858 Metetra
.586 .598 .831 r
.27032 .50858 .27609 .51874 .28531 .51738 .27954 .50726 Metetra
.58 .597 .834 r
.27954 .50726 .28531 .51738 .29456 .51616 .28879 .50608 Metetra
.575 .595 .836 r
.28879 .50608 .29456 .51616 .30385 .51509 .29807 .50505 Metetra
.569 .594 .839 r
.29807 .50505 .30385 .51509 .31317 .51416 .3074 .50415 Metetra
.564 .593 .841 r
.3074 .50415 .31317 .51416 .32253 .51335 .31675 .50339 Metetra
.558 .592 .844 r
.31675 .50339 .32253 .51335 .33193 .51267 .32615 .50275 Metetra
.553 .591 .846 r
.32615 .50275 .33193 .51267 .34136 .5121 .33559 .50224 Metetra
.548 .59 .849 r
.33559 .50224 .34136 .5121 .35084 .51165 .34507 .50183 Metetra
.543 .589 .851 r
.34507 .50183 .35084 .51165 .36037 .51131 .35459 .50154 Metetra
.538 .589 .853 r
.35459 .50154 .36037 .51131 .36994 .51108 .36416 .50135 Metetra
.533 .588 .856 r
.36416 .50135 .36994 .51108 .37955 .51094 .37378 .50126 Metetra
.528 .588 .858 r
.37378 .50126 .37955 .51094 .38922 .5109 .38345 .50127 Metetra
.523 .587 .86 r
.38345 .50127 .38922 .5109 .39893 .51095 .39317 .50136 Metetra
.519 .587 .863 r
.39317 .50136 .39893 .51095 .4087 .51108 .40294 .50155 Metetra
.515 .586 .865 r
.40294 .50155 .4087 .51108 .41852 .5113 .41276 .50181 Metetra
.51 .586 .867 r
.41276 .50181 .41852 .5113 .42839 .51159 .42264 .50214 Metetra
.506 .586 .869 r
.42264 .50214 .42839 .51159 .43832 .51196 .43257 .50256 Metetra
.502 .586 .871 r
.43257 .50256 .43832 .51196 .4483 .5124 .44256 .50304 Metetra
.499 .586 .873 r
.44256 .50304 .4483 .5124 .45834 .51291 .45261 .50359 Metetra
.495 .585 .875 r
.45261 .50359 .45834 .51291 .46845 .51348 .46271 .5042 Metetra
.491 .585 .876 r
.46271 .5042 .46845 .51348 .47861 .51411 .47288 .50487 Metetra
.488 .585 .878 r
.47288 .50487 .47861 .51411 .48883 .51481 .48311 .5056 Metetra
.484 .585 .88 r
.48311 .5056 .48883 .51481 .49911 .51556 .4934 .50639 Metetra
.644 .663 .853 r
.4934 .50639 .49911 .51556 .50948 .51234 .50379 .50314 Metetra
.742 .7 .811 r
.50379 .50314 .50948 .51234 .51989 .50513 .51422 .49584 Metetra
.741 .698 .811 r
.51422 .49584 .51989 .50513 .53032 .49796 .52467 .48859 Metetra
.739 .696 .81 r
.52467 .48859 .53032 .49796 .54076 .49084 .53513 .48138 Metetra
.737 .694 .81 r
.53513 .48138 .54076 .49084 .55122 .48377 .54561 .47421 Metetra
.736 .692 .809 r
.54561 .47421 .55122 .48377 .56169 .47675 .55611 .4671 Metetra
.734 .69 .809 r
.55611 .4671 .56169 .47675 .57218 .46978 .56662 .46004 Metetra
.732 .688 .808 r
.56662 .46004 .57218 .46978 .58269 .46287 .57715 .45303 Metetra
.73 .686 .808 r
.57715 .45303 .58269 .46287 .59322 .45602 .5877 .44609 Metetra
.727 .684 .808 r
.5877 .44609 .59322 .45602 .60377 .44924 .59826 .43921 Metetra
.725 .681 .807 r
.59826 .43921 .60377 .44924 .61434 .44253 .60885 .4324 Metetra
.723 .679 .807 r
.60885 .4324 .61434 .44253 .62493 .4359 .61945 .42567 Metetra
.72 .676 .807 r
.61945 .42567 .62493 .4359 .63554 .42934 .63008 .41901 Metetra
.718 .674 .806 r
.63008 .41901 .63554 .42934 .64617 .42287 .64074 .41244 Metetra
.715 .671 .806 r
.64074 .41244 .64617 .42287 .65684 .41649 .65141 .40596 Metetra
.712 .669 .806 r
.65141 .40596 .65684 .41649 .66752 .41021 .66212 .39957 Metetra
.709 .666 .805 r
.66212 .39957 .66752 .41021 .67824 .40402 .67285 .39329 Metetra
.706 .663 .805 r
.67285 .39329 .67824 .40402 .68898 .39795 .6836 .38711 Metetra
.703 .66 .805 r
.6836 .38711 .68898 .39795 .69976 .39198 .69439 .38105 Metetra
.699 .657 .805 r
.69439 .38105 .69976 .39198 .71056 .38614 .70521 .3751 Metetra
.696 .654 .805 r
.70521 .3751 .71056 .38614 .72141 .38041 .71607 .36928 Metetra
.692 .651 .805 r
.71607 .36928 .72141 .38041 .73229 .37482 .72696 .3636 Metetra
.688 .648 .805 r
.72696 .3636 .73229 .37482 .7432 .36937 .73789 .35805 Metetra
.684 .645 .805 r
.73789 .35805 .7432 .36937 .75416 .36406 .74886 .35265 Metetra
.68 .642 .805 r
.74886 .35265 .75416 .36406 .76516 .35889 .75987 .34741 Metetra
.676 .639 .806 r
.75987 .34741 .76516 .35889 .77621 .35388 .77093 .34232 Metetra
.671 .636 .806 r
.77093 .34232 .77621 .35388 .7873 .34904 .78203 .3374 Metetra
.667 .633 .807 r
.78203 .3374 .7873 .34904 .79845 .34435 .79319 .33264 Metetra
.662 .63 .807 r
.79319 .33264 .79845 .34435 .80964 .33983 .8044 .32806 Metetra
.658 .627 .808 r
.8044 .32806 .80964 .33983 .8209 .33549 .81566 .32366 Metetra
.653 .624 .809 r
.81566 .32366 .8209 .33549 .83221 .33132 .82698 .31944 Metetra
.638 .616 .812 r
.1826 .51775 .18842 .528 .19745 .52514 .19163 .51487 Metetra
.632 .614 .814 r
.19163 .51487 .19745 .52514 .20649 .52246 .20068 .51218 Metetra
.626 .611 .816 r
.20068 .51218 .20649 .52246 .21554 .51996 .20974 .50968 Metetra
.62 .609 .818 r
.20974 .50968 .21554 .51996 .22462 .51763 .21881 .50736 Metetra
.614 .607 .82 r
.21881 .50736 .22462 .51763 .23371 .51549 .22791 .50522 Metetra
.608 .605 .822 r
.22791 .50522 .23371 .51549 .24282 .51351 .23702 .50326 Metetra
.602 .603 .825 r
.23702 .50326 .24282 .51351 .25196 .51171 .24616 .50148 Metetra
.596 .601 .827 r
.24616 .50148 .25196 .51171 .26113 .51007 .25533 .49986 Metetra
.59 .599 .83 r
.25533 .49986 .26113 .51007 .27032 .50858 .26452 .49841 Metetra
.584 .598 .832 r
.26452 .49841 .27032 .50858 .27954 .50726 .27374 .49712 Metetra
.578 .596 .835 r
.27374 .49712 .27954 .50726 .28879 .50608 .28299 .49599 Metetra
.572 .595 .837 r
.28299 .49599 .28879 .50608 .29807 .50505 .29227 .495 Metetra
.566 .593 .84 r
.29227 .495 .29807 .50505 .3074 .50415 .30159 .49415 Metetra
.561 .592 .842 r
.30159 .49415 .3074 .50415 .31675 .50339 .31095 .49343 Metetra
.555 .591 .845 r
.31095 .49343 .31675 .50339 .32615 .50275 .32035 .49284 Metetra
.549 .59 .848 r
.32035 .49284 .32615 .50275 .33559 .50224 .32979 .49237 Metetra
.544 .59 .85 r
.32979 .49237 .33559 .50224 .34507 .50183 .33927 .49202 Metetra
.539 .589 .853 r
.33927 .49202 .34507 .50183 .35459 .50154 .34879 .49178 Metetra
.534 .588 .855 r
.34879 .49178 .35459 .50154 .36416 .50135 .35837 .49164 Metetra
.529 .588 .858 r
.35837 .49164 .36416 .50135 .37378 .50126 .36799 .4916 Metetra
.524 .587 .86 r
.36799 .4916 .37378 .50126 .38345 .50127 .37765 .49166 Metetra
.519 .587 .862 r
.37765 .49166 .38345 .50127 .39317 .50136 .38737 .4918 Metetra
.515 .586 .864 r
.38737 .4918 .39317 .50136 .40294 .50155 .39715 .49203 Metetra
.511 .586 .867 r
.39715 .49203 .40294 .50155 .41276 .50181 .40697 .49234 Metetra
.506 .586 .869 r
.40697 .49234 .41276 .50181 .42264 .50214 .41685 .49272 Metetra
.502 .586 .871 r
.41685 .49272 .42264 .50214 .43257 .50256 .42679 .49318 Metetra
.498 .585 .873 r
.42679 .49318 .43257 .50256 .44256 .50304 .43679 .49371 Metetra
.494 .585 .875 r
.43679 .49371 .44256 .50304 .45261 .50359 .44684 .4943 Metetra
.491 .585 .877 r
.44684 .4943 .45261 .50359 .46271 .5042 .45695 .49495 Metetra
.487 .585 .879 r
.45695 .49495 .46271 .5042 .47288 .50487 .46713 .49566 Metetra
.483 .585 .88 r
.46713 .49566 .47288 .50487 .48311 .5056 .47736 .49643 Metetra
.48 .585 .882 r
.47736 .49643 .48311 .5056 .4934 .50639 .48766 .49725 Metetra
.645 .665 .855 r
.48766 .49725 .4934 .50639 .50379 .50314 .49806 .49397 Metetra
.744 .702 .812 r
.49806 .49397 .50379 .50314 .51422 .49584 .50852 .48659 Metetra
.743 .7 .811 r
.50852 .48659 .51422 .49584 .52467 .48859 .51899 .47925 Metetra
.741 .698 .811 r
.51899 .47925 .52467 .48859 .53513 .48138 .52948 .47195 Metetra
.739 .697 .81 r
.52948 .47195 .53513 .48138 .54561 .47421 .53998 .46469 Metetra
.738 .695 .81 r
.53998 .46469 .54561 .47421 .55611 .4671 .55049 .45748 Metetra
.736 .692 .809 r
.55049 .45748 .55611 .4671 .56662 .46004 .56103 .45032 Metetra
.734 .69 .809 r
.56103 .45032 .56662 .46004 .57715 .45303 .57158 .44322 Metetra
.732 .688 .808 r
.57158 .44322 .57715 .45303 .5877 .44609 .58214 .43618 Metetra
.73 .686 .808 r
.58214 .43618 .5877 .44609 .59826 .43921 .59273 .4292 Metetra
.727 .683 .808 r
.59273 .4292 .59826 .43921 .60885 .4324 .60333 .42229 Metetra
.725 .681 .807 r
.60333 .42229 .60885 .4324 .61945 .42567 .61396 .41546 Metetra
.722 .678 .807 r
.61396 .41546 .61945 .42567 .63008 .41901 .62461 .4087 Metetra
.72 .676 .806 r
.62461 .4087 .63008 .41901 .64074 .41244 .63528 .40202 Metetra
.717 .673 .806 r
.63528 .40202 .64074 .41244 .65141 .40596 .64597 .39544 Metetra
.714 .67 .806 r
.64597 .39544 .65141 .40596 .66212 .39957 .65669 .38895 Metetra
.711 .668 .806 r
.65669 .38895 .66212 .39957 .67285 .39329 .66743 .38256 Metetra
.708 .665 .805 r
.66743 .38256 .67285 .39329 .6836 .38711 .6782 .37627 Metetra
.705 .662 .805 r
.6782 .37627 .6836 .38711 .69439 .38105 .68901 .37011 Metetra
.701 .659 .805 r
.68901 .37011 .69439 .38105 .70521 .3751 .69984 .36406 Metetra
.697 .656 .805 r
.69984 .36406 .70521 .3751 .71607 .36928 .71071 .35814 Metetra
.694 .653 .805 r
.71071 .35814 .71607 .36928 .72696 .3636 .72161 .35236 Metetra
.69 .65 .805 r
.72161 .35236 .72696 .3636 .73789 .35805 .73255 .34672 Metetra
.686 .646 .805 r
.73255 .34672 .73789 .35805 .74886 .35265 .74353 .34123 Metetra
.681 .643 .805 r
.74353 .34123 .74886 .35265 .75987 .34741 .75456 .33589 Metetra
.677 .64 .806 r
.75456 .33589 .75987 .34741 .77093 .34232 .76562 .33072 Metetra
.673 .637 .806 r
.76562 .33072 .77093 .34232 .78203 .3374 .77674 .32572 Metetra
.668 .634 .806 r
.77674 .32572 .78203 .3374 .79319 .33264 .78791 .3209 Metetra
.663 .631 .807 r
.78791 .3209 .79319 .33264 .8044 .32806 .79913 .31625 Metetra
.658 .628 .808 r
.79913 .31625 .8044 .32806 .81566 .32366 .8104 .31179 Metetra
.653 .624 .808 r
.8104 .31179 .81566 .32366 .82698 .31944 .82173 .30752 Metetra
.638 .616 .812 r
.17676 .50747 .1826 .51775 .19163 .51487 .1858 .50457 Metetra
.631 .613 .814 r
.1858 .50457 .19163 .51487 .20068 .51218 .19485 .50187 Metetra
.625 .611 .816 r
.19485 .50187 .20068 .51218 .20974 .50968 .20391 .49936 Metetra
.619 .609 .818 r
.20391 .49936 .20974 .50968 .21881 .50736 .21299 .49705 Metetra
.613 .606 .82 r
.21299 .49705 .21881 .50736 .22791 .50522 .22208 .49492 Metetra
.607 .604 .823 r
.22208 .49492 .22791 .50522 .23702 .50326 .2312 .49298 Metetra
.6 .602 .825 r
.2312 .49298 .23702 .50326 .24616 .50148 .24034 .49122 Metetra
.594 .6 .828 r
.24034 .49122 .24616 .50148 .25533 .49986 .2495 .48964 Metetra
.588 .598 .83 r
.2495 .48964 .25533 .49986 .26452 .49841 .25869 .48823 Metetra
.581 .597 .833 r
.25869 .48823 .26452 .49841 .27374 .49712 .26791 .48698 Metetra
.575 .595 .836 r
.26791 .48698 .27374 .49712 .28299 .49599 .27716 .48588 Metetra
.569 .594 .839 r
.27716 .48588 .28299 .49599 .29227 .495 .28645 .48494 Metetra
.563 .593 .841 r
.28645 .48494 .29227 .495 .30159 .49415 .29577 .48414 Metetra
.557 .592 .844 r
.29577 .48414 .30159 .49415 .31095 .49343 .30512 .48347 Metetra
.552 .591 .847 r
.30512 .48347 .31095 .49343 .32035 .49284 .31452 .48294 Metetra
.546 .59 .849 r
.31452 .48294 .32035 .49284 .32979 .49237 .32396 .48252 Metetra
.54 .589 .852 r
.32396 .48252 .32979 .49237 .33927 .49202 .33344 .48222 Metetra
.535 .588 .854 r
.33344 .48222 .33927 .49202 .34879 .49178 .34297 .48204 Metetra
.53 .588 .857 r
.34297 .48204 .34879 .49178 .35837 .49164 .35254 .48195 Metetra
.525 .587 .859 r
.35254 .48195 .35837 .49164 .36799 .4916 .36216 .48197 Metetra
.52 .587 .862 r
.36216 .48197 .36799 .4916 .37765 .49166 .37183 .48207 Metetra
.515 .586 .864 r
.37183 .48207 .37765 .49166 .38737 .4918 .38155 .48227 Metetra
.511 .586 .867 r
.38155 .48227 .38737 .4918 .39715 .49203 .39133 .48255 Metetra
.506 .586 .869 r
.39133 .48255 .39715 .49203 .40697 .49234 .40116 .4829 Metetra
.502 .586 .871 r
.40116 .4829 .40697 .49234 .41685 .49272 .41104 .48333 Metetra
.498 .585 .873 r
.41104 .48333 .41685 .49272 .42679 .49318 .42098 .48384 Metetra
.494 .585 .875 r
.42098 .48384 .42679 .49318 .43679 .49371 .43098 .4844 Metetra
.49 .585 .877 r
.43098 .4844 .43679 .49371 .44684 .4943 .44104 .48504 Metetra
.486 .585 .879 r
.44104 .48504 .44684 .4943 .45695 .49495 .45116 .48573 Metetra
.483 .585 .881 r
.45116 .48573 .45695 .49495 .46713 .49566 .46134 .48648 Metetra
.479 .585 .883 r
.46134 .48648 .46713 .49566 .47736 .49643 .47158 .48729 Metetra
.476 .585 .884 r
.47158 .48729 .47736 .49643 .48766 .49725 .48189 .48815 Metetra
.645 .667 .856 r
.48189 .48815 .48766 .49725 .49806 .49397 .49231 .48484 Metetra
.746 .705 .812 r
.49231 .48484 .49806 .49397 .50852 .48659 .50279 .47737 Metetra
.745 .703 .812 r
.50279 .47737 .50852 .48659 .51899 .47925 .51328 .46994 Metetra
.743 .701 .811 r
.51328 .46994 .51899 .47925 .52948 .47195 .52379 .46255 Metetra
.741 .699 .811 r
.52379 .46255 .52948 .47195 .53998 .46469 .53431 .4552 Metetra
.74 .697 .81 r
.53431 .4552 .53998 .46469 .55049 .45748 .54485 .44789 Metetra
.738 .695 .81 r
.54485 .44789 .55049 .45748 .56103 .45032 .55541 .44064 Metetra
.736 .693 .809 r
.55541 .44064 .56103 .45032 .57158 .44322 .56598 .43344 Metetra
.734 .69 .809 r
.56598 .43344 .57158 .44322 .58214 .43618 .57657 .4263 Metetra
.732 .688 .809 r
.57657 .4263 .58214 .43618 .59273 .4292 .58717 .41922 Metetra
.73 .686 .808 r
.58717 .41922 .59273 .4292 .60333 .42229 .5978 .41221 Metetra
.727 .683 .808 r
.5978 .41221 .60333 .42229 .61396 .41546 .60844 .40527 Metetra
.725 .681 .807 r
.60844 .40527 .61396 .41546 .62461 .4087 .6191 .3984 Metetra
.722 .678 .807 r
.6191 .3984 .62461 .4087 .63528 .40202 .62979 .39162 Metetra
.719 .675 .806 r
.62979 .39162 .63528 .40202 .64597 .39544 .6405 .38493 Metetra
.716 .673 .806 r
.6405 .38493 .64597 .39544 .65669 .38895 .65123 .37833 Metetra
.713 .67 .806 r
.65123 .37833 .65669 .38895 .66743 .38256 .66199 .37183 Metetra
.71 .667 .805 r
.66199 .37183 .66743 .38256 .6782 .37627 .67278 .36544 Metetra
.707 .664 .805 r
.67278 .36544 .6782 .37627 .68901 .37011 .6836 .35916 Metetra
.703 .661 .805 r
.6836 .35916 .68901 .37011 .69984 .36406 .69445 .35301 Metetra
.699 .658 .805 r
.69445 .35301 .69984 .36406 .71071 .35814 .70533 .34699 Metetra
.696 .654 .805 r
.70533 .34699 .71071 .35814 .72161 .35236 .71624 .3411 Metetra
.692 .651 .805 r
.71624 .3411 .72161 .35236 .73255 .34672 .7272 .33536 Metetra
.687 .648 .805 r
.7272 .33536 .73255 .34672 .74353 .34123 .73819 .32977 Metetra
.683 .644 .805 r
.73819 .32977 .74353 .34123 .75456 .33589 .74922 .32435 Metetra
.679 .641 .805 r
.74922 .32435 .75456 .33589 .76562 .33072 .7603 .31909 Metetra
.674 .638 .806 r
.7603 .31909 .76562 .33072 .77674 .32572 .77143 .31401 Metetra
.669 .635 .806 r
.77143 .31401 .77674 .32572 .78791 .3209 .78261 .30911 Metetra
.664 .631 .807 r
.78261 .30911 .78791 .3209 .79913 .31625 .79384 .3044 Metetra
.659 .628 .808 r
.79384 .3044 .79913 .31625 .8104 .31179 .80512 .29988 Metetra
.654 .625 .808 r
.80512 .29988 .8104 .31179 .82173 .30752 .81647 .29556 Metetra
.637 .616 .812 r
.1709 .49716 .17676 .50747 .1858 .50457 .17994 .49424 Metetra
.631 .613 .814 r
.17994 .49424 .1858 .50457 .19485 .50187 .18899 .49152 Metetra
.625 .611 .816 r
.18899 .49152 .19485 .50187 .20391 .49936 .19806 .48901 Metetra
.618 .608 .818 r
.19806 .48901 .20391 .49936 .21299 .49705 .20714 .48671 Metetra
.612 .606 .821 r
.20714 .48671 .21299 .49705 .22208 .49492 .21624 .4846 Metetra
.605 .604 .823 r
.21624 .4846 .22208 .49492 .2312 .49298 .22535 .48268 Metetra
.598 .602 .826 r
.22535 .48268 .2312 .49298 .24034 .49122 .23449 .48095 Metetra
.592 .6 .829 r
.23449 .48095 .24034 .49122 .2495 .48964 .24366 .4794 Metetra
.585 .598 .831 r
.24366 .4794 .2495 .48964 .25869 .48823 .25285 .47803 Metetra
.579 .596 .834 r
.25285 .47803 .25869 .48823 .26791 .48698 .26206 .47682 Metetra
.572 .595 .837 r
.26206 .47682 .26791 .48698 .27716 .48588 .27131 .47578 Metetra
.566 .593 .84 r
.27131 .47578 .27716 .48588 .28645 .48494 .28059 .47488 Metetra
.56 .592 .843 r
.28059 .47488 .28645 .48494 .29577 .48414 .28991 .47414 Metetra
.554 .591 .846 r
.28991 .47414 .29577 .48414 .30512 .48347 .29927 .47352 Metetra
.548 .59 .848 r
.29927 .47352 .30512 .48347 .31452 .48294 .30866 .47304 Metetra
.542 .589 .851 r
.30866 .47304 .31452 .48294 .32396 .48252 .3181 .47269 Metetra
.536 .588 .854 r
.3181 .47269 .32396 .48252 .33344 .48222 .32758 .47245 Metetra
.531 .588 .856 r
.32758 .47245 .33344 .48222 .34297 .48204 .33711 .47231 Metetra
.526 .587 .859 r
.33711 .47231 .34297 .48204 .35254 .48195 .34668 .47229 Metetra
.521 .587 .862 r
.34668 .47229 .35254 .48195 .36216 .48197 .3563 .47236 Metetra
.516 .586 .864 r
.3563 .47236 .36216 .48197 .37183 .48207 .36597 .47252 Metetra
.511 .586 .866 r
.36597 .47252 .37183 .48207 .38155 .48227 .3757 .47276 Metetra
.506 .586 .869 r
.3757 .47276 .38155 .48227 .39133 .48255 .38548 .47309 Metetra
.502 .585 .871 r
.38548 .47309 .39133 .48255 .40116 .4829 .39531 .4735 Metetra
.497 .585 .873 r
.39531 .4735 .40116 .4829 .41104 .48333 .4052 .47398 Metetra
.493 .585 .875 r
.4052 .47398 .41104 .48333 .42098 .48384 .41514 .47453 Metetra
.489 .585 .877 r
.41514 .47453 .42098 .48384 .43098 .4844 .42515 .47514 Metetra
.485 .585 .879 r
.42515 .47514 .43098 .4844 .44104 .48504 .43521 .47582 Metetra
.482 .585 .881 r
.43521 .47582 .44104 .48504 .45116 .48573 .44534 .47655 Metetra
.478 .585 .883 r
.44534 .47655 .45116 .48573 .46134 .48648 .45552 .47734 Metetra
.474 .585 .885 r
.45552 .47734 .46134 .48648 .47158 .48729 .46577 .47819 Metetra
.471 .585 .887 r
.46577 .47819 .47158 .48729 .48189 .48815 .47609 .47908 Metetra
.645 .669 .858 r
.47609 .47908 .48189 .48815 .49231 .48484 .48652 .47575 Metetra
.748 .707 .813 r
.48652 .47575 .49231 .48484 .50279 .47737 .49703 .46819 Metetra
.747 .705 .812 r
.49703 .46819 .50279 .47737 .51328 .46994 .50754 .46067 Metetra
.745 .703 .812 r
.50754 .46067 .51328 .46994 .52379 .46255 .51808 .45319 Metetra
.744 .701 .811 r
.51808 .45319 .52379 .46255 .53431 .4552 .52862 .44574 Metetra
.742 .699 .811 r
.52862 .44574 .53431 .4552 .54485 .44789 .53918 .43834 Metetra
.74 .697 .81 r
.53918 .43834 .54485 .44789 .55541 .44064 .54976 .43099 Metetra
.738 .695 .81 r
.54976 .43099 .55541 .44064 .56598 .43344 .56035 .42369 Metetra
.736 .693 .809 r
.56035 .42369 .56598 .43344 .57657 .4263 .57096 .41645 Metetra
.734 .691 .809 r
.57096 .41645 .57657 .4263 .58717 .41922 .58159 .40927 Metetra
.732 .688 .809 r
.58159 .40927 .58717 .41922 .5978 .41221 .59223 .40215 Metetra
.729 .686 .808 r
.59223 .40215 .5978 .41221 .60844 .40527 .6029 .3951 Metetra
.727 .683 .808 r
.6029 .3951 .60844 .40527 .6191 .3984 .61358 .38813 Metetra
.724 .68 .807 r
.61358 .38813 .6191 .3984 .62979 .39162 .62428 .38124 Metetra
.722 .678 .807 r
.62428 .38124 .62979 .39162 .6405 .38493 .63501 .37443 Metetra
.719 .675 .806 r
.63501 .37443 .6405 .38493 .65123 .37833 .64576 .36772 Metetra
.716 .672 .806 r
.64576 .36772 .65123 .37833 .66199 .37183 .65654 .36111 Metetra
.712 .669 .806 r
.65654 .36111 .66199 .37183 .67278 .36544 .66734 .35461 Metetra
.709 .666 .805 r
.66734 .35461 .67278 .36544 .6836 .35916 .67817 .34822 Metetra
.705 .663 .805 r
.67817 .34822 .6836 .35916 .69445 .35301 .68903 .34196 Metetra
.702 .659 .805 r
.68903 .34196 .69445 .35301 .70533 .34699 .69993 .33582 Metetra
.698 .656 .805 r
.69993 .33582 .70533 .34699 .71624 .3411 .71085 .32983 Metetra
.694 .653 .805 r
.71085 .32983 .71624 .3411 .7272 .33536 .72182 .32399 Metetra
.689 .649 .805 r
.72182 .32399 .7272 .33536 .73819 .32977 .73282 .3183 Metetra
.685 .646 .805 r
.73282 .3183 .73819 .32977 .74922 .32435 .74387 .31278 Metetra
.68 .642 .805 r
.74387 .31278 .74922 .32435 .7603 .31909 .75496 .30743 Metetra
.675 .639 .806 r
.75496 .30743 .7603 .31909 .77143 .31401 .7661 .30226 Metetra
.67 .635 .806 r
.7661 .30226 .77143 .31401 .78261 .30911 .77728 .29729 Metetra
.665 .632 .807 r
.77728 .29729 .78261 .30911 .79384 .3044 .78852 .2925 Metetra
.66 .629 .807 r
.78852 .2925 .79384 .3044 .80512 .29988 .79982 .28792 Metetra
.654 .625 .808 r
.79982 .28792 .80512 .29988 .81647 .29556 .81118 .28354 Metetra
.637 .616 .812 r
.16501 .4868 .1709 .49716 .17994 .49424 .17406 .48386 Metetra
.631 .613 .814 r
.17406 .48386 .17994 .49424 .18899 .49152 .18312 .48114 Metetra
.624 .61 .816 r
.18312 .48114 .18899 .49152 .19806 .48901 .19219 .47863 Metetra
.617 .608 .819 r
.19219 .47863 .19806 .48901 .20714 .48671 .20127 .47633 Metetra
.61 .605 .821 r
.20127 .47633 .20714 .48671 .21624 .4846 .21037 .47424 Metetra
.603 .603 .824 r
.21037 .47424 .21624 .4846 .22535 .48268 .21948 .47235 Metetra
.596 .601 .827 r
.21948 .47235 .22535 .48268 .23449 .48095 .22862 .47065 Metetra
.589 .599 .83 r
.22862 .47065 .23449 .48095 .24366 .4794 .23778 .46915 Metetra
.583 .597 .833 r
.23778 .46915 .24366 .4794 .25285 .47803 .24697 .46782 Metetra
.576 .595 .835 r
.24697 .46782 .25285 .47803 .26206 .47682 .25619 .46666 Metetra
.569 .594 .838 r
.25619 .46666 .26206 .47682 .27131 .47578 .26543 .46567 Metetra
.563 .593 .841 r
.26543 .46567 .27131 .47578 .28059 .47488 .27471 .46483 Metetra
.556 .591 .844 r
.27471 .46483 .28059 .47488 .28991 .47414 .28403 .46414 Metetra
.55 .59 .847 r
.28403 .46414 .28991 .47414 .29927 .47352 .29338 .46359 Metetra
.544 .589 .85 r
.29338 .46359 .29927 .47352 .30866 .47304 .30278 .46317 Metetra
.538 .588 .853 r
.30278 .46317 .30866 .47304 .3181 .47269 .31221 .46287 Metetra
.532 .588 .856 r
.31221 .46287 .3181 .47269 .32758 .47245 .32169 .46269 Metetra
.527 .587 .859 r
.32169 .46269 .32758 .47245 .33711 .47231 .33122 .46262 Metetra
.521 .587 .861 r
.33122 .46262 .33711 .47231 .34668 .47229 .34079 .46265 Metetra
.516 .586 .864 r
.34079 .46265 .34668 .47229 .3563 .47236 .35042 .46278 Metetra
.511 .586 .866 r
.35042 .46278 .3563 .47236 .36597 .47252 .36009 .46299 Metetra
.506 .586 .869 r
.36009 .46299 .36597 .47252 .3757 .47276 .36981 .46329 Metetra
.501 .585 .871 r
.36981 .46329 .3757 .47276 .38548 .47309 .37959 .46368 Metetra
.497 .585 .873 r
.37959 .46368 .38548 .47309 .39531 .4735 .38943 .46413 Metetra
.493 .585 .876 r
.38943 .46413 .39531 .4735 .4052 .47398 .39932 .46466 Metetra
.488 .585 .878 r
.39932 .46466 .4052 .47398 .41514 .47453 .40927 .46526 Metetra
.484 .585 .88 r
.40927 .46526 .41514 .47453 .42515 .47514 .41928 .46592 Metetra
.48 .585 .882 r
.41928 .46592 .42515 .47514 .43521 .47582 .42935 .46664 Metetra
.477 .585 .884 r
.42935 .46664 .43521 .47582 .44534 .47655 .43948 .46741 Metetra
.473 .585 .885 r
.43948 .46741 .44534 .47655 .45552 .47734 .44967 .46825 Metetra
.47 .585 .887 r
.44967 .46825 .45552 .47734 .46577 .47819 .45993 .46913 Metetra
.466 .585 .889 r
.45993 .46913 .46577 .47819 .47609 .47908 .47026 .47006 Metetra
.646 .671 .86 r
.47026 .47006 .47609 .47908 .48652 .47575 .4807 .4667 Metetra
.75 .71 .814 r
.4807 .4667 .48652 .47575 .49703 .46819 .49123 .45906 Metetra
.749 .708 .813 r
.49123 .45906 .49703 .46819 .50754 .46067 .50178 .45144 Metetra
.747 .706 .813 r
.50178 .45144 .50754 .46067 .51808 .45319 .51233 .44386 Metetra
.746 .704 .812 r
.51233 .44386 .51808 .45319 .52862 .44574 .5229 .43633 Metetra
.744 .702 .812 r
.5229 .43633 .52862 .44574 .53918 .43834 .53349 .42883 Metetra
.742 .7 .811 r
.53349 .42883 .53918 .43834 .54976 .43099 .54409 .42138 Metetra
.74 .698 .811 r
.54409 .42138 .54976 .43099 .56035 .42369 .5547 .41398 Metetra
.738 .696 .81 r
.5547 .41398 .56035 .42369 .57096 .41645 .56533 .40663 Metetra
.736 .693 .81 r
.56533 .40663 .57096 .41645 .58159 .40927 .57598 .39935 Metetra
.734 .691 .809 r
.57598 .39935 .58159 .40927 .59223 .40215 .58664 .39212 Metetra
.732 .688 .809 r
.58664 .39212 .59223 .40215 .6029 .3951 .59733 .38496 Metetra
.729 .686 .808 r
.59733 .38496 .6029 .3951 .61358 .38813 .60803 .37788 Metetra
.727 .683 .808 r
.60803 .37788 .61358 .38813 .62428 .38124 .61875 .37088 Metetra
.724 .68 .807 r
.61875 .37088 .62428 .38124 .63501 .37443 .6295 .36396 Metetra
.721 .677 .807 r
.6295 .36396 .63501 .37443 .64576 .36772 .64026 .35713 Metetra
.718 .674 .806 r
.64026 .35713 .64576 .36772 .65654 .36111 .65106 .35041 Metetra
.715 .671 .806 r
.65106 .35041 .65654 .36111 .66734 .35461 .66187 .34379 Metetra
.711 .668 .806 r
.66187 .34379 .66734 .35461 .67817 .34822 .67272 .33729 Metetra
.708 .665 .805 r
.67272 .33729 .67817 .34822 .68903 .34196 .6836 .33091 Metetra
.704 .661 .805 r
.6836 .33091 .68903 .34196 .69993 .33582 .6945 .32466 Metetra
.7 .658 .805 r
.6945 .32466 .69993 .33582 .71085 .32983 .70544 .31856 Metetra
.696 .654 .805 r
.70544 .31856 .71085 .32983 .72182 .32399 .71642 .3126 Metetra
.691 .651 .805 r
.71642 .3126 .72182 .32399 .73282 .3183 .72744 .30681 Metetra
.687 .647 .805 r
.72744 .30681 .73282 .3183 .74387 .31278 .73849 .30119 Metetra
.682 .644 .805 r
.73849 .30119 .74387 .31278 .75496 .30743 .74959 .29574 Metetra
.677 .64 .806 r
.74959 .29574 .75496 .30743 .7661 .30226 .76074 .29048 Metetra
.672 .636 .806 r
.76074 .29048 .7661 .30226 .77728 .29729 .77194 .28542 Metetra
.666 .633 .807 r
.77194 .28542 .77728 .29729 .78852 .2925 .78319 .28056 Metetra
.661 .629 .807 r
.78319 .28056 .78852 .2925 .79982 .28792 .7945 .27591 Metetra
.655 .626 .808 r
.7945 .27591 .79982 .28792 .81118 .28354 .80587 .27148 Metetra
.637 .616 .812 r
.15911 .47641 .16501 .4868 .17406 .48386 .16816 .47345 Metetra
.63 .613 .814 r
.16816 .47345 .17406 .48386 .18312 .48114 .17722 .47072 Metetra
.623 .61 .817 r
.17722 .47072 .18312 .48114 .19219 .47863 .18629 .46822 Metetra
.616 .607 .819 r
.18629 .46822 .19219 .47863 .20127 .47633 .19538 .46593 Metetra
.609 .605 .822 r
.19538 .46593 .20127 .47633 .21037 .47424 .20448 .46386 Metetra
.601 .602 .825 r
.20448 .46386 .21037 .47424 .21948 .47235 .21359 .462 Metetra
.594 .6 .828 r
.21359 .462 .21948 .47235 .22862 .47065 .22273 .46034 Metetra
.587 .598 .831 r
.22273 .46034 .22862 .47065 .23778 .46915 .23189 .45888 Metetra
.58 .596 .834 r
.23189 .45888 .23778 .46915 .24697 .46782 .24107 .4576 Metetra
.573 .595 .837 r
.24107 .4576 .24697 .46782 .25619 .46666 .25028 .4565 Metetra
.566 .593 .84 r
.25028 .4565 .25619 .46666 .26543 .46567 .25953 .45556 Metetra
.559 .592 .843 r
.25953 .45556 .26543 .46567 .27471 .46483 .26881 .45479 Metetra
.552 .591 .846 r
.26881 .45479 .27471 .46483 .28403 .46414 .27812 .45416 Metetra
.546 .59 .849 r
.27812 .45416 .28403 .46414 .29338 .46359 .28747 .45367 Metetra
.54 .589 .852 r
.28747 .45367 .29338 .46359 .30278 .46317 .29686 .45331 Metetra
.533 .588 .855 r
.29686 .45331 .30278 .46317 .31221 .46287 .3063 .45308 Metetra
.528 .587 .858 r
.3063 .45308 .31221 .46287 .32169 .46269 .31578 .45296 Metetra
.522 .587 .861 r
.31578 .45296 .32169 .46269 .33122 .46262 .3253 .45295 Metetra
.516 .586 .863 r
.3253 .45295 .33122 .46262 .34079 .46265 .33487 .45305 Metetra
.511 .586 .866 r
.33487 .45305 .34079 .46265 .35042 .46278 .3445 .45323 Metetra
.506 .585 .869 r
.3445 .45323 .35042 .46278 .36009 .46299 .35417 .45351 Metetra
.501 .585 .871 r
.35417 .45351 .36009 .46299 .36981 .46329 .3639 .45387 Metetra
.496 .585 .874 r
.3639 .45387 .36981 .46329 .37959 .46368 .37368 .4543 Metetra
.492 .585 .876 r
.37368 .4543 .37959 .46368 .38943 .46413 .38352 .45481 Metetra
.487 .585 .878 r
.38352 .45481 .38943 .46413 .39932 .46466 .39341 .45539 Metetra
.483 .585 .88 r
.39341 .45539 .39932 .46466 .40927 .46526 .40337 .45604 Metetra
.479 .585 .882 r
.40337 .45604 .40927 .46526 .41928 .46592 .41338 .45674 Metetra
.475 .585 .884 r
.41338 .45674 .41928 .46592 .42935 .46664 .42346 .45751 Metetra
.472 .585 .886 r
.42346 .45751 .42935 .46664 .43948 .46741 .43359 .45832 Metetra
.468 .585 .888 r
.43359 .45832 .43948 .46741 .44967 .46825 .44379 .45919 Metetra
.465 .585 .89 r
.44379 .45919 .44967 .46825 .45993 .46913 .45406 .46011 Metetra
.461 .585 .891 r
.45406 .46011 .45993 .46913 .47026 .47006 .46439 .46108 Metetra
.646 .674 .862 r
.46439 .46108 .47026 .47006 .4807 .4667 .47485 .4577 Metetra
.752 .712 .814 r
.47485 .4577 .4807 .4667 .49123 .45906 .48541 .44996 Metetra
.751 .711 .814 r
.48541 .44996 .49123 .45906 .50178 .45144 .49598 .44226 Metetra
.75 .709 .813 r
.49598 .44226 .50178 .45144 .51233 .44386 .50656 .43459 Metetra
.748 .707 .813 r
.50656 .43459 .51233 .44386 .5229 .43633 .51715 .42695 Metetra
.746 .705 .812 r
.51715 .42695 .5229 .43633 .53349 .42883 .52776 .41936 Metetra
.745 .703 .812 r
.52776 .41936 .53349 .42883 .54409 .42138 .53838 .41181 Metetra
.743 .701 .811 r
.53838 .41181 .54409 .42138 .5547 .41398 .54902 .40431 Metetra
.741 .698 .811 r
.54902 .40431 .5547 .41398 .56533 .40663 .55967 .39686 Metetra
.739 .696 .81 r
.55967 .39686 .56533 .40663 .57598 .39935 .57034 .38946 Metetra
.737 .693 .81 r
.57034 .38946 .57598 .39935 .58664 .39212 .58103 .38213 Metetra
.734 .691 .809 r
.58103 .38213 .58664 .39212 .59733 .38496 .59173 .37486 Metetra
.732 .688 .809 r
.59173 .37486 .59733 .38496 .60803 .37788 .60245 .36767 Metetra
.729 .686 .808 r
.60245 .36767 .60803 .37788 .61875 .37088 .6132 .36055 Metetra
.727 .683 .808 r
.6132 .36055 .61875 .37088 .6295 .36396 .62396 .35351 Metetra
.724 .68 .807 r
.62396 .35351 .6295 .36396 .64026 .35713 .63474 .34657 Metetra
.721 .677 .807 r
.63474 .34657 .64026 .35713 .65106 .35041 .64555 .33972 Metetra
.717 .674 .806 r
.64555 .33972 .65106 .35041 .66187 .34379 .65639 .33299 Metetra
.714 .67 .806 r
.65639 .33299 .66187 .34379 .67272 .33729 .66725 .32636 Metetra
.71 .667 .806 r
.66725 .32636 .67272 .33729 .6836 .33091 .67814 .31986 Metetra
.706 .663 .805 r
.67814 .31986 .6836 .33091 .6945 .32466 .68906 .3135 Metetra
.702 .66 .805 r
.68906 .3135 .6945 .32466 .70544 .31856 .70001 .30728 Metetra
.698 .656 .805 r
.70001 .30728 .70544 .31856 .71642 .3126 .711 .30121 Metetra
.693 .653 .805 r
.711 .30121 .71642 .3126 .72744 .30681 .72203 .2953 Metetra
.689 .649 .805 r
.72203 .2953 .72744 .30681 .73849 .30119 .7331 .28957 Metetra
.684 .645 .805 r
.7331 .28957 .73849 .30119 .74959 .29574 .74421 .28402 Metetra
.678 .641 .805 r
.74421 .28402 .74959 .29574 .76074 .29048 .75537 .27867 Metetra
.673 .637 .806 r
.75537 .27867 .76074 .29048 .77194 .28542 .76657 .27352 Metetra
.667 .633 .807 r
.76657 .27352 .77194 .28542 .78319 .28056 .77784 .26858 Metetra
.662 .63 .807 r
.77784 .26858 .78319 .28056 .7945 .27591 .78916 .26386 Metetra
.656 .626 .808 r
.78916 .26386 .7945 .27591 .80587 .27148 .80053 .25937 Metetra
.637 .616 .812 r
.15318 .46598 .15911 .47641 .16816 .47345 .16224 .46301 Metetra
.63 .613 .814 r
.16224 .46301 .16816 .47345 .17722 .47072 .17131 .46027 Metetra
.622 .61 .817 r
.17131 .46027 .17722 .47072 .18629 .46822 .18038 .45777 Metetra
.614 .607 .82 r
.18038 .45777 .18629 .46822 .19538 .46593 .18946 .4555 Metetra
.607 .604 .823 r
.18946 .4555 .19538 .46593 .20448 .46386 .19856 .45345 Metetra
.599 .602 .826 r
.19856 .45345 .20448 .46386 .21359 .462 .20767 .45163 Metetra
.592 .599 .829 r
.20767 .45163 .21359 .462 .22273 .46034 .21681 .45001 Metetra
.584 .597 .832 r
.21681 .45001 .22273 .46034 .23189 .45888 .22596 .4486 Metetra
.576 .595 .835 r
.22596 .4486 .23189 .45888 .24107 .4576 .23514 .44738 Metetra
.569 .594 .838 r
.23514 .44738 .24107 .4576 .25028 .4565 .24435 .44634 Metetra
.562 .592 .842 r
.24435 .44634 .25028 .4565 .25953 .45556 .25359 .44546 Metetra
.555 .591 .845 r
.25359 .44546 .25953 .45556 .26881 .45479 .26287 .44475 Metetra
.548 .59 .848 r
.26287 .44475 .26881 .45479 .27812 .45416 .27218 .44419 Metetra
.541 .589 .851 r
.27218 .44419 .27812 .45416 .28747 .45367 .28153 .44377 Metetra
.535 .588 .854 r
.28153 .44377 .28747 .45367 .29686 .45331 .29092 .44349 Metetra
.529 .587 .857 r
.29092 .44349 .29686 .45331 .3063 .45308 .30035 .44332 Metetra
.523 .587 .86 r
.30035 .44332 .3063 .45308 .31578 .45296 .30983 .44327 Metetra
.517 .586 .863 r
.30983 .44327 .31578 .45296 .3253 .45295 .31935 .44333 Metetra
.511 .586 .866 r
.31935 .44333 .3253 .45295 .33487 .45305 .32892 .44348 Metetra
.506 .585 .869 r
.32892 .44348 .33487 .45305 .3445 .45323 .33855 .44373 Metetra
.501 .585 .871 r
.33855 .44373 .3445 .45323 .35417 .45351 .34822 .44407 Metetra
.496 .585 .874 r
.34822 .44407 .35417 .45351 .3639 .45387 .35795 .44448 Metetra
.491 .585 .876 r
.35795 .44448 .3639 .45387 .37368 .4543 .36773 .44498 Metetra
.486 .585 .878 r
.36773 .44498 .37368 .4543 .38352 .45481 .37757 .44554 Metetra
.482 .585 .881 r
.37757 .44554 .38352 .45481 .39341 .45539 .38747 .44617 Metetra
.478 .585 .883 r
.38747 .44617 .39341 .45539 .40337 .45604 .39743 .44686 Metetra
.474 .585 .885 r
.39743 .44686 .40337 .45604 .41338 .45674 .40745 .44762 Metetra
.47 .585 .887 r
.40745 .44762 .41338 .45674 .42346 .45751 .41753 .44842 Metetra
.466 .585 .889 r
.41753 .44842 .42346 .45751 .43359 .45832 .42767 .44928 Metetra
.463 .585 .89 r
.42767 .44928 .43359 .45832 .44379 .45919 .43788 .45019 Metetra
.46 .585 .892 r
.43788 .45019 .44379 .45919 .45406 .46011 .44815 .45115 Metetra
.456 .586 .894 r
.44815 .45115 .45406 .46011 .46439 .46108 .45849 .45215 Metetra
.646 .676 .864 r
.45849 .45215 .46439 .46108 .47485 .4577 .46897 .44875 Metetra
.755 .715 .815 r
.46897 .44875 .47485 .4577 .48541 .44996 .47955 .44092 Metetra
.753 .713 .815 r
.47955 .44092 .48541 .44996 .49598 .44226 .49015 .43313 Metetra
.752 .712 .814 r
.49015 .43313 .49598 .44226 .50656 .43459 .50075 .42536 Metetra
.75 .71 .814 r
.50075 .42536 .50656 .43459 .51715 .42695 .51137 .41763 Metetra
.749 .708 .813 r
.51137 .41763 .51715 .42695 .52776 .41936 .522 .40994 Metetra
.747 .706 .813 r
.522 .40994 .52776 .41936 .53838 .41181 .53265 .40229 Metetra
.745 .703 .812 r
.53265 .40229 .53838 .41181 .54902 .40431 .54331 .39469 Metetra
.743 .701 .811 r
.54331 .39469 .54902 .40431 .55967 .39686 .55399 .38713 Metetra
.741 .699 .811 r
.55399 .38713 .55967 .39686 .57034 .38946 .56468 .37963 Metetra
.739 .696 .81 r
.56468 .37963 .57034 .38946 .58103 .38213 .57539 .37218 Metetra
.737 .694 .81 r
.57539 .37218 .58103 .38213 .59173 .37486 .58611 .3648 Metetra
.735 .691 .809 r
.58611 .3648 .59173 .37486 .60245 .36767 .59685 .35749 Metetra
.732 .688 .809 r
.59685 .35749 .60245 .36767 .6132 .36055 .60761 .35026 Metetra
.729 .685 .808 r
.60761 .35026 .6132 .36055 .62396 .35351 .6184 .3431 Metetra
.726 .682 .807 r
.6184 .3431 .62396 .35351 .63474 .34657 .6292 .33604 Metetra
.723 .679 .807 r
.6292 .33604 .63474 .34657 .64555 .33972 .64003 .32907 Metetra
.72 .676 .807 r
.64003 .32907 .64555 .33972 .65639 .33299 .65088 .3222 Metetra
.717 .673 .806 r
.65088 .3222 .65639 .33299 .66725 .32636 .66175 .31546 Metetra
.713 .669 .806 r
.66175 .31546 .66725 .32636 .67814 .31986 .67266 .30883 Metetra
.709 .666 .805 r
.67266 .30883 .67814 .31986 .68906 .3135 .68359 .30234 Metetra
.705 .662 .805 r
.68359 .30234 .68906 .3135 .70001 .30728 .69456 .296 Metetra
.7 .658 .805 r
.69456 .296 .70001 .30728 .711 .30121 .70556 .28981 Metetra
.696 .654 .805 r
.70556 .28981 .711 .30121 .72203 .2953 .7166 .28378 Metetra
.691 .65 .805 r
.7166 .28378 .72203 .2953 .7331 .28957 .72768 .27794 Metetra
.686 .646 .805 r
.72768 .27794 .7331 .28957 .74421 .28402 .7388 .27228 Metetra
.68 .642 .805 r
.7388 .27228 .74421 .28402 .75537 .27867 .74997 .26683 Metetra
.675 .638 .806 r
.74997 .26683 .75537 .27867 .76657 .27352 .76119 .26159 Metetra
.669 .634 .806 r
.76119 .26159 .76657 .27352 .77784 .26858 .77246 .25656 Metetra
.663 .63 .807 r
.77246 .25656 .77784 .26858 .78916 .26386 .78379 .25177 Metetra
.657 .627 .808 r
.78379 .25177 .78916 .26386 .80053 .25937 .79518 .24721 Metetra
.637 .616 .812 r
.14723 .45551 .15318 .46598 .16224 .46301 .1563 .45252 Metetra
.629 .612 .815 r
.1563 .45252 .16224 .46301 .17131 .46027 .16537 .44978 Metetra
.621 .609 .817 r
.16537 .44978 .17131 .46027 .18038 .45777 .17444 .44729 Metetra
.613 .606 .82 r
.17444 .44729 .18038 .45777 .18946 .4555 .18352 .44504 Metetra
.605 .603 .823 r
.18352 .44504 .18946 .4555 .19856 .45345 .19262 .44302 Metetra
.597 .601 .826 r
.19262 .44302 .19856 .45345 .20767 .45163 .20173 .44124 Metetra
.589 .599 .83 r
.20173 .44124 .20767 .45163 .21681 .45001 .21086 .43968 Metetra
.581 .596 .833 r
.21086 .43968 .21681 .45001 .22596 .4486 .22001 .43832 Metetra
.573 .595 .837 r
.22001 .43832 .22596 .4486 .23514 .44738 .22919 .43716 Metetra
.565 .593 .84 r
.22919 .43716 .23514 .44738 .24435 .44634 .2384 .43618 Metetra
.558 .591 .843 r
.2384 .43618 .24435 .44634 .25359 .44546 .24763 .43538 Metetra
.55 .59 .847 r
.24763 .43538 .25359 .44546 .26287 .44475 .2569 .43474 Metetra
.543 .589 .85 r
.2569 .43474 .26287 .44475 .27218 .44419 .26621 .43425 Metetra
.536 .588 .853 r
.26621 .43425 .27218 .44419 .28153 .44377 .27555 .43391 Metetra
.53 .587 .857 r
.27555 .43391 .28153 .44377 .29092 .44349 .28494 .43369 Metetra
.523 .587 .86 r
.28494 .43369 .29092 .44349 .30035 .44332 .29437 .4336 Metetra
.517 .586 .863 r
.29437 .4336 .30035 .44332 .30983 .44327 .30384 .43362 Metetra
.511 .586 .866 r
.30384 .43362 .30983 .44327 .31935 .44333 .31337 .43374 Metetra
.506 .585 .869 r
.31337 .43374 .31935 .44333 .32892 .44348 .32294 .43397 Metetra
.5 .585 .871 r
.32294 .43397 .32892 .44348 .33855 .44373 .33256 .43428 Metetra
.495 .585 .874 r
.33256 .43428 .33855 .44373 .34822 .44407 .34224 .43468 Metetra
.49 .585 .877 r
.34224 .43468 .34822 .44407 .35795 .44448 .35197 .43515 Metetra
.485 .585 .879 r
.35197 .43515 .35795 .44448 .36773 .44498 .36175 .4357 Metetra
.481 .585 .881 r
.36175 .4357 .36773 .44498 .37757 .44554 .37159 .43632 Metetra
.477 .585 .883 r
.37159 .43632 .37757 .44554 .38747 .44617 .3815 .437 Metetra
.472 .585 .886 r
.3815 .437 .38747 .44617 .39743 .44686 .39146 .43774 Metetra
.468 .585 .888 r
.39146 .43774 .39743 .44686 .40745 .44762 .40148 .43854 Metetra
.465 .585 .89 r
.40148 .43854 .40745 .44762 .41753 .44842 .41157 .43939 Metetra
.461 .585 .891 r
.41157 .43939 .41753 .44842 .42767 .44928 .42171 .4403 Metetra
.458 .585 .893 r
.42171 .4403 .42767 .44928 .43788 .45019 .43193 .44125 Metetra
.454 .586 .895 r
.43193 .44125 .43788 .45019 .44815 .45115 .44221 .44224 Metetra
.451 .586 .896 r
.44221 .44224 .44815 .45115 .45849 .45215 .45255 .44328 Metetra
.647 .679 .867 r
.45255 .44328 .45849 .45215 .46897 .44875 .46305 .43985 Metetra
.757 .718 .816 r
.46305 .43985 .46897 .44875 .47955 .44092 .47366 .43193 Metetra
.756 .716 .816 r
.47366 .43193 .47955 .44092 .49015 .43313 .48428 .42404 Metetra
.754 .715 .815 r
.48428 .42404 .49015 .43313 .50075 .42536 .49491 .41619 Metetra
.753 .713 .814 r
.49491 .41619 .50075 .42536 .51137 .41763 .50556 .40836 Metetra
.751 .711 .814 r
.50556 .40836 .51137 .41763 .522 .40994 .51622 .40057 Metetra
.75 .709 .813 r
.51622 .40057 .522 .40994 .53265 .40229 .52689 .39282 Metetra
.748 .706 .813 r
.52689 .39282 .53265 .40229 .54331 .39469 .53757 .38512 Metetra
.746 .704 .812 r
.53757 .38512 .54331 .39469 .55399 .38713 .54827 .37745 Metetra
.744 .702 .812 r
.54827 .37745 .55399 .38713 .56468 .37963 .55899 .36984 Metetra
.742 .699 .811 r
.55899 .36984 .56468 .37963 .57539 .37218 .56972 .36229 Metetra
.74 .697 .81 r
.56972 .36229 .57539 .37218 .58611 .3648 .58046 .35479 Metetra
.737 .694 .81 r
.58046 .35479 .58611 .3648 .59685 .35749 .59123 .34736 Metetra
.735 .691 .809 r
.59123 .34736 .59685 .35749 .60761 .35026 .60201 .34001 Metetra
.732 .688 .809 r
.60201 .34001 .60761 .35026 .6184 .3431 .61281 .33273 Metetra
.729 .685 .808 r
.61281 .33273 .6184 .3431 .6292 .33604 .62363 .32554 Metetra
.726 .682 .807 r
.62363 .32554 .6292 .33604 .64003 .32907 .63448 .31844 Metetra
.723 .679 .807 r
.63448 .31844 .64003 .32907 .65088 .3222 .64534 .31145 Metetra
.719 .675 .806 r
.64534 .31145 .65088 .3222 .66175 .31546 .65624 .30457 Metetra
.716 .672 .806 r
.65624 .30457 .66175 .31546 .67266 .30883 .66715 .29782 Metetra
.712 .668 .806 r
.66715 .29782 .67266 .30883 .68359 .30234 .6781 .2912 Metetra
.707 .664 .805 r
.6781 .2912 .68359 .30234 .69456 .296 .68908 .28472 Metetra
.703 .66 .805 r
.68908 .28472 .69456 .296 .70556 .28981 .7001 .27841 Metetra
.698 .656 .805 r
.7001 .27841 .70556 .28981 .7166 .28378 .71115 .27226 Metetra
.693 .652 .805 r
.71115 .27226 .7166 .28378 .72768 .27794 .72224 .26629 Metetra
.688 .648 .805 r
.72224 .26629 .72768 .27794 .7388 .27228 .73337 .26052 Metetra
.682 .644 .805 r
.73337 .26052 .7388 .27228 .74997 .26683 .74455 .25496 Metetra
.676 .64 .806 r
.74455 .25496 .74997 .26683 .76119 .26159 .75578 .24962 Metetra
.67 .635 .806 r
.75578 .24962 .76119 .26159 .77246 .25656 .76706 .24451 Metetra
.664 .631 .807 r
.76706 .24451 .77246 .25656 .78379 .25177 .7784 .23963 Metetra
.657 .627 .808 r
.7784 .23963 .78379 .25177 .79518 .24721 .7898 .23501 Metetra
.636 .616 .812 r
.14126 .445 .14723 .45551 .1563 .45252 .15033 .442 Metetra
.628 .612 .815 r
.15033 .442 .1563 .45252 .16537 .44978 .1594 .43925 Metetra
.62 .609 .818 r
.1594 .43925 .16537 .44978 .17444 .44729 .16848 .43677 Metetra
.611 .606 .821 r
.16848 .43677 .17444 .44729 .18352 .44504 .17756 .43455 Metetra
.603 .603 .824 r
.17756 .43455 .18352 .44504 .19262 .44302 .18665 .43257 Metetra
.594 .6 .827 r
.18665 .43257 .19262 .44302 .20173 .44124 .19576 .43084 Metetra
.586 .598 .831 r
.19576 .43084 .20173 .44124 .21086 .43968 .20489 .42933 Metetra
.577 .596 .835 r
.20489 .42933 .21086 .43968 .22001 .43832 .21404 .42803 Metetra
.569 .594 .838 r
.21404 .42803 .22001 .43832 .22919 .43716 .22321 .42694 Metetra
.561 .592 .842 r
.22321 .42694 .22919 .43716 .2384 .43618 .23241 .42604 Metetra
.553 .59 .845 r
.23241 .42604 .2384 .43618 .24763 .43538 .24164 .42532 Metetra
.546 .589 .849 r
.24164 .42532 .24763 .43538 .2569 .43474 .2509 .42476 Metetra
.538 .588 .852 r
.2509 .42476 .2569 .43474 .26621 .43425 .2602 .42435 Metetra
.531 .587 .856 r
.2602 .42435 .26621 .43425 .27555 .43391 .26955 .42408 Metetra
.524 .587 .859 r
.26955 .42408 .27555 .43391 .28494 .43369 .27893 .42394 Metetra
.518 .586 .862 r
.27893 .42394 .28494 .43369 .29437 .4336 .28835 .42392 Metetra
.512 .585 .866 r
.28835 .42392 .29437 .4336 .30384 .43362 .29783 .42402 Metetra
.506 .585 .869 r
.29783 .42402 .30384 .43362 .31337 .43374 .30735 .42421 Metetra
.5 .585 .871 r
.30735 .42421 .31337 .43374 .32294 .43397 .31692 .42451 Metetra
.494 .585 .874 r
.31692 .42451 .32294 .43397 .33256 .43428 .32654 .42489 Metetra
.489 .585 .877 r
.32654 .42489 .33256 .43428 .34224 .43468 .33622 .42535 Metetra
.484 .585 .879 r
.33622 .42535 .34224 .43468 .35197 .43515 .34595 .42588 Metetra
.48 .585 .882 r
.34595 .42588 .35197 .43515 .36175 .4357 .35573 .42649 Metetra
.475 .585 .884 r
.35573 .42649 .36175 .4357 .37159 .43632 .36558 .42716 Metetra
.471 .585 .886 r
.36558 .42716 .37159 .43632 .3815 .437 .37548 .4279 Metetra
.467 .585 .888 r
.37548 .4279 .3815 .437 .39146 .43774 .38545 .42869 Metetra
.463 .585 .89 r
.38545 .42869 .39146 .43774 .40148 .43854 .39548 .42953 Metetra
.459 .585 .892 r
.39548 .42953 .40148 .43854 .41157 .43939 .40557 .43043 Metetra
.455 .585 .894 r
.40557 .43043 .41157 .43939 .42171 .4403 .41572 .43137 Metetra
.452 .586 .896 r
.41572 .43137 .42171 .4403 .43193 .44125 .42594 .43236 Metetra
.449 .586 .898 r
.42594 .43236 .43193 .44125 .44221 .44224 .43623 .43339 Metetra
.446 .586 .899 r
.43623 .43339 .44221 .44224 .45255 .44328 .44658 .43446 Metetra
.647 .682 .869 r
.44658 .43446 .45255 .44328 .46305 .43985 .4571 .431 Metetra
.759 .721 .817 r
.4571 .431 .46305 .43985 .47366 .43193 .46773 .423 Metetra
.758 .719 .817 r
.46773 .423 .47366 .43193 .48428 .42404 .47838 .41502 Metetra
.756 .718 .816 r
.47838 .41502 .48428 .42404 .49491 .41619 .48904 .40707 Metetra
.755 .716 .815 r
.48904 .40707 .49491 .41619 .50556 .40836 .49971 .39915 Metetra
.754 .714 .815 r
.49971 .39915 .50556 .40836 .51622 .40057 .5104 .39127 Metetra
.752 .712 .814 r
.5104 .39127 .51622 .40057 .52689 .39282 .5211 .38341 Metetra
.75 .71 .814 r
.5211 .38341 .52689 .39282 .53757 .38512 .53181 .3756 Metetra
.749 .707 .813 r
.53181 .3756 .53757 .38512 .54827 .37745 .54253 .36783 Metetra
.747 .705 .812 r
.54253 .36783 .54827 .37745 .55899 .36984 .55327 .36011 Metetra
.745 .703 .812 r
.55327 .36011 .55899 .36984 .56972 .36229 .56402 .35244 Metetra
.742 .7 .811 r
.56402 .35244 .56972 .36229 .58046 .35479 .57479 .34483 Metetra
.74 .697 .81 r
.57479 .34483 .58046 .35479 .59123 .34736 .58557 .33729 Metetra
.738 .695 .81 r
.58557 .33729 .59123 .34736 .60201 .34001 .59638 .32981 Metetra
.735 .692 .809 r
.59638 .32981 .60201 .34001 .61281 .33273 .6072 .32241 Metetra
.732 .689 .809 r
.6072 .32241 .61281 .33273 .62363 .32554 .61804 .31509 Metetra
.729 .685 .808 r
.61804 .31509 .62363 .32554 .63448 .31844 .6289 .30786 Metetra
.726 .682 .807 r
.6289 .30786 .63448 .31844 .64534 .31145 .63979 .30074 Metetra
.722 .678 .807 r
.63979 .30074 .64534 .31145 .65624 .30457 .6507 .29372 Metetra
.719 .675 .806 r
.6507 .29372 .65624 .30457 .66715 .29782 .66163 .28683 Metetra
.715 .671 .806 r
.66163 .28683 .66715 .29782 .6781 .2912 .67259 .28007 Metetra
.71 .667 .806 r
.67259 .28007 .6781 .2912 .68908 .28472 .68359 .27346 Metetra
.706 .663 .805 r
.68359 .27346 .68908 .28472 .7001 .27841 .69462 .26701 Metetra
.701 .659 .805 r
.69462 .26701 .7001 .27841 .71115 .27226 .70568 .26073 Metetra
.696 .654 .805 r
.70568 .26073 .71115 .27226 .72224 .26629 .71678 .25464 Metetra
.69 .65 .805 r
.71678 .25464 .72224 .26629 .73337 .26052 .72792 .24874 Metetra
.684 .646 .805 r
.72792 .24874 .73337 .26052 .74455 .25496 .73911 .24307 Metetra
.678 .641 .806 r
.73911 .24307 .74455 .25496 .75578 .24962 .75035 .23762 Metetra
.672 .637 .806 r
.75035 .23762 .75578 .24962 .76706 .24451 .76165 .23241 Metetra
.665 .632 .807 r
.76165 .23241 .76706 .24451 .7784 .23963 .773 .22745 Metetra
.658 .628 .808 r
.773 .22745 .7784 .23963 .7898 .23501 .78441 .22276 Metetra
.636 .615 .812 r
.13527 .43446 .14126 .445 .15033 .442 .14435 .43143 Metetra
.627 .612 .815 r
.14435 .43143 .15033 .442 .1594 .43925 .15342 .42869 Metetra
.619 .608 .818 r
.15342 .42869 .1594 .43925 .16848 .43677 .16249 .42623 Metetra
.609 .605 .822 r
.16249 .42623 .16848 .43677 .17756 .43455 .17157 .42404 Metetra
.6 .602 .825 r
.17157 .42404 .17756 .43455 .18665 .43257 .18067 .4221 Metetra
.591 .599 .829 r
.18067 .4221 .18665 .43257 .19576 .43084 .18977 .42042 Metetra
.582 .597 .832 r
.18977 .42042 .19576 .43084 .20489 .42933 .19889 .41898 Metetra
.573 .595 .836 r
.19889 .41898 .20489 .42933 .21404 .42803 .20803 .41776 Metetra
.565 .593 .84 r
.20803 .41776 .21404 .42803 .22321 .42694 .2172 .41674 Metetra
.556 .591 .844 r
.2172 .41674 .22321 .42694 .23241 .42604 .22639 .41592 Metetra
.548 .59 .848 r
.22639 .41592 .23241 .42604 .24164 .42532 .23561 .41528 Metetra
.54 .588 .851 r
.23561 .41528 .24164 .42532 .2509 .42476 .24487 .4148 Metetra
.533 .587 .855 r
.24487 .4148 .2509 .42476 .2602 .42435 .25417 .41448 Metetra
.525 .587 .859 r
.25417 .41448 .2602 .42435 .26955 .42408 .2635 .4143 Metetra
.518 .586 .862 r
.2635 .4143 .26955 .42408 .27893 .42394 .27288 .41424 Metetra
.512 .585 .865 r
.27288 .41424 .27893 .42394 .28835 .42392 .2823 .4143 Metetra
.505 .585 .869 r
.2823 .4143 .28835 .42392 .29783 .42402 .29177 .41447 Metetra
.499 .585 .872 r
.29177 .41447 .29783 .42402 .30735 .42421 .30129 .41474 Metetra
.494 .585 .875 r
.30129 .41474 .30735 .42421 .31692 .42451 .31086 .41511 Metetra
.488 .584 .877 r
.31086 .41511 .31692 .42451 .32654 .42489 .32048 .41555 Metetra
.483 .584 .88 r
.32048 .41555 .32654 .42489 .33622 .42535 .33016 .41608 Metetra
.478 .584 .883 r
.33016 .41608 .33622 .42535 .34595 .42588 .33989 .41668 Metetra
.473 .585 .885 r
.33989 .41668 .34595 .42588 .35573 .42649 .34968 .41734 Metetra
.469 .585 .887 r
.34968 .41734 .35573 .42649 .36558 .42716 .35953 .41807 Metetra
.465 .585 .889 r
.35953 .41807 .36558 .42716 .37548 .4279 .36944 .41885 Metetra
.46 .585 .891 r
.36944 .41885 .37548 .4279 .38545 .42869 .3794 .41969 Metetra
.457 .585 .893 r
.3794 .41969 .38545 .42869 .39548 .42953 .38944 .42058 Metetra
.453 .585 .895 r
.38944 .42058 .39548 .42953 .40557 .43043 .39953 .42152 Metetra
.449 .586 .897 r
.39953 .42152 .40557 .43043 .41572 .43137 .40969 .42251 Metetra
.446 .586 .899 r
.40969 .42251 .41572 .43137 .42594 .43236 .41992 .42353 Metetra
.443 .586 .9 r
.41992 .42353 .42594 .43236 .43623 .43339 .43021 .4246 Metetra
.44 .586 .902 r
.43021 .4246 .43623 .43339 .44658 .43446 .44057 .4257 Metetra
.647 .685 .872 r
.44057 .4257 .44658 .43446 .4571 .431 .45111 .42222 Metetra
.761 .724 .818 r
.45111 .42222 .4571 .431 .46773 .423 .46177 .41413 Metetra
.76 .723 .818 r
.46177 .41413 .46773 .423 .47838 .41502 .47245 .40606 Metetra
.759 .721 .817 r
.47245 .40606 .47838 .41502 .48904 .40707 .48314 .39802 Metetra
.758 .719 .816 r
.48314 .39802 .48904 .40707 .49971 .39915 .49384 .39001 Metetra
.756 .717 .816 r
.49384 .39001 .49971 .39915 .5104 .39127 .50455 .38202 Metetra
.755 .715 .815 r
.50455 .38202 .5104 .39127 .5211 .38341 .51527 .37407 Metetra
.753 .713 .815 r
.51527 .37407 .5211 .38341 .53181 .3756 .52601 .36615 Metetra
.751 .711 .814 r
.52601 .36615 .53181 .3756 .54253 .36783 .53675 .35828 Metetra
.749 .708 .813 r
.53675 .35828 .54253 .36783 .55327 .36011 .54752 .35045 Metetra
.747 .706 .813 r
.54752 .35045 .55327 .36011 .56402 .35244 .55829 .34267 Metetra
.745 .703 .812 r
.55829 .34267 .56402 .35244 .57479 .34483 .56909 .33494 Metetra
.743 .701 .811 r
.56909 .33494 .57479 .34483 .58557 .33729 .57989 .32727 Metetra
.741 .698 .811 r
.57989 .32727 .58557 .33729 .59638 .32981 .59072 .31967 Metetra
.738 .695 .81 r
.59072 .31967 .59638 .32981 .6072 .32241 .60156 .31214 Metetra
.735 .692 .809 r
.60156 .31214 .6072 .32241 .61804 .31509 .61242 .30469 Metetra
.732 .689 .809 r
.61242 .30469 .61804 .31509 .6289 .30786 .6233 .29733 Metetra
.729 .685 .808 r
.6233 .29733 .6289 .30786 .63979 .30074 .63421 .29007 Metetra
.726 .682 .807 r
.63421 .29007 .63979 .30074 .6507 .29372 .64513 .28291 Metetra
.722 .678 .807 r
.64513 .28291 .6507 .29372 .66163 .28683 .65608 .27588 Metetra
.718 .674 .806 r
.65608 .27588 .66163 .28683 .67259 .28007 .66706 .26898 Metetra
.713 .67 .806 r
.66706 .26898 .67259 .28007 .68359 .27346 .67807 .26222 Metetra
.709 .666 .805 r
.67807 .26222 .68359 .27346 .69462 .26701 .68911 .25563 Metetra
.704 .661 .805 r
.68911 .25563 .69462 .26701 .70568 .26073 .70019 .24921 Metetra
.698 .657 .805 r
.70019 .24921 .70568 .26073 .71678 .25464 .7113 .24298 Metetra
.693 .652 .805 r
.7113 .24298 .71678 .25464 .72792 .24874 .72245 .23696 Metetra
.687 .647 .805 r
.72245 .23696 .72792 .24874 .73911 .24307 .73365 .23115 Metetra
.68 .643 .805 r
.73365 .23115 .73911 .24307 .75035 .23762 .7449 .22559 Metetra
.674 .638 .806 r
.7449 .22559 .75035 .23762 .76165 .23241 .75621 .22028 Metetra
.667 .633 .807 r
.75621 .22028 .76165 .23241 .773 .22745 .76757 .21523 Metetra
.659 .628 .808 r
.76757 .21523 .773 .22745 .78441 .22276 .77899 .21046 Metetra
.636 .615 .812 r
.12926 .42388 .13527 .43446 .14435 .43143 .13834 .42084 Metetra
.627 .611 .815 r
.13834 .42084 .14435 .43143 .15342 .42869 .14741 .4181 Metetra
.617 .608 .819 r
.14741 .4181 .15342 .42869 .16249 .42623 .15649 .41565 Metetra
.607 .604 .822 r
.15649 .41565 .16249 .42623 .17157 .42404 .16556 .4135 Metetra
.598 .601 .826 r
.16556 .4135 .17157 .42404 .18067 .4221 .17465 .41162 Metetra
.588 .598 .83 r
.17465 .41162 .18067 .4221 .18977 .42042 .18375 .41 Metetra
.578 .596 .834 r
.18375 .41 .18977 .42042 .19889 .41898 .19286 .40863 Metetra
.569 .593 .838 r
.19286 .40863 .19889 .41898 .20803 .41776 .202 .40749 Metetra
.56 .592 .842 r
.202 .40749 .20803 .41776 .2172 .41674 .21115 .40656 Metetra
.551 .59 .846 r
.21115 .40656 .2172 .41674 .22639 .41592 .22034 .40583 Metetra
.543 .589 .85 r
.22034 .40583 .22639 .41592 .23561 .41528 .22956 .40528 Metetra
.535 .587 .854 r
.22956 .40528 .23561 .41528 .24487 .4148 .23881 .4049 Metetra
.527 .587 .858 r
.23881 .4049 .24487 .4148 .25417 .41448 .2481 .40466 Metetra
.519 .586 .862 r
.2481 .40466 .25417 .41448 .2635 .4143 .25743 .40457 Metetra
.512 .585 .865 r
.25743 .40457 .2635 .4143 .27288 .41424 .2668 .4046 Metetra
.505 .585 .868 r
.2668 .4046 .27288 .41424 .2823 .4143 .27622 .40474 Metetra
.499 .585 .872 r
.27622 .40474 .2823 .4143 .29177 .41447 .28568 .40499 Metetra
.493 .584 .875 r
.28568 .40499 .29177 .41447 .30129 .41474 .2952 .40534 Metetra
.487 .584 .878 r
.2952 .40534 .30129 .41474 .31086 .41511 .30477 .40578 Metetra
.482 .584 .881 r
.30477 .40578 .31086 .41511 .32048 .41555 .31439 .40629 Metetra
.476 .584 .883 r
.31439 .40629 .32048 .41555 .33016 .41608 .32406 .40688 Metetra
.471 .584 .886 r
.32406 .40688 .33016 .41608 .33989 .41668 .3338 .40754 Metetra
.467 .585 .888 r
.3338 .40754 .33989 .41668 .34968 .41734 .34359 .40827 Metetra
.462 .585 .89 r
.34359 .40827 .34968 .41734 .35953 .41807 .35344 .40905 Metetra
.458 .585 .893 r
.35344 .40905 .35953 .41807 .36944 .41885 .36335 .40988 Metetra
.454 .585 .895 r
.36335 .40988 .36944 .41885 .3794 .41969 .37332 .41077 Metetra
.45 .586 .897 r
.37332 .41077 .3794 .41969 .38944 .42058 .38336 .41171 Metetra
.447 .586 .898 r
.38336 .41171 .38944 .42058 .39953 .42152 .39346 .41269 Metetra
.443 .586 .9 r
.39346 .41269 .39953 .42152 .40969 .42251 .40362 .41371 Metetra
.44 .586 .902 r
.40362 .41371 .40969 .42251 .41992 .42353 .41386 .41478 Metetra
.437 .587 .903 r
.41386 .41478 .41992 .42353 .43021 .4246 .42416 .41588 Metetra
.434 .587 .905 r
.42416 .41588 .43021 .4246 .44057 .4257 .43453 .41701 Metetra
.648 .688 .874 r
.43453 .41701 .44057 .4257 .45111 .42222 .44508 .4135 Metetra
.764 .727 .819 r
.44508 .4135 .45111 .42222 .46177 .41413 .45577 .40532 Metetra
.762 .726 .819 r
.45577 .40532 .46177 .41413 .47245 .40606 .46648 .39717 Metetra
.761 .724 .818 r
.46648 .39717 .47245 .40606 .48314 .39802 .4772 .38904 Metetra
.76 .722 .817 r
.4772 .38904 .48314 .39802 .49384 .39001 .48792 .38093 Metetra
.759 .72 .817 r
.48792 .38093 .49384 .39001 .50455 .38202 .49866 .37285 Metetra
.757 .718 .816 r
.49866 .37285 .50455 .38202 .51527 .37407 .50941 .36479 Metetra
.756 .716 .816 r
.50941 .36479 .51527 .37407 .52601 .36615 .52017 .35677 Metetra
.754 .714 .815 r
.52017 .35677 .52601 .36615 .53675 .35828 .53095 .34879 Metetra
.752 .712 .814 r
.53095 .34879 .53675 .35828 .54752 .35045 .54174 .34085 Metetra
.75 .71 .814 r
.54174 .34085 .54752 .35045 .55829 .34267 .55254 .33296 Metetra
.748 .707 .813 r
.55254 .33296 .55829 .34267 .56909 .33494 .56336 .32511 Metetra
.746 .704 .812 r
.56336 .32511 .56909 .33494 .57989 .32727 .57419 .31732 Metetra
.744 .702 .811 r
.57419 .31732 .57989 .32727 .59072 .31967 .58503 .30959 Metetra
.741 .699 .811 r
.58503 .30959 .59072 .31967 .60156 .31214 .5959 .30193 Metetra
.738 .695 .81 r
.5959 .30193 .60156 .31214 .61242 .30469 .60678 .29435 Metetra
.736 .692 .809 r
.60678 .29435 .61242 .30469 .6233 .29733 .61768 .28685 Metetra
.732 .689 .809 r
.61768 .28685 .6233 .29733 .63421 .29007 .6286 .27945 Metetra
.729 .685 .808 r
.6286 .27945 .63421 .29007 .64513 .28291 .63955 .27215 Metetra
.725 .681 .807 r
.63955 .27215 .64513 .28291 .65608 .27588 .65052 .26497 Metetra
.721 .677 .807 r
.65052 .26497 .65608 .27588 .66706 .26898 .66151 .25792 Metetra
.717 .673 .806 r
.66151 .25792 .66706 .26898 .67807 .26222 .67253 .25102 Metetra
.712 .669 .806 r
.67253 .25102 .67807 .26222 .68911 .25563 .68359 .24427 Metetra
.707 .664 .805 r
.68359 .24427 .68911 .25563 .70019 .24921 .69467 .2377 Metetra
.702 .659 .805 r
.69467 .2377 .70019 .24921 .7113 .24298 .7058 .23132 Metetra
.696 .655 .805 r
.7058 .23132 .7113 .24298 .72245 .23696 .71696 .22516 Metetra
.689 .65 .805 r
.71696 .22516 .72245 .23696 .73365 .23115 .72817 .21922 Metetra
.683 .644 .805 r
.72817 .21922 .73365 .23115 .7449 .22559 .73943 .21354 Metetra
.676 .639 .806 r
.73943 .21354 .7449 .22559 .75621 .22028 .75074 .20811 Metetra
.668 .634 .807 r
.75074 .20811 .75621 .22028 .76757 .21523 .76211 .20297 Metetra
.661 .629 .807 r
.76211 .20297 .76757 .21523 .77899 .21046 .77355 .19812 Metetra
.636 .615 .812 r
.12322 .41325 .12926 .42388 .13834 .42084 .13231 .4102 Metetra
.626 .611 .816 r
.13231 .4102 .13834 .42084 .14741 .4181 .14138 .40747 Metetra
.615 .607 .819 r
.14138 .40747 .14741 .4181 .15649 .41565 .15045 .40505 Metetra
.605 .603 .823 r
.15045 .40505 .15649 .41565 .16556 .4135 .15953 .40294 Metetra
.594 .6 .827 r
.15953 .40294 .16556 .4135 .17465 .41162 .16861 .40113 Metetra
.584 .597 .831 r
.16861 .40113 .17465 .41162 .18375 .41 .1777 .39958 Metetra
.574 .594 .836 r
.1777 .39958 .18375 .41 .19286 .40863 .18681 .39829 Metetra
.564 .592 .84 r
.18681 .39829 .19286 .40863 .202 .40749 .19593 .39724 Metetra
.555 .59 .844 r
.19593 .39724 .202 .40749 .21115 .40656 .20508 .39641 Metetra
.545 .589 .849 r
.20508 .39641 .21115 .40656 .22034 .40583 .21426 .39578 Metetra
.537 .588 .853 r
.21426 .39578 .22034 .40583 .22956 .40528 .22347 .39533 Metetra
.528 .586 .857 r
.22347 .39533 .22956 .40528 .23881 .4049 .23271 .39504 Metetra
.52 .586 .861 r
.23271 .39504 .23881 .4049 .2481 .40466 .24199 .3949 Metetra
.512 .585 .865 r
.24199 .3949 .2481 .40466 .25743 .40457 .25131 .3949 Metetra
.505 .585 .868 r
.25131 .3949 .25743 .40457 .2668 .4046 .26068 .39502 Metetra
.498 .584 .872 r
.26068 .39502 .2668 .4046 .27622 .40474 .2701 .39526 Metetra
.492 .584 .875 r
.2701 .39526 .27622 .40474 .28568 .40499 .27956 .39559 Metetra
.486 .584 .878 r
.27956 .39559 .28568 .40499 .2952 .40534 .28907 .39601 Metetra
.48 .584 .881 r
.28907 .39601 .2952 .40534 .30477 .40578 .29864 .39652 Metetra
.474 .584 .884 r
.29864 .39652 .30477 .40578 .31439 .40629 .30826 .39711 Metetra
.469 .584 .887 r
.30826 .39711 .31439 .40629 .32406 .40688 .31793 .39777 Metetra
.464 .585 .889 r
.31793 .39777 .32406 .40688 .3338 .40754 .32766 .39849 Metetra
.46 .585 .892 r
.32766 .39849 .3338 .40754 .34359 .40827 .33746 .39927 Metetra
.455 .585 .894 r
.33746 .39927 .34359 .40827 .35344 .40905 .34731 .40011 Metetra
.451 .585 .896 r
.34731 .40011 .35344 .40905 .36335 .40988 .35722 .40099 Metetra
.447 .586 .898 r
.35722 .40099 .36335 .40988 .37332 .41077 .3672 .40193 Metetra
.444 .586 .9 r
.3672 .40193 .37332 .41077 .38336 .41171 .37724 .40291 Metetra
.44 .586 .902 r
.37724 .40291 .38336 .41171 .39346 .41269 .38735 .40393 Metetra
.437 .587 .903 r
.38735 .40393 .39346 .41269 .40362 .41371 .39752 .40499 Metetra
.434 .587 .905 r
.39752 .40499 .40362 .41371 .41386 .41478 .40776 .40609 Metetra
.431 .587 .906 r
.40776 .40609 .41386 .41478 .42416 .41588 .41806 .40722 Metetra
.428 .588 .908 r
.41806 .40722 .42416 .41588 .43453 .41701 .42844 .40839 Metetra
.648 .691 .877 r
.42844 .40839 .43453 .41701 .44508 .4135 .43901 .40485 Metetra
.766 .731 .82 r
.43901 .40485 .44508 .4135 .45577 .40532 .44974 .39659 Metetra
.765 .729 .82 r
.44974 .39659 .45577 .40532 .46648 .39717 .46047 .38835 Metetra
.764 .728 .819 r
.46047 .38835 .46648 .39717 .4772 .38904 .47122 .38012 Metetra
.762 .726 .819 r
.47122 .38012 .4772 .38904 .48792 .38093 .48198 .37192 Metetra
.761 .724 .818 r
.48198 .37192 .48792 .38093 .49866 .37285 .49274 .36374 Metetra
.76 .722 .817 r
.49274 .36374 .49866 .37285 .50941 .36479 .50352 .35559 Metetra
.758 .72 .817 r
.50352 .35559 .50941 .36479 .52017 .35677 .51431 .34747 Metetra
.757 .718 .816 r
.51431 .34747 .52017 .35677 .53095 .34879 .52511 .33938 Metetra
.755 .716 .815 r
.52511 .33938 .53095 .34879 .54174 .34085 .53593 .33133 Metetra
.753 .713 .815 r
.53593 .33133 .54174 .34085 .55254 .33296 .54675 .32332 Metetra
.751 .711 .814 r
.54675 .32332 .55254 .33296 .56336 .32511 .5576 .31536 Metetra
.749 .708 .813 r
.5576 .31536 .56336 .32511 .57419 .31732 .56845 .30745 Metetra
.747 .705 .812 r
.56845 .30745 .57419 .31732 .58503 .30959 .57932 .29959 Metetra
.745 .702 .812 r
.57932 .29959 .58503 .30959 .5959 .30193 .59021 .2918 Metetra
.742 .699 .811 r
.59021 .2918 .5959 .30193 .60678 .29435 .60111 .28408 Metetra
.739 .696 .81 r
.60111 .28408 .60678 .29435 .61768 .28685 .61203 .27644 Metetra
.736 .693 .809 r
.61203 .27644 .61768 .28685 .6286 .27945 .62298 .2689 Metetra
.732 .689 .809 r
.62298 .2689 .6286 .27945 .63955 .27215 .63394 .26145 Metetra
.729 .685 .808 r
.63394 .26145 .63955 .27215 .65052 .26497 .64492 .25412 Metetra
.725 .681 .807 r
.64492 .25412 .65052 .26497 .66151 .25792 .65593 .24691 Metetra
.72 .677 .807 r
.65593 .24691 .66151 .25792 .67253 .25102 .66697 .23985 Metetra
.716 .672 .806 r
.66697 .23985 .67253 .25102 .68359 .24427 .67804 .23294 Metetra
.71 .667 .806 r
.67804 .23294 .68359 .24427 .69467 .2377 .68914 .22622 Metetra
.705 .662 .805 r
.68914 .22622 .69467 .2377 .7058 .23132 .70028 .21968 Metetra
.699 .657 .805 r
.70028 .21968 .7058 .23132 .71696 .22516 .71145 .21337 Metetra
.692 .652 .805 r
.71145 .21337 .71696 .22516 .72817 .21922 .72267 .20729 Metetra
.685 .647 .805 r
.72267 .20729 .72817 .21922 .73943 .21354 .73394 .20146 Metetra
.678 .641 .806 r
.73394 .20146 .73943 .21354 .75074 .20811 .74526 .19592 Metetra
.67 .636 .806 r
.74526 .19592 .75074 .20811 .76211 .20297 .75664 .19067 Metetra
.662 .63 .807 r
.75664 .19067 .76211 .20297 .77355 .19812 .76808 .18573 Metetra
.635 .615 .813 r
.11717 .40259 .12322 .41325 .13231 .4102 .12625 .39953 Metetra
.624 .61 .816 r
.12625 .39953 .13231 .4102 .14138 .40747 .13533 .39681 Metetra
.613 .606 .82 r
.13533 .39681 .14138 .40747 .15045 .40505 .1444 .39443 Metetra
.602 .602 .824 r
.1444 .39443 .15045 .40505 .15953 .40294 .15347 .39237 Metetra
.591 .599 .829 r
.15347 .39237 .15953 .40294 .16861 .40113 .16254 .39063 Metetra
.58 .596 .833 r
.16254 .39063 .16861 .40113 .1777 .39958 .17162 .38917 Metetra
.569 .593 .838 r
.17162 .38917 .1777 .39958 .18681 .39829 .18072 .38798 Metetra
.559 .591 .842 r
.18072 .38798 .18681 .39829 .19593 .39724 .18983 .38703 Metetra
.549 .589 .847 r
.18983 .38703 .19593 .39724 .20508 .39641 .19897 .3863 Metetra
.539 .588 .852 r
.19897 .3863 .20508 .39641 .21426 .39578 .20814 .38578 Metetra
.53 .586 .856 r
.20814 .38578 .21426 .39578 .22347 .39533 .21734 .38544 Metetra
.521 .586 .86 r
.21734 .38544 .22347 .39533 .23271 .39504 .22657 .38525 Metetra
.513 .585 .864 r
.22657 .38525 .23271 .39504 .24199 .3949 .23585 .38522 Metetra
.505 .584 .868 r
.23585 .38522 .24199 .3949 .25131 .3949 .24516 .38532 Metetra
.498 .584 .872 r
.24516 .38532 .25131 .3949 .26068 .39502 .25452 .38553 Metetra
.491 .584 .876 r
.25452 .38553 .26068 .39502 .2701 .39526 .26393 .38585 Metetra
.484 .584 .879 r
.26393 .38585 .2701 .39526 .27956 .39559 .27339 .38627 Metetra
.478 .584 .882 r
.27339 .38627 .27956 .39559 .28907 .39601 .2829 .38678 Metetra
.472 .584 .885 r
.2829 .38678 .28907 .39601 .29864 .39652 .29246 .38736 Metetra
.467 .584 .888 r
.29246 .38736 .29864 .39652 .30826 .39711 .30208 .38802 Metetra
.462 .584 .89 r
.30208 .38802 .30826 .39711 .31793 .39777 .31176 .38874 Metetra
.457 .585 .893 r
.31176 .38874 .31793 .39777 .32766 .39849 .32149 .38952 Metetra
.453 .585 .895 r
.32149 .38952 .32766 .39849 .33746 .39927 .33128 .39036 Metetra
.448 .585 .897 r
.33128 .39036 .33746 .39927 .34731 .40011 .34114 .39125 Metetra
.444 .586 .899 r
.34114 .39125 .34731 .40011 .35722 .40099 .35106 .39219 Metetra
.441 .586 .901 r
.35106 .39219 .35722 .40099 .3672 .40193 .36104 .39317 Metetra
.437 .586 .903 r
.36104 .39317 .3672 .40193 .37724 .40291 .37108 .39419 Metetra
.434 .587 .905 r
.37108 .39419 .37724 .40291 .38735 .40393 .38119 .39525 Metetra
.431 .587 .906 r
.38119 .39525 .38735 .40393 .39752 .40499 .39137 .39635 Metetra
.428 .588 .908 r
.39137 .39635 .39752 .40499 .40776 .40609 .40162 .39748 Metetra
.425 .588 .909 r
.40162 .39748 .40776 .40609 .41806 .40722 .41193 .39864 Metetra
.422 .588 .911 r
.41193 .39864 .41806 .40722 .42844 .40839 .42232 .39984 Metetra
.648 .695 .88 r
.42232 .39984 .42844 .40839 .43901 .40485 .43291 .39627 Metetra
.768 .734 .822 r
.43291 .39627 .43901 .40485 .44974 .39659 .44367 .38793 Metetra
.767 .733 .821 r
.44367 .38793 .44974 .39659 .46047 .38835 .45443 .3796 Metetra
.766 .731 .82 r
.45443 .3796 .46047 .38835 .47122 .38012 .46521 .37129 Metetra
.765 .729 .82 r
.46521 .37129 .47122 .38012 .48198 .37192 .47599 .36299 Metetra
.764 .728 .819 r
.47599 .36299 .48198 .37192 .49274 .36374 .48679 .35472 Metetra
.762 .726 .819 r
.48679 .35472 .49274 .36374 .50352 .35559 .49759 .34647 Metetra
.761 .724 .818 r
.49759 .34647 .50352 .35559 .51431 .34747 .50841 .33825 Metetra
.76 .722 .817 r
.50841 .33825 .51431 .34747 .52511 .33938 .51924 .33006 Metetra
.758 .72 .817 r
.51924 .33006 .52511 .33938 .53593 .33133 .53008 .3219 Metetra
.756 .717 .816 r
.53008 .3219 .53593 .33133 .54675 .32332 .54094 .31377 Metetra
.754 .715 .815 r
.54094 .31377 .54675 .32332 .5576 .31536 .5518 .30569 Metetra
.752 .712 .814 r
.5518 .30569 .5576 .31536 .56845 .30745 .56269 .29766 Metetra
.75 .709 .814 r
.56269 .29766 .56845 .30745 .57932 .29959 .57358 .28968 Metetra
.748 .707 .813 r
.57358 .28968 .57932 .29959 .59021 .2918 .58449 .28175 Metetra
.745 .703 .812 r
.58449 .28175 .59021 .2918 .60111 .28408 .59542 .2739 Metetra
.743 .7 .811 r
.59542 .2739 .60111 .28408 .61203 .27644 .60636 .26612 Metetra
.74 .697 .81 r
.60636 .26612 .61203 .27644 .62298 .2689 .61732 .25842 Metetra
.736 .693 .809 r
.61732 .25842 .62298 .2689 .63394 .26145 .62831 .25082 Metetra
.733 .689 .809 r
.62831 .25082 .63394 .26145 .64492 .25412 .63931 .24333 Metetra
.729 .685 .808 r
.63931 .24333 .64492 .25412 .65593 .24691 .65034 .23596 Metetra
.724 .68 .807 r
.65034 .23596 .65593 .24691 .66697 .23985 .66139 .22874 Metetra
.72 .676 .807 r
.66139 .22874 .66697 .23985 .67804 .23294 .67247 .22166 Metetra
.714 .671 .806 r
.67247 .22166 .67804 .23294 .68914 .22622 .68358 .21476 Metetra
.709 .666 .806 r
.68358 .21476 .68914 .22622 .70028 .21968 .69473 .20806 Metetra
.702 .66 .805 r
.69473 .20806 .70028 .21968 .71145 .21337 .70592 .20158 Metetra
.696 .655 .805 r
.70592 .20158 .71145 .21337 .72267 .20729 .71715 .19534 Metetra
.688 .649 .805 r
.71715 .19534 .72267 .20729 .73394 .20146 .72843 .18937 Metetra
.681 .643 .806 r
.72843 .18937 .73394 .20146 .74526 .19592 .73976 .18369 Metetra
.672 .637 .806 r
.73976 .18369 .74526 .19592 .75664 .19067 .75114 .17833 Metetra
.664 .631 .807 r
.75114 .17833 .75664 .19067 .76808 .18573 .7626 .1733 Metetra
.635 .615 .813 r
.11109 .39189 .11717 .40259 .12625 .39953 .12018 .38881 Metetra
.623 .61 .817 r
.12018 .38881 .12625 .39953 .13533 .39681 .12925 .38611 Metetra
.611 .605 .821 r
.12925 .38611 .13533 .39681 .1444 .39443 .13832 .38378 Metetra
.599 .601 .825 r
.13832 .38378 .1444 .39443 .15347 .39237 .14738 .38179 Metetra
.587 .598 .83 r
.14738 .38179 .15347 .39237 .16254 .39063 .15644 .38013 Metetra
.575 .594 .835 r
.15644 .38013 .16254 .39063 .17162 .38917 .16551 .37877 Metetra
.563 .592 .84 r
.16551 .37877 .17162 .38917 .18072 .38798 .1746 .37769 Metetra
.552 .59 .845 r
.1746 .37769 .18072 .38798 .18983 .38703 .1837 .37686 Metetra
.542 .588 .85 r
.1837 .37686 .18983 .38703 .19897 .3863 .19283 .37625 Metetra
.532 .586 .855 r
.19283 .37625 .19897 .3863 .20814 .38578 .20198 .37584 Metetra
.522 .585 .86 r
.20198 .37584 .20814 .38578 .21734 .38544 .21117 .37562 Metetra
.513 .585 .864 r
.21117 .37562 .21734 .38544 .22657 .38525 .22039 .37555 Metetra
.505 .584 .868 r
.22039 .37555 .22657 .38525 .23585 .38522 .22966 .37562 Metetra
.497 .584 .872 r
.22966 .37562 .23585 .38522 .24516 .38532 .23897 .37582 Metetra
.489 .584 .876 r
.23897 .37582 .24516 .38532 .25452 .38553 .24832 .37613 Metetra
.482 .584 .88 r
.24832 .37613 .25452 .38553 .26393 .38585 .25772 .37655 Metetra
.476 .584 .883 r
.25772 .37655 .26393 .38585 .27339 .38627 .26718 .37705 Metetra
.47 .584 .886 r
.26718 .37705 .27339 .38627 .2829 .38678 .27668 .37764 Metetra
.464 .584 .889 r
.27668 .37764 .2829 .38678 .29246 .38736 .28625 .3783 Metetra
.459 .584 .892 r
.28625 .3783 .29246 .38736 .30208 .38802 .29586 .37902 Metetra
.454 .585 .894 r
.29586 .37902 .30208 .38802 .31176 .38874 .30554 .37981 Metetra
.449 .585 .897 r
.30554 .37981 .31176 .38874 .32149 .38952 .31527 .38065 Metetra
.445 .585 .899 r
.31527 .38065 .32149 .38952 .33128 .39036 .32507 .38154 Metetra
.441 .586 .901 r
.32507 .38154 .33128 .39036 .34114 .39125 .33493 .38248 Metetra
.437 .586 .903 r
.33493 .38248 .34114 .39125 .35106 .39219 .34485 .38347 Metetra
.433 .587 .905 r
.34485 .38347 .35106 .39219 .36104 .39317 .35483 .38449 Metetra
.43 .587 .906 r
.35483 .38449 .36104 .39317 .37108 .39419 .36488 .38556 Metetra
.427 .587 .908 r
.36488 .38556 .37108 .39419 .38119 .39525 .375 .38666 Metetra
.424 .588 .91 r
.375 .38666 .38119 .39525 .39137 .39635 .38518 .38779 Metetra
.421 .588 .911 r
.38518 .38779 .39137 .39635 .40162 .39748 .39544 .38895 Metetra
.418 .589 .912 r
.39544 .38895 .40162 .39748 .41193 .39864 .40576 .39014 Metetra
.416 .589 .914 r
.40576 .39014 .41193 .39864 .42232 .39984 .41615 .39137 Metetra
.649 .699 .883 r
.41615 .39137 .42232 .39984 .43291 .39627 .42676 .38777 Metetra
.77 .738 .823 r
.42676 .38777 .43291 .39627 .44367 .38793 .43755 .37935 Metetra
.77 .736 .822 r
.43755 .37935 .44367 .38793 .45443 .3796 .44835 .37093 Metetra
.769 .735 .822 r
.44835 .37093 .45443 .3796 .46521 .37129 .45915 .36253 Metetra
.768 .733 .821 r
.45915 .36253 .46521 .37129 .47599 .36299 .46997 .35415 Metetra
.766 .731 .821 r
.46997 .35415 .47599 .36299 .48679 .35472 .48079 .34579 Metetra
.765 .73 .82 r
.48079 .34579 .48679 .35472 .49759 .34647 .49163 .33744 Metetra
.764 .728 .819 r
.49163 .33744 .49759 .34647 .50841 .33825 .50248 .32912 Metetra
.763 .726 .819 r
.50248 .32912 .50841 .33825 .51924 .33006 .51334 .32082 Metetra
.761 .724 .818 r
.51334 .32082 .51924 .33006 .53008 .3219 .52421 .31255 Metetra
.759 .721 .817 r
.52421 .31255 .53008 .3219 .54094 .31377 .53509 .30432 Metetra
.758 .719 .816 r
.53509 .30432 .54094 .31377 .5518 .30569 .54598 .29612 Metetra
.756 .717 .816 r
.54598 .29612 .5518 .30569 .56269 .29766 .55689 .28796 Metetra
.754 .714 .815 r
.55689 .28796 .56269 .29766 .57358 .28968 .56781 .27985 Metetra
.751 .711 .814 r
.56781 .27985 .57358 .28968 .58449 .28175 .57875 .2718 Metetra
.749 .708 .813 r
.57875 .2718 .58449 .28175 .59542 .2739 .5897 .26381 Metetra
.746 .705 .812 r
.5897 .26381 .59542 .2739 .60636 .26612 .60066 .25588 Metetra
.743 .701 .811 r
.60066 .25588 .60636 .26612 .61732 .25842 .61165 .24804 Metetra
.74 .697 .81 r
.61165 .24804 .61732 .25842 .62831 .25082 .62265 .24028 Metetra
.737 .693 .81 r
.62265 .24028 .62831 .25082 .63931 .24333 .63367 .23263 Metetra
.733 .689 .809 r
.63367 .23263 .63931 .24333 .65034 .23596 .64472 .22509 Metetra
.728 .685 .808 r
.64472 .22509 .65034 .23596 .66139 .22874 .65579 .21769 Metetra
.724 .68 .807 r
.65579 .21769 .66139 .22874 .67247 .22166 .66688 .21044 Metetra
.718 .675 .806 r
.66688 .21044 .67247 .22166 .68358 .21476 .67801 .20336 Metetra
.713 .669 .806 r
.67801 .20336 .68358 .21476 .69473 .20806 .68917 .19648 Metetra
.706 .664 .805 r
.68917 .19648 .69473 .20806 .70592 .20158 .70037 .18982 Metetra
.699 .658 .805 r
.70037 .18982 .70592 .20158 .71715 .19534 .71161 .18341 Metetra
.692 .652 .805 r
.71161 .18341 .71715 .19534 .72843 .18937 .72289 .17728 Metetra
.684 .645 .805 r
.72289 .17728 .72843 .18937 .73976 .18369 .73423 .17145 Metetra
.675 .639 .806 r
.73423 .17145 .73976 .18369 .75114 .17833 .74563 .16596 Metetra
.666 .632 .807 r
.74563 .16596 .75114 .17833 .7626 .1733 .75709 .16082 Metetra
.634 .615 .813 r
.10498 .38115 .11109 .39189 .12018 .38881 .11408 .37807 Metetra
.621 .609 .817 r
.11408 .37807 .12018 .38881 .12925 .38611 .12315 .37539 Metetra
.608 .604 .822 r
.12315 .37539 .12925 .38611 .13832 .38378 .13221 .37311 Metetra
.595 .6 .827 r
.13221 .37311 .13832 .38378 .14738 .38179 .14126 .3712 Metetra
.582 .596 .832 r
.14126 .3712 .14738 .38179 .15644 .38013 .15031 .36965 Metetra
.569 .593 .837 r
.15031 .36965 .15644 .38013 .16551 .37877 .15937 .3684 Metetra
.557 .59 .843 r
.15937 .3684 .16551 .37877 .1746 .37769 .16844 .36745 Metetra
.545 .588 .848 r
.16844 .36745 .1746 .37769 .1837 .37686 .17753 .36674 Metetra
.534 .587 .854 r
.17753 .36674 .1837 .37686 .19283 .37625 .18664 .36627 Metetra
.523 .585 .859 r
.18664 .36627 .19283 .37625 .20198 .37584 .19578 .36599 Metetra
.514 .584 .864 r
.19578 .36599 .20198 .37584 .21117 .37562 .20496 .36589 Metetra
.504 .584 .868 r
.20496 .36589 .21117 .37562 .22039 .37555 .21417 .36594 Metetra
.496 .584 .872 r
.21417 .36594 .22039 .37555 .22966 .37562 .22343 .36612 Metetra
.488 .583 .877 r
.22343 .36612 .22966 .37562 .23897 .37582 .23273 .36643 Metetra
.48 .583 .88 r
.23273 .36643 .23897 .37582 .24832 .37613 .24208 .36684 Metetra
.474 .584 .884 r
.24208 .36684 .24832 .37613 .25772 .37655 .25147 .36735 Metetra
.467 .584 .887 r
.25147 .36735 .25772 .37655 .26718 .37705 .26092 .36794 Metetra
.461 .584 .89 r
.26092 .36794 .26718 .37705 .27668 .37764 .27043 .36861 Metetra
.456 .584 .893 r
.27043 .36861 .27668 .37764 .28625 .3783 .27998 .36934 Metetra
.451 .585 .896 r
.27998 .36934 .28625 .3783 .29586 .37902 .2896 .37013 Metetra
.446 .585 .898 r
.2896 .37013 .29586 .37902 .30554 .37981 .29928 .37098 Metetra
.441 .586 .901 r
.29928 .37098 .30554 .37981 .31527 .38065 .30901 .37188 Metetra
.437 .586 .903 r
.30901 .37188 .31527 .38065 .32507 .38154 .31881 .37283 Metetra
.433 .586 .905 r
.31881 .37283 .32507 .38154 .33493 .38248 .32867 .37382 Metetra
.429 .587 .907 r
.32867 .37382 .33493 .38248 .34485 .38347 .33859 .37485 Metetra
.426 .587 .908 r
.33859 .37485 .34485 .38347 .35483 .38449 .34858 .37592 Metetra
.423 .588 .91 r
.34858 .37592 .35483 .38449 .36488 .38556 .35864 .37702 Metetra
.42 .588 .911 r
.35864 .37702 .36488 .38556 .375 .38666 .36876 .37815 Metetra
.417 .589 .913 r
.36876 .37815 .375 .38666 .38518 .38779 .37895 .37932 Metetra
.414 .589 .914 r
.37895 .37932 .38518 .38779 .39544 .38895 .38921 .38051 Metetra
.412 .59 .916 r
.38921 .38051 .39544 .38895 .40576 .39014 .39954 .38173 Metetra
.409 .59 .917 r
.39954 .38173 .40576 .39014 .41615 .39137 .40994 .38297 Metetra
.649 .702 .886 r
.40994 .38297 .41615 .39137 .42676 .38777 .42058 .37935 Metetra
.773 .741 .824 r
.42058 .37935 .42676 .38777 .43755 .37935 .4314 .37085 Metetra
.772 .74 .824 r
.4314 .37085 .43755 .37935 .44835 .37093 .44222 .36235 Metetra
.771 .739 .823 r
.44222 .36235 .44835 .37093 .45915 .36253 .45306 .35387 Metetra
.77 .737 .823 r
.45306 .35387 .45915 .36253 .46997 .35415 .46391 .3454 Metetra
.769 .735 .822 r
.46391 .3454 .46997 .35415 .48079 .34579 .47476 .33694 Metetra
.768 .734 .821 r
.47476 .33694 .48079 .34579 .49163 .33744 .48563 .3285 Metetra
.767 .732 .821 r
.48563 .3285 .49163 .33744 .50248 .32912 .49651 .32008 Metetra
.765 .73 .82 r
.49651 .32008 .50248 .32912 .51334 .32082 .5074 .31168 Metetra
.764 .728 .819 r
.5074 .31168 .51334 .32082 .52421 .31255 .5183 .30331 Metetra
.763 .726 .819 r
.5183 .30331 .52421 .31255 .53509 .30432 .52921 .29496 Metetra
.761 .724 .818 r
.52921 .29496 .53509 .30432 .54598 .29612 .54013 .28665 Metetra
.759 .721 .817 r
.54013 .28665 .54598 .29612 .55689 .28796 .55106 .27837 Metetra
.757 .718 .816 r
.55106 .27837 .55689 .28796 .56781 .27985 .56201 .27014 Metetra
.755 .716 .815 r
.56201 .27014 .56781 .27985 .57875 .2718 .57297 .26195 Metetra
.753 .713 .814 r
.57297 .26195 .57875 .2718 .5897 .26381 .58395 .25382 Metetra
.75 .709 .813 r
.58395 .25382 .5897 .26381 .60066 .25588 .59494 .24575 Metetra
.747 .706 .813 r
.59494 .24575 .60066 .25588 .61165 .24804 .60594 .23775 Metetra
.744 .702 .812 r
.60594 .23775 .61165 .24804 .62265 .24028 .61697 .22984 Metetra
.741 .698 .811 r
.61697 .22984 .62265 .24028 .63367 .23263 .62801 .22202 Metetra
.737 .694 .81 r
.62801 .22202 .63367 .23263 .64472 .22509 .63907 .21431 Metetra
.733 .689 .809 r
.63907 .21431 .64472 .22509 .65579 .21769 .65016 .20673 Metetra
.728 .684 .808 r
.65016 .20673 .65579 .21769 .66688 .21044 .66127 .19929 Metetra
.723 .679 .807 r
.66127 .19929 .66688 .21044 .67801 .20336 .67241 .19202 Metetra
.717 .674 .806 r
.67241 .19202 .67801 .20336 .68917 .19648 .68359 .18495 Metetra
.711 .668 .806 r
.68359 .18495 .68917 .19648 .70037 .18982 .69479 .1781 Metetra
.704 .661 .805 r
.69479 .1781 .70037 .18982 .71161 .18341 .70604 .1715 Metetra
.696 .655 .805 r
.70604 .1715 .71161 .18341 .72289 .17728 .71734 .16519 Metetra
.687 .648 .805 r
.71734 .16519 .72289 .17728 .73423 .17145 .72868 .1592 Metetra
.678 .641 .806 r
.72868 .1592 .73423 .17145 .74563 .16596 .74009 .15356 Metetra
.668 .634 .807 r
.74009 .15356 .74563 .16596 .75709 .16082 .75156 .1483 Metetra
.634 .614 .813 r
.09886 .37037 .10498 .38115 .11408 .37807 .10795 .36728 Metetra
.619 .608 .818 r
.10795 .36728 .11408 .37807 .12315 .37539 .11702 .36464 Metetra
.605 .603 .823 r
.11702 .36464 .12315 .37539 .13221 .37311 .12608 .36243 Metetra
.59 .598 .828 r
.12608 .36243 .13221 .37311 .14126 .3712 .13512 .36063 Metetra
.576 .594 .834 r
.13512 .36063 .14126 .3712 .15031 .36965 .14415 .35919 Metetra
.562 .591 .84 r
.14415 .35919 .15031 .36965 .15937 .3684 .15319 .35808 Metetra
.549 .589 .846 r
.15319 .35808 .15937 .3684 .16844 .36745 .16225 .35727 Metetra
.537 .587 .852 r
.16225 .35727 .16844 .36745 .17753 .36674 .17132 .35671 Metetra
.525 .585 .858 r
.17132 .35671 .17753 .36674 .18664 .36627 .18042 .35638 Metetra
.514 .584 .863 r
.18042 .35638 .18664 .36627 .19578 .36599 .18954 .35624 Metetra
.504 .584 .868 r
.18954 .35624 .19578 .36599 .20496 .36589 .19871 .35627 Metetra
.495 .583 .873 r
.19871 .35627 .20496 .36589 .21417 .36594 .20791 .35644 Metetra
.486 .583 .877 r
.20791 .35644 .21417 .36594 .22343 .36612 .21715 .35675 Metetra
.478 .583 .881 r
.21715 .35675 .22343 .36612 .23273 .36643 .22645 .35716 Metetra
.471 .583 .885 r
.22645 .35716 .23273 .36643 .24208 .36684 .23579 .35768 Metetra
.464 .584 .889 r
.23579 .35768 .24208 .36684 .25147 .36735 .24518 .35827 Metetra
.458 .584 .892 r
.24518 .35827 .25147 .36735 .26092 .36794 .25462 .35895 Metetra
.452 .584 .895 r
.25462 .35895 .26092 .36794 .27043 .36861 .26412 .3597 Metetra
.447 .585 .898 r
.26412 .3597 .27043 .36861 .27998 .36934 .27368 .3605 Metetra
.442 .585 .9 r
.27368 .3605 .27998 .36934 .2896 .37013 .28329 .36136 Metetra
.437 .586 .903 r
.28329 .36136 .2896 .37013 .29928 .37098 .29297 .36227 Metetra
.433 .586 .905 r
.29297 .36227 .29928 .37098 .30901 .37188 .3027 .36323 Metetra
.429 .587 .907 r
.3027 .36323 .30901 .37188 .31881 .37283 .3125 .36423 Metetra
.425 .587 .909 r
.3125 .36423 .31881 .37283 .32867 .37382 .32237 .36526 Metetra
.422 .588 .91 r
.32237 .36526 .32867 .37382 .33859 .37485 .33229 .36634 Metetra
.418 .588 .912 r
.33229 .36634 .33859 .37485 .34858 .37592 .34229 .36744 Metetra
.415 .589 .914 r
.34229 .36744 .34858 .37592 .35864 .37702 .35235 .36858 Metetra
.413 .589 .915 r
.35235 .36858 .35864 .37702 .36876 .37815 .36248 .36974 Metetra
.41 .59 .916 r
.36248 .36974 .36876 .37815 .37895 .37932 .37267 .37093 Metetra
.407 .59 .918 r
.37267 .37093 .37895 .37932 .38921 .38051 .38294 .37215 Metetra
.405 .591 .919 r
.38294 .37215 .38921 .38051 .39954 .38173 .39328 .3734 Metetra
.403 .591 .92 r
.39328 .3734 .39954 .38173 .40994 .38297 .40369 .37466 Metetra
.649 .706 .889 r
.40369 .37466 .40994 .38297 .42058 .37935 .41435 .37101 Metetra
.775 .745 .826 r
.41435 .37101 .42058 .37935 .4314 .37085 .4252 .36243 Metetra
.774 .744 .825 r
.4252 .36243 .4314 .37085 .44222 .36235 .43606 .35386 Metetra
.774 .743 .825 r
.43606 .35386 .44222 .36235 .45306 .35387 .44693 .34529 Metetra
.773 .741 .824 r
.44693 .34529 .45306 .35387 .46391 .3454 .45781 .33674 Metetra
.772 .74 .823 r
.45781 .33674 .46391 .3454 .47476 .33694 .4687 .32819 Metetra
.771 .738 .823 r
.4687 .32819 .47476 .33694 .48563 .3285 .47959 .31966 Metetra
.77 .736 .822 r
.47959 .31966 .48563 .3285 .49651 .32008 .4905 .31115 Metetra
.768 .734 .822 r
.4905 .31115 .49651 .32008 .5074 .31168 .50142 .30265 Metetra
.767 .732 .821 r
.50142 .30265 .5074 .31168 .5183 .30331 .51235 .29417 Metetra
.766 .73 .82 r
.51235 .29417 .5183 .30331 .52921 .29496 .52329 .28572 Metetra
.764 .728 .819 r
.52329 .28572 .52921 .29496 .54013 .28665 .53424 .27729 Metetra
.763 .726 .819 r
.53424 .27729 .54013 .28665 .55106 .27837 .5452 .2689 Metetra
.761 .723 .818 r
.5452 .2689 .55106 .27837 .56201 .27014 .55618 .26054 Metetra
.759 .721 .817 r
.55618 .26054 .56201 .27014 .57297 .26195 .56717 .25222 Metetra
.757 .718 .816 r
.56717 .25222 .57297 .26195 .58395 .25382 .57817 .24395 Metetra
.754 .715 .815 r
.57817 .24395 .58395 .25382 .59494 .24575 .58918 .23574 Metetra
.752 .711 .814 r
.58918 .23574 .59494 .24575 .60594 .23775 .60021 .22759 Metetra
.749 .707 .813 r
.60021 .22759 .60594 .23775 .61697 .22984 .61126 .21951 Metetra
.745 .703 .812 r
.61126 .21951 .61697 .22984 .62801 .22202 .62232 .21152 Metetra
.742 .699 .811 r
.62232 .21152 .62801 .22202 .63907 .21431 .63341 .20364 Metetra
.738 .695 .81 r
.63341 .20364 .63907 .21431 .65016 .20673 .64451 .19587 Metetra
.733 .69 .809 r
.64451 .19587 .65016 .20673 .66127 .19929 .65564 .18824 Metetra
.728 .684 .808 r
.65564 .18824 .66127 .19929 .67241 .19202 .6668 .18077 Metetra
.722 .678 .807 r
.6668 .18077 .67241 .19202 .68359 .18495 .67798 .17349 Metetra
.716 .672 .806 r
.67798 .17349 .68359 .18495 .69479 .1781 .6892 .16643 Metetra
.708 .665 .806 r
.6892 .16643 .69479 .1781 .70604 .1715 .70046 .15962 Metetra
.7 .658 .805 r
.70046 .15962 .70604 .1715 .71734 .16519 .71176 .15311 Metetra
.691 .651 .805 r
.71176 .15311 .71734 .16519 .72868 .1592 .72311 .14694 Metetra
.681 .644 .806 r
.72311 .14694 .72868 .1592 .74009 .15356 .73453 .14113 Metetra
.67 .636 .807 r
.73453 .14113 .74009 .15356 .75156 .1483 .746 .13574 Metetra
.633 .614 .813 r
.09271 .35955 .09886 .37037 .10795 .36728 .10181 .35646 Metetra
.617 .607 .818 r
.10181 .35646 .10795 .36728 .11702 .36464 .11087 .35387 Metetra
.601 .601 .824 r
.11087 .35387 .11702 .36464 .12608 .36243 .11991 .35175 Metetra
.585 .597 .83 r
.11991 .35175 .12608 .36243 .13512 .36063 .12894 .35006 Metetra
.569 .592 .837 r
.12894 .35006 .13512 .36063 .14415 .35919 .13796 .34877 Metetra
.554 .589 .844 r
.13796 .34877 .14415 .35919 .15319 .35808 .14698 .34782 Metetra
.54 .587 .85 r
.14698 .34782 .15319 .35808 .16225 .35727 .15601 .34717 Metetra
.527 .585 .856 r
.15601 .34717 .16225 .35727 .17132 .35671 .16507 .34677 Metetra
.515 .584 .862 r
.16507 .34677 .17132 .35671 .18042 .35638 .17415 .3466 Metetra
.504 .583 .868 r
.17415 .3466 .18042 .35638 .18954 .35624 .18326 .34661 Metetra
.493 .583 .873 r
.18326 .34661 .18954 .35624 .19871 .35627 .19241 .34678 Metetra
.484 .583 .878 r
.19241 .34678 .19871 .35627 .20791 .35644 .2016 .34708 Metetra
.475 .583 .882 r
.2016 .34708 .20791 .35644 .21715 .35675 .21083 .34751 Metetra
.468 .583 .887 r
.21083 .34751 .21715 .35675 .22645 .35716 .22011 .34803 Metetra
.46 .583 .89 r
.22011 .34803 .22645 .35716 .23579 .35768 .22944 .34865 Metetra
.454 .584 .894 r
.22944 .34865 .23579 .35768 .24518 .35827 .23883 .34934 Metetra
.448 .584 .897 r
.23883 .34934 .24518 .35827 .25462 .35895 .24827 .3501 Metetra
.442 .585 .9 r
.24827 .3501 .25462 .35895 .26412 .3597 .25777 .35092 Metetra
.437 .586 .902 r
.25777 .35092 .26412 .3597 .27368 .3605 .26732 .35179 Metetra
.432 .586 .905 r
.26732 .35179 .27368 .3605 .28329 .36136 .27693 .35272 Metetra
.428 .587 .907 r
.27693 .35272 .28329 .36136 .29297 .36227 .28661 .35369 Metetra
.424 .587 .909 r
.28661 .35369 .29297 .36227 .3027 .36323 .29635 .3547 Metetra
.42 .588 .911 r
.29635 .3547 .3027 .36323 .3125 .36423 .30615 .35574 Metetra
.417 .588 .913 r
.30615 .35574 .3125 .36423 .32237 .36526 .31601 .35682 Metetra
.414 .589 .914 r
.31601 .35682 .32237 .36526 .33229 .36634 .32595 .35793 Metetra
.411 .589 .916 r
.32595 .35793 .33229 .36634 .34229 .36744 .33594 .35907 Metetra
.408 .59 .917 r
.33594 .35907 .34229 .36744 .35235 .36858 .34601 .36024 Metetra
.405 .59 .919 r
.34601 .36024 .35235 .36858 .36248 .36974 .35615 .36143 Metetra
.403 .591 .92 r
.35615 .36143 .36248 .36974 .37267 .37093 .36635 .36265 Metetra
.4 .591 .921 r
.36635 .36265 .37267 .37093 .38294 .37215 .37663 .36389 Metetra
.398 .592 .922 r
.37663 .36389 .38294 .37215 .39328 .3734 .38697 .36516 Metetra
.396 .592 .923 r
.38697 .36516 .39328 .3734 .40369 .37466 .3974 .36644 Metetra
.65 .71 .892 r
.3974 .36644 .40369 .37466 .41435 .37101 .40807 .36276 Metetra
.777 .749 .827 r
.40807 .36276 .41435 .37101 .4252 .36243 .41896 .35411 Metetra
.777 .748 .827 r
.41896 .35411 .4252 .36243 .43606 .35386 .42985 .34546 Metetra
.776 .747 .826 r
.42985 .34546 .43606 .35386 .44693 .34529 .44075 .33681 Metetra
.775 .745 .826 r
.44075 .33681 .44693 .34529 .45781 .33674 .45166 .32817 Metetra
.774 .744 .825 r
.45166 .32817 .45781 .33674 .4687 .32819 .46259 .31954 Metetra
.773 .742 .825 r
.46259 .31954 .4687 .32819 .47959 .31966 .47352 .31093 Metetra
.772 .741 .824 r
.47352 .31093 .47959 .31966 .4905 .31115 .48446 .30232 Metetra
.771 .739 .823 r
.48446 .30232 .4905 .31115 .50142 .30265 .49541 .29372 Metetra
.77 .737 .823 r
.49541 .29372 .50142 .30265 .51235 .29417 .50637 .28515 Metetra
.769 .735 .822 r
.50637 .28515 .51235 .29417 .52329 .28572 .51734 .27659 Metetra
.768 .733 .821 r
.51734 .27659 .52329 .28572 .53424 .27729 .52832 .26805 Metetra
.766 .731 .82 r
.52832 .26805 .53424 .27729 .5452 .2689 .53931 .25954 Metetra
.764 .728 .819 r
.53931 .25954 .5452 .2689 .55618 .26054 .55032 .25106 Metetra
.763 .726 .819 r
.55032 .25106 .55618 .26054 .56717 .25222 .56133 .24262 Metetra
.761 .723 .818 r
.56133 .24262 .56717 .25222 .57817 .24395 .57236 .23422 Metetra
.758 .72 .817 r
.57236 .23422 .57817 .24395 .58918 .23574 .5834 .22586 Metetra
.756 .717 .816 r
.5834 .22586 .58918 .23574 .60021 .22759 .59446 .21756 Metetra
.753 .713 .814 r
.59446 .21756 .60021 .22759 .61126 .21951 .60553 .20932 Metetra
.75 .709 .813 r
.60553 .20932 .61126 .21951 .62232 .21152 .61661 .20116 Metetra
.747 .705 .812 r
.61661 .20116 .62232 .21152 .63341 .20364 .62772 .1931 Metetra
.743 .7 .811 r
.62772 .1931 .63341 .20364 .64451 .19587 .63884 .18514 Metetra
.738 .695 .81 r
.63884 .18514 .64451 .19587 .65564 .18824 .64999 .1773 Metetra
.733 .69 .809 r
.64999 .1773 .65564 .18824 .6668 .18077 .66116 .16962 Metetra
.728 .684 .808 r
.66116 .16962 .6668 .18077 .67798 .17349 .67236 .16212 Metetra
.721 .677 .807 r
.67236 .16212 .67798 .17349 .6892 .16643 .68359 .15484 Metetra
.714 .67 .806 r
.68359 .15484 .6892 .16643 .70046 .15962 .69486 .1478 Metetra
.705 .663 .806 r
.69486 .1478 .70046 .15962 .71176 .15311 .70617 .14107 Metetra
.696 .655 .805 r
.70617 .14107 .71176 .15311 .72311 .14694 .71753 .13468 Metetra
.685 .647 .806 r
.71753 .13468 .72311 .14694 .73453 .14113 .72894 .12869 Metetra
.673 .638 .806 r
.72894 .12869 .73453 .14113 .746 .13574 .74043 .12315 Metetra
.632 .613 .814 r
.08654 .34869 .09271 .35955 .10181 .35646 .09564 .34561 Metetra
.614 .606 .819 r
.09564 .34561 .10181 .35646 .11087 .35387 .10469 .34308 Metetra
.596 .6 .826 r
.10469 .34308 .11087 .35387 .11991 .35175 .11372 .34107 Metetra
.578 .594 .833 r
.11372 .34107 .11991 .35175 .12894 .35006 .12273 .33954 Metetra
.561 .59 .84 r
.12273 .33954 .12894 .35006 .13796 .34877 .13172 .33842 Metetra
.544 .587 .848 r
.13172 .33842 .13796 .34877 .14698 .34782 .14072 .33765 Metetra
.529 .585 .855 r
.14072 .33765 .14698 .34782 .15601 .34717 .14973 .33719 Metetra
.516 .583 .861 r
.14973 .33719 .15601 .34717 .16507 .34677 .15876 .33697 Metetra
.503 .583 .868 r
.15876 .33697 .16507 .34677 .17415 .3466 .16782 .33696 Metetra
.492 .582 .874 r
.16782 .33696 .17415 .3466 .18326 .34661 .17692 .33713 Metetra
.481 .582 .879 r
.17692 .33713 .18326 .34661 .19241 .34678 .18605 .33744 Metetra
.472 .582 .884 r
.18605 .33744 .19241 .34678 .2016 .34708 .19523 .33788 Metetra
.464 .583 .888 r
.19523 .33788 .2016 .34708 .21083 .34751 .20445 .33843 Metetra
.456 .583 .892 r
.20445 .33843 .21083 .34751 .22011 .34803 .21372 .33906 Metetra
.449 .584 .896 r
.21372 .33906 .22011 .34803 .22944 .34865 .22305 .33977 Metetra
.443 .585 .899 r
.22305 .33977 .22944 .34865 .23883 .34934 .23243 .34055 Metetra
.437 .585 .902 r
.23243 .34055 .23883 .34934 .24827 .3501 .24186 .34139 Metetra
.432 .586 .905 r
.24186 .34139 .24827 .3501 .25777 .35092 .25136 .34229 Metetra
.427 .587 .907 r
.25136 .34229 .25777 .35092 .26732 .35179 .26091 .34323 Metetra
.423 .587 .91 r
.26091 .34323 .26732 .35179 .27693 .35272 .27052 .34421 Metetra
.419 .588 .912 r
.27052 .34421 .27693 .35272 .28661 .35369 .2802 .34523 Metetra
.415 .588 .913 r
.2802 .34523 .28661 .35369 .29635 .3547 .28994 .34629 Metetra
.411 .589 .915 r
.28994 .34629 .29635 .3547 .30615 .35574 .29974 .34738 Metetra
.408 .59 .917 r
.29974 .34738 .30615 .35574 .31601 .35682 .30961 .3485 Metetra
.405 .59 .918 r
.30961 .3485 .31601 .35682 .32595 .35793 .31955 .34964 Metetra
.403 .591 .92 r
.31955 .34964 .32595 .35793 .33594 .35907 .32955 .35081 Metetra
.4 .591 .921 r
.32955 .35081 .33594 .35907 .34601 .36024 .33963 .35201 Metetra
.398 .592 .922 r
.33963 .35201 .34601 .36024 .35615 .36143 .34977 .35323 Metetra
.395 .592 .923 r
.34977 .35323 .35615 .36143 .36635 .36265 .35998 .35447 Metetra
.393 .593 .924 r
.35998 .35447 .36635 .36265 .37663 .36389 .37027 .35573 Metetra
.391 .593 .925 r
.37027 .35573 .37663 .36389 .38697 .36516 .38062 .35701 Metetra
.389 .593 .926 r
.38062 .35701 .38697 .36516 .3974 .36644 .39105 .35831 Metetra
.65 .715 .895 r
.39105 .35831 .3974 .36644 .40807 .36276 .40175 .35461 Metetra
.78 .753 .829 r
.40175 .35461 .40807 .36276 .41896 .35411 .41267 .34588 Metetra
.779 .752 .828 r
.41267 .34588 .41896 .35411 .42985 .34546 .4236 .33715 Metetra
.778 .751 .828 r
.4236 .33715 .42985 .34546 .44075 .33681 .43453 .32843 Metetra
.778 .75 .827 r
.43453 .32843 .44075 .33681 .45166 .32817 .44548 .31972 Metetra
.777 .748 .827 r
.44548 .31972 .45166 .32817 .46259 .31954 .45643 .311 Metetra
.776 .747 .826 r
.45643 .311 .46259 .31954 .47352 .31093 .4674 .3023 Metetra
.775 .745 .826 r
.4674 .3023 .47352 .31093 .48446 .30232 .47837 .29361 Metetra
.774 .744 .825 r
.47837 .29361 .48446 .30232 .49541 .29372 .48935 .28492 Metetra
.773 .742 .824 r
.48935 .28492 .49541 .29372 .50637 .28515 .50035 .27625 Metetra
.772 .74 .824 r
.50035 .27625 .50637 .28515 .51734 .27659 .51135 .26759 Metetra
.771 .738 .823 r
.51135 .26759 .51734 .27659 .52832 .26805 .52236 .25895 Metetra
.77 .736 .822 r
.52236 .25895 .52832 .26805 .53931 .25954 .53338 .25033 Metetra
.768 .734 .821 r
.53338 .25033 .53931 .25954 .55032 .25106 .54442 .24173 Metetra
.766 .731 .82 r
.54442 .24173 .55032 .25106 .56133 .24262 .55546 .23316 Metetra
.765 .729 .819 r
.55546 .23316 .56133 .24262 .57236 .23422 .56652 .22463 Metetra
.763 .726 .818 r
.56652 .22463 .57236 .23422 .5834 .22586 .57759 .21613 Metetra
.76 .723 .817 r
.57759 .21613 .5834 .22586 .59446 .21756 .58867 .20768 Metetra
.758 .719 .816 r
.58867 .20768 .59446 .21756 .60553 .20932 .59977 .19929 Metetra
.755 .716 .815 r
.59977 .19929 .60553 .20932 .61661 .20116 .61088 .19096 Metetra
.752 .711 .814 r
.61088 .19096 .61661 .20116 .62772 .1931 .62201 .18271 Metetra
.748 .707 .813 r
.62201 .18271 .62772 .1931 .63884 .18514 .63315 .17455 Metetra
.744 .702 .811 r
.63315 .17455 .63884 .18514 .64999 .1773 .64432 .16651 Metetra
.739 .696 .81 r
.64432 .16651 .64999 .1773 .66116 .16962 .6555 .15861 Metetra
.734 .69 .809 r
.6555 .15861 .66116 .16962 .67236 .16212 .66672 .15088 Metetra
.727 .684 .808 r
.66672 .15088 .67236 .16212 .68359 .15484 .67796 .14335 Metetra
.72 .676 .807 r
.67796 .14335 .68359 .15484 .69486 .1478 .68923 .13607 Metetra
.711 .668 .806 r
.68923 .13607 .69486 .1478 .70617 .14107 .70055 .12909 Metetra
.701 .66 .805 r
.70055 .12909 .70617 .14107 .71753 .13468 .71192 .12246 Metetra
.69 .65 .806 r
.71192 .12246 .71753 .13468 .72894 .12869 .72334 .11625 Metetra
.677 .641 .806 r
.72334 .11625 .72894 .12869 .74043 .12315 .73483 .11053 Metetra
.631 .613 .814 r
.08035 .33779 .08654 .34869 .09564 .34561 .08944 .33472 Metetra
.61 .605 .821 r
.08944 .33472 .09564 .34561 .10469 .34308 .09849 .33228 Metetra
.589 .597 .828 r
.09849 .33228 .10469 .34308 .11372 .34107 .10749 .33043 Metetra
.569 .592 .836 r
.10749 .33043 .11372 .34107 .12273 .33954 .11647 .32908 Metetra
.55 .588 .845 r
.11647 .32908 .12273 .33954 .13172 .33842 .12544 .32817 Metetra
.533 .585 .853 r
.12544 .32817 .13172 .33842 .14072 .33765 .13442 .32761 Metetra
.517 .583 .86 r
.13442 .32761 .14072 .33765 .14973 .33719 .1434 .32735 Metetra
.503 .582 .867 r
.1434 .32735 .14973 .33719 .15876 .33697 .15241 .32733 Metetra
.49 .582 .874 r
.15241 .32733 .15876 .33697 .16782 .33696 .16145 .3275 Metetra
.478 .582 .88 r
.16145 .3275 .16782 .33696 .17692 .33713 .17052 .32783 Metetra
.468 .582 .885 r
.17052 .32783 .17692 .33713 .18605 .33744 .17964 .32829 Metetra
.459 .583 .89 r
.17964 .32829 .18605 .33744 .19523 .33788 .1888 .32886 Metetra
.451 .583 .894 r
.1888 .32886 .19523 .33788 .20445 .33843 .19802 .32953 Metetra
.444 .584 .898 r
.19802 .32953 .20445 .33843 .21372 .33906 .20728 .33027 Metetra
.437 .585 .902 r
.20728 .33027 .21372 .33906 .22305 .33977 .2166 .33107 Metetra
.431 .586 .905 r
.2166 .33107 .22305 .33977 .23243 .34055 .22597 .33194 Metetra
.426 .586 .908 r
.22597 .33194 .23243 .34055 .24186 .34139 .2354 .33285 Metetra
.421 .587 .91 r
.2354 .33285 .24186 .34139 .25136 .34229 .2449 .33382 Metetra
.417 .588 .912 r
.2449 .33382 .25136 .34229 .26091 .34323 .25445 .33482 Metetra
.412 .588 .914 r
.25445 .33482 .26091 .34323 .27052 .34421 .26406 .33585 Metetra
.409 .589 .916 r
.26406 .33585 .27052 .34421 .2802 .34523 .27374 .33692 Metetra
.405 .59 .918 r
.27374 .33692 .2802 .34523 .28994 .34629 .28348 .33802 Metetra
.402 .59 .92 r
.28348 .33802 .28994 .34629 .29974 .34738 .29329 .33915 Metetra
.399 .591 .921 r
.29329 .33915 .29974 .34738 .30961 .3485 .30316 .3403 Metetra
.397 .592 .922 r
.30316 .3403 .30961 .3485 .31955 .34964 .3131 .34148 Metetra
.394 .592 .923 r
.3131 .34148 .31955 .34964 .32955 .35081 .32311 .34268 Metetra
.392 .593 .925 r
.32311 .34268 .32955 .35081 .33963 .35201 .33319 .3439 Metetra
.39 .593 .926 r
.33319 .3439 .33963 .35201 .34977 .35323 .34334 .34514 Metetra
.388 .594 .927 r
.34334 .34514 .34977 .35323 .35998 .35447 .35356 .34639 Metetra
.386 .594 .927 r
.35356 .34639 .35998 .35447 .37027 .35573 .36386 .34767 Metetra
.384 .594 .928 r
.36386 .34767 .37027 .35573 .38062 .35701 .37422 .34897 Metetra
.383 .595 .929 r
.37422 .34897 .38062 .35701 .39105 .35831 .38466 .35028 Metetra
.65 .719 .899 r
.38466 .35028 .39105 .35831 .40175 .35461 .39538 .34654 Metetra
.782 .757 .831 r
.39538 .34654 .40175 .35461 .41267 .34588 .40634 .33775 Metetra
.781 .756 .83 r
.40634 .33775 .41267 .34588 .4236 .33715 .4173 .32895 Metetra
.781 .755 .83 r
.4173 .32895 .4236 .33715 .43453 .32843 .42827 .32016 Metetra
.78 .754 .829 r
.42827 .32016 .43453 .32843 .44548 .31972 .43925 .31137 Metetra
.78 .753 .829 r
.43925 .31137 .44548 .31972 .45643 .311 .45024 .30258 Metetra
.779 .751 .828 r
.45024 .30258 .45643 .311 .4674 .3023 .46124 .29379 Metetra
.778 .75 .828 r
.46124 .29379 .4674 .3023 .47837 .29361 .47224 .28501 Metetra
.777 .749 .827 r
.47224 .28501 .47837 .29361 .48935 .28492 .48326 .27624 Metetra
.776 .747 .826 r
.48326 .27624 .48935 .28492 .50035 .27625 .49429 .26748 Metetra
.775 .745 .826 r
.49429 .26748 .50035 .27625 .51135 .26759 .50532 .25872 Metetra
.774 .744 .825 r
.50532 .25872 .51135 .26759 .52236 .25895 .51637 .24998 Metetra
.773 .742 .824 r
.51637 .24998 .52236 .25895 .53338 .25033 .52742 .24125 Metetra
.772 .74 .823 r
.52742 .24125 .53338 .25033 .54442 .24173 .53849 .23255 Metetra
.77 .737 .823 r
.53849 .23255 .54442 .24173 .55546 .23316 .54956 .22386 Metetra
.769 .735 .822 r
.54956 .22386 .55546 .23316 .56652 .22463 .56065 .2152 Metetra
.767 .732 .821 r
.56065 .2152 .56652 .22463 .57759 .21613 .57175 .20657 Metetra
.765 .729 .82 r
.57175 .20657 .57759 .21613 .58867 .20768 .58286 .19797 Metetra
.763 .726 .818 r
.58286 .19797 .58867 .20768 .59977 .19929 .59398 .18942 Metetra
.76 .722 .817 r
.59398 .18942 .59977 .19929 .61088 .19096 .60512 .18093 Metetra
.757 .718 .816 r
.60512 .18093 .61088 .19096 .62201 .18271 .61627 .1725 Metetra
.754 .714 .815 r
.61627 .1725 .62201 .18271 .63315 .17455 .62744 .16415 Metetra
.75 .709 .813 r
.62744 .16415 .63315 .17455 .64432 .16651 .63862 .1559 Metetra
.746 .704 .812 r
.63862 .1559 .64432 .16651 .6555 .15861 .64983 .14777 Metetra
.74 .697 .81 r
.64983 .14777 .6555 .15861 .66672 .15088 .66105 .1398 Metetra
.734 .691 .809 r
.66105 .1398 .66672 .15088 .67796 .14335 .67231 .13201 Metetra
.727 .683 .808 r
.67231 .13201 .67796 .14335 .68923 .13607 .6836 .12446 Metetra
.718 .675 .807 r
.6836 .12446 .68923 .13607 .70055 .12909 .69492 .11719 Metetra
.708 .665 .806 r
.69492 .11719 .70055 .12909 .71192 .12246 .70629 .11029 Metetra
.696 .655 .806 r
.70629 .11029 .71192 .12246 .72334 .11625 .71772 .10383 Metetra
.682 .644 .806 r
.71772 .10383 .72334 .11625 .73483 .11053 .72921 .09789 Metetra
.629 .612 .815 r
.07413 .32685 .08035 .33779 .08944 .33472 .08322 .32381 Metetra
.605 .602 .822 r
.08322 .32381 .08944 .33472 .09849 .33228 .09225 .32149 Metetra
.581 .594 .831 r
.09225 .32149 .09849 .33228 .10749 .33043 .10123 .31983 Metetra
.558 .589 .841 r
.10123 .31983 .10749 .33043 .11647 .32908 .11018 .31872 Metetra
.537 .585 .85 r
.11018 .31872 .11647 .32908 .12544 .32817 .11911 .31806 Metetra
.518 .582 .859 r
.11911 .31806 .12544 .32817 .13442 .32761 .12805 .31775 Metetra
.502 .581 .867 r
.12805 .31775 .13442 .32761 .1434 .32735 .13701 .31771 Metetra
.487 .581 .875 r
.13701 .31771 .1434 .32735 .15241 .32733 .14599 .3179 Metetra
.474 .581 .881 r
.14599 .3179 .15241 .32733 .16145 .3275 .15501 .31825 Metetra
.463 .582 .887 r
.15501 .31825 .16145 .3275 .17052 .32783 .16407 .31875 Metetra
.453 .582 .893 r
.16407 .31875 .17052 .32783 .17964 .32829 .17317 .31935 Metetra
.445 .583 .897 r
.17317 .31935 .17964 .32829 .1888 .32886 .18232 .32005 Metetra
.437 .584 .901 r
.18232 .32005 .1888 .32886 .19802 .32953 .19152 .32083 Metetra
.43 .585 .905 r
.19152 .32083 .19802 .32953 .20728 .33027 .20078 .32167 Metetra
.424 .586 .908 r
.20078 .32167 .20728 .33027 .2166 .33107 .21009 .32257 Metetra
.419 .587 .911 r
.21009 .32257 .2166 .33107 .22597 .33194 .21946 .32351 Metetra
.414 .588 .913 r
.21946 .32351 .22597 .33194 .2354 .33285 .22889 .32449 Metetra
.41 .589 .916 r
.22889 .32449 .2354 .33285 .2449 .33382 .23838 .32551 Metetra
.406 .589 .918 r
.23838 .32551 .2449 .33382 .25445 .33482 .24793 .32657 Metetra
.402 .59 .919 r
.24793 .32657 .25445 .33482 .26406 .33585 .25754 .32765 Metetra
.399 .591 .921 r
.25754 .32765 .26406 .33585 .27374 .33692 .26722 .32876 Metetra
.396 .592 .923 r
.26722 .32876 .27374 .33692 .28348 .33802 .27697 .3299 Metetra
.393 .592 .924 r
.27697 .3299 .28348 .33802 .29329 .33915 .28678 .33106 Metetra
.391 .593 .925 r
.28678 .33106 .29329 .33915 .30316 .3403 .29666 .33224 Metetra
.388 .593 .926 r
.29666 .33224 .30316 .3403 .3131 .34148 .3066 .33344 Metetra
.386 .594 .927 r
.3066 .33344 .3131 .34148 .32311 .34268 .31662 .33466 Metetra
.384 .594 .928 r
.31662 .33466 .32311 .34268 .33319 .3439 .32671 .3359 Metetra
.382 .595 .929 r
.32671 .3359 .33319 .3439 .34334 .34514 .33686 .33715 Metetra
.38 .595 .93 r
.33686 .33715 .34334 .34514 .35356 .34639 .34709 .33843 Metetra
.379 .596 .931 r
.34709 .33843 .35356 .34639 .36386 .34767 .35739 .33972 Metetra
.377 .596 .932 r
.35739 .33972 .36386 .34767 .37422 .34897 .36777 .34102 Metetra
.376 .596 .932 r
.36777 .34102 .37422 .34897 .38466 .35028 .37822 .34234 Metetra
.651 .724 .902 r
.37822 .34234 .38466 .35028 .39538 .34654 .38897 .33858 Metetra
.784 .761 .832 r
.38897 .33858 .39538 .34654 .40634 .33775 .39995 .32971 Metetra
.784 .76 .832 r
.39995 .32971 .40634 .33775 .4173 .32895 .41095 .32085 Metetra
.783 .759 .832 r
.41095 .32085 .4173 .32895 .42827 .32016 .42196 .31199 Metetra
.783 .758 .831 r
.42196 .31199 .42827 .32016 .43925 .31137 .43297 .30313 Metetra
.782 .757 .831 r
.43297 .30313 .43925 .31137 .45024 .30258 .444 .29427 Metetra
.781 .756 .83 r
.444 .29427 .45024 .30258 .46124 .29379 .45503 .28541 Metetra
.781 .755 .83 r
.45503 .28541 .46124 .29379 .47224 .28501 .46607 .27655 Metetra
.78 .754 .829 r
.46607 .27655 .47224 .28501 .48326 .27624 .47712 .26769 Metetra
.779 .752 .829 r
.47712 .26769 .48326 .27624 .49429 .26748 .48818 .25884 Metetra
.779 .751 .828 r
.48818 .25884 .49429 .26748 .50532 .25872 .49925 .25 Metetra
.778 .749 .827 r
.49925 .25 .50532 .25872 .51637 .24998 .51033 .24116 Metetra
.777 .748 .827 r
.51033 .24116 .51637 .24998 .52742 .24125 .52142 .23234 Metetra
.775 .746 .826 r
.52142 .23234 .52742 .24125 .53849 .23255 .53252 .22352 Metetra
.774 .744 .825 r
.53252 .22352 .53849 .23255 .54956 .22386 .54363 .21472 Metetra
.773 .741 .824 r
.54363 .21472 .54956 .22386 .56065 .2152 .55474 .20594 Metetra
.771 .739 .823 r
.55474 .20594 .56065 .2152 .57175 .20657 .56587 .19718 Metetra
.77 .736 .822 r
.56587 .19718 .57175 .20657 .58286 .19797 .57701 .18845 Metetra
.768 .733 .821 r
.57701 .18845 .58286 .19797 .59398 .18942 .58816 .17976 Metetra
.765 .73 .82 r
.58816 .17976 .59398 .18942 .60512 .18093 .59933 .1711 Metetra
.763 .726 .818 r
.59933 .1711 .60512 .18093 .61627 .1725 .6105 .1625 Metetra
.76 .722 .817 r
.6105 .1625 .61627 .1725 .62744 .16415 .6217 .15396 Metetra
.756 .717 .816 r
.6217 .15396 .62744 .16415 .63862 .1559 .6329 .1455 Metetra
.752 .712 .814 r
.6329 .1455 .63862 .1559 .64983 .14777 .64413 .13715 Metetra
.747 .706 .812 r
.64413 .13715 .64983 .14777 .66105 .1398 .65537 .12892 Metetra
.742 .699 .811 r
.65537 .12892 .66105 .1398 .67231 .13201 .66664 .12086 Metetra
.735 .691 .809 r
.66664 .12086 .67231 .13201 .6836 .12446 .67794 .11301 Metetra
.726 .682 .808 r
.67794 .11301 .6836 .12446 .69492 .11719 .68927 .10544 Metetra
.716 .672 .806 r
.68927 .10544 .69492 .11719 .70629 .11029 .70065 .09822 Metetra
.703 .661 .806 r
.70065 .09822 .70629 .11029 .71772 .10383 .71208 .09145 Metetra
.688 .649 .806 r
.71208 .09145 .71772 .10383 .72921 .09789 .72357 .08524 Metetra
.627 .611 .815 r
.06789 .31587 .07413 .32685 .08322 .32381 .07698 .31287 Metetra
.598 .6 .825 r
.07698 .31287 .08322 .32381 .09225 .32149 .08598 .31074 Metetra
.569 .591 .835 r
.08598 .31074 .09225 .32149 .10123 .31983 .09492 .30934 Metetra
.543 .585 .846 r
.09492 .30934 .10123 .31983 .11018 .31872 .10383 .30852 Metetra
.52 .582 .857 r
.10383 .30852 .11018 .31872 .11911 .31806 .11272 .30815 Metetra
.501 .58 .867 r
.11272 .30815 .11911 .31806 .12805 .31775 .12163 .30811 Metetra
.484 .58 .876 r
.12163 .30811 .12805 .31775 .13701 .31771 .13055 .30832 Metetra
.469 .58 .883 r
.13055 .30832 .13701 .31771 .14599 .3179 .13951 .30872 Metetra
.457 .581 .89 r
.13951 .30872 .14599 .3179 .15501 .31825 .1485 .30926 Metetra
.446 .582 .896 r
.1485 .30926 .15501 .31825 .16407 .31875 .15754 .30992 Metetra
.437 .583 .901 r
.15754 .30992 .16407 .31875 .17317 .31935 .16663 .31066 Metetra
.429 .585 .905 r
.16663 .31066 .17317 .31935 .18232 .32005 .17576 .31148 Metetra
.422 .586 .909 r
.17576 .31148 .18232 .32005 .19152 .32083 .18496 .31236 Metetra
.416 .587 .912 r
.18496 .31236 .19152 .32083 .20078 .32167 .1942 .31329 Metetra
.411 .588 .915 r
.1942 .31329 .20078 .32167 .21009 .32257 .20351 .31427 Metetra
.406 .589 .917 r
.20351 .31427 .21009 .32257 .21946 .32351 .21288 .31528 Metetra
.402 .59 .919 r
.21288 .31528 .21946 .32351 .22889 .32449 .22231 .31632 Metetra
.398 .591 .921 r
.22231 .31632 .22889 .32449 .23838 .32551 .23179 .3174 Metetra
.394 .591 .923 r
.23179 .3174 .23838 .32551 .24793 .32657 .24135 .3185 Metetra
.391 .592 .924 r
.24135 .3185 .24793 .32657 .25754 .32765 .25096 .31962 Metetra
.389 .593 .926 r
.25096 .31962 .25754 .32765 .26722 .32876 .26065 .32076 Metetra
.386 .594 .927 r
.26065 .32076 .26722 .32876 .27697 .3299 .2704 .32193 Metetra
.384 .594 .928 r
.2704 .32193 .27697 .3299 .28678 .33106 .28021 .32311 Metetra
.382 .595 .929 r
.28021 .32311 .28678 .33106 .29666 .33224 .2901 .32432 Metetra
.38 .595 .93 r
.2901 .32432 .29666 .33224 .3066 .33344 .30005 .32554 Metetra
.378 .596 .931 r
.30005 .32554 .3066 .33344 .31662 .33466 .31007 .32677 Metetra
.376 .596 .932 r
.31007 .32677 .31662 .33466 .32671 .3359 .32017 .32802 Metetra
.374 .597 .933 r
.32017 .32802 .32671 .3359 .33686 .33715 .33033 .32929 Metetra
.373 .597 .933 r
.33033 .32929 .33686 .33715 .34709 .33843 .34057 .33057 Metetra
.372 .598 .934 r
.34057 .33057 .34709 .33843 .35739 .33972 .35088 .33187 Metetra
.37 .598 .935 r
.35088 .33187 .35739 .33972 .36777 .34102 .36127 .33318 Metetra
.369 .598 .935 r
.36127 .33318 .36777 .34102 .37822 .34234 .37173 .3345 Metetra
.651 .728 .906 r
.37173 .3345 .37822 .34234 .38897 .33858 .3825 .33071 Metetra
.786 .765 .834 r
.3825 .33071 .38897 .33858 .39995 .32971 .39352 .32179 Metetra
.786 .765 .834 r
.39352 .32179 .39995 .32971 .41095 .32085 .40456 .31286 Metetra
.785 .764 .834 r
.40456 .31286 .41095 .32085 .42196 .31199 .4156 .30393 Metetra
.785 .763 .833 r
.4156 .30393 .42196 .31199 .43297 .30313 .42665 .29501 Metetra
.785 .762 .833 r
.42665 .29501 .43297 .30313 .444 .29427 .43771 .28608 Metetra
.784 .761 .832 r
.43771 .28608 .444 .29427 .45503 .28541 .44878 .27714 Metetra
.784 .76 .832 r
.44878 .27714 .45503 .28541 .46607 .27655 .45986 .26821 Metetra
.783 .759 .831 r
.45986 .26821 .46607 .27655 .47712 .26769 .47094 .25928 Metetra
.782 .758 .831 r
.47094 .25928 .47712 .26769 .48818 .25884 .48204 .25035 Metetra
.782 .756 .83 r
.48204 .25035 .48818 .25884 .49925 .25 .49314 .24142 Metetra
.781 .755 .83 r
.49314 .24142 .49925 .25 .51033 .24116 .50426 .2325 Metetra
.78 .754 .829 r
.50426 .2325 .51033 .24116 .52142 .23234 .51538 .22358 Metetra
.779 .752 .828 r
.51538 .22358 .52142 .23234 .53252 .22352 .52651 .21467 Metetra
.778 .75 .828 r
.52651 .21467 .53252 .22352 .54363 .21472 .53765 .20577 Metetra
.777 .748 .827 r
.53765 .20577 .54363 .21472 .55474 .20594 .5488 .19687 Metetra
.776 .746 .826 r
.5488 .19687 .55474 .20594 .56587 .19718 .55996 .188 Metetra
.774 .743 .825 r
.55996 .188 .56587 .19718 .57701 .18845 .57114 .17914 Metetra
.773 .741 .824 r
.57114 .17914 .57701 .18845 .58816 .17976 .58232 .1703 Metetra
.771 .738 .823 r
.58232 .1703 .58816 .17976 .59933 .1711 .59351 .1615 Metetra
.769 .734 .821 r
.59351 .1615 .59933 .1711 .6105 .1625 .60472 .15273 Metetra
.766 .73 .82 r
.60472 .15273 .6105 .1625 .6217 .15396 .61593 .14401 Metetra
.763 .726 .818 r
.61593 .14401 .6217 .15396 .6329 .1455 .62717 .13535 Metetra
.759 .721 .817 r
.62717 .13535 .6329 .1455 .64413 .13715 .63841 .12677 Metetra
.755 .715 .815 r
.63841 .12677 .64413 .13715 .65537 .12892 .64968 .11829 Metetra
.75 .709 .813 r
.64968 .11829 .65537 .12892 .66664 .12086 .66096 .10995 Metetra
.743 .701 .811 r
.66096 .10995 .66664 .12086 .67794 .11301 .67227 .10179 Metetra
.735 .692 .809 r
.67227 .10179 .67794 .11301 .68927 .10544 .68361 .09388 Metetra
.725 .682 .808 r
.68361 .09388 .68927 .10544 .70065 .09822 .69499 .08629 Metetra
.712 .669 .806 r
.69499 .08629 .70065 .09822 .71208 .09145 .70642 .07916 Metetra
.696 .656 .806 r
.70642 .07916 .71208 .09145 .72357 .08524 .71791 .07262 Metetra
.623 .61 .816 r
.06163 .30484 .06789 .31587 .07698 .31287 .0707 .30193 Metetra
.587 .595 .828 r
.0707 .30193 .07698 .31287 .08598 .31074 .07967 .30006 Metetra
.553 .586 .841 r
.07967 .30006 .08598 .31074 .09492 .30934 .08856 .29902 Metetra
.523 .58 .854 r
.08856 .29902 .09492 .30934 .10383 .30852 .09741 .29857 Metetra
.499 .578 .866 r
.09741 .29857 .10383 .30852 .11272 .30815 .10626 .29853 Metetra
.479 .578 .877 r
.10626 .29853 .11272 .30815 .12163 .30811 .11512 .29879 Metetra
.462 .579 .886 r
.11512 .29879 .12163 .30811 .13055 .30832 .12401 .29925 Metetra
.448 .581 .893 r
.12401 .29925 .13055 .30832 .13951 .30872 .13294 .29985 Metetra
.437 .582 .9 r
.13294 .29985 .13951 .30872 .1485 .30926 .14192 .30057 Metetra
.427 .584 .905 r
.14192 .30057 .1485 .30926 .15754 .30992 .15094 .30138 Metetra
.419 .585 .909 r
.15094 .30138 .15754 .30992 .16663 .31066 .16001 .30225 Metetra
.412 .587 .913 r
.16001 .30225 .16663 .31066 .17576 .31148 .16914 .30318 Metetra
.406 .588 .916 r
.16914 .30318 .17576 .31148 .18496 .31236 .17832 .30415 Metetra
.401 .589 .919 r
.17832 .30415 .18496 .31236 .1942 .31329 .18757 .30516 Metetra
.397 .59 .921 r
.18757 .30516 .1942 .31329 .20351 .31427 .19687 .30619 Metetra
.393 .591 .923 r
.19687 .30619 .20351 .31427 .21288 .31528 .20623 .30726 Metetra
.389 .592 .925 r
.20623 .30726 .21288 .31528 .22231 .31632 .21566 .30836 Metetra
.386 .593 .927 r
.21566 .30836 .22231 .31632 .23179 .3174 .22515 .30947 Metetra
.383 .594 .928 r
.22515 .30947 .23179 .3174 .24135 .3185 .2347 .31061 Metetra
.381 .595 .93 r
.2347 .31061 .24135 .3185 .25096 .31962 .24432 .31176 Metetra
.378 .595 .931 r
.24432 .31176 .25096 .31962 .26065 .32076 .25401 .31293 Metetra
.376 .596 .932 r
.25401 .31293 .26065 .32076 .2704 .32193 .26376 .31412 Metetra
.374 .596 .933 r
.26376 .31412 .2704 .32193 .28021 .32311 .27359 .31532 Metetra
.372 .597 .933 r
.27359 .31532 .28021 .32311 .2901 .32432 .28348 .31654 Metetra
.371 .597 .934 r
.28348 .31654 .2901 .32432 .30005 .32554 .29344 .31777 Metetra
.369 .598 .935 r
.29344 .31777 .30005 .32554 .31007 .32677 .30347 .31902 Metetra
.368 .598 .936 r
.30347 .31902 .31007 .32677 .32017 .32802 .31357 .32028 Metetra
.367 .599 .936 r
.31357 .32028 .32017 .32802 .33033 .32929 .32374 .32155 Metetra
.366 .599 .937 r
.32374 .32155 .33033 .32929 .34057 .33057 .33399 .32283 Metetra
.364 .6 .937 r
.33399 .32283 .34057 .33057 .35088 .33187 .34431 .32413 Metetra
.363 .6 .938 r
.34431 .32413 .35088 .33187 .36127 .33318 .35471 .32544 Metetra
.362 .6 .938 r
.35471 .32544 .36127 .33318 .37173 .3345 .36518 .32677 Metetra
.651 .733 .909 r
.36518 .32677 .37173 .3345 .3825 .33071 .37598 .32294 Metetra
.788 .77 .836 r
.37598 .32294 .3825 .33071 .39352 .32179 .38704 .31396 Metetra
.788 .769 .836 r
.38704 .31396 .39352 .32179 .40456 .31286 .39811 .30498 Metetra
.788 .769 .836 r
.39811 .30498 .40456 .31286 .4156 .30393 .40919 .29599 Metetra
.787 .768 .835 r
.40919 .29599 .4156 .30393 .42665 .29501 .42028 .287 Metetra
.787 .767 .835 r
.42028 .287 .42665 .29501 .43771 .28608 .43138 .27801 Metetra
.787 .766 .835 r
.43138 .27801 .43771 .28608 .44878 .27714 .44248 .26901 Metetra
.786 .765 .834 r
.44248 .26901 .44878 .27714 .45986 .26821 .4536 .26001 Metetra
.786 .764 .834 r
.4536 .26001 .45986 .26821 .47094 .25928 .46472 .25101 Metetra
.785 .763 .833 r
.46472 .25101 .47094 .25928 .48204 .25035 .47585 .24201 Metetra
.785 .762 .833 r
.47585 .24201 .48204 .25035 .49314 .24142 .48699 .233 Metetra
.784 .761 .832 r
.48699 .233 .49314 .24142 .50426 .2325 .49814 .224 Metetra
.783 .76 .832 r
.49814 .224 .50426 .2325 .51538 .22358 .5093 .215 Metetra
.783 .758 .831 r
.5093 .215 .51538 .22358 .52651 .21467 .52046 .206 Metetra
.782 .757 .83 r
.52046 .206 .52651 .21467 .53765 .20577 .53164 .197 Metetra
.781 .755 .83 r
.53164 .197 .53765 .20577 .5488 .19687 .54283 .18801 Metetra
.78 .753 .829 r
.54283 .18801 .5488 .19687 .55996 .188 .55402 .17902 Metetra
.779 .751 .828 r
.55402 .17902 .55996 .188 .57114 .17914 .56522 .17005 Metetra
.777 .749 .827 r
.56522 .17005 .57114 .17914 .58232 .1703 .57644 .16109 Metetra
.776 .746 .826 r
.57644 .16109 .58232 .1703 .59351 .1615 .58766 .15215 Metetra
.774 .743 .825 r
.58766 .15215 .59351 .1615 .60472 .15273 .5989 .14323 Metetra
.772 .74 .823 r
.5989 .14323 .60472 .15273 .61593 .14401 .61015 .13434 Metetra
.77 .736 .822 r
.61015 .13434 .61593 .14401 .62717 .13535 .6214 .12549 Metetra
.767 .731 .82 r
.6214 .12549 .62717 .13535 .63841 .12677 .63268 .1167 Metetra
.763 .726 .818 r
.63268 .1167 .63841 .12677 .64968 .11829 .64396 .10798 Metetra
.759 .72 .816 r
.64396 .10798 .64968 .11829 .66096 .10995 .65527 .09936 Metetra
.753 .713 .814 r
.65527 .09936 .66096 .10995 .67227 .10179 .66659 .09088 Metetra
.746 .704 .812 r
.66659 .09088 .67227 .10179 .68361 .09388 .67794 .0826 Metetra
.736 .693 .809 r
.67794 .0826 .68361 .09388 .69499 .08629 .68932 .07461 Metetra
.724 .68 .808 r
.68932 .07461 .69499 .08629 .70642 .07916 .70075 .06704 Metetra
.707 .665 .806 r
.70075 .06704 .70642 .07916 .71791 .07262 .71224 .06007 Metetra
.617 .607 .818 r
.05534 .29378 .06163 .30484 .0707 .30193 .06439 .29102 Metetra
.57 .589 .833 r
.06439 .29102 .0707 .30193 .07967 .30006 .0733 .28956 Metetra
.529 .579 .85 r
.0733 .28956 .07967 .30006 .08856 .29902 .08212 .28899 Metetra
.496 .576 .865 r
.08212 .28899 .08856 .29902 .09741 .29857 .09091 .28898 Metetra
.471 .576 .879 r
.09091 .28898 .09741 .29857 .10626 .29853 .0997 .28931 Metetra
.452 .578 .89 r
.0997 .28931 .10626 .29853 .11512 .29879 .10853 .28987 Metetra
.437 .58 .898 r
.10853 .28987 .11512 .29879 .12401 .29925 .11739 .29057 Metetra
.425 .583 .905 r
.11739 .29057 .12401 .29925 .13294 .29985 .12629 .29137 Metetra
.415 .585 .911 r
.12629 .29137 .13294 .29985 .14192 .30057 .13524 .29224 Metetra
.407 .587 .915 r
.13524 .29224 .14192 .30057 .15094 .30138 .14425 .29317 Metetra
.4 .588 .919 r
.14425 .29317 .15094 .30138 .16001 .30225 .15331 .29415 Metetra
.395 .59 .922 r
.15331 .29415 .16001 .30225 .16914 .30318 .16243 .29516 Metetra
.39 .591 .924 r
.16243 .29516 .16914 .30318 .17832 .30415 .17161 .29621 Metetra
.386 .592 .926 r
.17161 .29621 .17832 .30415 .18757 .30516 .18085 .29727 Metetra
.382 .593 .928 r
.18085 .29727 .18757 .30516 .19687 .30619 .19015 .29837 Metetra
.379 .594 .93 r
.19015 .29837 .19687 .30619 .20623 .30726 .19952 .29948 Metetra
.376 .595 .931 r
.19952 .29948 .20623 .30726 .21566 .30836 .20895 .3006 Metetra
.374 .596 .933 r
.20895 .3006 .21566 .30836 .22515 .30947 .21844 .30175 Metetra
.372 .597 .934 r
.21844 .30175 .22515 .30947 .2347 .31061 .228 .30291 Metetra
.37 .597 .935 r
.228 .30291 .2347 .31061 .24432 .31176 .23762 .30408 Metetra
.368 .598 .935 r
.23762 .30408 .24432 .31176 .25401 .31293 .24731 .30527 Metetra
.366 .599 .936 r
.24731 .30527 .25401 .31293 .26376 .31412 .25707 .30647 Metetra
.365 .599 .937 r
.25707 .30647 .26376 .31412 .27359 .31532 .2669 .30768 Metetra
.363 .6 .938 r
.2669 .30768 .27359 .31532 .28348 .31654 .2768 .30891 Metetra
.362 .6 .938 r
.2768 .30891 .28348 .31654 .29344 .31777 .28677 .31015 Metetra
.361 .6 .939 r
.28677 .31015 .29344 .31777 .30347 .31902 .29681 .3114 Metetra
.36 .601 .939 r
.29681 .3114 .30347 .31902 .31357 .32028 .30692 .31266 Metetra
.359 .601 .94 r
.30692 .31266 .31357 .32028 .32374 .32155 .3171 .31393 Metetra
.358 .601 .94 r
.3171 .31393 .32374 .32155 .33399 .32283 .32736 .31521 Metetra
.357 .602 .94 r
.32736 .31521 .33399 .32283 .34431 .32413 .33769 .31651 Metetra
.356 .602 .941 r
.33769 .31651 .34431 .32413 .35471 .32544 .3481 .31782 Metetra
.356 .602 .941 r
.3481 .31782 .35471 .32544 .36518 .32677 .35859 .31913 Metetra
.652 .738 .913 r
.35859 .31913 .36518 .32677 .37598 .32294 .3694 .31528 Metetra
.79 .774 .838 r
.3694 .31528 .37598 .32294 .38704 .31396 .3805 .30625 Metetra
.79 .774 .838 r
.3805 .30625 .38704 .31396 .39811 .30498 .39161 .29721 Metetra
.79 .773 .838 r
.39161 .29721 .39811 .30498 .40919 .29599 .40273 .28817 Metetra
.79 .773 .838 r
.40273 .28817 .40919 .29599 .42028 .287 .41386 .27912 Metetra
.789 .772 .837 r
.41386 .27912 .42028 .287 .43138 .27801 .42499 .27007 Metetra
.789 .771 .837 r
.42499 .27007 .43138 .27801 .44248 .26901 .43613 .26101 Metetra
.789 .771 .837 r
.43613 .26101 .44248 .26901 .4536 .26001 .44729 .25195 Metetra
.788 .77 .836 r
.44729 .25195 .4536 .26001 .46472 .25101 .45845 .24289 Metetra
.788 .769 .836 r
.45845 .24289 .46472 .25101 .47585 .24201 .46961 .23382 Metetra
.788 .768 .836 r
.46961 .23382 .47585 .24201 .48699 .233 .48079 .22475 Metetra
.787 .767 .835 r
.48079 .22475 .48699 .233 .49814 .224 .49198 .21567 Metetra
.787 .766 .835 r
.49198 .21567 .49814 .224 .5093 .215 .50317 .20659 Metetra
.786 .765 .834 r
.50317 .20659 .5093 .215 .52046 .206 .51438 .19751 Metetra
.785 .764 .833 r
.51438 .19751 .52046 .206 .53164 .197 .52559 .18843 Metetra
.785 .762 .833 r
.52559 .18843 .53164 .197 .54283 .18801 .53681 .17935 Metetra
.784 .761 .832 r
.53681 .17935 .54283 .18801 .55402 .17902 .54804 .17027 Metetra
.783 .759 .831 r
.54804 .17027 .55402 .17902 .56522 .17005 .55928 .1612 Metetra
.782 .757 .83 r
.55928 .1612 .56522 .17005 .57644 .16109 .57053 .15213 Metetra
.781 .755 .83 r
.57053 .15213 .57644 .16109 .58766 .15215 .58179 .14306 Metetra
.78 .753 .828 r
.58179 .14306 .58766 .15215 .5989 .14323 .59305 .13401 Metetra
.778 .75 .827 r
.59305 .13401 .5989 .14323 .61015 .13434 .60433 .12498 Metetra
.776 .747 .826 r
.60433 .12498 .61015 .13434 .6214 .12549 .61562 .11596 Metetra
.774 .743 .824 r
.61562 .11596 .6214 .12549 .63268 .1167 .62692 .10698 Metetra
.771 .738 .823 r
.62692 .10698 .63268 .1167 .64396 .10798 .63823 .09804 Metetra
.768 .733 .82 r
.63823 .09804 .64396 .10798 .65527 .09936 .64956 .08917 Metetra
.763 .726 .818 r
.64956 .08917 .65527 .09936 .66659 .09088 .6609 .08038 Metetra
.758 .718 .815 r
.6609 .08038 .66659 .09088 .67794 .0826 .67226 .07174 Metetra
.75 .708 .813 r
.67226 .07174 .67794 .0826 .68932 .07461 .68365 .0633 Metetra
.738 .695 .81 r
.68365 .0633 .68932 .07461 .70075 .06704 .69507 .05521 Metetra
.721 .678 .808 r
.69507 .05521 .70075 .06704 .71224 .06007 .70655 .04769 Metetra
.606 .602 .821 r
.04903 .28267 .05534 .29378 .06439 .29102 .05804 .28023 Metetra
.539 .578 .842 r
.05804 .28023 .06439 .29102 .0733 .28956 .06684 .27943 Metetra
.492 .571 .864 r
.06684 .27943 .0733 .28956 .08212 .28899 .07557 .27948 Metetra
.459 .573 .882 r
.07557 .27948 .08212 .28899 .09091 .28898 .08429 .27995 Metetra
.437 .577 .895 r
.08429 .27995 .09091 .28898 .0997 .28931 .09303 .28064 Metetra
.421 .581 .905 r
.09303 .28064 .0997 .28931 .10853 .28987 .10182 .28146 Metetra
.409 .584 .913 r
.10182 .28146 .10853 .28987 .11739 .29057 .11065 .28236 Metetra
.399 .587 .918 r
.11065 .28236 .11739 .29057 .12629 .29137 .11953 .28331 Metetra
.392 .589 .922 r
.11953 .28331 .12629 .29137 .13524 .29224 .12847 .28431 Metetra
.386 .591 .926 r
.12847 .28431 .13524 .29224 .14425 .29317 .13747 .28534 Metetra
.381 .593 .928 r
.13747 .28534 .14425 .29317 .15331 .29415 .14653 .28639 Metetra
.377 .594 .93 r
.14653 .28639 .15331 .29415 .16243 .29516 .15564 .28747 Metetra
.373 .595 .932 r
.15564 .28747 .16243 .29516 .17161 .29621 .16482 .28856 Metetra
.37 .597 .934 r
.16482 .28856 .17161 .29621 .18085 .29727 .17406 .28967 Metetra
.368 .597 .935 r
.17406 .28967 .18085 .29727 .19015 .29837 .18336 .29079 Metetra
.366 .598 .936 r
.18336 .29079 .19015 .29837 .19952 .29948 .19273 .29193 Metetra
.364 .599 .937 r
.19273 .29193 .19952 .29948 .20895 .3006 .20216 .29308 Metetra
.362 .6 .938 r
.20216 .29308 .20895 .3006 .21844 .30175 .21166 .29424 Metetra
.36 .6 .939 r
.21166 .29424 .21844 .30175 .228 .30291 .22122 .29541 Metetra
.359 .601 .939 r
.22122 .29541 .228 .30291 .23762 .30408 .23085 .29659 Metetra
.358 .601 .94 r
.23085 .29659 .23762 .30408 .24731 .30527 .24055 .29779 Metetra
.357 .602 .941 r
.24055 .29779 .24731 .30527 .25707 .30647 .25031 .29899 Metetra
.356 .602 .941 r
.25031 .29899 .25707 .30647 .2669 .30768 .26015 .30021 Metetra
.355 .602 .941 r
.26015 .30021 .2669 .30768 .2768 .30891 .27006 .30143 Metetra
.354 .603 .942 r
.27006 .30143 .2768 .30891 .28677 .31015 .28003 .30267 Metetra
.353 .603 .942 r
.28003 .30267 .28677 .31015 .29681 .3114 .29008 .30392 Metetra
.352 .603 .943 r
.29008 .30392 .29681 .3114 .30692 .31266 .3002 .30517 Metetra
.352 .604 .943 r
.3002 .30517 .30692 .31266 .3171 .31393 .3104 .30644 Metetra
.351 .604 .943 r
.3104 .30644 .3171 .31393 .32736 .31521 .32067 .30772 Metetra
.35 .604 .943 r
.32067 .30772 .32736 .31521 .33769 .31651 .33101 .309 Metetra
.35 .604 .944 r
.33101 .309 .33769 .31651 .3481 .31782 .34143 .3103 Metetra
.349 .605 .944 r
.34143 .3103 .3481 .31782 .35859 .31913 .35193 .31161 Metetra
.652 .743 .917 r
.35193 .31161 .35859 .31913 .3694 .31528 .36278 .30773 Metetra
.792 .779 .841 r
.36278 .30773 .3694 .31528 .3805 .30625 .37391 .29865 Metetra
.792 .778 .84 r
.37391 .29865 .3805 .30625 .39161 .29721 .38506 .28956 Metetra
.792 .778 .84 r
.38506 .28956 .39161 .29721 .40273 .28817 .39622 .28047 Metetra
.792 .777 .84 r
.39622 .28047 .40273 .28817 .41386 .27912 .40738 .27137 Metetra
.792 .777 .84 r
.40738 .27137 .41386 .27912 .42499 .27007 .41855 .26226 Metetra
.791 .777 .84 r
.41855 .26226 .42499 .27007 .43613 .26101 .42974 .25315 Metetra
.791 .776 .839 r
.42974 .25315 .43613 .26101 .44729 .25195 .44093 .24404 Metetra
.791 .776 .839 r
.44093 .24404 .44729 .25195 .45845 .24289 .45212 .23491 Metetra
.791 .775 .839 r
.45212 .23491 .45845 .24289 .46961 .23382 .46333 .22579 Metetra
.79 .774 .838 r
.46333 .22579 .46961 .23382 .48079 .22475 .47455 .21665 Metetra
.79 .774 .838 r
.47455 .21665 .48079 .22475 .49198 .21567 .48577 .20751 Metetra
.79 .773 .838 r
.48577 .20751 .49198 .21567 .50317 .20659 .497 .19837 Metetra
.789 .772 .837 r
.497 .19837 .50317 .20659 .51438 .19751 .50824 .18922 Metetra
.789 .771 .837 r
.50824 .18922 .51438 .19751 .52559 .18843 .51949 .18007 Metetra
.789 .77 .836 r
.51949 .18007 .52559 .18843 .53681 .17935 .53075 .17092 Metetra
.788 .769 .836 r
.53075 .17092 .53681 .17935 .54804 .17027 .54202 .16176 Metetra
.787 .768 .835 r
.54202 .16176 .54804 .17027 .55928 .1612 .55329 .1526 Metetra
.787 .766 .835 r
.55329 .1526 .55928 .1612 .57053 .15213 .56458 .14344 Metetra
.786 .765 .834 r
.56458 .14344 .57053 .15213 .58179 .14306 .57587 .13427 Metetra
.785 .763 .833 r
.57587 .13427 .58179 .14306 .59305 .13401 .58718 .12511 Metetra
.784 .761 .832 r
.58718 .12511 .59305 .13401 .60433 .12498 .59849 .11596 Metetra
.783 .758 .831 r
.59849 .11596 .60433 .12498 .61562 .11596 .60981 .10681 Metetra
.781 .755 .829 r
.60981 .10681 .61562 .11596 .62692 .10698 .62114 .09767 Metetra
.779 .752 .828 r
.62114 .09767 .62692 .10698 .63823 .09804 .63248 .08854 Metetra
.777 .747 .826 r
.63248 .08854 .63823 .09804 .64956 .08917 .64384 .07945 Metetra
.774 .742 .824 r
.64384 .07945 .64956 .08917 .6609 .08038 .6552 .0704 Metetra
.77 .735 .821 r
.6552 .0704 .6609 .08038 .67226 .07174 .66658 .06142 Metetra
.764 .727 .818 r
.66658 .06142 .67226 .07174 .68365 .0633 .67798 .05256 Metetra
.755 .715 .814 r
.67798 .05256 .68365 .0633 .69507 .05521 .6894 .04391 Metetra
.741 .698 .81 r
.6894 .04391 .69507 .05521 .70655 .04769 .70086 .03568 Metetra
.575 .587 .828 r
.04269 .27152 .04903 .28267 .05804 .28023 .05158 .26988 Metetra
.481 .561 .86 r
.05158 .26988 .05804 .28023 .06684 .27943 .06022 .27011 Metetra
.437 .568 .888 r
.06022 .27011 .06684 .27943 .07557 .27948 .06885 .27082 Metetra
.413 .577 .906 r
.06885 .27082 .07557 .27948 .08429 .27995 .07751 .27171 Metetra
.397 .584 .916 r
.07751 .27171 .08429 .27995 .09303 .28064 .08622 .27267 Metetra
.386 .588 .923 r
.08622 .27267 .09303 .28064 .10182 .28146 .09498 .27367 Metetra
.378 .592 .928 r
.09498 .27367 .10182 .28146 .11065 .28236 .10379 .2747 Metetra
.372 .594 .932 r
.10379 .2747 .11065 .28236 .11953 .28331 .11267 .27575 Metetra
.368 .596 .934 r
.11267 .27575 .11953 .28331 .12847 .28431 .1216 .27682 Metetra
.364 .598 .936 r
.1216 .27682 .12847 .28431 .13747 .28534 .13059 .2779 Metetra
.361 .599 .938 r
.13059 .2779 .13747 .28534 .14653 .28639 .13965 .279 Metetra
.359 .6 .939 r
.13965 .279 .14653 .28639 .15564 .28747 .14876 .2801 Metetra
.357 .601 .94 r
.14876 .2801 .15564 .28747 .16482 .28856 .15794 .28122 Metetra
.355 .602 .941 r
.15794 .28122 .16482 .28856 .17406 .28967 .16718 .28235 Metetra
.354 .602 .942 r
.16718 .28235 .17406 .28967 .18336 .29079 .17649 .28348 Metetra
.352 .603 .942 r
.17649 .28348 .18336 .29079 .19273 .29193 .18586 .28463 Metetra
.351 .603 .943 r
.18586 .28463 .19273 .29193 .20216 .29308 .1953 .28578 Metetra
.35 .604 .943 r
.1953 .28578 .20216 .29308 .21166 .29424 .2048 .28694 Metetra
.349 .604 .944 r
.2048 .28694 .21166 .29424 .22122 .29541 .21437 .28812 Metetra
.349 .605 .944 r
.21437 .28812 .22122 .29541 .23085 .29659 .22401 .2893 Metetra
.348 .605 .944 r
.22401 .2893 .23085 .29659 .24055 .29779 .23371 .29049 Metetra
.347 .605 .945 r
.23371 .29049 .24055 .29779 .25031 .29899 .24349 .29169 Metetra
.347 .605 .945 r
.24349 .29169 .25031 .29899 .26015 .30021 .25333 .29289 Metetra
.346 .606 .945 r
.25333 .29289 .26015 .30021 .27006 .30143 .26325 .29411 Metetra
.346 .606 .945 r
.26325 .29411 .27006 .30143 .28003 .30267 .27324 .29534 Metetra
.345 .606 .946 r
.27324 .29534 .28003 .30267 .29008 .30392 .2833 .29657 Metetra
.345 .606 .946 r
.2833 .29657 .29008 .30392 .3002 .30517 .29343 .29782 Metetra
.344 .606 .946 r
.29343 .29782 .3002 .30517 .3104 .30644 .30364 .29907 Metetra
.344 .607 .946 r
.30364 .29907 .3104 .30644 .32067 .30772 .31392 .30034 Metetra
.344 .607 .946 r
.31392 .30034 .32067 .30772 .33101 .309 .32427 .30161 Metetra
.343 .607 .947 r
.32427 .30161 .33101 .309 .34143 .3103 .33471 .30289 Metetra
.343 .607 .947 r
.33471 .30289 .34143 .3103 .35193 .31161 .34522 .30419 Metetra
.652 .748 .92 r
.34522 .30419 .35193 .31161 .36278 .30773 .35609 .30028 Metetra
.794 .783 .843 r
.35609 .30028 .36278 .30773 .37391 .29865 .36727 .29115 Metetra
.794 .783 .843 r
.36727 .29115 .37391 .29865 .38506 .28956 .37845 .28202 Metetra
.794 .783 .843 r
.37845 .28202 .38506 .28956 .39622 .28047 .38965 .27288 Metetra
.794 .782 .842 r
.38965 .27288 .39622 .28047 .40738 .27137 .40085 .26374 Metetra
.794 .782 .842 r
.40085 .26374 .40738 .27137 .41855 .26226 .41206 .25459 Metetra
.794 .782 .842 r
.41206 .25459 .41855 .26226 .42974 .25315 .42328 .24543 Metetra
.793 .782 .842 r
.42328 .24543 .42974 .25315 .44093 .24404 .43451 .23626 Metetra
.793 .781 .842 r
.43451 .23626 .44093 .24404 .45212 .23491 .44575 .22709 Metetra
.793 .781 .842 r
.44575 .22709 .45212 .23491 .46333 .22579 .457 .21791 Metetra
.793 .781 .841 r
.457 .21791 .46333 .22579 .47455 .21665 .46825 .20873 Metetra
.793 .78 .841 r
.46825 .20873 .47455 .21665 .48577 .20751 .47951 .19954 Metetra
.793 .78 .841 r
.47951 .19954 .48577 .20751 .497 .19837 .49079 .19034 Metetra
.792 .779 .841 r
.49079 .19034 .497 .19837 .50824 .18922 .50207 .18114 Metetra
.792 .779 .84 r
.50207 .18114 .50824 .18922 .51949 .18007 .51335 .17193 Metetra
.792 .778 .84 r
.51335 .17193 .51949 .18007 .53075 .17092 .52465 .16271 Metetra
.792 .777 .84 r
.52465 .16271 .53075 .17092 .54202 .16176 .53596 .15349 Metetra
.791 .776 .839 r
.53596 .15349 .54202 .16176 .55329 .1526 .54727 .14426 Metetra
.791 .776 .839 r
.54727 .14426 .55329 .1526 .56458 .14344 .55859 .13503 Metetra
.791 .775 .838 r
.55859 .13503 .56458 .14344 .57587 .13427 .56993 .12579 Metetra
.79 .773 .838 r
.56993 .12579 .57587 .13427 .58718 .12511 .58127 .11655 Metetra
.79 .772 .837 r
.58127 .11655 .58718 .12511 .59849 .11596 .59262 .1073 Metetra
.789 .771 .836 r
.59262 .1073 .59849 .11596 .60981 .10681 .60397 .09805 Metetra
.788 .769 .835 r
.60397 .09805 .60981 .10681 .62114 .09767 .61534 .08879 Metetra
.787 .766 .834 r
.61534 .08879 .62114 .09767 .63248 .08854 .62672 .07954 Metetra
.786 .764 .833 r
.62672 .07954 .63248 .08854 .64384 .07945 .6381 .07029 Metetra
.784 .76 .831 r
.6381 .07029 .64384 .07945 .6552 .0704 .6495 .06104 Metetra
.782 .756 .829 r
.6495 .06104 .6552 .0704 .66658 .06142 .6609 .05181 Metetra
.779 .749 .826 r
.6609 .05181 .66658 .06142 .67798 .05256 .67232 .04261 Metetra
.774 .741 .822 r
.67232 .04261 .67798 .05256 .6894 .04391 .68375 .03347 Metetra
.765 .727 .817 r
.68375 .03347 .6894 .04391 .70086 .03568 .6952 .0245 Metetra
.44 .519 .843 r
.03634 .26033 .04269 .27152 .05158 .26988 .0448 .26136 Metetra
.394 .572 .909 r
.0448 .26136 .05158 .26988 .06022 .27011 .05332 .26239 Metetra
.372 .59 .929 r
.05332 .26239 .06022 .27011 .06885 .27082 .0619 .26343 Metetra
.361 .597 .936 r
.0619 .26343 .06885 .27082 .07751 .27171 .07054 .26447 Metetra
.355 .6 .94 r
.07054 .26447 .07751 .27171 .08622 .27267 .07924 .26552 Metetra
.351 .602 .942 r
.07924 .26552 .08622 .27267 .09498 .27367 .08799 .26658 Metetra
.349 .604 .944 r
.08799 .26658 .09498 .27367 .10379 .2747 .0968 .26765 Metetra
.347 .605 .945 r
.0968 .26765 .10379 .2747 .11267 .27575 .10568 .26872 Metetra
.345 .606 .945 r
.10568 .26872 .11267 .27575 .1216 .27682 .11461 .2698 Metetra
.344 .606 .946 r
.11461 .2698 .1216 .27682 .13059 .2779 .12361 .27089 Metetra
.343 .607 .947 r
.12361 .27089 .13059 .2779 .13965 .279 .13267 .27199 Metetra
.342 .607 .947 r
.13267 .27199 .13965 .279 .14876 .2801 .14179 .27309 Metetra
.341 .607 .947 r
.14179 .27309 .14876 .2801 .15794 .28122 .15097 .2742 Metetra
.341 .608 .947 r
.15097 .2742 .15794 .28122 .16718 .28235 .16022 .27532 Metetra
.34 .608 .948 r
.16022 .27532 .16718 .28235 .17649 .28348 .16954 .27644 Metetra
.34 .608 .948 r
.16954 .27644 .17649 .28348 .18586 .28463 .17891 .27758 Metetra
.34 .608 .948 r
.17891 .27758 .18586 .28463 .1953 .28578 .18836 .27872 Metetra
.339 .608 .948 r
.18836 .27872 .1953 .28578 .2048 .28694 .19787 .27987 Metetra
.339 .609 .948 r
.19787 .27987 .2048 .28694 .21437 .28812 .20745 .28103 Metetra
.339 .609 .948 r
.20745 .28103 .21437 .28812 .22401 .2893 .21709 .2822 Metetra
.338 .609 .949 r
.21709 .2822 .22401 .2893 .23371 .29049 .22681 .28337 Metetra
.338 .609 .949 r
.22681 .28337 .23371 .29049 .24349 .29169 .23659 .28456 Metetra
.338 .609 .949 r
.23659 .28456 .24349 .29169 .25333 .29289 .24645 .28575 Metetra
.338 .609 .949 r
.24645 .28575 .25333 .29289 .26325 .29411 .25638 .28695 Metetra
.338 .609 .949 r
.25638 .28695 .26325 .29411 .27324 .29534 .26638 .28816 Metetra
.337 .609 .949 r
.26638 .28816 .27324 .29534 .2833 .29657 .27645 .28938 Metetra
.337 .609 .949 r
.27645 .28938 .2833 .29657 .29343 .29782 .28659 .2906 Metetra
.337 .609 .949 r
.28659 .2906 .29343 .29782 .30364 .29907 .29681 .29184 Metetra
.337 .609 .949 r
.29681 .29184 .30364 .29907 .31392 .30034 .30711 .29308 Metetra
.337 .61 .949 r
.30711 .29308 .31392 .30034 .32427 .30161 .31748 .29434 Metetra
.337 .61 .949 r
.31748 .29434 .32427 .30161 .33471 .30289 .32792 .2956 Metetra
.337 .61 .949 r
.32792 .2956 .33471 .30289 .34522 .30419 .33845 .29687 Metetra
.652 .753 .924 r
.33845 .29687 .34522 .30419 .35609 .30028 .34934 .29294 Metetra
.796 .788 .845 r
.34934 .29294 .35609 .30028 .36727 .29115 .36056 .28377 Metetra
.796 .788 .845 r
.36056 .28377 .36727 .29115 .37845 .28202 .37179 .2746 Metetra
.796 .788 .845 r
.37179 .2746 .37845 .28202 .38965 .27288 .38302 .26542 Metetra
.796 .787 .845 r
.38302 .26542 .38965 .27288 .40085 .26374 .39427 .25624 Metetra
.796 .787 .845 r
.39427 .25624 .40085 .26374 .41206 .25459 .40552 .24704 Metetra
.796 .787 .845 r
.40552 .24704 .41206 .25459 .42328 .24543 .41678 .23785 Metetra
.796 .787 .845 r
.41678 .23785 .42328 .24543 .43451 .23626 .42805 .22864 Metetra
.796 .787 .845 r
.42805 .22864 .43451 .23626 .44575 .22709 .43932 .21943 Metetra
.795 .787 .845 r
.43932 .21943 .44575 .22709 .457 .21791 .45061 .21021 Metetra
.795 .787 .845 r
.45061 .21021 .457 .21791 .46825 .20873 .46191 .20098 Metetra
.795 .787 .845 r
.46191 .20098 .46825 .20873 .47951 .19954 .47321 .19175 Metetra
.795 .786 .844 r
.47321 .19175 .47951 .19954 .49079 .19034 .48452 .1825 Metetra
.795 .786 .844 r
.48452 .1825 .49079 .19034 .50207 .18114 .49584 .17326 Metetra
.795 .786 .844 r
.49584 .17326 .50207 .18114 .51335 .17193 .50717 .164 Metetra
.795 .786 .844 r
.50717 .164 .51335 .17193 .52465 .16271 .51851 .15474 Metetra
.795 .786 .844 r
.51851 .15474 .52465 .16271 .53596 .15349 .52985 .14547 Metetra
.795 .785 .844 r
.52985 .14547 .53596 .15349 .54727 .14426 .54121 .13619 Metetra
.795 .785 .844 r
.54121 .13619 .54727 .14426 .55859 .13503 .55257 .12691 Metetra
.795 .785 .844 r
.55257 .12691 .55859 .13503 .56993 .12579 .56394 .11762 Metetra
.795 .784 .843 r
.56394 .11762 .56993 .12579 .58127 .11655 .57532 .10832 Metetra
.794 .784 .843 r
.57532 .10832 .58127 .11655 .59262 .1073 .58671 .09902 Metetra
.794 .783 .843 r
.58671 .09902 .59262 .1073 .60397 .09805 .59811 .08971 Metetra
.794 .783 .842 r
.59811 .08971 .60397 .09805 .61534 .08879 .60952 .08039 Metetra
.794 .782 .842 r
.60952 .08039 .61534 .08879 .62672 .07954 .62093 .07106 Metetra
.793 .781 .842 r
.62093 .07106 .62672 .07954 .6381 .07029 .63235 .06173 Metetra
.793 .78 .841 r
.63235 .06173 .6381 .07029 .6495 .06104 .64379 .05239 Metetra
.792 .778 .84 r
.64379 .05239 .6495 .06104 .6609 .05181 .65523 .04304 Metetra
.791 .776 .839 r
.65523 .04304 .6609 .05181 .67232 .04261 .66668 .03369 Metetra
.79 .772 .837 r
.66668 .03369 .67232 .04261 .68375 .03347 .67814 .02433 Metetra
.788 .767 .834 r
.67814 .02433 .68375 .03347 .6952 .0245 .68961 .01496 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 233.562},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GQ000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo2Goo00IcW248000002U:Li`4Ool015[F248003W>VWoo003oOol9Ool01RU:>Lioogoo>LhYBP=o
o`06HaPHaW>LLi`@Q5:DVGoo003oOol9Ool00`Q2Oomoo`02Ool01P00Oomoogoo8@QBU09oo`03DY@H
aWoo09Qoo`00ogoo2Goo00<007>LOol00Woo00D007ooOomoo`0000Aoo`03001oogoo09Moo`00ogoo
2Goo00H002U:LiaoocW>:DX3Ool00`00Oomoo`02Ool00`00Oomoo`2GOol00?moo`Uoo`0648@icP00
000YBW>L0goo00<007ooOol00Woo00<007ooOol0Ugoo003oOol9Ool00d8@<Haoo`06Ool01R48DYAo
ogooDY@Q29Uoo`00ogoo2Woo00<HaS6<JeX01Goo00IS61S6LiacW1S6HaPDOol20023Ool00?moo`]o
o`04>Lh8@P0048@4Ool015[F2488@V<H4Woo0`0000=oo`00Ool0PWoo003oOolWOol20004Ool20022
Ool00?moobAoo`<000Ioo`03001oo`00085oo`00ogoo8Goo0`002Goo00<007oo0000PGoo003oOolO
Ool2000<Ool01000Oomoo`00P7oo003oOolLOol3000=Ool20003Ool00`00Oomoo`1mOol00?mooaYo
o`8000moo`03001W6P0000=oo`03001oogoo07eoo`00ogoo5goo10003goo00<006LJIaX00P000goo
00<007ooOol0O7oo003oOolEOol20004Ool00`00Oomoo`0;Ool01000IaYW6VLJ0P0017oo00<007oo
Ool0Ngoo003oOolBOol3000BOol20004IaX30003Ool00`00Oomoo`1kOol00?moo`moo`<001Aoo`04
001W6VLJ0003IaX30004Ool00`00Oomoo`1jOol00?moo`eoo`8001Ioo`03001W6VLJ009W6P07001W
6P00H_X006;j00000goo00<007ooOol0NWoo003oOol:Ool3000FOol20005IaX20002H_X00`00H_X0
0004Ool00`00Oomoo`1iOol00?moo`Qoo`8001Qoo`03001W6P0000AW6P03001RnP00009RnP04001R
nV;j0002Ool00`00Ool0001jOol00?moo`Eoo`<001Uoo`05001W6VLJIaX00002IaX02000H_YRnV;j
001RnP00H_X20004Ool00`00Oomoo`1hOol00?moo`=oo`8001]oo`03001W6VLJ009W6P03001W6P00
00ARnP04001RnP000002G]T00`00Oomoo`02Ool00`00Oomoo`1gOol00?moo`<00003Ool007oo01Qo
o`8000EW6P8000ERnP03001RnP0000ANf@03001oogoo009oo`03001oogoo07Ioo`00o7oo0`007Goo
00<006LJ000016LJ00<006;j00001F;j0`0015kI00<007ooOol00Woo00<007ooOol0MWoo003jOol2
000OOol01@00IaYW6VLJ00000VLJ00D006;jH_YRnP00009RnP800003H]X0000000ANf@8000Aoo`03
001oogoo07Eoo`00mgoo0`0087oo00<006LJIaX00VLJ00<006LJ000016;j00<006;j000016;J00<0
05kIG]T00P0000=N^@00Ool017oo00<007ooOol0M7oo003eOol2000ROol00`00IaYW6P03IaX20006
H_X00`00H]YRfP03H]X00`00G]T00004G[T00`00Oomoo`02Ool00`00Oomoo`1dOol00?9oo`<002=o
o`03001W6P0000=W6P03001W6P0000ERnP8000ERfP8000EN^@03001oogoo00=oo`03001oogoo07=o
o`00l7oo0P009Goo00L006LJIaYW6P00IaX00003IaX01@00H_YRnV;j00000V;j00<006;JH]X01000
1Eji00<007ooOol017oo00<007ooOol0LWoo003]Ool3000VOol00`00IaYW6P02IaX20005IaX00`00
H_X00003H_X00`00H]X00002G]T00`00G]T00004G[T20005Ool00`00Oomoo`1bOol00>Yoo`<002Mo
o`8000AW6P03001W6P0000EW6P8000ERnP07001NfEkIG]T005kI00000Uji0P0000=J^@00Ool01Goo
00<007ooOol0LGoo003XOol20002Ool00`00Oomoo`0TOol00`00IaX00003IaX01@00IaYW6VLJ0000
0VLJ0P0000=RnP00H_X00f;j0P000ekI00D005kI001N^@0000AJ^@03001oogoo00Aoo`03001oogoo
071oo`00iGoo0`00:Woo00L006LJIaYW6P00IaX00004IaX00`00IaX00004H_X01000H_YRnP000UkJ
00D005kIG]T005kI008000EJ^@03001oogoo00Aoo`03001oogoo071oo`00/7oo0P0000<8@WooOol0
0Woo00AJePQ2000icRQoo`8002aoo`03001W6VLJ009W6P8000EW6P8000ERnP03001RnP0000ANfP06
001Nf@00001N^@001EZi00<007ooOol01Goo00<007ooOol0Kgoo002aOol00`00Oomoo`02Ool01V<H
6<IcW7>L48ABU2Aoo`<002aoo`8000AW6P03001W6P0000AW6P03001RnP0000ERnP8000ENfP03001N
f@0000=N^@03001J^EZi009J^@8000Moo`03001oogoo06ioo`00[Goo1P000goo00HQ25:DOomooe:D
6<HROol2000]Ool200000fLj001W6P02IaX01@00IaYW6VLJ00000VLJ00D006;jH_YRnP00009RnP80
0003H]X005kJ00ANfP<000AN^@06001J^EZi001JV@001Woo0P00L7oo002]Ool01CW>DYAoogoo0000
17oo00<007ooOol00Woo00<007ooOol07Goo0`00;Woo00<006LjIcX00VLj00<006LJ000016LJ00<0
06LJ000016;j00<006;j000016;J00<005kJG]X00P0000ANf@00G[T000=N^@03001J^@0000=JV@03
001oogoo00Eoo`03001oogoo06eoo`00[Goo00EcW1S6Liaoo`0000Aoo`03001oogoo009oo`03001o
ogoo01Yoo`<0031oo`03001W>VLj00AW>P03001W6VLJ00AW6P03001RnV;j00ARnP03001RfV;J00=R
fP03001NfP0000ANf@8000=N^@8000EJV@03001oogoo00Aoo`03001oogoo06eoo`00[Woo00ABU36<
Ool000Aoo`03001oogoo009oo`03001oogoo01Qoo`80039oo`8000EW>P8000EW6P8000ERnP8000IR
fP03001NfEkI00=Nf@800005G[T00000F[T00005FYT00`00Oomoo`05Ool00`00Oomoo`1/Ool00:mo
o`038@QS600000Aoo`068@QBU7ooOomBU2485goo0`00<goo00@006LjIcX000=W>P04001W6VLJ0003
IaX01000H_YRnP000f;j00@006;jH_X000ARfP8000ENf@<000AJ^@03001JVEZI009JV@8000Moo`03
001oogoo06]oo`00[goo00=[FR48000017oo00IS61S6LiacW1S6HaPEOol20003Ool00`00Oomoo`0_
Ool00`00IcYW>P02IcX00`00IcX00004IaX00`00IaX00004H_X00`00H_X00004H_X01000H]YRfP00
0UkI00<005kIG]T00UkI0P001EZi00<005ZIFYT00P0000=JV@00Ool01Woo00<007ooOol0Jgoo002`
Ool00cW>249oo`04Ool015[F2488@V<H4goo0`00=Goo0P001FLj0P001FLJ0P001F;j0P001F;j00<0
06;J00000ekI00<005kIG]T00P0000=N^@00F[T015Zi00<005ZI000015ZI00<007ooOol01Goo00<0
07ooOol0JWoo003<Ool2000gOol00`00IcX00003IcX200000fLJ001W6P02IaX200000f<J001RnP02
H_X200000f;j001RnP04H_X20004G]T00`00G]T00003G[T20004F[T20005FYT00`00Oomoo`06Ool0
0`00Oomoo`1YOol00<Uoo`<003Qoo`07001W>VLjIcX006Lj000016LJ00<006LJ000016<J00<006;j
000016;j00<006;jH_X00P0000=RfP00G]T00ekI0P0015ji0P000UZi0P0000=J^@00FYT015ZI00<0
07ooOol01Woo00<007ooOol0JGoo0036Ool3000jOol00`00IcYW>P03IcX00`00IaYW6P04IaX00`00
HaYS6P03HaX20005H_X00`00H_X00004H]X01P00G]UNf@00G]T000AN^@800003F[T005Zi00=J^@03
001JVEZI009JV@8000Qoo`03001oogoo06Qoo`00a7oo0P00?7oo00<006LjIcX00fLj0P001FLJ0P00
16<J00<006;j00001F;j0P001F;J00<005kI00000ekI00@005jiG[UN^@<000EJ^@03001JVEZI0080
0003EYT007oo00Qoo`03001oogoo06Moo`00`Goo0`00?Goo00<006Lj00000fLj00@006LJIaX000=W
6P04001S6V<J0002HaX01@00H_YRnV;j00000V;j0P0000=RnP00H]X016;J0P001EkI00H005ji0000
05Zi0005F[T00`00FYT00004EYT00`00Oomoo`06Ool00`00Oomoo`1WOol00;moo`8003moo`07001W
>VLjIcX006Lj000016LJ00<006LJ00000f<J00<006<J000016;j00<006;j000016;j00<006;JH]X0
0P0000=Nf@00G]T015kI0P0000EJ^@00F[UJ^@0000AJ^@8000EFV@03001oogoo00Moo`03001oogoo
06Ioo`00_7oo0`0000=oo`00Ool0?Goo00<006LjIcX00VLj0P001FLJ0P001F<J00<006;jH_X016;j
00<006;jH_X00f;j00<006;J000015kI00T005kIG]UNf@00G[T005Zi00000eZi00H005Zi000005ZI
0005EYT00`00Oomoo`08Ool00`00Oomoo`1UOol00;Yoo`8000Eoo`03001oogoo03Uoo`8000AW>P03
001W6P0000AW6P03001W6P0000AS6P8000ERnP8000IRnP03001NfEkI00=Nf@04001NfEkI0003G[T2
0003F[T20004FYT00`00EYUFV@03EYT00`00Oomoo`07Ool00`00Oomoo`1UOol00;Moo`<0045oo`80
0003IcX006Lj009W>P05001W6VLJIaX00002IaX01@00IaYW6VLJ00000V<J00@006;jH_X000=RnP04
001RnV;j0004H_X20005G]T00`00G]T00004G[T200001EZi000005Zi00001EZI00@005JIEYUFV@80
00Yoo`03001oogoo06Aoo`00]7oo0`00@goo00<006LjIcX00VLj00<006Lj000016LJ00<006LJ0000
16LJ00<006<J000016;j00<006;j000016;j00@006;jH_X0009NfP03001NfEkI009Nf@8000EN^@<0
00AJ^@03001JVEZI009JV@06001FV@00001FV@002Goo00<007oo0000IGoo002bOol20014Ool20005
IcX20005IaX20005IaX20005H_X20005H_X00`00H_X00004G]X01P00G]UNf@00G]T000EN^@8000EJ
^@03001JVEZI009JV@8000AFV@03001oogoo00Qoo`03001oogoo06=oo`00[goo0`00AGoo00<006Lk
000016Lj00<006LJ00000fLJ0P0000=W6P00IaX00VLJ0P0000=RnP00H_X00f;j00<006;j00001F;j
0P001EkJ00<005kI00000ekI00<005jiG[T00P0000=J^@00F[T015Zi00<005ZI00000P0000=JV@00
EYT015JI00<007ooOol027oo00<007ooOol0HWoo002]Ool20017Ool01@00Ic]W>fLk00000VLj00L0
06LJIaYW6P00IaX00004IaX00`00IaX00004H_X01000H_YRnP000f;j00<006;jH_X00P0000=RfP00
G]X015kJ0P0015kI00<005ji00000eZi0P0015Zi0P001EZI00<005JIEYT00UJI00<007ooOol027oo
00<007ooOol0HWoo002ZOol30018Ool00`00Ic]W>`02Ic/00`00IcX00005IaX00`00IaYW6P04IaX0
0`00H_YRnP03H_X00`00H_X00004H_X00`00H_X00004H]X00`00G]YNfP0200000ekI001Nf@03G]T2
0005F[T00`00F[UJ^@0200000eZi001JV@04FYT00`00EYUFV@02EYT2000:Ool00`00Oomoo`1QOol0
0:Moo`@004Uoo`03001W>fLk00=W>`8000EW6P8000EW6P8000ERnP8000IRnP03001RfV;J00=RfP03
001NfP0000ANf@06001NfEkI001N^@001EZi00<005Zi000015Zi00<005ZIFYT00UZI00<005JI0000
0P0000=FV@00Ool02Woo00<007ooOol0H7oo002UOol20004Ool00`00Oomoo`15Ool00`00Ic/00003
Ic/01000IaYW6P000fLJ00@006LJIaX000=W6P04001RnV;j0003H_X00`00H_X00005H_X20005H]X2
0005G]T00`00G]T00003G[T00`00F[UJ^@02F[T20005F[T00`00FYUJV@02FYT20005EYT00`00Oomo
o`08Ool00`00Oomoo`1POol00:9oo`<004eoo`07001W>fLkIc/006Lk000016LJ00<006LJ000016LJ
00<006LJ000016;j00<006;j00000f;j00D006;jH_YRnP00009RnP03001RfV;J00800003G]T005kI
00ANf@8000EN^@03001J^EZi00<000EJ^@03001JV@0000800003EYT005JI00AFV@03001oogoo00Uo
o`03001oogoo00Qoo`H000Aoo`04F]H8@P00>Li9Ool00:1oo`8004moo`03001W>fLk009W>`8000EW
6P8000EW6P8000ERnP8000ERnP03001RnP0000=RnP03001RfP0000ANf@03001NfEkI00800003G]T0
05ji00AN^@07001J^@00F[T005Zi000015Zi0P001EJI00<005JIEYT00UJI00<007ooOol02Woo00<0
07ooOol01goo00=:DP00HaP00Woo00H8@WooOomoof<H6<H2Li`00a24DYAoo`17Ool009eoo`<004mo
o`8000AW>`03001W6P0000AW6P03001W6P0000AW6P03001S6P0000ARnP03001RnP0000ERnP8000ER
nP03001NfEkI00=Nf@03001Nf@0000ANf@03001N^Eji009N^@80009J^@04001J^EZi0002F[T00`00
FYT00005EYT00`00EYUFV@02EYT2000;Ool00`00Oomoo`08Ool00dYB001S6005Ool01R48DYAoogoo
DY@HaTQoo`00Vgoo0P00DGoo00<006Lk00000fLk00D006LJIaYW6P00009W6P05001W6VLJIaX00002
IaX01@00HaYS6V<J00000V;j00D006;jH_YRnP00009RnP800003H_X006;j00=RnP8000INf@03001N
fEkI00=Nf@03001N^Eji00800005G[T005ZiF[T00002F[T00`00F[T00003FYT00`00EYUFV@02EYT0
0`00EYT0000200000eJI001oo`0;Ool00`00Oomoo`08Ool00e:D249S6004Ool00`00Oomoo`02Ool0
0`00Oomoo`16Ool009Qoo`<0059oo`07001W>fLkIc/006Lk000016LJ00<006LJ000016LJ00<006LJ
000016<J00<006;j000016;j00<006;j000016;j00@006;jH_X0009RfP03001NfEkI009Nf@8000EN
f@03001N^@0000AN^@03001J^@00009J^@8000AJV@03001FVEJI009FV@8000EFV@03001oogoo00Yo
o`03001oogoo00Qoo`03HaP8@V<H00=oo`03001oogoo009oo`03001oogoo04Ioo`00UGoo0`00E7oo
00<006LkIc/00fLk00<006LJIaX016LJ00<006LJIaX00fLJ0P001F<J0P001F;j0P001F;j00<006;j
000016;J00@005kIG]T0009Nf@03001NfEkI009Nf@8000EN^@03001J^@0000800003F[T005ZI00=J
V@03001FV@0000800003EYT005JI00AFV@03001oogoo00Yoo`03001oogoo00Uoo`03DY@HaWoo009o
o`03001oogoo009oo`03001oogoo04Ioo`00Tgoo0`00E7oo0P001FLk0P001FLJ00<006LJ00000fLJ
00@006<JHaX000=S6P03001RnP0000ARnP03001RnP0000ERnP8000ERfP03001Nf@0000ANf@06001N
fEkI001N^@001Eji00<005Zi000015Zi00@005ZIFYUJV@8000EFV@03001FVEJI009FV@03001oogoo
00]oo`03001oogoo00Uoo`06001oogooOolQ25:D0Woo00=BU248Ool0Agoo002@Ool30003Ool00`00
Oomoo`1@Ool01000Ic]W>`000fLk00@006LJIaX000=W6P07001W6VLJIaX006LJ000016<J00<006<J
00000f;j00@006;jH_X000=RnP03001RnV;j00800003H]X006;J00ARfP8000ENf@03001Nf@0000=N
^@03001N^Eji009N^@<000AJ^@06001JVEZI001JV@001EJI00<005JIEYT00UJI0P0037oo0P001Goo
00H0048@LiaoocW>6<H3Ool01V<H6<IcW7>L6<IS64Qoo`00F7oo1P0017oo00AJePQ2000icRQoo`80
05Qoo`03001W>fLk009W>`03001W>`0000AW6P03001W6P0000AW6P8000ES6P8000ARnP03001RnP00
00ARnP03001RnP0000ARfP03001RfV;J00800003G]T005kI00ANf@8000AN^@03001N^@0000800003
F[T0000000AJ^@03001JV@0000=JV@03001FVEJI009FV@03001FV@0000800003EYT007oo00Yoo`03
001oo`0000Eoo`06DY@HaP00000YBW>L17oo00AJePQ2249S64Uoo`00F7oo00=:DP00HaP00Woo00H8
@WooOomoof<H6<H2Li`00a24DYAoo`0SOol3001HOol20005Ic/20005IaX20004IaX00`00IaX00004
HaX00`00H_X00004H_X20006H_X00`00H]YRfP03H]X00`00H]X00004G]T00`00G]UNf@0200000ekI
001N^@03G[T20005F[T00`00F[UJ^@02F[T20005FYT01000EYUFVEJI0P001EJI00<007ooOol02goo
00<007ooOol0FGoo001IOol00dYB001S6005Ool01R48DYAoogooDY@HaR9oo`8005Yoo`03001W>`00
00AW>`03001W6P0000=W6P800003IaX006LJ009W6P05001W6VLJIaX00002HaX01@00H_YRnV;j0000
0V;j00<006;j00001F;j0P001F;J0P001EkI00<005kI000015kI00H005jiG[T005ji0005F[T00`00
F[T0000200000eZi001JV@04FYT01P00EYT00000EYT000EFV@03001oogoo00aoo`03001oogoo05Qo
o`00FWoo00=BU0Q2HaP017oo00<007ooOol00Woo00<007ooOol07Goo0`00Fgoo00D006LkIc]W>`00
009W>`07001W6VLJIaX006LJ000016LJ00<006LJ000016LJ00<006<J000016;j00<006;j00000f;j
00D006;jH_YRnP00009RnP07001RfV;JH]X005kJ00001EkI0P001EkI00<005ji00000eji00<005Zi
F[T00UZi0P001EZi00<005ZIFYT00UZI0P0015JI00<005JIEYT00UJI00<007ooOol037oo00<007oo
Ool0F7oo001KOol00f<H249S6003Ool00`00Oomoo`02Ool00`00Oomoo`0JOol3001MOol00`00Ic]W
>`02Ic/00`00Ic/00005IaX00`00IaYW6P04IaX00`00IaYW6P03IaX20005H_X20005H_X00`00H_X0
0004H_X00`00H]X00003G]X01`00G]UNfEkI001Nf@0000ENf@8000EN^@03001J^EZi00<000EJ^@03
001JVEZI00800003EYT005JI00AFV@04001FVEJIEYT2000>Ool00`00Oomoo`1GOol005aoo`03DY@H
aWoo009oo`03001oogoo009oo`03001oogoo01Qoo`8005ioo`8000EW>`8000EW6P8000EW6P8000AW
6P03001RnP0000ARnP03001RnP0000ERnP8000ERnP8000ENfP03001Nf@0000=Nf@03001NfEkI0080
0003G[T005ji00AN^@07001J^@00F[T005Zi000015Zi00<005ZI000015JI00<005JIEYT00UJI00H0
05JI000005JI000?Ool00`00Oomoo`1FOol005eoo`06001oogooOolQ25:D0Woo00=BU248Ool05Woo
1000GWoo00<006Lk00000fLk0P000VLJ00D006LJIaYW6P00009W6P05001W6VLJIaX00002IaX01000
IaYW6P000f;j00@006;jH_X000=RnP03001RnV;j00800003H_X006;j00=RnP03001RfP0000ENfP80
00ANf@03001Nf@0000AN^@03001N^Eji009N^@80009J^@04001J^EZi0003F[T20005EYT00`00EYUF
V@02EYT20004EYT00`00Oomoo`0<Ool00`00Oomoo`1FOol005Qoo`06001247>LOolicQS60goo00IS
61S6LiacW1S6HaPEOol20004Ool00`00Oomoo`1JOol01`00Ic]W>fLk001W>`0000EW6P03001W6P00
00AW6P03001W6P0000=W6P03001W6P0000ARnP03001RnP0000ARnP03001RnP0000ARnP04001RnV;j
0003H]X00`00G]YNfP0200000ekI001Nf@04G]T00`00G[UN^@03G[T00`00G[UN^@0200001EZi001J
^EZi00000UZi00H005Zi000005ZI0005EYT00`00EYT0000200000eJI001FV@03EYT00`00Oomoo`0=
Ool00`00Oomoo`1EOol005Qoo`06DY@HaP00000YBW>L17oo00AJePQ2249S61=oo`<0069oo`03001W
>fLk00=W>`03001W6VLJ00AW6P8000EW6P8000AW6P8000ERnP8000IRnP03001RnV;j00=RnP03001R
nP0000ARfP03001NfP0000ANf@04001NfEkIG]T20005G[T00`00G[T00004F[T00`00F[T00002F[T2
0004FYT00`00EYUFV@02EYT20005EYT01@00EYUFVEJI00003goo00<007ooOol0EGoo001gOol2001T
Ool00`00Ic]W>`03Ic/20005IaX00`00IaX00003IaX200000fLJ001W6P02IaX01000HaYS6P000f;j
00<006;j00001F;j0P001F;j0P001V;J00<005kIG]T00ekI00@005kIG]T0009Nf@03001N^Eji009N
^@8000EJ^@03001J^EZi00800003F[T005ZI00=JV@03001FVEJI00800003EYT005JI00AFV@04001F
VEJIEYT2000?Ool00`00Oomoo`1DOol007Aoo`<006Eoo`03001W>`0000=W>`04001W6VLJ0003IaX0
1`00IaYW6VLJ001W6P0000AW6P03001W6P0000AS6P03001RnP0000=RnP05001RnV;jH_X00002H_X0
1`00H_YRnV;j001RfP0000ERfP8000ENf@03001Nf@0000ANf@06001N^Eji001N^@001EZi00@005Zi
000000=J^@07001JVEZIFYT005JI000015JI00<005JIEYT00UJI00H005JI000005JI000@Ool00`00
Oomoo`1COol0075oo`<006Moo`07001W>fLkIc/006Lk000016LJ00<006LJ000016LJ0P001FLJ0P00
1F<J0P001F;j00<006;j000016;j00<006;j00000f;J00D006;JH]YRfP00009NfP03001NfEkI009N
f@8000ENf@03001N^@0000=N^@03001J^EZi009J^@800003F[T005Zi009J^@04001JVEZIFYT20005
EYT00`00EYUFV@02EYT20004EYT00`00Oomoo`0=Ool00`00Oomoo`1COol006moo`8006Uoo`03001W
>fLk009W>`8000EW6P8000AW6P03001W6P0000AW6P03001S6P0000AS6P03001RnP0000ERnP8000ER
nP8000ERfP03001RfP0000=NfP03001NfEkI00800003G]T005kI00ANf@8000AN^@03001J^EZi0080
0004F[T005Zi0003F[T01P00FYT00000FYT000EFV@03001FV@0000800003EYT005JI00AFV@03001o
ogoo00eoo`03001oogoo059oo`00K7oo0`00JGoo0P0016Lk00<006LJ00000fLJ0P0000=W6P00IaX0
0VLJ00D006LJIaYW6P00009W6P05001S6V<JHaX00002HaX01@00H_YRnV;j00000V;j0P0000=RnP00
H_X00V;j0P0000=RnP00H]X016;J0P0015kJ00<005kI000015kI00<005kIG]T00P0000=N^@00G[T0
0eji00<005Zi000015Zi0P000eZi0P0015ZI00<005JIEYT00UJI0P001EJI00<005JIEYT00UJI00<0
07ooOol03Woo00<007ooOol0DGoo001ZOol4001XOol200000fLk001W>`02Ic/01`00IaYW6VLJ001W
6P0000AW6P03001W6P0000AW6P03001W6P0000AS6P03001S6P0000ARnP03001RnP0000ARnP03001R
nP0000ARnP03001RfV;J00800003H]X005kJ00=NfP8000ENf@03001Nf@0000AN^@04001N^EjiG[T2
0005F[T200001EZi000005Zi00001EZI00H005JI000005JI0005EYT00`00EYUFV@02EYT2000?Ool2
001BOol006Moo`<000Aoo`03001oogoo06Aoo`03001W>fLk009W>`03001W>`0000EW6P03001W6VLJ
00AW6P03001W6VLJ00AW6P03001S6V<J00AS6P03001RnV;j00ARnP03001RnV;j00ARnP03001RnV;j
00=RnP03001RfP0000ARfP06001NfUkJ001Nf@001EkI0P001Eji00H005jiG[T005Zi0005F[T30004
F[T00`00FYUJV@02FYT20004EYT00`00EYUFV@02EYT00`00EYT0000200000eJI001oo`0=Ool00`00
Ool0001BOol006Eoo`8006eoo`03001W>fLk00AW>`03001W6VLJ00=W6P8000EW6P8000EW6P8000ES
6P8000ERnP8000ERnP8000ERnP8000ERfP03001NfP0000=Nf@07001NfEkIG]T005kI00001Eji00<0
05ji00000eZi00<005ZiF[T00UZi0P001EZi00<005ZIFYT00P0000=JV@00EYT00eJI00<005JIEYT0
0UJI0P001EJI00<007ooOol03Woo00<007ooOol0Cgoo001ROol3001^Ool20005Ic/00`00IaX00003
IaX01000IaYW6P000fLJ00@006LJIaX000=W6P04001S6V<J0003HaX01000H_YRnP000f;j00@006;j
H_X000=RnP04001RnV;j0002H_X200000f;J001RfP04H]X20005G]T00`00G]T00003G]T00`00G[UN
^@02G[T20005F[T01P00F[T00000F[T000EJ^@03001JV@0000AJV@06001FVEJIEYT005JI0`0000=F
V@00EYT015JI00<007ooOol03Woo00<007ooOol0Cgoo001OOol3001`Ool01000Ic]W>`000fLk00L0
06LJIaYW6P00IaX00004IaX00`00IaX00004IaX00`00IaX00004HaX00`00HaX00004H_X00`00H_X0
0004H_X00`00H_X00003H_X00`00H_X00004H]X00`00H]YRfP0200000ekI001Nf@04G]T20004G]T0
0`00G[T0000200000eji001J^@04F[T20003F[T20004F[T20005FYT01000EYUFVEJI0P001EJI00<0
05JIEYT00UJI00<007ooOol03goo00<007ooOol0CWoo001MOol2001bOol00`00Ic]W>`02Ic/00`00
Ic/00004IaX20005IaX20005IaX20005HaX20005H_X20005H_X20005H_X00`00H]YRfP03H]X00`00
H]X00004G]T00`00G]UNf@0200000ekI001Nf@04G]T00`00G[UN^@03G[T00`00F[UJ^@0200000eZi
001J^@02F[T01000F[T005Zi0P0000=JV@00FYT015ZI00H005JI000005JI0005EYT00`00EYUFV@02
EYT2000AOol00`00Oomoo`1=Ool005Yoo`<0079oo`8000EW>`8000AW6P03001W6P0000=W6P800003
IaX006LJ009W6P800003IaX006<J009S6P800003H_X006;j009RnP800003H_X006;j009RnP800003
H_X006;j00=RnP8000IRfP03001NfEkI00=Nf@03001Nf@0000ANf@04001NfEkIG]T20005G[T00`00
F[T00004F[T01@00F[UJ^@00F[T00P0015ZI00<005ZIFYT00UZI0P0015JI00<005JIEYT00UJI00<0
05JI00000P0000=FV@00Ool047oo00<007ooOol0CGoo001HOol2001dOol00`00Ic/00003Ic/20000
0fLJ001W6P02IaX01`00IaYW6VLJ001W6P0000AW6P03001W6P0000AW6P03001S6P0000ARnP03001R
nP0000ARnP03001RnP0000ARnP04001RnV;j0002H_X00`00H]YRfP02H]X20005G]T20005G]T01000
G]UNf@000Uji00<005jiG[T00Uji0P001EZi00<005ZiF[T00P0000=J^@00FYT00eZI00<005ZIFYT0
0P0000=FV@00EYT015JI00@005JIEYUFV@8000EFV@03001oogoo00moo`03001oogoo04aoo`00EGoo
0`000Woo00<007ooOol0L7oo00L006LkIc]W>`00Ic/00004IaX00`00IaX00005IaX00`00IaYW6P04
IaX00`00IaYW6P04IaX00`00H_YRnP04H_X00`00H_YRnP04H_X00`00H_YRnP03H_X00`00H_X00004
H_X01000H]YRfP000UkJ00L005kIG]UNf@00G]T00005G]T00`00G]T00004G[T01P00G[UN^@00F[T0
00EJ^@04001J^@000003F[T01`00FYUJVEZI001JV@0000AFV@03001FVEJI009FV@06001FV@00001F
V@001EJI00<007ooOol047oo00<007ooOol0Bgoo001COol2001gOol00`00Ic]W>`03Ic/00`00IaYW
6P04IaX00`00IaYW6P03IaX20005IaX20005IaX20005H_X20005H_X20005H_X20005H_X00`00H]X0
0004G]X00`00G]T00003G]T00`00G]UNf@02G]T20005G[T00`00G[T00003F[T00`00F[UJ^@02F[T2
00000eZi001J^@02F[T01000FYUJVEZI0P001EJI00<005JIEYT00UJI0P0015JI00<005JIEYT00UJI
00<007ooOol047oo00<007ooOol0Bgoo001@Ool3001gOol20005Ic/20005IaX00`00IaX00003IaX0
1000IaYW6P000fLJ00@006LJIaX000=W6P04001RnV;j0003H_X01000H_YRnP000f;j00@006;jH_X0
00=RnP03001RnP0000ERnP8000ENfP8000ANf@03001NfEkI00800003G]T005ji00AN^@8000AJ^@03
001J^EZi00800004F[T005Zi0003F[T01P00FYT00000FYT000EFV@03001FV@0000800003EYT005JI
00AFV@04001FVEJIEYT2000BOol00`00Oomoo`1:Ool004eoo`<007Uoo`04001W>fLk0003Ic/01000
IaYW6P000fLJ00L006LJIaYW6P00IaX00004IaX00`00IaX00004IaX00`00IaX00004H_X00`00H_X0
0004H_X00`00H_X00004H_X00`00H_X00003H_X00`00H_YRnP0200000f;J001NfP03G]X00`00G]T0
0004G]T00`00G]T00004G]T00`00G[UN^@0200000eji001J^@03F[T00`00F[T00004F[T20003F[T2
0004FYT00`00EYUFV@02EYT20005EYT00`00EYUFV@02EYT01P00EYT00000EYT001=oo`03001oogoo
04Uoo`00Bgoo0P00Ngoo00<006LkIc/00VLk00<006Lk000016LJ00<006LJ000016LJ0P001FLJ0P00
1FLJ0P001F;j0P001F;j0P001F;j0P0016;j00<006;j000016;J00@005kJG]X000=Nf@04001NfEkI
G]T20005G]T00`00G[T00004G[T01000F[UJ^EZi0P001EZi0P0000EJ^@00001J^@0000EJV@06001F
VEJI001FV@001EJI00<005JIEYT00UJI0P0015JI00<007ooOol047oo00<007ooOol0BGoo0018Ool3
001lOol00`00Ic]W>`03Ic/20005IaX20004IaX00`00IaX00004IaX00`00IaX00003IaX200000f<J
001RnP02H_X200000f;j001RnP02H_X200000f;j001RnP03H_X00`00H_X00004H_X20005H]X00`00
G]X00004G]T01P00G]UNf@00G]T000ENf@8000EN^@06001J^EZi001J^@001EZi0`0015Zi00<005ZI
FYT00UZI00<005JI00000eJI00<005JIEYT00UJI00<005JI00000P0000=FV@00EYT00eJI00<007oo
Ool04Goo00<007ooOol0B7oo0016Ool2001mOol20005Ic/00`00IaX00003IaX200000fLJ001W6P02
IaX01@00IaYW6VLJ00000VLJ00L006LJIaYW6P00IaX00004HaX00`00H_X00004H_X00`00H_X00004
H_X01000H_YRnP000f;j00H006;jH_X006;J0005H]X20005G]T00`00G]T00003G]T01`00G]UNfEkI
001N^@0000EN^@03001J^@0000=J^@03001J^EZi009J^@8000EJ^@03001JVEZI009JV@8000AFV@03
001FVEJI009FV@8000EFV@05001FVEJIEYT0000COol20019Ool004=oo`@007eoo`04001W>fLk0003
Ic/01`00IaYW6VLJ001W6P0000AW6P03001W6P0000AW6P03001W6P0000EW6P03001S6V<J00AS6P03
001RnV;j00ARnP03001RnV;j00=RnP03001RnP0000ARnP03001RnP0000=RfP07001RfV;JH]X005kJ
00001EkI0P001EkI00<005kI00000eji00<005jiG[T00Uji0P001EZi00D005Zi000005Zi008000AJ
^@03001JV@0000800003FYT005JI00=FV@03001FV@0000800003EYT005JI00AFV@04001FVEJIEYT2
000BOol20019Ool0045oo`8000Aoo`03001oogoo07Uoo`03001W>fLk009W>`03001W>`0000EW6P03
001W6VLJ00=W6P8000EW6P8000EW6P8000ES6P8000ERnP8000ERnP8000ERnP8000ERfP03001RfP00
00=NfP03001NfEkI00800003G]T005kI00ANf@8000AN^@03001N^@0000800003G[T005Zi00AJ^@80
00AJ^@03001J^EZi009J^@8000EJV@04001FVEJIEYT20005EYT00`00EYUFV@02EYT01P00EYT00000
EYT001Aoo`03001oogoo04Ioo`00?Woo0`00P7oo0P001FLk0P001FLJ00<006LJ00000fLJ00@006LJ
IaX000=W6P04001W6VLJ0003IaX01000HaYS6P000f<J00@006;jH_X000=RnP04001RnV;j0003H_X0
0`00H_X00004H_X00`00H_X00005H]X20004G]X00`00G]T00004G]T00`00G]UNf@0200000ekI001N
^@03G[T20005G[T00`00F[UJ^@0200000eZi001J^@03F[T00`00F[T0000200000eZI001JV@04FYT0
1P00EYT00000EYT000EFV@03001FVEJI009FV@8000AFV@03001oogoo015oo`03001oogoo04Ioo`00
>goo0`00PWoo00@006LkIc/000=W>`04001W6VLJ0003IaX01`00IaYW6VLJ001W6P0000AW6P03001W
6P0000AW6P03001W6P0000AS6P03001S6P0000ARnP03001RnP0000ARnP03001RnP0000=RnP04001R
nV;j0003H_X00`00H]YRfP0200000f;J001NfP03G]X20005G]T00`00G]T00004G]T01P00G[UN^@00
G[T000EN^@03001J^@0000AJ^@04001J^EZiF[T20005FYT00`00FYUJV@02FYT20004EYT00`00EYUF
V@02EYT00`00EYT0000200000eJI001FV@04EYT00`00Oomoo`0AOol00`00Oomoo`15Ool003Uoo`80
08Aoo`03001W>fLk009W>`03001W>`0000AW6P03001W6P0000AW6P8000EW6P8000EW6P8000ES6P80
00ERnP8000ERnP8000ARnP03001RnP0000ARnP03001RfP0000ARfP06001NfUkJ001Nf@001EkI0P00
1EkI00<005ji00000eji00<005jiG[T00Uji0P001EZi00<005ZiF[T00`001EZI00<005ZIFYT00P00
00=FV@00EYT015JI00@005JIEYUFV@8000EFV@03001FVEJI009FV@03001oogoo019oo`03001oogoo
04Aoo`00=Woo0`00QGoo00<006LkIc/00fLk0P001FLJ0P0016LJ00<006LJ000016LJ00<006LJ0000
16LJ00<006<J00000f<J0P0000=RnP00H_X00V;j0P0000=RnP00H_X00f;j00<006;j000016;j0P00
1V;j00<006;JH]X00f;J00<005kJ00000ekI00L005kIG]UNf@00G]T00005G]T20005G[T01P00G[UN
^@00F[T000EJ^@07001J^@00F[T005Zi000015ZI00<005ZI000015JI00<005JIEYT00UJI00H005JI
000005JI0005EYT00`00EYUFV@02EYT2000COol00`00Oomoo`14Ool003Aoo`8008Moo`03001W>fLk
00=W>`03001W>P0000AW6P03001W6P0000=W6P05001W6VLJIaX00002IaX01@00IaYW6VLJ00000VLJ
00L006<JHaYS6P00HaX00004H_X00`00H_X00004H_X01000H_YRnP000f;j00H006;jH_X006;j0005
H_X20005H]X20005G]T00`00G]T00003G]T01`00G]UNfEkI001N^@0000EN^@03001N^@0000=J^@03
001J^EZi009J^@80009J^@04001J^EZi0003FYT20005EYT00`00EYUFV@02EYT20004EYT00`00EYUF
V@02EYT00`00EYT0000200000eJI001oo`0COol00`00Oomoo`13Ool0035oo`<008Qoo`03001W>`00
00=W>`05001W>VLjIcX00002IaX01`00IaYW6VLJ001W6P0000AW6P03001W6P0000AW6P03001W6P00
00ES6P03001RnV;j00ARnP03001RnV;j00=RnP03001RnP0000ARnP03001RnP0000=RnP05001RnV;j
H_X00002H]X01`00H]YRfV;J001NfP0000ENf@8000ENf@03001Nf@0000=N^@03001N^Eji009N^@80
00AJ^@03001J^EZi00800005F[T005ZiF[T00002F[T01P00FYT00000FYT000EFV@03001FV@000080
0003EYT005JI00=FV@03001FVEJI009FV@8000EFV@03001oogoo019oo`03001oogoo049oo`00;goo
0P000goo00<007ooOol0Q7oo00L006LkIc]W>`00Ic/00004IcX00`00IaX00005IaX00`00IaYW6P03
IaX20005IaX20005HaX20005H_X20005H_X20005H_X20005H_X00`00H_X00004H]X00`00H]X00003
G]X00`00G]UNf@0200000ekI001Nf@04G]T20004G[T00`00G[UN^@0200000eji001J^@03F[T00`00
F[T00004F[T00`00F[T00002F[T20004FYT00`00EYUFV@02EYT20005EYT01P00EYUFVEJI001FV@<0
0003EYT005JI00AFV@03001oogoo019oo`03001oogoo049oo`00;7oo0`00Rgoo00<006LkIc/00VLk
0P001FLj0P001FLJ00<006LJ00000fLJ00@006LJIaX000=W6P04001W6VLJ0003HaX01000H_YRnP00
0f;j00@006;jH_X000=RnP03001RnP0000=RnP800003H_X006;j00ARnP8000ERfP8000ANfP03001N
f@0000ANf@03001NfEkI00800003G]T005ji00=N^@03001N^@0000AN^@04001J^EZiF[T20005F[T5
00000eZi001JV@03FYT00`00EYUFV@0200000eJI001FV@04EYT01000EYUFVEJI0P001EJI00<005JI
EYT00UJI00<007ooOol04goo00<007ooOol0@Goo000YOol3002<Ool20004Ic/01000IcYW>P000fLj
00@006LJIaX000=W6P07001W6VLJIaX006LJ000016LJ00<006LJ000016LJ00<006<J000016;j00<0
06;j000016;j00<006;j00000f;j00<006;j000016;j00<006;jH_X00P0000=RfP00H]X00f;J00<0
05kJ000015kJ0P001EkI00<005kI000015kI00@005jiG[UN^@8000EN^@06001J^@00001J^@000eZi
0`0000=J^@00F[T00eZi00L005ZIFYUJV@00EYT00004EYT00`00EYUFV@02EYT01P00EYT00000EYT0
00EFV@03001FVEJI009FV@8001Eoo`03001oogoo041oo`009goo0P00SWoo00<006Lk00000fLk00<0
06LjIcX00VLj00<006Lj000016LJ00<006LJ000016LJ0P001FLJ0P001FLJ0P001F;j0P001F;j0P00
1F;j00<006;jH_X00f;j00<006;j000016;J00@006;JH]X000=NfP06001NfUkJ001Nf@001EkI0P00
1EkI00H005jiG[T005ji0005G[T20004F[T30002F[T200000eZi001J^@02F[T01000FYUJVEZI0P00
1EJI00<005JIEYT00UJI0P0015JI00<005JIEYT00UJI00<005JI00000P0000=FV@00Ool057oo00<0
07ooOol0@7oo000TOol3002?Ool01`00Ic]W>fLk001W>`0000EW>P8000EW6P8000AW6P03001W6P00
00AW6P03001W6P0000AW6P03001S6P0000ARnP03001RnP0000ARnP03001RnP0000ARnP8000ERnP80
00ERfP03001RfP0000ANfP03001NfP0000=Nf@07001NfEkIG]T005kI00001EkI00<005ji00000eji
00P005jiG[UN^@00F[T005Zi0`0000=J^@00F[T00P0000EJ^@00F[UJ^@00009J^@06001JV@00001J
V@001EJI00<005JI00000P0000=FV@00EYT00eJI00<005JIEYT00UJI0P001EJI00<007ooOol04goo
00<007ooOol0?goo000SOol2002@Ool00`00Ic]W>`03Ic/00`00IcYW>P03IcX00`00IaX00004IaX0
0`00IaX00003IaX01@00IaYW6VLJ00000VLJ00D006LJIaYW6P00009W6P05001S6V<JHaX00002H_X0
1@00H_YRnV;j00000V;j00D006;jH_YRnP00009RnP04001RnV;j0003H_X00`00H_X00005H]X20005
G]X20005G]T00`00G]T00003G]T00`00G]UNf@02G]T20005G[T01000G[T005Zi0`0015Zi0P0015Zi
00D005ZiF[T005Zi008000AJV@03001FVEJI009FV@8000EFV@06001FVEJIEYT005JI0`0000=FV@00
EYT015JI00<007ooOol04Woo0`00@7oo000SOol01000Ool00000S7oo0P001FLk00<006Lj00000fLj
00D006LJIaYW6P00009W6P07001W6VLJIaX006LJ000016LJ00<006LJ000016LJ00<006LJ000016<J
00<006;j000016;j00<006;j000016;j00<006;j000016;j00<006;j00000f;j00L006;JH]YRfP00
H]X00004G]X00`00G]T00005G]T20004G]T00`00G]UNf@0200000eji001N^@04G[T40002F[T00`00
F[UJ^@0200000eZi001J^@03F[T00`00F[T0000200000eZI001JV@04FYT01P00EYT00000EYT000EF
V@04001FVEJIEYT20005EYT00`00EYUFV@02EYT00`00Oomoo`0DOol00`00Oomoo`0nOol002=oo`@0
08]oo`04001W>fLk0003Ic/01`00IcYW>VLj001W>P0000AW6P03001W6P0000EW6P03001W6VLJ00=W
6P8000EW6P8000ES6P8000ERnP8000ERnP8000ERnP8000ERnP03001RfP0000=RfP04001NfUkJ0003
G]T01`00G]UNfEkI001Nf@0000ANf@03001Nf@0000AN^@03001N^Eji00@000AJ^@03001J^@0000AJ
^@04001J^EZiF[T20002FYT01000FYUJV@0015ZI0P0015JI00<005JIEYT00UJI00H005JI000005JI
0005EYT00`00EYUFV@02EYT2000FOol00`00Oomoo`0mOol002=oo`03000j6SXJ00X0085oo`03001W
>fLk009W>`03001W>`0000EW>P03001W6VLJ00=W6P8000EW6P03001W6P0000=W6P04001W6VLJ0003
IaX01000HaYS6P000f<J00@006;jH_X000=RnP04001RnV;j0003H_X00`00H_X00004H_X00`00H_X0
0005H_X20004H]X00`00G]X00004G]T01000G]UNf@000ekI00@005kIG]UNf@8000EN^@<000AN^@04
001J^EZiF[T20005F[T01P00F[UJ^@00F[T000=JV@03001JV@00009JV@800003FYT005JI00=FV@03
001FVEJI009FV@8000AFV@03001FVEJI009FV@03001FV@0000800003DYT007oo01Ioo`03001oogoo
03aoo`008Woo00<007oo00000SXJ00D0039M<UdbG@00008^G@03000^O@0000H007Qoo`8000EW>`80
00EW>P03001W6P0000=W6P04001W6VLJ0003IaX01`00IaYW6VLJ001W6P0000AW6P03001W6P0000AS
6P03001S6P0000ARnP03001RnP0000ARnP03001RnP0000=RnP04001RnV;j0003H_X00`00H_YRnP02
00000f;J001RfP03H]X20005G]T00`00G]T00004G]T01P00G]UNf@00G]T000=N^@@000EN^@06001J
^EZi001J^@001EZi00<005Zi00000eZi00P005ZIFYT005ZI001JV@0015ZI00H005JIEYUFV@00EYT3
00000eJI001FV@04EYT01000EYUFVEJI0P001E:I00<007ooOol057oo00<007ooOol0?7oo000GOol0
15[F248003W>1goo10000SXJ00D0039M<UdbG@00008^G@04000^OBim0002;Wh00`00;Wh00007001_
Ool00`00Ic/00003Ic/20002IcX01@00IcYW>VLj00000fLJ00<006LJ000016LJ00<006LJ000016LJ
0P001FLJ0P001F<J0P001F;j0P001F;j0P0016;j00<006;j000016;j00<006;j000016;J00H006;J
H]X005kJ0005G]T20005G]T00`00G]T00003G]T3000015ji001N^@001Eji00<005Zi00000eZi00<0
05ZiF[T00UZi0P001EZi00<005ZIFYT00`001EZI00@005JIEYUFV@8000EFV@03001FVEJI009FV@06
001FV@00001FV@001E:I00<007ooOol05Goo00<007ooOol0>goo000FOol01V<H6<IcW7>L48ABU0Io
o`04001oogoo0002>QX<0002;Wh01000;Wh^OP000Rin00<002in;Wh01`00Igoo00L006LkIc]W>`00
Ic/00005IcX00`00IcX00004IaX20005IaX20004IaX00`00IaX00004IaX00`00HaX00004HaX00`00
H_X00004H_X00`00H_X00004H_X00`00H_X00004H_X20006H_X00`00H]YRfP03H]X00`00H]X00003
G]X01`00G]UNfEkI001Nf@0000ENf@800008G]T00000001Nf@00G[T000=N^@03001N^Eji009N^@80
00AJ^@03001J^EZi00800003F[T005Zi00AJ^@03001JV@0000<000EJV@06001FV@00001FV@001EJI
00<005JIEYT00UJI0P0015JI00<005:IDYT00U:I00<007ooOol05Goo00<007ooOol037oo0P0000<8
@WooOol00Woo00AJePQ2000icRAoo`005Woo00HQ25:DOomooe:D6<H6Ool01000Oomoogoo0P0000=:
FP00?S/00Shk00@003IL=U`0008fG0P0008^OP05000^ORin;Wh00002;Wh00`00;Wh0000:001KOol0
0`00Ic]W>`03Ic/00`00IcYW>P04IcX20004IaX00`00IaX00003IaX200000fLJ001W6P02IaX01@00
IaYW6VLJ00000VLJ00D006<JHaYS6P00009S6P05001RnV;jH_X00002H_X01@00H_YRnV;j00000V;j
00D006;jH_YRnP00009RnP03001RnP0000ERnP8000ERfP8000ENfP03001Nf@0000=Nf@03001NfEkI
00D000ANf@8000AN^@03001N^Eji00800003F[T005Zi00=J^@03001J^@0000AJ^@03001J^EZi009J
^@8000=JV@8000AJV@8000AFV@03001FVEJI009FV@03001FV@0000800003EYT005JI00=FV@03001B
VE:I009BV@8001Moo`03001oogoo00aoo`03001oogoo009oo`06HaPHaW>LLi`@Q5:D8goo000FOol0
0`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00000dYJ00D003hk?S/n>`00008fG005000f
G3IL=U`00002<Ud00`00<Ud0000;0002;Wh01000:WhZOP000bYn00<002Yn00001P00Dgoo00<006Lk
Ic/00fLk00<006Lj00000fLj0P0000=W6P00IaX00VLJ00L006LJIaYW6P00IaX00004IaX00`00IaX0
0004IaX00`00IaX00004HaX00`00HaX00004H_X00`00H_X00004H_X00`00H_X00004H_X00`00H_X0
0003H_X01@00H_YRnV;j00000V;J00L006;JH]YRfP00H]X00005G]X20004G]T00`00G]T000020002
G]T00`00G]UNf@0200000eji001N^@03G[T00`00G[T00004F[T01000F[UJ^EZi0P001EZi00<005Zi
F[T00P0000=JV@00FYT00UZI0P0000IJV@00000005JI0005EYT01000EYUFVEJI0P001EJI00H005JI
EYUFV@00DYT300000e:I001oo`0GOol00`00Oomoo`07Ool60003Ool01R48DYAoogooDY@HaR=oo`00
5Woo00<007ooOol00Woo00<007ooOol017oo0P000goo00D004YJBUY:FP00008n>`05000fG3IL=U`0
0003=U`01000<UdbG@000S9M00@0039M<Ud0008^O@03000^OBim00P000<ZOP03000ZOP0000<ZOP03
000ZOP0000L004Yoo`03001W>`0000=W>`07001W>VLjIcX006Lj000016LJ00<006LJ00001FLJ00<0
06LJIaX016LJ00<006LJIaX00fLJ0P001F<J0P001F;j0P001F;j0P001F;j0P001F;j00<006;j0000
16;J00<006;J00000f;J00<005kJG]X00P0000=Nf@00G]T00UkI0`001EkI00<005kI000015ji00@0
05jiG[UN^@8000EJ^@06001J^@00001J^@001EZi00<005Zi000015ZI00@005ZIFYUJV@8000EFV@03
001FVEJI009FV@06001FV@00001FV@001EJI00<005JIEYT00`001E:I00<007ooOol05Goo00<007oo
Ool01goo00DicU:DOomoo`0000Aoo`03001oogoo009oo`03001oogoo025oo`005Woo00<007ooOol0
0Woo00<007ooOol00goo0P0017oo00<004YJBUX050000S9M00@002im;Wd0008^O@06000^OBim;Wd0
02in20000bYn00@002Yn:Wh000<ZOP03000ZOP0000L0045oo`07001W>fLkIc/006Lk000016Lj0P00
1VLJ00<006LJIaX00fLJ0P001FLJ00<006LJ00000fLJ00@006<JHaX000=S6P04001RnV;j0003H_X0
1000H_YRnP000f;j00<006;j000016;j00<006;j00001F;j0P001F;J0P0016;J00<005kJ000015kI
100000=Nf@00G]T015kI0P001Eji00H005ji000005ji0005F[T20004F[T00`00F[UJ^@02F[T20005
FYT01P00FYUJV@00FYT000EFV@03001FVEJI009FV@8000AFV@03001FVEJI009FV@<0009FV@03001B
VE:I00=BV@03001oogoo01Ioo`03001oogoo00Ioo`05Li`HaW>LOol00004Ool00`00Oomoo`02Ool0
0`00Oomoo`0QOol001Ioo`068@QBU7ooOomBU2481Goo00<007ooOol017oo0P000Tij00@004IJAUX0
00<nF`05000jG3YL>U`00002=U`00`00=U`fG0080002;Wd01@00;Wd^OBim00000Rin00@002in;Wh0
008^OPP000<ZOP04000ZORYn0002:Wh00`00:WhZOP07000iOol00`00Ic]W>`02Ic/20004IcX00`00
IaX00005IaX00`00IaX00003IaX01000IaYW6P000fLJ00L006LJIaYW6P00IaX00004HaX00`00HaX0
0004H_X00`00H_X00004H_X00`00H_X00003H_X01000H_YRnP000f;j00<006;jH_X00P0000=RnP00
H]X00V;J0P0000=RfP00H]X00f;J0P000UkI100000=Nf@00G]T00UkI00L005kIG]UNf@00G]T00005
G[T20004G[T01`00F[UJ^EZi001J^@0000EJ^@06001J^@00001J^@001EZI00<005ZI00000eZI00<0
05JIEYT00UJI00<005JI00000P0000=FV@00EYT00eJI00<005JI00000P0000=FV@00EYT00eJI00<0
05:IDYT00U:I00<007ooOol05goo00<007ooOol01Woo00ABU36<Ool000Aoo`03001oogoo009oo`03
001oogoo025oo`005Woo00IS61S6LiacW1S6HaP5Ool00`00Oomoo`04Ool00`00CWY>NP02CWX01000
AUY6FP000ciK00D003YL>U`jG000008fG004000fG3IL0003=Ud00`00<Ud0000;0002;Wh01000;Wh^
OP000bin00<002in000020000RYn00D002Yn:WhZOP00008ZOP03000ZOP0000L002moo`8000AW>`03
001W>P0000=W>P05001W6VLJIaX00003IaX01`00IaYW6VLJ001W6P0000AW6P03001W6P0000AW6P80
00ES6P8000ERnP8000ERnP8000ARnP03001RnP0000ARnP03001RnP0000ARnP03001RfP0000ARfP05
001RfV;J001NfP030003G]T20005G]T00`00G]T00003G]T00`00G[UN^@0200000eji001N^@04G[T0
0`00F[T00003F[T00`00F[UJ^@02F[T20004F[T00`00FYUJV@02FYT20004FYT20003EYT20005EYT0
1000EYUFVEJI0P001EJI00<005JIEYT00UJI00<005:IDYT00`0067oo00<007ooOol01goo00<Q26<H
000017oo00HQ25:DOomooe:D8@PSOol001Moo`04F]H8@PQ2HaP6Ool30005Ool01@00CWY>NTij0000
0dIJ00D003iK?U/nF`00008jG005000fG3IL=U`00002=U`01@00=UdfGCIM00000S9M00@0039M<Ud0
008bG@03000bGC9M00P000<^OP04000^ORin0002;Wh00`00;Wh^OP0<0003:Wh01@00:WhZOP00:Wh0
20009Goo0P0000=W>`00Ic/00VLk00L006LjIcYW>P00IcX00005IaX00`00IaX00004IaX20005IaX2
0004IaX00`00HaX00004HaX00`00H_X00004H_X00`00H_X00004H_X00`00H_X00004H_X20005H_X2
0006H_X00`00H]YRfP03H]X00`00H]X0000200000ekJ001Nf@02G]T00`00G]T00005G]T20004G]T0
0`00G[T00004G[T00`00G[UN^@02G[T20004F[T00`00F[UJ^@0200000eZi001J^@03F[T00`00FYT0
000200000eZI001JV@04FYT01P00EYT00000EYT000EFV@06001FV@00001FV@001EJI00<005JIEYT0
0UJI0`000U9i00<007ooOol05goo0P001goo00=[FR48000017oo00IS61S6LiacW1S6HaPSOol0025o
o`03001oogoo00Ioo`04001>NTij0002AUXH0002<Ud01000<UdbG@000c9M00D0039m<Wd002im00T0
008^OP04000^ORin0003;Wh01P00;Wh^ORin000^OPT000<ZOP05000ZORYn000ZOP09000KOol00`00
Ic]W>`02Ic/00`00Ic/00005IcX00`00IaYW6P04IaX20004IaX00`00IaX00003IaX200000fLJ001W
6P02IaX01@00HaYS6V<J00000V<J00D006;jH_YRnP00009RnP05001RnV;jH_X00002H_X01@00H_YR
nV;j00000V;j00@006;jH_X000=RnP03001RnP0000ERnP8000ERfP<000ANfP03001Nf@0000=Nf@03
001NfEkI00800003G]T005kI00=Nf@8000EN^@03001N^Eji00800003G[T005Zi00=J^@03001J^@00
00AJ^@04001J^EZiF[T20005FYT00`00FYUJV@02FYT20004EYT00`00EYUFV@02EYT20004EYT00`00
EYUFV@02EYT00`00EYT0000200000eJI001BN@03DWT00`00Oomoo`0DOol200000goo001oo`07Ool0
0cW>249oo`04Ool015[F2488@V<H97oo000QOol00`00Oomoo`06Ool00`00CWY>NP030002BUX01@00
@U]2Fd9K00000SiK00D003iL?U`nG000008jG005000fG3IL=U`00002=U`80003<Ud01000<WdbO@00
0Rim00H002im;Wd^O@00;Wd80003;Wh01@00;Wh^ORin00000Rin00H002in;Wh^OP00;Wh90003:Wh0
1000:WhZOP000RYn20004Goo0P001FLk0P001FLj00<006LJ00000fLJ0P0000=W6P00IaX00VLJ00L0
06LJIaYW6P00IaX00004IaX00`00IaX00004HaX00`00HaX00004H_X00`00H_X00004H_X00`00H_X0
0004H_X00`00H_X00004H_X00`00H_X00003H_X01@00H_YRnV;j00000V;J00<006;J00000P0000=N
fP00G]X015kJ0P0015kI00<005kI000015kI00H005kIG]T005ji0005G[T00`00G[T00004G[T01000
F[UJ^EZi0P001EZi00H005ZiF[T005Zi0005FYT00`00FYT0000200000eZI001FV@03EYT00`00EYUF
V@0200000eJI001FV@03EYT00`00EYUFV@02EYT20005EYT01@00DWUBNE9i00006Goo00<007ooOol0
=Goo000QOol00`00Oomoo`07Ool200000dij001:FP03BUX01@00@U]2Fd9K00000SiK00D003iL?U`n
G000008jG005000fG3IL=U`00002=U`01000=UdfG@000SIM30000bim00<002im00000bim00<002im
000030000bin00@002in;Wh000<^OP03000^OP0000P000<ZOP04000ZORYn0002:Wh80007Ool20002
Dad01@00Ic]W>fLk00000VLj00D006LjIcYW>P0000=W6P03001W6P0000AW6P03001W6P0000EW6P03
001W6VLJ00AW6P03001S6V<J00=S6P8000ERnP8000ERnP8000ERnP8000ERnP8000ERnP03001RnP00
009RfP@000ANfP03001NfUkJ00800003G]T005kI00=Nf@8000ENf@03001Nf@0000=N^@03001N^Eji
009N^@8000EN^@06001J^@00001J^@001EZi00<005Zi00000eZi00<005ZIFYT00UZI0P001EZI00L0
05JIEYUFV@00EYT00004EYT01P00EYUFVEJI001FV@<00003EYT005JI00AFV@05001BNE9iDWT0000J
Ool00`00Oomoo`0dOol0021oo`<000Qoo`05001>NTijCWX00004BUX01000@U]2F`000ciK00@003iL
?U`000<jG005000fG3IL=U`00002=U`01000=UdfG@000cIM00@0039M<Ud0008bG@03000bGC9M00P0
00<^O@04000^OBim0003;Wh01P00;Wh^ORin000^OPT000<^OP04000^ORin0003;Wh00`00;Wh00008
0004:Wh01@00:WhZOP00:Wh01`001E<M00<006Lk000016Lj00<006Lj00001FLJ00<006LJIaX00fLJ
0P001FLJ0P001FLJ00<006LJ00000f<J00@006<JHaX000=RnP04001RnV;j0003H_X01000H_YRnP00
0f;j00<006;j000016;j00<006;j00001F;j1@000V;J00<005kJG]X00ekJ00<005kJ000015kI00H0
05kIG]T005kI0005G]T20005G[T01P00G[UN^@00G[T000EN^@8000AJ^@03001J^EZi009J^@8000EJ
^@06001JVEZI001JV@001EZI0P000UJI0P001EJI00@005JIEYUFV@8000EFV@03001FVEJI009FV@03
001BNE9i00<001Yoo`03001oogoo03=oo`0087oo00<007ooOol02Goo00D004ijCWY>NP00009:FQ/0
00<fG@04000bGC9M0002<Ud01@00<UdbGC9M00000S9M00<0039M<Ud020000bin00D002in;Wh^OP00
008^OP06000^ORin;Wh002in2@000bin00@002in;Wh000<^OP03000^OP0000T000<ZOP04000ZORYn
0005Dad20005IcX20005IaX00`00IaX00003IaX01000IaYW6P000fLJ00@006LJIaX000=W6P07001W
6VLJIaX006<J000016<J00<006;j000016;j00<006;j000016;j00<006;j00000f;j00@006;jH_X0
00=RnP03001RnV;j00@000ARfP8000ENfP8000ENf@03001Nf@0000=Nf@07001NfEkIG]T005kI0000
1Eji00<005ji00000eji00<005jiG[T00P0000=J^@00F[T00eZi00<005Zi00000P0000=J^@00F[T0
15Zi00<005ZI00000eZI00<005ZIFYT00UZI00H005JI000005JI0005EYT01P00EYT00000EYT000EF
V@03001FVEJI009FV@<0009BN@03001oogoo01Qoo`03001oogoo03=oo`0087oo00<007ooOol02Goo
00<004ijCWX010000TYj00@004IJAUX000=2F`04000nFciK0003?U`01@00>U`jG3YL00000SYL00<0
03IL=U`030000c9M00@0039M<Ud0008bG@06000bOC9m<Wd0039m3@000bin00@002in;Wh000<^OP03
000^OP0000P000<^OP04000^ORin0003;Wh00`00;Wh^OP0900001U<M00000000D_d000=W>P80009W
6P05001W6VLJIaX00003IaX00`00IaX00004IaX00`00IaX00004IaX00`00IaX00004IaX20005HaX2
0005H_X20005H_X20004H_X00`00H_X00004H_X40003H_X01000H]YRfP000V;J00L005kJG]YNfP00
G]T00005G]T20005G]T00`00G]T00003G]T00`00G[UN^@02G[T20004G[T00`00G[T00004F[T01000
F[UJ^EZi0P001EZi00<005ZiF[T00UZi0P0015ZI00<005ZIFYT00UZI0`000eJI00<005JIEYT00UJI
0P0015JI00<005JIEYT00UJI00<005JI00000P0000=FV@00DWT00e9i00<007ooOol067oo00<007oo
Ool0<Woo000POol01000Ool000002Goo0P000Tij00<004YjBWX00TYj00@004IJAUX000=2F`04000n
FciK0003?U`01@00>U`jG3YL00000SYL00D003IL=U`fG000008fG004000fGCIM0002=Ud<0003<Wd0
1000<WdbO@000bim00@002im;Wd0008^O@T000<^OP04000^ORin0003;Wh00`00;Wh000080003;Wh0
1@00;Wh^ORin00000bYn00@002Yn000000EBo@03001W>P0000EW6P03001W6P0000AW6P8000EW6P80
00EW6P8000AW6P03001S6P0000AS6P03001RnP0000ARnP03001RnP0000ARnP03001RnP0000ARnP80
00=RnP@000ERnP03001RfP0000ARfP03001NfP0000=Nf@07001NfEkIG]T005kI00001EkI0P0015kI
00<005jiG[T00P0000=N^@00G[T00eji0P001EZi00H005ZiF[T005Zi0005F[T00`00F[T000020000
0eZI001JV@03FYT00`00FYT00002000015JI001FV@000UJI00<005JI00000P0000=FV@00EYT015JI
00@005JIEYUFV@8000EFV@05001BNE9iDWT0000KOol00`00Oomoo`0aOol0021oo`8000]oo`03001>
NTij009>NP05001:NTYjBWX00003AUX01000@U]2F`000ciK00D003iL?U`nG000008jG005000jG3YL
>U`00003=U`01000=U`fG0000SIM00D003IM=UdfG@00008bG@04000bGC9M0002<Ud90003;Wd01000
;Wd^O@000Rim00D002im;Wd^O@00008^O@T000<^OP04000^ORin0003;Wh00`00;Wh000090003:Wh0
1000:WhZOP0015;m0P001VLJ0P0016LJ00<006LJ000016LJ00<006LJ00000fLJ0P0000=W6P00IaX0
0VLJ00D006<JHaYS6P00009S6P05001RnV;jH_X00002H_X01@00H_YRnV;j00000V;j00D006;jH_YR
nP00009RnP03001RnV;j00<00004H_X006;j0005H_X20005H]X20005G]T00`00G]T00003G]T00`00
G]UNf@0200000ekI001Nf@03G]T00`00G[T00004G[T01P00G[UN^@00G[T000EJ^@03001J^@0000=J
^@03001J^EZi009J^@8000EJV@04001JVEZIFYT20005EYT01000EYT005JI0P001EJI00<005JIEYT0
0UJI00H005JI000005JI0005EYT01000DWUBNE9i0P006Woo00<007ooOol0<Goo000POol00`00Oomo
o`0;Ool00`00CWY>NP02CWX01000BWY:NP000TIJ7`000cIM00@0039M<Ud0008bG@05000bGC9M<Ud0
0002<Ud00`00<UdbG@090002;Wd01@00;Wd^OBim00000Rim00D002im;Wd^O@00008^OPT000<^OP04
000^ORin0003;Wh00`00;Wh^OP0900001E;m000005;m00001FLJ00<006LJ00000fLJ00D006LJIaYW
6P00009W6P07001W6VLJIaX006LJ000016LJ00<006LJ000016<J00<006<J000016;j00<006;j0000
16;j00<006;j000016;j00@006;j001RnP@00003H_X006;j009RnP07001RnV;jH_X006;J000016;J
00<005kJ00001EkI0P0015kI00<005kI000015kI00@005kIG]UNf@8000EN^@03001N^@0000=N^@03
001J^EZi009J^@8000EJ^@06001J^EZi001J^@001EZI00H005ZI000005ZI0005EYT01P00EYT00000
EYT000EFV@03001FVEJI009FV@8000AFV@03001FVEJI009FV@06001BN@00001BN@006goo00<007oo
Ool0<7oo000;Ool400000`Q2Oomoo`02Ool015[F248003W>1goo00<007ooOol03Goo00D004ijCWY>
NP00009:NP<0009:FP040016FdIK0003@U/01@00@U]2Fd9K00000ciL00@003iL?U`000<jG004000j
G3YL0002=U`<0003<Ud01000<UdbG@000S9M00D0039M<UdbG@00008bO@P000<^O@05000^OBim;Wd0
0002;Wh01@00;Wh^ORin00000Rin2@000bin00@002in;Wh000<^OP03000^ORin008000ABo@05001W
6VLJIaX00003IaX00`00IaX00004IaX00`00IaX00005IaX00`00IaYW6P03IaX20005HaX20005H_X2
0005H_X20005H_X40003H_X20005H_X00`00H_X00003H]X01000H]YRfP000ekJ00<005kIG]T00P00
00=Nf@00G]T00ekI0P001EkI00H005kI000005ji0005G[T20005G[T01P00F[UJ^@00F[T000EJ^@03
001J^@0000=J^@03001JVEZI009JV@8000AJV@03001FVEJI009FV@800005EYT005JIEYT00004EYT0
0`00EYT0000200000eJI001FV@03EYT00`00EYUFV@02EYT20004DWT00`00Oomoo`0IOol00`00Oomo
o`0_Ool000eoo`03001oogoo00=oo`06HaPHaW>LLi`@Q5:D1Woo0`003Goo00<004ijCWX0100000=>
NP00BUX00dYJ00@004IKAU/000=2F`050012Fd9K@U/00003?U`01000?U`nG0000cYL00@003YL>U`0
00<fG004000fG3IL0002=Ud00`00=UdfG@090002<Ud01@00<UdbGC9M00000S9m00H0039m<WdbO@00
<Wd90003;Wh01@00;Wh^ORin00000Rin00D002in;Wh^OP00008^OPT000<^OP05000^ORin;Wh00004
D_d00`00IaX00005IaX00`00IaYW6P03IaX20005IaX00`00IaX00003IaX01000HaYS6P000f<J00@0
06;jH_X000=RnP04001RnV;j0003H_X01000H_YRnP000V;j100016;j00<006;j00001F;j0P0016;J
00<006;J000015kJ00<005kI000015kI00H005kIG]T005kI0005G]T20004G[T01`00G[UN^Eji001N
^@0000EN^@03001J^@0000=J^@03001J^EZi009J^@8000AJ^@03001JVEZI00800003FYT005ZI00=J
V@03001FVEJI00800005EYT005JIEYT00002EYT01000EYUFVEJI0P001EJI00H005JIEYUFV@00EYT3
00000eJI001BN@04DWT00`00Oomoo`0HOol00`00Oomoo`0_Ool000eoo`03001oogoo00=oo`068@QB
U7ooOomBU1S61Woo00<007ooOol03Woo0P000U9j00D004ijCWY>NP0000=:FP050016FdIKAU/00003
@U/01000@U]2F`000SiL1P000SYL00D003YL>U`jG00000<fG004000fG3IL0002=Ud01@00=UdfGCIM
00000cIM00<0039M00002`000c9m00@0039m<Wd000<bO@03000^O@0000P000<^OP05000^ORin;Wh0
0003;Wh01000;Wh^OP000Rin1@0012in00<005;mD_d00`001FLJ00<006LJ00000fLJ00@006LJIaX0
00=W6P07001W6VLJIaX006LJ000016<J00<006<J000016;j00<006;j000016;j00<006;j00000f;j
10000f;j00@006;jH_X000=RnP03001RnV;j00800003H]X006;J00=RfP8000ENfP8000ENf@03001N
f@0000=Nf@07001NfEkIG]T005kI00001Eji00<005ji00000eji00<005jiG[T00Uji0P0015Zi00<0
05Zi00000P0000=J^@00F[T00eZi00<005ZI000015ZI00L005ZIFYUJV@00EYT00004EYT01`00EYUF
V@00EYT005JI00800003EYT005JI00AFV@04001FVEJIEYT20005EYT00`00DWUBN@02DWT00`00Oomo
o`0IOol00`00Oomoo`0^Ool000eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo00ioo`03001BNU9j009BNP05001>NTijCWX00002BUX>0002@U/00`00?U/nF`0C0003=Ud0
1`00=UdfGCIM000bG@0000<bG@04000bGC9M0002<Ud90003<Wd01000;Wd^O@000bim00<002im0000
200012in00@002in;Wh000<^OP03000^OP0000L000=Bo@05001W6VLJIaX00003IaX00`00IaX00004
IaX00`00IaX00005IaX00`00HaYS6P04HaX00`00H_YRnP03H_X20005H_X200001F;j00000000H_X0
0P0016;j00<006;j000016;j00<006;j000016;J00@006;JH]X0009RfP07001NfUkJG]X005kI0000
1EkI0P001EkI00<005kI00000ekI00<005jiG[T00Uji0P0015ji00<005ji00000P0000=J^@00F[T0
0eZi0P001EZi00@005ZiF[UJ^@8000EJV@04001JVEZIFYT20005EYT01000EYUFVEJI0`0015JI00<0
05JIEYT00UJI00H005JI000005JI0005EYT00`00DWUBN@02DWT2000IOol3000_Ool000eoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00moo`05001BNU9jDWX00002CWX4
00000dYj0016FP02AUX01@00AU]6FdIK00000T9K00<0049K@U/00T9K00@003iK?U/000<nG004000j
G3YL0003>U`01000>U`jG0000SIL30000c9M00@0039M<Ud000<bG@04000bGC9M0002<Ud90003;Wd0
1000;Wd^O@000bim00<002im00002@000bin00@002in;Wh000<^OP03001BoE;m00=Bo@03001W6P00
00AW6P8000EW6P8000EW6P8000ES6P8000ARnP03001RnP0000ARnP@000=RnP03001RnP0000ARnP80
00IRnP03001RfV;J00=RfP03001RfP0000ARfP03001NfP0000=Nf@03001NfEkI00800003G]T005kI
00ANf@8000ANf@03001N^Eji00800003G[T005ji00=N^@8000EJ^@06001J^EZi001J^@001EZi00H0
05Zi000005Zi0005FYT01P00FYT00000FYT000EFV@03001FV@0000800003EYT005JI00=FV@03001F
VEJI009FV@8000AFV@03001FVEJI009FV@03001BN@0000800003DWT007oo01Yoo`03001oogoo02eo
o`003Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo0P0047oo00<0059jDWX01000
0Tij00D004YjBWY:NP0000=6FP050016FdIKAU/00002@U/01@00@U]2Fd9K00000ciK00D003iL?U`n
G000008jG005000jG3YL>U`00002>U`01@00=U`fG3IL00000SIL00D003IM=UdfG@00008fG@P000<b
G@04000bGC9M0003<Ud01P00<WdbOC9m000bO@T000<^O@04000^OBim0003;Wd00`00;Wd^O@090003
;Wh01000D_eBoE;m0`0016LJ00<006LJ00000fLJ0P000VLJ00D006LJIaYW6P00009S6P05001S6V<J
HaX00002H_X01000H_YRnP000f;j00<006;j00000P000V;j00@006;jH_X000=RnP06001RnV;j001R
nP001F;j0P001F;J0P001F;J0P0015kI00<005kI000015kI00<005kIG]T00P0000=Nf@00G]T00ekI
00<005ji000015ji00H005jiG[T005ji0005F[T00`00F[T00003F[T00`00F[UJ^@02F[T20004F[T0
0`00FYUJV@02FYT20004FYT00`00EYUFV@02EYT20003EYT00`00EYT00003EYT00`00EYT000020000
0eJI001FV@03EYT00`00EYUFV@02EYT20005DWT00`00Oomoo`0IOol00`00Oomoo`0/Ool000eoo`03
001oogoo00=oo`068@QBU7ooOomBU2481Goo0P004Woo0P000U9j00<004ijCWX00Tij00D004YjBWY:
NP0000=6FP040016FdIK0003@U/00`00@U]2F`0<0003>U`01@00>U`jG3YL00000cIL00@003IL=U`0
00<fG@04000fGCIM0002=Ud00`00=UdfG@090003<Ud01@00<WdbOC9m00000S9m00H0039m<WdbO@00
<Wd90003;Wd01000;Wd^O@0012im00<002in00001`000U;m00D006LJIaYW6P0000=W6P03001W6P00
00EW6P03001W6P0000AS6P03001S6P0000=RnP03001RnP0000ARnP<000ARnP03001RnP0000ARnP03
001RnP0000=RnP05001RnV;jH_X00002H_X01`00H]YRfV;J001RfP0000ARfP03001NfP0000ANf@80
00ENf@03001Nf@0000ANf@04001NfEkIG]T20005G[T00`00G[T00003G[T00`00F[UJ^@02F[T20004
F[T00`00F[UJ^@0200000eZi001J^@04F[T01P00FYT00000FYT000EJV@06001FV@00001FV@0015JI
0P000eJI0P001EJI00H005JIEYUFV@00EYT300000eJI001BN@04DWT00`00Oomoo`0IOol00`00Oomo
o`0/Ool000]oo`03000Q200000Eoo`06HaPHaW>LLi`HaV<H1Goo00<007ooOol04Goo00<0059jDWX0
0U9j00D004ijCWY>NP0000=:NP030016FTIJ00/00003@U/0049K0092F`05000nFciK?U/00002?U`?
0003=Ud01@00=UdfGCIM00000SIM00D003IM=UdfG@0000<bG@03000bG@0000`000<bO@04000bOC9m
0003<Wd00`00<Wd000080004;Wd01000;Wh^OP000bin00<005;mD_d00U;m00<006LJ00001FLJ00<0
06LJIaX016LJ0P001F<J0P0016;j0P000V;j1@001F;j0P001F;j0P001F;j00<006;j000016;j00<0
06;J00000f;J00@006;JH]X000=NfP06001NfEkI001Nf@001EkI0P001EkI00H005kIG]T005ji0005
G[T20004G[T00`00F[UJ^@0200000eZi001J^@03F[T00`00F[T00004F[T00`00F[UJ^@02F[T20004
FYT00`00FYUJV@02FYT20004EYT01000EYUFVEJI0P0000EFV@00001FV@0000EFV@04001FVEJIEYT2
0005EYT00`00DWUBN@02DWT00`00Oomoo`0JOol00`00Oomoo`0[Ool000]oo`03HaPYBP0000Ioo`04
F]H8@PQ2HaP6Ool00`00Oomoo`0BOol00`00DWYBNP02DWX00`00CWY>NP070002BUX01000AU]6F`00
0dIK00D0049K@U]2F`0000=2F`05000nFciK?U/00002?U`01@00>U`jG3YL00000SYL00D003YL>U`j
G000008jG0`000<fG@07000bGC9M<Ud0039M00000c9M00D0039M<UdbG@00008bG@T000<bO@04000b
OC9m0003;Wd00`00;Wd000090003;Wh00`00D_eBo@030005IaX20005IaX00`00HaX00003HaX20000
0f<J001RnP02H_X00`00H_X000020002H_X01000H_YRnP000f;j00@006;jH_X000=RnP03001RnP00
00ERnP8000ERnP8000ARfP03001RfP0000ANfP03001Nf@0000=Nf@07001NfEkIG]T005kI00001EkI
00<005kI00000eji00<005jiG[T00P0000=N^@00G[T00eji00<005Zi000015Zi00@005ZiF[UJ^@80
00EJ^@03001J^EZi00800003FYT005ZI00=JV@03001JVEZI00800003EYT005JI00=FV@03001FVEJI
009FV@8000AFV@03001FVEJI009FV@06001FV@00001FV@001EJI00<0059iDWT00U9i0P0077oo00<0
07ooOol0:Woo000NOol3000COol01000DWYBNU9j0`0000=>NP00BWX00TYj00<004YJBUX00TYJ00@0
04IKAU/000=6F`050012Fd9K@U/00003@U/01000?U/nF`000ciL00D003YL>U`jG000008jG005000j
G3YL>U`00002>U`01@00=U`fG3IL00000SIL00<003IM=Ud030000c9M00D0039M<UdbG@00008bG@05
000bGC9M<Ud00002<Ud90003;Wd01000;Wd^O@000bim00<002im;Wd01`000e;l00D006LJIaYW6P00
009W6P05001W6VLJIaX00003HaX00`00HaX00004HaX00`00H_X000020002H_X00`00H_X00004H_X0
0`00H_X00004H_X00`00H_X00003H_X00`00H_YRnP0200000f;j001RnP02H_X200000f;J001RfP03
H]X20006G]X00`00G]UNf@03G]T00`00G]T00003G]T00`00G]UNf@02G]T20004G[T00`00G[T00004
G[T01000G[UN^Eji0P001EZi00H005Zi000005Zi0005F[T00`00F[T00004FYT01`00FYUJVEZI001J
V@0000AFV@06001FVEJIEYT005JI0`0000=FV@00EYT00eJI00@005JIEYUFV@<000AFV@03001FVEJI
009FV@03001BN@0000800003DWT007oo01]oo`03001oogoo02Yoo`007Woo00<007ooOol04goo00H0
059j0000059j0003CWX01@00BWY:NTYj00000dYJ00D004IKAU]6F`000096F`030012Fd9K01D0008j
G005000jG3YL>U`00003=U`01000=U`fG0000SIM00D003IM=UdfG@0000<fG@03000fGCIM00P000<b
G@05000bGC9M<Ud00002<Ud01@00<WdbOC9m00000S9m2@000bim00@002im;Wd000@^O@03001Bo5;l
009Bo003001W6P0000AW6P03001W6P0000ES6P03001S6V<J009S6P<000IRnP03001RnV;j00=RnP80
00ERnP8000ARnP03001RnP0000ARnP03001RnP0000ARfP06001RfV;J001NfP001EkJ0P001EkI0P00
15kI00<005kIG]T00P0000=Nf@00G[T00eji0P001Eji00H005ji000005Zi0005F[T20004F[T00`00
F[UJ^@02F[T20005FYT01000FYUJVEZI0P001EJI00@005JIEYUFV@8000EFV@04001FVEJIEYT40002
EYT00`00EYUFV@03EYT00`00EYUFV@030005DWT00`00Oomoo`0JOol00`00Oomoo`0YOol001ioo`03
001oogoo01Aoo`03001BNU9j009BNP05001>NTijCWX00002BWX00`00BUY:FP0;0002@U/01@00@U]2
Fd9K00000T9K00D003iK?U/nF`0000<nG003000nG3iL0100008fG@05000fGCIM=Ud00003=Ud01000
=UdfG@000SIM00<0039M<Ud02@000c9M00D0039m<WdbO@00008bO@05000bOC9m<Wd00002<Wd90004
;Wd00`00D_aBo0030005IaX20005HaX200001F<J00000000HaX00P001F;j0P0016;j00<006;j0000
16;j00<006;j000016;j0P001V;j00<006;JH]X00f;J00<006;J00000ekJ00D005kJG]YNfP00009N
f@03001NfEkI00800003G]T005kI00=Nf@03001Nf@0000ANf@06001N^Eji001N^@001Eji0P0015Zi
00L005ZiF[UJ^@00F[T00005F[T01P00F[T00000F[T000EJV@06001JV@00001JV@001EJI00H005JI
000005JI0005EYT01P00EYT00000EYT000EFV@03001FVEJI009FV@<0009FV@03001BNE9i00=BN@03
001oogoo01]oo`03001oogoo02Qoo`007Woo00<007ooOol057oo00<0059jDWX00U9j00D004ijCWY>
NP00009:NP<0009:NP050016FTIJAUX00002AU/00`00@U]2F`02@U/01@00@U]2Fd9K00000T9K00D0
03iK?U/nF`0000<nG004000nG3iL0002>U`01@00>U`jG3YL00000cYL00<003YL>U`030000cIM00@0
03IM=Ud000<bG@04000bGC9M0002<Ud90003<Wd01@00<WdbOC9m00000c9m00@0039m<Wd0008bO@P0
00=Bo005001W6VLJIaX00002IaX01000HaYS6V<J10000f<J00@006;jH_X000=RnP04001RnV;j0002
H_X01@00H_YRnV;j00000V;j00D006;jH_YRnP00009RnP03001RnP0000ERnP8000ERfP8000ENfP03
001NfP0000=Nf@03001Nf@0000ANf@04001NfEkIG]T20005G]T00`00G[T00003G[T01`00G[UN^Eji
001N^@0000EJ^@03001J^@0000=J^@03001J^EZi009J^@8000AJ^@03001JVEZI009JV@8000AJV@03
001FVEJI009FV@8000AFV@03001FVEJI009FV@8000AFV@03001FVEJI009FV@03001FV@0000800003
EYT005JI00=FV@03001BNE9i009BN@03001oogoo01]oo`03001oogoo02Qoo`007Goo00<007oo0000
5Woo00D0059jDWYBNP00009>NP@00003CWX004Yj00=:NP050016FTIJAUX00002AU/00`00@U]2F`02
@U/01000@U]2F`000d9K00D003iK?U/nF`00008nG005000nG3iL?U`00002>U`01@00>U`jG3YL0000
0cYL00@003YL>U`0008fG005000fG3IL=U`00002=Ud90003<Ud01000<UdbG@000c9M00H0039M<Udb
G@00<Ud:0003<Wd01000<WdbO@000c9m00D0039m<WdbO@0000EBo003001W6P0000AW6P@000=S6P03
001S6P0000ARnP03001RnP0000=RnP03001RnP0000ARnP03001RnP0000ARnP03001RnP0000=RnP05
001RnV;jH_X00002H]X01`00H]YRfV;J001RfP0000ENfP8000ENf@03001NfEkI00=Nf@06001NfEkI
001Nf@001EkI0P001Eji00<005ji00000eji00<005ZiF[T00UZi0P0015Zi00<005ZiF[T00P0000=J
^@00F[T00eZi00<005ZI00000P0000=JV@00FYT00eZI00<005JI00000P0000=FV@00EYT00eJI00<0
05JIEYT00P0000=FV@00000015JI00@005JIEYUFV@8000EFV@05001FVEJIEYT00003DWT3000MOol0
0`00Oomoo`0WOol001eoo`8001Moo`03001BNU9j00@0009>NP05001>NTijCWX00004BWX01000AUY6
FP000dIK00<0049K@U/060000cYL00@003YL>U`000<jG004000fG3IL0003=U`01@00=UdfGCIM0000
0SIM00<003IM=Ud02@000c9M00D0039M<UdbG@00008bG@05000bGC9M<Ud00002<Ud90003<Wd01@00
<WdbOC9m000015;l0P0016LJ0`001F<J0P001F;j0P0016;j0P001F;j0P001F;j0P001F;j00<006;j
000016;J00<006;J00000f;J00<005kJG]X00P0000=NfP00G]T00ekI0P001EkI00<005kI00000ekI
00L005kIG]UNf@00G[T00005G[T20004G[T00`00F[UJ^@0200000eZi001J^@03F[T00`00F[T00004
F[T01000F[UJ^EZi0P001EZI00@005ZIFYUJV@8000EFV@07001FVEJIEYT005JI000015JI0P000eJI
00H005JI000005JI0005EYT01000EYUFVEJI10000U9i00<007ooOol077oo00<007ooOol09Woo000M
Ool00`00Oomoo`0GOol20002DWX00`00CWY>NP02CWX01@00CWY>NTij00000dYj00<004IJAUX01`00
0TIK00@0049K@U/000=2F`050012Fd9K@U/00002?U/01@00?U`nG3iL00000SiL40000cIL00D003IM
=UdfG@00008fG@05000fGCIM=Ud00002=Ud00`00=UdfG@0=0003<Ud01000<UdbG@000c9m00<0039m
<Wd02@0000MBo000000005;l001W6P0400000f<J001S6P02HaX200000f;j001RnP02H_X200000f;j
001RnP02H_X01000H_YRnP000f;j00@006;jH_X000=RnP03001RnP0000ERnP8000ERfP8000ARfP03
001NfP0000ANfP04001NfEkI0002G]T00`00G]UNf@02G]T20005G]T00`00G]T00003G[T00`00G[UN
^@0200000eji001N^@03G[T00`00F[T00004F[T01000F[UJ^EZi0P001EZi00H005ZiF[T005Zi0005
FYT01P00FYUJV@00FYT000EFV@04001FVEJIEYT20005EYT20003EYT20004EYT00`00EYUFV@02EYT0
1P00EYT00000DYT000EBN@03001oogoo01]oo`8002Moo`007Goo00<007ooOol05goo00<0059jDWX0
0U9j00D004ijCWY>NP00009>NPP00003BUX004IK0096F`030016FdIK0096F`040012Fd9K0003@U/0
1@00@U]2Fd9K00000SiK00D003iL?U`nG000008nG005000jG3YL>U`00002>U`01@00>U`jG3YL0000
0SYL3@000cIM00@003IM=Ud0008fG@05000fGCIM=Ud00003<Ud00`00<UdbG@090003<Wd01000<Wdb
O@00139m00@0039m000000=Bo0<00003IaX006<J00=S6P03001S6P0000ARnP03001RnP0000ARnP03
001RnP0000ARnP03001RnP0000ARnP03001RnP0000=RnP03001RnV;j00800003H_X006;J009RfP80
0003H]X006;J00=RfP8000ENfP03001Nf@0000ANf@06001NfEkI001Nf@001EkI0P0015ji00<005ji
000015ji00@005jiG[UN^@8000EJ^@06001J^@00001J^@001EZi00<005Zi00000eZi00<005ZIFYT0
0UZI00<005ZI00000eZI00<005JIEYT00UJI00H005JI000005JI0005EYT00`00EYT0000200000eJI
001FV@03EYT00`00EYUFV@02EYT20004DYT00`00DWUBN@02DWT00`00Oomoo`0JOol00`00Ool0000W
Ool001eoo`<001Qoo`03001BNU9j009BNP03001>NTij00<0009>NP05001:NTYjBWX00003BUX01@00
AU]6FdIK00000dIK00D0049K@U]2F`000092F`050012Fd9K@U/00003?U/01@00?U`nG3iL00000SiL
00D003YL>U`jG000008jG005000jG3YL>U`00003>U`01000>U`jG0000cIL00<003IL=U`030000cIM
00D0039M<UdbG@0000<bG@04000bGC9M0002<Ud90004<Wd00`00<WdbO@030002D_`20006HaX00`00
H_YRnP04H_X00`00H_YRnP04H_X00`00H_YRnP03H_X20005H_X20004H_X00`00H_X00004H_X00`00
H]X00004H]X01P00H]YRfP00G]X000ENfP8000ENf@03001Nf@0000=Nf@03001NfEkI00800003G]T0
05ji00=N^@8000EN^@06001N^@00001J^@001EZi0P0015Zi00<005ZiF[T00UZi0P0015Zi00<005ZI
FYT00UZI0P0015ZI00<005JIEYT00UJI0P0015JI00<005JIEYT00UJI0P0000=FV@00EYT00UJI00H0
05JIEYUFV@00EYT300000eJI001BV@03DYT00`00DWUBN@02DWT00`00Oomoo`0MOol00`00Oomoo`0T
Ool001eoo`03001oogoo01Uoo`03001BNU9j00@00003CWX004ij00=>NP05001:NTYjBWX00003BUX0
1000AU]6F`000dIK00<0049K@U/070000cYL00D003YL>U`jG000008jG005000fG3IL=U`00002=U`0
1@00=UdfGCIM00000SIM00<003IM=Ud02@00139M00@0039M<Ud000<bG@04000bGC9M0002<Ud:0000
1E;l000005;L00001F<J0P001F;j0P001F;j0P0016;j00<006;j000016;j00<006;j000016;j0P00
1V;j00<006;JH]X00f;J00<006;J00000ekJ00L005kJG]YNfP00G]T00005G]T20004G]T00`00G]T0
0004G]T01P00G[UN^@00G[T000EN^@8000AJ^@07001J^EZiF[T005Zi000015Zi00<005Zi00000P00
00=J^@00F[T00eZi00<005ZI00000P0000=JV@00FYT00eZI00<005JI00000P0000=FV@00EYT015JI
00P005JI000005JI001FV@000eJI00@005JIEYUFV@8000EFV@05001BVE:IDYT00003DWT3000NOol0
0`00Oomoo`0TOol001aoo`03001oogoo01]oo`80009BNP05001>NTijCWX00003CWX01@00BWY:NTYj
00000TYJ2`000TIK00@0049K@U/000=2F`050012Fd9K@U/00003?U/01000?U`nG0000ciL00<003iL
?U`030000cIL00D003IL=U`fG00000<fG@04000fGCIM0003=Ud01000=UdfG@000SIM2P000c9M00@0
039M<Ud000<bG@<00004<Ud0039M<Ud20004D]`01@00HaYS6V<J00000V;j00D006;jH_YRnP00009R
nP05001RnV;jH_X00002H_X01000H_YRnP000f;j00@006;jH_X000=RnP06001RnV;j001RnP001F;j
0P001F;J0P001EkJ00<005kJ00000ekI00<005kIG]T00P0000=Nf@00G]T00ekI0P001EkI00<005ji
00000eji00L005jiG[UN^@00G[T00005F[T00`00F[T00003F[T01000F[UJ^EZi0P001EZi00@005Zi
F[UJ^@8000EJV@04001JVEZIFYT20005EYT00`00EYUFV@02EYT20004EYT00`00EYT00002EYT01P00
EYT00000EYT000EFV@04001BVE:IDYT40002DWT00`00Oomoo`0MOol00`00Oomoo`0SOol000Moo`H0
00Aoo`04F]H8@P00>Lh7Ool00`00Oomoo`0KOol00`00DWYBNP02DWX01@00CWY>NTij00000Tij00<0
04YjBWX010000TYj00@004IJAUX000=6F`030016FdIK0096F`040012Fd9K0003@U/01@00@U]2Fd9K
00000ciK00@003iL?U`000<nG004000nG3iL0003>U`01@00>U`jG3YL00000SYL30000cIM00D003IM
=UdfG@00008fG@05000fGCIM=Ud00003=Ud00`00=UdfG@0;00000c9M000bG@02<Ud01000<UdbG@00
1E;L00<006<J000016;j00<006;j000016;j00<006;j00000f;j00<006;j000016;j00<006;j0000
16;j00<006;j00000f;j00D006;jH_YRnP00009RfP07001RfV;JH]X006;J00001EkJ0P0015kI00<0
05kI000015kI00H005kIG]T005kI0005G]T20005G[T00`00G[T00003G[T00`00F[UJ^@02F[T20004
F[T01P00F[UJ^@00F[T000EJ^@06001J^@00001JV@001EZI00H005ZI000005ZI0005EYT00`00EYT0
000200000eJI001FV@03EYT01@00EYUFV@00EYT00P0015JI00<005JIEYT00UJI00H005:I000005:I
0005DWT00`00Oomoo`0LOol00`00Oomoo`0SOol000Moo`03BU8006<H009oo`06249oogooOomS61S6
0W>L00<@Q5:DOol01Goo0`0077oo00D0059jDWYBNP0000=>NP03001>NTij00<0009:NP03001:NTYj
009:NP040016FTIJ0003AU/01@00AU]6FdIK00000d9K00D0049K@U]2F`000092F`05000nFciK?U/0
0003?U`01@00?U`nG3iL00000SiL00D003YL>U`jG00000<jG004000jG3YL0003>U`01000>U`jG000
0SIL3@000cIM00D003IM=UdfG@00008fG@04000bGC9M<Ud<0003<Ud01000D]aBg5;L0`001F;j0P00
1F;j0P0016;j0P001F;j0P001F;j0P001F;j00<006;j000016;J00<006;J00000f;J00<005kJG]X0
0P0000=Nf@00G]T00ekI0P001EkI00<005kI00000ekI00L005kIG]UNf@00G[T00005G[T20004G[T0
0`00F[UJ^@0200000eZi001J^@03F[T00`00F[T00003F[T00`00F[UJ^@02F[T20004FYT00`00FYUJ
V@02FYT20004FYT00`00EYUFV@02EYT20005EYT01P00EYUFVEJI001FV@<00003EYT005JI00=FV@03
001FVEJI009FV@8000ABV@03001BNE9i009BN@03001oogoo01eoo`03001oogoo029oo`0027oo00=:
DP00HaP01Goo00HQ25:DOomooe:D6<H6Ool00`00Oomoo`0LOol01@00DWYBNU9j00000Tij100000=>
NP00BWX00dYj00D004YjBWY:NP0000=6FP050016FdIKAU/00002AU/O0003>U`01@00>U`jG3YL0000
0cYL00@003YL>U`000<fG005000fG3IL=U`00002=Ud00`00=UdfG@090003=Ud300001C9M000bGC9M
00000c9M00<0039M<Ud020000U;L00@006;jH_YRnP800003H_X006;j009RnP800003H_X006;j009R
nP04001RnV;j0003H_X01000H_YRnP000f;j00<006;j00001F;j0P001F;J0P0016;J00<005kJ0000
15kI00H005kIG]T005kI0005G]T20005G]T00`00G]T00003G[T00`00G[UN^@0200000eji001N^@03
G[T00`00F[T00004F[T01000F[UJ^EZi0P001EZi00H005ZiF[T005Zi0005FYT01P00FYT00000FYT0
00EJV@06001FV@00001FV@001EJI00@005JIEYUFV@80009FV@04001FVEJI0003EYT00`00EYT00002
00000eJI001BV@03DYT00`00DWUBN@02DWT2000OOol00`00Oomoo`0QOol000Uoo`03DY@8@V<H00Ao
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo01aoo`03001BNU9j00@0009>NP05001>NTij
CWX00004BWX01000BWY:NP000TIJ200000=6F`00AU/00TIK00D0049K@U]2F`000092F`050012Fd9K
@U/00003?U/01@00?U`nG3iL00000SiL00<003iL?U`04@000cIL00D003IL=U`fG000008fG@05000f
GCIM=Ud00002=Ud00`00=UdfG@090003<Ud01@00<UdbGC9M00000c9M00@0039M<Ud000EBg003001R
nP0000ARnP03001RnP0000ARnP03001RnP0000ARnP03001RnP0000ARnP03001RnP0000=RnP07001R
nV;jH_X006;J00000f;J0P0000=RfP00H]X00f;J0P001EkI00<005kI00000ekI00L005kIG]UNf@00
G]T00005G]T20004G[T00`00G[T00004G[T01000G[UN^Eji0P001EZi00H005Zi000005Zi0005F[T0
0`00F[T00003F[T00`00FYUJV@02FYT20004FYT00`00FYUJV@02FYT20004EYT00`00EYUFV@02EYT0
1P00EYT00000EYT000=FV@03001FV@0000=FV@8000EFV@06001BVE:IDYT0059i0`0000=BN@00Ool0
7Woo00<007ooOol08Goo000:Ool00f<H249S6003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0MOol20002DWX00`00CWY>NP02CWX01@00CWY>NTij00000TYj1`000TYJ00D004IJAUY6FP00
00=6F`050016FdIKAU/00003@U/01000@U]2F`000d9K00D003iK?U/nF`0000<nG004000nG3iL0003
?U`01000>U`jG0000cYL00D003YL>U`jG000008jG0d000<fG@03000fGCIM00D0008fG@03000fGCIM
00X000<bG@04000bGC9M0004D]`20005H_X20005H_X20006H_X00`00H_YRnP03H_X20005H_X00`00
H_X00003H]X00`00H]X00004H]X01P00H]YRfP00G]X000ENf@8000ENf@03001Nf@0000=Nf@03001N
fEkI00800003G]T005ji00=N^@8000EN^@06001N^@00001N^@001EZi0P0015Zi00<005ZiF[T00UZi
0P0015Zi00<005ZIFYT00P0000=JV@00FYT00eZI00<005ZIFYT00P0000=FV@00EYT00eJI00<005JI
EYT00UJI0P0015JI00@005JIEYUFV@800005EYT00000EYT00005EYT01000DYUBVE:I0P001E9i00<0
07ooOol07Goo00<007ooOol087oo000;Ool00e:D6<Ioo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Ool0000NOol00`00DWYBNP02DWX01@00CWY>NTij00000Tij10000Tij00@004YjBWX000A:
FP050016FTIJAUX00003AU/01@00AU]6FdIK00000T9K00D0049K@U]2F`0000=2F`04000nFciK0003
?U`01@00?U`nG3iL00000ciL00@003YL>U`000<jG005000jG3YL>U`00002>U`01@00>U`jG3YL0000
0cYL00<003IL=U`02@000cIM00@003IM=Ud000<fG@05000fGCIM=Ud00002=Ud900000e;L00000002
D]`01@00H_YRnV;j00000V;j00L006;jH_YRnP00H_X00005H_X20004H_X00`00H_X00005H_X20005
H]X00`00H]YRfP03H]X00`00H]X00003G]X01`00G]UNfEkI001Nf@0000ENf@8000ANf@03001Nf@00
00ANf@06001N^Eji001N^@001Eji0P0015ji00<005ZiF[T00P0000=J^@00F[T00eZi00<005Zi0000
0P0000=J^@00F[T00eZi00<005ZI000015ZI00L005ZIFYUJV@00FYT00004EYT01P00EYUFVEJI001F
V@<00003EYT005JI00=FV@04001FVEJIEYT30004EYT00`00EYUFV@02EYT01P00DYT00000DYT000EB
N@03001oogoo01ioo`03001oogoo01moo`0037oo00H007ooOomoob48DY@2Ool00e:D8@Qoo`04Ool2
000POol00`00DWYBNP02DWX00`00CWY>NP030002CWX00`00CWY>NP02CWX01000BWY:NP000dYJ00D0
04IJAUY6FP000096Fb@000<jG004000jG3YL0003>U`01@00>U`jG3YL00000cYL00<003IL=U`01@00
0SIM2@000cIM00D003IM=UdfG@00008fG@05000bGC9M<Ud00002<Ud20005D]`00`00H_X00004H_X0
0`00H_X00003H_X01@00H_YRnV;j00000V;j00@006;jH_X000=RnP03001RnV;j00800003H_X006;J
00=RfP8000ERfP8000ENfP03001Nf@0000=Nf@03001NfEkI00800003G]T005kI00=Nf@8000ENf@03
001N^@0000=N^@03001N^Eji00800003G[T005ji00=N^@03001J^@0000AJ^@04001J^EZiF[T20005
F[T01000F[UJ^EZi0P001EZI00@005ZIFYUJV@8000EFV@04001FVEJIEYT20005EYT01000EYUFVEJI
100000=FV@00000015JI00@005JIEYUFV@<000ABV@03001BNE9i009BN@03001oogoo01ioo`03001o
ogoo01moo`001goo00H0048@LiaoocW>6<H3Ool01V<H6<IcW7>L6<IS60Eoo`03001oogoo021oo`03
001BNU9j00@00003CWX004ij00=>NP05001>NTijCWX00003BWX00`00BUY:FP070002AU/01@00AU]6
FdIK00000TIK00D0049K@U]2F`0000=2F`040012Fd9K0003?U/01@00?U`nG3iL00000ciL00<003iL
?U`040000cYL1@000cIL00@003IM=Ud000<fG@03000fGCIM00d000<bG@05000bGC9M<Ud00004D]`2
0005H_X20005H_X00`00H_X00003H_X00`00H_X00004H_X00`00H_X00004H_X01000H]YRfP000V;J
00L006;JH]YRfP00G]X00005G]X20004G]T00`00G]T00004G]T01P00G]UNf@00G]T000ENf@8000AN
^@03001N^@0000AN^@04001N^EjiG[T20005F[T01P00F[UJ^@00F[T000EJ^@06001J^@00001J^@00
1EZI00H005ZI000005ZI0005EYT01P00EYT00000EYT000EFV@06001FV@00001FV@0015JI0P000eJI
10000UJI00<005:IDYT00e:I00@0059iDWUBN@80021oo`8001moo`001goo00IBU1S6000002U:Li`4
Ool015[F2488@V<H1Woo00<007ooOol08Goo0P000U9j00D004ijCWY>NP0000=>NP03001>NTij00P0
0003BWX004YJ009:FP030016FdIK0096F`050016FdIKAU/00002AU/01@00@U]2Fd9K00000d9K00@0
049K@U/000<nF`05000nG3iL?U`00003?U`01000?U`nG0000ciL00@003YL>U`000<jG003000jG3YL
00d000<fG@05000fGCIM=Ud00002=Ud01@00=UdfGCIM00000cIM00<003IM=Ud02P0000EBg000001B
g00000ARnP03001RnP0000ERnP8000ARnP8000ERnP8000ERnP03001RfP0000ARfP03001RfP0000=N
fP03001NfUkJ00800003G]T005kI00=Nf@8000ENf@03001Nf@0000=Nf@07001NfEkIG]T005ji0000
15ji0P001Eji00H005jiG[T005Zi0005F[T00`00F[T00003F[T00`00F[UJ^@02F[T20004F[T00`00
FYUJV@02FYT20004FYT00`00EYUFV@02EYT20004EYT00`00EYUFV@02EYT20004EYT00`00EYUFV@02
EYT01P00EYT00000EYT000EFV@03001BVE:I009BV@06001BN@00001BN@007goo00<007oo00007goo
000KOol3000QOol00`00DWYBNP02DWX01@00CWY>NTij00000Tij0`000Tij00D004YjBWY:NP0000=:
NP05001:FTYJBUX00003AU/01@00AU]6FdIK00000dIK00@0049K@U/000=2F`050012Fd9K@U/00003
?U/01@00?U`nG3iL00000SiL00D003iL?U`nG00000<nG004000jG3YL0003>U`50002>U`01@00>U`j
G3YL00000SYL2@000cIM00D003IM=UdfG@0000<fG@05000fGCIM=Ud00002=Ud01000=UdfGCIM0P00
15;L00@006;jH_X000=RnP03001RnV;j00800003H_X006;j009RnP04001RnV;j0003H_X00`00H_X0
0005H_X20005H]X20004G]X00`00G]X00004G]T01P00G]UNf@00G]T000ENf@8000ENf@03001Nf@00
00=N^@06001N^Eji001N^@001Eji00<005ji00000eZi00<005ZiF[T00UZi0P0015Zi00<005ZiF[T0
0P0000=J^@00F[T00eZi00<005ZI00000P0000=JV@00FYT00eZI00<005JI00000P0000=FV@00EYT0
0eJI00<005JI00000P0000=FV@00EYT00eJI00<005JIEYT00UJI0P0015JI00<005JIEYT00UJI00@0
05:IDYUBV@<000ABN@03001oogoo01ioo`03001oogoo01eoo`006goo00<007ooOol08Woo00D0059j
DWYBNP00009>NP@00003CWX004ij00=>NP05001:NTYjBWX00003BWX01@00BUY:FTYJ00000TIK00<0
04IKAU/0;0000cYL00@003YL>U`000<jG005000jG3YL>U`00002=U`00`00=U`fG00>0003=Ud01000
=UdfG@000cIM00<005;LD]`00U;L00<006;j000016;j00<006;j000016;j00<006;j000016;j00<0
06;j00000f;j00L006;jH_YRnP00H]X00003H]X200000f;J001NfP03G]X20005G]T00`00G]T00003
G]T01`00G]UNfEkI001Nf@0000ENf@8000AN^@03001N^@0000=N^@03001N^Eji009N^@8000EJ^@06
001J^@00001J^@0015Zi00<005Zi000015Zi00@005ZiF[UJ^@8000EJV@04001JVEZIFYT20005EYT0
1000EYUFVEJI0P001EJI00H005JIEYUFV@00EYT300000eJI001FV@03EYT00`00EYUFV@02EYT40002
DWT00`00DWUBN@02DWT00`00Oomoo`0OOol00`00Oomoo`0LOol001]oo`03001oogoo029oo`04001B
NU9jDWX30002CWX01@00CWY>NTij000014ij00@004YjBWX0009:NP/00096F`050016FdIKAU/00002
@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000<nF`04000nG3iL0003?U`01P00?U`nG3iL000n
G0h000<jG005000jG3YL>U`00002=U`01@00=U`fG3IL00000cIL00@003IM=Ud000<fG@T000<fG@03
001Bg5;L00<000ERnP8000ERnP8000ERnP8000ERnP03001RnP0000=RfP03001RfP0000ARfP06001N
fUkJ001NfP001EkI0P001EkI00<005kI00000ekI00<005kIG]T00P0000=Nf@00G[T00eji0P001Eji
00H005ji000005ji0005F[T20004F[T01000F[UJ^EZi0P001EZi00H005ZiF[T005ZI0005FYT01P00
FYT00000FYT000EFV@06001FVEJI001FV@001EJI00@005JIEYUFV@8000EFV@06001FVEJIEYT005JI
0`0000=FV@00DWT0159i00D0059iDWUBN@00029oo`03001oogoo01]oo`006Woo00<007ooOol08goo
00H0059j0000059j0004CWX01@00CWY>NTij00000dij00<004YjBWX00`000TYj00D004YJBUY:FP00
0096FP030016FdIK0096F`050016FdIKAU/00002@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`00
00<nF`04000nG3iL0003?U`00`00?U`000020002?U`01@00>U`jG3YL00000cYL00<003YL>U`03@00
0cIL00D003IL=U`fG000008fG@05000fGCIM=Ud00003=Ud00`00=UdfG@070003D]`01@00H_YRnV;j
00000V;j00L006;jH_YRnP00H_X00004H_X00`00H_X00005H_X20005H]X00`00H]YRfP03H]X00`00
G]X00003G]X01`00G]UNfEkI001Nf@0000ENf@8000ANf@03001Nf@0000ANf@06001N^Eji001N^@00
1Eji0P0015ji00<005ZiF[T00P0000=J^@00F[T00eZi00H005Zi000005Zi0005F[T00`00F[T00003
FYT00`00FYUJV@02FYT20004FYT00`00EYUFV@02EYT00`00EYT00003EYT00`00EYUFV@02EYT01P00
EYT00000EYT000EFV@80009FV@8000EFV@03001BNE9i009BN@03001BNE9i00<0025oo`03001oogoo
00Qoo`06Li`Q2000000YBW>L17oo00AJePQ2000icPEoo`006Woo0`0097oo00<0059jDWX00U9j00D0
04ijCWY>NP0000=>NP03001>NTij00@00003BWX004Yj00=:NP05001:FTYJBUX00002AUX01@00AU]6
FdIK00000dIK00D0049K@U]2F`0000=2F`040012Fd9K0003@U/01@00?U/nFciK00000ciL00<003iL
00000P000ciL00@003iL?U`000<jG005000jG3YL>U`00002>U`01@00>U`jG3YL00000cYL00<003YL
>U`03@000cIM00D003IM=UdfG@00008fG@05000fGCIM=Ud00005D]`00`00H_X00004H_X00`00H_X0
0003H_X01000H_YRnP000f;j00<006;jH_X00P0000=RnP00H]X00f;J0P001F;J0P001EkJ00<005kI
00000ekI00<005kIG]T00P0000=Nf@00G]T00ekI0P001EkI00<005ji00000eji00<005jiG[T00P00
00=N^@00G[T00eji00<005Zi000015Zi00@005ZiF[UJ^@8000AJ^@03001J^EZi009J^@8000EJV@06
001JVEZI001JV@001EZI00@005JIEYUFV@8000AFV@03001FVEJI009FV@8000AFV@03001FVEJI009F
V@@00003EYT005JI00AFV@03001BNE9i009BN@<0009BN@03001oogoo021oo`03001oogoo00Moo`06
:DXicWooOolicRU:0goo00IS61S6LiacW124DY@4Ool001Yoo`03001oogoo02Aoo`03001BNU9j00=B
NP04001>NTij0002CWX40002CWX01@00BWY:NTYj00000dYj00D004YJBUY:FP0000=6FP030016FdIK
02/000<jG005000jG3YL>U`00003>U`01@00>U`jG3YL00000SYL00D003YL>U`jG00000<fG003000f
G3IL00T000<fG@05000fGCIM=Ud00004D]`20005H_X20004H_X00`00H_X00004H_X00`00H_X00004
H_X01000H]YRfP000V;J00L006;JH]YRfP00G]X00005G]X20004G]T00`00G]T00004G]T01P00G]UN
f@00G]T000ENf@8000AN^@03001N^@0000AN^@04001N^EjiG[T20005F[T01P00F[UJ^@00F[T000EJ
^@06001J^@00001J^@001EZI00<005ZI00000eZI00<005ZIFYT00UZI00H005JI000005JI0004EYT0
0`00EYT0000200000eJI001FV@03EYT00`00EYUFV@02EYT30003EYT00`00EYUFV@02EYT00`00DWT0
000200000e9i001BN@03DWT00`00Oomoo`0POol00`00Oomoo`06Ool00`Q2Oomoo`02Ool01P00Oomo
ogoo8@QBU09oo`03DY@HaWoo00=oo`006Woo00<007ooOol09Goo00<0059jDWX00U9j00<004ijCWX0
0`000Tij00<004ijCWX00Tij00D004YjBWY:NP00009:NP03001:FTYJ00P00003AU/004IK0096F`05
0016FdIKAU/00003@U/01000@U]2F`000d9K00<0049K@U/00`000SiK00D003iK?U/nF`0000<nG004
000nG3iL0002?U`=0003>U`01@00>U`jG3YL00000cYL00D003IL=U`fG000008fG005000fG3IL=U`0
0002=Ud:00001E;L000005;L000016;j00<006;j000016;j0P001F;j0P001F;j00<006;J000016;J
00<006;J00000ekJ00<005kJG]X00P0000=Nf@00G]T00ekI0P001EkI00<005kI00000ekI00<005kI
G]T00P0000=N^@00G[T00eji0P001Eji00H005jiG[T005Zi0005F[T00`00F[T00003F[T00`00F[UJ
^@02F[T20004F[T00`00FYUJV@02FYT20004FYT00`00FYUJV@02FYT20004EYT01000EYUFVEJI0P00
1EJI00H005JIEYUFV@00EYT3000015JI001FV@000eJI00@005JIEYUFV@8000EBN@05001BNE9iDWT0
000ROol00`00Oomoo`06Ool00`00Liaoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo000J
Ool00`00Oomoo`0VOol00`00DWYBNP0400000dij001>NP03CWX01@00CWY>NTij00000TYj1`000TYj
00D004YJBUY:FP0000=6F`050016FdIKAU/00003AU/01@00@U]2Fd9K00000T9K00<0049K@U/00`00
0T9K00D003iK?U/nF`0000<nF`05000nG3iL?U`00002?U`01@00?U`nG3iL00000SiL00D003YL>U`j
G000008jG0d000<fG005000fG3IL=U`00003=U`01@00=UdfGCIM00000SIM00@003IM=UdfG@8000AB
g004001RnV;j0003H_X01000H_YRnP000V;j00L006;jH_YRnP00H_X00005H_X20005H]X20004G]X0
0`00G]X00004G]T01P00G]UNf@00G]T000ENf@8000ANf@03001Nf@0000AN^@06001N^Eji001N^@00
1Eji00<005ji00000eZi00<005ZiF[T00UZi0P0015Zi00<005Zi00000P0000=J^@00F[T00eZi00<0
05ZI00000P0000=JV@00FYT00eZI00<005ZI00000P0000=FV@00EYT00eJI00H005JI000005JI0005
EYT01000EYUFVEJI0P001EJI00<005JI00000UJI00H005JI000005JI0005DWT01000DWUBNE9i0P00
8Woo00<007ooOol01Goo00H002U:LiaoocW>:DX3Ool00`00Oomoo`02Ool00`00Oomoo`02Ool001Yo
o`<002Moo`80009BNP05001>NTijCWX00003CWX00`00CWY>NP040002CWX01000BWY:NP0014Yj00D0
04YJBUY:FP0000=6F`050016FdIKAU/00002AU/01@00@U]2Fd9K00000T9K0`000T9K00D0049K@U]2
F`00008nF`05000nFciK?U/00003?U`01@00?U`nG3iL00000ciL00@003iL?U`000<jG005000jG3YL
>U`00002>U`01@00>U`jG3YL00000SYL3P000cIM00@003IM=Ud000<fG@03001Bg5;L009Bg003001R
nP0000ARnP03001RnP0000ARnP03001RnP0000=RnP07001RnV;jH_X006;J00000f;J0P0000=RfP00
G]X00ekJ0P001EkI00<005kI00000ekI00L005kIG]UNf@00G]T00004G]T20005G[T00`00G[T00003
G[T00`00G[UN^@02G[T20004F[T00`00F[T0000200000eZi001J^@03F[T20005F[T01000F[UJ^EZi
0P001EZI00@005ZIFYUJV@8000EFV@04001FVEJIEYT20004EYT00`00EYUFV@02EYT01P00EYT00000
EYT000EFV@03001FV@00009FV@8000AFV@03001BNE9i009BN@06001BN@00001G7@008goo00<007oo
Ool017oo00H@Q3W>000002U:Li`3Ool00`00Oomoo`02Ool00`00Oomoo`02Ool001Uoo`8002Uoo`03
001BNU9j009BNP05001>NTijCWX00002CWX30002CWX00`00CWY>NP02CWX01000BWY:NP0014Yj00@0
04YJBUX000=6F`030016FdIK02`000<jG005000jG3YL>U`00002>U`01@00>U`jG3YL00000cYL00@0
03YL>U`000<jG004000fG3IL=U`90003=Ud00`00D]aBg0030005H_X20006H_X00`00H_YRnP03H_X0
0`00H_X00003H]X00`00H]X00004H]X01P00G]YNfP00G]X000ENf@8000ENf@03001Nf@0000=Nf@06
001NfEkI001Nf@001Eji0P001Eji00H005ji000005ji0004F[T20005F[T01P00F[UJ^@00F[T000EJ
^@06001J^@00001J^@001EZI00H005ZI000005ZI0005EYT01P00EYT00000EYT000EFV@04001FVEJI
EYT20004EYT00`00EYUFV@02EYT00`00EYT0000200000eJI001FV@03EYT00`00DWUBN@02DWT20004
Ead00`00Oomoo`0POol00`00Oomoo`04Ool00d8@<Haoo`06Ool01R48DYAoogooDY@Q20Aoo`006Goo
00<007ooOol0:Goo00D0059jDWYBNP00009>NP@00003CWX004ij00=>NP05001>NTijCWX00003BWX0
0`00BWY:NP0;0002AU/00`00AU]6F`0300000dIK0012F`02@U/01@00@U]2Fd9K00000d9K00@0049K
@U/000<nF`05000nFciK?U/00003?U`01@00?U`nG3iL00000SiL3@000cYL00D003YL>U`jG000008j
G005000jG3YL>U`00003=U`01@00=U`fG3IL00000SIL1`000e;L00L006;jH_YRnP00H_X00005H_X2
0005H_X20004H]X20005H]X00`00G]X00003G]X01`00G]UNfEkI001Nf@0000ENf@8000ANf@03001N
f@0000=Nf@07001N^EjiG[T005ji00001Eji0P0015ji00H005ZiF[T005Zi0005F[T00`00F[T00003
F[T00`00F[UJ^@02F[T20004F[T00`00FYUJV@02FYT20004FYT00`00EYUFV@02EYT20004EYT00`00
EYUFV@02EYT01P00EYT00000EYT000EFV@03001FVEJI00<0009FV@04001FVEJI0003EYT00`00DWT0
000200000eLM001G7@03Ead3000OOol30006Ool00aS6<Ha[FP05Ool01V<H6<IcW7>L6<IS60Aoo`00
17oo00IBU124000002U:Li`4Ool015[F248003W>1goo00<007ooOol0:Goo00<0059jDWX010000U9j
00D004ijCWY>NP0000=>NP05001>NTijCWX00002BWX40002BWX01000BUY:FP000dIJ00<004IKAU/0
0TIK10000dIK00D0049K@U]2F`0000=2F`050012Fd9K@U/00002@U/01@00?U/nFciK00000ciK00D0
03iL?U`nG00000<nG004000nG3iL0003?U`01@00>U`jG3YL00000SYL3@000cYL00D003IL=U`fG000
00<fG004000fG3IL0003=Ud00`00D]aBg003D]`00`00H_X00003H_X01@00H_YRnV;j00000V;j00<0
06;jH_X00P0000=RfP00H]X00V;J00<006;J00001F;J0P001EkJ00<005kI00000ekI00<005kIG]T0
0P0000=Nf@00G]T00ekI0P001EkI00<005ji00000eji00<005jiG[T00P0000=N^@00G[T00eji00<0
05Zi00000eZi00<005ZiF[T00UZi0P0015Zi00<005ZiF[T00P0000=J^@00F[T00eZi00<005ZI0000
0P0000=JV@00FYT00eZI00<005JI00000P0000=FV@00EYT00eJI00<005JIEYT00UJI0P0015JI00<0
05JIEYT00UJI0`000UJI00@005JIEYT0009FV@03001FVEJI00<000EG7@05001G7@000013WP05000N
Ool00`00Oomoo`05Ool013W>2480012417oo00AJePQ2249S60Eoo`0017oo00H8@U:DOomoocW>6<H3
Ool01V<H6<IcW7>L48ABU0Ioo`<002Yoo`80009BN@03001BNU9j009BNP05001>NTijCWX00002CWX7
0002BWX00`00BWY:NP02BWX01000BUY:FP000dIJ1@000dIK00D004IKAU]6F`000092F`050012Fd9K
@U/00003@U/01@00@U]2Fd9K00000ciK00@003iK?U/000<nG005000nG3iL?U`00003?U`01@00?U`n
G3iL00000cYL00@003YL>U`000<jG005000jG3YL>U`00002>U`=0003=U`01@00=UdfGCIM000015;L
0P001F;j00<006;j00000f;j00<006;j000016;J00<006;J00000f;J00L006;JH]YRfP00G]X00005
G]X20004G]T00`00G]T00004G]T01P00G]UNf@00G]T000ENf@8000AN^@03001N^@0000AN^@04001N
^EjiG[T20005F[T01P00F[UJ^@00F[T000AJ^@03001J^@0000AJ^@04001J^EZiF[T20005FYT01000
FYUJVEZI0P001EJI00H005JIEYUFV@00EYT300000eJI001FV@03EYT00`00EYT0000200000eJI001F
V@03EYT01@00EYUFV@00EYT00`000eLM00@005LMEaeG7@P00003@ih0000000<001aoo`03001oogoo
01Eoo`002Goo00H007ooOomoob48DY@2Ool00e:D6<Ioo`05Ool00`00Oomoo`0ZOol00`00DWUBN@02
DWT01@00DWYBNU9j00000Tij100000=>NP00CWX00Tij00<004YjBWX00TYj00D004YjBWY:NP0000=:
FP@00096Fc0000<jG005000jG3YL>U`00003>U`01@00>U`jG3YL00000SYL00D003YL>U`jG00000<j
G003000jG3YL00X00005D]`00000D]/00005H_X20004H_X20006H]X00`00H]YRfP03H]X00`00H]X0
0003G]X00`00G]YNfP0200000ekI001Nf@03G]T20005G]T00`00G]T00003G]T00`00G]UNf@020000
0eji001N^@03G[T20005G[T01P00G[UN^@00F[T000EJ^@03001J^@0000=J^@04001J^EZiF[T20005
F[T01P00F[UJ^@00FYT000EJV@06001JVEZI001JV@001EJI00@005JIEYUFV@8000EFV@04001FVEJI
EYT20005EYT01P00EYUFVEJI001FV@<00003Ead005LM00=G7@H00003Akh0000000H00003@kh00000
00<001Yoo`03001oogoo01Aoo`0027oo00<icQ24Ool00Woo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol0:goo00D0059iDWUBN@00009BNP@0009>NP05001>NTijCWX00003CWX01@00BWY:NTYj
00000dYj00<004YJ00001`000TIK00D004IKAU]6F`0000=6F`040016FdIK0003@U/01@00@U]2Fd9K
00000d9K00D0049K@U]2F`00008nF`05000nFciK?U/00003?U`01@00?U`nG3iL00000SiL4@000cYL
00D003YL>U`jG00000<jG005000jG3YL>U`00002=U`01000=U`fG3IL0P0015;K00<006;jH_X00P00
00=RnP00H_X00V;j00<006;j00001F;J0P001F;J0P0015kJ00<005kJ000015kI00@005kIG]T0009N
f@03001NfEkI009Nf@8000ANf@03001Nf@0000AN^@06001N^Eji001N^@001Eji00<005ji00000eZi
00<005ZiF[T00UZi0P0015Zi00H005Zi000005Zi0005F[T00`00F[T00003FYT00`00FYUJV@02FYT0
0`00FYT00003FYT00`00EYUFV@02EYT01P00EYT00000EYT000EFV@06001FV@00001FV@001EJI00@0
05JIEYUFV@8000=G7@04001G7@00Ead20002Akh700000dNn0000000600000dNn00000003000GOol0
0`00Oomoo`0DOol000Ioo`0448@00000F]H3Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`0]Ool00`00DWUBN@030002DWX00`00CWY>NP02CWX01@00CWY>NTij00000dij00<004YjBWX01`00
0TYj00@004YJBUX000A6F`050016FdIKAU/00003AU/01000AU]6F`000d9K00D0049K@U]2F`0000=2
F`050012Fd9K@U/00002?U/01@00?U/nFciK00000ciL00D003iL?U`nG00000<nG004000nG3iL0003
?U`01@00>U`jG3YL00000SYL2@000cYL00<003YL>U`00SYL00@003IL=U`000<fG003001Bfe;K009B
f`03001RnP0000ARnP03001RnP0000=RnP05001RfV;JH]X00002H]X00`00H]YRfP0200000ekJ001N
fP03G]X20005G]T00`00G]T00004G]T01P00G]T00000G]T000ANf@8000EN^@03001N^@0000=N^@03
001N^Eji009N^@8000AJ^@03001J^@0000800003F[T005Zi00=J^@8000AJ^@03001J^EZi009J^@80
00AJV@03001JVEZI009JV@8000AJV@03001FVEJI009FV@8000AFV@03001FVEJI009FV@8000AFV@03
001FVEJI009FV@06001FV@00001K7@000eLM00D005LM000004Nn00@00097_PP00003Akh0000000/0
01Eoo`03001oogoo01=oo`001goo00=cW3W>6<H00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0;Goo00D0059i001BN@0000ABNP05001>NTijCWX00003CWX00`00CWY>NP070002BWX00`00
BWY:NP02BWX01000BUY:FP0014IK00@004IKAU/000=6F`050016FdIKAU/00003@U/01000@U]2F`00
0d9K00D0049K@U]2F`0000<nF`05000nFciK?U/00003?U`01@00?U`nG3iL00000ciL00@003iL?U`0
00<nG005000jG3YL>U`00003>U`01000>U`jG0000SYL3P000cIL00<005;KD]/00`001F;j0P001F;j
00<006;J00000f;J00<006;J000015kJ00H005kJG]X005kI0005G]T20005G]T20004G]T01P00G]UN
f@00G]T000EN^@8000AN^@03001N^@0000800003G[T005Zi00=J^@8000EJ^@06001J^EZi001J^@00
1EZi00H005Zi000005Zi0004FYT00`00FYT0000200000eZI001JV@03FYT00`00EYT0000200000eJI
001FV@03EYT00`00EYT0000200000eJI001FV@03EYT00`00EYUFV@02EYT20004Fad00`00Ead00007
00000dNn0000000300001DNn00000000Akh0100000=7_P0000001@0000=7_P0000000`004goo00<0
07ooOol04Woo0009Ool01P00Oomoogoo8@QBU09oo`03DY@Q27oo00Aoo`<002ioo`05001BNE9iDWT0
0004DWX00`00CWY>NP07000014ij000000000TYj00D004YjBWY:NP0000=:NP05001:FTYJBUX00002
AU/d0003?U`01@00>U`jG3YL00000cYL00@003YL>U`000<jG004000jG3YL0004>U`00`00>U`jG007
0003D[/01`00H_YRnV;j001RnP0000ERnP8000ARfP8000ENfP03001NfP0000=Nf@07001NfEkIG]T0
05kI00000ekI0P0000=Nf@00G]T00ekI00<005kI00000ekI00L005jiG[UN^@00G[T00004G[T20005
G[T01P00F[UJ^@00F[T000EJ^@03001J^@0000=J^@03001J^EZi009J^@8000AJ^@04001JVEZIFYT2
0005FYT01000FYUJVEZI0P001EJI00@005JIEYUFV@8000EFV@06001FVEJIEYT005JI0`0000=K7@00
Fad00e/M3P0000A7_P00001;_PD00003Akh0000000800003Akh0000000D00003Akh0000000<0011o
o`03001oogoo019oo`0017oo00H@Q48@Oomooc6<6<H3Ool01V<H6<IcW7>L6<IS60Eoo`03001oogoo
02ioo`03001BNE9i009BN@04001BNU9jDWX300000dij001>NP02CWX30002CWX01@00BWY:NTYj0000
0TYj00<004YjBWX020000TIJ00@004IKAU/000=6F`050016FdIKAU/00003@U/01000@U]2F`00149K
00D0049K@U]2F`000092F`05000nFciK?U/00003?U/01@00?U`nG3iL00000ciL00<003iL?U`04@00
0cYL00@003YL>U`000@jG004000jG3YL0003>U`00`00D[]B^`03D[/00`00H_X00003H_X00`00H_YR
nP0200000f;J001RfP02H]X00`00H]X00005G]X20005G]T00`00G]T00003G]T00`00G]T00004G]T0
1000G]UNfEkI0P001EkI00<005ji00000eji00H005jiG[T005ji0005G[T00`00F[T00003F[T00`00
F[UJ^@02F[T20004F[T00`00F[UJ^@0200000eZi001J^@03F[T01P00FYT00000FYT000EJV@06001J
V@00001JV@001EJI00H005JI000005JI0005EYT01000EYUFVEJI0P001E/M00<005/M00000`0000=;
_P0000000`0000A;_P00001;_PP00003Bkh0000000<00003Akh0000000800003Bkh0000000D00003
Akh00000008000moo`03001oogoo015oo`0017oo00IJeR4800000248Li`4Ool015[F2488@V<H1Woo
00<007ooOol0;goo00H0059iDWUBN@00DWX200000e9j001>NP02CWX50003CWX00`00BWY:NP070002
BWX01@00BWY:NTYj000014IJ00@004IKAU/000=6F`050016FdIKAU/00003@U/01000@U]2F`00149K
00D0049K@U]2F`000092F`05000nFciK?U/00003?U/01@00?U`nG3iL00000ciL00@003iL?U`000<n
G005000nG3iL?U`00003>U`00`00>U`jG0090003>U`01@00>U`jG3YL00000cYL00<005:kD[/00U:k
0P0016;j00<006;j000016;J00<006;J00000f;J00L005kJG]YNfP00G]X00005G]T20004G]T20005
G]T01P00G]T00000G]T000ENf@8000AN^@03001N^@0000=N^@03001N^Eji009N^@8000AJ^@03001J
^@0000800003F[T005Zi00=J^@03001J^@0000AJ^@04001J^EZiF[T20004FYT00`00FYUJV@02FYT2
0004FYT00`00EYUFV@02EYT20004EYT00`00EYUFV@02EYT01000EYT000000U/M00@005/MFaeK7@D0
0003Bkh0000000800003Bkh0000000H0009;_PL00003Bkh0000000<00003Bkh0000000800003Bkh0
000000X000]oo`<0019oo`0067oo00<007ooOol0;goo00<0059iDWT00`00159j1@000Tij00<004ij
CWX010000Tij00@004YjBWX000A:NP05001:NTYjBWX00003AUX01@00AU]6FdIK00000dIK00@004IK
AU/000=2F`050012Fd9K@U/00002@U/90003?U/01@00?U/nFciK00000ciL00D003iL?U`nG00000<n
G005000nG3iL?U`00003?U`01@00>U`jG3YL00000SYL00D003YL>U`jG000008jG0d00006D[/00000
001B^`0016;j0P001F;J0P001F;J00<005kJ00000ekJ00<005kIG]T00P0000=Nf@00G]T00UkI00<0
05kI00001EkI0P0015kI00<005kIG]T00P0000=N^@00G[T00eji0P001Eji00H005ji000005Zi0004
F[T20005F[T01000F[UJ^EZi0P001EZi00H005ZiF[T005Zi0005FYT01P00FYT00000FYT000AJV@03
001FV@0000800003EYT005JI00=FV@03001FVEJI009FV@8000AK7@H0009?_P@00003Bkh000000080
009?_P<00004Bkh000000002Bkh700000d^n00000003000014^n000000000T^n100000=;_P000000
1@001Goo0`000Woo00<007ooOol047oo000HOol2000aOol20002DWT00`00DWYBNP030003CWX00`00
CWY>NP030002CWX00`00CWY>NP02CWX01000BWY:NP0014Yj00@004YjBWX000=6FP030016FdIK01<0
0092F`050012Fd9K@U/00002@U/H0003?U`01@00>U`jG3YL00000cYL00D003YL>U`jG000008jG005
000jG3YL>U`00003>U`00`00>U`jG0020005D[/01000H_YRnP000V;J00L006;JH]YRfP00H]X00005
H]X20004G]X00`00G]T00004G]T00`00G]T00003G]T01`00G]UNfEkI001Nf@0000ANf@03001Nf@00
00AN^@06001N^Eji001N^@001Eji0P0015Zi00H005ZiF[T005Zi0005F[T01P00F[T00000F[T000EJ
^@03001J^@0000=J^@03001JVEZI009JV@8000AJV@04001JVEZIFYT20005EYT01P00EYUFVEJI001F
V@<0009K7@04001K7@000002Ckh300000dnn0000000200000dnn00000003000014nn000004nn1@00
00=;_P0000000P0000=?_P0000001@0000=?_P0000000`0000A;_P000000009?_PH00003Bkh00000
00D000Eoo`03001oogoo011oo`005goo00<007ooOol0<Goo00@0059iDWUBN@<0009BNP03001>NTij
00@00003CWX004ij00=>NP05001>NTijCWX00003BWX00`00BWY:NP0;0002AUX01@00AU]6FdIK0000
0TIK00D004IKAU]6F`0000=2F`030012Fd9K0092F`050012Fd9K@U/00002@U/01@00@U]2Fd9K0000
0SiK00D003iK?U/nF`0000<nG005000nG3iL?U`00002?U`A0003>U`01@00>U`jG3YL00000cYL00D0
03YL>U`jG00000AB^`03001RnP0000ARfP03001RfP0000=RfP03001RfV;J00800003G]X005kJ00=N
fP8000ENf@8000ENf@03001Nf@0000=Nf@04001NfEkIG]T20005G[T00`00G[T00003G[T00`00G[UN
^@0200000eji001J^@03F[T00`00F[T00003F[T00`00F[UJ^@02F[T20004F[T00`00F[UJ^@02F[T2
0004F[T00`00FYUJV@0200000eZI001JV@03FYT01P00FYT00000EYT000EFV@04001FVEJIEYT20005
Fad200001Dnn00000000Ckh01@0000=?_P0000000P000Tnn1`0000=?_P0000000`0000=?_P000000
0P0000=?_P0000001@0000=?_P0000000P0000=?_P0000000P0000=?_P0000002P001Goo00<007oo
Ool047oo000GOol00`00Oomoo`0bOol30000159i001BNU9j10000Tij00D004ijCWY>NP0000=>NP05
001>NTijCWX00002BWX40002BWX01000BWY:NP000dYJ00<004IJAUX00TIJ00D004IKAU]6F`000096
F`050016FdIKAU/00003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`04000nFciK0003
?U/01@00?U`nG3iL00000ciL00@003iL?U`000<nG005000nG3iL?U`00003>U`00`00>U`jG0090004
>U`01@00>U`jG3YL00000U:k0`001F;J0P0016;J00<006;J000015kJ00@005kJG]X0009Nf@07001N
fEkIG]T005kI00001EkI0P0015kI00H005kI000005kI0005G[T20004G[T00`00G[T00004G[T01000
F[UJ^EZi0P001EZi00H005ZiF[T005Zi0004F[T00`00F[T0000200000eZi001J^@03F[T00`00FYT0
0004FYT01000FYUJVEZI0P0015JI00<005JIEYT00UJI00@005JI0000009K7003001K7@0000800003
Cmh0000000H0009?gP@00003Ckh000000080009?gPL0009?gP@00004Ckh000000002Cmh700000doN
0000000200000dnn0000000200000e?N00000002000014nn000005?N0`0017oo00<007ooOol03goo
000GOol00`00Oomoo`0_Ool3000017oo001BNE9i0`000U9j00<004ijCWX00Tij00D004ijCWY>NP00
009>NPL0009:NP03001:NTYj009:NP04001:NTYj0003BUX01@00AUY6FTIJ00000dIK00D004IKAU]6
F`000096F`030012Fd9K01H000<nF`04000nG3iL0003?U`01@00?U`nG3iL00000ciL00D003iL?U`n
G00000<jG005000jG3YL>U`00002>U`00`00>U`jG00<0002D[/00`00H]YRfP02H]X00`00H]X00004
H]X20005G]X00`00G]X00004G]T00`00G]T00003G]T00`00G]UNf@0200000ekI001Nf@03G]T20004
G]T01`00G[UN^Eji001N^@0000AN^@8000EN^@06001J^EZi001J^@001EZi00<005Zi00000eZi00@0
05ZiF[UJ^@8000EJ^@04001J^EZiF[T20005FYT01P00FYUJV@00FYT000EFV@04001FVEJIEYT20004
Fa`300000doN000000020002Dmh300000doN0000000200000e?N0000000300000doN000000020000
1E?N00000000Cmh00`000U?N100000A?gP000000009CgP800003Cmh0000000800003Dmh000000080
0004Dmh000000002Emh200001E?N00000000Emh0100000=oo`00Ool047oo000GOol3000/Ool30005
Ool200000e9i001BNP03DWX01@00CWY>NTij00000Tij100000=>NP00CWX00Tij00<004YjBWX00TYj
00D004YjBWY:NP0000=:NP04001:FTYJ0002AUX?0002AU/01@00@U]2Fd9K00000d9K00D0049K@U]2
F`0000=2F`030012Fd9K01@000<nG003000jG3YL008jG005000jG3YL>U`00002>U`01@00>U`jG3YL
00000cYL00D003YL>U`jG00000AB^`04001RfV;J0003H]X01P00H]YRfP00H]X000ENfP8000ENf@80
00ANf@03001Nf@0000ANf@06001NfEkI001Nf@001EkI00<005ji00000eji00H005jiG[T005ji0005
G[T00`00F[T00003F[T00`00F[UJ^@02F[T20004F[T01P00F[T00000F[T000EJ^@06001J^@00001J
V@001EZI00<005ZI00000eZI00<005JIEYT00UJI00@005JI0000009K7004001K70000002Dmh50000
0e?N00000002Dmh400000e?N000000020002Dmh4000015?N000005?N1@0000ACgP000000009CgP@0
0003Dmh0000000D00003Dmh0000000800003Emh0000000800004Emh00000Emh400001EON001KgP00
Gkh00`004Goo000GOol00`00Oomoo`0YOol30008Ool01@00DWUBNE9i00000e9j00<004ijCWX01000
0Tij00D004ijCWY>NP0000=>NP05001:NTYjBWX00003BWX00`00BWY:NP070002AUX01@00AU]6FdIK
00000dIK00@004IKAU/000A6F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000d9K00@0049K@U/0
00=2F`04000nFciK0003?U`01@00?U`nG3iL00000SiL4P000cYL00D003YL>U`jG00000<jG007001B
^e:kD[/006;J000016;J00<006;J00000f;J00L005kJG]YNfP00G]X00003G]T200000ekI001Nf@03
G]T20005G]T00`00G]T00003G]T00`00G]UNf@02G]T20004G[T00`00G[T00003G[T00`00G[UN^@02
G[T20004F[T00`00F[T0000200000eZi001J^@03F[T20004F[T00`00F[UJ^@02F[T20004FYT00`00
FYUJV@02FYT20004FYT00`00EYUFV@02EYT20004Fa`300000e?N000000020002Dmh200000e?N0000
00020002Dmh400000e?N000000020002Dmh70002Dmh4000015?N000000000UON100000AGgP00001G
gP@00004Emh000000002Fmh2000015ON000000000UoN0P0000EKgP00000006>n0080015oo`005goo
00<007ooOol09goo0P0037oo00D0059iDWUBN@00009BNP<0009>NP03001>NTij009>NP05001>NTij
CWX00003CWX00`00BWY:NP070002BWX01000BWY:NP0014IJ00D004IKAU]6F`0000=6F`040016FdIK
0004AU/01@00@U]2Fd9K00000T9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/01000?U/n
F`000ciL00D003iL?U`nG00000<nG004000nG3iL0004?U`01@00?U`nG3iL00000SYL2@000cYL00<0
05:kD[/00`001F;J0P001F;J00<005kJ00000ekJ00<005kI000015kI00H005kIG]T005kI0005G]T2
0004G]T00`00G]T0000200000eji001N^@03G[T20005G[T01P00G[T00000G[T000AJ^@8000EJ^@06
001J^EZi001J^@001EZi00H005Zi000005Zi0004FYT00`00FYT0000200000eZI001JV@03FYT00`00
EYT000020002Fa`01000Fa`000000U?N100000ECgP00000005?N00D00003Dmh0000000800003Dmh0
000000<00004Dmh000000002Emh200000e?N000000020002Emh4000015ON000000000UON0P0000AG
gP000000009KgP@00004Fmh00000Fmh4000015oN000005nn0`0000ES_P00001oo`00015oo`005Woo
00<007ooOol09Goo0`003Woo00<0059iDWT0100000=BNP00CWX00dij00D004ijCWY>NP0000=>NP03
001>NTij00@00003BWX004Yj009:NP03001:NTYj009:NP04001:NTYj0004AUX01000AU]6F`000dIK
00D004IKAU]6F`000096FaT000<nF`05000nG3iL?U`00003?U`01@00?U`nG3iL00000SiL00<003iL
?U`00SiL00D003iL?U`nG000008jG005000jG3YL>U`00002>U`70003D[/01`00H]YRfV;J001RfP00
00ERfP8000ANfP8000ENf@03001Nf@0000=Nf@07001NfEkIG]T005kI000015kI0P001Eji00H005ji
G[T005ji0005G[T20004G[T01P00F[UJ^@00F[T000EJ^@03001J^@0000=J^@03001J^EZi009J^@80
00AJ^@04001JVEZIFYT20005FYT01000FYUJVEZI0P001E/L0P0000=CgP0000000`0000ECgP000000
05?N00@0009CgP@00003Dmh000000080009GgP800003Dmh005ON00800003Emh0000000<00004Emh0
00000002Emh200000eON001GgP0200000e_N00000002000015_N000000000UoN0P0000AKgP000000
009S_P800004Gkh000000002Iid01@00Oomoogoo00004Goo000FOol01000Ool000008Goo0`004Woo
0P000U9i00D0059jDWYBNP0000=>NP03001>NTij00P0009>NP05001:NTYjBWX00003BWX01@00BWY:
NTYj00000dYj00<004IJAUX03`000TIK00D004IKAU]6F`000092F`050012Fd9K@U/00003@U/01@00
@U]2Fd9K00000T9K5@000ciL00D003iL?U`nG00000<jG005000jG3YL>U`00002>U`01@00>U`jG3YL
00001E:k00<006;J00000f;J00<006;JH]X00P0000=NfP00G]X00UkJ00<005kI00001EkI0P001EkI
00<005kI00000ekI00H005kIG]T005kI0005G[T00`00G[T00003G[T00`00G[UN^@0200000eji001N
^@03G[T00`00F[T00003F[T00`00F[UJ^@02F[T20004F[T00`00F[UJ^@0200000eZi001J^@03F[T0
1P00FYT00000FYT000EJV@04001JV@000002Gc`00`00Fa`0000200000e?N0000000300000e?N0000
0002Dmh400000e?N000000020002Emh400001EON00000000Emh0100000=GgP0000000`0000=GgP00
00000P0000AGgP00001KgP@00004Fmh000000002Fmh200000e_N001OgP0200001EoN000005oN0000
0V>n00H006>m000006>n0002Iid00`00Oomoo`02Ool00`00Oomoo`0?Ool001Ioo`80021oo`<001Eo
o`03001BNE9i009BN@05001BNU9jDWX00002CWX30002CWX01@00CWY>NTij000014ij00D004YjBWY:
NP00009:NP03001:NTYj00P0009:FP040016FTIJ0003AU/01@00AU]6FdIK000014IK00D004IKAU]6
F`000092F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000T9K00D0049K@U]2F`0000<nF`05000n
G3iL?U`00003?U`00`00?U`nG00A0003>U`01@00>U`jG3YL000015:k0P0016;J00<006;J000015kJ
00<005kJ00000ekI00L005kIG]UNf@00G]T00005G]T20004G]T00`00G]T00003G]T00`00G[UN^@02
G[T20004G[T00`00G[T00004G[T01000G[UN^Eji0P001EZi00H005Zi000005Zi0004F[T00`00F[T0
0004F[T01000F[UJ^EZi0P0015ZI00<005ZIFYT00UZI0P0015ll0`0000ECgP00001GgP00009GgP<0
0003Dmh0000000800003Emh0000000<00006Emh00000Emh005ON0`0000=GgP0000000P0000=GgP00
00000P0000=GgP0000000P000U_N0P0000=KgP0000000P0000IKgP00001KgP00Fmh200000eoN0000
0002000015oN000006>n0`0000ES_P00000006NM00<00003Iid007oo00Eoo`03001oogoo00ioo`00
5Woo00<007ooOol077oo0`006Goo00D0059iDWUBN@00009BNP@00003CWX004ij00=>NP05001>NTij
CWX00003CWX00`00BWY:NP070002BWX01@00BWY:NTYj000014YJ00@004IJAUX000=6F`050016FdIK
AU/00003AU/01@00AU]6FdIK00000d9K00D0049K@U]2F`0000=2F`040012Fd9K0003@U/01@00@U]2
Fd9K00000ciK00D003iL?U`nG00000<nG004000nG3iL0003?U`01@00?U`nG3iL00000ciL00<003YL
>U`02P0000EB^`00001B^`0000ARfP8000ENfP8000ENf@03001Nf@0000=Nf@03001NfEkI00800003
G]T005kI00=Nf@8000ENf@06001N^@00001N^@0015ji0P001Eji00H005ji000005Zi0005F[T20004
F[T01000F[UJ^EZi0P001EZi00H005ZiF[T005Zi0005FYT01P00FYT00000Gc`000=O?003001GgUON
00<00003Emh005ON0080009GgP@00003Emh000000080009GgP<00004Emh000000002Emh400000eON
0000000200001E_N00000000Fmh0100000=KgP0000000P0000AKgP00001OgP@00006Gmh00000Gmh0
06>n0P0000=S_P0000000V>m0`000VNM00<006NLIi`00P001goo00<007ooOol03Woo0004Ool20000
0`Q2Oomoo`02Ool015[F248003W>1goo00<007ooOol06Goo0`0077oo00@0059iDWUBN@<0009BNP05
001>NTijCWX00004CWX01000CWY>NP000Tij10000Tij00@004YjBWX000A:NP05001:NTYjBWX00003
BUX01@00AUY6FTIJ00000dIK00@004IKAU/00096Fad000<nF`05000nG3iL?U`00003?U`01@00?U`n
G3iL00000ciL00D003iL?U`nG00000<nG004000jG3YL0003>U`01000>U`jG3YL0P0015:k00@006;J
H]X0009NfP07001NfUkJG]X005kI00001EkI0P0015kI00<005kI000015kI00H005kIG]T005kI0005
G]T20004G[T01P00G[UN^@00G[T000EN^@8000AJ^@03001J^EZi00800003F[T005Zi00=J^@06001J
^@00001J^@001EZi00<005Zi00000eZi00<005ZIFYT00UZI0P0015ll00@005ll001GgP80009GgP@0
0003Emh000000080009GgPD00003Emh00000009GgP@00003Emh0000000800003Fmh0000000800003
Fmh00000009KgP@00003Fmh0000000800004Gmh00000Gmh200000eoN001OgP03000015oN001S_P00
0V>m0P0000QS_@00000006NM001WW@000VNL00<007ooOol01goo00<007ooOol03Woo0005Ool00`00
Oomoo`02Ool01V<H6<IcW7>L48ABU0Ioo`8001Moo`<001moo`06001BN@00001BN@00159j00D004ij
CWY>NP0000=>NP03001>NTij00<0009>NP03001>NTij009>NP04001:NTYj0003BWX01@00BWY:NTYj
00000TYJ3`000TIK00D004IKAU]6F`0000=6F`050012Fd9K@U/00003@U/01000@U]2F`000d9K00<0
049K@U/05@000ciL00<003iL?U`00SiL00@003YL>U`000<jG005000jG3YL>U`00004D[/00`00H]X0
0004G]X00`00G]X00003G]T00`00G]UNf@0200000ekI001Nf@03G]T20005G]T00`00G]T00003G]T0
0`00G]UNf@0200000eji001N^@03G[T00`00G[T00003G[T01`00G[UN^Eji001N^@0000AJ^@03001J
^@0000AJ^@04001J^EZiF[T20004F[T00`00F[UJ^@02F[T20004F[T00`00FYUJV@0200000ell001O
?003Gc`500000eON0000000200000eON0000000300001EON000005ON00000U_N0P0000=GgP000000
0P000U_N100000IKgP00001KgP00Fmh3000015_N000000000UoN0P0000=OgP00Gmh00P0000EOgP00
000005oN00<0009S_P800006Hkh006>mHkd006Nm0P0000AW_@00IieWW@<00003Ii`007oo00Uoo`03
001oogoo00ioo`0000=oo`00000010000goo00HQ25:DOomooe:D6<H5Ool2000EOol3000SOol00`00
DWUBN@02DWT01@00DWYBNU9j00000dij00<004ijCWX0100000=>NP00CWX00dij00D004ijCWY>NP00
00=:NP03001:NTYj00L0009:NP05001:FTYJBUX00003AU/01000AU]6F`0014IK00D004IKAU]6F`00
00=6F`050012Fd9K@U/00003@U/01000@U]2F`000d9K00D0049K@U]2F`0000=2F`04000nFciK0003
?U`01@00?U`nG3iL00000SiL3P000cYL00D003YL>U`jG000009B^`<000INfP03001NfEkI009Nf@03
001Nf@0000ANf@06001NfEkI001Nf@001EkI0P0015kI00<005kI000015ji00@005jiG[UN^@8000EN
^@03001N^@0000=N^@04001J^EZiF[T20005F[T01P00F[UJ^@00F[T000AJ^@03001J^@0000800003
F[T005Zi00=J^@03001JV@0000AO?003001O?00000<0009GgP@00005Emh00000Emh00002Fmh30000
0eON0000000200000e_N00000003000015_N000000000U_N0`0000AKgP000000009OgP800003Fmh0
05oN00800003Gmh0000000800003Gmh00000009SgP@00004Hkh00000Hkd300001F>m001W_@00Iid0
0`0000AWW@00IgaWO08000]oo`03001oogoo00ioo`0000=oocW>DY@00Woo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol04Woo0P009Woo00<0059iDWT00e9i00@0059jDWX0
009>NP@0009>NP05001>NTijCWX00003CWX00`00CWY>NP0800000dYj001:NP02BWX00`00BWY:NP02
BWX01@00BUY:FTYJ00000dIK00@004IKAU/000=6F`050016FdIKAU/00003AU/01@00@U]2Fd9K0000
0d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/01000?U/nF`000ciL00D003iL?U`nG000
00<nG004000nG3iL0004?U`00`00?U`nG00;0002D[/00`00G]YNfP03G]X20004G]T20005G]T00`00
G]T00003G]T01`00G]UNfEkI001Nf@0000ANf@8000EN^@06001N^@00001N^@001Eji0P0015ji00H0
05Zi000005Zi0005F[T00`00F[T00003F[T01000F[UJ^EZi0P001EZi00@005ZiF[UJ^@8000EO?0@0
0003Emh000000080009KgP<00003Emh005_N0080009KgP@00005Fmh00000Fmh00002Fmh200000e_N
001KgP020002Fmh4000015oN000005oN100000IOgP00001OgP00Hmh3000016?N000000000V>m0P00
00=S_@0000000VNm0P0000AW_@00Iid0009WW080009WO003001oogoo00]oo`03001oogoo00ioo`00
00Ioog>L6<IcW7oo0004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool3000YOol0
0`00DWUBN@02DWT00`00DWYBNP030002CWX00`00CWY>NP02CWX01@00CWY>NTij00000Tij0`000Tij
00D004YjBWY:NP0000=:NP05001:NTYjBWX00003BWX01@00BUY:FTYJ00000dIK00D004IKAU]6F`00
0096FbD000<nG005000nG3iL?U`00003?U`01000?U`nG00013iL00@003iL?U`000<nG005000jG3YL
>U`00004D[/01@00G]YNfUkJ00000UkJ00H005kIG]T005kI0005G]T20005G]T00`00G]T00003G]T0
1P00G]UNf@00G]T000EN^@8000AN^@03001N^Eji00800003G[T005ji00=N^@8000AJ^@03001J^EZi
009J^@8000AJ^@06001J^@00001J^@001EZi00@005Zi0000009O?003001O?00000<0009KgP<00003
Emh005_N0080009KgPD00004Fmh000000002Fmh300000e_N001KgP0200000e_N00000003000015_N
000000000UoN0P0000IOgP00001OgP00Gmh3000015oN001SgP000V>n0P0000IS_P00HkeS_@00Ikd3
000016Nm000006NM0P0000UWW@00IiaWW000Ig`006Ml00003Woo00<007ooOol03Woo0002Ool015:D
<Haoo`0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol037oo0`00;Goo00<0059iDWT0
100000=BNP00CWX00dij00D004ijCWY>NP00009>NP@00003CWX004ij00=>NP05001:NTYjBWX00003
BWX01@00BWY:NTYj00000TYj00<004YJBUX0300000=6F`00AU/00TIK00D004IKAU]6F`0000=2F`05
0012Fd9K@U/00003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`000092Fa4000<nG005000nG3iL
?U`00003?U`01@00>U`jG3YL000015:k00<005kJ00000ekJ00<005kI00000ekI00L005kIG]UNf@00
G]T00005G]T20004G]T00`00G]T00003G]T01`00G[UN^Eji001N^@0000AN^@03001N^@0000AN^@06
001N^Eji001J^@0015Zi00<005Zi00000P0000=J^@00F[T00eZi0P0015Zi00<005ZiF[T00UZi0P00
15ll0`0000=GgP00Fmh00P000U_N1@0000EKgP00001KgP00009KgP800003Fmh005_N0080009KgP@0
0005Fmh00000Gmh00002Gmh200000eoN001OgP0200001EoN00000000Gmh00`000V?N0P0000ISgP00
001S_P00Hkd3000016>m001W_@000VNm0P0000=WW@0000000VNM0P0000AWW000IgaWO080011oo`03
001oogoo00eoo`000goo00<Q26<H000017oo00HQ25:DOomooe:D8@P5Ool30009Ool3000aOol20002
DWT01@00DWYBNU9j00000dij00<004ijCWX010000Tij00D004ijCWY>NP0000=>NP05001:NTYjBWX0
0002BWX;0002BUX01@00AUY6FTIJ00000dIK00D004IKAU]6F`0000=6F`050016FdIKAU/00003@U/0
1@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00002@U/01@00?U/nFciK0000
0ciK00D003iL?U`nG000008nG0d000<jG004001B^e:kD[/30004G]X20005G]T00`00G]T00003G]T0
0`00G]UNf@0200000ekI001Nf@03G]T20005G]T00`00G[T00003G[T01000G[UN^Eji0P001Eji00<0
05ji00000eZi00@005ZiF[UJ^@8000EJ^@06001J^EZi001J^@001EZi00@005Zi0000009O?004001O
?0000002Fmh500001E_N000005_N00000U_N0`0000=KgP0000000P0000=KgP0000000`0000=KgP00
00000P0000EOgP00000005oN00@00003Gmh0000000800003Gmh00000009OgP@00004Hmh00000Hkh3
000016>n000000000VNm0P0000IW_@00IkeW_@00Iid20003Iid01000Ig`000000VMl00<007ooOol0
47oo00<007ooOol03Goo0003Ool00f]J8@P00004Ool01V<H6<IcW7>L6<IS60Eoo`03001oogoo00Io
o`<003Aoo`03001BNE9i009BN@05001BNU9jDWX00002CWX30002CWX00`00CWY>NP02CWX01@00CWY>
NTij00000Tij00<004YjBWX010000TYj00D004YjBWY:NP00009:NP03001:FTYJ009:FP050016FTIJ
AUX00003AU/01@00AU]6FdIK00000dIK00D004IKAU]6F`000092F`050012Fd9K@U/00003@U/01@00
@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`05000nFciK?U/00003?U/01@00?U`nG3iL00000SiL
00D003iL?U`nG00000<nG003000nG3iL00P0009B^`07001NfUkJG]X005kI00001EkI0P0015kI00<0
05kI000015kI00H005kIG]T005kI0005G]T20004G[T01P00G[T00000G[T000EN^@8000AJ^@06001J
^EZi001J^@001EZi00<005Zi00000eZi00<005ZiF[T00UZi0P0015ll0`0000EKgP00001KgP00009K
gP<00003Fmh005_N0080009KgP@00005Fmh00000Fmh00002Gmh200000eoN001OgP020002Gmh40000
1UoN000005oN001SgP<00004Gmh000000002Hkh3000016>n001S_F>m100000AW_@00001W_@<00004
Ikd006NM0002Ii`02@00Iid006Ml001WO000Ig`0000COol00`00Oomoo`0=Ool000Aoo`03>Lh8@Woo
00Aoo`04F]H8@PQ2HaP6Ool00`00Oomoo`03Ool3000hOol01@00DWUBNE9i00000U9j100000=>NP00
CWX00dij00D004ijCWY>NP00009>NPL0009:NP03001:NTYj009:NP05001:NTYjBWX00002BWX01@00
BUY:FTYJ00000dIJ00D004IKAU]6F`000096FbT000<nF`05000nG3iL?U`00003?U`01@00?U`nG3iL
00000ciL00D003iL?U`nG000008nG003001B^e:k00=B^`03001NfP0000=Nf@07001NfEkIG]T005kI
000015kI0P001EkI00<005kI00000ekI00<005kIG]T00P0000=N^@00G[T00eji0P0015ji00<005ji
G[T00P0000=N^@00F[T00eZi00<005Zi00000eZi00<005ZiF[T00UZi0P0015Zi00<005ZiF[T00P00
00=O?000Gc`00Ull00<005_NFmh00`0000=KgP00Fmh00P000U_N100000=KgP0000000P000UoN0`00
00=KgP00Gmh00P0000=OgP0000000`0000AOgP000000009OgP<00004Gmh006?N0002Hmh200001F?N
001S_V>n00000V>m0P0000IS_@00001S_@00Ikd20002Ikd00`00IieWW@0200000fNM001WW002Ii`2
000016Ml001WO6Ml0P0057oo00<007ooOol03Goo000DOol01000Oomoogoo0`00>goo00<0059iDWT0
10000U9j00D004ijCWY>NP0000=>NP03001>NTij00@0009>NP04001>NTij0004BWX01@00BWY:NTYj
00000dYj00D004YjBWY:NP00009:FP/00096F`050016FdIKAU/00003AU/01000AU]6F`000d9K00D0
049K@U]2F`0000=2F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000T9K4@000ciL00<003iL?U`0
0SiL00@003iL?U`000AB^`8000ENf@03001Nf@0000=Nf@06001NfEkI001Nf@001EkI0P0015kI00<0
05kI000015ji00H005jiG[T005ji0004G[T00`00G[T00004G[T01000F[UJ^EZi0P001EZi00H005Zi
000005Zi0004F[T00`00F[T00004Gc`01000Gc`005_N0P000U_N1@0000=KgP0000000P0000MKgP00
000005_N001OgP020002Gmh400001EoN000005oN00000UoN0P0000EOgP00GmiOgP00009SgP800006
Hmh006?NHmh006>n0`0000IS_P00HkeS_@00Hkd3000026>m001W_@00Iid006Nm0002Iid01000Ii`0
00000fNL00@006Ml0000009WO003001oogoo01Aoo`03001oogoo00eoo`0057oo1000?goo0P000U9i
00<0059jDWX00U9j00D004ijCWY>NP00009>NP<0009>NP03001>NTij009>NP04001>NTij0004BWX0
1000BWY:NP000TYj200000=:NP00BUX00TYJ00D004IKAU]6F`0000A6F`050016FdIKAU/00003AU/0
1000AU]6F`000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000T9K
00D003iK?U/nF`0000<nF`05000nG3iL?U`00002?U`>00001E:k000005:k00001EkI0P0015kI00<0
05kI00000ekI00L005kIG]UNf@00G]T00004G]T20005G[T00`00G[T00003G[T01000G[UN^Eji0P00
1Eji00H005Zi000005Zi0005F[T20004F[T01000F[UJ^EZi0P001Ell1@0000=KgP0000000P000U_N
0P0000=KgP00Fmh00P000UoN1@0000=OgP0000000P0000MOgP00000005oN001OgP0200001eoN0000
0000Gmh006?N00800008Hmh00000001SgP00Hkh0009S_@<00004Hkd006>m0002Ikd2000016Nm001W
WFNM0`0000AWW@00Ii`0009WO009001WW000Ig`006ML001WO00001Moo`03001oogoo00eoo`0057oo
0P00@Goo00<0059iDWT00U9i00D0059jDWYBNP00009>NP@00003CWX004ij00=>NP05001>NTijCWX0
0003CWX00`00BWY:NP070002BWX01@00BWY:NTYj00000dYj00D004YJBUY:FP0000=6F`050016FdIK
AU/00003AU/01@00AU]6FdIK00000dIK00D0049K@U]2F`0000=2F`040012Fd9K0003@U/01@00@U]2
Fd9K00000d9K00D0049K@U]2F`0000<nF`05000nFciK?U/00003?U`01@00?U`nG3iL00000SiL00<0
03iL?U`00SiL00<003iL?U`00P0015:k00<005kIG]T00P0000=Nf@00G]T00ekI0P001EkI00<005kI
00000ekI00H005kIG]T005kI0005G[T20004G[T01P00G[T00000G[T000EN^@8000AJ^@03001J^EZi
00800003F[T005Zi00=J^@04001J^@000002Gc`00`00Gc`000040002Fmh200000e_N001KgP030000
0eoN0000000300001EoN000005oN00000UoN0P0000=OgP00Gmh00P000UoN100000=OgP0000000V?N
100000=SgP0000000V>n100000=S_@0000000V>m0P0000IS_@00IkeW_@00Ikd3000016NM001WWFNM
0P0000=WW000Ig`00VMl0P0000=WO000Ie`00VML00<007ooOol05Woo00<007ooOol03Goo000FOol0
0`00Oomoo`0oOol01@00DWUBNE9i00000U9j10000Tij00D004ijCWY>NP0000=>NP05001>NTijCWX0
0002CWX40002CWX01000BWY:NP0014Yj00D004YjBWY:NP0000=:NP05001:FTYJBUX00002AU/00`00
AU]6F`0]0003?U/01@00?U`nG3iL000013iL00@003iL?U`000@nG004000nG3iL0004D[/00`00G]T0
0004G]T01P00G]UNf@00G]T000ENf@8000ANf@03001Nf@0000=Nf@07001N^EjiG[T005ji000015ji
0P0015ji00L005jiG[UN^@00F[T00004F[T00`00F[T00004F[T01000F[UJ^EZi0P0015ll0`0000=K
gP00Fmh00`0000=OgP0000000`0000EOgP00001OgP00009OgP<00003Gmh005oN00800003Gmh00000
00<00006Gmh00000Gmh006?N0`0000ISgP00001SgP00Hkh300001V>n000006>m001S_@<00004Hkd0
0000Ikd3000016Nm001W_@000VNM0P000VNM00<006NL00000P0000AWO000001WO08000=WG003001o
ogoo01Qoo`03001oogoo00aoo`005goo00<007ooOol0?goo00<0059iDWT00`000U9j00<004ijCWX0
0Tij00D004ijCWY>NP00009>NPL0009>NP03001>NTij009>NP04001:NTYj0003BWX01@00BWY:NTYj
00000TYj2`000TIK00D004IKAU]6F`0000=6F`050016FdIKAU/00003AU/01@00@U]2Fd9K00000T9K
00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/00`00@U]2F`0B0003?U`01@00?U`nG3iL0000
0U:k0`001EkI00<005kI00000ekI00<005kIG]T00P0000=Nf@00G]T00ekI0P001EkI00<005ji0000
0eji00H005jiG[T005ji0005G[T00`00G[T00003F[T01000F[UJ^EZi0P001EZi00@005Zi0000009O
?004001O?0000002Fmh500001EoN000005oN00000UoN0`0000=OgP00Gmh00P000UoN100000EOgP00
001OgP00009SgP<00004Gmh006?N0002Hmh3000016?N001S_P000V>m0`0000AS_@00Hkd0009W_@80
0003Ikd00000009W_@800009Ikd006NMIid006NL001WW@00009WW004001WO0000002Ig`01P00Ie]W
F`00Ie`001]oo`03001oogoo00aoo`0067oo00<007ooOol0?goo0P0000=BN@00DWX00e9j00D004ij
CWY>NP00009>NP@00003CWX004ij009>NP03001>NTij009>NP05001>NTijCWX00003BWX00`00BWY:
NP070002BWX01@00BUY:FTYJ00000TIJ00<004IKAU/00TIK00D004IKAU]6F`0000=6F`050016FdIK
AU/00003AU/01@00@U]2Fd9K00000T9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/01@00
@U]2Fd9K00000SiK00D003iK?U/nF`0000@nG003000nG3iL00/0009B^`03001NfEkI00=Nf@8000AN
f@03001Nf@0000ANf@06001NfEkI001Nf@001EkI0P0015ji00<005ji00000eji00<005jiG[T00Uji
0P0015Zi00H005Zi000005Zi0005F[T20004Gc`300001E_N000005oN00000UoN0`0000=OgP00Gmh0
0P000UoN1@0000=OgP0000000P0000IOgP00000005oN0002Hmh00`00HmiSgP0200001F?N001SgV?N
00000V>n0P0000ES_P00HkeS_@00009S_@800006Hkd006NmIkd006Nm0`0000AW_@00001WW@<00004
Iid006NLIi`3000026NL001WO000Ig`006Ml0003Ie/2000LOol00`00Oomoo`0<Ool001Uoo`8003mo
o`05001BNE9iDWT00003DWX00`00CWY>NP040002CWX01@00CWY>NTij00000dij00D004ijCWY>NP00
009>NPP00003BWX004Yj009:NP03001:NTYj009:NP05001:FTYJBUX00002AUX00`00AU]6F`02AU/0
1000AU]6F`000dIK00D004IKAU]6F`0000=6F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000d9K
00D0049K@U]2F`0000=2F`050012Fd9K@U/00002?U/01@00?U/nFciK000013iL00@003iL?U`000<n
G005000nG3iL?U`00004D[/01`00G]UNfEkI001Nf@0000ANf@8000ENf@03001Nf@0000=Nf@03001N
fEkI00800003G[T005ji00=N^@8000AN^@03001N^@0000800003G[T005Zi00=J^@8000AJ^@07001J
^EZiF[T005ll00000ell00<005oNGmh00`0000=OgP00Gmh00P000UoN1@0000EOgP00001OgP00009O
gP800005Gmh005oNGmh00002Hmh300000f?N001SgP0200001f?N00000000Hmh006>n00800006Hkd0
0000001S_@000V>m00<006Nm00000P0000AW_@00Ikd0009WW@80009WW@03001WWFNM00800003Ii`0
0000009WO0800006Ig`006Ml001WO0000fMK00<007ooOol077oo00<007ooOol037oo000KOol00`00
Oomoo`0mOol01@00DWUBNE9i00000U9j0`000Tij00<004ijCWX00Tij00D004ijCWY>NP00009>NP03
001>NTij00@0009>NP05001:NTYjBWX00003BWX01@00BWY:NTYj00000dYj00D004YJBUY:FP0000=6
FP050016FdIKAU/00002AU/]0003?U/01@00?U`nG3iL00000ciL00D003iL?U`nG00000<nG003001B
^e:k009B^`03001Nf@0000=Nf@04001Nf@000002G]T00`00G]UNf@02G]T20004G]T00`00G]T00004
G[T01P00G[UN^@00G[T000AN^@8000EN^@06001J^EZi001J^@001EZi00<005Zi00000ell00@005ll
001OgP80009OgPD00005Gmh00000Gmh00002Gmh300001UoN001OgUoN001OgP<00003Gmh006?N0080
009SgP@00003Hmh00000009S_P@00003Hkd00000009S_@<00004Hkd006Nm0002Ikd200002FNm001W
WFNM001WW@00Iid00002Iid01000Ii`000000fMl00@006Ml0000009WO0800004Ie/006MK000OOol0
0`00Oomoo`0<Ool001aoo`03001oogoo03aoo`03001BNE9i00@00003DWX004ij00=>NP05001>NTij
CWX00003CWX00`00CWY>NP030002CWX00`00CWY>NP02CWX01@00BWY:NTYj00000dYj00@004YjBWX0
009:NQ000003AU/004IK0096F`050016FdIKAU/00003AU/01@00AU]6FdIK00000d9K00D0049K@U]2
F`0000=2F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000T9K4@000ciL00@005:kD[]B^`<000AN
f@8000ENf@06001Nf@00001Nf@0015kI0P001Eji00<005ji00000eji00H005jiG[T005ji0005G[T0
0`00F[T00003F[T00`00F[UJ^@02F[T20004Gc`500001EoN000005oN00000UoN0`0000EOgP00GmiO
gP00009OgP<00004Gmh000000002Hmh500001V?N000006?N001S_P<00006Hkh00000Hkd006>m0`00
00=S_@0000000VNm0P0000IW_@00IkeW_@00Ikd3000016NM001WWFNM0`0000AWW@00Ii`0009WO005
001WO000Ig`00002Ig`01@00Ig`00000Ie/00P0087oo00<007ooOol037oo000MOol00`00Oomoo`0l
Ool20002DWT01@00DWYBNU9j00000dij00<004ijCWX0200000=>NP00CWX00dij00D004ijCWY>NP00
00=:NP03001:NTYj00L0009:NP05001:NTYjBWX00003BUX01@00AU]6FdIK00000dIK00D004IKAU]6
F`0000=6F`050016FdIKAU/00003AU/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012
Fd9K@U/00003@U/01000@U]2F`000ciK00D003iK?U/nF`0000<nG003000nG3iL00P0009B^`07001N
fEkIG]T005kI00001EkI0P0015kI00@005kI0000009Nf@03001N^Eji009N^@8000AN^@03001N^@00
00=N^@03001N^Eji009N^@8000AJ^@03001J^@000080009O?006001O?000001OgP000UoN0`0000EO
gP00GmiOgP00009OgP<00003Gmh005oN0080009OgP@00005Hmh00000Hmh00002Hmh3000016?N001S
_P000V>m0`0000AS_@00Hkd0009W_@<00004Ikd00000Ikd3000016Nm001W_@000VNM0P0000=WW@00
00000VNL0P0000=WW000Ig`00VMl0P0000=WO000Ig`00VMl0P000VMK00<007ooOol087oo00<007oo
Ool037oo000NOol2000lOol00`00DWUBN@02DWT01@00DWYBNU9j00000Tij0`000Tij00D004ijCWY>
NP0000=>NP05001>NTijCWX00002CWX80002BWX01000BWY:NP0014Yj00D004YjBWY:NP0000=:FP05
0016FdIKAU/00003AU/01@00AU]6FdIK00000TIK00D004IKAU]6F`0000=6F`050012Fd9K@U/00003
@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003?U/01@00?U/nFciK
00000ciL00D003iL?U`nG000008nG003001B^e:k00=B^`03001Nf@0000=Nf@03001NfEkI00800003
G]T005kI00=Nf@8000ENf@06001N^@00001N^@0015ji0P001Eji00H005ji000005Zi0004F[T20005
Gc`300001EoN001OgUoN00000UoN0`0000=OgP00Gmh00P000UoN100000=OgP0000000P000V?N0`00
00ESgP00HmiSgP00009S_P800005Hkh006>mHkd00002Hkd200001F>m001W_FNm00000VNm0P0000=W
_@0000000VNm0P0000EW_@00IieWW@00009WW005001WW6NLIi`00002Ig`01@00IgaWO6Ml00000VMl
00/006MlIgaWO000Ie/006MK001oo`00029oo`03001oogoo00]oo`0087oo00<007ooOol0>Woo00D0
059iDWUBN@00009BNP@00003DWX004ij00=>NP05001>NTijCWX00003CWX00`00CWY>NP030002CWX0
1@00BWY:NTYj000014Yj00@004YjBWX000A:NP04001:NTYj0003BUX01@00AU]6FdIK00000TIK<@00
0ciK00D003iL?U`nG00000@nG004000nG3iL0004D[/20004G]T00`00G]T00004G]T01P00G]UNf@00
G]T000ENf@8000AN^@06001N^Eji001N^@001Eji0P0015Zi00H005ZiF[T006<l0003Gc`20002Gmh3
00000eoN001OgP020002Gmh500000eoN0000000200001V?N00000000Hmh0009SgP03001SgV?N00<0
0006Hmh006>nHkh006>m0`0000IS_@00HkeS_@00Ikd300001VNm001W_FNm001W_@<00003Ikd00000
009WW@800009Iid006NLIi`006NL001WW000009WO005001WO000Ig`00002Ig`01@00Ie/006Ml0000
0VMK0P000Woo00<007ooOol087oo00<007ooOol02goo000QOol00`00Oomoo`0iOol01000DWUBNE9i
0`000U9j00D0059jDWYBNP0000=>NP05001>NTijCWX00002CWX400000dij001>NP03CWX01@00BWY:
NTYj00000dYj00D004YjBWY:NP0000=:NP03001:NTYj00/00096F`050016FdIKAU/00002AU/01@00
AU]6FdIK00000dIK00D004IKAU]6F`0000=2F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000d9K
00D0049K@U]2F`000092Fa800005D[/00000D[/00004G]T20005G]T00`00G]T00003G]T00`00G]UN
f@0200000eji001N^@03G[T00`00G[T00003G[T00`00G[UN^@0200000eji001J^@03F[T00`00F[T0
0003Hc`01000Gc`005oN0`000UoN1@0000EOgP00001OgP00009SgP800005Hmh006?NHmh00002Hmh3
00001F?N001SgV?N00000V>n0`0000AS_P00Hkd0009S_@<00004Hkd006Nm0002Ikd3000016Nm001W
_@000VNM0P000fNM00<006NM00000P0000AWW000IiaWW0<00004Ig`006MlIg`3000016Ml001WFfMK
0P000VMK00<007ooOol00goo00<007ooOol07goo00<007ooOol02goo000ROol00`00Oomoo`0hOol0
1P00DWT00000DWT000ABNP05001BNU9jDWX00002CWX00`00CWY>NP040002CWX01@00CWY>NTij0000
14ij00@004YjBWX0009:NP`00003BWX004Yj009:NP050016FTIJAUX00004AU/01@00AU]6FdIK0000
0TIK00D004IKAU]6F`0000=6F`050016FdIKAU/00003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2
F`0000=2F`050012Fd9K@U/00002@U/01@00?U/nFciK00000ciK00<003iL?U`00SiL00<003iL?U`0
0P0015:k00H005kIG]T005kI0005G]T20004G]T00`00G]T00004G[T01000G[UN^Eji0P0015ji00<0
05ji000015ji00@005ZiF[UJ^@8000AS?0D00003Gmh0000000<0009OgP<00003Gmh006?N00800007
Hmh00000001SgP00Hmh00P000V>n0`0000=SgP00Hkh00P000V>m0P0000=S_@00Hkd00P000VNm0P00
00EW_@00IkeW_@00009W_@800005Ikd006NMIid00002Iid01@00Iid006NM00000VNL0P000VNL00<0
06MlIg`00P000VMl00<006MlIg`00P000VMK00D006MK001WF`0000Moo`03001oogoo01ioo`03001o
ogoo00]oo`008goo00<007ooOol0>7oo00<0059iDWT00U9i00D0059jDWYBNP00009BNPL0009>NP03
001>NTij009>NP05001>NTijCWX00003CWX00`00BWY:NP030002BWX01@00BWY:NTYj00000dYj00D0
04YjBWY:NP0000=:NP050016FTIJAUX00003AU/01@00AU]6FdIK00000dIK00D004IKAU]6F`0000=6
F`040016FdIK0003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003
@U/01@00?U/nFciK00000ciK00<003iL?U`00SiL00@003iL?U`000AB^`03001Nf@0000=Nf@07001N
fEkIG]T005kI000015kI0P001Eji00H005ji000005ji0004G[T20005G[T01000F[T000000V<l00H0
06<l000005oN0002Gmh3000015oN001OgUoN0P000V?N0P0000=SgP00Hmh00P000V?N1@0000=S_P00
00000V>n1@0000AS_@00001S_@D00004Ikd00000Ikd300001FNm001W_FNm00000VNM0P0000=WW@00
Iid00VNM0P0000UWW@00IiaWW000Ig`006NL00000VMl00D006Ml001WO000009WO005001WF`00Ie/0
0003Ie/00`00Oomoo`07Ool00`00Oomoo`0MOol00`00Oomoo`0;Ool002Aoo`8003Qoo`03001BNE9i
009BN@04001BNU9jDWX30002DWX01000CWY>NP0014ij00D004ijCWY>NP00009>NPP00003CWX004Yj
00=:NP05001:NTYjBWX00003BWX01@00BWY:NTYj00000TYj00D004IJAUY6FP000096FcH000<nF`05
000nG3iL?U`00003?U`00`00D[]B^`030005G]T00`00G]T00003G]T01P00G]UNf@00G]T000EN^@80
00AN^@06001N^Eji001N^@001Eji0P0016<l0`0000EOgP00GmiOgP00009OgP<00003Gmh006?N00<0
0003Hmh0000000<00005Hmh00000Hkh00002Hkd300001F>n000006>m00000V>m0P0000ES_@00001W
_@00009W_@<00004Ikd006NmIkd300001VNm001WWFNM001WW@<00004Iid00000Ii`3000016NL001W
O6Ml0`0000AWO000IgaWO0<00004Ig`006MKIe/20003Ie/00`00Oomoo`08Ool00`00Oomoo`0MOol0
0`00Oomoo`0;Ool002Ioo`03001oogoo03Ioo`06001BNE9iDWT0059j0P0000=BNP00DWX00e9j00@0
04ijCWX000=>NP03001>NTij00@0009>NP05001>NTijCWX00003CWX01@00BWY:NTYj00000dYj00D0
04YjBWY:NP00009:NP/00096FP050016FdIKAU/00003AU/01@00AU]6FdIK00000dIK00@004IKAU/0
00=2F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`040012Fd9K
@U/?0002D[/00`00G]UNf@03G]T20004G]T00`00G]T00003G]T01`00G[UN^Eji001N^@0000AN^@03
001N^@0000=N^@07001N^EjiG[T006<l00000f<l00<005oNGmh00`0000=OgP00Gmh00P000V?N1@00
00ESgP00001SgP00009S_P<00005Hkh006>mHkd00002Hkd300001V>m001S_F>m001W_@<00005Ikd0
06NmIkd00002Ikd200000fNm00000002Ikd3000016NM001WW@000VNM0P000VNL00<006NLIi`00P00
00=WO00000000VMl0P0000=WO00000000VMl0P000VMK00H006MKIe/006MK000<Ool00`00Oomoo`0L
Ool00`00Oomoo`0;Ool002Moo`03001oogoo03Ioo`03001BNE9i008000ABNP05001BNU9jDWX00003
CWX00`00CWY>NP030002CWX00`00CWY>NP02CWX01@00CWY>NTij00000dij00@004YjBWX0009:NPP0
009:NP04001:NTYj0003BUX00`00AUY6FP02AUX01@00AU]6FdIK00000dIK00D004IKAU]6F`0000=6
F`040016FdIK0003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003
@U/01@00@U]2Fd9K00000ciK00D003iK?U/nF`0000<nG003001B^e:k009B^`03001NfEkI00800003
G]T005kI00=Nf@8000ENf@03001N^@0000=N^@04001N^EjiG[T20005G[T00`00G[T00003Hc`00`00
Hc`00002Gmh00`00HmiSgP0500001F?N000006?N00000V?N0`0000ESgP00HkiS_P00009S_@<00005
Hkd006>mHkd00002Hkd3000016>m001W_@000VNm0`0000IW_@00IkeW_@00Ikd20003Ikd00`00IieW
W@0200002FNM001WWFNM001WW000Ii`00002Ii`01000IgaWO0000fMl00@006MlIg`000=WO005001W
F`00Ie/00003Ie/2000>Ool00`00Oomoo`0LOol00`00Oomoo`0:Ool002Qoo`03001oogoo03Ioo`80
0003DWT0059j00=BNP05001BNU9jDWX00002CWX400000dij001>NP03CWX01@00CWY>NTij00000dij
00<004ijCWX01`000TYj00D004YjBWY:NP0000A:NP04001:NTYj0003BUX01@00AUY6FTIJ00000dIK
00D004IKAU]6F`0000=6F`050016FdIKAU/00003AU/01@00@U]2Fd9K00000d9K00D0049K@U]2F`00
00=2F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000d9K00D003iK?U/nF`0000<nF`05000nG3iL
?U`00003D[/00`00G]T00004G]T01P00G]UNf@00G]T000ENf@8000AN^@06001N^@00001N^@001Eji
0P0016<l0`0000=OgP00Hmh00P0000ASgP00HmiSgP<00005Hmh006?NHmh00002Hkh300001F>n001S
_F>m00000V>m0`0000ES_@00HkeS_@00009W_@800005Ikd006NmIkd00002Ikd3000016Nm001W_@00
0VNM00<006Nm00000VNM00<006NM00000P0000AWW@00IiaWW0<00009Ii`006MlIg`006Ml001WO000
009WO005001WG000Ig`00003Ie/01@00Ie]WFfMK000047oo00<007ooOol077oo00<007ooOol02Woo
000YOol2000fOol01@00DWUBNE9i00000e9j00<0059jDWX010000Tij00D004ijCWY>NP0000=>NP03
001>NTij00P0009>NP04001:NTYj0004BWX01@00BWY:NTYj00000dYj00D004YjBWY:NP0000=:FP03
0016FTIJ03T000<nF`05000nG3iL?U`00002D[/30005G]T00`00G]T00003G]T00`00G]UNf@020000
0eji001N^@03G[T20004G[T00`00G[UN^@020002Hc`01000Hc`000000V?N1@0000ESgP00HmiSgP00
009SgP<00005Hmh006>nHkh00002Hkd300001F>m001S_F>m00000V>m0`0000IS_@00IkeW_@00Ikd3
00001FNm001W_FNm00000VNm0P0000=W_@00Iid00VNM0`0000AWW@00Iid0009WW0800003Ii`00000
009WO0<00004Ig`006MlIg`3000016Ml001WG6ML0P000fMK00D006MK001WF`00019oo`03001oogoo
01]oo`03001oogoo00Yoo`00:goo00<007ooOol0=7oo00D0059iDWUBN@00009BNP<0009BNP03001>
NTij009>NP05001>NTijCWX00002CWX30002CWX01@00CWY>NTij000014ij00@004YjBWX000=:NP05
001:NTYjBWX00002BWX<00000dIJ0016F`02AU/01@00AU]6FdIK00000dIK00D004IKAU]6F`0000=6
F`050016FdIKAU/00003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/0
0003@U/00`00@U]2F`0;0002D[/00`00G]UNf@03G]T20004G]T00`00G]T00004G[T01P00G[UN^@00
G[T000AN^@03001N^@0000AS?0<00005Hmh00000Hmh00002Hmh300001F?N001SgV?N00000V>n0`00
00=S_P00Hkd00P000V>m0`0000=S_@00Hkd00P000VNm0`0000AW_@00Ikd0009W_@<00006Ikd006Nm
Ikd006NM0`0000=WW@0000000VNM0P0000EWW@00IiaWW000009WW005001WO6MlIg`00002Ig`20002
Ig`00`00IgaWO0020002Ie`01P00Ie]WF`00Ie/0009WF`8001Aoo`03001oogoo01Yoo`03001oogoo
00Yoo`00;7oo00<007ooOol0<goo00<0059iDWT0100000=BNP00DWX00e9j00D004ijCWY>NP00009>
NP@00003CWX004ij00=>NP05001>NTijCWX00003CWX01@00BWY:NTYj00000TYj1`000TYj00D004Yj
BWY:NP0000=:NP050016FTIJAUX00003AU/01@00AU]6FdIK00000dIK00D004IKAU]6F`0000=6F`05
0016FdIKAU/00003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003
@U/01000@U]2F`000ciK00D003iK?U/nF`0000AB^`07001NfEkIG]T005kI000015kI0P001Eji00<0
05ji00000eji00@005jiG[UN^@<000=S?003001SgV?N00<00005Hmh006?NHmh00002Hmh300000f?N
001S_P020002Hkd500000f>m00000002Hkd500000fNm00000002Ikd200001FNm001W_FNm00000VNm
0`0000AW_@00Iid0009WW@<00004Iid00000Iid300002FNL001WW6NL001WO000Ig`00002Ig`01@00
Ig`006Ml00000VMl00D006MK001WG00000=WF`80009WF`03001oogoo01Eoo`03001oogoo01Uoo`03
001oogoo00Yoo`00;Goo00<007ooOol0<goo0P000U9i00D0059jDWYBNP0000=BNP03001>NTij00@0
009>NP05001>NTijCWX00004CWX01000CWY>NP000Tij200000=:NP00BWX00TYj00<004YjBWX00TYj
00D004YjBWY:NP0000=:NP050016FTIJAUX00003AU/01000AU]6F`000dIK00D004IKAU]6F`0000=6
F`050016FdIKAU/00003@U/01@00@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/0
0003@U/01@00@U]2Fd9K00000ciK00D003iK?U/nF`0000AB^`03001Nf@0000=Nf@06001NfEkI001N
f@001Eji0P0015ji00@005ji000000=S?003001S?000009SgP03001SgV?N00<00003Hmh006?N0080
009S_PD00005Hkd00000Hkd00002Hkd300001F>m000006Nm00000VNm0`0000AW_@00001W_@<00005
Ikd006NmIkd00002Ikd200001FNM001WWFNM00000VNM0P000VNM00<006NLIi`00`0000AWW000IgaW
O0<00004Ig`006MlIg`3000016Ml001WFfMK0P000fMK00D006MK001WF`0001Qoo`03001oogoo01Uo
o`03001oogoo00Yoo`00;Woo0P00<goo00<0059iDWT00U9i00D0059jDWYBNP00009BNP<0009>NP03
001>NTij009>NP05001>NTijCWX00003CWX00`00CWY>NP030002CWX01@00BWY:NTYj00000dYj00D0
04YjBWY:NP0000=:NP05001:NTYjBWX00003BWX00`00AUY6FP0m0004?U/00`00D[]B^`030004G]T0
0`00G]T00003G]T01`00G[UN^Eji001N^@0000AN^@8000ES?0<00003Hmh006?N0080009SgPD00005
Hkh00000Hkd00002Hkd300001F>m001S_F>m00000VNm0`0000EW_@00IkeW_@00009W_@800003Ikd0
0000009W_@<00006Ikd006NmIkd006NM0`0000UWW@00IieWW@00Ii`006NM00000VNL00<006NLIi`0
0P000VMl00<006MlIg`00P000VMl00<006MlIg`00P000VMK00H006MKIe/006MK0002Ie/2000JOol0
0`00Oomoo`0HOol00`00Oomoo`0:Ool0031oo`03001oogoo035oo`05001BNE9iDWT00002DWX40000
0e9j001>NP03CWX01@00CWY>NTij00000Tij200000=>NP00CWX00dij00D004YjBWY:NP0000=:NP04
001:NTYj0002BWX<0002BUX01@00AUY6FTIJ00000TIK00D004IKAU]6F`0000=6F`050016FdIKAU/0
0003AU/01@00AU]6FdIK00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/01@00@U]2
Fd9K00000d9K00<0049K@U/020000U:K00<005kIG]T00UkI0P001EkI00<005ji00000eji00H005ji
G[T006<l0003Hc`20002Hmh500001F?N000006>n00000V>m0`0000ES_@00HkeS_@00009S_@<00005
Hkd006NmIkd00002Ikd300001VNm001W_FNm001W_@<00003Ikd00000009W_@<00004Ikd006NM0002
Iid3000016NM001WW6NL0`0000UWW000IiaWW000Ig`006Ml00000VMl00D006Ml001WO000009WO005
001WF`00Ie/00003Ie/200000fMK0000000MOol00`00Oomoo`0HOol00`00Oomoo`09Ool0035oo`03
001oogoo031oo`03001BNE9i00@0009BNP05001BNU9jDWX00003CWX00`00CWY>NP040002CWX01@00
CWY>NTij00000dij00D004ijCWY>NP0000=:NP03001:NTYj00L0009:NP05001:NTYjBWX00003BWX0
0`00BUY:FP02BUX01@00AUY6FTIJ00000TIK00D004IKAU]6F`0000=6F`050016FdIKAU/00003AU/0
1@00AU]6FdIK00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/01@00@U]2Fd9K0000
0d9K00D0049K@U]2F`0000<nF`03001BVe:K009BV`06001Nf@00001Nf@001EkI0P0015ji00<005ji
00000f<l00<006<l00000V?N0P0000ASgP00HkiS_P<00005Hkh006>mHkd00002Hkd300001F>m001S
_F>m00000V>m0`0000EW_@00IkeW_@00009W_@<00004Ikd006Nm0002Ikd300000fNm00000002Iid2
00001FNM001WWFNM00000VNL0`0000AWW000IiaWW0<00004Ii`006MlIg`300000fMl001WO002Ig`2
00000fMl001WF`02Ie/01@00Ie]WFfMK00000VMK00<007ooOol07Woo00<007ooOol05goo00<007oo
Ool02Goo000bOol00`00Oomoo`0`Ool20002DWT00`00DWYBNP02DWX01@00DWYBNU9j00000Tij0`00
0Tij00<004ijCWX00Tij00D004ijCWY>NP0000=>NP03001>NTij00L0009:NP04001:NTYj0004BWX0
1@00BWY:NTYj00000dYj00D004YJBUY:FP0000=6FP050016FdIKAU/00003AU/01000AU]6F`000TIK
5P000d9K00D0049K@U]2F`0000=2F`030012Fd9K0092F`050012Fd9K@U/00003?U/01000DY]BVe:K
0P0015kI00<005kI00000P0000=N^@00G[T00eji0P0016<l1P0000ESgP00HkiS_P00009S_@<00005
Hkd006>mHkd00002Hkd300001F>m001S_F>m00000VNm0`0000EW_@00IkeW_@00009W_@800005Ikd0
06NmIkd00002Iid300000fNM00000002Iid200001FNM001WW6NL00000VNL0P000VNL00<006MlIg`0
0P000VMl00<006MlIg`00P000fMl00@006Ml000000=WF`05001WF`00Ie/00002Ie/00`00Oomoo`0O
Ool00`00Oomoo`0GOol00`00Oomoo`09Ool003=oo`80031oo`03001BNE9i009BN@05001BNU9jDWX0
0002DWX400000dij001>NP03CWX01@00CWY>NTij00000dij00<004ijCWX0100000=>NP00CWX00Tij
00<004YjBWX00TYj00@004YjBWX000A:NP04001:NTYj0003BWX00`00BUY:FP0C0002AU/01@00AU]6
FdIK00000dIK00D004IKAU]6F`0000=2F`030012Fd9K01X00005DY/00000DY/00004G]T20005G[T0
1000G[UN^@000V<l00D006<l000006?N0080009S_P<00005Hkh006>mHkd00002Hkd300001F>m001S
_F>m00000V>m0`0000ES_@00IkeW_@00009W_@<00006Ikd006NmIkd006Nm0`0000EW_@00IieWW@00
009WW@8000=WW@03001WW@0000800009Ii`006NLIi`006NL001WW000009WO005001WO000Ig`00002
Ig`02000IgaWO000Ig`006Ml0002Ie/00`00Ie/00002Ie/300000fMK001oo`0ROol00`00Oomoo`0F
Ool00`00Oomoo`09Ool003Eoo`03001oogoo02ioo`05001BNE9iDWT00002DWX40002DWX01@00CWY>
NTij00000dij00<004ijCWX020000Tij00D004ijCWY>NP0000=>NP05001:NTYjBWX00003BWX00`00
BWY:NP0;0002BWX01@00AUY6FTIJ00000dIK00D004IKAU]6F`0000=6F`050016FdIKAU/00003AU/0
1@00AU]6FdIK00000dIK00D0049K@U]2F`0000=2F`040012Fd9K0003@U/01@00@U]2Fd9K0000149K
00D0049K@U]2F`000092F`8000ABV`06001NfEkI001Nf@001Eji00<005ji00000f<l0`0000ASgP00
HkiS_P80009S_@<00005Hkd006>mHkd00002Hkd300001F>m001S_F>m00000VNm0`0000EW_@00IkeW
_@00009W_@<00004Ikd006Nm0002Ikd300001FNM001WWFNM00000VNM00D006NM001WW@00009WW0<0
0004Ii`006NLIi`300000fMl001WO002Ig`200000fMl001WO002Ig`200000fMl001WF`02Ie/20002
Ie/00`00Ie]WF`02000UOol00`00Oomoo`0EOol00`00Oomoo`09Ool003Ioo`03001oogoo02ioo`03
001BNE9i00<0009BNP03001BNU9j009BNP05001>NTijCWX00002CWX30002CWX01@00CWY>NTij0000
14ij00D004ijCWY>NP00009>NP03001:NTYj00P0009:NP04001:NTYj0003BWX00`00BWY:NP02BWX0
1@00AUY6FTIJ00000dIK00D004IKAU]6F`0000=6F`050016FdIKAU/00003AU/01@00AU]6FdIK0000
0dIK00D0049K@U]2F`0000=2F`040012Fd9K0003@U/01@00@U]2Fd9K0000149K00D0049K@U]2F`00
0092F`03001BVe:K009BV`03001Nf@0000=Nf@03001N^Eji009N^@8000=S?003001S_V>n00<00003
Hkh006>m009S_@03001S_F>m00<00003Hkd006>m0080009S_@<00003Hkd006Nm0080009W_@<00005
Ikd006NmIkd00002Ikd200001FNm001W_FNm00000VNM0`0000=WW@00Iid00VNM0P0000EWW@00IiaW
W000009WW080009WW003001WO6Ml008000=WO004001WO0000003Ig`01000Ie/000000fMK00D006MK
001WF`00009WF`03001oogoo02Eoo`03001oogoo01Eoo`03001oogoo00Uoo`00=goo00<007ooOol0
;Woo0P0000=BN@00DWX00e9j00D0059jDWYBNP00009>NP@00003CWX004ij00=>NP05001>NTijCWX0
0003CWX00`00CWY>NP070002BWX01@00BWY:NTYj000014Yj00@004YjBWX000=:NP05001:NTYjBWX0
0003AUX01@00AU]6FdIK00000dIK00<004IKAU/07P000d9K00D0049K@U]2F`0000=2F`050012Fd9K
@U/00003@U/00`00DY]BV`030005G]T01000G[T000000V<l00<006<l00000V>n00<006>mHkd01000
00=S_@00Hkd00P000V>m1@0000=S_@0000000VNm1@0000=W_@0000000VNm0`0000IW_@00IkeW_@00
Ikd300001FNm001WWFNM00000VNM0`0000AWW@00001WW0<00009Ii`006NLIi`006Ml001WW000009W
O008001WO6Ml001WO000Ig`0009WO005001WO000Ie/00002Ie/00`00Ie/00003Ie/200000fMK001o
o`0XOol00`00Oomoo`0DOol00`00Oomoo`09Ool003Qoo`03001oogoo02eoo`05001BNE9iDWT00003
DWX00`00DWYBNP040002CWX01@00CWY>NTij00000dij00D004ijCWY>NP00009>NP@0009>NP04001>
NTij0004BWX01@00BWY:NTYj00000dYj00D004YjBWY:NP00009:NP03001:NTYj01000096F`050016
FdIKAU/00003AU/01@00AU]6FdIK00000dIK00D0049K@U]2F`0000=2F`030012Fd9K01L0009BV`03
001NfEkI00=Nf@8000AS?0<00003Hkh006>m008000=S_@D00005Hkd00000Hkd00002Ikd300001FNm
000006Nm00000VNm0`0000=W_@0000000VNm0`0000AW_@00Ikd0009WW@<00005Iid006NMIid00002
Iid20002Ii`00`00IiaWW00300000fNL001WO002Ig`200000fMl001WO002Ig`200000fMl001WO002
Ig`200000fMK001WF`02Ie/20003Ie/01000Ie/00000:goo00<007ooOol057oo00<007ooOol027oo
000iOol2000^Ool01@00DWUBNE9i00000U9j0`000U9j00<004ijCWX00Tij00D004ijCWY>NP00009>
NPL0009>NP03001>NTij009>NP04001>NTij0003BWX01@00BWY:NTYj00000TYj2`000TYj00D004YJ
BUY:FP0000=6FP050016FdIKAU/00004AU/01@00AU]6FdIK00000dIK00D004IKAU]6F`0000=6F`05
0012Fd9K@U/00003@U/01000@U]2F`000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/0
0`00DY]BV`02DY/01`00G]UNfEkI001S>`0000=S?003001S_F>m00D00006Hkd00000001S_@000V>m
0`0000ES_@00IkeW_@00009W_@<00005Ikd006NmIkd00002Ikd300000fNm00000002Ikd200001FNm
001WWFNM00000VNM0`0000UWW@00IieWW@00Ii`006NL00000VNL00<006NLIi`00P000fMl00<006Ml
00000P0000=WO00000000VMl0P0000=WO00000000VMK00D006MKIe]WF`00009WF`05001WF`00Ie/0
000^Ool00`00Oomoo`0COol00`00Oomoo`08Ool003]oo`03001oogoo02]oo`03001BNE9i00@00003
DWX0059j00=BNP05001>NTijCWX00002CWX400000dij001>NP02CWX00`00CWY>NP02CWX01@00CWY>
NTij00000dij00<004YjBWX01`000TYj00D004YjBWY:NP00009:NP03001:NTYj009:NP05001:FTYJ
BUX00003AUX01@00AU]6FdIK00000dIK00D004IKAU]6F`0000=6F`050016FdIKAU/00003AU/01@00
@U]2Fd9K00000d9K00D0049K@U]2F`0000=2F`050012Fd9K@U/00003@U/01@00@U]2Fd9K00000d9K
00<005:KDY/00U:K00<005kI00000f<k00@006<l001S_@800004Hkd006>mHkd400001F>m001S_F>m
00000VNm0`0000EW_@00IkeW_@00009W_@<00005Ikd006NmIkd00002Ikd3000016Nm000006NM0`00
00EWW@00IieWW@00009WW@<00004Iid006NLIi`300001FNL001WW6NL00000VMl00D006Ml001WO000
009WO08000=WO004001WO0000003Ie/01@00Ie/006MK00000fMK0P0000=WF`00Ool0;Woo00<007oo
Ool04goo00<007ooOol027oo000lOol00`00Oomoo`0[Ool20002DWT01@00DWYBNU9j00000e9j00<0
04ijCWX010000Tij00D004ijCWY>NP0000=>NP05001>NTijCWX00002CWX800000dYj001:NP02BWX0
0`00BWY:NP02BWX01@00BWY:NTYj00000TYj00<004YjBWX00TYj00@004YJBUX000=6FP050016FdIK
AU/00002AU/V0003@U/01@00@U]2Fd9K00000d9K00@005:KDY]BV`<000AS>`D00005Hkd006>mHkd0
0003Hkd300001F>m001W_FNm00000VNm0`0000EW_@00IkeW_@00009W_@<00005Ikd006NmIkd00002
Iid3000016NM001WWFNM0`0000EWW@00IieWW@00009WW0<00004Ii`006NLIi`300000fNL001WO002
Ig`200001FMl001WO6Ml00000VMl00D006Ml001WO000009WF`03001WF`00009WF`8000=WF`04001W
F`00000aOol00`00Oomoo`0BOol00`00Oomoo`08Ool003eoo`03001oogoo02Yoo`03001BNE9i009B
N@05001BNU9jDWX00002DWX30002CWX00`00CWY>NP02CWX01@00CWY>NTij00000Tij00<004ijCWX0
10000Tij00D004ijCWY>NP0000=:NP05001:NTYjBWX00003BWX01@00BWY:NTYj00000dYj00<004Yj
BWX03`000SkN00D003kN?]hngP0000@ngP05000ngSkN?]h00003?]h01@00>]hjgS[N00000SZn00D0
03Zn>[hj_P0000<j_P03000j_SZn010000=C7@06001S>`00001S_@000V>m0`0000AS_@00HkeS_@80
009W_@<00005Ikd006NmIkd00002Ikd300001FNm001W_FNm00000VNm0`0000EW_@00IieWW@00009W
W@800003Iid00000009WW@<00005Iid006NLIi`00002Ii`20002Ii`00`00IgaWO003000016Ml0000
06Ml0`0000=WO000Ig`00VMl0P0000=WO000Ie/00VMK0P000VMK00P006MKIe/006MK001WF`00=7oo
00<007ooOol04Goo00<007ooOol027oo000nOol2000[Ool01@00DWUBNE9i00000U9j100000=BNP00
CWX00dij00D004ijCWY>NP0000=>NP03001>NTij00<0009>NP03001>NTij009>NP05001>NTijCWX0
0003BWX01000BWY:NP000TYj30000d;N00D004;N@]i2gP0000=2gP040012gT;N0003?]h01@00?]hn
gSkN00000SkN4P000cZn00D003Zn>[hj_P0000<j_P05000j_SZn>[h00003=[h00`00=[hf_P02=[h0
0`00DaeC7@0400001F>m001S_F>m00000V>m0`0000=S_@00Ikd00VNm00<006NmIkd00`0000EW_@00
IkeW_@00009W_@<00005Ikd006NmIkd00002Ikd300001VNM001WWFNM001WW@8000=WW@03001WW6NL
00<00009Ii`006NLIi`006NL001WW000009WO003001WO6Ml0080009WO003001WO6Ml008000=WO004
001WG0000003Ie/01@00Ie/006MK00000fMK0P0000=WF`00Ool0=Goo00<007ooOol047oo00<007oo
Ool027oo0010Ool00`00Oomoo`0XOol00`00DWUBN@040002DWX01@00DWYBNU9j00000dij00<004ij
CWX0200000=>NP00CWX00dij00D004ijCWY>NP0000=>NP03001:NTYj00L000=6oP050016oTKnA_h0
0003A_h00`00@]i2gP140002Bil400001F>m001S_F>m00000VNm100000EW_@00IkeW_@00009W_@<0
0005Ikd006NmIkd00002Ikd300001FNm001W_FNm00000VNM0`0000AWW@00Iid0009WW@03001WW@00
009WW003001WW6NL00<00004Ii`006NLIi`300002FMl001WO6Ml001WO000Ig`00002Ig`02000IgaW
O000Ig`006ML0002Ie/00`00Ie/00003Ie/200000fMK00000002Ic/00`00Oomoo`0eOol00`00Oomo
o`0@Ool00`00Oomoo`08Ool0045oo`03001oogoo02Qoo`80009BN@03001BNU9j009BNP05001BNU9j
DWX00002CWX30002CWX01@00CWY>NTij00000dij00D004ijCWY>NP00009>NPP000=:oP050016oTKn
A_h00003A_h00`00A_i6oP1=0002Bil400001F>m001W_FNm00000fNm0`0000EW_@00IkeW_@00009W
_@<00005Ikd006NmIkd00002Ikd300001FNm001WWFNM00000VNM0P0000=WW@00Iid00VNM0`0000EW
W000IiaWW000009WW080009WW003001WO6Ml00<00003Ig`006Ml009WO0800003Ig`006Ml009WO080
0003Ie`006MK009WF`8000=WF`04001WF`000003Ic/00`00Oomoo`0gOol00`00Oomoo`0@Ool00`00
Oomoo`07Ool0049oo`03001oogoo02Moo`03001BNE9i009BN@05001BNU9jDWX00002DWX400000dij
001>NP03CWX01@00CWY>NTij00000dij00<004ijCWX00`000d[n00D004[nB_i:oP00009:oU/0009;
W`@00003Ikd006Nm009W_@03001W_FNm00<00005Ikd006NmIkd00002Ikd300001FNm001W_FNm0000
0VNM0`0000EWW@00IieWW@00009WW@800003Iid00000009WW0<00009Ii`006NLIi`006Ml001WW000
009WO003001WO6Ml008000=WO004001WO0000003Ig`01000Ie]WF`000fMK00P006MKIe/006MK001W
F`000VLk00<006Lk0000>goo00<007ooOol03goo00<007ooOol01goo0013Ool2000XOol01@00DWUB
NE9i00000U9j10000U9j00D004ijCWY>NP0000=>NP05001>NTijCWX00002CWX40003C_h01@00B_i:
oT[n00000T[nH0000T^O1@0000=W_@00Ikd00P000VNm0`0000EW_@00IkeW_@00009W_@<00005Ikd0
06NMIid00002Iid300001VNM001WWFNM001WW08000=WW003001WW6NL00<00004Ii`006MlIg`30000
1FMl001WO6Ml00000VMl00D006Ml001WO000009WO003001WO000009WF`05001WF`00Ie/00003Ie/2
00000fMK001W>`02Ic/2000lOol00`00Oomoo`0?Ool00`00Oomoo`07Ool004Eoo`03001oogoo02Io
o`03001BNE9i00<0009BNP03001BNU9j009BNP05001>NTijCWX00002CWX70003C_h00`00C_i>oP1Z
0003Bil600000fNm00000002Ikd300001FNm001W_FNm00000VNM0`0000EWW@00IieWW@00009WW@<0
0004Iid006NL0002Ii`00`00Ii`00002Ii`00`00IiaWW003000016Ml001WO6Ml0`0000=WO000Ig`0
0VMl0P0000=WO000Ig`00VMl0`0000AWF`00Ie]WF`8000=WF`04001WFfMK0003Ic/00`00Oomoo`0m
Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool004Ioo`03001oogoo02Ioo`800003DWT0059j00=BNP05
001BNU9jDWX00002CWX40002C_h01@00C_i>oTkn00000TknL@0000=;W`0000000T^O0`0000=W_@00
00000VNm0`0000EW_@00IieWW@00009WW@<00005Iid006NMIid00002Iid200000fNL001WW002Ii`3
00001FNL001WW6NL00000VMl0P000VMl00<006MlIg`00P000fMl00@006MlIg`000=WO003001WFfMK
0080009WF`06001WFfMK001WF`000VMK00D006Lk001W>`00045oo`03001oogoo00eoo`03001oogoo
00Moo`00Agoo00<007ooOol09Goo00D0059iDWUBN@0000=BNP03001BNU9j00@000=Bo@05001>oTkn
C_h00002C_if00000d^O00000002Bgl300000fNm00000002Ikd300001FNM001WWFNM00000VNM0`00
00EWW@00IieWW@00009WW005001WW6NLIi`00002Ii`300002FNL001WO6Ml001WO000Ig`00002Ig`0
1P00IgaWO000Ig`0009WO005001WO000Ig`00002Ie/01@00Ie/006MK00000fMK0`0000AWF`00Ic]W
>`8004=oo`03001oogoo00aoo`03001oogoo00Moo`00B7oo0P009Woo00D0059iDWUBN@00009BNP<0
00=C7@03001BoE;m08000004Bgl00000Bgl400000fNm00000002Iid300001FNM001WWFNM00000VNM
0`0000UWW@00IiaWW000Ii`006NL00000VNL00<006MlIg`00`0000=WO000Ig`00VMl0P0000=WO000
Ig`00VMl0`0000AWO000IgaWO0<00003Ie/006MK009WF`05001WFfMKIe/00002Ie/20002Ic/00`00
Oomoo`13Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool004Yoo`03001oogoo02=oo`03001BNE9i00@0
00=C7@03001C7E<M00@0008gOH40009?O`@00003Iid00000009WW@<00005Iid006NMIid00002Ii`3
000016NL001WW6NL0`0000EWW000IgaWO000009WO08000=WO004001WO0000003Ig`00`00IgaWO002
0002Ig`00`00Ie]WF`020003Ie/01@00Ie/006MK00000VMK00D006Lk001W>`0004Moo`03001oogoo
00aoo`03001oogoo00Ioo`00Bgoo00<007ooOol08goo0P000e<M00<005<MDad0S@000dmo0`0000=W
W@0000000VNM0`0000EWW@00IiaWW000009WW0800003Ii`00000009WW0<00005Ig`006MlIg`00002
Ig`01@00Ig`006Ml00000VMl00<006Ml00000VMl00D006ML001WO000009WF`06001WFfMK001WF`00
0VMK0`0000AWF`00Ic]W>`8004Uoo`03001oogoo00]oo`03001oogoo00Ioo`00C7oo00<007ooOol0
8goo00<005<MDad01@0000@kOP00>ghkOXP00003Cgl00000009?O`8000=WW@03001WW6NL00<00005
Ii`006NLIi`00002Ii`01@00IiaWW6NL00000VMl0`0000=WO000Ig`00VMl0P0000=WO000Ig`00VMl
0`0000=WO000Ie`00VML0P0000=WF`00Ie/00VMK0P000VMK00<006MKIe/00P000VLk00<007ooOol0
BWoo00<007ooOol02Woo00<007ooOol01Woo001=Ool2000TOol30002?ihF0002>gih00000dmo0000
0002Cgl00`00Iid00002Ii`00`00IiaWW00300002FNL001WW6NL001WO000Ii`00002Ig`00`00IgaW
O0020003Ig`01000IgaWO0000fMl00<006MlIg`00P000fML00@006MK000000=WF`05001WF`00Ie/0
0002Ie/01@00Ic/006Lk0000CGoo00<007ooOol02Woo00<007ooOol01Woo001?Ool00`00Oomoo`0T
OolD0002?iin0002Cgl400001FNL001WW6NL00000VNL0`0000AWW000IgaWO0<00005Ig`006MlIg`0
0002Ig`00`00Ig`00002Ig`01@00Ig`006Ml00000VMl00P006MKIe/006ML001WF`000VMK00<006MK
00000fMK0P0000=WF`00Ic/00VLk00<007ooOol0CGoo00<007ooOol02Goo00<007ooOol01Woo001@
Ool00`00Oomoo`0gOon20002Cgl400001FNL001WW6NL00000VNL0P000VMl00<006MlIg`00`0000=W
O000Ig`00VMl0`0000AWO000IgaWO0<00003Ig`006MK009WF`800003Ie/006MK009WF`8000=WF`04
001WF`000003Ic/00`00Oomoo`1?Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0055oo`03001oogoo
04]oodL000035Yd0000002D0009?O`@00009Ii`006NLIi`006Ml001WO000009WO003001WO6Ml0080
00=WO003001WO6Ml0080009WO003001WO6Ml008000=WF`04001WFfMK0003Ie/02000Ie]WF`00Ie/0
06MK0002Ic/00`00Ic/0001COol00`00Oomoo`07Ool00`00Oomoo`06Ool0059oo`03001oogoo05eo
o`P000Qoob4000035Yh0000002X0009?O`@00004Ii`006MlIg`300001FMl001WO6Ml00000VMl00<0
06Ml00000VMl00D006Ml001WO000009WO006001WFfMK001WF`000VMK00D006MK001WF`0000=WF`80
0003Ie/006Lk009W>`8005Aoo`03001oogoo00Qoo`03001oogoo00Eoo`00Dgoo0P00I7oo00<007oo
Ool03Goo3@0000<JWP0000000P0000<JWP0000000P0000<JWP0000007`0000<JWP0000000`0000<J
WP0000000`0000@JWP000000009?O`@00004Ig`006MlIg`300000fMl001WO002Ig`3000016Ml001W
O6Ml0`0000=WO000Ie/00VMK0`0000AWF`00Ie]WF`8000=WF`04001WFfMK0003Ic/00`00Oomoo`1E
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool005Eoo`03001oogoo065oo`03001oogoo01=oo`@00003
7Yh0000002<000036Yh00000008000036Yh0000001<000=?G`80009WO003001WO6Ml008000=WO003
001WO6Ml00<00004Ig`006MLIe`20003Ie/00`00Ie]WF`020002Ie/01P00Ie]WF`00Ie/0009WF`05
001W>`00Ic/0001IOol00`00Oomoo`06Ool00`00Oomoo`05Ool005Ioo`03001oogoo061oo`03001o
ogoo01Moo`d000037Yh00000008000037Yh0000000<000036Yh00000008000036Yh0000000800003
6Yh0000001`00007Cel00000Del006Ml00000VMl00H006MlIg`006Ml0002Ig`00`00IgaWO0020002
Ie`01P00Ie]WF`00Ie/0009WF`05001WF`00Ie/00003Ie/3000016MK001W>fLk0P00FWoo00<007oo
Ool01Woo00<007ooOol01Goo001GOol00`00Oomoo`1OOol00`00Oomoo`0MOol400000b9n0000000N
00000aZN0000000300000aZN0000000300000aZN0000000300000aZN000000030002Del300000fMl
001WO002Ig`300002FMl001WO6Ml001WF`00Ie`00003Ie/300000fMK001WF`02Ie/200000fMK0000
0002Ie/20002Ic/00`00Oomoo`1KOol00`00Oomoo`05Ool00`00Oomoo`05Ool005Qoo`8005moo`03
001oogoo025oo`@000038Wh00000008000038Wh00000008000037Wh00000008000037Yh000000080
00037Yh0000000<000037Yh0000001X00003Del0000000800003Ig`00000009WO0<00003Ig`006MK
009WF`800003Ie/00000009WF`8000=WF`04001WF`000003Ie/01@00Ic/006Lk0000Ggoo00<007oo
Ool017oo00<007ooOol01Goo001JOol00`00Oomoo`1LOol00`00Oomoo`0TOolN00027Yh400000ajN
0000000300000ajN0000000300000ajN0000000200026Yh20003Del20003Ig`00`00IgaWO0020003
Ie/01000Ie/000000fMK00P006MKIe/006MK001WF`000VLk00<006MK00000fLk00<007ooOol0Ggoo
00<007ooOol00goo00<007ooOol01Goo001KOol00`00Oomoo`1KOol00`00Oomoo`0[Ool400000b9n
0000000200000b9n0000000300000b9n0000000200000ain0000000K00000e=O00000002Del00`00
Ig`00002Ig`02000Ie]WF`00Ie/006MK0002Ie/00`00Ie/00003Ie/200000fMK001W>`02Ic/20003
Ic/00`00Oomoo`1POol00`00Oomoo`04Ool00`00Oomoo`04Ool005aoo`03001oogoo05Yoo`03001o
ogoo02moo`@000039Wh00000008000038Wh00000008000038Wh0000000<000038Wh0000000800003
7Wh0000000<000037Wh000000080008NOP@000037Yh0000000<0009CG`@00003Ig`006MK009WF`80
0003Ie/006MK009WF`8000=WF`04001WFfMK0003Ic/01P00Ic]W>`00Ic/006Aoo`03001oogoo00=o
o`03001oogoo00Aoo`00GGoo0P00FWoo00<007ooOol0<Woo100000<VOP0000006@0000<NOP000000
0P0000<NOP0000000`0000@NOP000000009CGP<000=WF`04001WFfMK0003Ie/01P00Ie]WF`00Ie/0
009WF`05001W>`00Ic/00003Ic/2001VOol00`00Oomoo`02Ool00`00Oomoo`04Ool005moo`03001o
ogoo05Ioo`03001oogoo03Moo`L000039Wh0000000<000038Wh00000008000038Wh0000000<00003
8Wh00000018000=C?P03001WF`00009WF`05001WF`00Ie/00003Ie/3000016MK001W>fLk0P000fLk
00<007ooOol0Igoo00D007ooOomoo`0000Ioo`00H7oo00<007ooOol0EGoo00<007ooOol0?Woo1000
00<VOP0000000P0000<ROP0000000`0000<ROP0000000P000R9n100000<ROP0000000`0000<ROP00
00000`000U<n100000AWF`00Ie]WF`8000=WF`03001WFfMK0080009W>`06001W>fLk001W>`00JWoo
00D007ooOomoo`0000Ioo`00HGoo00<007ooOol0E7oo00<007ooOol0@Goo1@0000<VOP0000000P00
00<VOP0000000`0000<ROP0000000P0000<ROP0000000`0000<ROP0000000`0000@ROP000000009C
?P<0009WF`06001WFfMK001WF`000VMK00D006Lk001W>`0000=W>`8006aoo`04001oogoo0006Ool0
069oo`8005Aoo`03001oogoo04Eoo`@000039Wh0000001`0009C?P03001WF`0000=WF`<00003Ie/0
06Lk009W>`05001W>fLkIc/0001_Ool00`00Ool00006Ool006Aoo`03001oogoo055oo`03001oogoo
04Uoo`P000039Wh00000008000039Wh0000000<000038Wh0000000<000038Wh0000000<0009C?P80
00=WF`03001WFfMK008000=W>`05001W>`00Ic/0001`Ool01000Oomoo`001Goo001UOol00`00Oomo
o`1@Ool00`00Oomoo`1@Ool400000bIn0000000300000bIn0000000300000bIn000000030000129n
000000000U<n00<006MK00000VMK00H006LkIc/006Lk0002Ic/2001bOol00`00Ool00005Ool006Io
o`03001oogoo04moo`03001oogoo05Aoo`@000039Wh0000000<000039Wh0000000<000039Wh00000
0080009C?P@00003Ie/006Lk009W>`80009W>`03001oogoo07=oo`8000Eoo`00Igoo00<007ooOol0
CWoo00<007ooOol0Egoo1@0000<VOP0000000`0000<VOP0000000P000RIn0P000U<n0`000fLk00D0
06Lk001W>`0007Eoo`<000Eoo`00J7oo0P00CWoo00<007ooOol0Fgoo4P000e<N00<006Lk00000fLk
00<007ooOol0L7oo100027oo001ZOol00`00Oomoo`1;Ool00`00Oomoo`1SOol400000bIn00000003
0002Dah30003Ic/00`00Oomoo`1]Ool4000<Ool006]oo`03001oogoo04Yoo`03001oogoo06Ioo`D0
00049Wh000000003Dah00`00Ic/0001]Ool3000@Ool006aoo`03001oogoo04Uoo`03001oogoo06Yo
o`D0009C7P<006Yoo`@001=oo`00KGoo0P00BGoo00<007ooOol0KWoo0`00JGoo10005goo001_Ool0
0`00Oomoo`16Ool00`00Oomoo`3FOol4000KOol0071oo`03001oogoo04Eoo`03001oogoo0=9oo`@0
01moo`00LGoo00<007ooOol0A7oo00<007ooOol0cgoo0`008goo001bOol20014Ool00`00Oomoo`3;
Ool4000VOol007Aoo`03001oogoo045oo`03001oogoo0<Moo`@002Yoo`00MGoo00<007ooOol0@7oo
00<007ooOol0`goo1000;Woo001fOol00`00Oomoo`0oOol00`00Oomoo`2oOol4000bOol007Moo`80
03moo`03001oogoo0;aoo`<003Ioo`00NGoo00<007ooOol0?7oo00<007ooOol0^7oo1000>Goo001j
Ool00`00Oomoo`0kOol00`00Oomoo`2dOol4000mOol007]oo`03001oogoo03Yoo`03001oogoo0;1o
o`@0045oo`00O7oo00<007ooOol0>Goo00<007ooOol0[7oo1000AGoo001mOol2000iOol00`00Oomo
o`2XOol40019Ool007moo`03001oogoo03Ioo`03001oogoo0:Eoo`<004eoo`00P7oo00<007ooOol0
=Goo00<007ooOol0XGoo1000D7oo0021Ool00`00Oomoo`0dOol00`00Oomoo`2MOol4001DOol0089o
o`8003=oo`03001oogoo09Yoo`@005Qoo`00Q7oo00<007ooOol0<7oo00<007ooOol0UWoo1000G7oo
0025Ool00`00Oomoo`0_Ool00`00Oomoo`2COol3001POol008Ioo`03001oogoo02ioo`03001oogoo
08moo`@006=oo`00Qgoo0P00;Woo00<007ooOol0Rgoo1000Igoo0029Ool00`00Oomoo`0[Ool00`00
Oomoo`27Ool4001[Ool008Yoo`03001oogoo02Yoo`03001oogoo08=oo`@006moo`00Rgoo00<007oo
Ool0:Goo00<007ooOol0P7oo0`00Lgoo002<Ool2000YOol00`00Oomoo`1lOol4001fOol008ioo`03
001oogoo02Ioo`03001oogoo07Qoo`@007Yoo`00Sgoo00<007ooOol09Goo00<007ooOol0M7oo1000
OWoo002@Ool00`00Oomoo`0TOol00`00Oomoo`1`Ool40022Ool0095oo`8002Aoo`03001oogoo06ao
o`@008Ioo`00Tgoo00<007ooOol08Goo00<007ooOol0JGoo0`00RWoo002DOol00`00Oomoo`0POol0
0`00Oomoo`1UOol4002=Ool009Eoo`03001oogoo01moo`03001oogoo065oo`@0095oo`00UWoo00<0
07ooOol07Woo00<007ooOol0GGoo1000UGoo002GOol2000NOol00`00Oomoo`1IOol4002IOol009Uo
o`03001oogoo01]oo`03001oogoo05Ioo`<009eoo`00VWoo00<007ooOol06Woo00<007ooOol0DWoo
1000X7oo002KOol00`00Oomoo`0IOol00`00Oomoo`1>Ool4002TOol009aoo`8001Uoo`03001oogoo
04Yoo`@00:Qoo`00WWoo00<007ooOol05Woo00<007ooOol0AWoo1000[7oo002OOol00`00Oomoo`0E
Ool00`00Oomoo`13Ool3002`Ool00:1oo`03001oogoo01Aoo`03001oogoo03moo`@00;=oo`00XGoo
0P0057oo00<007ooOol0>goo1000]goo002SOol00`00Oomoo`0AOol00`00Oomoo`0gOol4002kOol0
0:Aoo`03001oogoo011oo`03001oogoo03=oo`@00;moo`00YGoo00<007ooOol03goo00<007ooOol0
;goo1000`goo002VOol2000>Ool00`00Oomoo`0]Ool30037Ool00:Qoo`03001oogoo00]oo`03001o
ogoo02Uoo`@00<Yoo`00ZGoo00<007ooOol02Woo00<007ooOol09Goo1000cWoo002ZOol00`00Oomo
o`09Ool00`00Oomoo`0QOol4003BOol00:]oo`03001oogoo00Qoo`03001oogoo01eoo`@00=Ioo`00
[7oo0P0027oo00<007ooOol06Woo0`00fWoo002^Ool00`00Oomoo`05Ool00`00Oomoo`0FOol4003M
Ool00:moo`03001oogoo00Aoo`03001oogoo019oo`@00>5oo`00/7oo00<007ooOol00goo00<007oo
Ool03Woo1000iGoo002aOol20003Ool00`00Oomoo`0:Ool4003YOol00;=oo`04001oogoo0009Ool3
003]Ool00;Aoo`03001oo`0000Eoo`@00?1oo`00]Goo0P0000=oo`0000000P00m7oo002fOol2003h
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
   ImageRangeCache->{{{0, 431}, {349.312, 0}} -> {-0.0490187, 0.0282727,
   0.00352486, 0.00352486}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
     \(\(FiltFdata = Fdata*Filt; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
     \(ListPlot3D[Re[FiltFdata], {PlotRange \[Rule] All}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.2083 .17506 -11.6698 -9 ]
[.2083 .17506 .33019 0 ]
[.41321 .09446 -10.8756 -9 ]
[.41321 .09446 1.12444 0 ]
[.63499 .00731 -10.0813 -9 ]
[.63499 .00731 1.9187 0 ]
[.79894 .14525 0 -6.11522 ]
[.79894 .14525 12 2.88478 ]
[.88874 .28276 0 -5.98496 ]
[.88874 .28276 12 3.01504 ]
[.96735 .40315 0 -5.87414 ]
[.96735 .40315 12 3.12586 ]
[.01914 .29626 -24 -2.76864 ]
[.01914 .29626 0 6.23136 ]
[.00834 .36396 -6 -2.82602 ]
[.00834 .36396 0 6.17398 ]
[-0.00294 .43467 -18 -2.88622 ]
[-0.00294 .43467 0 6.11378 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78659 .14969 m
.78042 .1519 L
s
[(20)] .79894 .14525 -1 .35894 Mshowa
.87628 .28687 m
.87005 .28893 L
s
[(40)] .88874 .28276 -1 .32999 Mshowa
.9548 .40699 m
.94853 .4089 L
s
[(60)] .96735 .40315 -1 .30537 Mshowa
.125 Mabswid
.7105 .03329 m
.70682 .0347 L
s
.7368 .07352 m
.73311 .0749 L
s
.76215 .11229 m
.75845 .11365 L
s
.81019 .18578 m
.80647 .18708 L
s
.83297 .22063 m
.82925 .22191 L
s
.85499 .25431 m
.85126 .25557 L
s
.89687 .31837 m
.89312 .31958 L
s
.9168 .34886 m
.91305 .35005 L
s
.9361 .37838 m
.93234 .37955 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03139 .29155 m
.03751 .28919 L
s
[(-500)] .01914 .29626 1 -0.38475 Mshowa
.02064 .35939 m
.02679 .3571 L
s
[(0)] .00834 .36396 1 -0.372 Mshowa
.00941 .43024 m
.01559 .42803 L
s
[(500)] -0.00294 .43467 1 -0.35862 Mshowa
.125 Mabswid
.02928 .30488 m
.03295 .30348 L
s
.02715 .31833 m
.03083 .31694 L
s
.025 .3319 m
.02868 .33051 L
s
.02283 .34558 m
.02651 .3442 L
s
.01843 .37331 m
.02213 .37195 L
s
.01621 .38736 m
.0199 .386 L
s
.01396 .40153 m
.01766 .40018 L
s
.0117 .41582 m
.0154 .41448 L
s
.03349 .27833 m
.03716 .27691 L
s
.03556 .26522 m
.03923 .26379 L
s
.0071 .4448 m
.01081 .44348 L
s
.00478 .45948 m
.00849 .45817 L
s
.00243 .47429 m
.00615 .47299 L
s
6e-05 .48924 m
.00378 .48795 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.298 .133 .482 r
.39291 .8016 .40512 .60371 .4103 .69161 .40534 .68723 Metetra
.656 .751 .919 r
.40534 .68723 .4103 .69161 .41867 .68925 .41372 .68485 Metetra
.656 .751 .919 r
.41372 .68485 .41867 .68925 .42705 .68687 .42213 .68246 Metetra
.656 .751 .919 r
.42213 .68246 .42705 .68687 .43547 .68448 .43056 .68006 Metetra
.656 .751 .919 r
.43056 .68006 .43547 .68448 .44391 .68209 .43901 .67766 Metetra
.656 .751 .919 r
.43901 .67766 .44391 .68209 .45238 .67969 .4475 .67524 Metetra
.656 .751 .919 r
.4475 .67524 .45238 .67969 .46087 .67728 .45601 .67282 Metetra
.656 .751 .919 r
.45601 .67282 .46087 .67728 .46939 .67487 .46455 .67039 Metetra
.656 .751 .919 r
.46455 .67039 .46939 .67487 .47794 .67245 .47311 .66796 Metetra
.656 .751 .919 r
.47311 .66796 .47794 .67245 .48651 .67002 .4817 .66551 Metetra
.656 .751 .919 r
.4817 .66551 .48651 .67002 .49511 .66758 .49032 .66306 Metetra
.656 .751 .919 r
.49032 .66306 .49511 .66758 .50374 .66514 .49897 .6606 Metetra
.656 .751 .919 r
.49897 .6606 .50374 .66514 .5124 .66268 .50764 .65813 Metetra
.656 .751 .919 r
.50764 .65813 .5124 .66268 .52108 .66022 .51634 .65566 Metetra
.656 .751 .919 r
.51634 .65566 .52108 .66022 .52979 .65775 .52507 .65318 Metetra
.656 .751 .919 r
.52507 .65318 .52979 .65775 .53853 .65528 .53383 .65069 Metetra
.656 .751 .919 r
.53383 .65069 .53853 .65528 .54729 .65279 .54261 .64819 Metetra
.656 .751 .919 r
.54261 .64819 .54729 .65279 .55609 .6503 .55142 .64568 Metetra
.656 .751 .919 r
.55142 .64568 .55609 .6503 .56491 .6478 .56026 .64317 Metetra
.656 .751 .919 r
.56026 .64317 .56491 .6478 .57376 .64529 .56913 .64064 Metetra
.656 .751 .919 r
.56913 .64064 .57376 .64529 .58264 .64278 .57803 .63811 Metetra
.656 .751 .919 r
.57803 .63811 .58264 .64278 .59154 .64025 .58695 .63557 Metetra
.656 .751 .919 r
.58695 .63557 .59154 .64025 .60048 .63772 .59591 .63303 Metetra
.656 .751 .919 r
.59591 .63303 .60048 .63772 .60944 .63518 .60489 .63047 Metetra
.656 .751 .919 r
.60489 .63047 .60944 .63518 .61844 .63263 .6139 .62791 Metetra
.656 .751 .919 r
.6139 .62791 .61844 .63263 .62746 .63008 .62294 .62533 Metetra
.656 .751 .919 r
.62294 .62533 .62746 .63008 .63651 .62751 .63202 .62275 Metetra
.656 .751 .919 r
.63202 .62275 .63651 .62751 .64559 .62494 .64112 .62017 Metetra
.656 .751 .919 r
.64112 .62017 .64559 .62494 .6547 .62236 .65025 .61757 Metetra
.656 .751 .919 r
.65025 .61757 .6547 .62236 .66384 .61977 .65941 .61496 Metetra
.656 .751 .919 r
.65941 .61496 .66384 .61977 .67301 .61717 .66859 .61235 Metetra
.656 .751 .919 r
.66859 .61235 .67301 .61717 .68221 .61456 .67781 .60973 Metetra
.656 .751 .919 r
.67781 .60973 .68221 .61456 .69144 .61195 .68706 .60709 Metetra
.656 .751 .919 r
.68706 .60709 .69144 .61195 .70069 .60932 .69634 .60446 Metetra
.656 .751 .919 r
.69634 .60446 .70069 .60932 .70998 .60669 .70565 .60181 Metetra
.656 .751 .919 r
.70565 .60181 .70998 .60669 .7193 .60405 .715 .59915 Metetra
.656 .751 .919 r
.715 .59915 .7193 .60405 .72865 .6014 .72437 .59648 Metetra
.656 .751 .919 r
.72437 .59648 .72865 .6014 .73804 .59874 .73377 .59381 Metetra
.656 .751 .919 r
.73377 .59381 .73804 .59874 .74745 .59607 .7432 .59113 Metetra
.656 .751 .919 r
.7432 .59113 .74745 .59607 .75689 .5934 .75267 .58843 Metetra
.656 .751 .919 r
.75267 .58843 .75689 .5934 .76637 .59071 .76216 .58573 Metetra
.656 .751 .919 r
.76216 .58573 .76637 .59071 .77587 .58802 .77169 .58302 Metetra
.656 .751 .919 r
.77169 .58302 .77587 .58802 .78541 .58532 .78125 .5803 Metetra
.656 .751 .919 r
.78125 .5803 .78541 .58532 .79498 .5826 .79084 .57757 Metetra
.656 .751 .919 r
.79084 .57757 .79498 .5826 .80458 .57988 .80047 .57484 Metetra
.656 .751 .919 r
.80047 .57484 .80458 .57988 .81421 .57715 .81012 .57209 Metetra
.656 .751 .919 r
.81012 .57209 .81421 .57715 .82388 .57441 .81981 .56933 Metetra
.656 .751 .919 r
.81981 .56933 .82388 .57441 .83357 .57167 .82953 .56657 Metetra
.656 .751 .919 r
.82953 .56657 .83357 .57167 .8433 .56891 .83929 .56379 Metetra
.656 .751 .919 r
.83929 .56379 .8433 .56891 .85307 .56614 .84907 .56101 Metetra
.656 .751 .919 r
.84907 .56101 .85307 .56614 .86286 .56337 .85889 .55822 Metetra
.656 .751 .919 r
.85889 .55822 .86286 .56337 .87269 .56058 .86874 .55541 Metetra
.656 .751 .919 r
.86874 .55541 .87269 .56058 .88255 .55779 .87863 .5526 Metetra
.656 .751 .919 r
.87863 .5526 .88255 .55779 .89245 .55498 .88855 .54978 Metetra
.656 .751 .919 r
.88855 .54978 .89245 .55498 .90237 .55217 .8985 .54695 Metetra
.656 .751 .919 r
.8985 .54695 .90237 .55217 .91234 .54935 .90849 .54411 Metetra
.656 .751 .919 r
.90849 .54411 .91234 .54935 .92233 .54651 .91851 .54126 Metetra
.656 .751 .919 r
.91851 .54126 .92233 .54651 .93236 .54367 .92856 .5384 Metetra
.656 .751 .919 r
.92856 .5384 .93236 .54367 .94242 .54082 .93865 .53553 Metetra
.656 .751 .919 r
.93865 .53553 .94242 .54082 .95252 .53796 .94877 .53265 Metetra
.656 .751 .919 r
.94877 .53265 .95252 .53796 .96266 .53509 .95893 .52976 Metetra
.656 .751 .919 r
.95893 .52976 .96266 .53509 .97282 .5322 .96913 .52686 Metetra
.656 .751 .919 r
.96913 .52686 .97282 .5322 .98303 .52931 .97935 .52395 Metetra
.383 .224 .539 r
.39532 .59716 .39291 .8016 .40534 .68723 .40035 .68283 Metetra
.656 .751 .919 r
.40035 .68283 .40534 .68723 .41372 .68485 .40875 .68043 Metetra
.656 .751 .919 r
.40875 .68043 .41372 .68485 .42213 .68246 .41717 .67803 Metetra
.656 .751 .919 r
.41717 .67803 .42213 .68246 .43056 .68006 .42562 .67561 Metetra
.656 .751 .919 r
.42562 .67561 .43056 .68006 .43901 .67766 .43409 .67319 Metetra
.656 .751 .919 r
.43409 .67319 .43901 .67766 .4475 .67524 .44259 .67077 Metetra
.656 .751 .919 r
.44259 .67077 .4475 .67524 .45601 .67282 .45112 .66833 Metetra
.656 .751 .919 r
.45112 .66833 .45601 .67282 .46455 .67039 .45967 .66589 Metetra
.656 .751 .919 r
.45967 .66589 .46455 .67039 .47311 .66796 .46826 .66344 Metetra
.656 .751 .919 r
.46826 .66344 .47311 .66796 .4817 .66551 .47686 .66098 Metetra
.656 .751 .919 r
.47686 .66098 .4817 .66551 .49032 .66306 .4855 .65851 Metetra
.656 .751 .919 r
.4855 .65851 .49032 .66306 .49897 .6606 .49416 .65604 Metetra
.656 .751 .919 r
.49416 .65604 .49897 .6606 .50764 .65813 .50286 .65356 Metetra
.656 .751 .919 r
.50286 .65356 .50764 .65813 .51634 .65566 .51157 .65107 Metetra
.656 .751 .919 r
.51157 .65107 .51634 .65566 .52507 .65318 .52032 .64857 Metetra
.656 .751 .919 r
.52032 .64857 .52507 .65318 .53383 .65069 .52909 .64607 Metetra
.656 .751 .919 r
.52909 .64607 .53383 .65069 .54261 .64819 .5379 .64355 Metetra
.656 .751 .919 r
.5379 .64355 .54261 .64819 .55142 .64568 .54673 .64103 Metetra
.656 .751 .919 r
.54673 .64103 .55142 .64568 .56026 .64317 .55559 .6385 Metetra
.656 .751 .919 r
.55559 .6385 .56026 .64317 .56913 .64064 .56447 .63596 Metetra
.656 .751 .919 r
.56447 .63596 .56913 .64064 .57803 .63811 .57339 .63342 Metetra
.656 .751 .919 r
.57339 .63342 .57803 .63811 .58695 .63557 .58234 .63086 Metetra
.656 .751 .919 r
.58234 .63086 .58695 .63557 .59591 .63303 .59131 .6283 Metetra
.656 .751 .919 r
.59131 .6283 .59591 .63303 .60489 .63047 .60031 .62573 Metetra
.656 .751 .919 r
.60031 .62573 .60489 .63047 .6139 .62791 .60934 .62315 Metetra
.656 .751 .919 r
.60934 .62315 .6139 .62791 .62294 .62533 .6184 .62056 Metetra
.656 .751 .919 r
.6184 .62056 .62294 .62533 .63202 .62275 .6275 .61797 Metetra
.656 .751 .919 r
.6275 .61797 .63202 .62275 .64112 .62017 .63662 .61536 Metetra
.656 .751 .919 r
.63662 .61536 .64112 .62017 .65025 .61757 .64577 .61275 Metetra
.656 .751 .919 r
.64577 .61275 .65025 .61757 .65941 .61496 .65495 .61013 Metetra
.656 .751 .919 r
.65495 .61013 .65941 .61496 .66859 .61235 .66416 .6075 Metetra
.656 .751 .919 r
.66416 .6075 .66859 .61235 .67781 .60973 .6734 .60486 Metetra
.656 .751 .919 r
.6734 .60486 .67781 .60973 .68706 .60709 .68267 .60221 Metetra
.656 .751 .919 r
.68267 .60221 .68706 .60709 .69634 .60446 .69197 .59956 Metetra
.656 .751 .919 r
.69197 .59956 .69634 .60446 .70565 .60181 .7013 .59689 Metetra
.656 .751 .919 r
.7013 .59689 .70565 .60181 .715 .59915 .71066 .59422 Metetra
.656 .751 .919 r
.71066 .59422 .715 .59915 .72437 .59648 .72005 .59154 Metetra
.656 .751 .919 r
.72005 .59154 .72437 .59648 .73377 .59381 .72948 .58885 Metetra
.656 .751 .919 r
.72948 .58885 .73377 .59381 .7432 .59113 .73893 .58615 Metetra
.656 .751 .919 r
.73893 .58615 .7432 .59113 .75267 .58843 .74842 .58344 Metetra
.656 .751 .919 r
.74842 .58344 .75267 .58843 .76216 .58573 .75794 .58072 Metetra
.656 .751 .919 r
.75794 .58072 .76216 .58573 .77169 .58302 .76749 .57799 Metetra
.656 .751 .919 r
.76749 .57799 .77169 .58302 .78125 .5803 .77707 .57526 Metetra
.656 .751 .919 r
.77707 .57526 .78125 .5803 .79084 .57757 .78669 .57251 Metetra
.656 .751 .919 r
.78669 .57251 .79084 .57757 .80047 .57484 .79633 .56976 Metetra
.656 .751 .919 r
.79633 .56976 .80047 .57484 .81012 .57209 .80601 .56699 Metetra
.656 .751 .919 r
.80601 .56699 .81012 .57209 .81981 .56933 .81572 .56422 Metetra
.656 .751 .919 r
.81572 .56422 .81981 .56933 .82953 .56657 .82547 .56144 Metetra
.656 .751 .919 r
.82547 .56144 .82953 .56657 .83929 .56379 .83524 .55865 Metetra
.656 .751 .919 r
.83524 .55865 .83929 .56379 .84907 .56101 .84505 .55585 Metetra
.656 .751 .919 r
.84505 .55585 .84907 .56101 .85889 .55822 .85489 .55304 Metetra
.656 .751 .919 r
.85489 .55304 .85889 .55822 .86874 .55541 .86477 .55022 Metetra
.656 .751 .919 r
.86477 .55022 .86874 .55541 .87863 .5526 .87468 .54739 Metetra
.656 .751 .919 r
.87468 .54739 .87863 .5526 .88855 .54978 .88462 .54455 Metetra
.656 .751 .919 r
.88462 .54455 .88855 .54978 .8985 .54695 .8946 .5417 Metetra
.656 .751 .919 r
.8946 .5417 .8985 .54695 .90849 .54411 .90461 .53884 Metetra
.656 .751 .919 r
.90461 .53884 .90849 .54411 .91851 .54126 .91466 .53597 Metetra
.656 .751 .919 r
.91466 .53597 .91851 .54126 .92856 .5384 .92474 .53309 Metetra
.656 .751 .919 r
.92474 .53309 .92856 .5384 .93865 .53553 .93485 .5302 Metetra
.656 .751 .919 r
.93485 .5302 .93865 .53553 .94877 .53265 .945 .52731 Metetra
.656 .751 .919 r
.945 .52731 .94877 .53265 .95893 .52976 .95519 .5244 Metetra
.656 .751 .919 r
.95519 .5244 .95893 .52976 .96913 .52686 .96541 .52148 Metetra
.656 .751 .919 r
.96541 .52148 .96913 .52686 .97935 .52395 .97566 .51855 Metetra
.413 .219 .505 r
.3851 .72778 .39532 .59716 .40035 .68283 .39533 .6784 Metetra
.656 .751 .919 r
.39533 .6784 .40035 .68283 .40875 .68043 .40375 .67599 Metetra
.656 .751 .919 r
.40375 .67599 .40875 .68043 .41717 .67803 .41218 .67357 Metetra
.656 .751 .919 r
.41218 .67357 .41717 .67803 .42562 .67561 .42065 .67114 Metetra
.656 .751 .919 r
.42065 .67114 .42562 .67561 .43409 .67319 .42914 .66871 Metetra
.656 .751 .919 r
.42914 .66871 .43409 .67319 .44259 .67077 .43766 .66627 Metetra
.656 .751 .919 r
.43766 .66627 .44259 .67077 .45112 .66833 .4462 .66382 Metetra
.656 .751 .919 r
.4462 .66382 .45112 .66833 .45967 .66589 .45477 .66136 Metetra
.656 .751 .919 r
.45477 .66136 .45967 .66589 .46826 .66344 .46337 .65889 Metetra
.656 .751 .919 r
.46337 .65889 .46826 .66344 .47686 .66098 .472 .65642 Metetra
.656 .751 .919 r
.472 .65642 .47686 .66098 .4855 .65851 .48065 .65394 Metetra
.656 .751 .919 r
.48065 .65394 .4855 .65851 .49416 .65604 .48933 .65145 Metetra
.656 .751 .919 r
.48933 .65145 .49416 .65604 .50286 .65356 .49804 .64896 Metetra
.656 .751 .919 r
.49804 .64896 .50286 .65356 .51157 .65107 .50678 .64645 Metetra
.656 .751 .919 r
.50678 .64645 .51157 .65107 .52032 .64857 .51554 .64394 Metetra
.656 .751 .919 r
.51554 .64394 .52032 .64857 .52909 .64607 .52434 .64142 Metetra
.656 .751 .919 r
.52434 .64142 .52909 .64607 .5379 .64355 .53316 .63889 Metetra
.656 .751 .919 r
.53316 .63889 .5379 .64355 .54673 .64103 .54201 .63635 Metetra
.656 .751 .919 r
.54201 .63635 .54673 .64103 .55559 .6385 .55088 .63381 Metetra
.656 .751 .919 r
.55088 .63381 .55559 .6385 .56447 .63596 .55979 .63126 Metetra
.656 .751 .919 r
.55979 .63126 .56447 .63596 .57339 .63342 .56873 .6287 Metetra
.656 .751 .919 r
.56873 .6287 .57339 .63342 .58234 .63086 .57769 .62613 Metetra
.656 .751 .919 r
.57769 .62613 .58234 .63086 .59131 .6283 .58668 .62355 Metetra
.656 .751 .919 r
.58668 .62355 .59131 .6283 .60031 .62573 .5957 .62096 Metetra
.656 .751 .919 r
.5957 .62096 .60031 .62573 .60934 .62315 .60476 .61837 Metetra
.656 .751 .919 r
.60476 .61837 .60934 .62315 .6184 .62056 .61384 .61577 Metetra
.656 .751 .919 r
.61384 .61577 .6184 .62056 .6275 .61797 .62295 .61315 Metetra
.656 .751 .919 r
.62295 .61315 .6275 .61797 .63662 .61536 .63209 .61053 Metetra
.656 .751 .919 r
.63209 .61053 .63662 .61536 .64577 .61275 .64126 .60791 Metetra
.656 .751 .919 r
.64126 .60791 .64577 .61275 .65495 .61013 .65046 .60527 Metetra
.656 .751 .919 r
.65046 .60527 .65495 .61013 .66416 .6075 .65969 .60262 Metetra
.656 .751 .919 r
.65969 .60262 .66416 .6075 .6734 .60486 .66895 .59997 Metetra
.656 .751 .919 r
.66895 .59997 .6734 .60486 .68267 .60221 .67824 .5973 Metetra
.656 .751 .919 r
.67824 .5973 .68267 .60221 .69197 .59956 .68756 .59463 Metetra
.656 .751 .919 r
.68756 .59463 .69197 .59956 .7013 .59689 .69692 .59195 Metetra
.656 .751 .919 r
.69692 .59195 .7013 .59689 .71066 .59422 .7063 .58926 Metetra
.656 .751 .919 r
.7063 .58926 .71066 .59422 .72005 .59154 .71571 .58656 Metetra
.656 .751 .919 r
.71571 .58656 .72005 .59154 .72948 .58885 .72516 .58386 Metetra
.656 .751 .919 r
.72516 .58386 .72948 .58885 .73893 .58615 .73464 .58114 Metetra
.656 .751 .919 r
.73464 .58114 .73893 .58615 .74842 .58344 .74415 .57841 Metetra
.656 .751 .919 r
.74415 .57841 .74842 .58344 .75794 .58072 .75369 .57568 Metetra
.656 .751 .919 r
.75369 .57568 .75794 .58072 .76749 .57799 .76326 .57294 Metetra
.656 .751 .919 r
.76326 .57294 .76749 .57799 .77707 .57526 .77286 .57018 Metetra
.656 .751 .919 r
.77286 .57018 .77707 .57526 .78669 .57251 .7825 .56742 Metetra
.656 .751 .919 r
.7825 .56742 .78669 .57251 .79633 .56976 .79217 .56465 Metetra
.656 .751 .919 r
.79217 .56465 .79633 .56976 .80601 .56699 .80187 .56187 Metetra
.656 .751 .919 r
.80187 .56187 .80601 .56699 .81572 .56422 .81161 .55908 Metetra
.656 .751 .919 r
.81161 .55908 .81572 .56422 .82547 .56144 .82137 .55628 Metetra
.656 .751 .919 r
.82137 .55628 .82547 .56144 .83524 .55865 .83117 .55347 Metetra
.656 .751 .919 r
.83117 .55347 .83524 .55865 .84505 .55585 .84101 .55065 Metetra
.656 .751 .919 r
.84101 .55065 .84505 .55585 .85489 .55304 .85087 .54782 Metetra
.656 .751 .919 r
.85087 .54782 .85489 .55304 .86477 .55022 .86077 .54498 Metetra
.656 .751 .919 r
.86077 .54498 .86477 .55022 .87468 .54739 .87071 .54214 Metetra
.656 .751 .919 r
.87071 .54214 .87468 .54739 .88462 .54455 .88068 .53928 Metetra
.656 .751 .919 r
.88068 .53928 .88462 .54455 .8946 .5417 .89068 .53641 Metetra
.656 .751 .919 r
.89068 .53641 .8946 .5417 .90461 .53884 .90072 .53354 Metetra
.656 .751 .919 r
.90072 .53354 .90461 .53884 .91466 .53597 .91079 .53065 Metetra
.656 .751 .919 r
.91079 .53065 .91466 .53597 .92474 .53309 .92089 .52775 Metetra
.656 .751 .919 r
.92089 .52775 .92474 .53309 .93485 .5302 .93103 .52485 Metetra
.656 .751 .919 r
.93103 .52485 .93485 .5302 .945 .52731 .94121 .52193 Metetra
.656 .751 .919 r
.94121 .52193 .945 .52731 .95519 .5244 .95142 .519 Metetra
.656 .751 .919 r
.95142 .519 .95519 .5244 .96541 .52148 .96166 .51607 Metetra
.656 .751 .919 r
.96166 .51607 .96541 .52148 .97566 .51855 .97194 .51312 Metetra
.615 .437 .618 r
.38174 .68 .3851 .72778 .39533 .6784 .39029 .67394 Metetra
.656 .751 .919 r
.39029 .67394 .39533 .6784 .40375 .67599 .39871 .67151 Metetra
.656 .751 .919 r
.39871 .67151 .40375 .67599 .41218 .67357 .40717 .66908 Metetra
.656 .751 .919 r
.40717 .66908 .41218 .67357 .42065 .67114 .41565 .66664 Metetra
.656 .751 .919 r
.41565 .66664 .42065 .67114 .42914 .66871 .42416 .66419 Metetra
.656 .751 .919 r
.42416 .66419 .42914 .66871 .43766 .66627 .43269 .66174 Metetra
.656 .751 .919 r
.43269 .66174 .43766 .66627 .4462 .66382 .44126 .65927 Metetra
.656 .751 .919 r
.44126 .65927 .4462 .66382 .45477 .66136 .44984 .6568 Metetra
.656 .751 .919 r
.44984 .6568 .45477 .66136 .46337 .65889 .45846 .65432 Metetra
.656 .751 .919 r
.45846 .65432 .46337 .65889 .472 .65642 .4671 .65184 Metetra
.656 .751 .919 r
.4671 .65184 .472 .65642 .48065 .65394 .47578 .64934 Metetra
.656 .751 .919 r
.47578 .64934 .48065 .65394 .48933 .65145 .48447 .64684 Metetra
.656 .751 .919 r
.48447 .64684 .48933 .65145 .49804 .64896 .4932 .64433 Metetra
.656 .751 .919 r
.4932 .64433 .49804 .64896 .50678 .64645 .50196 .64181 Metetra
.656 .751 .919 r
.50196 .64181 .50678 .64645 .51554 .64394 .51074 .63928 Metetra
.656 .751 .919 r
.51074 .63928 .51554 .64394 .52434 .64142 .51955 .63675 Metetra
.656 .751 .919 r
.51955 .63675 .52434 .64142 .53316 .63889 .52839 .6342 Metetra
.656 .751 .919 r
.52839 .6342 .53316 .63889 .54201 .63635 .53726 .63165 Metetra
.656 .751 .919 r
.53726 .63165 .54201 .63635 .55088 .63381 .54615 .62909 Metetra
.656 .751 .919 r
.54615 .62909 .55088 .63381 .55979 .63126 .55508 .62652 Metetra
.656 .751 .919 r
.55508 .62652 .55979 .63126 .56873 .6287 .56403 .62395 Metetra
.656 .751 .919 r
.56403 .62395 .56873 .6287 .57769 .62613 .57302 .62136 Metetra
.656 .751 .919 r
.57302 .62136 .57769 .62613 .58668 .62355 .58203 .61877 Metetra
.656 .751 .919 r
.58203 .61877 .58668 .62355 .5957 .62096 .59107 .61617 Metetra
.656 .751 .919 r
.59107 .61617 .5957 .62096 .60476 .61837 .60014 .61356 Metetra
.656 .751 .919 r
.60014 .61356 .60476 .61837 .61384 .61577 .60924 .61094 Metetra
.656 .751 .919 r
.60924 .61094 .61384 .61577 .62295 .61315 .61837 .60831 Metetra
.656 .751 .919 r
.61837 .60831 .62295 .61315 .63209 .61053 .62753 .60567 Metetra
.656 .751 .919 r
.62753 .60567 .63209 .61053 .64126 .60791 .63672 .60303 Metetra
.656 .751 .919 r
.63672 .60303 .64126 .60791 .65046 .60527 .64594 .60038 Metetra
.656 .751 .919 r
.64594 .60038 .65046 .60527 .65969 .60262 .6552 .59772 Metetra
.656 .751 .919 r
.6552 .59772 .65969 .60262 .66895 .59997 .66448 .59504 Metetra
.656 .751 .919 r
.66448 .59504 .66895 .59997 .67824 .5973 .67379 .59236 Metetra
.656 .751 .919 r
.67379 .59236 .67824 .5973 .68756 .59463 .68313 .58968 Metetra
.656 .751 .919 r
.68313 .58968 .68756 .59463 .69692 .59195 .69251 .58698 Metetra
.656 .751 .919 r
.69251 .58698 .69692 .59195 .7063 .58926 .70191 .58427 Metetra
.656 .751 .919 r
.70191 .58427 .7063 .58926 .71571 .58656 .71135 .58156 Metetra
.656 .751 .919 r
.71135 .58156 .71571 .58656 .72516 .58386 .72082 .57883 Metetra
.656 .751 .919 r
.72082 .57883 .72516 .58386 .73464 .58114 .73031 .5761 Metetra
.656 .751 .919 r
.73031 .5761 .73464 .58114 .74415 .57841 .73985 .57336 Metetra
.656 .751 .919 r
.73985 .57336 .74415 .57841 .75369 .57568 .74941 .57061 Metetra
.656 .751 .919 r
.74941 .57061 .75369 .57568 .76326 .57294 .759 .56785 Metetra
.656 .751 .919 r
.759 .56785 .76326 .57294 .77286 .57018 .76863 .56508 Metetra
.656 .751 .919 r
.76863 .56508 .77286 .57018 .7825 .56742 .77829 .5623 Metetra
.656 .751 .919 r
.77829 .5623 .7825 .56742 .79217 .56465 .78798 .55951 Metetra
.656 .751 .919 r
.78798 .55951 .79217 .56465 .80187 .56187 .79771 .55671 Metetra
.656 .751 .919 r
.79771 .55671 .80187 .56187 .81161 .55908 .80747 .5539 Metetra
.656 .751 .919 r
.80747 .5539 .81161 .55908 .82137 .55628 .81726 .55108 Metetra
.656 .751 .919 r
.81726 .55108 .82137 .55628 .83117 .55347 .82708 .54826 Metetra
.656 .751 .919 r
.82708 .54826 .83117 .55347 .84101 .55065 .83694 .54542 Metetra
.656 .751 .919 r
.83694 .54542 .84101 .55065 .85087 .54782 .84683 .54257 Metetra
.656 .751 .919 r
.84683 .54257 .85087 .54782 .86077 .54498 .85675 .53972 Metetra
.656 .751 .919 r
.85675 .53972 .86077 .54498 .87071 .54214 .86671 .53685 Metetra
.656 .751 .919 r
.86671 .53685 .87071 .54214 .88068 .53928 .8767 .53398 Metetra
.656 .751 .919 r
.8767 .53398 .88068 .53928 .89068 .53641 .88673 .53109 Metetra
.656 .751 .919 r
.88673 .53109 .89068 .53641 .90072 .53354 .89679 .5282 Metetra
.656 .751 .919 r
.89679 .5282 .90072 .53354 .91079 .53065 .90689 .52529 Metetra
.656 .751 .919 r
.90689 .52529 .91079 .53065 .92089 .52775 .91702 .52238 Metetra
.656 .751 .919 r
.91702 .52238 .92089 .52775 .93103 .52485 .92719 .51945 Metetra
.656 .751 .919 r
.92719 .51945 .93103 .52485 .94121 .52193 .93739 .51652 Metetra
.656 .751 .919 r
.93739 .51652 .94121 .52193 .95142 .519 .94762 .51357 Metetra
.656 .751 .919 r
.94762 .51357 .95142 .519 .96166 .51607 .95789 .51062 Metetra
.656 .751 .919 r
.95789 .51062 .96166 .51607 .97194 .51312 .9682 .50765 Metetra
.108 .06 .516 r
.37841 .63373 .38174 .68 .39029 .67394 .38521 .66946 Metetra
.656 .751 .919 r
.38521 .66946 .39029 .67394 .39871 .67151 .39365 .66702 Metetra
.656 .751 .919 r
.39365 .66702 .39871 .67151 .40717 .66908 .40213 .66457 Metetra
.656 .751 .919 r
.40213 .66457 .40717 .66908 .41565 .66664 .41062 .66212 Metetra
.656 .751 .919 r
.41062 .66212 .41565 .66664 .42416 .66419 .41915 .65965 Metetra
.656 .751 .919 r
.41915 .65965 .42416 .66419 .43269 .66174 .4277 .65718 Metetra
.656 .751 .919 r
.4277 .65718 .43269 .66174 .44126 .65927 .43628 .65471 Metetra
.656 .751 .919 r
.43628 .65471 .44126 .65927 .44984 .6568 .44489 .65222 Metetra
.656 .751 .919 r
.44489 .65222 .44984 .6568 .45846 .65432 .45352 .64973 Metetra
.656 .751 .919 r
.45352 .64973 .45846 .65432 .4671 .65184 .46218 .64722 Metetra
.656 .751 .919 r
.46218 .64722 .4671 .65184 .47578 .64934 .47087 .64471 Metetra
.656 .751 .919 r
.47087 .64471 .47578 .64934 .48447 .64684 .47959 .6422 Metetra
.656 .751 .919 r
.47959 .6422 .48447 .64684 .4932 .64433 .48833 .63967 Metetra
.656 .751 .919 r
.48833 .63967 .4932 .64433 .50196 .64181 .4971 .63714 Metetra
.656 .751 .919 r
.4971 .63714 .50196 .64181 .51074 .63928 .50591 .63459 Metetra
.656 .751 .919 r
.50591 .63459 .51074 .63928 .51955 .63675 .51473 .63204 Metetra
.656 .751 .919 r
.51473 .63204 .51955 .63675 .52839 .6342 .52359 .62948 Metetra
.656 .751 .919 r
.52359 .62948 .52839 .6342 .53726 .63165 .53248 .62692 Metetra
.656 .751 .919 r
.53248 .62692 .53726 .63165 .54615 .62909 .54139 .62434 Metetra
.656 .751 .919 r
.54139 .62434 .54615 .62909 .55508 .62652 .55034 .62176 Metetra
.656 .751 .919 r
.55034 .62176 .55508 .62652 .56403 .62395 .55931 .61917 Metetra
.656 .751 .919 r
.55931 .61917 .56403 .62395 .57302 .62136 .56831 .61657 Metetra
.656 .751 .919 r
.56831 .61657 .57302 .62136 .58203 .61877 .57735 .61396 Metetra
.656 .751 .919 r
.57735 .61396 .58203 .61877 .59107 .61617 .58641 .61134 Metetra
.656 .751 .919 r
.58641 .61134 .59107 .61617 .60014 .61356 .5955 .60872 Metetra
.656 .751 .919 r
.5955 .60872 .60014 .61356 .60924 .61094 .60462 .60608 Metetra
.656 .751 .919 r
.60462 .60608 .60924 .61094 .61837 .60831 .61377 .60344 Metetra
.656 .751 .919 r
.61377 .60344 .61837 .60831 .62753 .60567 .62295 .60079 Metetra
.656 .751 .919 r
.62295 .60079 .62753 .60567 .63672 .60303 .63216 .59813 Metetra
.656 .751 .919 r
.63216 .59813 .63672 .60303 .64594 .60038 .6414 .59546 Metetra
.656 .751 .919 r
.6414 .59546 .64594 .60038 .6552 .59772 .65067 .59278 Metetra
.656 .751 .919 r
.65067 .59278 .6552 .59772 .66448 .59504 .65998 .59009 Metetra
.656 .751 .919 r
.65998 .59009 .66448 .59504 .67379 .59236 .66931 .58739 Metetra
.656 .751 .919 r
.66931 .58739 .67379 .59236 .68313 .58968 .67867 .58469 Metetra
.656 .751 .919 r
.67867 .58469 .68313 .58968 .69251 .58698 .68807 .58198 Metetra
.656 .751 .919 r
.68807 .58198 .69251 .58698 .70191 .58427 .6975 .57925 Metetra
.656 .751 .919 r
.6975 .57925 .70191 .58427 .71135 .58156 .70695 .57652 Metetra
.656 .751 .919 r
.70695 .57652 .71135 .58156 .72082 .57883 .71644 .57378 Metetra
.656 .751 .919 r
.71644 .57378 .72082 .57883 .73031 .5761 .72597 .57103 Metetra
.656 .751 .919 r
.72597 .57103 .73031 .5761 .73985 .57336 .73552 .56827 Metetra
.656 .751 .919 r
.73552 .56827 .73985 .57336 .74941 .57061 .7451 .5655 Metetra
.656 .751 .919 r
.7451 .5655 .74941 .57061 .759 .56785 .75472 .56272 Metetra
.656 .751 .919 r
.75472 .56272 .759 .56785 .76863 .56508 .76437 .55994 Metetra
.656 .751 .919 r
.76437 .55994 .76863 .56508 .77829 .5623 .77405 .55714 Metetra
.656 .751 .919 r
.77405 .55714 .77829 .5623 .78798 .55951 .78377 .55433 Metetra
.656 .751 .919 r
.78377 .55433 .78798 .55951 .79771 .55671 .79352 .55152 Metetra
.656 .751 .919 r
.79352 .55152 .79771 .55671 .80747 .5539 .8033 .54869 Metetra
.656 .751 .919 r
.8033 .54869 .80747 .5539 .81726 .55108 .81311 .54586 Metetra
.656 .751 .919 r
.81311 .54586 .81726 .55108 .82708 .54826 .82296 .54301 Metetra
.656 .751 .919 r
.82296 .54301 .82708 .54826 .83694 .54542 .83284 .54016 Metetra
.656 .751 .919 r
.83284 .54016 .83694 .54542 .84683 .54257 .84276 .5373 Metetra
.656 .751 .919 r
.84276 .5373 .84683 .54257 .85675 .53972 .85271 .53442 Metetra
.656 .751 .919 r
.85271 .53442 .85675 .53972 .86671 .53685 .86269 .53154 Metetra
.656 .751 .919 r
.86269 .53154 .86671 .53685 .8767 .53398 .87271 .52864 Metetra
.656 .751 .919 r
.87271 .52864 .8767 .53398 .88673 .53109 .88276 .52574 Metetra
.656 .751 .919 r
.88276 .52574 .88673 .53109 .89679 .5282 .89285 .52283 Metetra
.656 .751 .919 r
.89285 .52283 .89679 .5282 .90689 .52529 .90297 .5199 Metetra
.656 .751 .919 r
.90297 .5199 .90689 .52529 .91702 .52238 .91312 .51697 Metetra
.656 .751 .919 r
.91312 .51697 .91702 .52238 .92719 .51945 .92331 .51403 Metetra
.656 .751 .919 r
.92331 .51403 .92719 .51945 .93739 .51652 .93354 .51107 Metetra
.656 .751 .919 r
.93354 .51107 .93739 .51652 .94762 .51357 .9438 .50811 Metetra
.656 .751 .919 r
.9438 .50811 .94762 .51357 .95789 .51062 .9541 .50513 Metetra
.656 .751 .919 r
.9541 .50513 .95789 .51062 .9682 .50765 .96444 .50215 Metetra
.246 .068 .431 r
.36961 .71426 .37841 .63373 .38521 .66946 .3801 .66495 Metetra
.656 .751 .919 r
.3801 .66495 .38521 .66946 .39365 .66702 .38856 .66249 Metetra
.656 .751 .919 r
.38856 .66249 .39365 .66702 .40213 .66457 .39705 .66003 Metetra
.656 .751 .919 r
.39705 .66003 .40213 .66457 .41062 .66212 .40557 .65756 Metetra
.656 .751 .919 r
.40557 .65756 .41062 .66212 .41915 .65965 .41411 .65509 Metetra
.656 .751 .919 r
.41411 .65509 .41915 .65965 .4277 .65718 .42268 .6526 Metetra
.656 .751 .919 r
.42268 .6526 .4277 .65718 .43628 .65471 .43127 .65011 Metetra
.656 .751 .919 r
.43127 .65011 .43628 .65471 .44489 .65222 .4399 .64761 Metetra
.656 .751 .919 r
.4399 .64761 .44489 .65222 .45352 .64973 .44855 .6451 Metetra
.656 .751 .919 r
.44855 .6451 .45352 .64973 .46218 .64722 .45723 .64258 Metetra
.656 .751 .919 r
.45723 .64258 .46218 .64722 .47087 .64471 .46594 .64006 Metetra
.656 .751 .919 r
.46594 .64006 .47087 .64471 .47959 .6422 .47467 .63753 Metetra
.656 .751 .919 r
.47467 .63753 .47959 .6422 .48833 .63967 .48343 .63499 Metetra
.656 .751 .919 r
.48343 .63499 .48833 .63967 .4971 .63714 .49222 .63244 Metetra
.656 .751 .919 r
.49222 .63244 .4971 .63714 .50591 .63459 .50104 .62988 Metetra
.656 .751 .919 r
.50104 .62988 .50591 .63459 .51473 .63204 .50989 .62731 Metetra
.656 .751 .919 r
.50989 .62731 .51473 .63204 .52359 .62948 .51877 .62474 Metetra
.656 .751 .919 r
.51877 .62474 .52359 .62948 .53248 .62692 .52767 .62216 Metetra
.656 .751 .919 r
.52767 .62216 .53248 .62692 .54139 .62434 .53661 .61957 Metetra
.656 .751 .919 r
.53661 .61957 .54139 .62434 .55034 .62176 .54557 .61697 Metetra
.656 .751 .919 r
.54557 .61697 .55034 .62176 .55931 .61917 .55456 .61436 Metetra
.656 .751 .919 r
.55456 .61436 .55931 .61917 .56831 .61657 .56358 .61174 Metetra
.656 .751 .919 r
.56358 .61174 .56831 .61657 .57735 .61396 .57264 .60912 Metetra
.656 .751 .919 r
.57264 .60912 .57735 .61396 .58641 .61134 .58172 .60649 Metetra
.656 .751 .919 r
.58172 .60649 .58641 .61134 .5955 .60872 .59083 .60384 Metetra
.656 .751 .919 r
.59083 .60384 .5955 .60872 .60462 .60608 .59997 .60119 Metetra
.656 .751 .919 r
.59997 .60119 .60462 .60608 .61377 .60344 .60914 .59854 Metetra
.656 .751 .919 r
.60914 .59854 .61377 .60344 .62295 .60079 .61834 .59587 Metetra
.656 .751 .919 r
.61834 .59587 .62295 .60079 .63216 .59813 .62757 .59319 Metetra
.656 .751 .919 r
.62757 .59319 .63216 .59813 .6414 .59546 .63683 .5905 Metetra
.656 .751 .919 r
.63683 .5905 .6414 .59546 .65067 .59278 .64613 .58781 Metetra
.656 .751 .919 r
.64613 .58781 .65067 .59278 .65998 .59009 .65545 .58511 Metetra
.656 .751 .919 r
.65545 .58511 .65998 .59009 .66931 .58739 .6648 .58239 Metetra
.656 .751 .919 r
.6648 .58239 .66931 .58739 .67867 .58469 .67419 .57967 Metetra
.656 .751 .919 r
.67419 .57967 .67867 .58469 .68807 .58198 .68361 .57694 Metetra
.656 .751 .919 r
.68361 .57694 .68807 .58198 .6975 .57925 .69305 .5742 Metetra
.656 .751 .919 r
.69305 .5742 .6975 .57925 .70695 .57652 .70253 .57145 Metetra
.656 .751 .919 r
.70253 .57145 .70695 .57652 .71644 .57378 .71205 .5687 Metetra
.656 .751 .919 r
.71205 .5687 .71644 .57378 .72597 .57103 .72159 .56593 Metetra
.656 .751 .919 r
.72159 .56593 .72597 .57103 .73552 .56827 .73116 .56315 Metetra
.656 .751 .919 r
.73116 .56315 .73552 .56827 .7451 .5655 .74077 .56037 Metetra
.656 .751 .919 r
.74077 .56037 .7451 .5655 .75472 .56272 .75041 .55757 Metetra
.656 .751 .919 r
.75041 .55757 .75472 .56272 .76437 .55994 .76009 .55477 Metetra
.656 .751 .919 r
.76009 .55477 .76437 .55994 .77405 .55714 .76979 .55195 Metetra
.656 .751 .919 r
.76979 .55195 .77405 .55714 .78377 .55433 .77953 .54913 Metetra
.656 .751 .919 r
.77953 .54913 .78377 .55433 .79352 .55152 .7893 .54629 Metetra
.656 .751 .919 r
.7893 .54629 .79352 .55152 .8033 .54869 .79911 .54345 Metetra
.656 .751 .919 r
.79911 .54345 .8033 .54869 .81311 .54586 .80894 .5406 Metetra
.656 .751 .919 r
.80894 .5406 .81311 .54586 .82296 .54301 .81882 .53774 Metetra
.656 .751 .919 r
.81882 .53774 .82296 .54301 .83284 .54016 .82872 .53486 Metetra
.656 .751 .919 r
.82872 .53486 .83284 .54016 .84276 .5373 .83866 .53198 Metetra
.656 .751 .919 r
.83866 .53198 .84276 .5373 .85271 .53442 .84863 .52909 Metetra
.656 .751 .919 r
.84863 .52909 .85271 .53442 .86269 .53154 .85864 .52619 Metetra
.656 .751 .919 r
.85864 .52619 .86269 .53154 .87271 .52864 .86868 .52328 Metetra
.656 .751 .919 r
.86868 .52328 .87271 .52864 .88276 .52574 .87876 .52035 Metetra
.656 .751 .919 r
.87876 .52035 .88276 .52574 .89285 .52283 .88887 .51742 Metetra
.656 .751 .919 r
.88887 .51742 .89285 .52283 .90297 .5199 .89902 .51448 Metetra
.656 .751 .919 r
.89902 .51448 .90297 .5199 .91312 .51697 .9092 .51153 Metetra
.656 .751 .919 r
.9092 .51153 .91312 .51697 .92331 .51403 .91942 .50856 Metetra
.656 .751 .919 r
.91942 .50856 .92331 .51403 .93354 .51107 .92967 .50559 Metetra
.656 .751 .919 r
.92967 .50559 .93354 .51107 .9438 .50811 .93996 .50261 Metetra
.656 .751 .919 r
.93996 .50261 .9438 .50811 .9541 .50513 .95028 .49961 Metetra
.656 .751 .919 r
.95028 .49961 .9541 .50513 .96444 .50215 .96064 .49661 Metetra
.432 .279 .571 r
.3678 .63453 .36961 .71426 .3801 .66495 .37497 .66041 Metetra
.656 .751 .919 r
.37497 .66041 .3801 .66495 .38856 .66249 .38345 .65794 Metetra
.656 .751 .919 r
.38345 .65794 .38856 .66249 .39705 .66003 .39195 .65547 Metetra
.656 .751 .919 r
.39195 .65547 .39705 .66003 .40557 .65756 .40048 .65298 Metetra
.656 .751 .919 r
.40048 .65298 .40557 .65756 .41411 .65509 .40904 .65049 Metetra
.656 .751 .919 r
.40904 .65049 .41411 .65509 .42268 .6526 .41763 .64799 Metetra
.656 .751 .919 r
.41763 .64799 .42268 .6526 .43127 .65011 .42624 .64549 Metetra
.656 .751 .919 r
.42624 .64549 .43127 .65011 .4399 .64761 .43488 .64297 Metetra
.656 .751 .919 r
.43488 .64297 .4399 .64761 .44855 .6451 .44355 .64045 Metetra
.656 .751 .919 r
.44355 .64045 .44855 .6451 .45723 .64258 .45225 .63792 Metetra
.656 .751 .919 r
.45225 .63792 .45723 .64258 .46594 .64006 .46097 .63538 Metetra
.656 .751 .919 r
.46097 .63538 .46594 .64006 .47467 .63753 .46972 .63283 Metetra
.656 .751 .919 r
.46972 .63283 .47467 .63753 .48343 .63499 .4785 .63027 Metetra
.656 .751 .919 r
.4785 .63027 .48343 .63499 .49222 .63244 .48731 .62771 Metetra
.656 .751 .919 r
.48731 .62771 .49222 .63244 .50104 .62988 .49615 .62514 Metetra
.656 .751 .919 r
.49615 .62514 .50104 .62988 .50989 .62731 .50502 .62256 Metetra
.656 .751 .919 r
.50502 .62256 .50989 .62731 .51877 .62474 .51391 .61997 Metetra
.656 .751 .919 r
.51391 .61997 .51877 .62474 .52767 .62216 .52284 .61737 Metetra
.656 .751 .919 r
.52284 .61737 .52767 .62216 .53661 .61957 .53179 .61476 Metetra
.656 .751 .919 r
.53179 .61476 .53661 .61957 .54557 .61697 .54077 .61215 Metetra
.656 .751 .919 r
.54077 .61215 .54557 .61697 .55456 .61436 .54979 .60952 Metetra
.656 .751 .919 r
.54979 .60952 .55456 .61436 .56358 .61174 .55883 .60689 Metetra
.656 .751 .919 r
.55883 .60689 .56358 .61174 .57264 .60912 .5679 .60425 Metetra
.656 .751 .919 r
.5679 .60425 .57264 .60912 .58172 .60649 .577 .6016 Metetra
.656 .751 .919 r
.577 .6016 .58172 .60649 .59083 .60384 .58613 .59894 Metetra
.656 .751 .919 r
.58613 .59894 .59083 .60384 .59997 .60119 .59529 .59628 Metetra
.656 .751 .919 r
.59529 .59628 .59997 .60119 .60914 .59854 .60448 .5936 Metetra
.656 .751 .919 r
.60448 .5936 .60914 .59854 .61834 .59587 .6137 .59092 Metetra
.656 .751 .919 r
.6137 .59092 .61834 .59587 .62757 .59319 .62295 .58823 Metetra
.656 .751 .919 r
.62295 .58823 .62757 .59319 .63683 .5905 .63224 .58552 Metetra
.656 .751 .919 r
.63224 .58552 .63683 .5905 .64613 .58781 .64155 .58281 Metetra
.656 .751 .919 r
.64155 .58281 .64613 .58781 .65545 .58511 .65089 .58009 Metetra
.656 .751 .919 r
.65089 .58009 .65545 .58511 .6648 .58239 .66027 .57736 Metetra
.656 .751 .919 r
.66027 .57736 .6648 .58239 .67419 .57967 .66968 .57462 Metetra
.656 .751 .919 r
.66968 .57462 .67419 .57967 .68361 .57694 .67911 .57188 Metetra
.656 .751 .919 r
.67911 .57188 .68361 .57694 .69305 .5742 .68858 .56912 Metetra
.656 .751 .919 r
.68858 .56912 .69305 .5742 .70253 .57145 .69809 .56635 Metetra
.656 .751 .919 r
.69809 .56635 .70253 .57145 .71205 .5687 .70762 .56358 Metetra
.656 .751 .919 r
.70762 .56358 .71205 .5687 .72159 .56593 .71719 .5608 Metetra
.656 .751 .919 r
.71719 .5608 .72159 .56593 .73116 .56315 .72678 .558 Metetra
.656 .751 .919 r
.72678 .558 .73116 .56315 .74077 .56037 .73641 .5552 Metetra
.656 .751 .919 r
.73641 .5552 .74077 .56037 .75041 .55757 .74608 .55239 Metetra
.656 .751 .919 r
.74608 .55239 .75041 .55757 .76009 .55477 .75577 .54956 Metetra
.656 .751 .919 r
.75577 .54956 .76009 .55477 .76979 .55195 .7655 .54673 Metetra
.656 .751 .919 r
.7655 .54673 .76979 .55195 .77953 .54913 .77526 .54389 Metetra
.656 .751 .919 r
.77526 .54389 .77953 .54913 .7893 .54629 .78506 .54104 Metetra
.656 .751 .919 r
.78506 .54104 .7893 .54629 .79911 .54345 .79489 .53818 Metetra
.656 .751 .919 r
.79489 .53818 .79911 .54345 .80894 .5406 .80475 .53531 Metetra
.656 .751 .919 r
.80475 .53531 .80894 .5406 .81882 .53774 .81464 .53243 Metetra
.656 .751 .919 r
.81464 .53243 .81882 .53774 .82872 .53486 .82457 .52954 Metetra
.656 .751 .919 r
.82457 .52954 .82872 .53486 .83866 .53198 .83454 .52664 Metetra
.656 .751 .919 r
.83454 .52664 .83866 .53198 .84863 .52909 .84454 .52372 Metetra
.656 .751 .919 r
.84454 .52372 .84863 .52909 .85864 .52619 .85457 .5208 Metetra
.656 .751 .919 r
.85457 .5208 .85864 .52619 .86868 .52328 .86464 .51787 Metetra
.656 .751 .919 r
.86464 .51787 .86868 .52328 .87876 .52035 .87474 .51493 Metetra
.656 .751 .919 r
.87474 .51493 .87876 .52035 .88887 .51742 .88487 .51198 Metetra
.656 .751 .919 r
.88487 .51198 .88887 .51742 .89902 .51448 .89505 .50902 Metetra
.656 .751 .919 r
.89505 .50902 .89902 .51448 .9092 .51153 .90525 .50605 Metetra
.656 .751 .919 r
.90525 .50605 .9092 .51153 .91942 .50856 .9155 .50307 Metetra
.656 .751 .919 r
.9155 .50307 .91942 .50856 .92967 .50559 .92578 .50008 Metetra
.656 .751 .919 r
.92578 .50008 .92967 .50559 .93996 .50261 .93609 .49707 Metetra
.656 .751 .919 r
.93609 .49707 .93996 .50261 .95028 .49961 .94644 .49406 Metetra
.656 .751 .919 r
.94644 .49406 .95028 .49961 .96064 .49661 .95683 .49104 Metetra
.521 .238 .426 r
.36137 .65755 .3678 .63453 .37497 .66041 .3698 .65585 Metetra
.656 .751 .919 r
.3698 .65585 .37497 .66041 .38345 .65794 .3783 .65337 Metetra
.656 .751 .919 r
.3783 .65337 .38345 .65794 .39195 .65547 .38682 .65088 Metetra
.656 .751 .919 r
.38682 .65088 .39195 .65547 .40048 .65298 .39537 .64838 Metetra
.656 .751 .919 r
.39537 .64838 .40048 .65298 .40904 .65049 .40394 .64587 Metetra
.656 .751 .919 r
.40394 .64587 .40904 .65049 .41763 .64799 .41254 .64336 Metetra
.656 .751 .919 r
.41254 .64336 .41763 .64799 .42624 .64549 .42118 .64084 Metetra
.656 .751 .919 r
.42118 .64084 .42624 .64549 .43488 .64297 .42983 .63831 Metetra
.656 .751 .919 r
.42983 .63831 .43488 .64297 .44355 .64045 .43852 .63577 Metetra
.656 .751 .919 r
.43852 .63577 .44355 .64045 .45225 .63792 .44724 .63322 Metetra
.656 .751 .919 r
.44724 .63322 .45225 .63792 .46097 .63538 .45598 .63067 Metetra
.656 .751 .919 r
.45598 .63067 .46097 .63538 .46972 .63283 .46475 .6281 Metetra
.656 .751 .919 r
.46475 .6281 .46972 .63283 .4785 .63027 .47355 .62553 Metetra
.656 .751 .919 r
.47355 .62553 .4785 .63027 .48731 .62771 .48237 .62295 Metetra
.656 .751 .919 r
.48237 .62295 .48731 .62771 .49615 .62514 .49123 .62036 Metetra
.656 .751 .919 r
.49123 .62036 .49615 .62514 .50502 .62256 .50012 .61777 Metetra
.656 .751 .919 r
.50012 .61777 .50502 .62256 .51391 .61997 .50903 .61516 Metetra
.656 .751 .919 r
.50903 .61516 .51391 .61997 .52284 .61737 .51797 .61255 Metetra
.656 .751 .919 r
.51797 .61255 .52284 .61737 .53179 .61476 .52695 .60993 Metetra
.656 .751 .919 r
.52695 .60993 .53179 .61476 .54077 .61215 .53595 .6073 Metetra
.656 .751 .919 r
.53595 .6073 .54077 .61215 .54979 .60952 .54498 .60466 Metetra
.656 .751 .919 r
.54498 .60466 .54979 .60952 .55883 .60689 .55404 .60201 Metetra
.656 .751 .919 r
.55404 .60201 .55883 .60689 .5679 .60425 .56313 .59935 Metetra
.656 .751 .919 r
.56313 .59935 .5679 .60425 .577 .6016 .57225 .59669 Metetra
.656 .751 .919 r
.57225 .59669 .577 .6016 .58613 .59894 .5814 .59401 Metetra
.656 .751 .919 r
.5814 .59401 .58613 .59894 .59529 .59628 .59058 .59133 Metetra
.656 .751 .919 r
.59058 .59133 .59529 .59628 .60448 .5936 .59979 .58864 Metetra
.656 .751 .919 r
.59979 .58864 .60448 .5936 .6137 .59092 .60903 .58594 Metetra
.656 .751 .919 r
.60903 .58594 .6137 .59092 .62295 .58823 .61831 .58323 Metetra
.656 .751 .919 r
.61831 .58323 .62295 .58823 .63224 .58552 .62761 .58051 Metetra
.656 .751 .919 r
.62761 .58051 .63224 .58552 .64155 .58281 .63694 .57778 Metetra
.656 .751 .919 r
.63694 .57778 .64155 .58281 .65089 .58009 .64631 .57505 Metetra
.656 .751 .919 r
.64631 .57505 .65089 .58009 .66027 .57736 .65571 .5723 Metetra
.656 .751 .919 r
.65571 .5723 .66027 .57736 .66968 .57462 .66514 .56955 Metetra
.656 .751 .919 r
.66514 .56955 .66968 .57462 .67911 .57188 .6746 .56678 Metetra
.656 .751 .919 r
.6746 .56678 .67911 .57188 .68858 .56912 .68409 .56401 Metetra
.656 .751 .919 r
.68409 .56401 .68858 .56912 .69809 .56635 .69361 .56122 Metetra
.656 .751 .919 r
.69361 .56122 .69809 .56635 .70762 .56358 .70317 .55843 Metetra
.656 .751 .919 r
.70317 .55843 .70762 .56358 .71719 .5608 .71275 .55563 Metetra
.656 .751 .919 r
.71275 .55563 .71719 .5608 .72678 .558 .72237 .55282 Metetra
.656 .751 .919 r
.72237 .55282 .72678 .558 .73641 .5552 .73203 .55 Metetra
.656 .751 .919 r
.73203 .55 .73641 .5552 .74608 .55239 .74171 .54717 Metetra
.656 .751 .919 r
.74171 .54717 .74608 .55239 .75577 .54956 .75143 .54433 Metetra
.656 .751 .919 r
.75143 .54433 .75577 .54956 .7655 .54673 .76118 .54148 Metetra
.656 .751 .919 r
.76118 .54148 .7655 .54673 .77526 .54389 .77097 .53862 Metetra
.656 .751 .919 r
.77097 .53862 .77526 .54389 .78506 .54104 .78079 .53575 Metetra
.656 .751 .919 r
.78079 .53575 .78506 .54104 .79489 .53818 .79064 .53287 Metetra
.656 .751 .919 r
.79064 .53287 .79489 .53818 .80475 .53531 .80053 .52998 Metetra
.656 .751 .919 r
.80053 .52998 .80475 .53531 .81464 .53243 .81045 .52708 Metetra
.656 .751 .919 r
.81045 .52708 .81464 .53243 .82457 .52954 .8204 .52417 Metetra
.656 .751 .919 r
.8204 .52417 .82457 .52954 .83454 .52664 .83039 .52125 Metetra
.656 .751 .919 r
.83039 .52125 .83454 .52664 .84454 .52372 .84041 .51833 Metetra
.656 .751 .919 r
.84041 .51833 .84454 .52372 .85457 .5208 .85047 .51539 Metetra
.656 .751 .919 r
.85047 .51539 .85457 .5208 .86464 .51787 .86056 .51244 Metetra
.656 .751 .919 r
.86056 .51244 .86464 .51787 .87474 .51493 .87069 .50948 Metetra
.656 .751 .919 r
.87069 .50948 .87474 .51493 .88487 .51198 .88085 .50651 Metetra
.656 .751 .919 r
.88085 .50651 .88487 .51198 .89505 .50902 .89105 .50353 Metetra
.656 .751 .919 r
.89105 .50353 .89505 .50902 .90525 .50605 .90128 .50054 Metetra
.656 .751 .919 r
.90128 .50054 .90525 .50605 .9155 .50307 .91155 .49754 Metetra
.656 .751 .919 r
.91155 .49754 .9155 .50307 .92578 .50008 .92186 .49452 Metetra
.656 .751 .919 r
.92186 .49452 .92578 .50008 .93609 .49707 .9322 .4915 Metetra
.656 .751 .919 r
.9322 .4915 .93609 .49707 .94644 .49406 .94258 .48847 Metetra
.656 .751 .919 r
.94258 .48847 .94644 .49406 .95683 .49104 .95299 .48543 Metetra
.35492 .6785 .36137 .65755 .3698 .65585 .3646 .65126 Metetra
.656 .751 .919 r
.3646 .65126 .3698 .65585 .3783 .65337 .37312 .64876 Metetra
.656 .751 .919 r
.37312 .64876 .3783 .65337 .38682 .65088 .38165 .64626 Metetra
.656 .751 .919 r
.38165 .64626 .38682 .65088 .39537 .64838 .39022 .64375 Metetra
.656 .751 .919 r
.39022 .64375 .39537 .64838 .40394 .64587 .39881 .64123 Metetra
.656 .751 .919 r
.39881 .64123 .40394 .64587 .41254 .64336 .40743 .6387 Metetra
.656 .751 .919 r
.40743 .6387 .41254 .64336 .42118 .64084 .41608 .63616 Metetra
.656 .751 .919 r
.41608 .63616 .42118 .64084 .42983 .63831 .42476 .63361 Metetra
.656 .751 .919 r
.42476 .63361 .42983 .63831 .43852 .63577 .43346 .63106 Metetra
.656 .751 .919 r
.43346 .63106 .43852 .63577 .44724 .63322 .44219 .6285 Metetra
.656 .751 .919 r
.44219 .6285 .44724 .63322 .45598 .63067 .45095 .62593 Metetra
.656 .751 .919 r
.45095 .62593 .45598 .63067 .46475 .6281 .45974 .62335 Metetra
.656 .751 .919 r
.45974 .62335 .46475 .6281 .47355 .62553 .46856 .62076 Metetra
.656 .751 .919 r
.46856 .62076 .47355 .62553 .48237 .62295 .47741 .61817 Metetra
.656 .751 .919 r
.47741 .61817 .48237 .62295 .49123 .62036 .48628 .61556 Metetra
.656 .751 .919 r
.48628 .61556 .49123 .62036 .50012 .61777 .49518 .61295 Metetra
.656 .751 .919 r
.49518 .61295 .50012 .61777 .50903 .61516 .50412 .61033 Metetra
.656 .751 .919 r
.50412 .61033 .50903 .61516 .51797 .61255 .51308 .6077 Metetra
.656 .751 .919 r
.51308 .6077 .51797 .61255 .52695 .60993 .52207 .60507 Metetra
.656 .751 .919 r
.52207 .60507 .52695 .60993 .53595 .6073 .53109 .60242 Metetra
.656 .751 .919 r
.53109 .60242 .53595 .6073 .54498 .60466 .54014 .59976 Metetra
.656 .751 .919 r
.54014 .59976 .54498 .60466 .55404 .60201 .54922 .5971 Metetra
.656 .751 .919 r
.54922 .5971 .55404 .60201 .56313 .59935 .55833 .59443 Metetra
.656 .751 .919 r
.55833 .59443 .56313 .59935 .57225 .59669 .56747 .59175 Metetra
.656 .751 .919 r
.56747 .59175 .57225 .59669 .5814 .59401 .57664 .58905 Metetra
.656 .751 .919 r
.57664 .58905 .5814 .59401 .59058 .59133 .58585 .58636 Metetra
.656 .751 .919 r
.58585 .58636 .59058 .59133 .59979 .58864 .59508 .58365 Metetra
.656 .751 .919 r
.59508 .58365 .59979 .58864 .60903 .58594 .60434 .58093 Metetra
.656 .751 .919 r
.60434 .58093 .60903 .58594 .61831 .58323 .61363 .5782 Metetra
.656 .751 .919 r
.61363 .5782 .61831 .58323 .62761 .58051 .62296 .57547 Metetra
.656 .751 .919 r
.62296 .57547 .62761 .58051 .63694 .57778 .63231 .57272 Metetra
.656 .751 .919 r
.63231 .57272 .63694 .57778 .64631 .57505 .6417 .56997 Metetra
.656 .751 .919 r
.6417 .56997 .64631 .57505 .65571 .5723 .65112 .56721 Metetra
.656 .751 .919 r
.65112 .56721 .65571 .5723 .66514 .56955 .66057 .56443 Metetra
.656 .751 .919 r
.66057 .56443 .66514 .56955 .6746 .56678 .67005 .56165 Metetra
.656 .751 .919 r
.67005 .56165 .6746 .56678 .68409 .56401 .67956 .55886 Metetra
.656 .751 .919 r
.67956 .55886 .68409 .56401 .69361 .56122 .68911 .55606 Metetra
.656 .751 .919 r
.68911 .55606 .69361 .56122 .70317 .55843 .69869 .55325 Metetra
.656 .751 .919 r
.69869 .55325 .70317 .55843 .71275 .55563 .7083 .55043 Metetra
.656 .751 .919 r
.7083 .55043 .71275 .55563 .72237 .55282 .71794 .5476 Metetra
.656 .751 .919 r
.71794 .5476 .72237 .55282 .73203 .55 .72761 .54476 Metetra
.656 .751 .919 r
.72761 .54476 .73203 .55 .74171 .54717 .73732 .54192 Metetra
.656 .751 .919 r
.73732 .54192 .74171 .54717 .75143 .54433 .74707 .53906 Metetra
.656 .751 .919 r
.74707 .53906 .75143 .54433 .76118 .54148 .75684 .53619 Metetra
.656 .751 .919 r
.75684 .53619 .76118 .54148 .77097 .53862 .76665 .53331 Metetra
.656 .751 .919 r
.76665 .53331 .77097 .53862 .78079 .53575 .77649 .53043 Metetra
.656 .751 .919 r
.77649 .53043 .78079 .53575 .79064 .53287 .78637 .52753 Metetra
.656 .751 .919 r
.78637 .52753 .79064 .53287 .80053 .52998 .79628 .52462 Metetra
.656 .751 .919 r
.79628 .52462 .80053 .52998 .81045 .52708 .80622 .5217 Metetra
.656 .751 .919 r
.80622 .5217 .81045 .52708 .8204 .52417 .8162 .51878 Metetra
.656 .751 .919 r
.8162 .51878 .8204 .52417 .83039 .52125 .82621 .51584 Metetra
.656 .751 .919 r
.82621 .51584 .83039 .52125 .84041 .51833 .83626 .51289 Metetra
.656 .751 .919 r
.83626 .51289 .84041 .51833 .85047 .51539 .84634 .50993 Metetra
.656 .751 .919 r
.84634 .50993 .85047 .51539 .86056 .51244 .85646 .50697 Metetra
.656 .751 .919 r
.85646 .50697 .86056 .51244 .87069 .50948 .86661 .50399 Metetra
.656 .751 .919 r
.86661 .50399 .87069 .50948 .88085 .50651 .8768 .501 Metetra
.656 .751 .919 r
.8768 .501 .88085 .50651 .89105 .50353 .88703 .498 Metetra
.656 .751 .919 r
.88703 .498 .89105 .50353 .90128 .50054 .89728 .49499 Metetra
.656 .751 .919 r
.89728 .49499 .90128 .50054 .91155 .49754 .90758 .49197 Metetra
.656 .751 .919 r
.90758 .49197 .91155 .49754 .92186 .49452 .91791 .48894 Metetra
.656 .751 .919 r
.91791 .48894 .92186 .49452 .9322 .4915 .92828 .4859 Metetra
.656 .751 .919 r
.92828 .4859 .9322 .4915 .94258 .48847 .93868 .48284 Metetra
.656 .751 .919 r
.93868 .48284 .94258 .48847 .95299 .48543 .94913 .47978 Metetra
.336 .214 .562 r
.35243 .61821 .35492 .6785 .3646 .65126 .35938 .64665 Metetra
.656 .751 .919 r
.35938 .64665 .3646 .65126 .37312 .64876 .36791 .64413 Metetra
.656 .751 .919 r
.36791 .64413 .37312 .64876 .38165 .64626 .37646 .64161 Metetra
.656 .751 .919 r
.37646 .64161 .38165 .64626 .39022 .64375 .38504 .63909 Metetra
.656 .751 .919 r
.38504 .63909 .39022 .64375 .39881 .64123 .39365 .63655 Metetra
.656 .751 .919 r
.39365 .63655 .39881 .64123 .40743 .6387 .40229 .63401 Metetra
.656 .751 .919 r
.40229 .63401 .40743 .6387 .41608 .63616 .41096 .63145 Metetra
.656 .751 .919 r
.41096 .63145 .41608 .63616 .42476 .63361 .41965 .62889 Metetra
.656 .751 .919 r
.41965 .62889 .42476 .63361 .43346 .63106 .42837 .62632 Metetra
.656 .751 .919 r
.42837 .62632 .43346 .63106 .44219 .6285 .43712 .62375 Metetra
.656 .751 .919 r
.43712 .62375 .44219 .6285 .45095 .62593 .4459 .62116 Metetra
.656 .751 .919 r
.4459 .62116 .45095 .62593 .45974 .62335 .45471 .61857 Metetra
.656 .751 .919 r
.45471 .61857 .45974 .62335 .46856 .62076 .46354 .61597 Metetra
.656 .751 .919 r
.46354 .61597 .46856 .62076 .47741 .61817 .47241 .61336 Metetra
.656 .751 .919 r
.47241 .61336 .47741 .61817 .48628 .61556 .4813 .61074 Metetra
.656 .751 .919 r
.4813 .61074 .48628 .61556 .49518 .61295 .49022 .60811 Metetra
.656 .751 .919 r
.49022 .60811 .49518 .61295 .50412 .61033 .49918 .60547 Metetra
.656 .751 .919 r
.49918 .60547 .50412 .61033 .51308 .6077 .50816 .60283 Metetra
.656 .751 .919 r
.50816 .60283 .51308 .6077 .52207 .60507 .51717 .60017 Metetra
.656 .751 .919 r
.51717 .60017 .52207 .60507 .53109 .60242 .52621 .59751 Metetra
.656 .751 .919 r
.52621 .59751 .53109 .60242 .54014 .59976 .53528 .59484 Metetra
.656 .751 .919 r
.53528 .59484 .54014 .59976 .54922 .5971 .54438 .59216 Metetra
.656 .751 .919 r
.54438 .59216 .54922 .5971 .55833 .59443 .55351 .58947 Metetra
.656 .751 .919 r
.55351 .58947 .55833 .59443 .56747 .59175 .56267 .58677 Metetra
.656 .751 .919 r
.56267 .58677 .56747 .59175 .57664 .58905 .57186 .58406 Metetra
.656 .751 .919 r
.57186 .58406 .57664 .58905 .58585 .58636 .58108 .58135 Metetra
.656 .751 .919 r
.58108 .58135 .58585 .58636 .59508 .58365 .59033 .57862 Metetra
.656 .751 .919 r
.59033 .57862 .59508 .58365 .60434 .58093 .59961 .57589 Metetra
.656 .751 .919 r
.59961 .57589 .60434 .58093 .61363 .5782 .60893 .57315 Metetra
.656 .751 .919 r
.60893 .57315 .61363 .5782 .62296 .57547 .61827 .57039 Metetra
.656 .751 .919 r
.61827 .57039 .62296 .57547 .63231 .57272 .62765 .56763 Metetra
.656 .751 .919 r
.62765 .56763 .63231 .57272 .6417 .56997 .63706 .56486 Metetra
.656 .751 .919 r
.63706 .56486 .6417 .56997 .65112 .56721 .6465 .56208 Metetra
.656 .751 .919 r
.6465 .56208 .65112 .56721 .66057 .56443 .65597 .55929 Metetra
.656 .751 .919 r
.65597 .55929 .66057 .56443 .67005 .56165 .66547 .55649 Metetra
.656 .751 .919 r
.66547 .55649 .67005 .56165 .67956 .55886 .67501 .55368 Metetra
.656 .751 .919 r
.67501 .55368 .67956 .55886 .68911 .55606 .68458 .55087 Metetra
.656 .751 .919 r
.68458 .55087 .68911 .55606 .69869 .55325 .69418 .54804 Metetra
.656 .751 .919 r
.69418 .54804 .69869 .55325 .7083 .55043 .70381 .5452 Metetra
.656 .751 .919 r
.70381 .5452 .7083 .55043 .71794 .5476 .71347 .54236 Metetra
.656 .751 .919 r
.71347 .54236 .71794 .5476 .72761 .54476 .72317 .5395 Metetra
.656 .751 .919 r
.72317 .5395 .72761 .54476 .73732 .54192 .73291 .53663 Metetra
.656 .751 .919 r
.73291 .53663 .73732 .54192 .74707 .53906 .74267 .53376 Metetra
.656 .751 .919 r
.74267 .53376 .74707 .53906 .75684 .53619 .75247 .53087 Metetra
.656 .751 .919 r
.75247 .53087 .75684 .53619 .76665 .53331 .7623 .52797 Metetra
.656 .751 .919 r
.7623 .52797 .76665 .53331 .77649 .53043 .77217 .52507 Metetra
.656 .751 .919 r
.77217 .52507 .77649 .53043 .78637 .52753 .78207 .52215 Metetra
.656 .751 .919 r
.78207 .52215 .78637 .52753 .79628 .52462 .792 .51923 Metetra
.656 .751 .919 r
.792 .51923 .79628 .52462 .80622 .5217 .80197 .51629 Metetra
.656 .751 .919 r
.80197 .51629 .80622 .5217 .8162 .51878 .81197 .51335 Metetra
.656 .751 .919 r
.81197 .51335 .8162 .51878 .82621 .51584 .82201 .51039 Metetra
.656 .751 .919 r
.82201 .51039 .82621 .51584 .83626 .51289 .83208 .50742 Metetra
.656 .751 .919 r
.83208 .50742 .83626 .51289 .84634 .50993 .84219 .50445 Metetra
.656 .751 .919 r
.84219 .50445 .84634 .50993 .85646 .50697 .85233 .50146 Metetra
.656 .751 .919 r
.85233 .50146 .85646 .50697 .86661 .50399 .86251 .49846 Metetra
.656 .751 .919 r
.86251 .49846 .86661 .50399 .8768 .501 .87273 .49545 Metetra
.656 .751 .919 r
.87273 .49545 .8768 .501 .88703 .498 .88298 .49243 Metetra
.656 .751 .919 r
.88298 .49243 .88703 .498 .89728 .49499 .89326 .4894 Metetra
.656 .751 .919 r
.89326 .4894 .89728 .49499 .90758 .49197 .90358 .48636 Metetra
.656 .751 .919 r
.90358 .48636 .90758 .49197 .91791 .48894 .91394 .48331 Metetra
.656 .751 .919 r
.91394 .48331 .91791 .48894 .92828 .4859 .92434 .48025 Metetra
.656 .751 .919 r
.92434 .48025 .92828 .4859 .93868 .48284 .93477 .47718 Metetra
.656 .751 .919 r
.93477 .47718 .93868 .48284 .94913 .47978 .94524 .4741 Metetra
.316 .098 .415 r
.34456 .66462 .35243 .61821 .35938 .64665 .35412 .642 Metetra
.656 .751 .919 r
.35412 .642 .35938 .64665 .36791 .64413 .36266 .63948 Metetra
.656 .751 .919 r
.36266 .63948 .36791 .64413 .37646 .64161 .37124 .63694 Metetra
.656 .751 .919 r
.37124 .63694 .37646 .64161 .38504 .63909 .37984 .6344 Metetra
.656 .751 .919 r
.37984 .6344 .38504 .63909 .39365 .63655 .38846 .63185 Metetra
.656 .751 .919 r
.38846 .63185 .39365 .63655 .40229 .63401 .39712 .62929 Metetra
.656 .751 .919 r
.39712 .62929 .40229 .63401 .41096 .63145 .4058 .62672 Metetra
.656 .751 .919 r
.4058 .62672 .41096 .63145 .41965 .62889 .41451 .62414 Metetra
.656 .751 .919 r
.41451 .62414 .41965 .62889 .42837 .62632 .42325 .62156 Metetra
.656 .751 .919 r
.42325 .62156 .42837 .62632 .43712 .62375 .43202 .61897 Metetra
.656 .751 .919 r
.43202 .61897 .43712 .62375 .4459 .62116 .44082 .61637 Metetra
.656 .751 .919 r
.44082 .61637 .4459 .62116 .45471 .61857 .44964 .61376 Metetra
.656 .751 .919 r
.44964 .61376 .45471 .61857 .46354 .61597 .4585 .61114 Metetra
.656 .751 .919 r
.4585 .61114 .46354 .61597 .47241 .61336 .46738 .60851 Metetra
.656 .751 .919 r
.46738 .60851 .47241 .61336 .4813 .61074 .47629 .60588 Metetra
.656 .751 .919 r
.47629 .60588 .4813 .61074 .49022 .60811 .48523 .60323 Metetra
.656 .751 .919 r
.48523 .60323 .49022 .60811 .49918 .60547 .4942 .60058 Metetra
.656 .751 .919 r
.4942 .60058 .49918 .60547 .50816 .60283 .5032 .59792 Metetra
.656 .751 .919 r
.5032 .59792 .50816 .60283 .51717 .60017 .51223 .59525 Metetra
.656 .751 .919 r
.51223 .59525 .51717 .60017 .52621 .59751 .52129 .59257 Metetra
.656 .751 .919 r
.52129 .59257 .52621 .59751 .53528 .59484 .53038 .58988 Metetra
.656 .751 .919 r
.53038 .58988 .53528 .59484 .54438 .59216 .5395 .58719 Metetra
.656 .751 .919 r
.5395 .58719 .54438 .59216 .55351 .58947 .54865 .58448 Metetra
.656 .751 .919 r
.54865 .58448 .55351 .58947 .56267 .58677 .55783 .58177 Metetra
.656 .751 .919 r
.55783 .58177 .56267 .58677 .57186 .58406 .56704 .57904 Metetra
.656 .751 .919 r
.56704 .57904 .57186 .58406 .58108 .58135 .57628 .57631 Metetra
.656 .751 .919 r
.57628 .57631 .58108 .58135 .59033 .57862 .58556 .57357 Metetra
.656 .751 .919 r
.58556 .57357 .59033 .57862 .59961 .57589 .59486 .57082 Metetra
.656 .751 .919 r
.59486 .57082 .59961 .57589 .60893 .57315 .6042 .56806 Metetra
.656 .751 .919 r
.6042 .56806 .60893 .57315 .61827 .57039 .61356 .56529 Metetra
.656 .751 .919 r
.61356 .56529 .61827 .57039 .62765 .56763 .62296 .56251 Metetra
.656 .751 .919 r
.62296 .56251 .62765 .56763 .63706 .56486 .63239 .55972 Metetra
.656 .751 .919 r
.63239 .55972 .63706 .56486 .6465 .56208 .64185 .55692 Metetra
.656 .751 .919 r
.64185 .55692 .6465 .56208 .65597 .55929 .65134 .55412 Metetra
.656 .751 .919 r
.65134 .55412 .65597 .55929 .66547 .55649 .66087 .5513 Metetra
.656 .751 .919 r
.66087 .5513 .66547 .55649 .67501 .55368 .67043 .54847 Metetra
.656 .751 .919 r
.67043 .54847 .67501 .55368 .68458 .55087 .68002 .54564 Metetra
.656 .751 .919 r
.68002 .54564 .68458 .55087 .69418 .54804 .68964 .54279 Metetra
.656 .751 .919 r
.68964 .54279 .69418 .54804 .70381 .5452 .69929 .53994 Metetra
.656 .751 .919 r
.69929 .53994 .70381 .5452 .71347 .54236 .70898 .53707 Metetra
.656 .751 .919 r
.70898 .53707 .71347 .54236 .72317 .5395 .7187 .5342 Metetra
.656 .751 .919 r
.7187 .5342 .72317 .5395 .73291 .53663 .72846 .53132 Metetra
.656 .751 .919 r
.72846 .53132 .73291 .53663 .74267 .53376 .73825 .52842 Metetra
.656 .751 .919 r
.73825 .52842 .74267 .53376 .75247 .53087 .74807 .52552 Metetra
.656 .751 .919 r
.74807 .52552 .75247 .53087 .7623 .52797 .75793 .5226 Metetra
.656 .751 .919 r
.75793 .5226 .7623 .52797 .77217 .52507 .76782 .51968 Metetra
.656 .751 .919 r
.76782 .51968 .77217 .52507 .78207 .52215 .77774 .51674 Metetra
.656 .751 .919 r
.77774 .51674 .78207 .52215 .792 .51923 .7877 .5138 Metetra
.656 .751 .919 r
.7877 .5138 .792 .51923 .80197 .51629 .79769 .51084 Metetra
.656 .751 .919 r
.79769 .51084 .80197 .51629 .81197 .51335 .80772 .50788 Metetra
.656 .751 .919 r
.80772 .50788 .81197 .51335 .82201 .51039 .81778 .5049 Metetra
.656 .751 .919 r
.81778 .5049 .82201 .51039 .83208 .50742 .82788 .50192 Metetra
.656 .751 .919 r
.82788 .50192 .83208 .50742 .84219 .50445 .83801 .49892 Metetra
.656 .751 .919 r
.83801 .49892 .84219 .50445 .85233 .50146 .84818 .49592 Metetra
.656 .751 .919 r
.84818 .49592 .85233 .50146 .86251 .49846 .85838 .4929 Metetra
.656 .751 .919 r
.85838 .4929 .86251 .49846 .87273 .49545 .86862 .48987 Metetra
.656 .751 .919 r
.86862 .48987 .87273 .49545 .88298 .49243 .8789 .48683 Metetra
.656 .751 .919 r
.8789 .48683 .88298 .49243 .89326 .4894 .88921 .48378 Metetra
.656 .751 .919 r
.88921 .48378 .89326 .4894 .90358 .48636 .89956 .48072 Metetra
.656 .751 .919 r
.89956 .48072 .90358 .48636 .91394 .48331 .90994 .47765 Metetra
.656 .751 .919 r
.90994 .47765 .91394 .48331 .92434 .48025 .92037 .47457 Metetra
.656 .751 .919 r
.92037 .47457 .92434 .48025 .93477 .47718 .93083 .47148 Metetra
.656 .751 .919 r
.93083 .47148 .93477 .47718 .94524 .4741 .94132 .46838 Metetra
.609 .469 .666 r
.34029 .64001 .34456 .66462 .35412 .642 .34883 .63733 Metetra
.656 .751 .919 r
.34883 .63733 .35412 .642 .36266 .63948 .35739 .63479 Metetra
.656 .751 .919 r
.35739 .63479 .36266 .63948 .37124 .63694 .36598 .63224 Metetra
.656 .751 .919 r
.36598 .63224 .37124 .63694 .37984 .6344 .3746 .62968 Metetra
.656 .751 .919 r
.3746 .62968 .37984 .6344 .38846 .63185 .38324 .62712 Metetra
.656 .751 .919 r
.38324 .62712 .38846 .63185 .39712 .62929 .39191 .62454 Metetra
.656 .751 .919 r
.39191 .62454 .39712 .62929 .4058 .62672 .40062 .62196 Metetra
.656 .751 .919 r
.40062 .62196 .4058 .62672 .41451 .62414 .40934 .61937 Metetra
.656 .751 .919 r
.40934 .61937 .41451 .62414 .42325 .62156 .4181 .61677 Metetra
.656 .751 .919 r
.4181 .61677 .42325 .62156 .43202 .61897 .42689 .61416 Metetra
.656 .751 .919 r
.42689 .61416 .43202 .61897 .44082 .61637 .4357 .61154 Metetra
.656 .751 .919 r
.4357 .61154 .44082 .61637 .44964 .61376 .44455 .60892 Metetra
.656 .751 .919 r
.44455 .60892 .44964 .61376 .4585 .61114 .45342 .60628 Metetra
.656 .751 .919 r
.45342 .60628 .4585 .61114 .46738 .60851 .46232 .60364 Metetra
.656 .751 .919 r
.46232 .60364 .46738 .60851 .47629 .60588 .47125 .60099 Metetra
.656 .751 .919 r
.47125 .60099 .47629 .60588 .48523 .60323 .48021 .59833 Metetra
.656 .751 .919 r
.48021 .59833 .48523 .60323 .4942 .60058 .4892 .59566 Metetra
.656 .751 .919 r
.4892 .59566 .4942 .60058 .5032 .59792 .49822 .59298 Metetra
.656 .751 .919 r
.49822 .59298 .5032 .59792 .51223 .59525 .50727 .5903 Metetra
.656 .751 .919 r
.50727 .5903 .51223 .59525 .52129 .59257 .51635 .5876 Metetra
.656 .751 .919 r
.51635 .5876 .52129 .59257 .53038 .58988 .52546 .5849 Metetra
.656 .751 .919 r
.52546 .5849 .53038 .58988 .5395 .58719 .5346 .58219 Metetra
.656 .751 .919 r
.5346 .58219 .5395 .58719 .54865 .58448 .54377 .57946 Metetra
.656 .751 .919 r
.54377 .57946 .54865 .58448 .55783 .58177 .55297 .57673 Metetra
.656 .751 .919 r
.55297 .57673 .55783 .58177 .56704 .57904 .5622 .57399 Metetra
.656 .751 .919 r
.5622 .57399 .56704 .57904 .57628 .57631 .57146 .57124 Metetra
.656 .751 .919 r
.57146 .57124 .57628 .57631 .58556 .57357 .58075 .56848 Metetra
.656 .751 .919 r
.58075 .56848 .58556 .57357 .59486 .57082 .59008 .56572 Metetra
.656 .751 .919 r
.59008 .56572 .59486 .57082 .6042 .56806 .59943 .56294 Metetra
.656 .751 .919 r
.59943 .56294 .6042 .56806 .61356 .56529 .60882 .56015 Metetra
.656 .751 .919 r
.60882 .56015 .61356 .56529 .62296 .56251 .61824 .55736 Metetra
.656 .751 .919 r
.61824 .55736 .62296 .56251 .63239 .55972 .62769 .55455 Metetra
.656 .751 .919 r
.62769 .55455 .63239 .55972 .64185 .55692 .63717 .55173 Metetra
.656 .751 .919 r
.63717 .55173 .64185 .55692 .65134 .55412 .64669 .54891 Metetra
.656 .751 .919 r
.64669 .54891 .65134 .55412 .66087 .5513 .65624 .54608 Metetra
.656 .751 .919 r
.65624 .54608 .66087 .5513 .67043 .54847 .66582 .54323 Metetra
.656 .751 .919 r
.66582 .54323 .67043 .54847 .68002 .54564 .67543 .54038 Metetra
.656 .751 .919 r
.67543 .54038 .68002 .54564 .68964 .54279 .68507 .53752 Metetra
.656 .751 .919 r
.68507 .53752 .68964 .54279 .69929 .53994 .69475 .53464 Metetra
.656 .751 .919 r
.69475 .53464 .69929 .53994 .70898 .53707 .70446 .53176 Metetra
.656 .751 .919 r
.70446 .53176 .70898 .53707 .7187 .5342 .71421 .52887 Metetra
.656 .751 .919 r
.71421 .52887 .7187 .5342 .72846 .53132 .72398 .52596 Metetra
.656 .751 .919 r
.72398 .52596 .72846 .53132 .73825 .52842 .7338 .52305 Metetra
.656 .751 .919 r
.7338 .52305 .73825 .52842 .74807 .52552 .74364 .52013 Metetra
.656 .751 .919 r
.74364 .52013 .74807 .52552 .75793 .5226 .75352 .5172 Metetra
.656 .751 .919 r
.75352 .5172 .75793 .5226 .76782 .51968 .76344 .51425 Metetra
.656 .751 .919 r
.76344 .51425 .76782 .51968 .77774 .51674 .77338 .5113 Metetra
.656 .751 .919 r
.77338 .5113 .77774 .51674 .7877 .5138 .78337 .50834 Metetra
.656 .751 .919 r
.78337 .50834 .7877 .5138 .79769 .51084 .79338 .50536 Metetra
.656 .751 .919 r
.79338 .50536 .79769 .51084 .80772 .50788 .80344 .50238 Metetra
.656 .751 .919 r
.80344 .50238 .80772 .50788 .81778 .5049 .81352 .49938 Metetra
.656 .751 .919 r
.81352 .49938 .81778 .5049 .82788 .50192 .82365 .49638 Metetra
.656 .751 .919 r
.82365 .49638 .82788 .50192 .83801 .49892 .8338 .49336 Metetra
.656 .751 .919 r
.8338 .49336 .83801 .49892 .84818 .49592 .844 .49034 Metetra
.656 .751 .919 r
.844 .49034 .84818 .49592 .85838 .4929 .85423 .4873 Metetra
.656 .751 .919 r
.85423 .4873 .85838 .4929 .86862 .48987 .86449 .48425 Metetra
.656 .751 .919 r
.86449 .48425 .86862 .48987 .8789 .48683 .8748 .4812 Metetra
.656 .751 .919 r
.8748 .4812 .8789 .48683 .88921 .48378 .88513 .47813 Metetra
.656 .751 .919 r
.88513 .47813 .88921 .48378 .89956 .48072 .89551 .47505 Metetra
.656 .751 .919 r
.89551 .47505 .89956 .48072 .90994 .47765 .90592 .47196 Metetra
.656 .751 .919 r
.90592 .47196 .90994 .47765 .92037 .47457 .91637 .46885 Metetra
.656 .751 .919 r
.91637 .46885 .92037 .47457 .93083 .47148 .92686 .46574 Metetra
.656 .751 .919 r
.92686 .46574 .93083 .47148 .94132 .46838 .93738 .46262 Metetra
.179 .187 .63 r
.33587 .61857 .34029 .64001 .34883 .63733 .34351 .63263 Metetra
.656 .751 .919 r
.34351 .63263 .34883 .63733 .35739 .63479 .35209 .63008 Metetra
.656 .751 .919 r
.35209 .63008 .35739 .63479 .36598 .63224 .36069 .62751 Metetra
.656 .751 .919 r
.36069 .62751 .36598 .63224 .3746 .62968 .36933 .62494 Metetra
.656 .751 .919 r
.36933 .62494 .3746 .62968 .38324 .62712 .37799 .62236 Metetra
.656 .751 .919 r
.37799 .62236 .38324 .62712 .39191 .62454 .38668 .61977 Metetra
.656 .751 .919 r
.38668 .61977 .39191 .62454 .40062 .62196 .3954 .61717 Metetra
.656 .751 .919 r
.3954 .61717 .40062 .62196 .40934 .61937 .40414 .61456 Metetra
.656 .751 .919 r
.40414 .61456 .40934 .61937 .4181 .61677 .41292 .61195 Metetra
.656 .751 .919 r
.41292 .61195 .4181 .61677 .42689 .61416 .42172 .60932 Metetra
.656 .751 .919 r
.42172 .60932 .42689 .61416 .4357 .61154 .43056 .60669 Metetra
.656 .751 .919 r
.43056 .60669 .4357 .61154 .44455 .60892 .43942 .60405 Metetra
.656 .751 .919 r
.43942 .60405 .44455 .60892 .45342 .60628 .44831 .6014 Metetra
.656 .751 .919 r
.44831 .6014 .45342 .60628 .46232 .60364 .45723 .59874 Metetra
.656 .751 .919 r
.45723 .59874 .46232 .60364 .47125 .60099 .46618 .59607 Metetra
.656 .751 .919 r
.46618 .59607 .47125 .60099 .48021 .59833 .47516 .5934 Metetra
.656 .751 .919 r
.47516 .5934 .48021 .59833 .4892 .59566 .48417 .59071 Metetra
.656 .751 .919 r
.48417 .59071 .4892 .59566 .49822 .59298 .49321 .58802 Metetra
.656 .751 .919 r
.49321 .58802 .49822 .59298 .50727 .5903 .50227 .58532 Metetra
.656 .751 .919 r
.50227 .58532 .50727 .5903 .51635 .5876 .51137 .5826 Metetra
.656 .751 .919 r
.51137 .5826 .51635 .5876 .52546 .5849 .5205 .57988 Metetra
.656 .751 .919 r
.5205 .57988 .52546 .5849 .5346 .58219 .52966 .57715 Metetra
.656 .751 .919 r
.52966 .57715 .5346 .58219 .54377 .57946 .53885 .57441 Metetra
.656 .751 .919 r
.53885 .57441 .54377 .57946 .55297 .57673 .54807 .57167 Metetra
.656 .751 .919 r
.54807 .57167 .55297 .57673 .5622 .57399 .55732 .56891 Metetra
.656 .751 .919 r
.55732 .56891 .5622 .57399 .57146 .57124 .56661 .56614 Metetra
.656 .751 .919 r
.56661 .56614 .57146 .57124 .58075 .56848 .57592 .56337 Metetra
.656 .751 .919 r
.57592 .56337 .58075 .56848 .59008 .56572 .58527 .56058 Metetra
.656 .751 .919 r
.58527 .56058 .59008 .56572 .59943 .56294 .59464 .55779 Metetra
.656 .751 .919 r
.59464 .55779 .59943 .56294 .60882 .56015 .60405 .55498 Metetra
.656 .751 .919 r
.60405 .55498 .60882 .56015 .61824 .55736 .61349 .55217 Metetra
.656 .751 .919 r
.61349 .55217 .61824 .55736 .62769 .55455 .62296 .54935 Metetra
.656 .751 .919 r
.62296 .54935 .62769 .55455 .63717 .55173 .63247 .54651 Metetra
.656 .751 .919 r
.63247 .54651 .63717 .55173 .64669 .54891 .642 .54367 Metetra
.656 .751 .919 r
.642 .54367 .64669 .54891 .65624 .54608 .65157 .54082 Metetra
.656 .751 .919 r
.65157 .54082 .65624 .54608 .66582 .54323 .66118 .53796 Metetra
.656 .751 .919 r
.66118 .53796 .66582 .54323 .67543 .54038 .67081 .53509 Metetra
.656 .751 .919 r
.67081 .53509 .67543 .54038 .68507 .53752 .68048 .5322 Metetra
.656 .751 .919 r
.68048 .5322 .68507 .53752 .69475 .53464 .69018 .52931 Metetra
.656 .751 .919 r
.69018 .52931 .69475 .53464 .70446 .53176 .69991 .52641 Metetra
.656 .751 .919 r
.69991 .52641 .70446 .53176 .71421 .52887 .70968 .5235 Metetra
.656 .751 .919 r
.70968 .5235 .71421 .52887 .72398 .52596 .71948 .52058 Metetra
.656 .751 .919 r
.71948 .52058 .72398 .52596 .7338 .52305 .72932 .51765 Metetra
.656 .751 .919 r
.72932 .51765 .7338 .52305 .74364 .52013 .73919 .51471 Metetra
.656 .751 .919 r
.73919 .51471 .74364 .52013 .75352 .5172 .74909 .51175 Metetra
.656 .751 .919 r
.74909 .51175 .75352 .5172 .76344 .51425 .75903 .50879 Metetra
.656 .751 .919 r
.75903 .50879 .76344 .51425 .77338 .5113 .769 .50582 Metetra
.656 .751 .919 r
.769 .50582 .77338 .5113 .78337 .50834 .77901 .50284 Metetra
.656 .751 .919 r
.77901 .50284 .78337 .50834 .79338 .50536 .78905 .49985 Metetra
.656 .751 .919 r
.78905 .49985 .79338 .50536 .80344 .50238 .79913 .49684 Metetra
.656 .751 .919 r
.79913 .49684 .80344 .50238 .81352 .49938 .80924 .49383 Metetra
.656 .751 .919 r
.80924 .49383 .81352 .49938 .82365 .49638 .81939 .4908 Metetra
.656 .751 .919 r
.81939 .4908 .82365 .49638 .8338 .49336 .82957 .48777 Metetra
.656 .751 .919 r
.82957 .48777 .8338 .49336 .844 .49034 .83979 .48472 Metetra
.656 .751 .919 r
.83979 .48472 .844 .49034 .85423 .4873 .85005 .48167 Metetra
.656 .751 .919 r
.85005 .48167 .85423 .4873 .86449 .48425 .86034 .4786 Metetra
.656 .751 .919 r
.86034 .4786 .86449 .48425 .8748 .4812 .87067 .47552 Metetra
.656 .751 .919 r
.87067 .47552 .8748 .4812 .88513 .47813 .88103 .47243 Metetra
.656 .751 .919 r
.88103 .47243 .88513 .47813 .89551 .47505 .89143 .46933 Metetra
.656 .751 .919 r
.89143 .46933 .89551 .47505 .90592 .47196 .90187 .46622 Metetra
.656 .751 .919 r
.90187 .46622 .90592 .47196 .91637 .46885 .91235 .4631 Metetra
.656 .751 .919 r
.91235 .4631 .91637 .46885 .92686 .46574 .92286 .45996 Metetra
.656 .751 .919 r
.92286 .45996 .92686 .46574 .93738 .46262 .93341 .45682 Metetra
.111 0 .291 r
.32839 .65169 .33587 .61857 .34351 .63263 .33816 .62791 Metetra
.656 .751 .919 r
.33816 .62791 .34351 .63263 .35209 .63008 .34675 .62533 Metetra
.656 .751 .919 r
.34675 .62533 .35209 .63008 .36069 .62751 .35538 .62275 Metetra
.656 .751 .919 r
.35538 .62275 .36069 .62751 .36933 .62494 .36403 .62017 Metetra
.656 .751 .919 r
.36403 .62017 .36933 .62494 .37799 .62236 .37271 .61757 Metetra
.656 .751 .919 r
.37271 .61757 .37799 .62236 .38668 .61977 .38141 .61496 Metetra
.656 .751 .919 r
.38141 .61496 .38668 .61977 .3954 .61717 .39015 .61235 Metetra
.656 .751 .919 r
.39015 .61235 .3954 .61717 .40414 .61456 .39891 .60973 Metetra
.656 .751 .919 r
.39891 .60973 .40414 .61456 .41292 .61195 .40771 .60709 Metetra
.656 .751 .919 r
.40771 .60709 .41292 .61195 .42172 .60932 .41653 .60446 Metetra
.656 .751 .919 r
.41653 .60446 .42172 .60932 .43056 .60669 .42538 .60181 Metetra
.656 .751 .919 r
.42538 .60181 .43056 .60669 .43942 .60405 .43426 .59915 Metetra
.656 .751 .919 r
.43426 .59915 .43942 .60405 .44831 .6014 .44317 .59648 Metetra
.656 .751 .919 r
.44317 .59648 .44831 .6014 .45723 .59874 .45211 .59381 Metetra
.656 .751 .919 r
.45211 .59381 .45723 .59874 .46618 .59607 .46108 .59113 Metetra
.656 .751 .919 r
.46108 .59113 .46618 .59607 .47516 .5934 .47008 .58843 Metetra
.656 .751 .919 r
.47008 .58843 .47516 .5934 .48417 .59071 .4791 .58573 Metetra
.656 .751 .919 r
.4791 .58573 .48417 .59071 .49321 .58802 .48816 .58302 Metetra
.656 .751 .919 r
.48816 .58302 .49321 .58802 .50227 .58532 .49725 .5803 Metetra
.656 .751 .919 r
.49725 .5803 .50227 .58532 .51137 .5826 .50637 .57757 Metetra
.656 .751 .919 r
.50637 .57757 .51137 .5826 .5205 .57988 .51552 .57484 Metetra
.656 .751 .919 r
.51552 .57484 .5205 .57988 .52966 .57715 .5247 .57209 Metetra
.656 .751 .919 r
.5247 .57209 .52966 .57715 .53885 .57441 .53391 .56933 Metetra
.656 .751 .919 r
.53391 .56933 .53885 .57441 .54807 .57167 .54315 .56657 Metetra
.656 .751 .919 r
.54315 .56657 .54807 .57167 .55732 .56891 .55242 .56379 Metetra
.656 .751 .919 r
.55242 .56379 .55732 .56891 .56661 .56614 .56172 .56101 Metetra
.656 .751 .919 r
.56172 .56101 .56661 .56614 .57592 .56337 .57106 .55822 Metetra
.656 .751 .919 r
.57106 .55822 .57592 .56337 .58527 .56058 .58042 .55541 Metetra
.656 .751 .919 r
.58042 .55541 .58527 .56058 .59464 .55779 .58982 .5526 Metetra
.656 .751 .919 r
.58982 .5526 .59464 .55779 .60405 .55498 .59925 .54978 Metetra
.656 .751 .919 r
.59925 .54978 .60405 .55498 .61349 .55217 .60871 .54695 Metetra
.656 .751 .919 r
.60871 .54695 .61349 .55217 .62296 .54935 .61821 .54411 Metetra
.656 .751 .919 r
.61821 .54411 .62296 .54935 .63247 .54651 .62773 .54126 Metetra
.656 .751 .919 r
.62773 .54126 .63247 .54651 .642 .54367 .63729 .5384 Metetra
.656 .751 .919 r
.63729 .5384 .642 .54367 .65157 .54082 .64688 .53553 Metetra
.656 .751 .919 r
.64688 .53553 .65157 .54082 .66118 .53796 .65651 .53265 Metetra
.656 .751 .919 r
.65651 .53265 .66118 .53796 .67081 .53509 .66616 .52976 Metetra
.656 .751 .919 r
.66616 .52976 .67081 .53509 .68048 .5322 .67585 .52686 Metetra
.656 .751 .919 r
.67585 .52686 .68048 .5322 .69018 .52931 .68558 .52395 Metetra
.656 .751 .919 r
.68558 .52395 .69018 .52931 .69991 .52641 .69533 .52103 Metetra
.656 .751 .919 r
.69533 .52103 .69991 .52641 .70968 .5235 .70513 .5181 Metetra
.656 .751 .919 r
.70513 .5181 .70968 .5235 .71948 .52058 .71495 .51516 Metetra
.656 .751 .919 r
.71495 .51516 .71948 .52058 .72932 .51765 .72481 .51221 Metetra
.656 .751 .919 r
.72481 .51221 .72932 .51765 .73919 .51471 .7347 .50925 Metetra
.656 .751 .919 r
.7347 .50925 .73919 .51471 .74909 .51175 .74463 .50628 Metetra
.656 .751 .919 r
.74463 .50628 .74909 .51175 .75903 .50879 .75459 .5033 Metetra
.656 .751 .919 r
.75459 .5033 .75903 .50879 .769 .50582 .76459 .50031 Metetra
.656 .751 .919 r
.76459 .50031 .769 .50582 .77901 .50284 .77462 .4973 Metetra
.656 .751 .919 r
.77462 .4973 .77901 .50284 .78905 .49985 .78469 .49429 Metetra
.656 .751 .919 r
.78469 .49429 .78905 .49985 .79913 .49684 .79479 .49127 Metetra
.656 .751 .919 r
.79479 .49127 .79913 .49684 .80924 .49383 .80493 .48824 Metetra
.656 .751 .919 r
.80493 .48824 .80924 .49383 .81939 .4908 .8151 .48519 Metetra
.656 .751 .919 r
.8151 .48519 .81939 .4908 .82957 .48777 .82531 .48214 Metetra
.656 .751 .919 r
.82531 .48214 .82957 .48777 .83979 .48472 .83556 .47907 Metetra
.656 .751 .919 r
.83556 .47907 .83979 .48472 .85005 .48167 .84584 .47599 Metetra
.656 .751 .919 r
.84584 .47599 .85005 .48167 .86034 .4786 .85616 .47291 Metetra
.656 .751 .919 r
.85616 .47291 .86034 .4786 .87067 .47552 .86651 .46981 Metetra
.656 .751 .919 r
.86651 .46981 .87067 .47552 .88103 .47243 .8769 .4667 Metetra
.656 .751 .919 r
.8769 .4667 .88103 .47243 .89143 .46933 .88733 .46358 Metetra
.656 .751 .919 r
.88733 .46358 .89143 .46933 .90187 .46622 .8978 .46045 Metetra
.656 .751 .919 r
.8978 .46045 .90187 .46622 .91235 .4631 .9083 .4573 Metetra
.656 .751 .919 r
.9083 .4573 .91235 .4631 .92286 .45996 .91884 .45415 Metetra
.656 .751 .919 r
.91884 .45415 .92286 .45996 .93341 .45682 .92942 .45099 Metetra
.453 .324 .614 r
.32493 .6129 .32839 .65169 .33816 .62791 .33277 .62315 Metetra
.656 .751 .919 r
.33277 .62315 .33816 .62791 .34675 .62533 .34138 .62056 Metetra
.656 .751 .919 r
.34138 .62056 .34675 .62533 .35538 .62275 .35002 .61797 Metetra
.656 .751 .919 r
.35002 .61797 .35538 .62275 .36403 .62017 .35869 .61536 Metetra
.656 .751 .919 r
.35869 .61536 .36403 .62017 .37271 .61757 .36739 .61275 Metetra
.656 .751 .919 r
.36739 .61275 .37271 .61757 .38141 .61496 .37612 .61013 Metetra
.656 .751 .919 r
.37612 .61013 .38141 .61496 .39015 .61235 .38487 .6075 Metetra
.656 .751 .919 r
.38487 .6075 .39015 .61235 .39891 .60973 .39365 .60486 Metetra
.656 .751 .919 r
.39365 .60486 .39891 .60973 .40771 .60709 .40246 .60221 Metetra
.656 .751 .919 r
.40246 .60221 .40771 .60709 .41653 .60446 .4113 .59956 Metetra
.656 .751 .919 r
.4113 .59956 .41653 .60446 .42538 .60181 .42017 .59689 Metetra
.656 .751 .919 r
.42017 .59689 .42538 .60181 .43426 .59915 .42907 .59422 Metetra
.656 .751 .919 r
.42907 .59422 .43426 .59915 .44317 .59648 .438 .59154 Metetra
.656 .751 .919 r
.438 .59154 .44317 .59648 .45211 .59381 .44696 .58885 Metetra
.656 .751 .919 r
.44696 .58885 .45211 .59381 .46108 .59113 .45594 .58615 Metetra
.656 .751 .919 r
.45594 .58615 .46108 .59113 .47008 .58843 .46496 .58344 Metetra
.656 .751 .919 r
.46496 .58344 .47008 .58843 .4791 .58573 .47401 .58072 Metetra
.656 .751 .919 r
.47401 .58072 .4791 .58573 .48816 .58302 .48309 .57799 Metetra
.656 .751 .919 r
.48309 .57799 .48816 .58302 .49725 .5803 .49219 .57526 Metetra
.656 .751 .919 r
.49219 .57526 .49725 .5803 .50637 .57757 .50133 .57251 Metetra
.656 .751 .919 r
.50133 .57251 .50637 .57757 .51552 .57484 .5105 .56976 Metetra
.656 .751 .919 r
.5105 .56976 .51552 .57484 .5247 .57209 .5197 .56699 Metetra
.656 .751 .919 r
.5197 .56699 .5247 .57209 .53391 .56933 .52893 .56422 Metetra
.656 .751 .919 r
.52893 .56422 .53391 .56933 .54315 .56657 .53819 .56144 Metetra
.656 .751 .919 r
.53819 .56144 .54315 .56657 .55242 .56379 .54748 .55865 Metetra
.656 .751 .919 r
.54748 .55865 .55242 .56379 .56172 .56101 .55681 .55585 Metetra
.656 .751 .919 r
.55681 .55585 .56172 .56101 .57106 .55822 .56616 .55304 Metetra
.656 .751 .919 r
.56616 .55304 .57106 .55822 .58042 .55541 .57555 .55022 Metetra
.656 .751 .919 r
.57555 .55022 .58042 .55541 .58982 .5526 .58497 .54739 Metetra
.656 .751 .919 r
.58497 .54739 .58982 .5526 .59925 .54978 .59442 .54455 Metetra
.656 .751 .919 r
.59442 .54455 .59925 .54978 .60871 .54695 .6039 .5417 Metetra
.656 .751 .919 r
.6039 .5417 .60871 .54695 .61821 .54411 .61342 .53884 Metetra
.656 .751 .919 r
.61342 .53884 .61821 .54411 .62773 .54126 .62297 .53597 Metetra
.656 .751 .919 r
.62297 .53597 .62773 .54126 .63729 .5384 .63255 .53309 Metetra
.656 .751 .919 r
.63255 .53309 .63729 .5384 .64688 .53553 .64216 .5302 Metetra
.656 .751 .919 r
.64216 .5302 .64688 .53553 .65651 .53265 .65181 .52731 Metetra
.656 .751 .919 r
.65181 .52731 .65651 .53265 .66616 .52976 .66149 .5244 Metetra
.656 .751 .919 r
.66149 .5244 .66616 .52976 .67585 .52686 .6712 .52148 Metetra
.656 .751 .919 r
.6712 .52148 .67585 .52686 .68558 .52395 .68095 .51855 Metetra
.656 .751 .919 r
.68095 .51855 .68558 .52395 .69533 .52103 .69073 .51561 Metetra
.656 .751 .919 r
.69073 .51561 .69533 .52103 .70513 .5181 .70054 .51266 Metetra
.656 .751 .919 r
.70054 .51266 .70513 .5181 .71495 .51516 .71039 .50971 Metetra
.656 .751 .919 r
.71039 .50971 .71495 .51516 .72481 .51221 .72027 .50674 Metetra
.656 .751 .919 r
.72027 .50674 .72481 .51221 .7347 .50925 .73019 .50376 Metetra
.656 .751 .919 r
.73019 .50376 .7347 .50925 .74463 .50628 .74014 .50077 Metetra
.656 .751 .919 r
.74014 .50077 .74463 .50628 .75459 .5033 .75013 .49777 Metetra
.656 .751 .919 r
.75013 .49777 .75459 .5033 .76459 .50031 .76015 .49476 Metetra
.656 .751 .919 r
.76015 .49476 .76459 .50031 .77462 .4973 .77021 .49174 Metetra
.656 .751 .919 r
.77021 .49174 .77462 .4973 .78469 .49429 .7803 .4887 Metetra
.656 .751 .919 r
.7803 .4887 .78469 .49429 .79479 .49127 .79042 .48566 Metetra
.656 .751 .919 r
.79042 .48566 .79479 .49127 .80493 .48824 .80059 .48261 Metetra
.656 .751 .919 r
.80059 .48261 .80493 .48824 .8151 .48519 .81079 .47954 Metetra
.656 .751 .919 r
.81079 .47954 .8151 .48519 .82531 .48214 .82102 .47647 Metetra
.656 .751 .919 r
.82102 .47647 .82531 .48214 .83556 .47907 .83129 .47338 Metetra
.656 .751 .919 r
.83129 .47338 .83556 .47907 .84584 .47599 .8416 .47029 Metetra
.656 .751 .919 r
.8416 .47029 .84584 .47599 .85616 .47291 .85195 .46718 Metetra
.656 .751 .919 r
.85195 .46718 .85616 .47291 .86651 .46981 .86233 .46406 Metetra
.656 .751 .919 r
.86233 .46406 .86651 .46981 .8769 .4667 .87274 .46093 Metetra
.656 .751 .919 r
.87274 .46093 .8769 .4667 .88733 .46358 .8832 .45779 Metetra
.656 .751 .919 r
.8832 .45779 .88733 .46358 .8978 .46045 .89369 .45464 Metetra
.656 .751 .919 r
.89369 .45464 .8978 .46045 .9083 .4573 .90422 .45147 Metetra
.656 .751 .919 r
.90422 .45147 .9083 .4573 .91884 .45415 .91479 .4483 Metetra
.656 .751 .919 r
.91479 .4483 .91884 .45415 .92942 .45099 .9254 .44511 Metetra
.376 0 .082 r
.31882 .61977 .32493 .6129 .33277 .62315 .32735 .61837 Metetra
.656 .751 .919 r
.32735 .61837 .33277 .62315 .34138 .62056 .33598 .61577 Metetra
.656 .751 .919 r
.33598 .61577 .34138 .62056 .35002 .61797 .34464 .61315 Metetra
.656 .751 .919 r
.34464 .61315 .35002 .61797 .35869 .61536 .35333 .61053 Metetra
.656 .751 .919 r
.35333 .61053 .35869 .61536 .36739 .61275 .36204 .60791 Metetra
.656 .751 .919 r
.36204 .60791 .36739 .61275 .37612 .61013 .37079 .60527 Metetra
.656 .751 .919 r
.37079 .60527 .37612 .61013 .38487 .6075 .37956 .60262 Metetra
.656 .751 .919 r
.37956 .60262 .38487 .6075 .39365 .60486 .38836 .59997 Metetra
.656 .751 .919 r
.38836 .59997 .39365 .60486 .40246 .60221 .39719 .5973 Metetra
.656 .751 .919 r
.39719 .5973 .40246 .60221 .4113 .59956 .40604 .59463 Metetra
.656 .751 .919 r
.40604 .59463 .4113 .59956 .42017 .59689 .41493 .59195 Metetra
.656 .751 .919 r
.41493 .59195 .42017 .59689 .42907 .59422 .42385 .58926 Metetra
.656 .751 .919 r
.42385 .58926 .42907 .59422 .438 .59154 .4328 .58656 Metetra
.656 .751 .919 r
.4328 .58656 .438 .59154 .44696 .58885 .44177 .58386 Metetra
.656 .751 .919 r
.44177 .58386 .44696 .58885 .45594 .58615 .45078 .58114 Metetra
.656 .751 .919 r
.45078 .58114 .45594 .58615 .46496 .58344 .45982 .57841 Metetra
.656 .751 .919 r
.45982 .57841 .46496 .58344 .47401 .58072 .46888 .57568 Metetra
.656 .751 .919 r
.46888 .57568 .47401 .58072 .48309 .57799 .47798 .57294 Metetra
.656 .751 .919 r
.47798 .57294 .48309 .57799 .49219 .57526 .48711 .57018 Metetra
.656 .751 .919 r
.48711 .57018 .49219 .57526 .50133 .57251 .49626 .56742 Metetra
.656 .751 .919 r
.49626 .56742 .50133 .57251 .5105 .56976 .50545 .56465 Metetra
.656 .751 .919 r
.50545 .56465 .5105 .56976 .5197 .56699 .51467 .56187 Metetra
.656 .751 .919 r
.51467 .56187 .5197 .56699 .52893 .56422 .52392 .55908 Metetra
.656 .751 .919 r
.52392 .55908 .52893 .56422 .53819 .56144 .5332 .55628 Metetra
.656 .751 .919 r
.5332 .55628 .53819 .56144 .54748 .55865 .54252 .55347 Metetra
.656 .751 .919 r
.54252 .55347 .54748 .55865 .55681 .55585 .55186 .55065 Metetra
.656 .751 .919 r
.55186 .55065 .55681 .55585 .56616 .55304 .56124 .54782 Metetra
.656 .751 .919 r
.56124 .54782 .56616 .55304 .57555 .55022 .57065 .54498 Metetra
.656 .751 .919 r
.57065 .54498 .57555 .55022 .58497 .54739 .58009 .54214 Metetra
.656 .751 .919 r
.58009 .54214 .58497 .54739 .59442 .54455 .58956 .53928 Metetra
.656 .751 .919 r
.58956 .53928 .59442 .54455 .6039 .5417 .59906 .53641 Metetra
.656 .751 .919 r
.59906 .53641 .6039 .5417 .61342 .53884 .6086 .53354 Metetra
.656 .751 .919 r
.6086 .53354 .61342 .53884 .62297 .53597 .61817 .53065 Metetra
.656 .751 .919 r
.61817 .53065 .62297 .53597 .63255 .53309 .62777 .52775 Metetra
.656 .751 .919 r
.62777 .52775 .63255 .53309 .64216 .5302 .63741 .52485 Metetra
.656 .751 .919 r
.63741 .52485 .64216 .5302 .65181 .52731 .64708 .52193 Metetra
.656 .751 .919 r
.64708 .52193 .65181 .52731 .66149 .5244 .65678 .519 Metetra
.656 .751 .919 r
.65678 .519 .66149 .5244 .6712 .52148 .66652 .51607 Metetra
.656 .751 .919 r
.66652 .51607 .6712 .52148 .68095 .51855 .67629 .51312 Metetra
.656 .751 .919 r
.67629 .51312 .68095 .51855 .69073 .51561 .68609 .51016 Metetra
.656 .751 .919 r
.68609 .51016 .69073 .51561 .70054 .51266 .69593 .50719 Metetra
.656 .751 .919 r
.69593 .50719 .70054 .51266 .71039 .50971 .7058 .50422 Metetra
.656 .751 .919 r
.7058 .50422 .71039 .50971 .72027 .50674 .71571 .50123 Metetra
.656 .751 .919 r
.71571 .50123 .72027 .50674 .73019 .50376 .72565 .49823 Metetra
.656 .751 .919 r
.72565 .49823 .73019 .50376 .74014 .50077 .73562 .49522 Metetra
.656 .751 .919 r
.73562 .49522 .74014 .50077 .75013 .49777 .74563 .4922 Metetra
.656 .751 .919 r
.74563 .4922 .75013 .49777 .76015 .49476 .75568 .48917 Metetra
.656 .751 .919 r
.75568 .48917 .76015 .49476 .77021 .49174 .76576 .48613 Metetra
.656 .751 .919 r
.76576 .48613 .77021 .49174 .7803 .4887 .77588 .48308 Metetra
.656 .751 .919 r
.77588 .48308 .7803 .4887 .79042 .48566 .78603 .48002 Metetra
.656 .751 .919 r
.78603 .48002 .79042 .48566 .80059 .48261 .79622 .47694 Metetra
.656 .751 .919 r
.79622 .47694 .80059 .48261 .81079 .47954 .80644 .47386 Metetra
.656 .751 .919 r
.80644 .47386 .81079 .47954 .82102 .47647 .8167 .47076 Metetra
.656 .751 .919 r
.8167 .47076 .82102 .47647 .83129 .47338 .827 .46766 Metetra
.656 .751 .919 r
.827 .46766 .83129 .47338 .8416 .47029 .83734 .46454 Metetra
.656 .751 .919 r
.83734 .46454 .8416 .47029 .85195 .46718 .84771 .46141 Metetra
.656 .751 .919 r
.84771 .46141 .85195 .46718 .86233 .46406 .85811 .45827 Metetra
.656 .751 .919 r
.85811 .45827 .86233 .46406 .87274 .46093 .86856 .45512 Metetra
.656 .751 .919 r
.86856 .45512 .87274 .46093 .8832 .45779 .87904 .45196 Metetra
.656 .751 .919 r
.87904 .45196 .8832 .45779 .89369 .45464 .88956 .44879 Metetra
.656 .751 .919 r
.88956 .44879 .89369 .45464 .90422 .45147 .90012 .4456 Metetra
.656 .751 .919 r
.90012 .4456 .90422 .45147 .91479 .4483 .91072 .44241 Metetra
.656 .751 .919 r
.91072 .44241 .91479 .4483 .9254 .44511 .92135 .4392 Metetra
.728 .891 .501 r
.31254 .62832 .31882 .61977 .32735 .61837 .32191 .61356 Metetra
.656 .751 .919 r
.32191 .61356 .32735 .61837 .33598 .61577 .33055 .61094 Metetra
.656 .751 .919 r
.33055 .61094 .33598 .61577 .34464 .61315 .33923 .60831 Metetra
.656 .751 .919 r
.33923 .60831 .34464 .61315 .35333 .61053 .34793 .60567 Metetra
.656 .751 .919 r
.34793 .60567 .35333 .61053 .36204 .60791 .35666 .60303 Metetra
.656 .751 .919 r
.35666 .60303 .36204 .60791 .37079 .60527 .36542 .60038 Metetra
.656 .751 .919 r
.36542 .60038 .37079 .60527 .37956 .60262 .37421 .59772 Metetra
.656 .751 .919 r
.37421 .59772 .37956 .60262 .38836 .59997 .38303 .59504 Metetra
.656 .751 .919 r
.38303 .59504 .38836 .59997 .39719 .5973 .39188 .59236 Metetra
.656 .751 .919 r
.39188 .59236 .39719 .5973 .40604 .59463 .40075 .58968 Metetra
.656 .751 .919 r
.40075 .58968 .40604 .59463 .41493 .59195 .40966 .58698 Metetra
.656 .751 .919 r
.40966 .58698 .41493 .59195 .42385 .58926 .4186 .58427 Metetra
.656 .751 .919 r
.4186 .58427 .42385 .58926 .4328 .58656 .42756 .58156 Metetra
.656 .751 .919 r
.42756 .58156 .4328 .58656 .44177 .58386 .43656 .57883 Metetra
.656 .751 .919 r
.43656 .57883 .44177 .58386 .45078 .58114 .44558 .5761 Metetra
.656 .751 .919 r
.44558 .5761 .45078 .58114 .45982 .57841 .45464 .57336 Metetra
.656 .751 .919 r
.45464 .57336 .45982 .57841 .46888 .57568 .46372 .57061 Metetra
.656 .751 .919 r
.46372 .57061 .46888 .57568 .47798 .57294 .47284 .56785 Metetra
.656 .751 .919 r
.47284 .56785 .47798 .57294 .48711 .57018 .48199 .56508 Metetra
.656 .751 .919 r
.48199 .56508 .48711 .57018 .49626 .56742 .49116 .5623 Metetra
.656 .751 .919 r
.49116 .5623 .49626 .56742 .50545 .56465 .50037 .55951 Metetra
.656 .751 .919 r
.50037 .55951 .50545 .56465 .51467 .56187 .50961 .55671 Metetra
.656 .751 .919 r
.50961 .55671 .51467 .56187 .52392 .55908 .51888 .5539 Metetra
.656 .751 .919 r
.51888 .5539 .52392 .55908 .5332 .55628 .52819 .55108 Metetra
.656 .751 .919 r
.52819 .55108 .5332 .55628 .54252 .55347 .53752 .54826 Metetra
.656 .751 .919 r
.53752 .54826 .54252 .55347 .55186 .55065 .54688 .54542 Metetra
.656 .751 .919 r
.54688 .54542 .55186 .55065 .56124 .54782 .55628 .54257 Metetra
.656 .751 .919 r
.55628 .54257 .56124 .54782 .57065 .54498 .56571 .53972 Metetra
.656 .751 .919 r
.56571 .53972 .57065 .54498 .58009 .54214 .57517 .53685 Metetra
.656 .751 .919 r
.57517 .53685 .58009 .54214 .58956 .53928 .58467 .53398 Metetra
.656 .751 .919 r
.58467 .53398 .58956 .53928 .59906 .53641 .59419 .53109 Metetra
.656 .751 .919 r
.59419 .53109 .59906 .53641 .6086 .53354 .60375 .5282 Metetra
.656 .751 .919 r
.60375 .5282 .6086 .53354 .61817 .53065 .61334 .52529 Metetra
.656 .751 .919 r
.61334 .52529 .61817 .53065 .62777 .52775 .62297 .52238 Metetra
.656 .751 .919 r
.62297 .52238 .62777 .52775 .63741 .52485 .63263 .51945 Metetra
.656 .751 .919 r
.63263 .51945 .63741 .52485 .64708 .52193 .64232 .51652 Metetra
.656 .751 .919 r
.64232 .51652 .64708 .52193 .65678 .519 .65204 .51357 Metetra
.656 .751 .919 r
.65204 .51357 .65678 .519 .66652 .51607 .6618 .51062 Metetra
.656 .751 .919 r
.6618 .51062 .66652 .51607 .67629 .51312 .6716 .50765 Metetra
.656 .751 .919 r
.6716 .50765 .67629 .51312 .68609 .51016 .68142 .50468 Metetra
.656 .751 .919 r
.68142 .50468 .68609 .51016 .69593 .50719 .69128 .50169 Metetra
.656 .751 .919 r
.69128 .50169 .69593 .50719 .7058 .50422 .70118 .49869 Metetra
.656 .751 .919 r
.70118 .49869 .7058 .50422 .71571 .50123 .71111 .49568 Metetra
.656 .751 .919 r
.71111 .49568 .71571 .50123 .72565 .49823 .72108 .49267 Metetra
.656 .751 .919 r
.72108 .49267 .72565 .49823 .73562 .49522 .73108 .48964 Metetra
.656 .751 .919 r
.73108 .48964 .73562 .49522 .74563 .4922 .74111 .4866 Metetra
.656 .751 .919 r
.74111 .4866 .74563 .4922 .75568 .48917 .75118 .48355 Metetra
.656 .751 .919 r
.75118 .48355 .75568 .48917 .76576 .48613 .76129 .48049 Metetra
.656 .751 .919 r
.76129 .48049 .76576 .48613 .77588 .48308 .77143 .47742 Metetra
.656 .751 .919 r
.77143 .47742 .77588 .48308 .78603 .48002 .78161 .47433 Metetra
.656 .751 .919 r
.78161 .47433 .78603 .48002 .79622 .47694 .79182 .47124 Metetra
.656 .751 .919 r
.79182 .47124 .79622 .47694 .80644 .47386 .80207 .46814 Metetra
.656 .751 .919 r
.80207 .46814 .80644 .47386 .8167 .47076 .81236 .46502 Metetra
.656 .751 .919 r
.81236 .46502 .8167 .47076 .827 .46766 .82268 .46189 Metetra
.656 .751 .919 r
.82268 .46189 .827 .46766 .83734 .46454 .83304 .45876 Metetra
.656 .751 .919 r
.83304 .45876 .83734 .46454 .84771 .46141 .84344 .45561 Metetra
.656 .751 .919 r
.84344 .45561 .84771 .46141 .85811 .45827 .85388 .45245 Metetra
.656 .751 .919 r
.85388 .45245 .85811 .45827 .86856 .45512 .86435 .44928 Metetra
.656 .751 .919 r
.86435 .44928 .86856 .45512 .87904 .45196 .87486 .44609 Metetra
.656 .751 .919 r
.87486 .44609 .87904 .45196 .88956 .44879 .88541 .4429 Metetra
.656 .751 .919 r
.88541 .4429 .88956 .44879 .90012 .4456 .89599 .43969 Metetra
.656 .751 .919 r
.89599 .43969 .90012 .4456 .91072 .44241 .90662 .43647 Metetra
.656 .751 .919 r
.90662 .43647 .91072 .44241 .92135 .4392 .91728 .43325 Metetra
.386 .291 .625 r
.30868 .59727 .31254 .62832 .32191 .61356 .31642 .60872 Metetra
.656 .751 .919 r
.31642 .60872 .32191 .61356 .33055 .61094 .32509 .60608 Metetra
.656 .751 .919 r
.32509 .60608 .33055 .61094 .33923 .60831 .33378 .60344 Metetra
.656 .751 .919 r
.33378 .60344 .33923 .60831 .34793 .60567 .3425 .60079 Metetra
.656 .751 .919 r
.3425 .60079 .34793 .60567 .35666 .60303 .35125 .59813 Metetra
.656 .751 .919 r
.35125 .59813 .35666 .60303 .36542 .60038 .36003 .59546 Metetra
.656 .751 .919 r
.36003 .59546 .36542 .60038 .37421 .59772 .36883 .59278 Metetra
.656 .751 .919 r
.36883 .59278 .37421 .59772 .38303 .59504 .37767 .59009 Metetra
.656 .751 .919 r
.37767 .59009 .38303 .59504 .39188 .59236 .38654 .58739 Metetra
.656 .751 .919 r
.38654 .58739 .39188 .59236 .40075 .58968 .39543 .58469 Metetra
.656 .751 .919 r
.39543 .58469 .40075 .58968 .40966 .58698 .40436 .58198 Metetra
.656 .751 .919 r
.40436 .58198 .40966 .58698 .4186 .58427 .41331 .57925 Metetra
.656 .751 .919 r
.41331 .57925 .4186 .58427 .42756 .58156 .42229 .57652 Metetra
.656 .751 .919 r
.42229 .57652 .42756 .58156 .43656 .57883 .43131 .57378 Metetra
.656 .751 .919 r
.43131 .57378 .43656 .57883 .44558 .5761 .44035 .57103 Metetra
.656 .751 .919 r
.44035 .57103 .44558 .5761 .45464 .57336 .44943 .56827 Metetra
.656 .751 .919 r
.44943 .56827 .45464 .57336 .46372 .57061 .45853 .5655 Metetra
.656 .751 .919 r
.45853 .5655 .46372 .57061 .47284 .56785 .46767 .56272 Metetra
.656 .751 .919 r
.46767 .56272 .47284 .56785 .48199 .56508 .47684 .55994 Metetra
.656 .751 .919 r
.47684 .55994 .48199 .56508 .49116 .5623 .48603 .55714 Metetra
.656 .751 .919 r
.48603 .55714 .49116 .5623 .50037 .55951 .49526 .55433 Metetra
.656 .751 .919 r
.49526 .55433 .50037 .55951 .50961 .55671 .50452 .55152 Metetra
.656 .751 .919 r
.50452 .55152 .50961 .55671 .51888 .5539 .51381 .54869 Metetra
.656 .751 .919 r
.51381 .54869 .51888 .5539 .52819 .55108 .52314 .54586 Metetra
.656 .751 .919 r
.52314 .54586 .52819 .55108 .53752 .54826 .53249 .54301 Metetra
.656 .751 .919 r
.53249 .54301 .53752 .54826 .54688 .54542 .54188 .54016 Metetra
.656 .751 .919 r
.54188 .54016 .54688 .54542 .55628 .54257 .55129 .5373 Metetra
.656 .751 .919 r
.55129 .5373 .55628 .54257 .56571 .53972 .56075 .53442 Metetra
.656 .751 .919 r
.56075 .53442 .56571 .53972 .57517 .53685 .57023 .53154 Metetra
.656 .751 .919 r
.57023 .53154 .57517 .53685 .58467 .53398 .57974 .52864 Metetra
.656 .751 .919 r
.57974 .52864 .58467 .53398 .59419 .53109 .58929 .52574 Metetra
.656 .751 .919 r
.58929 .52574 .59419 .53109 .60375 .5282 .59887 .52283 Metetra
.656 .751 .919 r
.59887 .52283 .60375 .5282 .61334 .52529 .60849 .5199 Metetra
.656 .751 .919 r
.60849 .5199 .61334 .52529 .62297 .52238 .61813 .51697 Metetra
.656 .751 .919 r
.61813 .51697 .62297 .52238 .63263 .51945 .62782 .51403 Metetra
.656 .751 .919 r
.62782 .51403 .63263 .51945 .64232 .51652 .63753 .51107 Metetra
.656 .751 .919 r
.63753 .51107 .64232 .51652 .65204 .51357 .64728 .50811 Metetra
.656 .751 .919 r
.64728 .50811 .65204 .51357 .6618 .51062 .65706 .50513 Metetra
.656 .751 .919 r
.65706 .50513 .6618 .51062 .6716 .50765 .66688 .50215 Metetra
.656 .751 .919 r
.66688 .50215 .6716 .50765 .68142 .50468 .67673 .49915 Metetra
.656 .751 .919 r
.67673 .49915 .68142 .50468 .69128 .50169 .68661 .49615 Metetra
.656 .751 .919 r
.68661 .49615 .69128 .50169 .70118 .49869 .69653 .49313 Metetra
.656 .751 .919 r
.69653 .49313 .70118 .49869 .71111 .49568 .70649 .4901 Metetra
.656 .751 .919 r
.70649 .4901 .71111 .49568 .72108 .49267 .71647 .48707 Metetra
.656 .751 .919 r
.71647 .48707 .72108 .49267 .73108 .48964 .7265 .48402 Metetra
.656 .751 .919 r
.7265 .48402 .73108 .48964 .74111 .4866 .73656 .48096 Metetra
.656 .751 .919 r
.73656 .48096 .74111 .4866 .75118 .48355 .74665 .47789 Metetra
.656 .751 .919 r
.74665 .47789 .75118 .48355 .76129 .48049 .75679 .47481 Metetra
.656 .751 .919 r
.75679 .47481 .76129 .48049 .77143 .47742 .76695 .47172 Metetra
.656 .751 .919 r
.76695 .47172 .77143 .47742 .78161 .47433 .77716 .46861 Metetra
.656 .751 .919 r
.77716 .46861 .78161 .47433 .79182 .47124 .7874 .4655 Metetra
.656 .751 .919 r
.7874 .4655 .79182 .47124 .80207 .46814 .79767 .46238 Metetra
.656 .751 .919 r
.79767 .46238 .80207 .46814 .81236 .46502 .80799 .45924 Metetra
.656 .751 .919 r
.80799 .45924 .81236 .46502 .82268 .46189 .81833 .45609 Metetra
.656 .751 .919 r
.81833 .45609 .82268 .46189 .83304 .45876 .82872 .45293 Metetra
.656 .751 .919 r
.82872 .45293 .83304 .45876 .84344 .45561 .83915 .44976 Metetra
.656 .751 .919 r
.83915 .44976 .84344 .45561 .85388 .45245 .84961 .44658 Metetra
.656 .751 .919 r
.84961 .44658 .85388 .45245 .86435 .44928 .86011 .44339 Metetra
.656 .751 .919 r
.86011 .44339 .86435 .44928 .87486 .44609 .87064 .44019 Metetra
.656 .751 .919 r
.87064 .44019 .87486 .44609 .88541 .4429 .88122 .43697 Metetra
.656 .751 .919 r
.88122 .43697 .88541 .4429 .89599 .43969 .89183 .43374 Metetra
.656 .751 .919 r
.89183 .43374 .89599 .43969 .90662 .43647 .90249 .4305 Metetra
.656 .751 .919 r
.90249 .4305 .90662 .43647 .91728 .43325 .91318 .42725 Metetra
.173 0 .192 r
.30176 .61412 .30868 .59727 .31642 .60872 .31091 .60384 Metetra
.656 .751 .919 r
.31091 .60384 .31642 .60872 .32509 .60608 .31959 .60119 Metetra
.656 .751 .919 r
.31959 .60119 .32509 .60608 .33378 .60344 .3283 .59854 Metetra
.656 .751 .919 r
.3283 .59854 .33378 .60344 .3425 .60079 .33704 .59587 Metetra
.656 .751 .919 r
.33704 .59587 .3425 .60079 .35125 .59813 .3458 .59319 Metetra
.656 .751 .919 r
.3458 .59319 .35125 .59813 .36003 .59546 .3546 .5905 Metetra
.656 .751 .919 r
.3546 .5905 .36003 .59546 .36883 .59278 .36342 .58781 Metetra
.656 .751 .919 r
.36342 .58781 .36883 .59278 .37767 .59009 .37228 .58511 Metetra
.656 .751 .919 r
.37228 .58511 .37767 .59009 .38654 .58739 .38116 .58239 Metetra
.656 .751 .919 r
.38116 .58239 .38654 .58739 .39543 .58469 .39008 .57967 Metetra
.656 .751 .919 r
.39008 .57967 .39543 .58469 .40436 .58198 .39902 .57694 Metetra
.656 .751 .919 r
.39902 .57694 .40436 .58198 .41331 .57925 .40799 .5742 Metetra
.656 .751 .919 r
.40799 .5742 .41331 .57925 .42229 .57652 .417 .57145 Metetra
.656 .751 .919 r
.417 .57145 .42229 .57652 .43131 .57378 .42603 .5687 Metetra
.656 .751 .919 r
.42603 .5687 .43131 .57378 .44035 .57103 .43509 .56593 Metetra
.656 .751 .919 r
.43509 .56593 .44035 .57103 .44943 .56827 .44419 .56315 Metetra
.656 .751 .919 r
.44419 .56315 .44943 .56827 .45853 .5655 .45331 .56037 Metetra
.656 .751 .919 r
.45331 .56037 .45853 .5655 .46767 .56272 .46247 .55757 Metetra
.656 .751 .919 r
.46247 .55757 .46767 .56272 .47684 .55994 .47165 .55477 Metetra
.656 .751 .919 r
.47165 .55477 .47684 .55994 .48603 .55714 .48087 .55195 Metetra
.656 .751 .919 r
.48087 .55195 .48603 .55714 .49526 .55433 .49012 .54913 Metetra
.656 .751 .919 r
.49012 .54913 .49526 .55433 .50452 .55152 .4994 .54629 Metetra
.656 .751 .919 r
.4994 .54629 .50452 .55152 .51381 .54869 .50871 .54345 Metetra
.656 .751 .919 r
.50871 .54345 .51381 .54869 .52314 .54586 .51805 .5406 Metetra
.656 .751 .919 r
.51805 .5406 .52314 .54586 .53249 .54301 .52743 .53774 Metetra
.656 .751 .919 r
.52743 .53774 .53249 .54301 .54188 .54016 .53684 .53486 Metetra
.656 .751 .919 r
.53684 .53486 .54188 .54016 .55129 .5373 .54628 .53198 Metetra
.656 .751 .919 r
.54628 .53198 .55129 .5373 .56075 .53442 .55575 .52909 Metetra
.656 .751 .919 r
.55575 .52909 .56075 .53442 .57023 .53154 .56525 .52619 Metetra
.656 .751 .919 r
.56525 .52619 .57023 .53154 .57974 .52864 .57479 .52328 Metetra
.656 .751 .919 r
.57479 .52328 .57974 .52864 .58929 .52574 .58436 .52035 Metetra
.656 .751 .919 r
.58436 .52035 .58929 .52574 .59887 .52283 .59396 .51742 Metetra
.656 .751 .919 r
.59396 .51742 .59887 .52283 .60849 .5199 .6036 .51448 Metetra
.656 .751 .919 r
.6036 .51448 .60849 .5199 .61813 .51697 .61327 .51153 Metetra
.656 .751 .919 r
.61327 .51153 .61813 .51697 .62782 .51403 .62297 .50856 Metetra
.656 .751 .919 r
.62297 .50856 .62782 .51403 .63753 .51107 .63271 .50559 Metetra
.656 .751 .919 r
.63271 .50559 .63753 .51107 .64728 .50811 .64248 .50261 Metetra
.656 .751 .919 r
.64248 .50261 .64728 .50811 .65706 .50513 .65229 .49961 Metetra
.656 .751 .919 r
.65229 .49961 .65706 .50513 .66688 .50215 .66213 .49661 Metetra
.656 .751 .919 r
.66213 .49661 .66688 .50215 .67673 .49915 .672 .4936 Metetra
.656 .751 .919 r
.672 .4936 .67673 .49915 .68661 .49615 .68191 .49057 Metetra
.656 .751 .919 r
.68191 .49057 .68661 .49615 .69653 .49313 .69185 .48753 Metetra
.656 .751 .919 r
.69185 .48753 .69653 .49313 .70649 .4901 .70183 .48449 Metetra
.656 .751 .919 r
.70183 .48449 .70649 .4901 .71647 .48707 .71184 .48143 Metetra
.656 .751 .919 r
.71184 .48143 .71647 .48707 .7265 .48402 .72189 .47836 Metetra
.656 .751 .919 r
.72189 .47836 .7265 .48402 .73656 .48096 .73198 .47528 Metetra
.656 .751 .919 r
.73198 .47528 .73656 .48096 .74665 .47789 .7421 .47219 Metetra
.656 .751 .919 r
.7421 .47219 .74665 .47789 .75679 .47481 .75225 .46909 Metetra
.656 .751 .919 r
.75225 .46909 .75679 .47481 .76695 .47172 .76245 .46598 Metetra
.656 .751 .919 r
.76245 .46598 .76695 .47172 .77716 .46861 .77268 .46286 Metetra
.656 .751 .919 r
.77268 .46286 .77716 .46861 .7874 .4655 .78294 .45972 Metetra
.656 .751 .919 r
.78294 .45972 .7874 .4655 .79767 .46238 .79324 .45658 Metetra
.656 .751 .919 r
.79324 .45658 .79767 .46238 .80799 .45924 .80358 .45342 Metetra
.656 .751 .919 r
.80358 .45342 .80799 .45924 .81833 .45609 .81396 .45025 Metetra
.656 .751 .919 r
.81396 .45025 .81833 .45609 .82872 .45293 .82437 .44707 Metetra
.656 .751 .919 r
.82437 .44707 .82872 .45293 .83915 .44976 .83482 .44388 Metetra
.656 .751 .919 r
.83482 .44388 .83915 .44976 .84961 .44658 .84531 .44068 Metetra
.656 .751 .919 r
.84531 .44068 .84961 .44658 .86011 .44339 .85584 .43747 Metetra
.656 .751 .919 r
.85584 .43747 .86011 .44339 .87064 .44019 .8664 .43424 Metetra
.656 .751 .919 r
.8664 .43424 .87064 .44019 .88122 .43697 .87701 .431 Metetra
.656 .751 .919 r
.87701 .431 .88122 .43697 .89183 .43374 .88765 .42775 Metetra
.656 .751 .919 r
.88765 .42775 .89183 .43374 .90249 .4305 .89833 .42449 Metetra
.656 .751 .919 r
.89833 .42449 .90249 .4305 .91318 .42725 .90905 .42122 Metetra
.688 .618 .773 r
.29655 .60369 .30176 .61412 .31091 .60384 .30536 .59894 Metetra
.656 .751 .919 r
.30536 .59894 .31091 .60384 .31959 .60119 .31406 .59628 Metetra
.656 .751 .919 r
.31406 .59628 .31959 .60119 .3283 .59854 .32278 .5936 Metetra
.656 .751 .919 r
.32278 .5936 .3283 .59854 .33704 .59587 .33154 .59092 Metetra
.656 .751 .919 r
.33154 .59092 .33704 .59587 .3458 .59319 .34032 .58823 Metetra
.656 .751 .919 r
.34032 .58823 .3458 .59319 .3546 .5905 .34914 .58552 Metetra
.656 .751 .919 r
.34914 .58552 .3546 .5905 .36342 .58781 .35798 .58281 Metetra
.656 .751 .919 r
.35798 .58281 .36342 .58781 .37228 .58511 .36685 .58009 Metetra
.656 .751 .919 r
.36685 .58009 .37228 .58511 .38116 .58239 .37576 .57736 Metetra
.656 .751 .919 r
.37576 .57736 .38116 .58239 .39008 .57967 .38469 .57462 Metetra
.656 .751 .919 r
.38469 .57462 .39008 .57967 .39902 .57694 .39365 .57188 Metetra
.656 .751 .919 r
.39365 .57188 .39902 .57694 .40799 .5742 .40264 .56912 Metetra
.656 .751 .919 r
.40264 .56912 .40799 .5742 .417 .57145 .41166 .56635 Metetra
.656 .751 .919 r
.41166 .56635 .417 .57145 .42603 .5687 .42072 .56358 Metetra
.656 .751 .919 r
.42072 .56358 .42603 .5687 .43509 .56593 .4298 .5608 Metetra
.656 .751 .919 r
.4298 .5608 .43509 .56593 .44419 .56315 .43891 .558 Metetra
.656 .751 .919 r
.43891 .558 .44419 .56315 .45331 .56037 .44806 .5552 Metetra
.656 .751 .919 r
.44806 .5552 .45331 .56037 .46247 .55757 .45723 .55239 Metetra
.656 .751 .919 r
.45723 .55239 .46247 .55757 .47165 .55477 .46644 .54956 Metetra
.656 .751 .919 r
.46644 .54956 .47165 .55477 .48087 .55195 .47567 .54673 Metetra
.656 .751 .919 r
.47567 .54673 .48087 .55195 .49012 .54913 .48494 .54389 Metetra
.656 .751 .919 r
.48494 .54389 .49012 .54913 .4994 .54629 .49424 .54104 Metetra
.656 .751 .919 r
.49424 .54104 .4994 .54629 .50871 .54345 .50358 .53818 Metetra
.656 .751 .919 r
.50358 .53818 .50871 .54345 .51805 .5406 .51294 .53531 Metetra
.656 .751 .919 r
.51294 .53531 .51805 .5406 .52743 .53774 .52234 .53243 Metetra
.656 .751 .919 r
.52234 .53243 .52743 .53774 .53684 .53486 .53176 .52954 Metetra
.656 .751 .919 r
.53176 .52954 .53684 .53486 .54628 .53198 .54123 .52664 Metetra
.656 .751 .919 r
.54123 .52664 .54628 .53198 .55575 .52909 .55072 .52372 Metetra
.656 .751 .919 r
.55072 .52372 .55575 .52909 .56525 .52619 .56025 .5208 Metetra
.656 .751 .919 r
.56025 .5208 .56525 .52619 .57479 .52328 .5698 .51787 Metetra
.656 .751 .919 r
.5698 .51787 .57479 .52328 .58436 .52035 .5794 .51493 Metetra
.656 .751 .919 r
.5794 .51493 .58436 .52035 .59396 .51742 .58902 .51198 Metetra
.656 .751 .919 r
.58902 .51198 .59396 .51742 .6036 .51448 .59868 .50902 Metetra
.656 .751 .919 r
.59868 .50902 .6036 .51448 .61327 .51153 .60837 .50605 Metetra
.656 .751 .919 r
.60837 .50605 .61327 .51153 .62297 .50856 .6181 .50307 Metetra
.656 .751 .919 r
.6181 .50307 .62297 .50856 .63271 .50559 .62786 .50008 Metetra
.656 .751 .919 r
.62786 .50008 .63271 .50559 .64248 .50261 .63765 .49707 Metetra
.656 .751 .919 r
.63765 .49707 .64248 .50261 .65229 .49961 .64748 .49406 Metetra
.656 .751 .919 r
.64748 .49406 .65229 .49961 .66213 .49661 .65734 .49104 Metetra
.656 .751 .919 r
.65734 .49104 .66213 .49661 .672 .4936 .66724 .488 Metetra
.656 .751 .919 r
.66724 .488 .672 .4936 .68191 .49057 .67717 .48496 Metetra
.656 .751 .919 r
.67717 .48496 .68191 .49057 .69185 .48753 .68714 .4819 Metetra
.656 .751 .919 r
.68714 .4819 .69185 .48753 .70183 .48449 .69714 .47884 Metetra
.656 .751 .919 r
.69714 .47884 .70183 .48449 .71184 .48143 .70718 .47576 Metetra
.656 .751 .919 r
.70718 .47576 .71184 .48143 .72189 .47836 .71726 .47267 Metetra
.656 .751 .919 r
.71726 .47267 .72189 .47836 .73198 .47528 .72737 .46957 Metetra
.656 .751 .919 r
.72737 .46957 .73198 .47528 .7421 .47219 .73751 .46646 Metetra
.656 .751 .919 r
.73751 .46646 .7421 .47219 .75225 .46909 .74769 .46334 Metetra
.656 .751 .919 r
.74769 .46334 .75225 .46909 .76245 .46598 .75791 .46021 Metetra
.656 .751 .919 r
.75791 .46021 .76245 .46598 .77268 .46286 .76817 .45706 Metetra
.656 .751 .919 r
.76817 .45706 .77268 .46286 .78294 .45972 .77846 .45391 Metetra
.656 .751 .919 r
.77846 .45391 .78294 .45972 .79324 .45658 .78878 .45074 Metetra
.656 .751 .919 r
.78878 .45074 .79324 .45658 .80358 .45342 .79915 .44756 Metetra
.656 .751 .919 r
.79915 .44756 .80358 .45342 .81396 .45025 .80955 .44437 Metetra
.656 .751 .919 r
.80955 .44437 .81396 .45025 .82437 .44707 .81999 .44117 Metetra
.656 .751 .919 r
.81999 .44117 .82437 .44707 .83482 .44388 .83047 .43796 Metetra
.656 .751 .919 r
.83047 .43796 .83482 .44388 .84531 .44068 .84099 .43474 Metetra
.656 .751 .919 r
.84099 .43474 .84531 .44068 .85584 .43747 .85154 .4315 Metetra
.656 .751 .919 r
.85154 .4315 .85584 .43747 .8664 .43424 .86213 .42825 Metetra
.656 .751 .919 r
.86213 .42825 .8664 .43424 .87701 .431 .87276 .425 Metetra
.656 .751 .919 r
.87276 .425 .87701 .431 .88765 .42775 .88343 .42172 Metetra
.656 .751 .919 r
.88343 .42172 .88765 .42775 .89833 .42449 .89414 .41844 Metetra
.656 .751 .919 r
.89414 .41844 .89833 .42449 .90905 .42122 .90489 .41515 Metetra
.367 .368 .728 r
.29168 .58803 .29655 .60369 .30536 .59894 .29978 .59401 Metetra
.656 .751 .919 r
.29978 .59401 .30536 .59894 .31406 .59628 .30849 .59133 Metetra
.656 .751 .919 r
.30849 .59133 .31406 .59628 .32278 .5936 .31724 .58864 Metetra
.656 .751 .919 r
.31724 .58864 .32278 .5936 .33154 .59092 .32601 .58594 Metetra
.656 .751 .919 r
.32601 .58594 .33154 .59092 .34032 .58823 .33481 .58323 Metetra
.656 .751 .919 r
.33481 .58323 .34032 .58823 .34914 .58552 .34364 .58051 Metetra
.656 .751 .919 r
.34364 .58051 .34914 .58552 .35798 .58281 .3525 .57778 Metetra
.656 .751 .919 r
.3525 .57778 .35798 .58281 .36685 .58009 .3614 .57505 Metetra
.656 .751 .919 r
.3614 .57505 .36685 .58009 .37576 .57736 .37032 .5723 Metetra
.656 .751 .919 r
.37032 .5723 .37576 .57736 .38469 .57462 .37927 .56955 Metetra
.656 .751 .919 r
.37927 .56955 .38469 .57462 .39365 .57188 .38825 .56678 Metetra
.656 .751 .919 r
.38825 .56678 .39365 .57188 .40264 .56912 .39726 .56401 Metetra
.656 .751 .919 r
.39726 .56401 .40264 .56912 .41166 .56635 .4063 .56122 Metetra
.656 .751 .919 r
.4063 .56122 .41166 .56635 .42072 .56358 .41537 .55843 Metetra
.656 .751 .919 r
.41537 .55843 .42072 .56358 .4298 .5608 .42447 .55563 Metetra
.656 .751 .919 r
.42447 .55563 .4298 .5608 .43891 .558 .4336 .55282 Metetra
.656 .751 .919 r
.4336 .55282 .43891 .558 .44806 .5552 .44277 .55 Metetra
.656 .751 .919 r
.44277 .55 .44806 .5552 .45723 .55239 .45196 .54717 Metetra
.656 .751 .919 r
.45196 .54717 .45723 .55239 .46644 .54956 .46119 .54433 Metetra
.656 .751 .919 r
.46119 .54433 .46644 .54956 .47567 .54673 .47045 .54148 Metetra
.656 .751 .919 r
.47045 .54148 .47567 .54673 .48494 .54389 .47974 .53862 Metetra
.656 .751 .919 r
.47974 .53862 .48494 .54389 .49424 .54104 .48906 .53575 Metetra
.656 .751 .919 r
.48906 .53575 .49424 .54104 .50358 .53818 .49841 .53287 Metetra
.656 .751 .919 r
.49841 .53287 .50358 .53818 .51294 .53531 .50779 .52998 Metetra
.656 .751 .919 r
.50779 .52998 .51294 .53531 .52234 .53243 .51721 .52708 Metetra
.656 .751 .919 r
.51721 .52708 .52234 .53243 .53176 .52954 .52666 .52417 Metetra
.656 .751 .919 r
.52666 .52417 .53176 .52954 .54123 .52664 .53614 .52125 Metetra
.656 .751 .919 r
.53614 .52125 .54123 .52664 .55072 .52372 .54566 .51833 Metetra
.656 .751 .919 r
.54566 .51833 .55072 .52372 .56025 .5208 .55521 .51539 Metetra
.656 .751 .919 r
.55521 .51539 .56025 .5208 .5698 .51787 .56479 .51244 Metetra
.656 .751 .919 r
.56479 .51244 .5698 .51787 .5794 .51493 .5744 .50948 Metetra
.656 .751 .919 r
.5744 .50948 .5794 .51493 .58902 .51198 .58405 .50651 Metetra
.656 .751 .919 r
.58405 .50651 .58902 .51198 .59868 .50902 .59373 .50353 Metetra
.656 .751 .919 r
.59373 .50353 .59868 .50902 .60837 .50605 .60344 .50054 Metetra
.656 .751 .919 r
.60344 .50054 .60837 .50605 .6181 .50307 .61319 .49754 Metetra
.656 .751 .919 r
.61319 .49754 .6181 .50307 .62786 .50008 .62298 .49452 Metetra
.656 .751 .919 r
.62298 .49452 .62786 .50008 .63765 .49707 .63279 .4915 Metetra
.656 .751 .919 r
.63279 .4915 .63765 .49707 .64748 .49406 .64265 .48847 Metetra
.656 .751 .919 r
.64265 .48847 .64748 .49406 .65734 .49104 .65253 .48543 Metetra
.656 .751 .919 r
.65253 .48543 .65734 .49104 .66724 .488 .66245 .48237 Metetra
.656 .751 .919 r
.66245 .48237 .66724 .488 .67717 .48496 .67241 .47931 Metetra
.656 .751 .919 r
.67241 .47931 .67717 .48496 .68714 .4819 .6824 .47623 Metetra
.656 .751 .919 r
.6824 .47623 .68714 .4819 .69714 .47884 .69243 .47315 Metetra
.656 .751 .919 r
.69243 .47315 .69714 .47884 .70718 .47576 .70249 .47005 Metetra
.656 .751 .919 r
.70249 .47005 .70718 .47576 .71726 .47267 .71259 .46694 Metetra
.656 .751 .919 r
.71259 .46694 .71726 .47267 .72737 .46957 .72272 .46382 Metetra
.656 .751 .919 r
.72272 .46382 .72737 .46957 .73751 .46646 .73289 .46069 Metetra
.656 .751 .919 r
.73289 .46069 .73751 .46646 .74769 .46334 .7431 .45755 Metetra
.656 .751 .919 r
.7431 .45755 .74769 .46334 .75791 .46021 .75334 .45439 Metetra
.656 .751 .919 r
.75334 .45439 .75791 .46021 .76817 .45706 .76362 .45123 Metetra
.656 .751 .919 r
.76362 .45123 .76817 .45706 .77846 .45391 .77394 .44805 Metetra
.656 .751 .919 r
.77394 .44805 .77846 .45391 .78878 .45074 .7843 .44487 Metetra
.656 .751 .919 r
.7843 .44487 .78878 .45074 .79915 .44756 .79469 .44167 Metetra
.656 .751 .919 r
.79469 .44167 .79915 .44756 .80955 .44437 .80512 .43846 Metetra
.656 .751 .919 r
.80512 .43846 .80955 .44437 .81999 .44117 .81558 .43523 Metetra
.656 .751 .919 r
.81558 .43523 .81999 .44117 .83047 .43796 .82609 .432 Metetra
.656 .751 .919 r
.82609 .432 .83047 .43796 .84099 .43474 .83663 .42875 Metetra
.656 .751 .919 r
.83663 .42875 .84099 .43474 .85154 .4315 .84721 .4255 Metetra
.656 .751 .919 r
.84721 .4255 .85154 .4315 .86213 .42825 .85784 .42223 Metetra
.656 .751 .919 r
.85784 .42223 .86213 .42825 .87276 .425 .86849 .41895 Metetra
.656 .751 .919 r
.86849 .41895 .87276 .425 .88343 .42172 .87919 .41565 Metetra
.656 .751 .919 r
.87919 .41565 .88343 .42172 .89414 .41844 .88993 .41235 Metetra
.656 .751 .919 r
.88993 .41235 .89414 .41844 .90489 .41515 .90071 .40903 Metetra
.28483 .60064 .29168 .58803 .29978 .59401 .29416 .58905 Metetra
.656 .751 .919 r
.29416 .58905 .29978 .59401 .30849 .59133 .30289 .58636 Metetra
.656 .751 .919 r
.30289 .58636 .30849 .59133 .31724 .58864 .31165 .58365 Metetra
.656 .751 .919 r
.31165 .58365 .31724 .58864 .32601 .58594 .32044 .58093 Metetra
.656 .751 .919 r
.32044 .58093 .32601 .58594 .33481 .58323 .32926 .5782 Metetra
.656 .751 .919 r
.32926 .5782 .33481 .58323 .34364 .58051 .33811 .57547 Metetra
.656 .751 .919 r
.33811 .57547 .34364 .58051 .3525 .57778 .34699 .57272 Metetra
.656 .751 .919 r
.34699 .57272 .3525 .57778 .3614 .57505 .3559 .56997 Metetra
.656 .751 .919 r
.3559 .56997 .3614 .57505 .37032 .5723 .36484 .56721 Metetra
.656 .751 .919 r
.36484 .56721 .37032 .5723 .37927 .56955 .37381 .56443 Metetra
.656 .751 .919 r
.37381 .56443 .37927 .56955 .38825 .56678 .38281 .56165 Metetra
.656 .751 .919 r
.38281 .56165 .38825 .56678 .39726 .56401 .39184 .55886 Metetra
.656 .751 .919 r
.39184 .55886 .39726 .56401 .4063 .56122 .4009 .55606 Metetra
.656 .751 .919 r
.4009 .55606 .4063 .56122 .41537 .55843 .40999 .55325 Metetra
.656 .751 .919 r
.40999 .55325 .41537 .55843 .42447 .55563 .41911 .55043 Metetra
.656 .751 .919 r
.41911 .55043 .42447 .55563 .4336 .55282 .42826 .5476 Metetra
.656 .751 .919 r
.42826 .5476 .4336 .55282 .44277 .55 .43745 .54476 Metetra
.656 .751 .919 r
.43745 .54476 .44277 .55 .45196 .54717 .44666 .54192 Metetra
.656 .751 .919 r
.44666 .54192 .45196 .54717 .46119 .54433 .45591 .53906 Metetra
.656 .751 .919 r
.45591 .53906 .46119 .54433 .47045 .54148 .46519 .53619 Metetra
.656 .751 .919 r
.46519 .53619 .47045 .54148 .47974 .53862 .4745 .53331 Metetra
.656 .751 .919 r
.4745 .53331 .47974 .53862 .48906 .53575 .48384 .53043 Metetra
.656 .751 .919 r
.48384 .53043 .48906 .53575 .49841 .53287 .49321 .52753 Metetra
.656 .751 .919 r
.49321 .52753 .49841 .53287 .50779 .52998 .50262 .52462 Metetra
.656 .751 .919 r
.50262 .52462 .50779 .52998 .51721 .52708 .51205 .5217 Metetra
.656 .751 .919 r
.51205 .5217 .51721 .52708 .52666 .52417 .52152 .51878 Metetra
.656 .751 .919 r
.52152 .51878 .52666 .52417 .53614 .52125 .53103 .51584 Metetra
.656 .751 .919 r
.53103 .51584 .53614 .52125 .54566 .51833 .54056 .51289 Metetra
.656 .751 .919 r
.54056 .51289 .54566 .51833 .55521 .51539 .55013 .50993 Metetra
.656 .751 .919 r
.55013 .50993 .55521 .51539 .56479 .51244 .55974 .50697 Metetra
.656 .751 .919 r
.55974 .50697 .56479 .51244 .5744 .50948 .56937 .50399 Metetra
.656 .751 .919 r
.56937 .50399 .5744 .50948 .58405 .50651 .57904 .501 Metetra
.656 .751 .919 r
.57904 .501 .58405 .50651 .59373 .50353 .58875 .498 Metetra
.656 .751 .919 r
.58875 .498 .59373 .50353 .60344 .50054 .59848 .49499 Metetra
.656 .751 .919 r
.59848 .49499 .60344 .50054 .61319 .49754 .60826 .49197 Metetra
.656 .751 .919 r
.60826 .49197 .61319 .49754 .62298 .49452 .61806 .48894 Metetra
.656 .751 .919 r
.61806 .48894 .62298 .49452 .63279 .4915 .6279 .4859 Metetra
.656 .751 .919 r
.6279 .4859 .63279 .4915 .64265 .48847 .63778 .48284 Metetra
.656 .751 .919 r
.63778 .48284 .64265 .48847 .65253 .48543 .64769 .47978 Metetra
.656 .751 .919 r
.64769 .47978 .65253 .48543 .66245 .48237 .65763 .47671 Metetra
.656 .751 .919 r
.65763 .47671 .66245 .48237 .67241 .47931 .66761 .47362 Metetra
.656 .751 .919 r
.66761 .47362 .67241 .47931 .6824 .47623 .67763 .47053 Metetra
.656 .751 .919 r
.67763 .47053 .6824 .47623 .69243 .47315 .68768 .46742 Metetra
.656 .751 .919 r
.68768 .46742 .69243 .47315 .70249 .47005 .69777 .4643 Metetra
.656 .751 .919 r
.69777 .4643 .70249 .47005 .71259 .46694 .70789 .46117 Metetra
.656 .751 .919 r
.70789 .46117 .71259 .46694 .72272 .46382 .71805 .45803 Metetra
.656 .751 .919 r
.71805 .45803 .72272 .46382 .73289 .46069 .72825 .45488 Metetra
.656 .751 .919 r
.72825 .45488 .73289 .46069 .7431 .45755 .73848 .45172 Metetra
.656 .751 .919 r
.73848 .45172 .7431 .45755 .75334 .45439 .74875 .44854 Metetra
.656 .751 .919 r
.74875 .44854 .75334 .45439 .76362 .45123 .75905 .44536 Metetra
.656 .751 .919 r
.75905 .44536 .76362 .45123 .77394 .44805 .7694 .44216 Metetra
.656 .751 .919 r
.7694 .44216 .77394 .44805 .7843 .44487 .77978 .43895 Metetra
.656 .751 .919 r
.77978 .43895 .7843 .44487 .79469 .44167 .7902 .43573 Metetra
.656 .751 .919 r
.7902 .43573 .79469 .44167 .80512 .43846 .80065 .4325 Metetra
.656 .751 .919 r
.80065 .4325 .80512 .43846 .81558 .43523 .81115 .42926 Metetra
.656 .751 .919 r
.81115 .42926 .81558 .43523 .82609 .432 .82168 .426 Metetra
.656 .751 .919 r
.82168 .426 .82609 .432 .83663 .42875 .83225 .42273 Metetra
.656 .751 .919 r
.83225 .42273 .83663 .42875 .84721 .4255 .84286 .41945 Metetra
.656 .751 .919 r
.84286 .41945 .84721 .4255 .85784 .42223 .85351 .41616 Metetra
.656 .751 .919 r
.85351 .41616 .85784 .42223 .86849 .41895 .86419 .41286 Metetra
.656 .751 .919 r
.86419 .41286 .86849 .41895 .87919 .41565 .87492 .40954 Metetra
.656 .751 .919 r
.87492 .40954 .87919 .41565 .88993 .41235 .88569 .40621 Metetra
.656 .751 .919 r
.88569 .40621 .88993 .41235 .90071 .40903 .89649 .40287 Metetra
.538 .459 .714 r
.28006 .58292 .28483 .60064 .29416 .58905 .28851 .58406 Metetra
.656 .751 .919 r
.28851 .58406 .29416 .58905 .30289 .58636 .29726 .58135 Metetra
.656 .751 .919 r
.29726 .58135 .30289 .58636 .31165 .58365 .30604 .57862 Metetra
.656 .751 .919 r
.30604 .57862 .31165 .58365 .32044 .58093 .31485 .57589 Metetra
.656 .751 .919 r
.31485 .57589 .32044 .58093 .32926 .5782 .32368 .57315 Metetra
.656 .751 .919 r
.32368 .57315 .32926 .5782 .33811 .57547 .33255 .57039 Metetra
.656 .751 .919 r
.33255 .57039 .33811 .57547 .34699 .57272 .34145 .56763 Metetra
.656 .751 .919 r
.34145 .56763 .34699 .57272 .3559 .56997 .35038 .56486 Metetra
.656 .751 .919 r
.35038 .56486 .3559 .56997 .36484 .56721 .35933 .56208 Metetra
.656 .751 .919 r
.35933 .56208 .36484 .56721 .37381 .56443 .36832 .55929 Metetra
.656 .751 .919 r
.36832 .55929 .37381 .56443 .38281 .56165 .37734 .55649 Metetra
.656 .751 .919 r
.37734 .55649 .38281 .56165 .39184 .55886 .38639 .55368 Metetra
.656 .751 .919 r
.38639 .55368 .39184 .55886 .4009 .55606 .39547 .55087 Metetra
.656 .751 .919 r
.39547 .55087 .4009 .55606 .40999 .55325 .40458 .54804 Metetra
.656 .751 .919 r
.40458 .54804 .40999 .55325 .41911 .55043 .41372 .5452 Metetra
.656 .751 .919 r
.41372 .5452 .41911 .55043 .42826 .5476 .42289 .54236 Metetra
.656 .751 .919 r
.42289 .54236 .42826 .5476 .43745 .54476 .43209 .5395 Metetra
.656 .751 .919 r
.43209 .5395 .43745 .54476 .44666 .54192 .44133 .53663 Metetra
.656 .751 .919 r
.44133 .53663 .44666 .54192 .45591 .53906 .45059 .53376 Metetra
.656 .751 .919 r
.45059 .53376 .45591 .53906 .46519 .53619 .45989 .53087 Metetra
.656 .751 .919 r
.45989 .53087 .46519 .53619 .4745 .53331 .46922 .52797 Metetra
.656 .751 .919 r
.46922 .52797 .4745 .53331 .48384 .53043 .47858 .52507 Metetra
.656 .751 .919 r
.47858 .52507 .48384 .53043 .49321 .52753 .48798 .52215 Metetra
.656 .751 .919 r
.48798 .52215 .49321 .52753 .50262 .52462 .4974 .51923 Metetra
.656 .751 .919 r
.4974 .51923 .50262 .52462 .51205 .5217 .50686 .51629 Metetra
.656 .751 .919 r
.50686 .51629 .51205 .5217 .52152 .51878 .51636 .51335 Metetra
.656 .751 .919 r
.51636 .51335 .52152 .51878 .53103 .51584 .52588 .51039 Metetra
.656 .751 .919 r
.52588 .51039 .53103 .51584 .54056 .51289 .53544 .50742 Metetra
.656 .751 .919 r
.53544 .50742 .54056 .51289 .55013 .50993 .54503 .50445 Metetra
.656 .751 .919 r
.54503 .50445 .55013 .50993 .55974 .50697 .55465 .50146 Metetra
.656 .751 .919 r
.55465 .50146 .55974 .50697 .56937 .50399 .56431 .49846 Metetra
.656 .751 .919 r
.56431 .49846 .56937 .50399 .57904 .501 .57401 .49545 Metetra
.656 .751 .919 r
.57401 .49545 .57904 .501 .58875 .498 .58373 .49243 Metetra
.656 .751 .919 r
.58373 .49243 .58875 .498 .59848 .49499 .59349 .4894 Metetra
.656 .751 .919 r
.59349 .4894 .59848 .49499 .60826 .49197 .60329 .48636 Metetra
.656 .751 .919 r
.60329 .48636 .60826 .49197 .61806 .48894 .61312 .48331 Metetra
.656 .751 .919 r
.61312 .48331 .61806 .48894 .6279 .4859 .62298 .48025 Metetra
.656 .751 .919 r
.62298 .48025 .6279 .4859 .63778 .48284 .63288 .47718 Metetra
.656 .751 .919 r
.63288 .47718 .63778 .48284 .64769 .47978 .64281 .4741 Metetra
.656 .751 .919 r
.64281 .4741 .64769 .47978 .65763 .47671 .65278 .471 Metetra
.656 .751 .919 r
.65278 .471 .65763 .47671 .66761 .47362 .66279 .4679 Metetra
.656 .751 .919 r
.66279 .4679 .66761 .47362 .67763 .47053 .67283 .46478 Metetra
.656 .751 .919 r
.67283 .46478 .67763 .47053 .68768 .46742 .6829 .46165 Metetra
.656 .751 .919 r
.6829 .46165 .68768 .46742 .69777 .4643 .69301 .45851 Metetra
.656 .751 .919 r
.69301 .45851 .69777 .4643 .70789 .46117 .70316 .45537 Metetra
.656 .751 .919 r
.70316 .45537 .70789 .46117 .71805 .45803 .71335 .4522 Metetra
.656 .751 .919 r
.71335 .4522 .71805 .45803 .72825 .45488 .72357 .44903 Metetra
.656 .751 .919 r
.72357 .44903 .72825 .45488 .73848 .45172 .73383 .44585 Metetra
.656 .751 .919 r
.73383 .44585 .73848 .45172 .74875 .44854 .74412 .44265 Metetra
.656 .751 .919 r
.74412 .44265 .74875 .44854 .75905 .44536 .75445 .43945 Metetra
.656 .751 .919 r
.75445 .43945 .75905 .44536 .7694 .44216 .76482 .43623 Metetra
.656 .751 .919 r
.76482 .43623 .7694 .44216 .77978 .43895 .77523 .433 Metetra
.656 .751 .919 r
.77523 .433 .77978 .43895 .7902 .43573 .78567 .42975 Metetra
.656 .751 .919 r
.78567 .42975 .7902 .43573 .80065 .4325 .79616 .4265 Metetra
.656 .751 .919 r
.79616 .4265 .80065 .4325 .81115 .42926 .80668 .42324 Metetra
.656 .751 .919 r
.80668 .42324 .81115 .42926 .82168 .426 .81724 .41996 Metetra
.656 .751 .919 r
.81724 .41996 .82168 .426 .83225 .42273 .82784 .41667 Metetra
.656 .751 .919 r
.82784 .41667 .83225 .42273 .84286 .41945 .83847 .41337 Metetra
.656 .751 .919 r
.83847 .41337 .84286 .41945 .85351 .41616 .84915 .41005 Metetra
.656 .751 .919 r
.84915 .41005 .85351 .41616 .86419 .41286 .85987 .40673 Metetra
.656 .751 .919 r
.85987 .40673 .86419 .41286 .87492 .40954 .87062 .40339 Metetra
.656 .751 .919 r
.87062 .40339 .87492 .40954 .88569 .40621 .88142 .40004 Metetra
.656 .751 .919 r
.88142 .40004 .88569 .40621 .89649 .40287 .89225 .39668 Metetra
.46 .761 .995 r
.27424 .57957 .28006 .58292 .28851 .58406 .28282 .57904 Metetra
.656 .751 .919 r
.28282 .57904 .28851 .58406 .29726 .58135 .29159 .57631 Metetra
.656 .751 .919 r
.29159 .57631 .29726 .58135 .30604 .57862 .30039 .57357 Metetra
.656 .751 .919 r
.30039 .57357 .30604 .57862 .31485 .57589 .30921 .57082 Metetra
.656 .751 .919 r
.30921 .57082 .31485 .57589 .32368 .57315 .31807 .56806 Metetra
.656 .751 .919 r
.31807 .56806 .32368 .57315 .33255 .57039 .32695 .56529 Metetra
.656 .751 .919 r
.32695 .56529 .33255 .57039 .34145 .56763 .33587 .56251 Metetra
.656 .751 .919 r
.33587 .56251 .34145 .56763 .35038 .56486 .34482 .55972 Metetra
.656 .751 .919 r
.34482 .55972 .35038 .56486 .35933 .56208 .35379 .55692 Metetra
.656 .751 .919 r
.35379 .55692 .35933 .56208 .36832 .55929 .3628 .55412 Metetra
.656 .751 .919 r
.3628 .55412 .36832 .55929 .37734 .55649 .37183 .5513 Metetra
.656 .751 .919 r
.37183 .5513 .37734 .55649 .38639 .55368 .3809 .54847 Metetra
.656 .751 .919 r
.3809 .54847 .38639 .55368 .39547 .55087 .39 .54564 Metetra
.656 .751 .919 r
.39 .54564 .39547 .55087 .40458 .54804 .39913 .54279 Metetra
.656 .751 .919 r
.39913 .54279 .40458 .54804 .41372 .5452 .40829 .53994 Metetra
.656 .751 .919 r
.40829 .53994 .41372 .5452 .42289 .54236 .41748 .53707 Metetra
.656 .751 .919 r
.41748 .53707 .42289 .54236 .43209 .5395 .4267 .5342 Metetra
.656 .751 .919 r
.4267 .5342 .43209 .5395 .44133 .53663 .43596 .53132 Metetra
.656 .751 .919 r
.43596 .53132 .44133 .53663 .45059 .53376 .44525 .52842 Metetra
.656 .751 .919 r
.44525 .52842 .45059 .53376 .45989 .53087 .45456 .52552 Metetra
.656 .751 .919 r
.45456 .52552 .45989 .53087 .46922 .52797 .46391 .5226 Metetra
.656 .751 .919 r
.46391 .5226 .46922 .52797 .47858 .52507 .4733 .51968 Metetra
.656 .751 .919 r
.4733 .51968 .47858 .52507 .48798 .52215 .48271 .51674 Metetra
.656 .751 .919 r
.48271 .51674 .48798 .52215 .4974 .51923 .49216 .5138 Metetra
.656 .751 .919 r
.49216 .5138 .4974 .51923 .50686 .51629 .50164 .51084 Metetra
.656 .751 .919 r
.50164 .51084 .50686 .51629 .51636 .51335 .51115 .50788 Metetra
.656 .751 .919 r
.51115 .50788 .51636 .51335 .52588 .51039 .5207 .5049 Metetra
.656 .751 .919 r
.5207 .5049 .52588 .51039 .53544 .50742 .53028 .50192 Metetra
.656 .751 .919 r
.53028 .50192 .53544 .50742 .54503 .50445 .53989 .49892 Metetra
.656 .751 .919 r
.53989 .49892 .54503 .50445 .55465 .50146 .54954 .49592 Metetra
.656 .751 .919 r
.54954 .49592 .55465 .50146 .56431 .49846 .55922 .4929 Metetra
.656 .751 .919 r
.55922 .4929 .56431 .49846 .57401 .49545 .56894 .48987 Metetra
.656 .751 .919 r
.56894 .48987 .57401 .49545 .58373 .49243 .57868 .48683 Metetra
.656 .751 .919 r
.57868 .48683 .58373 .49243 .59349 .4894 .58847 .48378 Metetra
.656 .751 .919 r
.58847 .48378 .59349 .4894 .60329 .48636 .59828 .48072 Metetra
.656 .751 .919 r
.59828 .48072 .60329 .48636 .61312 .48331 .60814 .47765 Metetra
.656 .751 .919 r
.60814 .47765 .61312 .48331 .62298 .48025 .61802 .47457 Metetra
.656 .751 .919 r
.61802 .47457 .62298 .48025 .63288 .47718 .62795 .47148 Metetra
.656 .751 .919 r
.62795 .47148 .63288 .47718 .64281 .4741 .6379 .46838 Metetra
.656 .751 .919 r
.6379 .46838 .64281 .4741 .65278 .471 .6479 .46526 Metetra
.656 .751 .919 r
.6479 .46526 .65278 .471 .66279 .4679 .65793 .46214 Metetra
.656 .751 .919 r
.65793 .46214 .66279 .4679 .67283 .46478 .66799 .459 Metetra
.656 .751 .919 r
.66799 .459 .67283 .46478 .6829 .46165 .67809 .45585 Metetra
.656 .751 .919 r
.67809 .45585 .6829 .46165 .69301 .45851 .68823 .45269 Metetra
.656 .751 .919 r
.68823 .45269 .69301 .45851 .70316 .45537 .6984 .44952 Metetra
.656 .751 .919 r
.6984 .44952 .70316 .45537 .71335 .4522 .70861 .44634 Metetra
.656 .751 .919 r
.70861 .44634 .71335 .4522 .72357 .44903 .71886 .44314 Metetra
.656 .751 .919 r
.71886 .44314 .72357 .44903 .73383 .44585 .72914 .43994 Metetra
.656 .751 .919 r
.72914 .43994 .73383 .44585 .74412 .44265 .73946 .43672 Metetra
.656 .751 .919 r
.73946 .43672 .74412 .44265 .75445 .43945 .74982 .43349 Metetra
.656 .751 .919 r
.74982 .43349 .75445 .43945 .76482 .43623 .76022 .43025 Metetra
.656 .751 .919 r
.76022 .43025 .76482 .43623 .77523 .433 .77065 .427 Metetra
.656 .751 .919 r
.77065 .427 .77523 .433 .78567 .42975 .78112 .42374 Metetra
.656 .751 .919 r
.78112 .42374 .78567 .42975 .79616 .4265 .79163 .42046 Metetra
.656 .751 .919 r
.79163 .42046 .79616 .4265 .80668 .42324 .80218 .41718 Metetra
.656 .751 .919 r
.80218 .41718 .80668 .42324 .81724 .41996 .81277 .41388 Metetra
.656 .751 .919 r
.81277 .41388 .81724 .41996 .82784 .41667 .82339 .41056 Metetra
.656 .751 .919 r
.82339 .41056 .82784 .41667 .83847 .41337 .83406 .40724 Metetra
.656 .751 .919 r
.83406 .40724 .83847 .41337 .84915 .41005 .84476 .4039 Metetra
.656 .751 .919 r
.84476 .4039 .84915 .41005 .85987 .40673 .85551 .40056 Metetra
.656 .751 .919 r
.85551 .40056 .85987 .40673 .87062 .40339 .86629 .39719 Metetra
.656 .751 .919 r
.86629 .39719 .87062 .40339 .88142 .40004 .87712 .39382 Metetra
.656 .751 .919 r
.87712 .39382 .88142 .40004 .89225 .39668 .88798 .39043 Metetra
.778 .998 .83 r
.26794 .58212 .27424 .57957 .28282 .57904 .2771 .57399 Metetra
.656 .751 .919 r
.2771 .57399 .28282 .57904 .29159 .57631 .28589 .57124 Metetra
.656 .751 .919 r
.28589 .57124 .29159 .57631 .30039 .57357 .2947 .56848 Metetra
.656 .751 .919 r
.2947 .56848 .30039 .57357 .30921 .57082 .30354 .56572 Metetra
.656 .751 .919 r
.30354 .56572 .30921 .57082 .31807 .56806 .31242 .56294 Metetra
.656 .751 .919 r
.31242 .56294 .31807 .56806 .32695 .56529 .32132 .56015 Metetra
.656 .751 .919 r
.32132 .56015 .32695 .56529 .33587 .56251 .33026 .55736 Metetra
.656 .751 .919 r
.33026 .55736 .33587 .56251 .34482 .55972 .33922 .55455 Metetra
.656 .751 .919 r
.33922 .55455 .34482 .55972 .35379 .55692 .34822 .55173 Metetra
.656 .751 .919 r
.34822 .55173 .35379 .55692 .3628 .55412 .35724 .54891 Metetra
.656 .751 .919 r
.35724 .54891 .3628 .55412 .37183 .5513 .3663 .54608 Metetra
.656 .751 .919 r
.3663 .54608 .37183 .5513 .3809 .54847 .37538 .54323 Metetra
.656 .751 .919 r
.37538 .54323 .3809 .54847 .39 .54564 .3845 .54038 Metetra
.656 .751 .919 r
.3845 .54038 .39 .54564 .39913 .54279 .39365 .53752 Metetra
.656 .751 .919 r
.39365 .53752 .39913 .54279 .40829 .53994 .40283 .53464 Metetra
.656 .751 .919 r
.40283 .53464 .40829 .53994 .41748 .53707 .41204 .53176 Metetra
.656 .751 .919 r
.41204 .53176 .41748 .53707 .4267 .5342 .42128 .52887 Metetra
.656 .751 .919 r
.42128 .52887 .4267 .5342 .43596 .53132 .43056 .52596 Metetra
.656 .751 .919 r
.43056 .52596 .43596 .53132 .44525 .52842 .43986 .52305 Metetra
.656 .751 .919 r
.43986 .52305 .44525 .52842 .45456 .52552 .4492 .52013 Metetra
.656 .751 .919 r
.4492 .52013 .45456 .52552 .46391 .5226 .45857 .5172 Metetra
.656 .751 .919 r
.45857 .5172 .46391 .5226 .4733 .51968 .46798 .51425 Metetra
.656 .751 .919 r
.46798 .51425 .4733 .51968 .48271 .51674 .47741 .5113 Metetra
.656 .751 .919 r
.47741 .5113 .48271 .51674 .49216 .5138 .48688 .50834 Metetra
.656 .751 .919 r
.48688 .50834 .49216 .5138 .50164 .51084 .49638 .50536 Metetra
.656 .751 .919 r
.49638 .50536 .50164 .51084 .51115 .50788 .50592 .50238 Metetra
.656 .751 .919 r
.50592 .50238 .51115 .50788 .5207 .5049 .51549 .49938 Metetra
.656 .751 .919 r
.51549 .49938 .5207 .5049 .53028 .50192 .52509 .49638 Metetra
.656 .751 .919 r
.52509 .49638 .53028 .50192 .53989 .49892 .53472 .49336 Metetra
.656 .751 .919 r
.53472 .49336 .53989 .49892 .54954 .49592 .54439 .49034 Metetra
.656 .751 .919 r
.54439 .49034 .54954 .49592 .55922 .4929 .55409 .4873 Metetra
.656 .751 .919 r
.55409 .4873 .55922 .4929 .56894 .48987 .56383 .48425 Metetra
.656 .751 .919 r
.56383 .48425 .56894 .48987 .57868 .48683 .5736 .4812 Metetra
.656 .751 .919 r
.5736 .4812 .57868 .48683 .58847 .48378 .58341 .47813 Metetra
.656 .751 .919 r
.58341 .47813 .58847 .48378 .59828 .48072 .59325 .47505 Metetra
.656 .751 .919 r
.59325 .47505 .59828 .48072 .60814 .47765 .60313 .47196 Metetra
.656 .751 .919 r
.60313 .47196 .60814 .47765 .61802 .47457 .61304 .46885 Metetra
.656 .751 .919 r
.61304 .46885 .61802 .47457 .62795 .47148 .62298 .46574 Metetra
.656 .751 .919 r
.62298 .46574 .62795 .47148 .6379 .46838 .63296 .46262 Metetra
.656 .751 .919 r
.63296 .46262 .6379 .46838 .6479 .46526 .64298 .45948 Metetra
.656 .751 .919 r
.64298 .45948 .6479 .46526 .65793 .46214 .65303 .45634 Metetra
.656 .751 .919 r
.65303 .45634 .65793 .46214 .66799 .459 .66312 .45318 Metetra
.656 .751 .919 r
.66312 .45318 .66799 .459 .67809 .45585 .67325 .45001 Metetra
.656 .751 .919 r
.67325 .45001 .67809 .45585 .68823 .45269 .68341 .44683 Metetra
.656 .751 .919 r
.68341 .44683 .68823 .45269 .6984 .44952 .69361 .44364 Metetra
.656 .751 .919 r
.69361 .44364 .6984 .44952 .70861 .44634 .70384 .44043 Metetra
.656 .751 .919 r
.70384 .44043 .70861 .44634 .71886 .44314 .71412 .43722 Metetra
.656 .751 .919 r
.71412 .43722 .71886 .44314 .72914 .43994 .72443 .43399 Metetra
.656 .751 .919 r
.72443 .43399 .72914 .43994 .73946 .43672 .73477 .43075 Metetra
.656 .751 .919 r
.73477 .43075 .73946 .43672 .74982 .43349 .74516 .4275 Metetra
.656 .751 .919 r
.74516 .4275 .74982 .43349 .76022 .43025 .75558 .42424 Metetra
.656 .751 .919 r
.75558 .42424 .76022 .43025 .77065 .427 .76604 .42097 Metetra
.656 .751 .919 r
.76604 .42097 .77065 .427 .78112 .42374 .77654 .41768 Metetra
.656 .751 .919 r
.77654 .41768 .78112 .42374 .79163 .42046 .78708 .41438 Metetra
.656 .751 .919 r
.78708 .41438 .79163 .42046 .80218 .41718 .79765 .41107 Metetra
.656 .751 .919 r
.79765 .41107 .80218 .41718 .81277 .41388 .80827 .40775 Metetra
.656 .751 .919 r
.80827 .40775 .81277 .41388 .82339 .41056 .81892 .40442 Metetra
.656 .751 .919 r
.81892 .40442 .82339 .41056 .83406 .40724 .82962 .40107 Metetra
.656 .751 .919 r
.82962 .40107 .83406 .40724 .84476 .4039 .84035 .39771 Metetra
.656 .751 .919 r
.84035 .39771 .84476 .4039 .85551 .40056 .85112 .39434 Metetra
.656 .751 .919 r
.85112 .39434 .85551 .40056 .86629 .39719 .86193 .39096 Metetra
.656 .751 .919 r
.86193 .39096 .86629 .39719 .87712 .39382 .87279 .38756 Metetra
.656 .751 .919 r
.87279 .38756 .87712 .39382 .88798 .39043 .88368 .38415 Metetra
.509 .467 .746 r
.26292 .56715 .26794 .58212 .2771 .57399 .27134 .56891 Metetra
.656 .751 .919 r
.27134 .56891 .2771 .57399 .28589 .57124 .28015 .56614 Metetra
.656 .751 .919 r
.28015 .56614 .28589 .57124 .2947 .56848 .28898 .56337 Metetra
.656 .751 .919 r
.28898 .56337 .2947 .56848 .30354 .56572 .29784 .56058 Metetra
.656 .751 .919 r
.29784 .56058 .30354 .56572 .31242 .56294 .30673 .55779 Metetra
.656 .751 .919 r
.30673 .55779 .31242 .56294 .32132 .56015 .31566 .55498 Metetra
.656 .751 .919 r
.31566 .55498 .32132 .56015 .33026 .55736 .32461 .55217 Metetra
.656 .751 .919 r
.32461 .55217 .33026 .55736 .33922 .55455 .33359 .54935 Metetra
.656 .751 .919 r
.33359 .54935 .33922 .55455 .34822 .55173 .3426 .54651 Metetra
.656 .751 .919 r
.3426 .54651 .34822 .55173 .35724 .54891 .35165 .54367 Metetra
.656 .751 .919 r
.35165 .54367 .35724 .54891 .3663 .54608 .36072 .54082 Metetra
.656 .751 .919 r
.36072 .54082 .3663 .54608 .37538 .54323 .36983 .53796 Metetra
.656 .751 .919 r
.36983 .53796 .37538 .54323 .3845 .54038 .37896 .53509 Metetra
.656 .751 .919 r
.37896 .53509 .3845 .54038 .39365 .53752 .38813 .5322 Metetra
.656 .751 .919 r
.38813 .5322 .39365 .53752 .40283 .53464 .39733 .52931 Metetra
.656 .751 .919 r
.39733 .52931 .40283 .53464 .41204 .53176 .40656 .52641 Metetra
.656 .751 .919 r
.40656 .52641 .41204 .53176 .42128 .52887 .41583 .5235 Metetra
.656 .751 .919 r
.41583 .5235 .42128 .52887 .43056 .52596 .42512 .52058 Metetra
.656 .751 .919 r
.42512 .52058 .43056 .52596 .43986 .52305 .43445 .51765 Metetra
.656 .751 .919 r
.43445 .51765 .43986 .52305 .4492 .52013 .44381 .51471 Metetra
.656 .751 .919 r
.44381 .51471 .4492 .52013 .45857 .5172 .4532 .51175 Metetra
.656 .751 .919 r
.4532 .51175 .45857 .5172 .46798 .51425 .46262 .50879 Metetra
.656 .751 .919 r
.46262 .50879 .46798 .51425 .47741 .5113 .47208 .50582 Metetra
.656 .751 .919 r
.47208 .50582 .47741 .5113 .48688 .50834 .48157 .50284 Metetra
.656 .751 .919 r
.48157 .50284 .48688 .50834 .49638 .50536 .49109 .49985 Metetra
.656 .751 .919 r
.49109 .49985 .49638 .50536 .50592 .50238 .50065 .49684 Metetra
.656 .751 .919 r
.50065 .49684 .50592 .50238 .51549 .49938 .51024 .49383 Metetra
.656 .751 .919 r
.51024 .49383 .51549 .49938 .52509 .49638 .51986 .4908 Metetra
.656 .751 .919 r
.51986 .4908 .52509 .49638 .53472 .49336 .52952 .48777 Metetra
.656 .751 .919 r
.52952 .48777 .53472 .49336 .54439 .49034 .53921 .48472 Metetra
.656 .751 .919 r
.53921 .48472 .54439 .49034 .55409 .4873 .54894 .48167 Metetra
.656 .751 .919 r
.54894 .48167 .55409 .4873 .56383 .48425 .5587 .4786 Metetra
.656 .751 .919 r
.5587 .4786 .56383 .48425 .5736 .4812 .56849 .47552 Metetra
.656 .751 .919 r
.56849 .47552 .5736 .4812 .58341 .47813 .57832 .47243 Metetra
.656 .751 .919 r
.57832 .47243 .58341 .47813 .59325 .47505 .58818 .46933 Metetra
.656 .751 .919 r
.58818 .46933 .59325 .47505 .60313 .47196 .59808 .46622 Metetra
.656 .751 .919 r
.59808 .46622 .60313 .47196 .61304 .46885 .60802 .4631 Metetra
.656 .751 .919 r
.60802 .4631 .61304 .46885 .62298 .46574 .61799 .45996 Metetra
.656 .751 .919 r
.61799 .45996 .62298 .46574 .63296 .46262 .62799 .45682 Metetra
.656 .751 .919 r
.62799 .45682 .63296 .46262 .64298 .45948 .63803 .45366 Metetra
.656 .751 .919 r
.63803 .45366 .64298 .45948 .65303 .45634 .64811 .4505 Metetra
.656 .751 .919 r
.64811 .4505 .65303 .45634 .66312 .45318 .65822 .44732 Metetra
.656 .751 .919 r
.65822 .44732 .66312 .45318 .67325 .45001 .66838 .44413 Metetra
.656 .751 .919 r
.66838 .44413 .67325 .45001 .68341 .44683 .67856 .44093 Metetra
.656 .751 .919 r
.67856 .44093 .68341 .44683 .69361 .44364 .68879 .43771 Metetra
.656 .751 .919 r
.68879 .43771 .69361 .44364 .70384 .44043 .69905 .43449 Metetra
.656 .751 .919 r
.69905 .43449 .70384 .44043 .71412 .43722 .70934 .43125 Metetra
.656 .751 .919 r
.70934 .43125 .71412 .43722 .72443 .43399 .71968 .428 Metetra
.656 .751 .919 r
.71968 .428 .72443 .43399 .73477 .43075 .73005 .42474 Metetra
.656 .751 .919 r
.73005 .42474 .73477 .43075 .74516 .4275 .74046 .42147 Metetra
.656 .751 .919 r
.74046 .42147 .74516 .4275 .75558 .42424 .75091 .41819 Metetra
.656 .751 .919 r
.75091 .41819 .75558 .42424 .76604 .42097 .7614 .41489 Metetra
.656 .751 .919 r
.7614 .41489 .76604 .42097 .77654 .41768 .77193 .41158 Metetra
.656 .751 .919 r
.77193 .41158 .77654 .41768 .78708 .41438 .78249 .40826 Metetra
.656 .751 .919 r
.78249 .40826 .78708 .41438 .79765 .41107 .79309 .40493 Metetra
.656 .751 .919 r
.79309 .40493 .79765 .41107 .80827 .40775 .80374 .40159 Metetra
.656 .751 .919 r
.80374 .40159 .80827 .40775 .81892 .40442 .81442 .39823 Metetra
.656 .751 .919 r
.81442 .39823 .81892 .40442 .82962 .40107 .82514 .39486 Metetra
.656 .751 .919 r
.82514 .39486 .82962 .40107 .84035 .39771 .8359 .39148 Metetra
.656 .751 .919 r
.8359 .39148 .84035 .39771 .85112 .39434 .8467 .38808 Metetra
.656 .751 .919 r
.8467 .38808 .85112 .39434 .86193 .39096 .85754 .38468 Metetra
.656 .751 .919 r
.85754 .38468 .86193 .39096 .87279 .38756 .86843 .38126 Metetra
.656 .751 .919 r
.86843 .38126 .87279 .38756 .88368 .38415 .87935 .37782 Metetra
.566 .935 .907 r
.25665 .56793 .26292 .56715 .27134 .56891 .26555 .56379 Metetra
.656 .751 .919 r
.26555 .56379 .27134 .56891 .28015 .56614 .27437 .56101 Metetra
.656 .751 .919 r
.27437 .56101 .28015 .56614 .28898 .56337 .28322 .55822 Metetra
.656 .751 .919 r
.28322 .55822 .28898 .56337 .29784 .56058 .2921 .55541 Metetra
.656 .751 .919 r
.2921 .55541 .29784 .56058 .30673 .55779 .30101 .5526 Metetra
.656 .751 .919 r
.30101 .5526 .30673 .55779 .31566 .55498 .30995 .54978 Metetra
.656 .751 .919 r
.30995 .54978 .31566 .55498 .32461 .55217 .31892 .54695 Metetra
.656 .751 .919 r
.31892 .54695 .32461 .55217 .33359 .54935 .32792 .54411 Metetra
.656 .751 .919 r
.32792 .54411 .33359 .54935 .3426 .54651 .33696 .54126 Metetra
.656 .751 .919 r
.33696 .54126 .3426 .54651 .35165 .54367 .34602 .5384 Metetra
.656 .751 .919 r
.34602 .5384 .35165 .54367 .36072 .54082 .35511 .53553 Metetra
.656 .751 .919 r
.35511 .53553 .36072 .54082 .36983 .53796 .36424 .53265 Metetra
.656 .751 .919 r
.36424 .53265 .36983 .53796 .37896 .53509 .37339 .52976 Metetra
.656 .751 .919 r
.37339 .52976 .37896 .53509 .38813 .5322 .38258 .52686 Metetra
.656 .751 .919 r
.38258 .52686 .38813 .5322 .39733 .52931 .3918 .52395 Metetra
.656 .751 .919 r
.3918 .52395 .39733 .52931 .40656 .52641 .40105 .52103 Metetra
.656 .751 .919 r
.40105 .52103 .40656 .52641 .41583 .5235 .41033 .5181 Metetra
.656 .751 .919 r
.41033 .5181 .41583 .5235 .42512 .52058 .41965 .51516 Metetra
.656 .751 .919 r
.41965 .51516 .42512 .52058 .43445 .51765 .429 .51221 Metetra
.656 .751 .919 r
.429 .51221 .43445 .51765 .44381 .51471 .43838 .50925 Metetra
.656 .751 .919 r
.43838 .50925 .44381 .51471 .4532 .51175 .44779 .50628 Metetra
.656 .751 .919 r
.44779 .50628 .4532 .51175 .46262 .50879 .45723 .5033 Metetra
.656 .751 .919 r
.45723 .5033 .46262 .50879 .47208 .50582 .46671 .50031 Metetra
.656 .751 .919 r
.46671 .50031 .47208 .50582 .48157 .50284 .47622 .4973 Metetra
.656 .751 .919 r
.47622 .4973 .48157 .50284 .49109 .49985 .48577 .49429 Metetra
.656 .751 .919 r
.48577 .49429 .49109 .49985 .50065 .49684 .49534 .49127 Metetra
.656 .751 .919 r
.49534 .49127 .50065 .49684 .51024 .49383 .50496 .48824 Metetra
.656 .751 .919 r
.50496 .48824 .51024 .49383 .51986 .4908 .5146 .48519 Metetra
.656 .751 .919 r
.5146 .48519 .51986 .4908 .52952 .48777 .52428 .48214 Metetra
.656 .751 .919 r
.52428 .48214 .52952 .48777 .53921 .48472 .53399 .47907 Metetra
.656 .751 .919 r
.53399 .47907 .53921 .48472 .54894 .48167 .54374 .47599 Metetra
.656 .751 .919 r
.54374 .47599 .54894 .48167 .5587 .4786 .55353 .47291 Metetra
.656 .751 .919 r
.55353 .47291 .5587 .4786 .56849 .47552 .56334 .46981 Metetra
.656 .751 .919 r
.56334 .46981 .56849 .47552 .57832 .47243 .57319 .4667 Metetra
.656 .751 .919 r
.57319 .4667 .57832 .47243 .58818 .46933 .58308 .46358 Metetra
.656 .751 .919 r
.58308 .46358 .58818 .46933 .59808 .46622 .593 .46045 Metetra
.656 .751 .919 r
.593 .46045 .59808 .46622 .60802 .4631 .60296 .4573 Metetra
.656 .751 .919 r
.60296 .4573 .60802 .4631 .61799 .45996 .61296 .45415 Metetra
.656 .751 .919 r
.61296 .45415 .61799 .45996 .62799 .45682 .62299 .45099 Metetra
.656 .751 .919 r
.62299 .45099 .62799 .45682 .63803 .45366 .63305 .44781 Metetra
.656 .751 .919 r
.63305 .44781 .63803 .45366 .64811 .4505 .64315 .44462 Metetra
.656 .751 .919 r
.64315 .44462 .64811 .4505 .65822 .44732 .65329 .44142 Metetra
.656 .751 .919 r
.65329 .44142 .65822 .44732 .66838 .44413 .66347 .43821 Metetra
.656 .751 .919 r
.66347 .43821 .66838 .44413 .67856 .44093 .67368 .43499 Metetra
.656 .751 .919 r
.67368 .43499 .67856 .44093 .68879 .43771 .68393 .43175 Metetra
.656 .751 .919 r
.68393 .43175 .68879 .43771 .69905 .43449 .69422 .4285 Metetra
.656 .751 .919 r
.69422 .4285 .69905 .43449 .70934 .43125 .70454 .42525 Metetra
.656 .751 .919 r
.70454 .42525 .70934 .43125 .71968 .428 .7149 .42198 Metetra
.656 .751 .919 r
.7149 .42198 .71968 .428 .73005 .42474 .7253 .41869 Metetra
.656 .751 .919 r
.7253 .41869 .73005 .42474 .74046 .42147 .73574 .4154 Metetra
.656 .751 .919 r
.73574 .4154 .74046 .42147 .75091 .41819 .74621 .41209 Metetra
.656 .751 .919 r
.74621 .41209 .75091 .41819 .7614 .41489 .75673 .40878 Metetra
.656 .751 .919 r
.75673 .40878 .7614 .41489 .77193 .41158 .76728 .40545 Metetra
.656 .751 .919 r
.76728 .40545 .77193 .41158 .78249 .40826 .77787 .4021 Metetra
.656 .751 .919 r
.77787 .4021 .78249 .40826 .79309 .40493 .7885 .39875 Metetra
.656 .751 .919 r
.7885 .39875 .79309 .40493 .80374 .40159 .79917 .39538 Metetra
.656 .751 .919 r
.79917 .39538 .80374 .40159 .81442 .39823 .80988 .392 Metetra
.656 .751 .919 r
.80988 .392 .81442 .39823 .82514 .39486 .82063 .38861 Metetra
.656 .751 .919 r
.82063 .38861 .82514 .39486 .8359 .39148 .83142 .3852 Metetra
.656 .751 .919 r
.83142 .3852 .8359 .39148 .8467 .38808 .84225 .38178 Metetra
.656 .751 .919 r
.84225 .38178 .8467 .38808 .85754 .38468 .85312 .37835 Metetra
.656 .751 .919 r
.85312 .37835 .85754 .38468 .86843 .38126 .86404 .37491 Metetra
.656 .751 .919 r
.86404 .37491 .86843 .38126 .87935 .37782 .87499 .37145 Metetra
.705 .756 .892 r
.25081 .56268 .25665 .56793 .26555 .56379 .25972 .55865 Metetra
.656 .751 .919 r
.25972 .55865 .26555 .56379 .27437 .56101 .26856 .55585 Metetra
.656 .751 .919 r
.26856 .55585 .27437 .56101 .28322 .55822 .27743 .55304 Metetra
.656 .751 .919 r
.27743 .55304 .28322 .55822 .2921 .55541 .28633 .55022 Metetra
.656 .751 .919 r
.28633 .55022 .2921 .55541 .30101 .5526 .29526 .54739 Metetra
.656 .751 .919 r
.29526 .54739 .30101 .5526 .30995 .54978 .30421 .54455 Metetra
.656 .751 .919 r
.30421 .54455 .30995 .54978 .31892 .54695 .3132 .5417 Metetra
.656 .751 .919 r
.3132 .5417 .31892 .54695 .32792 .54411 .32222 .53884 Metetra
.656 .751 .919 r
.32222 .53884 .32792 .54411 .33696 .54126 .33127 .53597 Metetra
.656 .751 .919 r
.33127 .53597 .33696 .54126 .34602 .5384 .34035 .53309 Metetra
.656 .751 .919 r
.34035 .53309 .34602 .5384 .35511 .53553 .34947 .5302 Metetra
.656 .751 .919 r
.34947 .5302 .35511 .53553 .36424 .53265 .35861 .52731 Metetra
.656 .751 .919 r
.35861 .52731 .36424 .53265 .37339 .52976 .36779 .5244 Metetra
.656 .751 .919 r
.36779 .5244 .37339 .52976 .38258 .52686 .37699 .52148 Metetra
.656 .751 .919 r
.37699 .52148 .38258 .52686 .3918 .52395 .38623 .51855 Metetra
.656 .751 .919 r
.38623 .51855 .3918 .52395 .40105 .52103 .3955 .51561 Metetra
.656 .751 .919 r
.3955 .51561 .40105 .52103 .41033 .5181 .40481 .51266 Metetra
.656 .751 .919 r
.40481 .51266 .41033 .5181 .41965 .51516 .41414 .50971 Metetra
.656 .751 .919 r
.41414 .50971 .41965 .51516 .429 .51221 .42351 .50674 Metetra
.656 .751 .919 r
.42351 .50674 .429 .51221 .43838 .50925 .43291 .50376 Metetra
.656 .751 .919 r
.43291 .50376 .43838 .50925 .44779 .50628 .44234 .50077 Metetra
.656 .751 .919 r
.44234 .50077 .44779 .50628 .45723 .5033 .45181 .49777 Metetra
.656 .751 .919 r
.45181 .49777 .45723 .5033 .46671 .50031 .46131 .49476 Metetra
.656 .751 .919 r
.46131 .49476 .46671 .50031 .47622 .4973 .47084 .49174 Metetra
.656 .751 .919 r
.47084 .49174 .47622 .4973 .48577 .49429 .48041 .4887 Metetra
.656 .751 .919 r
.48041 .4887 .48577 .49429 .49534 .49127 .49001 .48566 Metetra
.656 .751 .919 r
.49001 .48566 .49534 .49127 .50496 .48824 .49964 .48261 Metetra
.656 .751 .919 r
.49964 .48261 .50496 .48824 .5146 .48519 .50931 .47954 Metetra
.656 .751 .919 r
.50931 .47954 .5146 .48519 .52428 .48214 .51901 .47647 Metetra
.656 .751 .919 r
.51901 .47647 .52428 .48214 .53399 .47907 .52874 .47338 Metetra
.656 .751 .919 r
.52874 .47338 .53399 .47907 .54374 .47599 .53852 .47029 Metetra
.656 .751 .919 r
.53852 .47029 .54374 .47599 .55353 .47291 .54832 .46718 Metetra
.656 .751 .919 r
.54832 .46718 .55353 .47291 .56334 .46981 .55816 .46406 Metetra
.656 .751 .919 r
.55816 .46406 .56334 .46981 .57319 .4667 .56804 .46093 Metetra
.656 .751 .919 r
.56804 .46093 .57319 .4667 .58308 .46358 .57795 .45779 Metetra
.656 .751 .919 r
.57795 .45779 .58308 .46358 .593 .46045 .58789 .45464 Metetra
.656 .751 .919 r
.58789 .45464 .593 .46045 .60296 .4573 .59788 .45147 Metetra
.656 .751 .919 r
.59788 .45147 .60296 .4573 .61296 .45415 .60789 .4483 Metetra
.656 .751 .919 r
.60789 .4483 .61296 .45415 .62299 .45099 .61795 .44511 Metetra
.656 .751 .919 r
.61795 .44511 .62299 .45099 .63305 .44781 .62804 .44191 Metetra
.656 .751 .919 r
.62804 .44191 .63305 .44781 .64315 .44462 .63816 .4387 Metetra
.656 .751 .919 r
.63816 .4387 .64315 .44462 .65329 .44142 .64833 .43548 Metetra
.656 .751 .919 r
.64833 .43548 .65329 .44142 .66347 .43821 .65853 .43225 Metetra
.656 .751 .919 r
.65853 .43225 .66347 .43821 .67368 .43499 .66877 .42901 Metetra
.656 .751 .919 r
.66877 .42901 .67368 .43499 .68393 .43175 .67904 .42575 Metetra
.656 .751 .919 r
.67904 .42575 .68393 .43175 .69422 .4285 .68935 .42248 Metetra
.656 .751 .919 r
.68935 .42248 .69422 .4285 .70454 .42525 .6997 .4192 Metetra
.656 .751 .919 r
.6997 .4192 .70454 .42525 .7149 .42198 .71009 .41591 Metetra
.656 .751 .919 r
.71009 .41591 .7149 .42198 .7253 .41869 .72052 .4126 Metetra
.656 .751 .919 r
.72052 .4126 .7253 .41869 .73574 .4154 .73098 .40929 Metetra
.656 .751 .919 r
.73098 .40929 .73574 .4154 .74621 .41209 .74148 .40596 Metetra
.656 .751 .919 r
.74148 .40596 .74621 .41209 .75673 .40878 .75202 .40262 Metetra
.656 .751 .919 r
.75202 .40262 .75673 .40878 .76728 .40545 .7626 .39926 Metetra
.656 .751 .919 r
.7626 .39926 .76728 .40545 .77787 .4021 .77322 .3959 Metetra
.656 .751 .919 r
.77322 .3959 .77787 .4021 .7885 .39875 .78388 .39252 Metetra
.656 .751 .919 r
.78388 .39252 .7885 .39875 .79917 .39538 .79458 .38913 Metetra
.656 .751 .919 r
.79458 .38913 .79917 .39538 .80988 .392 .80532 .38573 Metetra
.656 .751 .919 r
.80532 .38573 .80988 .392 .82063 .38861 .8161 .38231 Metetra
.656 .751 .919 r
.8161 .38231 .82063 .38861 .83142 .3852 .82692 .37888 Metetra
.656 .751 .919 r
.82692 .37888 .83142 .3852 .84225 .38178 .83777 .37544 Metetra
.656 .751 .919 r
.83777 .37544 .84225 .38178 .85312 .37835 .84867 .37198 Metetra
.656 .751 .919 r
.84867 .37198 .85312 .37835 .86404 .37491 .85962 .36852 Metetra
.656 .751 .919 r
.85962 .36852 .86404 .37491 .87499 .37145 .8706 .36504 Metetra
.586 .631 .863 r
.24517 .55457 .25081 .56268 .25972 .55865 .25386 .55347 Metetra
.656 .751 .919 r
.25386 .55347 .25972 .55865 .26856 .55585 .26271 .55065 Metetra
.656 .751 .919 r
.26271 .55065 .26856 .55585 .27743 .55304 .2716 .54782 Metetra
.656 .751 .919 r
.2716 .54782 .27743 .55304 .28633 .55022 .28052 .54498 Metetra
.656 .751 .919 r
.28052 .54498 .28633 .55022 .29526 .54739 .28946 .54214 Metetra
.656 .751 .919 r
.28946 .54214 .29526 .54739 .30421 .54455 .29844 .53928 Metetra
.656 .751 .919 r
.29844 .53928 .30421 .54455 .3132 .5417 .30745 .53641 Metetra
.656 .751 .919 r
.30745 .53641 .3132 .5417 .32222 .53884 .31649 .53354 Metetra
.656 .751 .919 r
.31649 .53354 .32222 .53884 .33127 .53597 .32555 .53065 Metetra
.656 .751 .919 r
.32555 .53065 .33127 .53597 .34035 .53309 .33466 .52775 Metetra
.656 .751 .919 r
.33466 .52775 .34035 .53309 .34947 .5302 .34379 .52485 Metetra
.656 .751 .919 r
.34379 .52485 .34947 .5302 .35861 .52731 .35295 .52193 Metetra
.656 .751 .919 r
.35295 .52193 .35861 .52731 .36779 .5244 .36215 .519 Metetra
.656 .751 .919 r
.36215 .519 .36779 .5244 .37699 .52148 .37137 .51607 Metetra
.656 .751 .919 r
.37137 .51607 .37699 .52148 .38623 .51855 .38063 .51312 Metetra
.656 .751 .919 r
.38063 .51312 .38623 .51855 .3955 .51561 .38992 .51016 Metetra
.656 .751 .919 r
.38992 .51016 .3955 .51561 .40481 .51266 .39924 .50719 Metetra
.656 .751 .919 r
.39924 .50719 .40481 .51266 .41414 .50971 .4086 .50422 Metetra
.656 .751 .919 r
.4086 .50422 .41414 .50971 .42351 .50674 .41799 .50123 Metetra
.656 .751 .919 r
.41799 .50123 .42351 .50674 .43291 .50376 .42741 .49823 Metetra
.656 .751 .919 r
.42741 .49823 .43291 .50376 .44234 .50077 .43686 .49522 Metetra
.656 .751 .919 r
.43686 .49522 .44234 .50077 .45181 .49777 .44635 .4922 Metetra
.656 .751 .919 r
.44635 .4922 .45181 .49777 .46131 .49476 .45587 .48917 Metetra
.656 .751 .919 r
.45587 .48917 .46131 .49476 .47084 .49174 .46542 .48613 Metetra
.656 .751 .919 r
.46542 .48613 .47084 .49174 .48041 .4887 .47501 .48308 Metetra
.656 .751 .919 r
.47501 .48308 .48041 .4887 .49001 .48566 .48463 .48002 Metetra
.656 .751 .919 r
.48463 .48002 .49001 .48566 .49964 .48261 .49429 .47694 Metetra
.656 .751 .919 r
.49429 .47694 .49964 .48261 .50931 .47954 .50398 .47386 Metetra
.656 .751 .919 r
.50398 .47386 .50931 .47954 .51901 .47647 .5137 .47076 Metetra
.656 .751 .919 r
.5137 .47076 .51901 .47647 .52874 .47338 .52346 .46766 Metetra
.656 .751 .919 r
.52346 .46766 .52874 .47338 .53852 .47029 .53325 .46454 Metetra
.656 .751 .919 r
.53325 .46454 .53852 .47029 .54832 .46718 .54308 .46141 Metetra
.656 .751 .919 r
.54308 .46141 .54832 .46718 .55816 .46406 .55295 .45827 Metetra
.656 .751 .919 r
.55295 .45827 .55816 .46406 .56804 .46093 .56284 .45512 Metetra
.656 .751 .919 r
.56284 .45512 .56804 .46093 .57795 .45779 .57278 .45196 Metetra
.656 .751 .919 r
.57278 .45196 .57795 .45779 .58789 .45464 .58275 .44879 Metetra
.656 .751 .919 r
.58275 .44879 .58789 .45464 .59788 .45147 .59276 .4456 Metetra
.656 .751 .919 r
.59276 .4456 .59788 .45147 .60789 .4483 .6028 .44241 Metetra
.656 .751 .919 r
.6028 .44241 .60789 .4483 .61795 .44511 .61288 .4392 Metetra
.656 .751 .919 r
.61288 .4392 .61795 .44511 .62804 .44191 .62299 .43598 Metetra
.656 .751 .919 r
.62299 .43598 .62804 .44191 .63816 .4387 .63314 .43275 Metetra
.656 .751 .919 r
.63314 .43275 .63816 .4387 .64833 .43548 .64333 .4295 Metetra
.656 .751 .919 r
.64333 .4295 .64833 .43548 .65853 .43225 .65356 .42625 Metetra
.656 .751 .919 r
.65356 .42625 .65853 .43225 .66877 .42901 .66382 .42298 Metetra
.656 .751 .919 r
.66382 .42298 .66877 .42901 .67904 .42575 .67412 .41971 Metetra
.656 .751 .919 r
.67412 .41971 .67904 .42575 .68935 .42248 .68446 .41642 Metetra
.656 .751 .919 r
.68446 .41642 .68935 .42248 .6997 .4192 .69483 .41311 Metetra
.656 .751 .919 r
.69483 .41311 .6997 .4192 .71009 .41591 .70525 .4098 Metetra
.656 .751 .919 r
.70525 .4098 .71009 .41591 .72052 .4126 .7157 .40647 Metetra
.656 .751 .919 r
.7157 .40647 .72052 .4126 .73098 .40929 .72619 .40313 Metetra
.656 .751 .919 r
.72619 .40313 .73098 .40929 .74148 .40596 .73672 .39978 Metetra
.656 .751 .919 r
.73672 .39978 .74148 .40596 .75202 .40262 .74729 .39642 Metetra
.656 .751 .919 r
.74729 .39642 .75202 .40262 .7626 .39926 .75789 .39304 Metetra
.656 .751 .919 r
.75789 .39304 .7626 .39926 .77322 .3959 .76854 .38965 Metetra
.656 .751 .919 r
.76854 .38965 .77322 .3959 .78388 .39252 .77923 .38625 Metetra
.656 .751 .919 r
.77923 .38625 .78388 .39252 .79458 .38913 .78996 .38284 Metetra
.656 .751 .919 r
.78996 .38284 .79458 .38913 .80532 .38573 .80072 .37941 Metetra
.656 .751 .919 r
.80072 .37941 .80532 .38573 .8161 .38231 .81153 .37597 Metetra
.656 .751 .919 r
.81153 .37597 .8161 .38231 .82692 .37888 .82238 .37252 Metetra
.656 .751 .919 r
.82238 .37252 .82692 .37888 .83777 .37544 .83326 .36905 Metetra
.656 .751 .919 r
.83326 .36905 .83777 .37544 .84867 .37198 .84419 .36557 Metetra
.656 .751 .919 r
.84419 .36557 .84867 .37198 .85962 .36852 .85516 .36208 Metetra
.656 .751 .919 r
.85516 .36208 .85962 .36852 .8706 .36504 .86618 .35858 Metetra
.676 .855 .968 r
.23906 .55177 .24517 .55457 .25386 .55347 .24796 .54826 Metetra
.656 .751 .919 r
.24796 .54826 .25386 .55347 .26271 .55065 .25683 .54542 Metetra
.656 .751 .919 r
.25683 .54542 .26271 .55065 .2716 .54782 .26573 .54257 Metetra
.656 .751 .919 r
.26573 .54257 .2716 .54782 .28052 .54498 .27467 .53972 Metetra
.656 .751 .919 r
.27467 .53972 .28052 .54498 .28946 .54214 .28363 .53685 Metetra
.656 .751 .919 r
.28363 .53685 .28946 .54214 .29844 .53928 .29263 .53398 Metetra
.656 .751 .919 r
.29263 .53398 .29844 .53928 .30745 .53641 .30165 .53109 Metetra
.656 .751 .919 r
.30165 .53109 .30745 .53641 .31649 .53354 .31071 .5282 Metetra
.656 .751 .919 r
.31071 .5282 .31649 .53354 .32555 .53065 .3198 .52529 Metetra
.656 .751 .919 r
.3198 .52529 .32555 .53065 .33466 .52775 .32892 .52238 Metetra
.656 .751 .919 r
.32892 .52238 .33466 .52775 .34379 .52485 .33807 .51945 Metetra
.656 .751 .919 r
.33807 .51945 .34379 .52485 .35295 .52193 .34725 .51652 Metetra
.656 .751 .919 r
.34725 .51652 .35295 .52193 .36215 .519 .35647 .51357 Metetra
.656 .751 .919 r
.35647 .51357 .36215 .519 .37137 .51607 .36571 .51062 Metetra
.656 .751 .919 r
.36571 .51062 .37137 .51607 .38063 .51312 .37499 .50765 Metetra
.656 .751 .919 r
.37499 .50765 .38063 .51312 .38992 .51016 .3843 .50468 Metetra
.656 .751 .919 r
.3843 .50468 .38992 .51016 .39924 .50719 .39365 .50169 Metetra
.656 .751 .919 r
.39365 .50169 .39924 .50719 .4086 .50422 .40302 .49869 Metetra
.656 .751 .919 r
.40302 .49869 .4086 .50422 .41799 .50123 .41243 .49568 Metetra
.656 .751 .919 r
.41243 .49568 .41799 .50123 .42741 .49823 .42187 .49267 Metetra
.656 .751 .919 r
.42187 .49267 .42741 .49823 .43686 .49522 .43135 .48964 Metetra
.656 .751 .919 r
.43135 .48964 .43686 .49522 .44635 .4922 .44086 .4866 Metetra
.656 .751 .919 r
.44086 .4866 .44635 .4922 .45587 .48917 .4504 .48355 Metetra
.656 .751 .919 r
.4504 .48355 .45587 .48917 .46542 .48613 .45997 .48049 Metetra
.656 .751 .919 r
.45997 .48049 .46542 .48613 .47501 .48308 .46958 .47742 Metetra
.656 .751 .919 r
.46958 .47742 .47501 .48308 .48463 .48002 .47922 .47433 Metetra
.656 .751 .919 r
.47922 .47433 .48463 .48002 .49429 .47694 .4889 .47124 Metetra
.656 .751 .919 r
.4889 .47124 .49429 .47694 .50398 .47386 .49861 .46814 Metetra
.656 .751 .919 r
.49861 .46814 .50398 .47386 .5137 .47076 .50836 .46502 Metetra
.656 .751 .919 r
.50836 .46502 .5137 .47076 .52346 .46766 .51814 .46189 Metetra
.656 .751 .919 r
.51814 .46189 .52346 .46766 .53325 .46454 .52796 .45876 Metetra
.656 .751 .919 r
.52796 .45876 .53325 .46454 .54308 .46141 .53781 .45561 Metetra
.656 .751 .919 r
.53781 .45561 .54308 .46141 .55295 .45827 .5477 .45245 Metetra
.656 .751 .919 r
.5477 .45245 .55295 .45827 .56284 .45512 .55762 .44928 Metetra
.656 .751 .919 r
.55762 .44928 .56284 .45512 .57278 .45196 .56758 .44609 Metetra
.656 .751 .919 r
.56758 .44609 .57278 .45196 .58275 .44879 .57757 .4429 Metetra
.656 .751 .919 r
.57757 .4429 .58275 .44879 .59276 .4456 .5876 .43969 Metetra
.656 .751 .919 r
.5876 .43969 .59276 .4456 .6028 .44241 .59767 .43647 Metetra
.656 .751 .919 r
.59767 .43647 .6028 .44241 .61288 .4392 .60777 .43325 Metetra
.656 .751 .919 r
.60777 .43325 .61288 .4392 .62299 .43598 .61791 .43 Metetra
.656 .751 .919 r
.61791 .43 .62299 .43598 .63314 .43275 .62808 .42675 Metetra
.656 .751 .919 r
.62808 .42675 .63314 .43275 .64333 .4295 .6383 .42349 Metetra
.656 .751 .919 r
.6383 .42349 .64333 .4295 .65356 .42625 .64855 .42021 Metetra
.656 .751 .919 r
.64855 .42021 .65356 .42625 .66382 .42298 .65884 .41692 Metetra
.656 .751 .919 r
.65884 .41692 .66382 .42298 .67412 .41971 .66916 .41362 Metetra
.656 .751 .919 r
.66916 .41362 .67412 .41971 .68446 .41642 .67953 .41031 Metetra
.656 .751 .919 r
.67953 .41031 .68446 .41642 .69483 .41311 .68993 .40698 Metetra
.656 .751 .919 r
.68993 .40698 .69483 .41311 .70525 .4098 .70037 .40365 Metetra
.656 .751 .919 r
.70037 .40365 .70525 .4098 .7157 .40647 .71085 .4003 Metetra
.656 .751 .919 r
.71085 .4003 .7157 .40647 .72619 .40313 .72137 .39694 Metetra
.656 .751 .919 r
.72137 .39694 .72619 .40313 .73672 .39978 .73192 .39356 Metetra
.656 .751 .919 r
.73192 .39356 .73672 .39978 .74729 .39642 .74252 .39017 Metetra
.656 .751 .919 r
.74252 .39017 .74729 .39642 .75789 .39304 .75315 .38677 Metetra
.656 .751 .919 r
.75315 .38677 .75789 .39304 .76854 .38965 .76383 .38336 Metetra
.656 .751 .919 r
.76383 .38336 .76854 .38965 .77923 .38625 .77454 .37994 Metetra
.656 .751 .919 r
.77454 .37994 .77923 .38625 .78996 .38284 .7853 .3765 Metetra
.656 .751 .919 r
.7853 .3765 .78996 .38284 .80072 .37941 .79609 .37305 Metetra
.656 .751 .919 r
.79609 .37305 .80072 .37941 .81153 .37597 .80693 .36959 Metetra
.656 .751 .919 r
.80693 .36959 .81153 .37597 .82238 .37252 .81781 .36611 Metetra
.656 .751 .919 r
.81781 .36611 .82238 .37252 .83326 .36905 .82872 .36262 Metetra
.656 .751 .919 r
.82872 .36262 .83326 .36905 .84419 .36557 .83968 .35912 Metetra
.656 .751 .919 r
.83968 .35912 .84419 .36557 .85516 .36208 .85068 .3556 Metetra
.656 .751 .919 r
.85068 .3556 .85516 .36208 .86618 .35858 .86172 .35207 Metetra
.657 .726 .9 r
.23316 .54586 .23906 .55177 .24796 .54826 .24202 .54301 Metetra
.656 .751 .919 r
.24202 .54301 .24796 .54826 .25683 .54542 .25091 .54016 Metetra
.656 .751 .919 r
.25091 .54016 .25683 .54542 .26573 .54257 .25983 .5373 Metetra
.656 .751 .919 r
.25983 .5373 .26573 .54257 .27467 .53972 .26878 .53442 Metetra
.656 .751 .919 r
.26878 .53442 .27467 .53972 .28363 .53685 .27777 .53154 Metetra
.656 .751 .919 r
.27777 .53154 .28363 .53685 .29263 .53398 .28678 .52864 Metetra
.656 .751 .919 r
.28678 .52864 .29263 .53398 .30165 .53109 .29583 .52574 Metetra
.656 .751 .919 r
.29583 .52574 .30165 .53109 .31071 .5282 .3049 .52283 Metetra
.656 .751 .919 r
.3049 .52283 .31071 .5282 .3198 .52529 .31401 .5199 Metetra
.656 .751 .919 r
.31401 .5199 .3198 .52529 .32892 .52238 .32315 .51697 Metetra
.656 .751 .919 r
.32315 .51697 .32892 .52238 .33807 .51945 .33232 .51403 Metetra
.656 .751 .919 r
.33232 .51403 .33807 .51945 .34725 .51652 .34152 .51107 Metetra
.656 .751 .919 r
.34152 .51107 .34725 .51652 .35647 .51357 .35075 .50811 Metetra
.656 .751 .919 r
.35075 .50811 .35647 .51357 .36571 .51062 .36002 .50513 Metetra
.656 .751 .919 r
.36002 .50513 .36571 .51062 .37499 .50765 .36932 .50215 Metetra
.656 .751 .919 r
.36932 .50215 .37499 .50765 .3843 .50468 .37865 .49915 Metetra
.656 .751 .919 r
.37865 .49915 .3843 .50468 .39365 .50169 .38801 .49615 Metetra
.656 .751 .919 r
.38801 .49615 .39365 .50169 .40302 .49869 .39741 .49313 Metetra
.656 .751 .919 r
.39741 .49313 .40302 .49869 .41243 .49568 .40684 .4901 Metetra
.656 .751 .919 r
.40684 .4901 .41243 .49568 .42187 .49267 .4163 .48707 Metetra
.656 .751 .919 r
.4163 .48707 .42187 .49267 .43135 .48964 .4258 .48402 Metetra
.656 .751 .919 r
.4258 .48402 .43135 .48964 .44086 .4866 .43533 .48096 Metetra
.656 .751 .919 r
.43533 .48096 .44086 .4866 .4504 .48355 .44489 .47789 Metetra
.656 .751 .919 r
.44489 .47789 .4504 .48355 .45997 .48049 .45449 .47481 Metetra
.656 .751 .919 r
.45449 .47481 .45997 .48049 .46958 .47742 .46412 .47172 Metetra
.656 .751 .919 r
.46412 .47172 .46958 .47742 .47922 .47433 .47378 .46861 Metetra
.656 .751 .919 r
.47378 .46861 .47922 .47433 .4889 .47124 .48348 .4655 Metetra
.656 .751 .919 r
.48348 .4655 .4889 .47124 .49861 .46814 .49322 .46238 Metetra
.656 .751 .919 r
.49322 .46238 .49861 .46814 .50836 .46502 .50298 .45924 Metetra
.656 .751 .919 r
.50298 .45924 .50836 .46502 .51814 .46189 .51279 .45609 Metetra
.656 .751 .919 r
.51279 .45609 .51814 .46189 .52796 .45876 .52263 .45293 Metetra
.656 .751 .919 r
.52263 .45293 .52796 .45876 .53781 .45561 .5325 .44976 Metetra
.656 .751 .919 r
.5325 .44976 .53781 .45561 .5477 .45245 .54241 .44658 Metetra
.656 .751 .919 r
.54241 .44658 .5477 .45245 .55762 .44928 .55236 .44339 Metetra
.656 .751 .919 r
.55236 .44339 .55762 .44928 .56758 .44609 .56234 .44019 Metetra
.656 .751 .919 r
.56234 .44019 .56758 .44609 .57757 .4429 .57236 .43697 Metetra
.656 .751 .919 r
.57236 .43697 .57757 .4429 .5876 .43969 .58241 .43374 Metetra
.656 .751 .919 r
.58241 .43374 .5876 .43969 .59767 .43647 .5925 .4305 Metetra
.656 .751 .919 r
.5925 .4305 .59767 .43647 .60777 .43325 .60263 .42725 Metetra
.656 .751 .919 r
.60263 .42725 .60777 .43325 .61791 .43 .61279 .42399 Metetra
.656 .751 .919 r
.61279 .42399 .61791 .43 .62808 .42675 .62299 .42072 Metetra
.656 .751 .919 r
.62299 .42072 .62808 .42675 .6383 .42349 .63323 .41743 Metetra
.656 .751 .919 r
.63323 .41743 .6383 .42349 .64855 .42021 .64351 .41413 Metetra
.656 .751 .919 r
.64351 .41413 .64855 .42021 .65884 .41692 .65382 .41082 Metetra
.656 .751 .919 r
.65382 .41082 .65884 .41692 .66916 .41362 .66417 .4075 Metetra
.656 .751 .919 r
.66417 .4075 .66916 .41362 .67953 .41031 .67456 .40416 Metetra
.656 .751 .919 r
.67456 .40416 .67953 .41031 .68993 .40698 .68499 .40081 Metetra
.656 .751 .919 r
.68499 .40081 .68993 .40698 .70037 .40365 .69546 .39745 Metetra
.656 .751 .919 r
.69546 .39745 .70037 .40365 .71085 .4003 .70596 .39408 Metetra
.656 .751 .919 r
.70596 .39408 .71085 .4003 .72137 .39694 .71651 .3907 Metetra
.656 .751 .919 r
.71651 .3907 .72137 .39694 .73192 .39356 .72709 .3873 Metetra
.656 .751 .919 r
.72709 .3873 .73192 .39356 .74252 .39017 .73772 .38389 Metetra
.656 .751 .919 r
.73772 .38389 .74252 .39017 .75315 .38677 .74838 .38047 Metetra
.656 .751 .919 r
.74838 .38047 .75315 .38677 .76383 .38336 .75908 .37703 Metetra
.656 .751 .919 r
.75908 .37703 .76383 .38336 .77454 .37994 .76983 .37358 Metetra
.656 .751 .919 r
.76983 .37358 .77454 .37994 .7853 .3765 .78061 .37012 Metetra
.656 .751 .919 r
.78061 .37012 .7853 .3765 .79609 .37305 .79143 .36664 Metetra
.656 .751 .919 r
.79143 .36664 .79609 .37305 .80693 .36959 .8023 .36316 Metetra
.656 .751 .919 r
.8023 .36316 .80693 .36959 .81781 .36611 .8132 .35966 Metetra
.656 .751 .919 r
.8132 .35966 .81781 .36611 .82872 .36262 .82415 .35614 Metetra
.656 .751 .919 r
.82415 .35614 .82872 .36262 .83968 .35912 .83514 .35261 Metetra
.656 .751 .919 r
.83514 .35261 .83968 .35912 .85068 .3556 .84617 .34907 Metetra
.656 .751 .919 r
.84617 .34907 .85068 .3556 .86172 .35207 .85724 .34552 Metetra
.685 .782 .924 r
.22711 .54126 .23316 .54586 .24202 .54301 .23604 .53774 Metetra
.656 .751 .919 r
.23604 .53774 .24202 .54301 .25091 .54016 .24495 .53486 Metetra
.656 .751 .919 r
.24495 .53486 .25091 .54016 .25983 .5373 .25389 .53198 Metetra
.656 .751 .919 r
.25389 .53198 .25983 .5373 .26878 .53442 .26286 .52909 Metetra
.656 .751 .919 r
.26286 .52909 .26878 .53442 .27777 .53154 .27186 .52619 Metetra
.656 .751 .919 r
.27186 .52619 .27777 .53154 .28678 .52864 .2809 .52328 Metetra
.656 .751 .919 r
.2809 .52328 .28678 .52864 .29583 .52574 .28996 .52035 Metetra
.656 .751 .919 r
.28996 .52035 .29583 .52574 .3049 .52283 .29905 .51742 Metetra
.656 .751 .919 r
.29905 .51742 .3049 .52283 .31401 .5199 .30818 .51448 Metetra
.656 .751 .919 r
.30818 .51448 .31401 .5199 .32315 .51697 .31734 .51153 Metetra
.656 .751 .919 r
.31734 .51153 .32315 .51697 .33232 .51403 .32653 .50856 Metetra
.656 .751 .919 r
.32653 .50856 .33232 .51403 .34152 .51107 .33575 .50559 Metetra
.656 .751 .919 r
.33575 .50559 .34152 .51107 .35075 .50811 .345 .50261 Metetra
.656 .751 .919 r
.345 .50261 .35075 .50811 .36002 .50513 .35429 .49961 Metetra
.656 .751 .919 r
.35429 .49961 .36002 .50513 .36932 .50215 .36361 .49661 Metetra
.656 .751 .919 r
.36361 .49661 .36932 .50215 .37865 .49915 .37296 .4936 Metetra
.656 .751 .919 r
.37296 .4936 .37865 .49915 .38801 .49615 .38234 .49057 Metetra
.656 .751 .919 r
.38234 .49057 .38801 .49615 .39741 .49313 .39176 .48753 Metetra
.656 .751 .919 r
.39176 .48753 .39741 .49313 .40684 .4901 .40121 .48449 Metetra
.656 .751 .919 r
.40121 .48449 .40684 .4901 .4163 .48707 .41069 .48143 Metetra
.656 .751 .919 r
.41069 .48143 .4163 .48707 .4258 .48402 .42021 .47836 Metetra
.656 .751 .919 r
.42021 .47836 .4258 .48402 .43533 .48096 .42976 .47528 Metetra
.656 .751 .919 r
.42976 .47528 .43533 .48096 .44489 .47789 .43934 .47219 Metetra
.656 .751 .919 r
.43934 .47219 .44489 .47789 .45449 .47481 .44896 .46909 Metetra
.656 .751 .919 r
.44896 .46909 .45449 .47481 .46412 .47172 .45861 .46598 Metetra
.656 .751 .919 r
.45861 .46598 .46412 .47172 .47378 .46861 .4683 .46286 Metetra
.656 .751 .919 r
.4683 .46286 .47378 .46861 .48348 .4655 .47802 .45972 Metetra
.656 .751 .919 r
.47802 .45972 .48348 .4655 .49322 .46238 .48778 .45658 Metetra
.656 .751 .919 r
.48778 .45658 .49322 .46238 .50298 .45924 .49757 .45342 Metetra
.656 .751 .919 r
.49757 .45342 .50298 .45924 .51279 .45609 .5074 .45025 Metetra
.656 .751 .919 r
.5074 .45025 .51279 .45609 .52263 .45293 .51726 .44707 Metetra
.656 .751 .919 r
.51726 .44707 .52263 .45293 .5325 .44976 .52716 .44388 Metetra
.656 .751 .919 r
.52716 .44388 .5325 .44976 .54241 .44658 .53709 .44068 Metetra
.656 .751 .919 r
.53709 .44068 .54241 .44658 .55236 .44339 .54706 .43747 Metetra
.656 .751 .919 r
.54706 .43747 .55236 .44339 .56234 .44019 .55707 .43424 Metetra
.656 .751 .919 r
.55707 .43424 .56234 .44019 .57236 .43697 .56711 .431 Metetra
.656 .751 .919 r
.56711 .431 .57236 .43697 .58241 .43374 .57719 .42775 Metetra
.656 .751 .919 r
.57719 .42775 .58241 .43374 .5925 .4305 .5873 .42449 Metetra
.656 .751 .919 r
.5873 .42449 .5925 .4305 .60263 .42725 .59745 .42122 Metetra
.656 .751 .919 r
.59745 .42122 .60263 .42725 .61279 .42399 .60764 .41794 Metetra
.656 .751 .919 r
.60764 .41794 .61279 .42399 .62299 .42072 .61787 .41464 Metetra
.656 .751 .919 r
.61787 .41464 .62299 .42072 .63323 .41743 .62813 .41133 Metetra
.656 .751 .919 r
.62813 .41133 .63323 .41743 .64351 .41413 .63843 .40801 Metetra
.656 .751 .919 r
.63843 .40801 .64351 .41413 .65382 .41082 .64877 .40467 Metetra
.656 .751 .919 r
.64877 .40467 .65382 .41082 .66417 .4075 .65915 .40133 Metetra
.656 .751 .919 r
.65915 .40133 .66417 .4075 .67456 .40416 .66957 .39797 Metetra
.656 .751 .919 r
.66957 .39797 .67456 .40416 .68499 .40081 .68002 .3946 Metetra
.656 .751 .919 r
.68002 .3946 .68499 .40081 .69546 .39745 .69052 .39122 Metetra
.656 .751 .919 r
.69052 .39122 .69546 .39745 .70596 .39408 .70105 .38782 Metetra
.656 .751 .919 r
.70105 .38782 .70596 .39408 .71651 .3907 .71162 .38441 Metetra
.656 .751 .919 r
.71162 .38441 .71651 .3907 .72709 .3873 .72223 .38099 Metetra
.656 .751 .919 r
.72223 .38099 .72709 .3873 .73772 .38389 .73288 .37756 Metetra
.656 .751 .919 r
.73288 .37756 .73772 .38389 .74838 .38047 .74357 .37411 Metetra
.656 .751 .919 r
.74357 .37411 .74838 .38047 .75908 .37703 .7543 .37065 Metetra
.656 .751 .919 r
.7543 .37065 .75908 .37703 .76983 .37358 .76507 .36718 Metetra
.656 .751 .919 r
.76507 .36718 .76983 .37358 .78061 .37012 .77589 .36369 Metetra
.656 .751 .919 r
.77589 .36369 .78061 .37012 .79143 .36664 .78674 .3602 Metetra
.656 .751 .919 r
.78674 .3602 .79143 .36664 .8023 .36316 .79763 .35668 Metetra
.656 .751 .919 r
.79763 .35668 .8023 .36316 .8132 .35966 .80857 .35316 Metetra
.656 .751 .919 r
.80857 .35316 .8132 .35966 .82415 .35614 .81954 .34962 Metetra
.656 .751 .919 r
.81954 .34962 .82415 .35614 .83514 .35261 .83056 .34607 Metetra
.656 .751 .919 r
.83056 .34607 .83514 .35261 .84617 .34907 .84162 .3425 Metetra
.656 .751 .919 r
.84162 .3425 .84617 .34907 .85724 .34552 .85272 .33892 Metetra
.585 .649 .88 r
.22128 .53364 .22711 .54126 .23604 .53774 .23003 .53243 Metetra
.656 .751 .919 r
.23003 .53243 .23604 .53774 .24495 .53486 .23896 .52954 Metetra
.656 .751 .919 r
.23896 .52954 .24495 .53486 .25389 .53198 .24791 .52664 Metetra
.656 .751 .919 r
.24791 .52664 .25389 .53198 .26286 .52909 .2569 .52372 Metetra
.656 .751 .919 r
.2569 .52372 .26286 .52909 .27186 .52619 .26592 .5208 Metetra
.656 .751 .919 r
.26592 .5208 .27186 .52619 .2809 .52328 .27497 .51787 Metetra
.656 .751 .919 r
.27497 .51787 .2809 .52328 .28996 .52035 .28405 .51493 Metetra
.656 .751 .919 r
.28405 .51493 .28996 .52035 .29905 .51742 .29317 .51198 Metetra
.656 .751 .919 r
.29317 .51198 .29905 .51742 .30818 .51448 .30231 .50902 Metetra
.656 .751 .919 r
.30231 .50902 .30818 .51448 .31734 .51153 .31149 .50605 Metetra
.656 .751 .919 r
.31149 .50605 .31734 .51153 .32653 .50856 .3207 .50307 Metetra
.656 .751 .919 r
.3207 .50307 .32653 .50856 .33575 .50559 .32994 .50008 Metetra
.656 .751 .919 r
.32994 .50008 .33575 .50559 .345 .50261 .33921 .49707 Metetra
.656 .751 .919 r
.33921 .49707 .345 .50261 .35429 .49961 .34852 .49406 Metetra
.656 .751 .919 r
.34852 .49406 .35429 .49961 .36361 .49661 .35786 .49104 Metetra
.656 .751 .919 r
.35786 .49104 .36361 .49661 .37296 .4936 .36723 .488 Metetra
.656 .751 .919 r
.36723 .488 .37296 .4936 .38234 .49057 .37663 .48496 Metetra
.656 .751 .919 r
.37663 .48496 .38234 .49057 .39176 .48753 .38607 .4819 Metetra
.656 .751 .919 r
.38607 .4819 .39176 .48753 .40121 .48449 .39554 .47884 Metetra
.656 .751 .919 r
.39554 .47884 .40121 .48449 .41069 .48143 .40505 .47576 Metetra
.656 .751 .919 r
.40505 .47576 .41069 .48143 .42021 .47836 .41458 .47267 Metetra
.656 .751 .919 r
.41458 .47267 .42021 .47836 .42976 .47528 .42416 .46957 Metetra
.656 .751 .919 r
.42416 .46957 .42976 .47528 .43934 .47219 .43376 .46646 Metetra
.656 .751 .919 r
.43376 .46646 .43934 .47219 .44896 .46909 .4434 .46334 Metetra
.656 .751 .919 r
.4434 .46334 .44896 .46909 .45861 .46598 .45308 .46021 Metetra
.656 .751 .919 r
.45308 .46021 .45861 .46598 .4683 .46286 .46279 .45706 Metetra
.656 .751 .919 r
.46279 .45706 .4683 .46286 .47802 .45972 .47253 .45391 Metetra
.656 .751 .919 r
.47253 .45391 .47802 .45972 .48778 .45658 .48231 .45074 Metetra
.656 .751 .919 r
.48231 .45074 .48778 .45658 .49757 .45342 .49212 .44756 Metetra
.656 .751 .919 r
.49212 .44756 .49757 .45342 .5074 .45025 .50197 .44437 Metetra
.656 .751 .919 r
.50197 .44437 .5074 .45025 .51726 .44707 .51186 .44117 Metetra
.656 .751 .919 r
.51186 .44117 .51726 .44707 .52716 .44388 .52178 .43796 Metetra
.656 .751 .919 r
.52178 .43796 .52716 .44388 .53709 .44068 .53174 .43474 Metetra
.656 .751 .919 r
.53174 .43474 .53709 .44068 .54706 .43747 .54173 .4315 Metetra
.656 .751 .919 r
.54173 .4315 .54706 .43747 .55707 .43424 .55176 .42825 Metetra
.656 .751 .919 r
.55176 .42825 .55707 .43424 .56711 .431 .56182 .425 Metetra
.656 .751 .919 r
.56182 .425 .56711 .431 .57719 .42775 .57193 .42172 Metetra
.656 .751 .919 r
.57193 .42172 .57719 .42775 .5873 .42449 .58207 .41844 Metetra
.656 .751 .919 r
.58207 .41844 .5873 .42449 .59745 .42122 .59224 .41515 Metetra
.656 .751 .919 r
.59224 .41515 .59745 .42122 .60764 .41794 .60246 .41184 Metetra
.656 .751 .919 r
.60246 .41184 .60764 .41794 .61787 .41464 .61271 .40852 Metetra
.656 .751 .919 r
.61271 .40852 .61787 .41464 .62813 .41133 .623 .40519 Metetra
.656 .751 .919 r
.623 .40519 .62813 .41133 .63843 .40801 .63332 .40184 Metetra
.656 .751 .919 r
.63332 .40184 .63843 .40801 .64877 .40467 .64369 .39849 Metetra
.656 .751 .919 r
.64369 .39849 .64877 .40467 .65915 .40133 .65409 .39512 Metetra
.656 .751 .919 r
.65409 .39512 .65915 .40133 .66957 .39797 .66454 .39174 Metetra
.656 .751 .919 r
.66454 .39174 .66957 .39797 .68002 .3946 .67502 .38835 Metetra
.656 .751 .919 r
.67502 .38835 .68002 .3946 .69052 .39122 .68554 .38494 Metetra
.656 .751 .919 r
.68554 .38494 .69052 .39122 .70105 .38782 .6961 .38152 Metetra
.656 .751 .919 r
.6961 .38152 .70105 .38782 .71162 .38441 .7067 .37809 Metetra
.656 .751 .919 r
.7067 .37809 .71162 .38441 .72223 .38099 .71733 .37464 Metetra
.656 .751 .919 r
.71733 .37464 .72223 .38099 .73288 .37756 .72801 .37119 Metetra
.656 .751 .919 r
.72801 .37119 .73288 .37756 .74357 .37411 .73873 .36772 Metetra
.656 .751 .919 r
.73873 .36772 .74357 .37411 .7543 .37065 .74949 .36423 Metetra
.656 .751 .919 r
.74949 .36423 .7543 .37065 .76507 .36718 .76029 .36073 Metetra
.656 .751 .919 r
.76029 .36073 .76507 .36718 .77589 .36369 .77113 .35722 Metetra
.656 .751 .919 r
.77113 .35722 .77589 .36369 .78674 .3602 .78201 .3537 Metetra
.656 .751 .919 r
.78201 .3537 .78674 .3602 .79763 .35668 .79294 .35016 Metetra
.656 .751 .919 r
.79294 .35016 .79763 .35668 .80857 .35316 .8039 .34661 Metetra
.656 .751 .919 r
.8039 .34661 .80857 .35316 .81954 .34962 .81491 .34305 Metetra
.656 .751 .919 r
.81491 .34305 .81954 .34962 .83056 .34607 .82595 .33947 Metetra
.656 .751 .919 r
.82595 .33947 .83056 .34607 .84162 .3425 .83704 .33588 Metetra
.656 .751 .919 r
.83704 .33588 .84162 .3425 .85272 .33892 .84818 .33228 Metetra
.701 .876 .963 r
.21495 .53119 .22128 .53364 .23003 .53243 .22398 .52708 Metetra
.656 .751 .919 r
.22398 .52708 .23003 .53243 .23896 .52954 .23292 .52417 Metetra
.656 .751 .919 r
.23292 .52417 .23896 .52954 .24791 .52664 .2419 .52125 Metetra
.656 .751 .919 r
.2419 .52125 .24791 .52664 .2569 .52372 .25091 .51833 Metetra
.656 .751 .919 r
.25091 .51833 .2569 .52372 .26592 .5208 .25994 .51539 Metetra
.656 .751 .919 r
.25994 .51539 .26592 .5208 .27497 .51787 .26901 .51244 Metetra
.656 .751 .919 r
.26901 .51244 .27497 .51787 .28405 .51493 .27811 .50948 Metetra
.656 .751 .919 r
.27811 .50948 .28405 .51493 .29317 .51198 .28725 .50651 Metetra
.656 .751 .919 r
.28725 .50651 .29317 .51198 .30231 .50902 .29641 .50353 Metetra
.656 .751 .919 r
.29641 .50353 .30231 .50902 .31149 .50605 .30561 .50054 Metetra
.656 .751 .919 r
.30561 .50054 .31149 .50605 .3207 .50307 .31483 .49754 Metetra
.656 .751 .919 r
.31483 .49754 .3207 .50307 .32994 .50008 .32409 .49452 Metetra
.656 .751 .919 r
.32409 .49452 .32994 .50008 .33921 .49707 .33339 .4915 Metetra
.656 .751 .919 r
.33339 .4915 .33921 .49707 .34852 .49406 .34271 .48847 Metetra
.656 .751 .919 r
.34271 .48847 .34852 .49406 .35786 .49104 .35207 .48543 Metetra
.656 .751 .919 r
.35207 .48543 .35786 .49104 .36723 .488 .36146 .48237 Metetra
.656 .751 .919 r
.36146 .48237 .36723 .488 .37663 .48496 .37089 .47931 Metetra
.656 .751 .919 r
.37089 .47931 .37663 .48496 .38607 .4819 .38035 .47623 Metetra
.656 .751 .919 r
.38035 .47623 .38607 .4819 .39554 .47884 .38984 .47315 Metetra
.656 .751 .919 r
.38984 .47315 .39554 .47884 .40505 .47576 .39936 .47005 Metetra
.656 .751 .919 r
.39936 .47005 .40505 .47576 .41458 .47267 .40892 .46694 Metetra
.656 .751 .919 r
.40892 .46694 .41458 .47267 .42416 .46957 .41852 .46382 Metetra
.656 .751 .919 r
.41852 .46382 .42416 .46957 .43376 .46646 .42814 .46069 Metetra
.656 .751 .919 r
.42814 .46069 .43376 .46646 .4434 .46334 .43781 .45755 Metetra
.656 .751 .919 r
.43781 .45755 .4434 .46334 .45308 .46021 .4475 .45439 Metetra
.656 .751 .919 r
.4475 .45439 .45308 .46021 .46279 .45706 .45723 .45123 Metetra
.656 .751 .919 r
.45723 .45123 .46279 .45706 .47253 .45391 .467 .44805 Metetra
.656 .751 .919 r
.467 .44805 .47253 .45391 .48231 .45074 .4768 .44487 Metetra
.656 .751 .919 r
.4768 .44487 .48231 .45074 .49212 .44756 .48664 .44167 Metetra
.656 .751 .919 r
.48664 .44167 .49212 .44756 .50197 .44437 .49651 .43846 Metetra
.656 .751 .919 r
.49651 .43846 .50197 .44437 .51186 .44117 .50642 .43523 Metetra
.656 .751 .919 r
.50642 .43523 .51186 .44117 .52178 .43796 .51636 .432 Metetra
.656 .751 .919 r
.51636 .432 .52178 .43796 .53174 .43474 .52634 .42875 Metetra
.656 .751 .919 r
.52634 .42875 .53174 .43474 .54173 .4315 .53636 .4255 Metetra
.656 .751 .919 r
.53636 .4255 .54173 .4315 .55176 .42825 .54641 .42223 Metetra
.656 .751 .919 r
.54641 .42223 .55176 .42825 .56182 .425 .5565 .41895 Metetra
.656 .751 .919 r
.5565 .41895 .56182 .425 .57193 .42172 .56663 .41565 Metetra
.656 .751 .919 r
.56663 .41565 .57193 .42172 .58207 .41844 .5768 .41235 Metetra
.656 .751 .919 r
.5768 .41235 .58207 .41844 .59224 .41515 .587 .40903 Metetra
.656 .751 .919 r
.587 .40903 .59224 .41515 .60246 .41184 .59724 .4057 Metetra
.656 .751 .919 r
.59724 .4057 .60246 .41184 .61271 .40852 .60751 .40236 Metetra
.656 .751 .919 r
.60751 .40236 .61271 .40852 .623 .40519 .61783 .39901 Metetra
.656 .751 .919 r
.61783 .39901 .623 .40519 .63332 .40184 .62818 .39564 Metetra
.656 .751 .919 r
.62818 .39564 .63332 .40184 .64369 .39849 .63857 .39226 Metetra
.656 .751 .919 r
.63857 .39226 .64369 .39849 .65409 .39512 .649 .38887 Metetra
.656 .751 .919 r
.649 .38887 .65409 .39512 .66454 .39174 .65947 .38546 Metetra
.656 .751 .919 r
.65947 .38546 .66454 .39174 .67502 .38835 .66998 .38205 Metetra
.656 .751 .919 r
.66998 .38205 .67502 .38835 .68554 .38494 .68053 .37862 Metetra
.656 .751 .919 r
.68053 .37862 .68554 .38494 .6961 .38152 .69111 .37517 Metetra
.656 .751 .919 r
.69111 .37517 .6961 .38152 .7067 .37809 .70174 .37172 Metetra
.656 .751 .919 r
.70174 .37172 .7067 .37809 .71733 .37464 .7124 .36825 Metetra
.656 .751 .919 r
.7124 .36825 .71733 .37464 .72801 .37119 .72311 .36477 Metetra
.656 .751 .919 r
.72311 .36477 .72801 .37119 .73873 .36772 .73386 .36127 Metetra
.656 .751 .919 r
.73386 .36127 .73873 .36772 .74949 .36423 .74465 .35777 Metetra
.656 .751 .919 r
.74465 .35777 .74949 .36423 .76029 .36073 .75547 .35424 Metetra
.656 .751 .919 r
.75547 .35424 .76029 .36073 .77113 .35722 .76634 .35071 Metetra
.656 .751 .919 r
.76634 .35071 .77113 .35722 .78201 .3537 .77725 .34716 Metetra
.656 .751 .919 r
.77725 .34716 .78201 .3537 .79294 .35016 .78821 .3436 Metetra
.656 .751 .919 r
.78821 .3436 .79294 .35016 .8039 .34661 .7992 .34003 Metetra
.656 .751 .919 r
.7992 .34003 .8039 .34661 .81491 .34305 .81024 .33644 Metetra
.656 .751 .919 r
.81024 .33644 .81491 .34305 .82595 .33947 .82131 .33283 Metetra
.656 .751 .919 r
.82131 .33283 .82595 .33947 .83704 .33588 .83243 .32922 Metetra
.656 .751 .919 r
.83243 .32922 .83704 .33588 .84818 .33228 .8436 .32559 Metetra
.709 .766 .897 r
.20883 .52596 .21495 .53119 .22398 .52708 .21789 .5217 Metetra
.656 .751 .919 r
.21789 .5217 .22398 .52708 .23292 .52417 .22685 .51878 Metetra
.656 .751 .919 r
.22685 .51878 .23292 .52417 .2419 .52125 .23584 .51584 Metetra
.656 .751 .919 r
.23584 .51584 .2419 .52125 .25091 .51833 .24487 .51289 Metetra
.656 .751 .919 r
.24487 .51289 .25091 .51833 .25994 .51539 .25393 .50993 Metetra
.656 .751 .919 r
.25393 .50993 .25994 .51539 .26901 .51244 .26301 .50697 Metetra
.656 .751 .919 r
.26301 .50697 .26901 .51244 .27811 .50948 .27213 .50399 Metetra
.656 .751 .919 r
.27213 .50399 .27811 .50948 .28725 .50651 .28128 .501 Metetra
.656 .751 .919 r
.28128 .501 .28725 .50651 .29641 .50353 .29047 .498 Metetra
.656 .751 .919 r
.29047 .498 .29641 .50353 .30561 .50054 .29968 .49499 Metetra
.656 .751 .919 r
.29968 .49499 .30561 .50054 .31483 .49754 .30893 .49197 Metetra
.656 .751 .919 r
.30893 .49197 .31483 .49754 .32409 .49452 .31821 .48894 Metetra
.656 .751 .919 r
.31821 .48894 .32409 .49452 .33339 .4915 .32752 .4859 Metetra
.656 .751 .919 r
.32752 .4859 .33339 .4915 .34271 .48847 .33687 .48284 Metetra
.656 .751 .919 r
.33687 .48284 .34271 .48847 .35207 .48543 .34625 .47978 Metetra
.656 .751 .919 r
.34625 .47978 .35207 .48543 .36146 .48237 .35566 .47671 Metetra
.656 .751 .919 r
.35566 .47671 .36146 .48237 .37089 .47931 .36511 .47362 Metetra
.656 .751 .919 r
.36511 .47362 .37089 .47931 .38035 .47623 .37459 .47053 Metetra
.656 .751 .919 r
.37459 .47053 .38035 .47623 .38984 .47315 .3841 .46742 Metetra
.656 .751 .919 r
.3841 .46742 .38984 .47315 .39936 .47005 .39364 .4643 Metetra
.656 .751 .919 r
.39364 .4643 .39936 .47005 .40892 .46694 .40322 .46117 Metetra
.656 .751 .919 r
.40322 .46117 .40892 .46694 .41852 .46382 .41284 .45803 Metetra
.656 .751 .919 r
.41284 .45803 .41852 .46382 .42814 .46069 .42249 .45488 Metetra
.656 .751 .919 r
.42249 .45488 .42814 .46069 .43781 .45755 .43217 .45172 Metetra
.656 .751 .919 r
.43217 .45172 .43781 .45755 .4475 .45439 .44189 .44854 Metetra
.656 .751 .919 r
.44189 .44854 .4475 .45439 .45723 .45123 .45165 .44536 Metetra
.656 .751 .919 r
.45165 .44536 .45723 .45123 .467 .44805 .46143 .44216 Metetra
.656 .751 .919 r
.46143 .44216 .467 .44805 .4768 .44487 .47126 .43895 Metetra
.656 .751 .919 r
.47126 .43895 .4768 .44487 .48664 .44167 .48112 .43573 Metetra
.656 .751 .919 r
.48112 .43573 .48664 .44167 .49651 .43846 .49101 .4325 Metetra
.656 .751 .919 r
.49101 .4325 .49651 .43846 .50642 .43523 .50095 .42926 Metetra
.656 .751 .919 r
.50095 .42926 .50642 .43523 .51636 .432 .51091 .426 Metetra
.656 .751 .919 r
.51091 .426 .51636 .432 .52634 .42875 .52092 .42273 Metetra
.656 .751 .919 r
.52092 .42273 .52634 .42875 .53636 .4255 .53096 .41945 Metetra
.656 .751 .919 r
.53096 .41945 .53636 .4255 .54641 .42223 .54103 .41616 Metetra
.656 .751 .919 r
.54103 .41616 .54641 .42223 .5565 .41895 .55115 .41286 Metetra
.656 .751 .919 r
.55115 .41286 .5565 .41895 .56663 .41565 .5613 .40954 Metetra
.656 .751 .919 r
.5613 .40954 .56663 .41565 .5768 .41235 .57149 .40621 Metetra
.656 .751 .919 r
.57149 .40621 .5768 .41235 .587 .40903 .58172 .40287 Metetra
.656 .751 .919 r
.58172 .40287 .587 .40903 .59724 .4057 .59198 .39952 Metetra
.656 .751 .919 r
.59198 .39952 .59724 .4057 .60751 .40236 .60228 .39616 Metetra
.656 .751 .919 r
.60228 .39616 .60751 .40236 .61783 .39901 .61262 .39278 Metetra
.656 .751 .919 r
.61262 .39278 .61783 .39901 .62818 .39564 .623 .38939 Metetra
.656 .751 .919 r
.623 .38939 .62818 .39564 .63857 .39226 .63342 .38599 Metetra
.656 .751 .919 r
.63342 .38599 .63857 .39226 .649 .38887 .64387 .38257 Metetra
.656 .751 .919 r
.64387 .38257 .649 .38887 .65947 .38546 .65437 .37915 Metetra
.656 .751 .919 r
.65437 .37915 .65947 .38546 .66998 .38205 .6649 .3757 Metetra
.656 .751 .919 r
.6649 .3757 .66998 .38205 .68053 .37862 .67548 .37225 Metetra
.656 .751 .919 r
.67548 .37225 .68053 .37862 .69111 .37517 .68609 .36878 Metetra
.656 .751 .919 r
.68609 .36878 .69111 .37517 .70174 .37172 .69675 .3653 Metetra
.656 .751 .919 r
.69675 .3653 .70174 .37172 .7124 .36825 .70744 .36181 Metetra
.656 .751 .919 r
.70744 .36181 .7124 .36825 .72311 .36477 .71817 .35831 Metetra
.656 .751 .919 r
.71817 .35831 .72311 .36477 .73386 .36127 .72895 .35479 Metetra
.656 .751 .919 r
.72895 .35479 .73386 .36127 .74465 .35777 .73977 .35125 Metetra
.656 .751 .919 r
.73977 .35125 .74465 .35777 .75547 .35424 .75062 .34771 Metetra
.656 .751 .919 r
.75062 .34771 .75547 .35424 .76634 .35071 .76152 .34415 Metetra
.656 .751 .919 r
.76152 .34415 .76634 .35071 .77725 .34716 .77246 .34058 Metetra
.656 .751 .919 r
.77246 .34058 .77725 .34716 .78821 .3436 .78344 .33699 Metetra
.656 .751 .919 r
.78344 .33699 .78821 .3436 .7992 .34003 .79447 .33339 Metetra
.656 .751 .919 r
.79447 .33339 .7992 .34003 .81024 .33644 .80553 .32977 Metetra
.656 .751 .919 r
.80553 .32977 .81024 .33644 .82131 .33283 .81664 .32615 Metetra
.656 .751 .919 r
.81664 .32615 .82131 .33283 .83243 .32922 .82779 .3225 Metetra
.656 .751 .919 r
.82779 .3225 .83243 .32922 .8436 .32559 .83899 .31885 Metetra
.476 .514 .817 r
.20323 .51481 .20883 .52596 .21789 .5217 .21176 .51629 Metetra
.656 .751 .919 r
.21176 .51629 .21789 .5217 .22685 .51878 .22074 .51335 Metetra
.656 .751 .919 r
.22074 .51335 .22685 .51878 .23584 .51584 .22975 .51039 Metetra
.656 .751 .919 r
.22975 .51039 .23584 .51584 .24487 .51289 .23879 .50742 Metetra
.656 .751 .919 r
.23879 .50742 .24487 .51289 .25393 .50993 .24787 .50445 Metetra
.656 .751 .919 r
.24787 .50445 .25393 .50993 .26301 .50697 .25698 .50146 Metetra
.656 .751 .919 r
.25698 .50146 .26301 .50697 .27213 .50399 .26611 .49846 Metetra
.656 .751 .919 r
.26611 .49846 .27213 .50399 .28128 .501 .27529 .49545 Metetra
.656 .751 .919 r
.27529 .49545 .28128 .501 .29047 .498 .28449 .49243 Metetra
.656 .751 .919 r
.28449 .49243 .29047 .498 .29968 .49499 .29372 .4894 Metetra
.656 .751 .919 r
.29372 .4894 .29968 .49499 .30893 .49197 .30299 .48636 Metetra
.656 .751 .919 r
.30299 .48636 .30893 .49197 .31821 .48894 .31229 .48331 Metetra
.656 .751 .919 r
.31229 .48331 .31821 .48894 .32752 .4859 .32162 .48025 Metetra
.656 .751 .919 r
.32162 .48025 .32752 .4859 .33687 .48284 .33099 .47718 Metetra
.656 .751 .919 r
.33099 .47718 .33687 .48284 .34625 .47978 .34039 .4741 Metetra
.656 .751 .919 r
.34039 .4741 .34625 .47978 .35566 .47671 .34982 .471 Metetra
.656 .751 .919 r
.34982 .471 .35566 .47671 .36511 .47362 .35929 .4679 Metetra
.656 .751 .919 r
.35929 .4679 .36511 .47362 .37459 .47053 .36879 .46478 Metetra
.656 .751 .919 r
.36879 .46478 .37459 .47053 .3841 .46742 .37832 .46165 Metetra
.656 .751 .919 r
.37832 .46165 .3841 .46742 .39364 .4643 .38789 .45851 Metetra
.656 .751 .919 r
.38789 .45851 .39364 .4643 .40322 .46117 .39749 .45537 Metetra
.656 .751 .919 r
.39749 .45537 .40322 .46117 .41284 .45803 .40713 .4522 Metetra
.656 .751 .919 r
.40713 .4522 .41284 .45803 .42249 .45488 .4168 .44903 Metetra
.656 .751 .919 r
.4168 .44903 .42249 .45488 .43217 .45172 .4265 .44585 Metetra
.656 .751 .919 r
.4265 .44585 .43217 .45172 .44189 .44854 .43624 .44265 Metetra
.656 .751 .919 r
.43624 .44265 .44189 .44854 .45165 .44536 .44602 .43945 Metetra
.656 .751 .919 r
.44602 .43945 .45165 .44536 .46143 .44216 .45583 .43623 Metetra
.656 .751 .919 r
.45583 .43623 .46143 .44216 .47126 .43895 .46568 .433 Metetra
.656 .751 .919 r
.46568 .433 .47126 .43895 .48112 .43573 .47556 .42975 Metetra
.656 .751 .919 r
.47556 .42975 .48112 .43573 .49101 .4325 .48548 .4265 Metetra
.656 .751 .919 r
.48548 .4265 .49101 .4325 .50095 .42926 .49543 .42324 Metetra
.656 .751 .919 r
.49543 .42324 .50095 .42926 .51091 .426 .50542 .41996 Metetra
.656 .751 .919 r
.50542 .41996 .51091 .426 .52092 .42273 .51545 .41667 Metetra
.656 .751 .919 r
.51545 .41667 .52092 .42273 .53096 .41945 .52552 .41337 Metetra
.656 .751 .919 r
.52552 .41337 .53096 .41945 .54103 .41616 .53562 .41005 Metetra
.656 .751 .919 r
.53562 .41005 .54103 .41616 .55115 .41286 .54576 .40673 Metetra
.656 .751 .919 r
.54576 .40673 .55115 .41286 .5613 .40954 .55593 .40339 Metetra
.656 .751 .919 r
.55593 .40339 .5613 .40954 .57149 .40621 .56615 .40004 Metetra
.656 .751 .919 r
.56615 .40004 .57149 .40621 .58172 .40287 .5764 .39668 Metetra
.656 .751 .919 r
.5764 .39668 .58172 .40287 .59198 .39952 .58669 .3933 Metetra
.656 .751 .919 r
.58669 .3933 .59198 .39952 .60228 .39616 .59702 .38991 Metetra
.656 .751 .919 r
.59702 .38991 .60228 .39616 .61262 .39278 .60738 .38651 Metetra
.656 .751 .919 r
.60738 .38651 .61262 .39278 .623 .38939 .61779 .3831 Metetra
.656 .751 .919 r
.61779 .3831 .623 .38939 .63342 .38599 .62823 .37967 Metetra
.656 .751 .919 r
.62823 .37967 .63342 .38599 .64387 .38257 .63871 .37623 Metetra
.656 .751 .919 r
.63871 .37623 .64387 .38257 .65437 .37915 .64923 .37278 Metetra
.656 .751 .919 r
.64923 .37278 .65437 .37915 .6649 .3757 .6598 .36932 Metetra
.656 .751 .919 r
.6598 .36932 .6649 .3757 .67548 .37225 .6704 .36584 Metetra
.656 .751 .919 r
.6704 .36584 .67548 .37225 .68609 .36878 .68104 .36235 Metetra
.656 .751 .919 r
.68104 .36235 .68609 .36878 .69675 .3653 .69172 .35885 Metetra
.656 .751 .919 r
.69172 .35885 .69675 .3653 .70744 .36181 .70244 .35533 Metetra
.656 .751 .919 r
.70244 .35533 .70744 .36181 .71817 .35831 .7132 .3518 Metetra
.656 .751 .919 r
.7132 .3518 .71817 .35831 .72895 .35479 .72401 .34825 Metetra
.656 .751 .919 r
.72401 .34825 .72895 .35479 .73977 .35125 .73485 .3447 Metetra
.656 .751 .919 r
.73485 .3447 .73977 .35125 .75062 .34771 .74574 .34113 Metetra
.656 .751 .919 r
.74574 .34113 .75062 .34771 .76152 .34415 .75667 .33754 Metetra
.656 .751 .919 r
.75667 .33754 .76152 .34415 .77246 .34058 .76763 .33394 Metetra
.656 .751 .919 r
.76763 .33394 .77246 .34058 .78344 .33699 .77865 .33033 Metetra
.656 .751 .919 r
.77865 .33033 .78344 .33699 .79447 .33339 .7897 .32671 Metetra
.656 .751 .919 r
.7897 .32671 .79447 .33339 .80553 .32977 .8008 .32307 Metetra
.656 .751 .919 r
.8008 .32307 .80553 .32977 .81664 .32615 .81193 .31941 Metetra
.656 .751 .919 r
.81193 .31941 .81664 .32615 .82779 .3225 .82312 .31574 Metetra
.656 .751 .919 r
.82312 .31574 .82779 .3225 .83899 .31885 .83434 .31206 Metetra
.667 .958 .735 r
.1961 .51909 .20323 .51481 .21176 .51629 .20559 .51084 Metetra
.656 .751 .919 r
.20559 .51084 .21176 .51629 .22074 .51335 .21459 .50788 Metetra
.656 .751 .919 r
.21459 .50788 .22074 .51335 .22975 .51039 .22362 .5049 Metetra
.656 .751 .919 r
.22362 .5049 .22975 .51039 .23879 .50742 .23268 .50192 Metetra
.656 .751 .919 r
.23268 .50192 .23879 .50742 .24787 .50445 .24177 .49892 Metetra
.656 .751 .919 r
.24177 .49892 .24787 .50445 .25698 .50146 .2509 .49592 Metetra
.656 .751 .919 r
.2509 .49592 .25698 .50146 .26611 .49846 .26006 .4929 Metetra
.656 .751 .919 r
.26006 .4929 .26611 .49846 .27529 .49545 .26925 .48987 Metetra
.656 .751 .919 r
.26925 .48987 .27529 .49545 .28449 .49243 .27847 .48683 Metetra
.656 .751 .919 r
.27847 .48683 .28449 .49243 .29372 .4894 .28772 .48378 Metetra
.656 .751 .919 r
.28772 .48378 .29372 .4894 .30299 .48636 .29701 .48072 Metetra
.656 .751 .919 r
.29701 .48072 .30299 .48636 .31229 .48331 .30633 .47765 Metetra
.656 .751 .919 r
.30633 .47765 .31229 .48331 .32162 .48025 .31568 .47457 Metetra
.656 .751 .919 r
.31568 .47457 .32162 .48025 .33099 .47718 .32507 .47148 Metetra
.656 .751 .919 r
.32507 .47148 .33099 .47718 .34039 .4741 .33449 .46838 Metetra
.656 .751 .919 r
.33449 .46838 .34039 .4741 .34982 .471 .34394 .46526 Metetra
.656 .751 .919 r
.34394 .46526 .34982 .471 .35929 .4679 .35343 .46214 Metetra
.656 .751 .919 r
.35343 .46214 .35929 .4679 .36879 .46478 .36295 .459 Metetra
.656 .751 .919 r
.36295 .459 .36879 .46478 .37832 .46165 .3725 .45585 Metetra
.656 .751 .919 r
.3725 .45585 .37832 .46165 .38789 .45851 .38209 .45269 Metetra
.656 .751 .919 r
.38209 .45269 .38789 .45851 .39749 .45537 .39171 .44952 Metetra
.656 .751 .919 r
.39171 .44952 .39749 .45537 .40713 .4522 .40137 .44634 Metetra
.656 .751 .919 r
.40137 .44634 .40713 .4522 .4168 .44903 .41107 .44314 Metetra
.656 .751 .919 r
.41107 .44314 .4168 .44903 .4265 .44585 .42079 .43994 Metetra
.656 .751 .919 r
.42079 .43994 .4265 .44585 .43624 .44265 .43056 .43672 Metetra
.656 .751 .919 r
.43056 .43672 .43624 .44265 .44602 .43945 .44035 .43349 Metetra
.656 .751 .919 r
.44035 .43349 .44602 .43945 .45583 .43623 .45019 .43025 Metetra
.656 .751 .919 r
.45019 .43025 .45583 .43623 .46568 .433 .46006 .427 Metetra
.656 .751 .919 r
.46006 .427 .46568 .433 .47556 .42975 .46996 .42374 Metetra
.656 .751 .919 r
.46996 .42374 .47556 .42975 .48548 .4265 .47991 .42046 Metetra
.656 .751 .919 r
.47991 .42046 .48548 .4265 .49543 .42324 .48988 .41718 Metetra
.656 .751 .919 r
.48988 .41718 .49543 .42324 .50542 .41996 .4999 .41388 Metetra
.656 .751 .919 r
.4999 .41388 .50542 .41996 .51545 .41667 .50995 .41056 Metetra
.656 .751 .919 r
.50995 .41056 .51545 .41667 .52552 .41337 .52004 .40724 Metetra
.656 .751 .919 r
.52004 .40724 .52552 .41337 .53562 .41005 .53017 .4039 Metetra
.656 .751 .919 r
.53017 .4039 .53562 .41005 .54576 .40673 .54033 .40056 Metetra
.656 .751 .919 r
.54033 .40056 .54576 .40673 .55593 .40339 .55053 .39719 Metetra
.656 .751 .919 r
.55053 .39719 .55593 .40339 .56615 .40004 .56077 .39382 Metetra
.656 .751 .919 r
.56077 .39382 .56615 .40004 .5764 .39668 .57104 .39043 Metetra
.656 .751 .919 r
.57104 .39043 .5764 .39668 .58669 .3933 .58136 .38704 Metetra
.656 .751 .919 r
.58136 .38704 .58669 .3933 .59702 .38991 .59171 .38363 Metetra
.656 .751 .919 r
.59171 .38363 .59702 .38991 .60738 .38651 .6021 .3802 Metetra
.656 .751 .919 r
.6021 .3802 .60738 .38651 .61779 .3831 .61254 .37676 Metetra
.656 .751 .919 r
.61254 .37676 .61779 .3831 .62823 .37967 .62301 .37331 Metetra
.656 .751 .919 r
.62301 .37331 .62823 .37967 .63871 .37623 .63351 .36985 Metetra
.656 .751 .919 r
.63351 .36985 .63871 .37623 .64923 .37278 .64406 .36638 Metetra
.656 .751 .919 r
.64406 .36638 .64923 .37278 .6598 .36932 .65465 .36289 Metetra
.656 .751 .919 r
.65465 .36289 .6598 .36932 .6704 .36584 .66528 .35939 Metetra
.656 .751 .919 r
.66528 .35939 .6704 .36584 .68104 .36235 .67595 .35587 Metetra
.656 .751 .919 r
.67595 .35587 .68104 .36235 .69172 .35885 .68666 .35234 Metetra
.656 .751 .919 r
.68666 .35234 .69172 .35885 .70244 .35533 .69741 .3488 Metetra
.656 .751 .919 r
.69741 .3488 .70244 .35533 .7132 .3518 .7082 .34525 Metetra
.656 .751 .919 r
.7082 .34525 .7132 .3518 .72401 .34825 .71903 .34168 Metetra
.656 .751 .919 r
.71903 .34168 .72401 .34825 .73485 .3447 .7299 .33809 Metetra
.656 .751 .919 r
.7299 .33809 .73485 .3447 .74574 .34113 .74082 .3345 Metetra
.656 .751 .919 r
.74082 .3345 .74574 .34113 .75667 .33754 .75177 .33089 Metetra
.656 .751 .919 r
.75177 .33089 .75667 .33754 .76763 .33394 .76277 .32726 Metetra
.656 .751 .919 r
.76277 .32726 .76763 .33394 .77865 .33033 .77381 .32363 Metetra
.656 .751 .919 r
.77381 .32363 .77865 .33033 .7897 .32671 .7849 .31997 Metetra
.656 .751 .919 r
.7849 .31997 .7897 .32671 .8008 .32307 .79602 .31631 Metetra
.656 .751 .919 r
.79602 .31631 .8008 .32307 .81193 .31941 .80719 .31263 Metetra
.656 .751 .919 r
.80719 .31263 .81193 .31941 .82312 .31574 .81841 .30893 Metetra
.656 .751 .919 r
.81841 .30893 .82312 .31574 .83434 .31206 .82966 .30523 Metetra
.571 .537 .778 r
.19061 .50618 .1961 .51909 .20559 .51084 .19938 .50536 Metetra
.656 .751 .919 r
.19938 .50536 .20559 .51084 .21459 .50788 .2084 .50238 Metetra
.656 .751 .919 r
.2084 .50238 .21459 .50788 .22362 .5049 .21745 .49938 Metetra
.656 .751 .919 r
.21745 .49938 .22362 .5049 .23268 .50192 .22653 .49638 Metetra
.656 .751 .919 r
.22653 .49638 .23268 .50192 .24177 .49892 .23564 .49336 Metetra
.656 .751 .919 r
.23564 .49336 .24177 .49892 .2509 .49592 .24478 .49034 Metetra
.656 .751 .919 r
.24478 .49034 .2509 .49592 .26006 .4929 .25396 .4873 Metetra
.656 .751 .919 r
.25396 .4873 .26006 .4929 .26925 .48987 .26317 .48425 Metetra
.656 .751 .919 r
.26317 .48425 .26925 .48987 .27847 .48683 .27241 .4812 Metetra
.656 .751 .919 r
.27241 .4812 .27847 .48683 .28772 .48378 .28168 .47813 Metetra
.656 .751 .919 r
.28168 .47813 .28772 .48378 .29701 .48072 .29099 .47505 Metetra
.656 .751 .919 r
.29099 .47505 .29701 .48072 .30633 .47765 .30033 .47196 Metetra
.656 .751 .919 r
.30033 .47196 .30633 .47765 .31568 .47457 .3097 .46885 Metetra
.656 .751 .919 r
.3097 .46885 .31568 .47457 .32507 .47148 .31911 .46574 Metetra
.656 .751 .919 r
.31911 .46574 .32507 .47148 .33449 .46838 .32855 .46262 Metetra
.656 .751 .919 r
.32855 .46262 .33449 .46838 .34394 .46526 .33802 .45948 Metetra
.656 .751 .919 r
.33802 .45948 .34394 .46526 .35343 .46214 .34753 .45634 Metetra
.656 .751 .919 r
.34753 .45634 .35343 .46214 .36295 .459 .35707 .45318 Metetra
.656 .751 .919 r
.35707 .45318 .36295 .459 .3725 .45585 .36665 .45001 Metetra
.656 .751 .919 r
.36665 .45001 .3725 .45585 .38209 .45269 .37626 .44683 Metetra
.656 .751 .919 r
.37626 .44683 .38209 .45269 .39171 .44952 .3859 .44364 Metetra
.656 .751 .919 r
.3859 .44364 .39171 .44952 .40137 .44634 .39558 .44043 Metetra
.656 .751 .919 r
.39558 .44043 .40137 .44634 .41107 .44314 .4053 .43722 Metetra
.656 .751 .919 r
.4053 .43722 .41107 .44314 .42079 .43994 .41505 .43399 Metetra
.656 .751 .919 r
.41505 .43399 .42079 .43994 .43056 .43672 .42483 .43075 Metetra
.656 .751 .919 r
.42483 .43075 .43056 .43672 .44035 .43349 .43465 .4275 Metetra
.656 .751 .919 r
.43465 .4275 .44035 .43349 .45019 .43025 .44451 .42424 Metetra
.656 .751 .919 r
.44451 .42424 .45019 .43025 .46006 .427 .4544 .42097 Metetra
.656 .751 .919 r
.4544 .42097 .46006 .427 .46996 .42374 .46433 .41768 Metetra
.656 .751 .919 r
.46433 .41768 .46996 .42374 .47991 .42046 .4743 .41438 Metetra
.656 .751 .919 r
.4743 .41438 .47991 .42046 .48988 .41718 .4843 .41107 Metetra
.656 .751 .919 r
.4843 .41107 .48988 .41718 .4999 .41388 .49434 .40775 Metetra
.656 .751 .919 r
.49434 .40775 .4999 .41388 .50995 .41056 .50441 .40442 Metetra
.656 .751 .919 r
.50441 .40442 .50995 .41056 .52004 .40724 .51452 .40107 Metetra
.656 .751 .919 r
.51452 .40107 .52004 .40724 .53017 .4039 .52468 .39771 Metetra
.656 .751 .919 r
.52468 .39771 .53017 .4039 .54033 .40056 .53486 .39434 Metetra
.656 .751 .919 r
.53486 .39434 .54033 .40056 .55053 .39719 .54509 .39096 Metetra
.656 .751 .919 r
.54509 .39096 .55053 .39719 .56077 .39382 .55535 .38756 Metetra
.656 .751 .919 r
.55535 .38756 .56077 .39382 .57104 .39043 .56565 .38415 Metetra
.656 .751 .919 r
.56565 .38415 .57104 .39043 .58136 .38704 .57599 .38073 Metetra
.656 .751 .919 r
.57599 .38073 .58136 .38704 .59171 .38363 .58637 .37729 Metetra
.656 .751 .919 r
.58637 .37729 .59171 .38363 .6021 .3802 .59679 .37385 Metetra
.656 .751 .919 r
.59679 .37385 .6021 .3802 .61254 .37676 .60725 .37039 Metetra
.656 .751 .919 r
.60725 .37039 .61254 .37676 .62301 .37331 .61774 .36691 Metetra
.656 .751 .919 r
.61774 .36691 .62301 .37331 .63351 .36985 .62828 .36343 Metetra
.656 .751 .919 r
.62828 .36343 .63351 .36985 .64406 .36638 .63886 .35993 Metetra
.656 .751 .919 r
.63886 .35993 .64406 .36638 .65465 .36289 .64947 .35641 Metetra
.656 .751 .919 r
.64947 .35641 .65465 .36289 .66528 .35939 .66013 .35289 Metetra
.656 .751 .919 r
.66013 .35289 .66528 .35939 .67595 .35587 .67082 .34935 Metetra
.656 .751 .919 r
.67082 .34935 .67595 .35587 .68666 .35234 .68156 .34579 Metetra
.656 .751 .919 r
.68156 .34579 .68666 .35234 .69741 .3488 .69234 .34223 Metetra
.656 .751 .919 r
.69234 .34223 .69741 .3488 .7082 .34525 .70316 .33865 Metetra
.656 .751 .919 r
.70316 .33865 .7082 .34525 .71903 .34168 .71402 .33505 Metetra
.656 .751 .919 r
.71402 .33505 .71903 .34168 .7299 .33809 .72492 .33144 Metetra
.656 .751 .919 r
.72492 .33144 .7299 .33809 .74082 .3345 .73586 .32782 Metetra
.656 .751 .919 r
.73586 .32782 .74082 .3345 .75177 .33089 .74685 .32419 Metetra
.656 .751 .919 r
.74685 .32419 .75177 .33089 .76277 .32726 .75788 .32054 Metetra
.656 .751 .919 r
.75788 .32054 .76277 .32726 .77381 .32363 .76895 .31687 Metetra
.656 .751 .919 r
.76895 .31687 .77381 .32363 .7849 .31997 .78006 .3132 Metetra
.656 .751 .919 r
.78006 .3132 .7849 .31997 .79602 .31631 .79122 .3095 Metetra
.656 .751 .919 r
.79122 .3095 .79602 .31631 .80719 .31263 .80242 .3058 Metetra
.656 .751 .919 r
.80242 .3058 .80719 .31263 .81841 .30893 .81366 .30208 Metetra
.656 .751 .919 r
.81366 .30208 .81841 .30893 .82966 .30523 .82495 .29834 Metetra
.445 .612 .92 r
.18452 .49904 .19061 .50618 .19938 .50536 .19313 .49985 Metetra
.656 .751 .919 r
.19313 .49985 .19938 .50536 .2084 .50238 .20217 .49684 Metetra
.656 .751 .919 r
.20217 .49684 .2084 .50238 .21745 .49938 .21124 .49383 Metetra
.656 .751 .919 r
.21124 .49383 .21745 .49938 .22653 .49638 .22033 .4908 Metetra
.656 .751 .919 r
.22033 .4908 .22653 .49638 .23564 .49336 .22947 .48777 Metetra
.656 .751 .919 r
.22947 .48777 .23564 .49336 .24478 .49034 .23863 .48472 Metetra
.656 .751 .919 r
.23863 .48472 .24478 .49034 .25396 .4873 .24782 .48167 Metetra
.656 .751 .919 r
.24782 .48167 .25396 .4873 .26317 .48425 .25705 .4786 Metetra
.656 .751 .919 r
.25705 .4786 .26317 .48425 .27241 .4812 .26631 .47552 Metetra
.656 .751 .919 r
.26631 .47552 .27241 .4812 .28168 .47813 .27561 .47243 Metetra
.656 .751 .919 r
.27561 .47243 .28168 .47813 .29099 .47505 .28493 .46933 Metetra
.656 .751 .919 r
.28493 .46933 .29099 .47505 .30033 .47196 .29429 .46622 Metetra
.656 .751 .919 r
.29429 .46622 .30033 .47196 .3097 .46885 .30368 .4631 Metetra
.656 .751 .919 r
.30368 .4631 .3097 .46885 .31911 .46574 .31311 .45996 Metetra
.656 .751 .919 r
.31311 .45996 .31911 .46574 .32855 .46262 .32257 .45682 Metetra
.656 .751 .919 r
.32257 .45682 .32855 .46262 .33802 .45948 .33207 .45366 Metetra
.656 .751 .919 r
.33207 .45366 .33802 .45948 .34753 .45634 .34159 .4505 Metetra
.656 .751 .919 r
.34159 .4505 .34753 .45634 .35707 .45318 .35116 .44732 Metetra
.656 .751 .919 r
.35116 .44732 .35707 .45318 .36665 .45001 .36075 .44413 Metetra
.656 .751 .919 r
.36075 .44413 .36665 .45001 .37626 .44683 .37038 .44093 Metetra
.656 .751 .919 r
.37038 .44093 .37626 .44683 .3859 .44364 .38005 .43771 Metetra
.656 .751 .919 r
.38005 .43771 .3859 .44364 .39558 .44043 .38975 .43449 Metetra
.656 .751 .919 r
.38975 .43449 .39558 .44043 .4053 .43722 .39949 .43125 Metetra
.656 .751 .919 r
.39949 .43125 .4053 .43722 .41505 .43399 .40926 .428 Metetra
.656 .751 .919 r
.40926 .428 .41505 .43399 .42483 .43075 .41907 .42474 Metetra
.656 .751 .919 r
.41907 .42474 .42483 .43075 .43465 .4275 .42891 .42147 Metetra
.656 .751 .919 r
.42891 .42147 .43465 .4275 .44451 .42424 .43879 .41819 Metetra
.656 .751 .919 r
.43879 .41819 .44451 .42424 .4544 .42097 .44871 .41489 Metetra
.656 .751 .919 r
.44871 .41489 .4544 .42097 .46433 .41768 .45866 .41158 Metetra
.656 .751 .919 r
.45866 .41158 .46433 .41768 .4743 .41438 .46865 .40826 Metetra
.656 .751 .919 r
.46865 .40826 .4743 .41438 .4843 .41107 .47867 .40493 Metetra
.656 .751 .919 r
.47867 .40493 .4843 .41107 .49434 .40775 .48874 .40159 Metetra
.656 .751 .919 r
.48874 .40159 .49434 .40775 .50441 .40442 .49884 .39823 Metetra
.656 .751 .919 r
.49884 .39823 .50441 .40442 .51452 .40107 .50897 .39486 Metetra
.656 .751 .919 r
.50897 .39486 .51452 .40107 .52468 .39771 .51915 .39148 Metetra
.656 .751 .919 r
.51915 .39148 .52468 .39771 .53486 .39434 .52936 .38808 Metetra
.656 .751 .919 r
.52936 .38808 .53486 .39434 .54509 .39096 .53961 .38468 Metetra
.656 .751 .919 r
.53961 .38468 .54509 .39096 .55535 .38756 .5499 .38126 Metetra
.656 .751 .919 r
.5499 .38126 .55535 .38756 .56565 .38415 .56023 .37782 Metetra
.656 .751 .919 r
.56023 .37782 .56565 .38415 .57599 .38073 .57059 .37438 Metetra
.656 .751 .919 r
.57059 .37438 .57599 .38073 .58637 .37729 .581 .37092 Metetra
.656 .751 .919 r
.581 .37092 .58637 .37729 .59679 .37385 .59144 .36745 Metetra
.656 .751 .919 r
.59144 .36745 .59679 .37385 .60725 .37039 .60192 .36396 Metetra
.656 .751 .919 r
.60192 .36396 .60725 .37039 .61774 .36691 .61245 .36047 Metetra
.656 .751 .919 r
.61245 .36047 .61774 .36691 .62828 .36343 .62301 .35695 Metetra
.656 .751 .919 r
.62301 .35695 .62828 .36343 .63886 .35993 .63361 .35343 Metetra
.656 .751 .919 r
.63361 .35343 .63886 .35993 .64947 .35641 .64425 .34989 Metetra
.656 .751 .919 r
.64425 .34989 .64947 .35641 .66013 .35289 .65494 .34634 Metetra
.656 .751 .919 r
.65494 .34634 .66013 .35289 .67082 .34935 .66566 .34278 Metetra
.656 .751 .919 r
.66566 .34278 .67082 .34935 .68156 .34579 .67643 .3392 Metetra
.656 .751 .919 r
.67643 .3392 .68156 .34579 .69234 .34223 .68723 .33561 Metetra
.656 .751 .919 r
.68723 .33561 .69234 .34223 .70316 .33865 .69808 .332 Metetra
.656 .751 .919 r
.69808 .332 .70316 .33865 .71402 .33505 .70897 .32838 Metetra
.656 .751 .919 r
.70897 .32838 .71402 .33505 .72492 .33144 .7199 .32475 Metetra
.656 .751 .919 r
.7199 .32475 .72492 .33144 .73586 .32782 .73087 .3211 Metetra
.656 .751 .919 r
.73087 .3211 .73586 .32782 .74685 .32419 .74189 .31744 Metetra
.656 .751 .919 r
.74189 .31744 .74685 .32419 .75788 .32054 .75295 .31376 Metetra
.656 .751 .919 r
.75295 .31376 .75788 .32054 .76895 .31687 .76405 .31007 Metetra
.656 .751 .919 r
.76405 .31007 .76895 .31687 .78006 .3132 .77519 .30637 Metetra
.656 .751 .919 r
.77519 .30637 .78006 .3132 .79122 .3095 .78638 .30265 Metetra
.656 .751 .919 r
.78638 .30265 .79122 .3095 .80242 .3058 .79761 .29892 Metetra
.656 .751 .919 r
.79761 .29892 .80242 .3058 .81366 .30208 .80889 .29517 Metetra
.656 .751 .919 r
.80889 .29517 .81366 .30208 .82495 .29834 .82021 .29141 Metetra
.722 .942 .629 r
.17691 .50607 .18452 .49904 .19313 .49985 .18684 .49429 Metetra
.656 .751 .919 r
.18684 .49429 .19313 .49985 .20217 .49684 .1959 .49127 Metetra
.656 .751 .919 r
.1959 .49127 .20217 .49684 .21124 .49383 .20498 .48824 Metetra
.656 .751 .919 r
.20498 .48824 .21124 .49383 .22033 .4908 .2141 .48519 Metetra
.656 .751 .919 r
.2141 .48519 .22033 .4908 .22947 .48777 .22325 .48214 Metetra
.656 .751 .919 r
.22325 .48214 .22947 .48777 .23863 .48472 .23243 .47907 Metetra
.656 .751 .919 r
.23243 .47907 .23863 .48472 .24782 .48167 .24165 .47599 Metetra
.656 .751 .919 r
.24165 .47599 .24782 .48167 .25705 .4786 .25089 .47291 Metetra
.656 .751 .919 r
.25089 .47291 .25705 .4786 .26631 .47552 .26017 .46981 Metetra
.656 .751 .919 r
.26017 .46981 .26631 .47552 .27561 .47243 .26949 .4667 Metetra
.656 .751 .919 r
.26949 .4667 .27561 .47243 .28493 .46933 .27883 .46358 Metetra
.656 .751 .919 r
.27883 .46358 .28493 .46933 .29429 .46622 .28821 .46045 Metetra
.656 .751 .919 r
.28821 .46045 .29429 .46622 .30368 .4631 .29763 .4573 Metetra
.656 .751 .919 r
.29763 .4573 .30368 .4631 .31311 .45996 .30707 .45415 Metetra
.656 .751 .919 r
.30707 .45415 .31311 .45996 .32257 .45682 .31655 .45099 Metetra
.656 .751 .919 r
.31655 .45099 .32257 .45682 .33207 .45366 .32607 .44781 Metetra
.656 .751 .919 r
.32607 .44781 .33207 .45366 .34159 .4505 .33562 .44462 Metetra
.656 .751 .919 r
.33562 .44462 .34159 .4505 .35116 .44732 .3452 .44142 Metetra
.656 .751 .919 r
.3452 .44142 .35116 .44732 .36075 .44413 .35482 .43821 Metetra
.656 .751 .919 r
.35482 .43821 .36075 .44413 .37038 .44093 .36447 .43499 Metetra
.656 .751 .919 r
.36447 .43499 .37038 .44093 .38005 .43771 .37416 .43175 Metetra
.656 .751 .919 r
.37416 .43175 .38005 .43771 .38975 .43449 .38388 .4285 Metetra
.656 .751 .919 r
.38388 .4285 .38975 .43449 .39949 .43125 .39364 .42525 Metetra
.656 .751 .919 r
.39364 .42525 .39949 .43125 .40926 .428 .40344 .42198 Metetra
.656 .751 .919 r
.40344 .42198 .40926 .428 .41907 .42474 .41327 .41869 Metetra
.656 .751 .919 r
.41327 .41869 .41907 .42474 .42891 .42147 .42313 .4154 Metetra
.656 .751 .919 r
.42313 .4154 .42891 .42147 .43879 .41819 .43304 .41209 Metetra
.656 .751 .919 r
.43304 .41209 .43879 .41819 .44871 .41489 .44297 .40878 Metetra
.656 .751 .919 r
.44297 .40878 .44871 .41489 .45866 .41158 .45295 .40545 Metetra
.656 .751 .919 r
.45295 .40545 .45866 .41158 .46865 .40826 .46296 .4021 Metetra
.656 .751 .919 r
.46296 .4021 .46865 .40826 .47867 .40493 .47301 .39875 Metetra
.656 .751 .919 r
.47301 .39875 .47867 .40493 .48874 .40159 .4831 .39538 Metetra
.656 .751 .919 r
.4831 .39538 .48874 .40159 .49884 .39823 .49322 .392 Metetra
.656 .751 .919 r
.49322 .392 .49884 .39823 .50897 .39486 .50338 .38861 Metetra
.656 .751 .919 r
.50338 .38861 .50897 .39486 .51915 .39148 .51358 .3852 Metetra
.656 .751 .919 r
.51358 .3852 .51915 .39148 .52936 .38808 .52382 .38178 Metetra
.656 .751 .919 r
.52382 .38178 .52936 .38808 .53961 .38468 .53409 .37835 Metetra
.656 .751 .919 r
.53409 .37835 .53961 .38468 .5499 .38126 .54441 .37491 Metetra
.656 .751 .919 r
.54441 .37491 .5499 .38126 .56023 .37782 .55476 .37145 Metetra
.656 .751 .919 r
.55476 .37145 .56023 .37782 .57059 .37438 .56515 .36798 Metetra
.656 .751 .919 r
.56515 .36798 .57059 .37438 .581 .37092 .57558 .3645 Metetra
.656 .751 .919 r
.57558 .3645 .581 .37092 .59144 .36745 .58605 .361 Metetra
.656 .751 .919 r
.58605 .361 .59144 .36745 .60192 .36396 .59656 .3575 Metetra
.656 .751 .919 r
.59656 .3575 .60192 .36396 .61245 .36047 .60711 .35397 Metetra
.656 .751 .919 r
.60711 .35397 .61245 .36047 .62301 .35695 .6177 .35044 Metetra
.656 .751 .919 r
.6177 .35044 .62301 .35695 .63361 .35343 .62833 .34689 Metetra
.656 .751 .919 r
.62833 .34689 .63361 .35343 .64425 .34989 .639 .34333 Metetra
.656 .751 .919 r
.639 .34333 .64425 .34989 .65494 .34634 .64971 .33975 Metetra
.656 .751 .919 r
.64971 .33975 .65494 .34634 .66566 .34278 .66046 .33616 Metetra
.656 .751 .919 r
.66046 .33616 .66566 .34278 .67643 .3392 .67126 .33256 Metetra
.656 .751 .919 r
.67126 .33256 .67643 .3392 .68723 .33561 .68209 .32894 Metetra
.656 .751 .919 r
.68209 .32894 .68723 .33561 .69808 .332 .69297 .32531 Metetra
.656 .751 .919 r
.69297 .32531 .69808 .332 .70897 .32838 .70389 .32166 Metetra
.656 .751 .919 r
.70389 .32166 .70897 .32838 .7199 .32475 .71485 .318 Metetra
.656 .751 .919 r
.71485 .318 .7199 .32475 .73087 .3211 .72585 .31433 Metetra
.656 .751 .919 r
.72585 .31433 .73087 .3211 .74189 .31744 .73689 .31064 Metetra
.656 .751 .919 r
.73689 .31064 .74189 .31744 .75295 .31376 .74798 .30694 Metetra
.656 .751 .919 r
.74798 .30694 .75295 .31376 .76405 .31007 .75911 .30322 Metetra
.656 .751 .919 r
.75911 .30322 .76405 .31007 .77519 .30637 .77029 .29949 Metetra
.656 .751 .919 r
.77029 .29949 .77519 .30637 .78638 .30265 .78151 .29575 Metetra
.656 .751 .919 r
.78151 .29575 .78638 .30265 .79761 .29892 .79277 .29199 Metetra
.656 .751 .919 r
.79277 .29199 .79761 .29892 .80889 .29517 .80407 .28821 Metetra
.656 .751 .919 r
.80407 .28821 .80889 .29517 .82021 .29141 .81542 .28442 Metetra
.411 .343 .671 r
.17239 .48318 .17691 .50607 .18684 .49429 .18052 .4887 Metetra
.656 .751 .919 r
.18052 .4887 .18684 .49429 .1959 .49127 .18959 .48566 Metetra
.656 .751 .919 r
.18959 .48566 .1959 .49127 .20498 .48824 .19869 .48261 Metetra
.656 .751 .919 r
.19869 .48261 .20498 .48824 .2141 .48519 .20783 .47954 Metetra
.656 .751 .919 r
.20783 .47954 .2141 .48519 .22325 .48214 .217 .47647 Metetra
.656 .751 .919 r
.217 .47647 .22325 .48214 .23243 .47907 .2262 .47338 Metetra
.656 .751 .919 r
.2262 .47338 .23243 .47907 .24165 .47599 .23543 .47029 Metetra
.656 .751 .919 r
.23543 .47029 .24165 .47599 .25089 .47291 .2447 .46718 Metetra
.656 .751 .919 r
.2447 .46718 .25089 .47291 .26017 .46981 .254 .46406 Metetra
.656 .751 .919 r
.254 .46406 .26017 .46981 .26949 .4667 .26333 .46093 Metetra
.656 .751 .919 r
.26333 .46093 .26949 .4667 .27883 .46358 .27269 .45779 Metetra
.656 .751 .919 r
.27269 .45779 .27883 .46358 .28821 .46045 .28209 .45464 Metetra
.656 .751 .919 r
.28209 .45464 .28821 .46045 .29763 .4573 .29153 .45147 Metetra
.656 .751 .919 r
.29153 .45147 .29763 .4573 .30707 .45415 .30099 .4483 Metetra
.656 .751 .919 r
.30099 .4483 .30707 .45415 .31655 .45099 .3105 .44511 Metetra
.656 .751 .919 r
.3105 .44511 .31655 .45099 .32607 .44781 .32003 .44191 Metetra
.656 .751 .919 r
.32003 .44191 .32607 .44781 .33562 .44462 .3296 .4387 Metetra
.656 .751 .919 r
.3296 .4387 .33562 .44462 .3452 .44142 .33921 .43548 Metetra
.656 .751 .919 r
.33921 .43548 .3452 .44142 .35482 .43821 .34885 .43225 Metetra
.656 .751 .919 r
.34885 .43225 .35482 .43821 .36447 .43499 .35852 .42901 Metetra
.656 .751 .919 r
.35852 .42901 .36447 .43499 .37416 .43175 .36823 .42575 Metetra
.656 .751 .919 r
.36823 .42575 .37416 .43175 .38388 .4285 .37798 .42248 Metetra
.656 .751 .919 r
.37798 .42248 .38388 .4285 .39364 .42525 .38776 .4192 Metetra
.656 .751 .919 r
.38776 .4192 .39364 .42525 .40344 .42198 .39757 .41591 Metetra
.656 .751 .919 r
.39757 .41591 .40344 .42198 .41327 .41869 .40743 .4126 Metetra
.656 .751 .919 r
.40743 .4126 .41327 .41869 .42313 .4154 .41731 .40929 Metetra
.656 .751 .919 r
.41731 .40929 .42313 .4154 .43304 .41209 .42724 .40596 Metetra
.656 .751 .919 r
.42724 .40596 .43304 .41209 .44297 .40878 .4372 .40262 Metetra
.656 .751 .919 r
.4372 .40262 .44297 .40878 .45295 .40545 .4472 .39926 Metetra
.656 .751 .919 r
.4472 .39926 .45295 .40545 .46296 .4021 .45724 .3959 Metetra
.656 .751 .919 r
.45724 .3959 .46296 .4021 .47301 .39875 .46731 .39252 Metetra
.656 .751 .919 r
.46731 .39252 .47301 .39875 .4831 .39538 .47742 .38913 Metetra
.656 .751 .919 r
.47742 .38913 .4831 .39538 .49322 .392 .48757 .38573 Metetra
.656 .751 .919 r
.48757 .38573 .49322 .392 .50338 .38861 .49775 .38231 Metetra
.656 .751 .919 r
.49775 .38231 .50338 .38861 .51358 .3852 .50798 .37888 Metetra
.656 .751 .919 r
.50798 .37888 .51358 .3852 .52382 .38178 .51824 .37544 Metetra
.656 .751 .919 r
.51824 .37544 .52382 .38178 .53409 .37835 .52854 .37198 Metetra
.656 .751 .919 r
.52854 .37198 .53409 .37835 .54441 .37491 .53888 .36852 Metetra
.656 .751 .919 r
.53888 .36852 .54441 .37491 .55476 .37145 .54926 .36504 Metetra
.656 .751 .919 r
.54926 .36504 .55476 .37145 .56515 .36798 .55967 .36154 Metetra
.656 .751 .919 r
.55967 .36154 .56515 .36798 .57558 .3645 .57013 .35804 Metetra
.656 .751 .919 r
.57013 .35804 .57558 .3645 .58605 .361 .58063 .35452 Metetra
.656 .751 .919 r
.58063 .35452 .58605 .361 .59656 .3575 .59116 .35098 Metetra
.656 .751 .919 r
.59116 .35098 .59656 .3575 .60711 .35397 .60174 .34744 Metetra
.656 .751 .919 r
.60174 .34744 .60711 .35397 .6177 .35044 .61236 .34387 Metetra
.656 .751 .919 r
.61236 .34387 .6177 .35044 .62833 .34689 .62301 .3403 Metetra
.656 .751 .919 r
.62301 .3403 .62833 .34689 .639 .34333 .63371 .33671 Metetra
.656 .751 .919 r
.63371 .33671 .639 .34333 .64971 .33975 .64445 .33311 Metetra
.656 .751 .919 r
.64445 .33311 .64971 .33975 .66046 .33616 .65523 .3295 Metetra
.656 .751 .919 r
.65523 .3295 .66046 .33616 .67126 .33256 .66605 .32587 Metetra
.656 .751 .919 r
.66605 .32587 .67126 .33256 .68209 .32894 .67691 .32222 Metetra
.656 .751 .919 r
.67691 .32222 .68209 .32894 .69297 .32531 .68782 .31857 Metetra
.656 .751 .919 r
.68782 .31857 .69297 .32531 .70389 .32166 .69877 .31489 Metetra
.656 .751 .919 r
.69877 .31489 .70389 .32166 .71485 .318 .70975 .31121 Metetra
.656 .751 .919 r
.70975 .31121 .71485 .318 .72585 .31433 .72079 .30751 Metetra
.656 .751 .919 r
.72079 .30751 .72585 .31433 .73689 .31064 .73186 .3038 Metetra
.656 .751 .919 r
.73186 .3038 .73689 .31064 .74798 .30694 .74298 .30007 Metetra
.656 .751 .919 r
.74298 .30007 .74798 .30694 .75911 .30322 .75414 .29632 Metetra
.656 .751 .919 r
.75414 .29632 .75911 .30322 .77029 .29949 .76535 .29257 Metetra
.656 .751 .919 r
.76535 .29257 .77029 .29949 .78151 .29575 .7766 .28879 Metetra
.656 .751 .919 r
.7766 .28879 .78151 .29575 .79277 .29199 .78789 .285 Metetra
.656 .751 .919 r
.78789 .285 .79277 .29199 .80407 .28821 .79923 .2812 Metetra
.656 .751 .919 r
.79923 .2812 .80407 .28821 .81542 .28442 .81061 .27739 Metetra
.16486 .4882 .17239 .48318 .18052 .4887 .17415 .48308 Metetra
.656 .751 .919 r
.17415 .48308 .18052 .4887 .18959 .48566 .18324 .48002 Metetra
.656 .751 .919 r
.18324 .48002 .18959 .48566 .19869 .48261 .19236 .47694 Metetra
.656 .751 .919 r
.19236 .47694 .19869 .48261 .20783 .47954 .20151 .47386 Metetra
.656 .751 .919 r
.20151 .47386 .20783 .47954 .217 .47647 .2107 .47076 Metetra
.656 .751 .919 r
.2107 .47076 .217 .47647 .2262 .47338 .21992 .46766 Metetra
.656 .751 .919 r
.21992 .46766 .2262 .47338 .23543 .47029 .22917 .46454 Metetra
.656 .751 .919 r
.22917 .46454 .23543 .47029 .2447 .46718 .23846 .46141 Metetra
.656 .751 .919 r
.23846 .46141 .2447 .46718 .254 .46406 .24778 .45827 Metetra
.656 .751 .919 r
.24778 .45827 .254 .46406 .26333 .46093 .25713 .45512 Metetra
.656 .751 .919 r
.25713 .45512 .26333 .46093 .27269 .45779 .26652 .45196 Metetra
.656 .751 .919 r
.26652 .45196 .27269 .45779 .28209 .45464 .27594 .44879 Metetra
.656 .751 .919 r
.27594 .44879 .28209 .45464 .29153 .45147 .28539 .4456 Metetra
.656 .751 .919 r
.28539 .4456 .29153 .45147 .30099 .4483 .29488 .44241 Metetra
.656 .751 .919 r
.29488 .44241 .30099 .4483 .3105 .44511 .3044 .4392 Metetra
.656 .751 .919 r
.3044 .4392 .3105 .44511 .32003 .44191 .31395 .43598 Metetra
.656 .751 .919 r
.31395 .43598 .32003 .44191 .3296 .4387 .32355 .43275 Metetra
.656 .751 .919 r
.32355 .43275 .3296 .4387 .33921 .43548 .33317 .4295 Metetra
.656 .751 .919 r
.33317 .4295 .33921 .43548 .34885 .43225 .34283 .42625 Metetra
.656 .751 .919 r
.34283 .42625 .34885 .43225 .35852 .42901 .35253 .42298 Metetra
.656 .751 .919 r
.35253 .42298 .35852 .42901 .36823 .42575 .36226 .41971 Metetra
.656 .751 .919 r
.36226 .41971 .36823 .42575 .37798 .42248 .37203 .41642 Metetra
.656 .751 .919 r
.37203 .41642 .37798 .42248 .38776 .4192 .38183 .41311 Metetra
.656 .751 .919 r
.38183 .41311 .38776 .4192 .39757 .41591 .39167 .4098 Metetra
.656 .751 .919 r
.39167 .4098 .39757 .41591 .40743 .4126 .40154 .40647 Metetra
.656 .751 .919 r
.40154 .40647 .40743 .4126 .41731 .40929 .41146 .40313 Metetra
.656 .751 .919 r
.41146 .40313 .41731 .40929 .42724 .40596 .4214 .39978 Metetra
.656 .751 .919 r
.4214 .39978 .42724 .40596 .4372 .40262 .43139 .39642 Metetra
.656 .751 .919 r
.43139 .39642 .4372 .40262 .4472 .39926 .44141 .39304 Metetra
.656 .751 .919 r
.44141 .39304 .4472 .39926 .45724 .3959 .45147 .38965 Metetra
.656 .751 .919 r
.45147 .38965 .45724 .3959 .46731 .39252 .46157 .38625 Metetra
.656 .751 .919 r
.46157 .38625 .46731 .39252 .47742 .38913 .4717 .38284 Metetra
.656 .751 .919 r
.4717 .38284 .47742 .38913 .48757 .38573 .48187 .37941 Metetra
.656 .751 .919 r
.48187 .37941 .48757 .38573 .49775 .38231 .49208 .37597 Metetra
.656 .751 .919 r
.49208 .37597 .49775 .38231 .50798 .37888 .50233 .37252 Metetra
.656 .751 .919 r
.50233 .37252 .50798 .37888 .51824 .37544 .51262 .36905 Metetra
.656 .751 .919 r
.51262 .36905 .51824 .37544 .52854 .37198 .52295 .36557 Metetra
.656 .751 .919 r
.52295 .36557 .52854 .37198 .53888 .36852 .53331 .36208 Metetra
.656 .751 .919 r
.53331 .36208 .53888 .36852 .54926 .36504 .54372 .35858 Metetra
.656 .751 .919 r
.54372 .35858 .54926 .36504 .55967 .36154 .55416 .35506 Metetra
.656 .751 .919 r
.55416 .35506 .55967 .36154 .57013 .35804 .56464 .35153 Metetra
.656 .751 .919 r
.56464 .35153 .57013 .35804 .58063 .35452 .57516 .34798 Metetra
.656 .751 .919 r
.57516 .34798 .58063 .35452 .59116 .35098 .58573 .34442 Metetra
.656 .751 .919 r
.58573 .34442 .59116 .35098 .60174 .34744 .59633 .34085 Metetra
.656 .751 .919 r
.59633 .34085 .60174 .34744 .61236 .34387 .60697 .33727 Metetra
.656 .751 .919 r
.60697 .33727 .61236 .34387 .62301 .3403 .61766 .33367 Metetra
.656 .751 .919 r
.61766 .33367 .62301 .3403 .63371 .33671 .62838 .33005 Metetra
.656 .751 .919 r
.62838 .33005 .63371 .33671 .64445 .33311 .63915 .32643 Metetra
.656 .751 .919 r
.63915 .32643 .64445 .33311 .65523 .3295 .64996 .32279 Metetra
.656 .751 .919 r
.64996 .32279 .65523 .3295 .66605 .32587 .66081 .31913 Metetra
.656 .751 .919 r
.66081 .31913 .66605 .32587 .67691 .32222 .6717 .31546 Metetra
.656 .751 .919 r
.6717 .31546 .67691 .32222 .68782 .31857 .68263 .31178 Metetra
.656 .751 .919 r
.68263 .31178 .68782 .31857 .69877 .31489 .69361 .30808 Metetra
.656 .751 .919 r
.69361 .30808 .69877 .31489 .70975 .31121 .70463 .30437 Metetra
.656 .751 .919 r
.70463 .30437 .70975 .31121 .72079 .30751 .71569 .30064 Metetra
.656 .751 .919 r
.71569 .30064 .72079 .30751 .73186 .3038 .72679 .2969 Metetra
.656 .751 .919 r
.72679 .2969 .73186 .3038 .74298 .30007 .73794 .29314 Metetra
.656 .751 .919 r
.73794 .29314 .74298 .30007 .75414 .29632 .74913 .28937 Metetra
.656 .751 .919 r
.74913 .28937 .75414 .29632 .76535 .29257 .76037 .28559 Metetra
.656 .751 .919 r
.76037 .28559 .76535 .29257 .7766 .28879 .77165 .28179 Metetra
.656 .751 .919 r
.77165 .28179 .7766 .28879 .78789 .285 .78298 .27797 Metetra
.656 .751 .919 r
.78298 .27797 .78789 .285 .79923 .2812 .79434 .27414 Metetra
.656 .751 .919 r
.79434 .27414 .79923 .2812 .81061 .27739 .80576 .2703 Metetra
.884 .922 .844 r
.15782 .48804 .16486 .4882 .17415 .48308 .16773 .47742 Metetra
.656 .751 .919 r
.16773 .47742 .17415 .48308 .18324 .48002 .17684 .47433 Metetra
.656 .751 .919 r
.17684 .47433 .18324 .48002 .19236 .47694 .18598 .47124 Metetra
.656 .751 .919 r
.18598 .47124 .19236 .47694 .20151 .47386 .19516 .46814 Metetra
.656 .751 .919 r
.19516 .46814 .20151 .47386 .2107 .47076 .20436 .46502 Metetra
.656 .751 .919 r
.20436 .46502 .2107 .47076 .21992 .46766 .2136 .46189 Metetra
.656 .751 .919 r
.2136 .46189 .21992 .46766 .22917 .46454 .22287 .45876 Metetra
.656 .751 .919 r
.22287 .45876 .22917 .46454 .23846 .46141 .23218 .45561 Metetra
.656 .751 .919 r
.23218 .45561 .23846 .46141 .24778 .45827 .24152 .45245 Metetra
.656 .751 .919 r
.24152 .45245 .24778 .45827 .25713 .45512 .25089 .44928 Metetra
.656 .751 .919 r
.25089 .44928 .25713 .45512 .26652 .45196 .26029 .44609 Metetra
.656 .751 .919 r
.26029 .44609 .26652 .45196 .27594 .44879 .26973 .4429 Metetra
.656 .751 .919 r
.26973 .4429 .27594 .44879 .28539 .4456 .27921 .43969 Metetra
.656 .751 .919 r
.27921 .43969 .28539 .4456 .29488 .44241 .28872 .43647 Metetra
.656 .751 .919 r
.28872 .43647 .29488 .44241 .3044 .4392 .29826 .43325 Metetra
.656 .751 .919 r
.29826 .43325 .3044 .4392 .31395 .43598 .30784 .43 Metetra
.656 .751 .919 r
.30784 .43 .31395 .43598 .32355 .43275 .31745 .42675 Metetra
.656 .751 .919 r
.31745 .42675 .32355 .43275 .33317 .4295 .3271 .42349 Metetra
.656 .751 .919 r
.3271 .42349 .33317 .4295 .34283 .42625 .33678 .42021 Metetra
.656 .751 .919 r
.33678 .42021 .34283 .42625 .35253 .42298 .3465 .41692 Metetra
.656 .751 .919 r
.3465 .41692 .35253 .42298 .36226 .41971 .35625 .41362 Metetra
.656 .751 .919 r
.35625 .41362 .36226 .41971 .37203 .41642 .36604 .41031 Metetra
.656 .751 .919 r
.36604 .41031 .37203 .41642 .38183 .41311 .37586 .40698 Metetra
.656 .751 .919 r
.37586 .40698 .38183 .41311 .39167 .4098 .38573 .40365 Metetra
.656 .751 .919 r
.38573 .40365 .39167 .4098 .40154 .40647 .39562 .4003 Metetra
.656 .751 .919 r
.39562 .4003 .40154 .40647 .41146 .40313 .40556 .39694 Metetra
.656 .751 .919 r
.40556 .39694 .41146 .40313 .4214 .39978 .41553 .39356 Metetra
.656 .751 .919 r
.41553 .39356 .4214 .39978 .43139 .39642 .42554 .39017 Metetra
.656 .751 .919 r
.42554 .39017 .43139 .39642 .44141 .39304 .43558 .38677 Metetra
.656 .751 .919 r
.43558 .38677 .44141 .39304 .45147 .38965 .44567 .38336 Metetra
.656 .751 .919 r
.44567 .38336 .45147 .38965 .46157 .38625 .45579 .37994 Metetra
.656 .751 .919 r
.45579 .37994 .46157 .38625 .4717 .38284 .46595 .3765 Metetra
.656 .751 .919 r
.46595 .3765 .4717 .38284 .48187 .37941 .47614 .37305 Metetra
.656 .751 .919 r
.47614 .37305 .48187 .37941 .49208 .37597 .48638 .36959 Metetra
.656 .751 .919 r
.48638 .36959 .49208 .37597 .50233 .37252 .49665 .36611 Metetra
.656 .751 .919 r
.49665 .36611 .50233 .37252 .51262 .36905 .50696 .36262 Metetra
.656 .751 .919 r
.50696 .36262 .51262 .36905 .52295 .36557 .51731 .35912 Metetra
.656 .751 .919 r
.51731 .35912 .52295 .36557 .53331 .36208 .5277 .3556 Metetra
.656 .751 .919 r
.5277 .3556 .53331 .36208 .54372 .35858 .53813 .35207 Metetra
.656 .751 .919 r
.53813 .35207 .54372 .35858 .55416 .35506 .5486 .34853 Metetra
.656 .751 .919 r
.5486 .34853 .55416 .35506 .56464 .35153 .55911 .34497 Metetra
.656 .751 .919 r
.55911 .34497 .56464 .35153 .57516 .34798 .56966 .3414 Metetra
.656 .751 .919 r
.56966 .3414 .57516 .34798 .58573 .34442 .58025 .33782 Metetra
.656 .751 .919 r
.58025 .33782 .58573 .34442 .59633 .34085 .59088 .33422 Metetra
.656 .751 .919 r
.59088 .33422 .59633 .34085 .60697 .33727 .60155 .33061 Metetra
.656 .751 .919 r
.60155 .33061 .60697 .33727 .61766 .33367 .61226 .32698 Metetra
.656 .751 .919 r
.61226 .32698 .61766 .33367 .62838 .33005 .62302 .32335 Metetra
.656 .751 .919 r
.62302 .32335 .62838 .33005 .63915 .32643 .63381 .31969 Metetra
.656 .751 .919 r
.63381 .31969 .63915 .32643 .64996 .32279 .64465 .31603 Metetra
.656 .751 .919 r
.64465 .31603 .64996 .32279 .66081 .31913 .65553 .31234 Metetra
.656 .751 .919 r
.65553 .31234 .66081 .31913 .6717 .31546 .66645 .30865 Metetra
.656 .751 .919 r
.66645 .30865 .6717 .31546 .68263 .31178 .67741 .30494 Metetra
.656 .751 .919 r
.67741 .30494 .68263 .31178 .69361 .30808 .68841 .30122 Metetra
.656 .751 .919 r
.68841 .30122 .69361 .30808 .70463 .30437 .69946 .29748 Metetra
.656 .751 .919 r
.69946 .29748 .70463 .30437 .71569 .30064 .71055 .29372 Metetra
.656 .751 .919 r
.71055 .29372 .71569 .30064 .72679 .2969 .72169 .28995 Metetra
.656 .751 .919 r
.72169 .28995 .72679 .2969 .73794 .29314 .73287 .28617 Metetra
.656 .751 .919 r
.73287 .28617 .73794 .29314 .74913 .28937 .74409 .28237 Metetra
.656 .751 .919 r
.74409 .28237 .74913 .28937 .76037 .28559 .75536 .27856 Metetra
.656 .751 .919 r
.75536 .27856 .76037 .28559 .77165 .28179 .76667 .27473 Metetra
.656 .751 .919 r
.76667 .27473 .77165 .28179 .78298 .27797 .77803 .27089 Metetra
.656 .751 .919 r
.77803 .27089 .78298 .27797 .79434 .27414 .78943 .26703 Metetra
.656 .751 .919 r
.78943 .26703 .79434 .27414 .80576 .2703 .80087 .26316 Metetra
.274 .224 .618 r
.15376 .46089 .15782 .48804 .16773 .47742 .16128 .47172 Metetra
.656 .751 .919 r
.16128 .47172 .16773 .47742 .17684 .47433 .17041 .46861 Metetra
.656 .751 .919 r
.17041 .46861 .17684 .47433 .18598 .47124 .17957 .4655 Metetra
.656 .751 .919 r
.17957 .4655 .18598 .47124 .19516 .46814 .18876 .46238 Metetra
.656 .751 .919 r
.18876 .46238 .19516 .46814 .20436 .46502 .19798 .45924 Metetra
.656 .751 .919 r
.19798 .45924 .20436 .46502 .2136 .46189 .20724 .45609 Metetra
.656 .751 .919 r
.20724 .45609 .2136 .46189 .22287 .45876 .21653 .45293 Metetra
.656 .751 .919 r
.21653 .45293 .22287 .45876 .23218 .45561 .22586 .44976 Metetra
.656 .751 .919 r
.22586 .44976 .23218 .45561 .24152 .45245 .23522 .44658 Metetra
.656 .751 .919 r
.23522 .44658 .24152 .45245 .25089 .44928 .24461 .44339 Metetra
.656 .751 .919 r
.24461 .44339 .25089 .44928 .26029 .44609 .25403 .44019 Metetra
.656 .751 .919 r
.25403 .44019 .26029 .44609 .26973 .4429 .26349 .43697 Metetra
.656 .751 .919 r
.26349 .43697 .26973 .4429 .27921 .43969 .27299 .43374 Metetra
.656 .751 .919 r
.27299 .43374 .27921 .43969 .28872 .43647 .28252 .4305 Metetra
.656 .751 .919 r
.28252 .4305 .28872 .43647 .29826 .43325 .29208 .42725 Metetra
.656 .751 .919 r
.29208 .42725 .29826 .43325 .30784 .43 .30168 .42399 Metetra
.656 .751 .919 r
.30168 .42399 .30784 .43 .31745 .42675 .31131 .42072 Metetra
.656 .751 .919 r
.31131 .42072 .31745 .42675 .3271 .42349 .32098 .41743 Metetra
.656 .751 .919 r
.32098 .41743 .3271 .42349 .33678 .42021 .33068 .41413 Metetra
.656 .751 .919 r
.33068 .41413 .33678 .42021 .3465 .41692 .34042 .41082 Metetra
.656 .751 .919 r
.34042 .41082 .3465 .41692 .35625 .41362 .3502 .4075 Metetra
.656 .751 .919 r
.3502 .4075 .35625 .41362 .36604 .41031 .36001 .40416 Metetra
.656 .751 .919 r
.36001 .40416 .36604 .41031 .37586 .40698 .36986 .40081 Metetra
.656 .751 .919 r
.36986 .40081 .37586 .40698 .38573 .40365 .37974 .39745 Metetra
.656 .751 .919 r
.37974 .39745 .38573 .40365 .39562 .4003 .38966 .39408 Metetra
.656 .751 .919 r
.38966 .39408 .39562 .4003 .40556 .39694 .39962 .3907 Metetra
.656 .751 .919 r
.39962 .3907 .40556 .39694 .41553 .39356 .40961 .3873 Metetra
.656 .751 .919 r
.40961 .3873 .41553 .39356 .42554 .39017 .41965 .38389 Metetra
.656 .751 .919 r
.41965 .38389 .42554 .39017 .43558 .38677 .42972 .38047 Metetra
.656 .751 .919 r
.42972 .38047 .43558 .38677 .44567 .38336 .43982 .37703 Metetra
.656 .751 .919 r
.43982 .37703 .44567 .38336 .45579 .37994 .44997 .37358 Metetra
.656 .751 .919 r
.44997 .37358 .45579 .37994 .46595 .3765 .46015 .37012 Metetra
.656 .751 .919 r
.46015 .37012 .46595 .3765 .47614 .37305 .47037 .36664 Metetra
.656 .751 .919 r
.47037 .36664 .47614 .37305 .48638 .36959 .48063 .36316 Metetra
.656 .751 .919 r
.48063 .36316 .48638 .36959 .49665 .36611 .49093 .35966 Metetra
.656 .751 .919 r
.49093 .35966 .49665 .36611 .50696 .36262 .50127 .35614 Metetra
.656 .751 .919 r
.50127 .35614 .50696 .36262 .51731 .35912 .51164 .35261 Metetra
.656 .751 .919 r
.51164 .35261 .51731 .35912 .5277 .3556 .52206 .34907 Metetra
.656 .751 .919 r
.52206 .34907 .5277 .3556 .53813 .35207 .53251 .34552 Metetra
.656 .751 .919 r
.53251 .34552 .53813 .35207 .5486 .34853 .54301 .34195 Metetra
.656 .751 .919 r
.54301 .34195 .5486 .34853 .55911 .34497 .55355 .33837 Metetra
.656 .751 .919 r
.55355 .33837 .55911 .34497 .56966 .3414 .56412 .33478 Metetra
.656 .751 .919 r
.56412 .33478 .56966 .3414 .58025 .33782 .57474 .33117 Metetra
.656 .751 .919 r
.57474 .33117 .58025 .33782 .59088 .33422 .58539 .32754 Metetra
.656 .751 .919 r
.58539 .32754 .59088 .33422 .60155 .33061 .59609 .32391 Metetra
.656 .751 .919 r
.59609 .32391 .60155 .33061 .61226 .32698 .60683 .32026 Metetra
.656 .751 .919 r
.60683 .32026 .61226 .32698 .62302 .32335 .61761 .31659 Metetra
.656 .751 .919 r
.61761 .31659 .62302 .32335 .63381 .31969 .62844 .31291 Metetra
.656 .751 .919 r
.62844 .31291 .63381 .31969 .64465 .31603 .6393 .30922 Metetra
.656 .751 .919 r
.6393 .30922 .64465 .31603 .65553 .31234 .65021 .30551 Metetra
.656 .751 .919 r
.65021 .30551 .65553 .31234 .66645 .30865 .66116 .30179 Metetra
.656 .751 .919 r
.66116 .30179 .66645 .30865 .67741 .30494 .67215 .29805 Metetra
.656 .751 .919 r
.67215 .29805 .67741 .30494 .68841 .30122 .68318 .2943 Metetra
.656 .751 .919 r
.68318 .2943 .68841 .30122 .69946 .29748 .69426 .29054 Metetra
.656 .751 .919 r
.69426 .29054 .69946 .29748 .71055 .29372 .70538 .28675 Metetra
.656 .751 .919 r
.70538 .28675 .71055 .29372 .72169 .28995 .71655 .28296 Metetra
.656 .751 .919 r
.71655 .28296 .72169 .28995 .73287 .28617 .72776 .27915 Metetra
.656 .751 .919 r
.72776 .27915 .73287 .28617 .74409 .28237 .73901 .27532 Metetra
.656 .751 .919 r
.73901 .27532 .74409 .28237 .75536 .27856 .75031 .27148 Metetra
.656 .751 .919 r
.75031 .27148 .75536 .27856 .76667 .27473 .76165 .26763 Metetra
.656 .751 .919 r
.76165 .26763 .76667 .27473 .77803 .27089 .77304 .26376 Metetra
.656 .751 .919 r
.77304 .26376 .77803 .27089 .78943 .26703 .78447 .25987 Metetra
.656 .751 .919 r
.78447 .25987 .78943 .26703 .80087 .26316 .79595 .25597 Metetra
.14428 .48113 .15376 .46089 .16128 .47172 .15478 .46598 Metetra
.656 .751 .919 r
.15478 .46598 .16128 .47172 .17041 .46861 .16393 .46286 Metetra
.656 .751 .919 r
.16393 .46286 .17041 .46861 .17957 .4655 .17311 .45972 Metetra
.656 .751 .919 r
.17311 .45972 .17957 .4655 .18876 .46238 .18232 .45658 Metetra
.656 .751 .919 r
.18232 .45658 .18876 .46238 .19798 .45924 .19156 .45342 Metetra
.656 .751 .919 r
.19156 .45342 .19798 .45924 .20724 .45609 .20084 .45025 Metetra
.656 .751 .919 r
.20084 .45025 .20724 .45609 .21653 .45293 .21015 .44707 Metetra
.656 .751 .919 r
.21015 .44707 .21653 .45293 .22586 .44976 .21949 .44388 Metetra
.656 .751 .919 r
.21949 .44388 .22586 .44976 .23522 .44658 .22887 .44068 Metetra
.656 .751 .919 r
.22887 .44068 .23522 .44658 .24461 .44339 .23828 .43747 Metetra
.656 .751 .919 r
.23828 .43747 .24461 .44339 .25403 .44019 .24773 .43424 Metetra
.656 .751 .919 r
.24773 .43424 .25403 .44019 .26349 .43697 .25721 .431 Metetra
.656 .751 .919 r
.25721 .431 .26349 .43697 .27299 .43374 .26672 .42775 Metetra
.656 .751 .919 r
.26672 .42775 .27299 .43374 .28252 .4305 .27627 .42449 Metetra
.656 .751 .919 r
.27627 .42449 .28252 .4305 .29208 .42725 .28586 .42122 Metetra
.656 .751 .919 r
.28586 .42122 .29208 .42725 .30168 .42399 .29548 .41794 Metetra
.656 .751 .919 r
.29548 .41794 .30168 .42399 .31131 .42072 .30513 .41464 Metetra
.656 .751 .919 r
.30513 .41464 .31131 .42072 .32098 .41743 .31482 .41133 Metetra
.656 .751 .919 r
.31482 .41133 .32098 .41743 .33068 .41413 .32455 .40801 Metetra
.656 .751 .919 r
.32455 .40801 .33068 .41413 .34042 .41082 .33431 .40467 Metetra
.656 .751 .919 r
.33431 .40467 .34042 .41082 .3502 .4075 .34411 .40133 Metetra
.656 .751 .919 r
.34411 .40133 .3502 .4075 .36001 .40416 .35394 .39797 Metetra
.656 .751 .919 r
.35394 .39797 .36001 .40416 .36986 .40081 .36381 .3946 Metetra
.656 .751 .919 r
.36381 .3946 .36986 .40081 .37974 .39745 .37372 .39122 Metetra
.656 .751 .919 r
.37372 .39122 .37974 .39745 .38966 .39408 .38366 .38782 Metetra
.656 .751 .919 r
.38366 .38782 .38966 .39408 .39962 .3907 .39364 .38441 Metetra
.656 .751 .919 r
.39364 .38441 .39962 .3907 .40961 .3873 .40366 .38099 Metetra
.656 .751 .919 r
.40366 .38099 .40961 .3873 .41965 .38389 .41371 .37756 Metetra
.656 .751 .919 r
.41371 .37756 .41965 .38389 .42972 .38047 .42381 .37411 Metetra
.656 .751 .919 r
.42381 .37411 .42972 .38047 .43982 .37703 .43394 .37065 Metetra
.656 .751 .919 r
.43394 .37065 .43982 .37703 .44997 .37358 .44411 .36718 Metetra
.656 .751 .919 r
.44411 .36718 .44997 .37358 .46015 .37012 .45431 .36369 Metetra
.656 .751 .919 r
.45431 .36369 .46015 .37012 .47037 .36664 .46456 .3602 Metetra
.656 .751 .919 r
.46456 .3602 .47037 .36664 .48063 .36316 .47484 .35668 Metetra
.656 .751 .919 r
.47484 .35668 .48063 .36316 .49093 .35966 .48517 .35316 Metetra
.656 .751 .919 r
.48517 .35316 .49093 .35966 .50127 .35614 .49553 .34962 Metetra
.656 .751 .919 r
.49553 .34962 .50127 .35614 .51164 .35261 .50593 .34607 Metetra
.656 .751 .919 r
.50593 .34607 .51164 .35261 .52206 .34907 .51637 .3425 Metetra
.656 .751 .919 r
.51637 .3425 .52206 .34907 .53251 .34552 .52686 .33892 Metetra
.656 .751 .919 r
.52686 .33892 .53251 .34552 .54301 .34195 .53738 .33533 Metetra
.656 .751 .919 r
.53738 .33533 .54301 .34195 .55355 .33837 .54794 .33172 Metetra
.656 .751 .919 r
.54794 .33172 .55355 .33837 .56412 .33478 .55854 .3281 Metetra
.656 .751 .919 r
.55854 .3281 .56412 .33478 .57474 .33117 .56918 .32447 Metetra
.656 .751 .919 r
.56918 .32447 .57474 .33117 .58539 .32754 .57987 .32082 Metetra
.656 .751 .919 r
.57987 .32082 .58539 .32754 .59609 .32391 .59059 .31716 Metetra
.656 .751 .919 r
.59059 .31716 .59609 .32391 .60683 .32026 .60136 .31348 Metetra
.656 .751 .919 r
.60136 .31348 .60683 .32026 .61761 .31659 .61217 .30979 Metetra
.656 .751 .919 r
.61217 .30979 .61761 .31659 .62844 .31291 .62302 .30608 Metetra
.656 .751 .919 r
.62302 .30608 .62844 .31291 .6393 .30922 .63391 .30236 Metetra
.656 .751 .919 r
.63391 .30236 .6393 .30922 .65021 .30551 .64485 .29863 Metetra
.656 .751 .919 r
.64485 .29863 .65021 .30551 .66116 .30179 .65583 .29488 Metetra
.656 .751 .919 r
.65583 .29488 .66116 .30179 .67215 .29805 .66685 .29112 Metetra
.656 .751 .919 r
.66685 .29112 .67215 .29805 .68318 .2943 .67791 .28734 Metetra
.656 .751 .919 r
.67791 .28734 .68318 .2943 .69426 .29054 .68902 .28354 Metetra
.656 .751 .919 r
.68902 .28354 .69426 .29054 .70538 .28675 .70017 .27974 Metetra
.656 .751 .919 r
.70017 .27974 .70538 .28675 .71655 .28296 .71137 .27591 Metetra
.656 .751 .919 r
.71137 .27591 .71655 .28296 .72776 .27915 .72261 .27207 Metetra
.656 .751 .919 r
.72261 .27207 .72776 .27915 .73901 .27532 .73389 .26822 Metetra
.656 .751 .919 r
.73389 .26822 .73901 .27532 .75031 .27148 .74522 .26435 Metetra
.656 .751 .919 r
.74522 .26435 .75031 .27148 .76165 .26763 .7566 .26047 Metetra
.656 .751 .919 r
.7566 .26047 .76165 .26763 .77304 .26376 .76802 .25657 Metetra
.656 .751 .919 r
.76802 .25657 .77304 .26376 .78447 .25987 .77948 .25265 Metetra
.656 .751 .919 r
.77948 .25265 .78447 .25987 .79595 .25597 .79099 .24872 Metetra
.583 .486 .709 r
.13925 .46216 .14428 .48113 .15478 .46598 .14824 .46021 Metetra
.656 .751 .919 r
.14824 .46021 .15478 .46598 .16393 .46286 .15741 .45706 Metetra
.656 .751 .919 r
.15741 .45706 .16393 .46286 .17311 .45972 .1666 .45391 Metetra
.656 .751 .919 r
.1666 .45391 .17311 .45972 .18232 .45658 .17583 .45074 Metetra
.656 .751 .919 r
.17583 .45074 .18232 .45658 .19156 .45342 .1851 .44756 Metetra
.656 .751 .919 r
.1851 .44756 .19156 .45342 .20084 .45025 .19439 .44437 Metetra
.656 .751 .919 r
.19439 .44437 .20084 .45025 .21015 .44707 .20372 .44117 Metetra
.656 .751 .919 r
.20372 .44117 .21015 .44707 .21949 .44388 .21309 .43796 Metetra
.656 .751 .919 r
.21309 .43796 .21949 .44388 .22887 .44068 .22249 .43474 Metetra
.656 .751 .919 r
.22249 .43474 .22887 .44068 .23828 .43747 .23192 .4315 Metetra
.656 .751 .919 r
.23192 .4315 .23828 .43747 .24773 .43424 .24138 .42825 Metetra
.656 .751 .919 r
.24138 .42825 .24773 .43424 .25721 .431 .25088 .425 Metetra
.656 .751 .919 r
.25088 .425 .25721 .431 .26672 .42775 .26042 .42172 Metetra
.656 .751 .919 r
.26042 .42172 .26672 .42775 .27627 .42449 .26999 .41844 Metetra
.656 .751 .919 r
.26999 .41844 .27627 .42449 .28586 .42122 .27959 .41515 Metetra
.656 .751 .919 r
.27959 .41515 .28586 .42122 .29548 .41794 .28923 .41184 Metetra
.656 .751 .919 r
.28923 .41184 .29548 .41794 .30513 .41464 .29891 .40852 Metetra
.656 .751 .919 r
.29891 .40852 .30513 .41464 .31482 .41133 .30862 .40519 Metetra
.656 .751 .919 r
.30862 .40519 .31482 .41133 .32455 .40801 .31837 .40184 Metetra
.656 .751 .919 r
.31837 .40184 .32455 .40801 .33431 .40467 .32815 .39849 Metetra
.656 .751 .919 r
.32815 .39849 .33431 .40467 .34411 .40133 .33797 .39512 Metetra
.656 .751 .919 r
.33797 .39512 .34411 .40133 .35394 .39797 .34783 .39174 Metetra
.656 .751 .919 r
.34783 .39174 .35394 .39797 .36381 .3946 .35772 .38835 Metetra
.656 .751 .919 r
.35772 .38835 .36381 .3946 .37372 .39122 .36765 .38494 Metetra
.656 .751 .919 r
.36765 .38494 .37372 .39122 .38366 .38782 .37762 .38152 Metetra
.656 .751 .919 r
.37762 .38152 .38366 .38782 .39364 .38441 .38762 .37809 Metetra
.656 .751 .919 r
.38762 .37809 .39364 .38441 .40366 .38099 .39766 .37464 Metetra
.656 .751 .919 r
.39766 .37464 .40366 .38099 .41371 .37756 .40774 .37119 Metetra
.656 .751 .919 r
.40774 .37119 .41371 .37756 .42381 .37411 .41786 .36772 Metetra
.656 .751 .919 r
.41786 .36772 .42381 .37411 .43394 .37065 .42801 .36423 Metetra
.656 .751 .919 r
.42801 .36423 .43394 .37065 .44411 .36718 .4382 .36073 Metetra
.656 .751 .919 r
.4382 .36073 .44411 .36718 .45431 .36369 .44844 .35722 Metetra
.656 .751 .919 r
.44844 .35722 .45431 .36369 .46456 .3602 .45871 .3537 Metetra
.656 .751 .919 r
.45871 .3537 .46456 .3602 .47484 .35668 .46902 .35016 Metetra
.656 .751 .919 r
.46902 .35016 .47484 .35668 .48517 .35316 .47936 .34661 Metetra
.656 .751 .919 r
.47936 .34661 .48517 .35316 .49553 .34962 .48975 .34305 Metetra
.656 .751 .919 r
.48975 .34305 .49553 .34962 .50593 .34607 .50018 .33947 Metetra
.656 .751 .919 r
.50018 .33947 .50593 .34607 .51637 .3425 .51065 .33588 Metetra
.656 .751 .919 r
.51065 .33588 .51637 .3425 .52686 .33892 .52116 .33228 Metetra
.656 .751 .919 r
.52116 .33228 .52686 .33892 .53738 .33533 .5317 .32866 Metetra
.656 .751 .919 r
.5317 .32866 .53738 .33533 .54794 .33172 .54229 .32503 Metetra
.656 .751 .919 r
.54229 .32503 .54794 .33172 .55854 .3281 .55292 .32138 Metetra
.656 .751 .919 r
.55292 .32138 .55854 .3281 .56918 .32447 .56359 .31772 Metetra
.656 .751 .919 r
.56359 .31772 .56918 .32447 .57987 .32082 .5743 .31405 Metetra
.656 .751 .919 r
.5743 .31405 .57987 .32082 .59059 .31716 .58506 .31036 Metetra
.656 .751 .919 r
.58506 .31036 .59059 .31716 .60136 .31348 .59585 .30665 Metetra
.656 .751 .919 r
.59585 .30665 .60136 .31348 .61217 .30979 .60669 .30294 Metetra
.656 .751 .919 r
.60669 .30294 .61217 .30979 .62302 .30608 .61757 .2992 Metetra
.656 .751 .919 r
.61757 .2992 .62302 .30608 .63391 .30236 .62849 .29546 Metetra
.656 .751 .919 r
.62849 .29546 .63391 .30236 .64485 .29863 .63945 .2917 Metetra
.656 .751 .919 r
.63945 .2917 .64485 .29863 .65583 .29488 .65046 .28792 Metetra
.656 .751 .919 r
.65046 .28792 .65583 .29488 .66685 .29112 .66151 .28413 Metetra
.656 .751 .919 r
.66151 .28413 .66685 .29112 .67791 .28734 .67261 .28032 Metetra
.656 .751 .919 r
.67261 .28032 .67791 .28734 .68902 .28354 .68374 .2765 Metetra
.656 .751 .919 r
.68374 .2765 .68902 .28354 .70017 .27974 .69493 .27267 Metetra
.656 .751 .919 r
.69493 .27267 .70017 .27974 .71137 .27591 .70615 .26881 Metetra
.656 .751 .919 r
.70615 .26881 .71137 .27591 .72261 .27207 .71742 .26495 Metetra
.656 .751 .919 r
.71742 .26495 .72261 .27207 .73389 .26822 .72874 .26107 Metetra
.656 .751 .919 r
.72874 .26107 .73389 .26822 .74522 .26435 .7401 .25717 Metetra
.656 .751 .919 r
.7401 .25717 .74522 .26435 .7566 .26047 .75151 .25326 Metetra
.656 .751 .919 r
.75151 .25326 .7566 .26047 .76802 .25657 .76296 .24933 Metetra
.656 .751 .919 r
.76296 .24933 .76802 .25657 .77948 .25265 .77445 .24538 Metetra
.656 .751 .919 r
.77445 .24538 .77948 .25265 .79099 .24872 .786 .24142 Metetra
.096 .183 .666 r
.13403 .44485 .13925 .46216 .14824 .46021 .14166 .45439 Metetra
.656 .751 .919 r
.14166 .45439 .14824 .46021 .15741 .45706 .15084 .45123 Metetra
.656 .751 .919 r
.15084 .45123 .15741 .45706 .1666 .45391 .16006 .44805 Metetra
.656 .751 .919 r
.16006 .44805 .1666 .45391 .17583 .45074 .16931 .44487 Metetra
.656 .751 .919 r
.16931 .44487 .17583 .45074 .1851 .44756 .17859 .44167 Metetra
.656 .751 .919 r
.17859 .44167 .1851 .44756 .19439 .44437 .18791 .43846 Metetra
.656 .751 .919 r
.18791 .43846 .19439 .44437 .20372 .44117 .19726 .43523 Metetra
.656 .751 .919 r
.19726 .43523 .20372 .44117 .21309 .43796 .20664 .432 Metetra
.656 .751 .919 r
.20664 .432 .21309 .43796 .22249 .43474 .21606 .42875 Metetra
.656 .751 .919 r
.21606 .42875 .22249 .43474 .23192 .4315 .22551 .4255 Metetra
.656 .751 .919 r
.22551 .4255 .23192 .4315 .24138 .42825 .23499 .42223 Metetra
.656 .751 .919 r
.23499 .42223 .24138 .42825 .25088 .425 .24451 .41895 Metetra
.656 .751 .919 r
.24451 .41895 .25088 .425 .26042 .42172 .25407 .41565 Metetra
.656 .751 .919 r
.25407 .41565 .26042 .42172 .26999 .41844 .26366 .41235 Metetra
.656 .751 .919 r
.26366 .41235 .26999 .41844 .27959 .41515 .27329 .40903 Metetra
.656 .751 .919 r
.27329 .40903 .27959 .41515 .28923 .41184 .28295 .4057 Metetra
.656 .751 .919 r
.28295 .4057 .28923 .41184 .29891 .40852 .29265 .40236 Metetra
.656 .751 .919 r
.29265 .40236 .29891 .40852 .30862 .40519 .30238 .39901 Metetra
.656 .751 .919 r
.30238 .39901 .30862 .40519 .31837 .40184 .31215 .39564 Metetra
.656 .751 .919 r
.31215 .39564 .31837 .40184 .32815 .39849 .32195 .39226 Metetra
.656 .751 .919 r
.32195 .39226 .32815 .39849 .33797 .39512 .3318 .38887 Metetra
.656 .751 .919 r
.3318 .38887 .33797 .39512 .34783 .39174 .34167 .38546 Metetra
.656 .751 .919 r
.34167 .38546 .34783 .39174 .35772 .38835 .35159 .38205 Metetra
.656 .751 .919 r
.35159 .38205 .35772 .38835 .36765 .38494 .36154 .37862 Metetra
.656 .751 .919 r
.36154 .37862 .36765 .38494 .37762 .38152 .37153 .37517 Metetra
.656 .751 .919 r
.37153 .37517 .37762 .38152 .38762 .37809 .38156 .37172 Metetra
.656 .751 .919 r
.38156 .37172 .38762 .37809 .39766 .37464 .39162 .36825 Metetra
.656 .751 .919 r
.39162 .36825 .39766 .37464 .40774 .37119 .40172 .36477 Metetra
.656 .751 .919 r
.40172 .36477 .40774 .37119 .41786 .36772 .41187 .36127 Metetra
.656 .751 .919 r
.41187 .36127 .41786 .36772 .42801 .36423 .42204 .35777 Metetra
.656 .751 .919 r
.42204 .35777 .42801 .36423 .4382 .36073 .43226 .35424 Metetra
.656 .751 .919 r
.43226 .35424 .4382 .36073 .44844 .35722 .44252 .35071 Metetra
.656 .751 .919 r
.44252 .35071 .44844 .35722 .45871 .3537 .45281 .34716 Metetra
.656 .751 .919 r
.45281 .34716 .45871 .3537 .46902 .35016 .46315 .3436 Metetra
.656 .751 .919 r
.46315 .3436 .46902 .35016 .47936 .34661 .47352 .34003 Metetra
.656 .751 .919 r
.47352 .34003 .47936 .34661 .48975 .34305 .48394 .33644 Metetra
.656 .751 .919 r
.48394 .33644 .48975 .34305 .50018 .33947 .49439 .33283 Metetra
.656 .751 .919 r
.49439 .33283 .50018 .33947 .51065 .33588 .50488 .32922 Metetra
.656 .751 .919 r
.50488 .32922 .51065 .33588 .52116 .33228 .51542 .32559 Metetra
.656 .751 .919 r
.51542 .32559 .52116 .33228 .5317 .32866 .52599 .32194 Metetra
.656 .751 .919 r
.52599 .32194 .5317 .32866 .54229 .32503 .53661 .31828 Metetra
.656 .751 .919 r
.53661 .31828 .54229 .32503 .55292 .32138 .54726 .31461 Metetra
.656 .751 .919 r
.54726 .31461 .55292 .32138 .56359 .31772 .55796 .31093 Metetra
.656 .751 .919 r
.55796 .31093 .56359 .31772 .5743 .31405 .5687 .30722 Metetra
.656 .751 .919 r
.5687 .30722 .5743 .31405 .58506 .31036 .57948 .30351 Metetra
.656 .751 .919 r
.57948 .30351 .58506 .31036 .59585 .30665 .5903 .29978 Metetra
.656 .751 .919 r
.5903 .29978 .59585 .30665 .60669 .30294 .60117 .29603 Metetra
.656 .751 .919 r
.60117 .29603 .60669 .30294 .61757 .2992 .61208 .29228 Metetra
.656 .751 .919 r
.61208 .29228 .61757 .2992 .62849 .29546 .62303 .2885 Metetra
.656 .751 .919 r
.62303 .2885 .62849 .29546 .63945 .2917 .63402 .28471 Metetra
.656 .751 .919 r
.63402 .28471 .63945 .2917 .65046 .28792 .64506 .28091 Metetra
.656 .751 .919 r
.64506 .28091 .65046 .28792 .66151 .28413 .65614 .27709 Metetra
.656 .751 .919 r
.65614 .27709 .66151 .28413 .67261 .28032 .66726 .27326 Metetra
.656 .751 .919 r
.66726 .27326 .67261 .28032 .68374 .2765 .67843 .26941 Metetra
.656 .751 .919 r
.67843 .26941 .68374 .2765 .69493 .27267 .68964 .26554 Metetra
.656 .751 .919 r
.68964 .26554 .69493 .27267 .70615 .26881 .7009 .26166 Metetra
.656 .751 .919 r
.7009 .26166 .70615 .26881 .71742 .26495 .7122 .25777 Metetra
.656 .751 .919 r
.7122 .25777 .71742 .26495 .72874 .26107 .72355 .25386 Metetra
.656 .751 .919 r
.72355 .25386 .72874 .26107 .7401 .25717 .73494 .24993 Metetra
.656 .751 .919 r
.73494 .24993 .7401 .25717 .75151 .25326 .74638 .24599 Metetra
.656 .751 .919 r
.74638 .24599 .75151 .25326 .76296 .24933 .75786 .24203 Metetra
.656 .751 .919 r
.75786 .24203 .76296 .24933 .77445 .24538 .76939 .23806 Metetra
.656 .751 .919 r
.76939 .23806 .77445 .24538 .786 .24142 .78097 .23407 Metetra
.12331 .47271 .13403 .44485 .14166 .45439 .13503 .44854 Metetra
.656 .751 .919 r
.13503 .44854 .14166 .45439 .15084 .45123 .14424 .44536 Metetra
.656 .751 .919 r
.14424 .44536 .15084 .45123 .16006 .44805 .15347 .44216 Metetra
.656 .751 .919 r
.15347 .44216 .16006 .44805 .16931 .44487 .16274 .43895 Metetra
.656 .751 .919 r
.16274 .43895 .16931 .44487 .17859 .44167 .17204 .43573 Metetra
.656 .751 .919 r
.17204 .43573 .17859 .44167 .18791 .43846 .18137 .4325 Metetra
.656 .751 .919 r
.18137 .4325 .18791 .43846 .19726 .43523 .19074 .42926 Metetra
.656 .751 .919 r
.19074 .42926 .19726 .43523 .20664 .432 .20015 .426 Metetra
.656 .751 .919 r
.20015 .426 .20664 .432 .21606 .42875 .20958 .42273 Metetra
.656 .751 .919 r
.20958 .42273 .21606 .42875 .22551 .4255 .21906 .41945 Metetra
.656 .751 .919 r
.21906 .41945 .22551 .4255 .23499 .42223 .22856 .41616 Metetra
.656 .751 .919 r
.22856 .41616 .23499 .42223 .24451 .41895 .2381 .41286 Metetra
.656 .751 .919 r
.2381 .41286 .24451 .41895 .25407 .41565 .24768 .40954 Metetra
.656 .751 .919 r
.24768 .40954 .25407 .41565 .26366 .41235 .25729 .40621 Metetra
.656 .751 .919 r
.25729 .40621 .26366 .41235 .27329 .40903 .26694 .40287 Metetra
.656 .751 .919 r
.26694 .40287 .27329 .40903 .28295 .4057 .27662 .39952 Metetra
.656 .751 .919 r
.27662 .39952 .28295 .4057 .29265 .40236 .28634 .39616 Metetra
.656 .751 .919 r
.28634 .39616 .29265 .40236 .30238 .39901 .29609 .39278 Metetra
.656 .751 .919 r
.29609 .39278 .30238 .39901 .31215 .39564 .30589 .38939 Metetra
.656 .751 .919 r
.30589 .38939 .31215 .39564 .32195 .39226 .31571 .38599 Metetra
.656 .751 .919 r
.31571 .38599 .32195 .39226 .3318 .38887 .32558 .38257 Metetra
.656 .751 .919 r
.32558 .38257 .3318 .38887 .34167 .38546 .33548 .37915 Metetra
.656 .751 .919 r
.33548 .37915 .34167 .38546 .35159 .38205 .34542 .3757 Metetra
.656 .751 .919 r
.34542 .3757 .35159 .38205 .36154 .37862 .35539 .37225 Metetra
.656 .751 .919 r
.35539 .37225 .36154 .37862 .37153 .37517 .3654 .36878 Metetra
.656 .751 .919 r
.3654 .36878 .37153 .37517 .38156 .37172 .37545 .3653 Metetra
.656 .751 .919 r
.37545 .3653 .38156 .37172 .39162 .36825 .38554 .36181 Metetra
.656 .751 .919 r
.38554 .36181 .39162 .36825 .40172 .36477 .39567 .35831 Metetra
.656 .751 .919 r
.39567 .35831 .40172 .36477 .41187 .36127 .40583 .35479 Metetra
.656 .751 .919 r
.40583 .35479 .41187 .36127 .42204 .35777 .41604 .35125 Metetra
.656 .751 .919 r
.41604 .35125 .42204 .35777 .43226 .35424 .42628 .34771 Metetra
.656 .751 .919 r
.42628 .34771 .43226 .35424 .44252 .35071 .43656 .34415 Metetra
.656 .751 .919 r
.43656 .34415 .44252 .35071 .45281 .34716 .44688 .34058 Metetra
.656 .751 .919 r
.44688 .34058 .45281 .34716 .46315 .3436 .45724 .33699 Metetra
.656 .751 .919 r
.45724 .33699 .46315 .3436 .47352 .34003 .46764 .33339 Metetra
.656 .751 .919 r
.46764 .33339 .47352 .34003 .48394 .33644 .47808 .32977 Metetra
.656 .751 .919 r
.47808 .32977 .48394 .33644 .49439 .33283 .48856 .32615 Metetra
.656 .751 .919 r
.48856 .32615 .49439 .33283 .50488 .32922 .49907 .3225 Metetra
.656 .751 .919 r
.49907 .3225 .50488 .32922 .51542 .32559 .50964 .31885 Metetra
.656 .751 .919 r
.50964 .31885 .51542 .32559 .52599 .32194 .52024 .31518 Metetra
.656 .751 .919 r
.52024 .31518 .52599 .32194 .53661 .31828 .53088 .31149 Metetra
.656 .751 .919 r
.53088 .31149 .53661 .31828 .54726 .31461 .54156 .30779 Metetra
.656 .751 .919 r
.54156 .30779 .54726 .31461 .55796 .31093 .55229 .30408 Metetra
.656 .751 .919 r
.55229 .30408 .55796 .31093 .5687 .30722 .56305 .30035 Metetra
.656 .751 .919 r
.56305 .30035 .5687 .30722 .57948 .30351 .57386 .29661 Metetra
.656 .751 .919 r
.57386 .29661 .57948 .30351 .5903 .29978 .58471 .29285 Metetra
.656 .751 .919 r
.58471 .29285 .5903 .29978 .60117 .29603 .59561 .28908 Metetra
.656 .751 .919 r
.59561 .28908 .60117 .29603 .61208 .29228 .60654 .2853 Metetra
.656 .751 .919 r
.60654 .2853 .61208 .29228 .62303 .2885 .61752 .2815 Metetra
.656 .751 .919 r
.61752 .2815 .62303 .2885 .63402 .28471 .62854 .27768 Metetra
.656 .751 .919 r
.62854 .27768 .63402 .28471 .64506 .28091 .63961 .27385 Metetra
.656 .751 .919 r
.63961 .27385 .64506 .28091 .65614 .27709 .65072 .27 Metetra
.656 .751 .919 r
.65072 .27 .65614 .27709 .66726 .27326 .66187 .26614 Metetra
.656 .751 .919 r
.66187 .26614 .66726 .27326 .67843 .26941 .67307 .26226 Metetra
.656 .751 .919 r
.67307 .26226 .67843 .26941 .68964 .26554 .68432 .25837 Metetra
.656 .751 .919 r
.68432 .25837 .68964 .26554 .7009 .26166 .6956 .25446 Metetra
.656 .751 .919 r
.6956 .25446 .7009 .26166 .7122 .25777 .70694 .25054 Metetra
.656 .751 .919 r
.70694 .25054 .7122 .25777 .72355 .25386 .71831 .2466 Metetra
.656 .751 .919 r
.71831 .2466 .72355 .25386 .73494 .24993 .72974 .24264 Metetra
.656 .751 .919 r
.72974 .24264 .73494 .24993 .74638 .24599 .74121 .23867 Metetra
.656 .751 .919 r
.74121 .23867 .74638 .24599 .75786 .24203 .75272 .23469 Metetra
.656 .751 .919 r
.75272 .23469 .75786 .24203 .76939 .23806 .76429 .23068 Metetra
.656 .751 .919 r
.76429 .23068 .76939 .23806 .78097 .23407 .7759 .22666 Metetra
.334 .216 .566 r
.12121 .42944 .12331 .47271 .13503 .44854 .12836 .44265 Metetra
.656 .751 .919 r
.12836 .44265 .13503 .44854 .14424 .44536 .13758 .43945 Metetra
.656 .751 .919 r
.13758 .43945 .14424 .44536 .15347 .44216 .14684 .43623 Metetra
.656 .751 .919 r
.14684 .43623 .15347 .44216 .16274 .43895 .15612 .433 Metetra
.656 .751 .919 r
.15612 .433 .16274 .43895 .17204 .43573 .16544 .42975 Metetra
.656 .751 .919 r
.16544 .42975 .17204 .43573 .18137 .4325 .1748 .4265 Metetra
.656 .751 .919 r
.1748 .4265 .18137 .4325 .19074 .42926 .18419 .42324 Metetra
.656 .751 .919 r
.18419 .42324 .19074 .42926 .20015 .426 .19361 .41996 Metetra
.656 .751 .919 r
.19361 .41996 .20015 .426 .20958 .42273 .20307 .41667 Metetra
.656 .751 .919 r
.20307 .41667 .20958 .42273 .21906 .41945 .21256 .41337 Metetra
.656 .751 .919 r
.21256 .41337 .21906 .41945 .22856 .41616 .22209 .41005 Metetra
.656 .751 .919 r
.22209 .41005 .22856 .41616 .2381 .41286 .23165 .40673 Metetra
.656 .751 .919 r
.23165 .40673 .2381 .41286 .24768 .40954 .24125 .40339 Metetra
.656 .751 .919 r
.24125 .40339 .24768 .40954 .25729 .40621 .25088 .40004 Metetra
.656 .751 .919 r
.25088 .40004 .25729 .40621 .26694 .40287 .26055 .39668 Metetra
.656 .751 .919 r
.26055 .39668 .26694 .40287 .27662 .39952 .27025 .3933 Metetra
.656 .751 .919 r
.27025 .3933 .27662 .39952 .28634 .39616 .27999 .38991 Metetra
.656 .751 .919 r
.27999 .38991 .28634 .39616 .29609 .39278 .28977 .38651 Metetra
.656 .751 .919 r
.28977 .38651 .29609 .39278 .30589 .38939 .29958 .3831 Metetra
.656 .751 .919 r
.29958 .3831 .30589 .38939 .31571 .38599 .30943 .37967 Metetra
.656 .751 .919 r
.30943 .37967 .31571 .38599 .32558 .38257 .31931 .37623 Metetra
.656 .751 .919 r
.31931 .37623 .32558 .38257 .33548 .37915 .32924 .37278 Metetra
.656 .751 .919 r
.32924 .37278 .33548 .37915 .34542 .3757 .3392 .36932 Metetra
.656 .751 .919 r
.3392 .36932 .34542 .3757 .35539 .37225 .3492 .36584 Metetra
.656 .751 .919 r
.3492 .36584 .35539 .37225 .3654 .36878 .35923 .36235 Metetra
.656 .751 .919 r
.35923 .36235 .3654 .36878 .37545 .3653 .36931 .35885 Metetra
.656 .751 .919 r
.36931 .35885 .37545 .3653 .38554 .36181 .37942 .35533 Metetra
.656 .751 .919 r
.37942 .35533 .38554 .36181 .39567 .35831 .38957 .3518 Metetra
.656 .751 .919 r
.38957 .3518 .39567 .35831 .40583 .35479 .39976 .34825 Metetra
.656 .751 .919 r
.39976 .34825 .40583 .35479 .41604 .35125 .40998 .3447 Metetra
.656 .751 .919 r
.40998 .3447 .41604 .35125 .42628 .34771 .42025 .34113 Metetra
.656 .751 .919 r
.42025 .34113 .42628 .34771 .43656 .34415 .43056 .33754 Metetra
.656 .751 .919 r
.43056 .33754 .43656 .34415 .44688 .34058 .4409 .33394 Metetra
.656 .751 .919 r
.4409 .33394 .44688 .34058 .45724 .33699 .45129 .33033 Metetra
.656 .751 .919 r
.45129 .33033 .45724 .33699 .46764 .33339 .46171 .32671 Metetra
.656 .751 .919 r
.46171 .32671 .46764 .33339 .47808 .32977 .47218 .32307 Metetra
.656 .751 .919 r
.47218 .32307 .47808 .32977 .48856 .32615 .48268 .31941 Metetra
.656 .751 .919 r
.48268 .31941 .48856 .32615 .49907 .3225 .49323 .31574 Metetra
.656 .751 .919 r
.49323 .31574 .49907 .3225 .50964 .31885 .50381 .31206 Metetra
.656 .751 .919 r
.50381 .31206 .50964 .31885 .52024 .31518 .51444 .30836 Metetra
.656 .751 .919 r
.51444 .30836 .52024 .31518 .53088 .31149 .52511 .30465 Metetra
.656 .751 .919 r
.52511 .30465 .53088 .31149 .54156 .30779 .53582 .30093 Metetra
.656 .751 .919 r
.53582 .30093 .54156 .30779 .55229 .30408 .54657 .29719 Metetra
.656 .751 .919 r
.54657 .29719 .55229 .30408 .56305 .30035 .55737 .29343 Metetra
.656 .751 .919 r
.55737 .29343 .56305 .30035 .57386 .29661 .5682 .28966 Metetra
.656 .751 .919 r
.5682 .28966 .57386 .29661 .58471 .29285 .57908 .28588 Metetra
.656 .751 .919 r
.57908 .28588 .58471 .29285 .59561 .28908 .59 .28208 Metetra
.656 .751 .919 r
.59 .28208 .59561 .28908 .60654 .2853 .60097 .27827 Metetra
.656 .751 .919 r
.60097 .27827 .60654 .2853 .61752 .2815 .61198 .27444 Metetra
.656 .751 .919 r
.61198 .27444 .61752 .2815 .62854 .27768 .62303 .27059 Metetra
.656 .751 .919 r
.62303 .27059 .62854 .27768 .63961 .27385 .63413 .26673 Metetra
.656 .751 .919 r
.63413 .26673 .63961 .27385 .65072 .27 .64527 .26286 Metetra
.656 .751 .919 r
.64527 .26286 .65072 .27 .66187 .26614 .65645 .25897 Metetra
.656 .751 .919 r
.65645 .25897 .66187 .26614 .67307 .26226 .66768 .25506 Metetra
.656 .751 .919 r
.66768 .25506 .67307 .26226 .68432 .25837 .67895 .25114 Metetra
.656 .751 .919 r
.67895 .25114 .68432 .25837 .6956 .25446 .69027 .24721 Metetra
.656 .751 .919 r
.69027 .24721 .6956 .25446 .70694 .25054 .70163 .24325 Metetra
.656 .751 .919 r
.70163 .24325 .70694 .25054 .71831 .2466 .71304 .23928 Metetra
.656 .751 .919 r
.71304 .23928 .71831 .2466 .72974 .24264 .7245 .2353 Metetra
.656 .751 .919 r
.7245 .2353 .72974 .24264 .74121 .23867 .736 .2313 Metetra
.656 .751 .919 r
.736 .2313 .74121 .23867 .75272 .23469 .74755 .22728 Metetra
.656 .751 .919 r
.74755 .22728 .75272 .23469 .76429 .23068 .75915 .22325 Metetra
.656 .751 .919 r
.75915 .22325 .76429 .23068 .7759 .22666 .77079 .2192 Metetra
.247 0 .018 r
.11243 .44008 .12121 .42944 .12836 .44265 .12165 .43672 Metetra
.656 .751 .919 r
.12165 .43672 .12836 .44265 .13758 .43945 .13089 .43349 Metetra
.656 .751 .919 r
.13089 .43349 .13758 .43945 .14684 .43623 .14016 .43025 Metetra
.656 .751 .919 r
.14016 .43025 .14684 .43623 .15612 .433 .14947 .427 Metetra
.656 .751 .919 r
.14947 .427 .15612 .433 .16544 .42975 .15881 .42374 Metetra
.656 .751 .919 r
.15881 .42374 .16544 .42975 .1748 .4265 .16818 .42046 Metetra
.656 .751 .919 r
.16818 .42046 .1748 .4265 .18419 .42324 .17759 .41718 Metetra
.656 .751 .919 r
.17759 .41718 .18419 .42324 .19361 .41996 .18703 .41388 Metetra
.656 .751 .919 r
.18703 .41388 .19361 .41996 .20307 .41667 .19651 .41056 Metetra
.656 .751 .919 r
.19651 .41056 .20307 .41667 .21256 .41337 .20602 .40724 Metetra
.656 .751 .919 r
.20602 .40724 .21256 .41337 .22209 .41005 .21557 .4039 Metetra
.656 .751 .919 r
.21557 .4039 .22209 .41005 .23165 .40673 .22515 .40056 Metetra
.656 .751 .919 r
.22515 .40056 .23165 .40673 .24125 .40339 .23477 .39719 Metetra
.656 .751 .919 r
.23477 .39719 .24125 .40339 .25088 .40004 .24442 .39382 Metetra
.656 .751 .919 r
.24442 .39382 .25088 .40004 .26055 .39668 .25411 .39043 Metetra
.656 .751 .919 r
.25411 .39043 .26055 .39668 .27025 .3933 .26383 .38704 Metetra
.656 .751 .919 r
.26383 .38704 .27025 .3933 .27999 .38991 .2736 .38363 Metetra
.656 .751 .919 r
.2736 .38363 .27999 .38991 .28977 .38651 .28339 .3802 Metetra
.656 .751 .919 r
.28339 .3802 .28977 .38651 .29958 .3831 .29323 .37676 Metetra
.656 .751 .919 r
.29323 .37676 .29958 .3831 .30943 .37967 .3031 .37331 Metetra
.656 .751 .919 r
.3031 .37331 .30943 .37967 .31931 .37623 .31301 .36985 Metetra
.656 .751 .919 r
.31301 .36985 .31931 .37623 .32924 .37278 .32296 .36638 Metetra
.656 .751 .919 r
.32296 .36638 .32924 .37278 .3392 .36932 .33294 .36289 Metetra
.656 .751 .919 r
.33294 .36289 .3392 .36932 .3492 .36584 .34296 .35939 Metetra
.656 .751 .919 r
.34296 .35939 .3492 .36584 .35923 .36235 .35302 .35587 Metetra
.656 .751 .919 r
.35302 .35587 .35923 .36235 .36931 .35885 .36312 .35234 Metetra
.656 .751 .919 r
.36312 .35234 .36931 .35885 .37942 .35533 .37325 .3488 Metetra
.656 .751 .919 r
.37325 .3488 .37942 .35533 .38957 .3518 .38343 .34525 Metetra
.656 .751 .919 r
.38343 .34525 .38957 .3518 .39976 .34825 .39364 .34168 Metetra
.656 .751 .919 r
.39364 .34168 .39976 .34825 .40998 .3447 .40389 .33809 Metetra
.656 .751 .919 r
.40389 .33809 .40998 .3447 .42025 .34113 .41418 .3345 Metetra
.656 .751 .919 r
.41418 .3345 .42025 .34113 .43056 .33754 .42451 .33089 Metetra
.656 .751 .919 r
.42451 .33089 .43056 .33754 .4409 .33394 .43488 .32726 Metetra
.656 .751 .919 r
.43488 .32726 .4409 .33394 .45129 .33033 .44529 .32363 Metetra
.656 .751 .919 r
.44529 .32363 .45129 .33033 .46171 .32671 .45574 .31997 Metetra
.656 .751 .919 r
.45574 .31997 .46171 .32671 .47218 .32307 .46623 .31631 Metetra
.656 .751 .919 r
.46623 .31631 .47218 .32307 .48268 .31941 .47676 .31263 Metetra
.656 .751 .919 r
.47676 .31263 .48268 .31941 .49323 .31574 .48734 .30893 Metetra
.656 .751 .919 r
.48734 .30893 .49323 .31574 .50381 .31206 .49795 .30523 Metetra
.656 .751 .919 r
.49795 .30523 .50381 .31206 .51444 .30836 .5086 .3015 Metetra
.656 .751 .919 r
.5086 .3015 .51444 .30836 .52511 .30465 .5193 .29776 Metetra
.656 .751 .919 r
.5193 .29776 .52511 .30465 .53582 .30093 .53004 .29401 Metetra
.656 .751 .919 r
.53004 .29401 .53582 .30093 .54657 .29719 .54082 .29025 Metetra
.656 .751 .919 r
.54082 .29025 .54657 .29719 .55737 .29343 .55164 .28646 Metetra
.656 .751 .919 r
.55164 .28646 .55737 .29343 .5682 .28966 .5625 .28267 Metetra
.656 .751 .919 r
.5625 .28267 .5682 .28966 .57908 .28588 .57341 .27886 Metetra
.656 .751 .919 r
.57341 .27886 .57908 .28588 .59 .28208 .58436 .27503 Metetra
.656 .751 .919 r
.58436 .27503 .59 .28208 .60097 .27827 .59536 .27119 Metetra
.656 .751 .919 r
.59536 .27119 .60097 .27827 .61198 .27444 .60639 .26733 Metetra
.656 .751 .919 r
.60639 .26733 .61198 .27444 .62303 .27059 .61747 .26346 Metetra
.656 .751 .919 r
.61747 .26346 .62303 .27059 .63413 .26673 .6286 .25957 Metetra
.656 .751 .919 r
.6286 .25957 .63413 .26673 .64527 .26286 .63977 .25567 Metetra
.656 .751 .919 r
.63977 .25567 .64527 .26286 .65645 .25897 .65098 .25175 Metetra
.656 .751 .919 r
.65098 .25175 .65645 .25897 .66768 .25506 .66224 .24781 Metetra
.656 .751 .919 r
.66224 .24781 .66768 .25506 .67895 .25114 .67355 .24386 Metetra
.656 .751 .919 r
.67355 .24386 .67895 .25114 .69027 .24721 .6849 .2399 Metetra
.656 .751 .919 r
.6849 .2399 .69027 .24721 .70163 .24325 .69629 .23591 Metetra
.656 .751 .919 r
.69629 .23591 .70163 .24325 .71304 .23928 .70773 .23192 Metetra
.656 .751 .919 r
.70773 .23192 .71304 .23928 .7245 .2353 .71922 .2279 Metetra
.656 .751 .919 r
.71922 .2279 .7245 .2353 .736 .2313 .73076 .22387 Metetra
.656 .751 .919 r
.73076 .22387 .736 .2313 .74755 .22728 .74234 .21982 Metetra
.656 .751 .919 r
.74234 .21982 .74755 .22728 .75915 .22325 .75397 .21576 Metetra
.656 .751 .919 r
.75397 .21576 .75915 .22325 .77079 .2192 .76564 .21168 Metetra
.873 .93 .546 r
.10312 .45375 .11243 .44008 .12165 .43672 .11489 .43075 Metetra
.656 .751 .919 r
.11489 .43075 .12165 .43672 .13089 .43349 .12415 .4275 Metetra
.656 .751 .919 r
.12415 .4275 .13089 .43349 .14016 .43025 .13344 .42424 Metetra
.656 .751 .919 r
.13344 .42424 .14016 .43025 .14947 .427 .14276 .42097 Metetra
.656 .751 .919 r
.14276 .42097 .14947 .427 .15881 .42374 .15212 .41768 Metetra
.656 .751 .919 r
.15212 .41768 .15881 .42374 .16818 .42046 .16152 .41438 Metetra
.656 .751 .919 r
.16152 .41438 .16818 .42046 .17759 .41718 .17094 .41107 Metetra
.656 .751 .919 r
.17094 .41107 .17759 .41718 .18703 .41388 .18041 .40775 Metetra
.656 .751 .919 r
.18041 .40775 .18703 .41388 .19651 .41056 .1899 .40442 Metetra
.656 .751 .919 r
.1899 .40442 .19651 .41056 .20602 .40724 .19943 .40107 Metetra
.656 .751 .919 r
.19943 .40107 .20602 .40724 .21557 .4039 .209 .39771 Metetra
.656 .751 .919 r
.209 .39771 .21557 .4039 .22515 .40056 .21861 .39434 Metetra
.656 .751 .919 r
.21861 .39434 .22515 .40056 .23477 .39719 .22824 .39096 Metetra
.656 .751 .919 r
.22824 .39096 .23477 .39719 .24442 .39382 .23792 .38756 Metetra
.656 .751 .919 r
.23792 .38756 .24442 .39382 .25411 .39043 .24763 .38415 Metetra
.656 .751 .919 r
.24763 .38415 .25411 .39043 .26383 .38704 .25738 .38073 Metetra
.656 .751 .919 r
.25738 .38073 .26383 .38704 .2736 .38363 .26716 .37729 Metetra
.656 .751 .919 r
.26716 .37729 .2736 .38363 .28339 .3802 .27698 .37385 Metetra
.656 .751 .919 r
.27698 .37385 .28339 .3802 .29323 .37676 .28684 .37039 Metetra
.656 .751 .919 r
.28684 .37039 .29323 .37676 .3031 .37331 .29673 .36691 Metetra
.656 .751 .919 r
.29673 .36691 .3031 .37331 .31301 .36985 .30666 .36343 Metetra
.656 .751 .919 r
.30666 .36343 .31301 .36985 .32296 .36638 .31663 .35993 Metetra
.656 .751 .919 r
.31663 .35993 .32296 .36638 .33294 .36289 .32664 .35641 Metetra
.656 .751 .919 r
.32664 .35641 .33294 .36289 .34296 .35939 .33668 .35289 Metetra
.656 .751 .919 r
.33668 .35289 .34296 .35939 .35302 .35587 .34676 .34935 Metetra
.656 .751 .919 r
.34676 .34935 .35302 .35587 .36312 .35234 .35688 .34579 Metetra
.656 .751 .919 r
.35688 .34579 .36312 .35234 .37325 .3488 .36704 .34223 Metetra
.656 .751 .919 r
.36704 .34223 .37325 .3488 .38343 .34525 .37724 .33865 Metetra
.656 .751 .919 r
.37724 .33865 .38343 .34525 .39364 .34168 .38748 .33505 Metetra
.656 .751 .919 r
.38748 .33505 .39364 .34168 .40389 .33809 .39775 .33144 Metetra
.656 .751 .919 r
.39775 .33144 .40389 .33809 .41418 .3345 .40807 .32782 Metetra
.656 .751 .919 r
.40807 .32782 .41418 .3345 .42451 .33089 .41842 .32419 Metetra
.656 .751 .919 r
.41842 .32419 .42451 .33089 .43488 .32726 .42882 .32054 Metetra
.656 .751 .919 r
.42882 .32054 .43488 .32726 .44529 .32363 .43926 .31687 Metetra
.656 .751 .919 r
.43926 .31687 .44529 .32363 .45574 .31997 .44973 .3132 Metetra
.656 .751 .919 r
.44973 .3132 .45574 .31997 .46623 .31631 .46025 .3095 Metetra
.656 .751 .919 r
.46025 .3095 .46623 .31631 .47676 .31263 .4708 .3058 Metetra
.656 .751 .919 r
.4708 .3058 .47676 .31263 .48734 .30893 .4814 .30208 Metetra
.656 .751 .919 r
.4814 .30208 .48734 .30893 .49795 .30523 .49204 .29834 Metetra
.656 .751 .919 r
.49204 .29834 .49795 .30523 .5086 .3015 .50272 .29459 Metetra
.656 .751 .919 r
.50272 .29459 .5086 .3015 .5193 .29776 .51345 .29083 Metetra
.656 .751 .919 r
.51345 .29083 .5193 .29776 .53004 .29401 .52421 .28705 Metetra
.656 .751 .919 r
.52421 .28705 .53004 .29401 .54082 .29025 .53502 .28325 Metetra
.656 .751 .919 r
.53502 .28325 .54082 .29025 .55164 .28646 .54587 .27944 Metetra
.656 .751 .919 r
.54587 .27944 .55164 .28646 .5625 .28267 .55676 .27562 Metetra
.656 .751 .919 r
.55676 .27562 .5625 .28267 .57341 .27886 .5677 .27178 Metetra
.656 .751 .919 r
.5677 .27178 .57341 .27886 .58436 .27503 .57868 .26792 Metetra
.656 .751 .919 r
.57868 .26792 .58436 .27503 .59536 .27119 .5897 .26405 Metetra
.656 .751 .919 r
.5897 .26405 .59536 .27119 .60639 .26733 .60077 .26017 Metetra
.656 .751 .919 r
.60077 .26017 .60639 .26733 .61747 .26346 .61188 .25627 Metetra
.656 .751 .919 r
.61188 .25627 .61747 .26346 .6286 .25957 .62303 .25235 Metetra
.656 .751 .919 r
.62303 .25235 .6286 .25957 .63977 .25567 .63423 .24842 Metetra
.656 .751 .919 r
.63423 .24842 .63977 .25567 .65098 .25175 .64548 .24447 Metetra
.656 .751 .919 r
.64548 .24447 .65098 .25175 .66224 .24781 .65677 .24051 Metetra
.656 .751 .919 r
.65677 .24051 .66224 .24781 .67355 .24386 .6681 .23653 Metetra
.656 .751 .919 r
.6681 .23653 .67355 .24386 .6849 .2399 .67949 .23253 Metetra
.656 .751 .919 r
.67949 .23253 .6849 .2399 .69629 .23591 .69091 .22852 Metetra
.656 .751 .919 r
.69091 .22852 .69629 .23591 .70773 .23192 .70239 .22449 Metetra
.656 .751 .919 r
.70239 .22449 .70773 .23192 .71922 .2279 .71391 .22045 Metetra
.656 .751 .919 r
.71391 .22045 .71922 .2279 .73076 .22387 .72547 .21639 Metetra
.656 .751 .919 r
.72547 .21639 .73076 .22387 .74234 .21982 .73709 .21231 Metetra
.656 .751 .919 r
.73709 .21231 .74234 .21982 .75397 .21576 .74875 .20822 Metetra
.656 .751 .919 r
.74875 .20822 .75397 .21576 .76564 .21168 .76046 .2041 Metetra
.142 .047 .478 r
.10281 .39772 .10312 .45375 .11489 .43075 .10808 .42474 Metetra
.656 .751 .919 r
.10808 .42474 .11489 .43075 .12415 .4275 .11736 .42147 Metetra
.656 .751 .919 r
.11736 .42147 .12415 .4275 .13344 .42424 .12667 .41819 Metetra
.656 .751 .919 r
.12667 .41819 .13344 .42424 .14276 .42097 .13601 .41489 Metetra
.656 .751 .919 r
.13601 .41489 .14276 .42097 .15212 .41768 .14539 .41158 Metetra
.656 .751 .919 r
.14539 .41158 .15212 .41768 .16152 .41438 .15481 .40826 Metetra
.656 .751 .919 r
.15481 .40826 .16152 .41438 .17094 .41107 .16425 .40493 Metetra
.656 .751 .919 r
.16425 .40493 .17094 .41107 .18041 .40775 .17374 .40159 Metetra
.656 .751 .919 r
.17374 .40159 .18041 .40775 .1899 .40442 .18325 .39823 Metetra
.656 .751 .919 r
.18325 .39823 .1899 .40442 .19943 .40107 .1928 .39486 Metetra
.656 .751 .919 r
.1928 .39486 .19943 .40107 .209 .39771 .20239 .39148 Metetra
.656 .751 .919 r
.20239 .39148 .209 .39771 .21861 .39434 .21202 .38808 Metetra
.656 .751 .919 r
.21202 .38808 .21861 .39434 .22824 .39096 .22168 .38468 Metetra
.656 .751 .919 r
.22168 .38468 .22824 .39096 .23792 .38756 .23137 .38126 Metetra
.656 .751 .919 r
.23137 .38126 .23792 .38756 .24763 .38415 .2411 .37782 Metetra
.656 .751 .919 r
.2411 .37782 .24763 .38415 .25738 .38073 .25087 .37438 Metetra
.656 .751 .919 r
.25087 .37438 .25738 .38073 .26716 .37729 .26068 .37092 Metetra
.656 .751 .919 r
.26068 .37092 .26716 .37729 .27698 .37385 .27052 .36745 Metetra
.656 .751 .919 r
.27052 .36745 .27698 .37385 .28684 .37039 .2804 .36396 Metetra
.656 .751 .919 r
.2804 .36396 .28684 .37039 .29673 .36691 .29031 .36047 Metetra
.656 .751 .919 r
.29031 .36047 .29673 .36691 .30666 .36343 .30027 .35695 Metetra
.656 .751 .919 r
.30027 .35695 .30666 .36343 .31663 .35993 .31026 .35343 Metetra
.656 .751 .919 r
.31026 .35343 .31663 .35993 .32664 .35641 .32029 .34989 Metetra
.656 .751 .919 r
.32029 .34989 .32664 .35641 .33668 .35289 .33036 .34634 Metetra
.656 .751 .919 r
.33036 .34634 .33668 .35289 .34676 .34935 .34046 .34278 Metetra
.656 .751 .919 r
.34046 .34278 .34676 .34935 .35688 .34579 .35061 .3392 Metetra
.656 .751 .919 r
.35061 .3392 .35688 .34579 .36704 .34223 .36079 .33561 Metetra
.656 .751 .919 r
.36079 .33561 .36704 .34223 .37724 .33865 .37101 .332 Metetra
.656 .751 .919 r
.37101 .332 .37724 .33865 .38748 .33505 .38127 .32838 Metetra
.656 .751 .919 r
.38127 .32838 .38748 .33505 .39775 .33144 .39157 .32475 Metetra
.656 .751 .919 r
.39157 .32475 .39775 .33144 .40807 .32782 .40191 .3211 Metetra
.656 .751 .919 r
.40191 .3211 .40807 .32782 .41842 .32419 .41229 .31744 Metetra
.656 .751 .919 r
.41229 .31744 .41842 .32419 .42882 .32054 .42271 .31376 Metetra
.656 .751 .919 r
.42271 .31376 .42882 .32054 .43926 .31687 .43317 .31007 Metetra
.656 .751 .919 r
.43317 .31007 .43926 .31687 .44973 .3132 .44368 .30637 Metetra
.656 .751 .919 r
.44368 .30637 .44973 .3132 .46025 .3095 .45422 .30265 Metetra
.656 .751 .919 r
.45422 .30265 .46025 .3095 .4708 .3058 .4648 .29892 Metetra
.656 .751 .919 r
.4648 .29892 .4708 .3058 .4814 .30208 .47543 .29517 Metetra
.656 .751 .919 r
.47543 .29517 .4814 .30208 .49204 .29834 .48609 .29141 Metetra
.656 .751 .919 r
.48609 .29141 .49204 .29834 .50272 .29459 .4968 .28763 Metetra
.656 .751 .919 r
.4968 .28763 .50272 .29459 .51345 .29083 .50755 .28384 Metetra
.656 .751 .919 r
.50755 .28384 .51345 .29083 .52421 .28705 .51835 .28003 Metetra
.656 .751 .919 r
.51835 .28003 .52421 .28705 .53502 .28325 .52918 .27621 Metetra
.656 .751 .919 r
.52918 .27621 .53502 .28325 .54587 .27944 .54006 .27237 Metetra
.656 .751 .919 r
.54006 .27237 .54587 .27944 .55676 .27562 .55098 .26852 Metetra
.656 .751 .919 r
.55098 .26852 .55676 .27562 .5677 .27178 .56194 .26465 Metetra
.656 .751 .919 r
.56194 .26465 .5677 .27178 .57868 .26792 .57295 .26077 Metetra
.656 .751 .919 r
.57295 .26077 .57868 .26792 .5897 .26405 .58401 .25687 Metetra
.656 .751 .919 r
.58401 .25687 .5897 .26405 .60077 .26017 .5951 .25295 Metetra
.656 .751 .919 r
.5951 .25295 .60077 .26017 .61188 .25627 .60624 .24903 Metetra
.656 .751 .919 r
.60624 .24903 .61188 .25627 .62303 .25235 .61743 .24508 Metetra
.656 .751 .919 r
.61743 .24508 .62303 .25235 .63423 .24842 .62866 .24112 Metetra
.656 .751 .919 r
.62866 .24112 .63423 .24842 .64548 .24447 .63993 .23714 Metetra
.656 .751 .919 r
.63993 .23714 .64548 .24447 .65677 .24051 .65125 .23315 Metetra
.656 .751 .919 r
.65125 .23315 .65677 .24051 .6681 .23653 .66262 .22914 Metetra
.656 .751 .919 r
.66262 .22914 .6681 .23653 .67949 .23253 .67403 .22511 Metetra
.656 .751 .919 r
.67403 .22511 .67949 .23253 .69091 .22852 .68549 .22107 Metetra
.656 .751 .919 r
.68549 .22107 .69091 .22852 .70239 .22449 .697 .21701 Metetra
.656 .751 .919 r
.697 .21701 .70239 .22449 .71391 .22045 .70855 .21294 Metetra
.656 .751 .919 r
.70855 .21294 .71391 .22045 .72547 .21639 .72015 .20885 Metetra
.656 .751 .919 r
.72015 .20885 .72547 .21639 .73709 .21231 .7318 .20474 Metetra
.656 .751 .919 r
.7318 .20474 .73709 .21231 .74875 .20822 .74349 .20061 Metetra
.656 .751 .919 r
.74349 .20061 .74875 .20822 .76046 .2041 .75523 .19647 Metetra
.04 0 .209 r
.08875 .4461 .10281 .39772 .10808 .42474 .10123 .41869 Metetra
.656 .751 .919 r
.10123 .41869 .10808 .42474 .11736 .42147 .11053 .4154 Metetra
.656 .751 .919 r
.11053 .4154 .11736 .42147 .12667 .41819 .11986 .41209 Metetra
.656 .751 .919 r
.11986 .41209 .12667 .41819 .13601 .41489 .12922 .40878 Metetra
.656 .751 .919 r
.12922 .40878 .13601 .41489 .14539 .41158 .13862 .40545 Metetra
.656 .751 .919 r
.13862 .40545 .14539 .41158 .15481 .40826 .14805 .4021 Metetra
.656 .751 .919 r
.14805 .4021 .15481 .40826 .16425 .40493 .15752 .39875 Metetra
.656 .751 .919 r
.15752 .39875 .16425 .40493 .17374 .40159 .16702 .39538 Metetra
.656 .751 .919 r
.16702 .39538 .17374 .40159 .18325 .39823 .17656 .392 Metetra
.656 .751 .919 r
.17656 .392 .18325 .39823 .1928 .39486 .18613 .38861 Metetra
.656 .751 .919 r
.18613 .38861 .1928 .39486 .20239 .39148 .19574 .3852 Metetra
.656 .751 .919 r
.19574 .3852 .20239 .39148 .21202 .38808 .20538 .38178 Metetra
.656 .751 .919 r
.20538 .38178 .21202 .38808 .22168 .38468 .21506 .37835 Metetra
.656 .751 .919 r
.21506 .37835 .22168 .38468 .23137 .38126 .22478 .37491 Metetra
.656 .751 .919 r
.22478 .37491 .23137 .38126 .2411 .37782 .23453 .37145 Metetra
.656 .751 .919 r
.23453 .37145 .2411 .37782 .25087 .37438 .24432 .36798 Metetra
.656 .751 .919 r
.24432 .36798 .25087 .37438 .26068 .37092 .25415 .3645 Metetra
.656 .751 .919 r
.25415 .3645 .26068 .37092 .27052 .36745 .26401 .361 Metetra
.656 .751 .919 r
.26401 .361 .27052 .36745 .2804 .36396 .27391 .3575 Metetra
.656 .751 .919 r
.27391 .3575 .2804 .36396 .29031 .36047 .28385 .35397 Metetra
.656 .751 .919 r
.28385 .35397 .29031 .36047 .30027 .35695 .29383 .35044 Metetra
.656 .751 .919 r
.29383 .35044 .30027 .35695 .31026 .35343 .30384 .34689 Metetra
.656 .751 .919 r
.30384 .34689 .31026 .35343 .32029 .34989 .3139 .34333 Metetra
.656 .751 .919 r
.3139 .34333 .32029 .34989 .33036 .34634 .32399 .33975 Metetra
.656 .751 .919 r
.32399 .33975 .33036 .34634 .34046 .34278 .33412 .33616 Metetra
.656 .751 .919 r
.33412 .33616 .34046 .34278 .35061 .3392 .34428 .33256 Metetra
.656 .751 .919 r
.34428 .33256 .35061 .3392 .36079 .33561 .35449 .32894 Metetra
.656 .751 .919 r
.35449 .32894 .36079 .33561 .37101 .332 .36474 .32531 Metetra
.656 .751 .919 r
.36474 .32531 .37101 .332 .38127 .32838 .37502 .32166 Metetra
.656 .751 .919 r
.37502 .32166 .38127 .32838 .39157 .32475 .38535 .318 Metetra
.656 .751 .919 r
.38535 .318 .39157 .32475 .40191 .3211 .39571 .31433 Metetra
.656 .751 .919 r
.39571 .31433 .40191 .3211 .41229 .31744 .40612 .31064 Metetra
.656 .751 .919 r
.40612 .31064 .41229 .31744 .42271 .31376 .41656 .30694 Metetra
.656 .751 .919 r
.41656 .30694 .42271 .31376 .43317 .31007 .42705 .30322 Metetra
.656 .751 .919 r
.42705 .30322 .43317 .31007 .44368 .30637 .43758 .29949 Metetra
.656 .751 .919 r
.43758 .29949 .44368 .30637 .45422 .30265 .44815 .29575 Metetra
.656 .751 .919 r
.44815 .29575 .45422 .30265 .4648 .29892 .45876 .29199 Metetra
.656 .751 .919 r
.45876 .29199 .4648 .29892 .47543 .29517 .46941 .28821 Metetra
.656 .751 .919 r
.46941 .28821 .47543 .29517 .48609 .29141 .4801 .28442 Metetra
.656 .751 .919 r
.4801 .28442 .48609 .29141 .4968 .28763 .49084 .28062 Metetra
.656 .751 .919 r
.49084 .28062 .4968 .28763 .50755 .28384 .50162 .2768 Metetra
.656 .751 .919 r
.50162 .2768 .50755 .28384 .51835 .28003 .51244 .27296 Metetra
.656 .751 .919 r
.51244 .27296 .51835 .28003 .52918 .27621 .5233 .26911 Metetra
.656 .751 .919 r
.5233 .26911 .52918 .27621 .54006 .27237 .53421 .26525 Metetra
.656 .751 .919 r
.53421 .26525 .54006 .27237 .55098 .26852 .54516 .26137 Metetra
.656 .751 .919 r
.54516 .26137 .55098 .26852 .56194 .26465 .55615 .25747 Metetra
.656 .751 .919 r
.55615 .25747 .56194 .26465 .57295 .26077 .56719 .25356 Metetra
.656 .751 .919 r
.56719 .25356 .57295 .26077 .58401 .25687 .57827 .24963 Metetra
.656 .751 .919 r
.57827 .24963 .58401 .25687 .5951 .25295 .58939 .24569 Metetra
.656 .751 .919 r
.58939 .24569 .5951 .25295 .60624 .24903 .60056 .24173 Metetra
.656 .751 .919 r
.60056 .24173 .60624 .24903 .61743 .24508 .61178 .23775 Metetra
.656 .751 .919 r
.61178 .23775 .61743 .24508 .62866 .24112 .62304 .23376 Metetra
.656 .751 .919 r
.62304 .23376 .62866 .24112 .63993 .23714 .63434 .22976 Metetra
.656 .751 .919 r
.63434 .22976 .63993 .23714 .65125 .23315 .6457 .22573 Metetra
.656 .751 .919 r
.6457 .22573 .65125 .23315 .66262 .22914 .65709 .22169 Metetra
.656 .751 .919 r
.65709 .22169 .66262 .22914 .67403 .22511 .66854 .21764 Metetra
.656 .751 .919 r
.66854 .21764 .67403 .22511 .68549 .22107 .68003 .21357 Metetra
.656 .751 .919 r
.68003 .21357 .68549 .22107 .697 .21701 .69157 .20948 Metetra
.656 .751 .919 r
.69157 .20948 .697 .21701 .70855 .21294 .70315 .20537 Metetra
.656 .751 .919 r
.70315 .20537 .70855 .21294 .72015 .20885 .71478 .20125 Metetra
.656 .751 .919 r
.71478 .20125 .72015 .20885 .7318 .20474 .72646 .19711 Metetra
.656 .751 .919 r
.72646 .19711 .7318 .20474 .74349 .20061 .73819 .19295 Metetra
.656 .751 .919 r
.73819 .19295 .74349 .20061 .75523 .19647 .74997 .18878 Metetra
.566 .418 .639 r
.08516 .41516 .08875 .4461 .10123 .41869 .09434 .4126 Metetra
.656 .751 .919 r
.09434 .4126 .10123 .41869 .11053 .4154 .10365 .40929 Metetra
.656 .751 .919 r
.10365 .40929 .11053 .4154 .11986 .41209 .113 .40596 Metetra
.656 .751 .919 r
.113 .40596 .11986 .41209 .12922 .40878 .12238 .40262 Metetra
.656 .751 .919 r
.12238 .40262 .12922 .40878 .13862 .40545 .1318 .39926 Metetra
.656 .751 .919 r
.1318 .39926 .13862 .40545 .14805 .4021 .14125 .3959 Metetra
.656 .751 .919 r
.14125 .3959 .14805 .4021 .15752 .39875 .15074 .39252 Metetra
.656 .751 .919 r
.15074 .39252 .15752 .39875 .16702 .39538 .16026 .38913 Metetra
.656 .751 .919 r
.16026 .38913 .16702 .39538 .17656 .392 .16982 .38573 Metetra
.656 .751 .919 r
.16982 .38573 .17656 .392 .18613 .38861 .17941 .38231 Metetra
.656 .751 .919 r
.17941 .38231 .18613 .38861 .19574 .3852 .18904 .37888 Metetra
.656 .751 .919 r
.18904 .37888 .19574 .3852 .20538 .38178 .1987 .37544 Metetra
.656 .751 .919 r
.1987 .37544 .20538 .38178 .21506 .37835 .2084 .37198 Metetra
.656 .751 .919 r
.2084 .37198 .21506 .37835 .22478 .37491 .21814 .36852 Metetra
.656 .751 .919 r
.21814 .36852 .22478 .37491 .23453 .37145 .22792 .36504 Metetra
.656 .751 .919 r
.22792 .36504 .23453 .37145 .24432 .36798 .23773 .36154 Metetra
.656 .751 .919 r
.23773 .36154 .24432 .36798 .25415 .3645 .24758 .35804 Metetra
.656 .751 .919 r
.24758 .35804 .25415 .3645 .26401 .361 .25746 .35452 Metetra
.656 .751 .919 r
.25746 .35452 .26401 .361 .27391 .3575 .26739 .35098 Metetra
.656 .751 .919 r
.26739 .35098 .27391 .3575 .28385 .35397 .27735 .34744 Metetra
.656 .751 .919 r
.27735 .34744 .28385 .35397 .29383 .35044 .28735 .34387 Metetra
.656 .751 .919 r
.28735 .34387 .29383 .35044 .30384 .34689 .29738 .3403 Metetra
.656 .751 .919 r
.29738 .3403 .30384 .34689 .3139 .34333 .30746 .33671 Metetra
.656 .751 .919 r
.30746 .33671 .3139 .34333 .32399 .33975 .31757 .33311 Metetra
.656 .751 .919 r
.31757 .33311 .32399 .33975 .33412 .33616 .32772 .3295 Metetra
.656 .751 .919 r
.32772 .3295 .33412 .33616 .34428 .33256 .33792 .32587 Metetra
.656 .751 .919 r
.33792 .32587 .34428 .33256 .35449 .32894 .34815 .32222 Metetra
.656 .751 .919 r
.34815 .32222 .35449 .32894 .36474 .32531 .35842 .31857 Metetra
.656 .751 .919 r
.35842 .31857 .36474 .32531 .37502 .32166 .36873 .31489 Metetra
.656 .751 .919 r
.36873 .31489 .37502 .32166 .38535 .318 .37908 .31121 Metetra
.656 .751 .919 r
.37908 .31121 .38535 .318 .39571 .31433 .38947 .30751 Metetra
.656 .751 .919 r
.38947 .30751 .39571 .31433 .40612 .31064 .3999 .3038 Metetra
.656 .751 .919 r
.3999 .3038 .40612 .31064 .41656 .30694 .41037 .30007 Metetra
.656 .751 .919 r
.41037 .30007 .41656 .30694 .42705 .30322 .42088 .29632 Metetra
.656 .751 .919 r
.42088 .29632 .42705 .30322 .43758 .29949 .43144 .29257 Metetra
.656 .751 .919 r
.43144 .29257 .43758 .29949 .44815 .29575 .44203 .28879 Metetra
.656 .751 .919 r
.44203 .28879 .44815 .29575 .45876 .29199 .45267 .285 Metetra
.656 .751 .919 r
.45267 .285 .45876 .29199 .46941 .28821 .46335 .2812 Metetra
.656 .751 .919 r
.46335 .2812 .46941 .28821 .4801 .28442 .47407 .27739 Metetra
.656 .751 .919 r
.47407 .27739 .4801 .28442 .49084 .28062 .48483 .27355 Metetra
.656 .751 .919 r
.48483 .27355 .49084 .28062 .50162 .2768 .49563 .26971 Metetra
.656 .751 .919 r
.49563 .26971 .50162 .2768 .51244 .27296 .50648 .26584 Metetra
.656 .751 .919 r
.50648 .26584 .51244 .27296 .5233 .26911 .51737 .26196 Metetra
.656 .751 .919 r
.51737 .26196 .5233 .26911 .53421 .26525 .52831 .25807 Metetra
.656 .751 .919 r
.52831 .25807 .53421 .26525 .54516 .26137 .53929 .25416 Metetra
.656 .751 .919 r
.53929 .25416 .54516 .26137 .55615 .25747 .55031 .25024 Metetra
.656 .751 .919 r
.55031 .25024 .55615 .25747 .56719 .25356 .56138 .2463 Metetra
.656 .751 .919 r
.56138 .2463 .56719 .25356 .57827 .24963 .57249 .24234 Metetra
.656 .751 .919 r
.57249 .24234 .57827 .24963 .58939 .24569 .58364 .23837 Metetra
.656 .751 .919 r
.58364 .23837 .58939 .24569 .60056 .24173 .59484 .23438 Metetra
.656 .751 .919 r
.59484 .23438 .60056 .24173 .61178 .23775 .60609 .23037 Metetra
.656 .751 .919 r
.60609 .23037 .61178 .23775 .62304 .23376 .61738 .22635 Metetra
.656 .751 .919 r
.61738 .22635 .62304 .23376 .63434 .22976 .62872 .22232 Metetra
.656 .751 .919 r
.62872 .22232 .63434 .22976 .6457 .22573 .6401 .21826 Metetra
.656 .751 .919 r
.6401 .21826 .6457 .22573 .65709 .22169 .65153 .21419 Metetra
.656 .751 .919 r
.65153 .21419 .65709 .22169 .66854 .21764 .663 .21011 Metetra
.656 .751 .919 r
.663 .21011 .66854 .21764 .68003 .21357 .67453 .206 Metetra
.656 .751 .919 r
.67453 .206 .68003 .21357 .69157 .20948 .6861 .20188 Metetra
.656 .751 .919 r
.6861 .20188 .69157 .20948 .70315 .20537 .69771 .19775 Metetra
.656 .751 .919 r
.69771 .19775 .70315 .20537 .71478 .20125 .70938 .19359 Metetra
.656 .751 .919 r
.70938 .19359 .71478 .20125 .72646 .19711 .72109 .18942 Metetra
.656 .751 .919 r
.72109 .18942 .72646 .19711 .73819 .19295 .73285 .18523 Metetra
.656 .751 .919 r
.73285 .18523 .73819 .19295 .74997 .18878 .74466 .18103 Metetra
0 0 .401 r
.08185 .38264 .08516 .41516 .09434 .4126 .08739 .40647 Metetra
.656 .751 .919 r
.08739 .40647 .09434 .4126 .10365 .40929 .09672 .40313 Metetra
.656 .751 .919 r
.09672 .40313 .10365 .40929 .113 .40596 .10609 .39978 Metetra
.656 .751 .919 r
.10609 .39978 .113 .40596 .12238 .40262 .11549 .39642 Metetra
.656 .751 .919 r
.11549 .39642 .12238 .40262 .1318 .39926 .12493 .39304 Metetra
.656 .751 .919 r
.12493 .39304 .1318 .39926 .14125 .3959 .1344 .38965 Metetra
.656 .751 .919 r
.1344 .38965 .14125 .3959 .15074 .39252 .14391 .38625 Metetra
.656 .751 .919 r
.14391 .38625 .15074 .39252 .16026 .38913 .15345 .38284 Metetra
.656 .751 .919 r
.15345 .38284 .16026 .38913 .16982 .38573 .16303 .37941 Metetra
.656 .751 .919 r
.16303 .37941 .16982 .38573 .17941 .38231 .17264 .37597 Metetra
.656 .751 .919 r
.17264 .37597 .17941 .38231 .18904 .37888 .18229 .37252 Metetra
.656 .751 .919 r
.18229 .37252 .18904 .37888 .1987 .37544 .19198 .36905 Metetra
.656 .751 .919 r
.19198 .36905 .1987 .37544 .2084 .37198 .2017 .36557 Metetra
.656 .751 .919 r
.2017 .36557 .2084 .37198 .21814 .36852 .21146 .36208 Metetra
.656 .751 .919 r
.21146 .36208 .21814 .36852 .22792 .36504 .22125 .35858 Metetra
.656 .751 .919 r
.22125 .35858 .22792 .36504 .23773 .36154 .23109 .35506 Metetra
.656 .751 .919 r
.23109 .35506 .23773 .36154 .24758 .35804 .24096 .35153 Metetra
.656 .751 .919 r
.24096 .35153 .24758 .35804 .25746 .35452 .25087 .34798 Metetra
.656 .751 .919 r
.25087 .34798 .25746 .35452 .26739 .35098 .26081 .34442 Metetra
.656 .751 .919 r
.26081 .34442 .26739 .35098 .27735 .34744 .27079 .34085 Metetra
.656 .751 .919 r
.27079 .34085 .27735 .34744 .28735 .34387 .28082 .33727 Metetra
.656 .751 .919 r
.28082 .33727 .28735 .34387 .29738 .3403 .29088 .33367 Metetra
.656 .751 .919 r
.29088 .33367 .29738 .3403 .30746 .33671 .30098 .33005 Metetra
.656 .751 .919 r
.30098 .33005 .30746 .33671 .31757 .33311 .31111 .32643 Metetra
.656 .751 .919 r
.31111 .32643 .31757 .33311 .32772 .3295 .32129 .32279 Metetra
.656 .751 .919 r
.32129 .32279 .32772 .3295 .33792 .32587 .3315 .31913 Metetra
.656 .751 .919 r
.3315 .31913 .33792 .32587 .34815 .32222 .34176 .31546 Metetra
.656 .751 .919 r
.34176 .31546 .34815 .32222 .35842 .31857 .35205 .31178 Metetra
.656 .751 .919 r
.35205 .31178 .35842 .31857 .36873 .31489 .36239 .30808 Metetra
.656 .751 .919 r
.36239 .30808 .36873 .31489 .37908 .31121 .37276 .30437 Metetra
.656 .751 .919 r
.37276 .30437 .37908 .31121 .38947 .30751 .38318 .30064 Metetra
.656 .751 .919 r
.38318 .30064 .38947 .30751 .3999 .3038 .39364 .2969 Metetra
.656 .751 .919 r
.39364 .2969 .3999 .3038 .41037 .30007 .40413 .29314 Metetra
.656 .751 .919 r
.40413 .29314 .41037 .30007 .42088 .29632 .41467 .28937 Metetra
.656 .751 .919 r
.41467 .28937 .42088 .29632 .43144 .29257 .42525 .28559 Metetra
.656 .751 .919 r
.42525 .28559 .43144 .29257 .44203 .28879 .43587 .28179 Metetra
.656 .751 .919 r
.43587 .28179 .44203 .28879 .45267 .285 .44653 .27797 Metetra
.656 .751 .919 r
.44653 .27797 .45267 .285 .46335 .2812 .45724 .27414 Metetra
.656 .751 .919 r
.45724 .27414 .46335 .2812 .47407 .27739 .46799 .2703 Metetra
.656 .751 .919 r
.46799 .2703 .47407 .27739 .48483 .27355 .47878 .26644 Metetra
.656 .751 .919 r
.47878 .26644 .48483 .27355 .49563 .26971 .48961 .26256 Metetra
.656 .751 .919 r
.48961 .26256 .49563 .26971 .50648 .26584 .50049 .25867 Metetra
.656 .751 .919 r
.50049 .25867 .50648 .26584 .51737 .26196 .51141 .25476 Metetra
.656 .751 .919 r
.51141 .25476 .51737 .26196 .52831 .25807 .52237 .25084 Metetra
.656 .751 .919 r
.52237 .25084 .52831 .25807 .53929 .25416 .53338 .2469 Metetra
.656 .751 .919 r
.53338 .2469 .53929 .25416 .55031 .25024 .54443 .24295 Metetra
.656 .751 .919 r
.54443 .24295 .55031 .25024 .56138 .2463 .55552 .23898 Metetra
.656 .751 .919 r
.55552 .23898 .56138 .2463 .57249 .24234 .56666 .23499 Metetra
.656 .751 .919 r
.56666 .23499 .57249 .24234 .58364 .23837 .57785 .23099 Metetra
.656 .751 .919 r
.57785 .23099 .58364 .23837 .59484 .23438 .58908 .22697 Metetra
.656 .751 .919 r
.58908 .22697 .59484 .23438 .60609 .23037 .60035 .22294 Metetra
.656 .751 .919 r
.60035 .22294 .60609 .23037 .61738 .22635 .61168 .21889 Metetra
.656 .751 .919 r
.61168 .21889 .61738 .22635 .62872 .22232 .62304 .21482 Metetra
.656 .751 .919 r
.62304 .21482 .62872 .22232 .6401 .21826 .63446 .21074 Metetra
.656 .751 .919 r
.63446 .21074 .6401 .21826 .65153 .21419 .64592 .20664 Metetra
.656 .751 .919 r
.64592 .20664 .65153 .21419 .663 .21011 .65743 .20252 Metetra
.656 .751 .919 r
.65743 .20252 .663 .21011 .67453 .206 .66898 .19838 Metetra
.656 .751 .919 r
.66898 .19838 .67453 .206 .6861 .20188 .68058 .19423 Metetra
.656 .751 .919 r
.68058 .19423 .6861 .20188 .69771 .19775 .69223 .19006 Metetra
.656 .751 .919 r
.69223 .19006 .69771 .19775 .70938 .19359 .70393 .18588 Metetra
.656 .751 .919 r
.70393 .18588 .70938 .19359 .72109 .18942 .71568 .18168 Metetra
.656 .751 .919 r
.71568 .18168 .72109 .18942 .73285 .18523 .72747 .17746 Metetra
.656 .751 .919 r
.72747 .17746 .73285 .18523 .74466 .18103 .73932 .17322 Metetra
0 0 .112 r
.06484 .44802 .08185 .38264 .08739 .40647 .0804 .4003 Metetra
.656 .751 .919 r
.0804 .4003 .08739 .40647 .09672 .40313 .08975 .39694 Metetra
.656 .751 .919 r
.08975 .39694 .09672 .40313 .10609 .39978 .09914 .39356 Metetra
.656 .751 .919 r
.09914 .39356 .10609 .39978 .11549 .39642 .10856 .39017 Metetra
.656 .751 .919 r
.10856 .39017 .11549 .39642 .12493 .39304 .11801 .38677 Metetra
.656 .751 .919 r
.11801 .38677 .12493 .39304 .1344 .38965 .12751 .38336 Metetra
.656 .751 .919 r
.12751 .38336 .1344 .38965 .14391 .38625 .13703 .37994 Metetra
.656 .751 .919 r
.13703 .37994 .14391 .38625 .15345 .38284 .14659 .3765 Metetra
.656 .751 .919 r
.14659 .3765 .15345 .38284 .16303 .37941 .15619 .37305 Metetra
.656 .751 .919 r
.15619 .37305 .16303 .37941 .17264 .37597 .16583 .36959 Metetra
.656 .751 .919 r
.16583 .36959 .17264 .37597 .18229 .37252 .1755 .36611 Metetra
.656 .751 .919 r
.1755 .36611 .18229 .37252 .19198 .36905 .1852 .36262 Metetra
.656 .751 .919 r
.1852 .36262 .19198 .36905 .2017 .36557 .19495 .35912 Metetra
.656 .751 .919 r
.19495 .35912 .2017 .36557 .21146 .36208 .20473 .3556 Metetra
.656 .751 .919 r
.20473 .3556 .21146 .36208 .22125 .35858 .21455 .35207 Metetra
.656 .751 .919 r
.21455 .35207 .22125 .35858 .23109 .35506 .2244 .34853 Metetra
.656 .751 .919 r
.2244 .34853 .23109 .35506 .24096 .35153 .23429 .34497 Metetra
.656 .751 .919 r
.23429 .34497 .24096 .35153 .25087 .34798 .24422 .3414 Metetra
.656 .751 .919 r
.24422 .3414 .25087 .34798 .26081 .34442 .25419 .33782 Metetra
.656 .751 .919 r
.25419 .33782 .26081 .34442 .27079 .34085 .2642 .33422 Metetra
.656 .751 .919 r
.2642 .33422 .27079 .34085 .28082 .33727 .27424 .33061 Metetra
.656 .751 .919 r
.27424 .33061 .28082 .33727 .29088 .33367 .28432 .32698 Metetra
.656 .751 .919 r
.28432 .32698 .29088 .33367 .30098 .33005 .29445 .32335 Metetra
.656 .751 .919 r
.29445 .32335 .30098 .33005 .31111 .32643 .30461 .31969 Metetra
.656 .751 .919 r
.30461 .31969 .31111 .32643 .32129 .32279 .31481 .31603 Metetra
.656 .751 .919 r
.31481 .31603 .32129 .32279 .3315 .31913 .32505 .31234 Metetra
.656 .751 .919 r
.32505 .31234 .3315 .31913 .34176 .31546 .33533 .30865 Metetra
.656 .751 .919 r
.33533 .30865 .34176 .31546 .35205 .31178 .34565 .30494 Metetra
.656 .751 .919 r
.34565 .30494 .35205 .31178 .36239 .30808 .356 .30122 Metetra
.656 .751 .919 r
.356 .30122 .36239 .30808 .37276 .30437 .3664 .29748 Metetra
.656 .751 .919 r
.3664 .29748 .37276 .30437 .38318 .30064 .37685 .29372 Metetra
.656 .751 .919 r
.37685 .29372 .38318 .30064 .39364 .2969 .38733 .28995 Metetra
.656 .751 .919 r
.38733 .28995 .39364 .2969 .40413 .29314 .39785 .28617 Metetra
.656 .751 .919 r
.39785 .28617 .40413 .29314 .41467 .28937 .40841 .28237 Metetra
.656 .751 .919 r
.40841 .28237 .41467 .28937 .42525 .28559 .41902 .27856 Metetra
.656 .751 .919 r
.41902 .27856 .42525 .28559 .43587 .28179 .42967 .27473 Metetra
.656 .751 .919 r
.42967 .27473 .43587 .28179 .44653 .27797 .44036 .27089 Metetra
.656 .751 .919 r
.44036 .27089 .44653 .27797 .45724 .27414 .45109 .26703 Metetra
.656 .751 .919 r
.45109 .26703 .45724 .27414 .46799 .2703 .46186 .26316 Metetra
.656 .751 .919 r
.46186 .26316 .46799 .2703 .47878 .26644 .47268 .25927 Metetra
.656 .751 .919 r
.47268 .25927 .47878 .26644 .48961 .26256 .48354 .25537 Metetra
.656 .751 .919 r
.48354 .25537 .48961 .26256 .50049 .25867 .49444 .25145 Metetra
.656 .751 .919 r
.49444 .25145 .50049 .25867 .51141 .25476 .50539 .24751 Metetra
.656 .751 .919 r
.50539 .24751 .51141 .25476 .52237 .25084 .51638 .24356 Metetra
.656 .751 .919 r
.51638 .24356 .52237 .25084 .53338 .2469 .52742 .23959 Metetra
.656 .751 .919 r
.52742 .23959 .53338 .2469 .54443 .24295 .5385 .23561 Metetra
.656 .751 .919 r
.5385 .23561 .54443 .24295 .55552 .23898 .54962 .23161 Metetra
.656 .751 .919 r
.54962 .23161 .55552 .23898 .56666 .23499 .56079 .22759 Metetra
.656 .751 .919 r
.56079 .22759 .56666 .23499 .57785 .23099 .57201 .22356 Metetra
.656 .751 .919 r
.57201 .22356 .57785 .23099 .58908 .22697 .58327 .21951 Metetra
.656 .751 .919 r
.58327 .21951 .58908 .22697 .60035 .22294 .59458 .21545 Metetra
.656 .751 .919 r
.59458 .21545 .60035 .22294 .61168 .21889 .60593 .21137 Metetra
.656 .751 .919 r
.60593 .21137 .61168 .21889 .62304 .21482 .61733 .20727 Metetra
.656 .751 .919 r
.61733 .20727 .62304 .21482 .63446 .21074 .62877 .20315 Metetra
.656 .751 .919 r
.62877 .20315 .63446 .21074 .64592 .20664 .64027 .19902 Metetra
.656 .751 .919 r
.64027 .19902 .64592 .20664 .65743 .20252 .65181 .19487 Metetra
.656 .751 .919 r
.65181 .19487 .65743 .20252 .66898 .19838 .66339 .19071 Metetra
.656 .751 .919 r
.66339 .19071 .66898 .19838 .68058 .19423 .67503 .18652 Metetra
.656 .751 .919 r
.67503 .18652 .68058 .19423 .69223 .19006 .68671 .18232 Metetra
.656 .751 .919 r
.68671 .18232 .69223 .19006 .70393 .18588 .69844 .17811 Metetra
.656 .751 .919 r
.69844 .17811 .70393 .18588 .71568 .18168 .71022 .17387 Metetra
.656 .751 .919 r
.71022 .17387 .71568 .18168 .72747 .17746 .72205 .16962 Metetra
.656 .751 .919 r
.72205 .16962 .72747 .17746 .73932 .17322 .73393 .16535 Metetra
.23 .086 .468 r
.0691 .36197 .06484 .44802 .0804 .4003 .07336 .39408 Metetra
.656 .751 .919 r
.07336 .39408 .0804 .4003 .08975 .39694 .08273 .3907 Metetra
.656 .751 .919 r
.08273 .3907 .08975 .39694 .09914 .39356 .09214 .3873 Metetra
.656 .751 .919 r
.09214 .3873 .09914 .39356 .10856 .39017 .10158 .38389 Metetra
.656 .751 .919 r
.10158 .38389 .10856 .39017 .11801 .38677 .11105 .38047 Metetra
.656 .751 .919 r
.11105 .38047 .11801 .38677 .12751 .38336 .12056 .37703 Metetra
.656 .751 .919 r
.12056 .37703 .12751 .38336 .13703 .37994 .13011 .37358 Metetra
.656 .751 .919 r
.13011 .37358 .13703 .37994 .14659 .3765 .13969 .37012 Metetra
.656 .751 .919 r
.13969 .37012 .14659 .3765 .15619 .37305 .14931 .36664 Metetra
.656 .751 .919 r
.14931 .36664 .15619 .37305 .16583 .36959 .15896 .36316 Metetra
.656 .751 .919 r
.15896 .36316 .16583 .36959 .1755 .36611 .16866 .35966 Metetra
.656 .751 .919 r
.16866 .35966 .1755 .36611 .1852 .36262 .17838 .35614 Metetra
.656 .751 .919 r
.17838 .35614 .1852 .36262 .19495 .35912 .18815 .35261 Metetra
.656 .751 .919 r
.18815 .35261 .19495 .35912 .20473 .3556 .19795 .34907 Metetra
.656 .751 .919 r
.19795 .34907 .20473 .3556 .21455 .35207 .20779 .34552 Metetra
.656 .751 .919 r
.20779 .34552 .21455 .35207 .2244 .34853 .21767 .34195 Metetra
.656 .751 .919 r
.21767 .34195 .2244 .34853 .23429 .34497 .22758 .33837 Metetra
.656 .751 .919 r
.22758 .33837 .23429 .34497 .24422 .3414 .23753 .33478 Metetra
.656 .751 .919 r
.23753 .33478 .24422 .3414 .25419 .33782 .24752 .33117 Metetra
.656 .751 .919 r
.24752 .33117 .25419 .33782 .2642 .33422 .25755 .32754 Metetra
.656 .751 .919 r
.25755 .32754 .2642 .33422 .27424 .33061 .26762 .32391 Metetra
.656 .751 .919 r
.26762 .32391 .27424 .33061 .28432 .32698 .27773 .32026 Metetra
.656 .751 .919 r
.27773 .32026 .28432 .32698 .29445 .32335 .28787 .31659 Metetra
.656 .751 .919 r
.28787 .31659 .29445 .32335 .30461 .31969 .29805 .31291 Metetra
.656 .751 .919 r
.29805 .31291 .30461 .31969 .31481 .31603 .30828 .30922 Metetra
.656 .751 .919 r
.30828 .30922 .31481 .31603 .32505 .31234 .31854 .30551 Metetra
.656 .751 .919 r
.31854 .30551 .32505 .31234 .33533 .30865 .32885 .30179 Metetra
.656 .751 .919 r
.32885 .30179 .33533 .30865 .34565 .30494 .33919 .29805 Metetra
.656 .751 .919 r
.33919 .29805 .34565 .30494 .356 .30122 .34957 .2943 Metetra
.656 .751 .919 r
.34957 .2943 .356 .30122 .3664 .29748 .36 .29054 Metetra
.656 .751 .919 r
.36 .29054 .3664 .29748 .37685 .29372 .37047 .28675 Metetra
.656 .751 .919 r
.37047 .28675 .37685 .29372 .38733 .28995 .38097 .28296 Metetra
.656 .751 .919 r
.38097 .28296 .38733 .28995 .39785 .28617 .39152 .27915 Metetra
.656 .751 .919 r
.39152 .27915 .39785 .28617 .40841 .28237 .40211 .27532 Metetra
.656 .751 .919 r
.40211 .27532 .40841 .28237 .41902 .27856 .41274 .27148 Metetra
.656 .751 .919 r
.41274 .27148 .41902 .27856 .42967 .27473 .42342 .26763 Metetra
.656 .751 .919 r
.42342 .26763 .42967 .27473 .44036 .27089 .43413 .26376 Metetra
.656 .751 .919 r
.43413 .26376 .44036 .27089 .45109 .26703 .44489 .25987 Metetra
.656 .751 .919 r
.44489 .25987 .45109 .26703 .46186 .26316 .45569 .25597 Metetra
.656 .751 .919 r
.45569 .25597 .46186 .26316 .47268 .25927 .46654 .25205 Metetra
.656 .751 .919 r
.46654 .25205 .47268 .25927 .48354 .25537 .47743 .24812 Metetra
.656 .751 .919 r
.47743 .24812 .48354 .25537 .49444 .25145 .48836 .24417 Metetra
.656 .751 .919 r
.48836 .24417 .49444 .25145 .50539 .24751 .49934 .2402 Metetra
.656 .751 .919 r
.49934 .2402 .50539 .24751 .51638 .24356 .51036 .23622 Metetra
.656 .751 .919 r
.51036 .23622 .51638 .24356 .52742 .23959 .52142 .23222 Metetra
.656 .751 .919 r
.52142 .23222 .52742 .23959 .5385 .23561 .53253 .22821 Metetra
.656 .751 .919 r
.53253 .22821 .5385 .23561 .54962 .23161 .54368 .22418 Metetra
.656 .751 .919 r
.54368 .22418 .54962 .23161 .56079 .22759 .55488 .22014 Metetra
.656 .751 .919 r
.55488 .22014 .56079 .22759 .57201 .22356 .56613 .21607 Metetra
.656 .751 .919 r
.56613 .21607 .57201 .22356 .58327 .21951 .57742 .21199 Metetra
.656 .751 .919 r
.57742 .21199 .58327 .21951 .59458 .21545 .58876 .2079 Metetra
.656 .751 .919 r
.58876 .2079 .59458 .21545 .60593 .21137 .60014 .20379 Metetra
.656 .751 .919 r
.60014 .20379 .60593 .21137 .61733 .20727 .61157 .19966 Metetra
.656 .751 .919 r
.61157 .19966 .61733 .20727 .62877 .20315 .62305 .19551 Metetra
.656 .751 .919 r
.62305 .19551 .62877 .20315 .64027 .19902 .63457 .19135 Metetra
.656 .751 .919 r
.63457 .19135 .64027 .19902 .65181 .19487 .64614 .18717 Metetra
.656 .751 .919 r
.64614 .18717 .65181 .19487 .66339 .19071 .65776 .18297 Metetra
.656 .751 .919 r
.65776 .18297 .66339 .19071 .67503 .18652 .66943 .17876 Metetra
.656 .751 .919 r
.66943 .17876 .67503 .18652 .68671 .18232 .68115 .17452 Metetra
.656 .751 .919 r
.68115 .17452 .68671 .18232 .69844 .17811 .69291 .17027 Metetra
.656 .751 .919 r
.69291 .17027 .69844 .17811 .71022 .17387 .70473 .16601 Metetra
.656 .751 .919 r
.70473 .16601 .71022 .17387 .72205 .16962 .71659 .16172 Metetra
.656 .751 .919 r
.71659 .16172 .72205 .16962 .73393 .16535 .7285 .15742 Metetra
.353 .044 .294 r
.05644 .39452 .0691 .36197 .07336 .39408 .06627 .38782 Metetra
.656 .751 .919 r
.06627 .38782 .07336 .39408 .08273 .3907 .07566 .38441 Metetra
.656 .751 .919 r
.07566 .38441 .08273 .3907 .09214 .3873 .08509 .38099 Metetra
.656 .751 .919 r
.08509 .38099 .09214 .3873 .10158 .38389 .09455 .37756 Metetra
.656 .751 .919 r
.09455 .37756 .10158 .38389 .11105 .38047 .10404 .37411 Metetra
.656 .751 .919 r
.10404 .37411 .11105 .38047 .12056 .37703 .11357 .37065 Metetra
.656 .751 .919 r
.11357 .37065 .12056 .37703 .13011 .37358 .12314 .36718 Metetra
.656 .751 .919 r
.12314 .36718 .13011 .37358 .13969 .37012 .13274 .36369 Metetra
.656 .751 .919 r
.13274 .36369 .13969 .37012 .14931 .36664 .14238 .3602 Metetra
.656 .751 .919 r
.14238 .3602 .14931 .36664 .15896 .36316 .15205 .35668 Metetra
.656 .751 .919 r
.15205 .35668 .15896 .36316 .16866 .35966 .16177 .35316 Metetra
.656 .751 .919 r
.16177 .35316 .16866 .35966 .17838 .35614 .17152 .34962 Metetra
.656 .751 .919 r
.17152 .34962 .17838 .35614 .18815 .35261 .1813 .34607 Metetra
.656 .751 .919 r
.1813 .34607 .18815 .35261 .19795 .34907 .19112 .3425 Metetra
.656 .751 .919 r
.19112 .3425 .19795 .34907 .20779 .34552 .20099 .33892 Metetra
.656 .751 .919 r
.20099 .33892 .20779 .34552 .21767 .34195 .21088 .33533 Metetra
.656 .751 .919 r
.21088 .33533 .21767 .34195 .22758 .33837 .22082 .33172 Metetra
.656 .751 .919 r
.22082 .33172 .22758 .33837 .23753 .33478 .2308 .3281 Metetra
.656 .751 .919 r
.2308 .3281 .23753 .33478 .24752 .33117 .24081 .32447 Metetra
.656 .751 .919 r
.24081 .32447 .24752 .33117 .25755 .32754 .25086 .32082 Metetra
.656 .751 .919 r
.25086 .32082 .25755 .32754 .26762 .32391 .26095 .31716 Metetra
.656 .751 .919 r
.26095 .31716 .26762 .32391 .27773 .32026 .27108 .31348 Metetra
.656 .751 .919 r
.27108 .31348 .27773 .32026 .28787 .31659 .28125 .30979 Metetra
.656 .751 .919 r
.28125 .30979 .28787 .31659 .29805 .31291 .29146 .30608 Metetra
.656 .751 .919 r
.29146 .30608 .29805 .31291 .30828 .30922 .3017 .30236 Metetra
.656 .751 .919 r
.3017 .30236 .30828 .30922 .31854 .30551 .31199 .29863 Metetra
.656 .751 .919 r
.31199 .29863 .31854 .30551 .32885 .30179 .32232 .29488 Metetra
.656 .751 .919 r
.32232 .29488 .32885 .30179 .33919 .29805 .33269 .29112 Metetra
.656 .751 .919 r
.33269 .29112 .33919 .29805 .34957 .2943 .3431 .28734 Metetra
.656 .751 .919 r
.3431 .28734 .34957 .2943 .36 .29054 .35355 .28354 Metetra
.656 .751 .919 r
.35355 .28354 .36 .29054 .37047 .28675 .36404 .27974 Metetra
.656 .751 .919 r
.36404 .27974 .37047 .28675 .38097 .28296 .37457 .27591 Metetra
.656 .751 .919 r
.37457 .27591 .38097 .28296 .39152 .27915 .38515 .27207 Metetra
.656 .751 .919 r
.38515 .27207 .39152 .27915 .40211 .27532 .39576 .26822 Metetra
.656 .751 .919 r
.39576 .26822 .40211 .27532 .41274 .27148 .40642 .26435 Metetra
.656 .751 .919 r
.40642 .26435 .41274 .27148 .42342 .26763 .41712 .26047 Metetra
.656 .751 .919 r
.41712 .26047 .42342 .26763 .43413 .26376 .42786 .25657 Metetra
.656 .751 .919 r
.42786 .25657 .43413 .26376 .44489 .25987 .43865 .25265 Metetra
.656 .751 .919 r
.43865 .25265 .44489 .25987 .45569 .25597 .44948 .24872 Metetra
.656 .751 .919 r
.44948 .24872 .45569 .25597 .46654 .25205 .46035 .24478 Metetra
.656 .751 .919 r
.46035 .24478 .46654 .25205 .47743 .24812 .47127 .24081 Metetra
.656 .751 .919 r
.47127 .24081 .47743 .24812 .48836 .24417 .48223 .23683 Metetra
.656 .751 .919 r
.48223 .23683 .48836 .24417 .49934 .2402 .49323 .23284 Metetra
.656 .751 .919 r
.49323 .23284 .49934 .2402 .51036 .23622 .50428 .22883 Metetra
.656 .751 .919 r
.50428 .22883 .51036 .23622 .52142 .23222 .51538 .2248 Metetra
.656 .751 .919 r
.51538 .2248 .52142 .23222 .53253 .22821 .52651 .22076 Metetra
.656 .751 .919 r
.52651 .22076 .53253 .22821 .54368 .22418 .5377 .2167 Metetra
.656 .751 .919 r
.5377 .2167 .54368 .22418 .55488 .22014 .54893 .21262 Metetra
.656 .751 .919 r
.54893 .21262 .55488 .22014 .56613 .21607 .5602 .20853 Metetra
.656 .751 .919 r
.5602 .20853 .56613 .21607 .57742 .21199 .57152 .20442 Metetra
.656 .751 .919 r
.57152 .20442 .57742 .21199 .58876 .2079 .58289 .20029 Metetra
.656 .751 .919 r
.58289 .20029 .58876 .2079 .60014 .20379 .59431 .19615 Metetra
.656 .751 .919 r
.59431 .19615 .60014 .20379 .61157 .19966 .60577 .19199 Metetra
.656 .751 .919 r
.60577 .19199 .61157 .19966 .62305 .19551 .61728 .18781 Metetra
.656 .751 .919 r
.61728 .18781 .62305 .19551 .63457 .19135 .62883 .18362 Metetra
.656 .751 .919 r
.62883 .18362 .63457 .19135 .64614 .18717 .64044 .17941 Metetra
.656 .751 .919 r
.64044 .17941 .64614 .18717 .65776 .18297 .65209 .17518 Metetra
.656 .751 .919 r
.65209 .17518 .65776 .18297 .66943 .17876 .66379 .17093 Metetra
.656 .751 .919 r
.66379 .17093 .66943 .17876 .68115 .17452 .67554 .16666 Metetra
.656 .751 .919 r
.67554 .16666 .68115 .17452 .69291 .17027 .68734 .16238 Metetra
.656 .751 .919 r
.68734 .16238 .69291 .17027 .70473 .16601 .69919 .15808 Metetra
.656 .751 .919 r
.69919 .15808 .70473 .16601 .71659 .16172 .71109 .15376 Metetra
.656 .751 .919 r
.71109 .15376 .71659 .16172 .7285 .15742 .72303 .14942 Metetra
.863 .856 .402 r
.04369 .42595 .05644 .39452 .06627 .38782 .05913 .38152 Metetra
.656 .751 .919 r
.05913 .38152 .06627 .38782 .07566 .38441 .06854 .37809 Metetra
.656 .751 .919 r
.06854 .37809 .07566 .38441 .08509 .38099 .07799 .37464 Metetra
.656 .751 .919 r
.07799 .37464 .08509 .38099 .09455 .37756 .08747 .37119 Metetra
.656 .751 .919 r
.08747 .37119 .09455 .37756 .10404 .37411 .09698 .36772 Metetra
.656 .751 .919 r
.09698 .36772 .10404 .37411 .11357 .37065 .10653 .36423 Metetra
.656 .751 .919 r
.10653 .36423 .11357 .37065 .12314 .36718 .11612 .36073 Metetra
.656 .751 .919 r
.11612 .36073 .12314 .36718 .13274 .36369 .12574 .35722 Metetra
.656 .751 .919 r
.12574 .35722 .13274 .36369 .14238 .3602 .1354 .3537 Metetra
.656 .751 .919 r
.1354 .3537 .14238 .3602 .15205 .35668 .1451 .35016 Metetra
.656 .751 .919 r
.1451 .35016 .15205 .35668 .16177 .35316 .15483 .34661 Metetra
.656 .751 .919 r
.15483 .34661 .16177 .35316 .17152 .34962 .1646 .34305 Metetra
.656 .751 .919 r
.1646 .34305 .17152 .34962 .1813 .34607 .17441 .33947 Metetra
.656 .751 .919 r
.17441 .33947 .1813 .34607 .19112 .3425 .18425 .33588 Metetra
.656 .751 .919 r
.18425 .33588 .19112 .3425 .20099 .33892 .19413 .33228 Metetra
.656 .751 .919 r
.19413 .33228 .20099 .33892 .21088 .33533 .20405 .32866 Metetra
.656 .751 .919 r
.20405 .32866 .21088 .33533 .22082 .33172 .21401 .32503 Metetra
.656 .751 .919 r
.21401 .32503 .22082 .33172 .2308 .3281 .22401 .32138 Metetra
.656 .751 .919 r
.22401 .32138 .2308 .3281 .24081 .32447 .23405 .31772 Metetra
.656 .751 .919 r
.23405 .31772 .24081 .32447 .25086 .32082 .24412 .31405 Metetra
.656 .751 .919 r
.24412 .31405 .25086 .32082 .26095 .31716 .25423 .31036 Metetra
.656 .751 .919 r
.25423 .31036 .26095 .31716 .27108 .31348 .26439 .30665 Metetra
.656 .751 .919 r
.26439 .30665 .27108 .31348 .28125 .30979 .27458 .30294 Metetra
.656 .751 .919 r
.27458 .30294 .28125 .30979 .29146 .30608 .28481 .2992 Metetra
.656 .751 .919 r
.28481 .2992 .29146 .30608 .3017 .30236 .29508 .29546 Metetra
.656 .751 .919 r
.29508 .29546 .3017 .30236 .31199 .29863 .30539 .2917 Metetra
.656 .751 .919 r
.30539 .2917 .31199 .29863 .32232 .29488 .31575 .28792 Metetra
.656 .751 .919 r
.31575 .28792 .32232 .29488 .33269 .29112 .32614 .28413 Metetra
.656 .751 .919 r
.32614 .28413 .33269 .29112 .3431 .28734 .33657 .28032 Metetra
.656 .751 .919 r
.33657 .28032 .3431 .28734 .35355 .28354 .34705 .2765 Metetra
.656 .751 .919 r
.34705 .2765 .35355 .28354 .36404 .27974 .35756 .27267 Metetra
.656 .751 .919 r
.35756 .27267 .36404 .27974 .37457 .27591 .36812 .26881 Metetra
.656 .751 .919 r
.36812 .26881 .37457 .27591 .38515 .27207 .37872 .26495 Metetra
.656 .751 .919 r
.37872 .26495 .38515 .27207 .39576 .26822 .38937 .26107 Metetra
.656 .751 .919 r
.38937 .26107 .39576 .26822 .40642 .26435 .40005 .25717 Metetra
.656 .751 .919 r
.40005 .25717 .40642 .26435 .41712 .26047 .41078 .25326 Metetra
.656 .751 .919 r
.41078 .25326 .41712 .26047 .42786 .25657 .42155 .24933 Metetra
.656 .751 .919 r
.42155 .24933 .42786 .25657 .43865 .25265 .43236 .24538 Metetra
.656 .751 .919 r
.43236 .24538 .43865 .25265 .44948 .24872 .44322 .24142 Metetra
.656 .751 .919 r
.44322 .24142 .44948 .24872 .46035 .24478 .45412 .23745 Metetra
.656 .751 .919 r
.45412 .23745 .46035 .24478 .47127 .24081 .46506 .23346 Metetra
.656 .751 .919 r
.46506 .23346 .47127 .24081 .48223 .23683 .47605 .22945 Metetra
.656 .751 .919 r
.47605 .22945 .48223 .23683 .49323 .23284 .48708 .22542 Metetra
.656 .751 .919 r
.48708 .22542 .49323 .23284 .50428 .22883 .49816 .22138 Metetra
.656 .751 .919 r
.49816 .22138 .50428 .22883 .51538 .2248 .50929 .21733 Metetra
.656 .751 .919 r
.50929 .21733 .51538 .2248 .52651 .22076 .52045 .21325 Metetra
.656 .751 .919 r
.52045 .21325 .52651 .22076 .5377 .2167 .53167 .20916 Metetra
.656 .751 .919 r
.53167 .20916 .5377 .2167 .54893 .21262 .54293 .20505 Metetra
.656 .751 .919 r
.54293 .20505 .54893 .21262 .5602 .20853 .55423 .20093 Metetra
.656 .751 .919 r
.55423 .20093 .5602 .20853 .57152 .20442 .56559 .19679 Metetra
.656 .751 .919 r
.56559 .19679 .57152 .20442 .58289 .20029 .57698 .19263 Metetra
.656 .751 .919 r
.57698 .19263 .58289 .20029 .59431 .19615 .58843 .18846 Metetra
.656 .751 .919 r
.58843 .18846 .59431 .19615 .60577 .19199 .59992 .18426 Metetra
.656 .751 .919 r
.59992 .18426 .60577 .19199 .61728 .18781 .61146 .18006 Metetra
.656 .751 .919 r
.61146 .18006 .61728 .18781 .62883 .18362 .62305 .17583 Metetra
.656 .751 .919 r
.62305 .17583 .62883 .18362 .64044 .17941 .63469 .17158 Metetra
.656 .751 .919 r
.63469 .17158 .64044 .17941 .65209 .17518 .64637 .16732 Metetra
.656 .751 .919 r
.64637 .16732 .65209 .17518 .66379 .17093 .65811 .16304 Metetra
.656 .751 .919 r
.65811 .16304 .66379 .17093 .67554 .16666 .66989 .15874 Metetra
.656 .751 .919 r
.66989 .15874 .67554 .16666 .68734 .16238 .68172 .15443 Metetra
.656 .751 .919 r
.68172 .15443 .68734 .16238 .69919 .15808 .69361 .15009 Metetra
.656 .751 .919 r
.69361 .15009 .69919 .15808 .71109 .15376 .70554 .14574 Metetra
.656 .751 .919 r
.70554 .14574 .71109 .15376 .72303 .14942 .71752 .14137 Metetra
0 0 .335 r
.05348 .3061 .04369 .42595 .05913 .38152 .05195 .37517 Metetra
.656 .751 .919 r
.05195 .37517 .05913 .38152 .06854 .37809 .06138 .37172 Metetra
.656 .751 .919 r
.06138 .37172 .06854 .37809 .07799 .37464 .07084 .36825 Metetra
.656 .751 .919 r
.07084 .36825 .07799 .37464 .08747 .37119 .08034 .36477 Metetra
.656 .751 .919 r
.08034 .36477 .08747 .37119 .09698 .36772 .08987 .36127 Metetra
.656 .751 .919 r
.08987 .36127 .09698 .36772 .10653 .36423 .09944 .35777 Metetra
.656 .751 .919 r
.09944 .35777 .10653 .36423 .11612 .36073 .10905 .35424 Metetra
.656 .751 .919 r
.10905 .35424 .11612 .36073 .12574 .35722 .11869 .35071 Metetra
.656 .751 .919 r
.11869 .35071 .12574 .35722 .1354 .3537 .12837 .34716 Metetra
.656 .751 .919 r
.12837 .34716 .1354 .3537 .1451 .35016 .13809 .3436 Metetra
.656 .751 .919 r
.13809 .3436 .1451 .35016 .15483 .34661 .14784 .34003 Metetra
.656 .751 .919 r
.14784 .34003 .15483 .34661 .1646 .34305 .15763 .33644 Metetra
.656 .751 .919 r
.15763 .33644 .1646 .34305 .17441 .33947 .16746 .33283 Metetra
.656 .751 .919 r
.16746 .33283 .17441 .33947 .18425 .33588 .17733 .32922 Metetra
.656 .751 .919 r
.17733 .32922 .18425 .33588 .19413 .33228 .18723 .32559 Metetra
.656 .751 .919 r
.18723 .32559 .19413 .33228 .20405 .32866 .19718 .32194 Metetra
.656 .751 .919 r
.19718 .32194 .20405 .32866 .21401 .32503 .20716 .31828 Metetra
.656 .751 .919 r
.20716 .31828 .21401 .32503 .22401 .32138 .21718 .31461 Metetra
.656 .751 .919 r
.21718 .31461 .22401 .32138 .23405 .31772 .22723 .31093 Metetra
.656 .751 .919 r
.22723 .31093 .23405 .31772 .24412 .31405 .23733 .30722 Metetra
.656 .751 .919 r
.23733 .30722 .24412 .31405 .25423 .31036 .24747 .30351 Metetra
.656 .751 .919 r
.24747 .30351 .25423 .31036 .26439 .30665 .25764 .29978 Metetra
.656 .751 .919 r
.25764 .29978 .26439 .30665 .27458 .30294 .26786 .29603 Metetra
.656 .751 .919 r
.26786 .29603 .27458 .30294 .28481 .2992 .27811 .29228 Metetra
.656 .751 .919 r
.27811 .29228 .28481 .2992 .29508 .29546 .28841 .2885 Metetra
.656 .751 .919 r
.28841 .2885 .29508 .29546 .30539 .2917 .29875 .28471 Metetra
.656 .751 .919 r
.29875 .28471 .30539 .2917 .31575 .28792 .30912 .28091 Metetra
.656 .751 .919 r
.30912 .28091 .31575 .28792 .32614 .28413 .31954 .27709 Metetra
.656 .751 .919 r
.31954 .27709 .32614 .28413 .33657 .28032 .33 .27326 Metetra
.656 .751 .919 r
.33 .27326 .33657 .28032 .34705 .2765 .3405 .26941 Metetra
.656 .751 .919 r
.3405 .26941 .34705 .2765 .35756 .27267 .35104 .26554 Metetra
.656 .751 .919 r
.35104 .26554 .35756 .27267 .36812 .26881 .36163 .26166 Metetra
.656 .751 .919 r
.36163 .26166 .36812 .26881 .37872 .26495 .37225 .25777 Metetra
.656 .751 .919 r
.37225 .25777 .37872 .26495 .38937 .26107 .38292 .25386 Metetra
.656 .751 .919 r
.38292 .25386 .38937 .26107 .40005 .25717 .39363 .24993 Metetra
.656 .751 .919 r
.39363 .24993 .40005 .25717 .41078 .25326 .40439 .24599 Metetra
.656 .751 .919 r
.40439 .24599 .41078 .25326 .42155 .24933 .41519 .24203 Metetra
.656 .751 .919 r
.41519 .24203 .42155 .24933 .43236 .24538 .42603 .23806 Metetra
.656 .751 .919 r
.42603 .23806 .43236 .24538 .44322 .24142 .43691 .23407 Metetra
.656 .751 .919 r
.43691 .23407 .44322 .24142 .45412 .23745 .44784 .23007 Metetra
.656 .751 .919 r
.44784 .23007 .45412 .23745 .46506 .23346 .45881 .22604 Metetra
.656 .751 .919 r
.45881 .22604 .46506 .23346 .47605 .22945 .46983 .22201 Metetra
.656 .751 .919 r
.46983 .22201 .47605 .22945 .48708 .22542 .48089 .21795 Metetra
.656 .751 .919 r
.48089 .21795 .48708 .22542 .49816 .22138 .492 .21388 Metetra
.656 .751 .919 r
.492 .21388 .49816 .22138 .50929 .21733 .50315 .20979 Metetra
.656 .751 .919 r
.50315 .20979 .50929 .21733 .52045 .21325 .51435 .20569 Metetra
.656 .751 .919 r
.51435 .20569 .52045 .21325 .53167 .20916 .52559 .20157 Metetra
.656 .751 .919 r
.52559 .20157 .53167 .20916 .54293 .20505 .53688 .19743 Metetra
.656 .751 .919 r
.53688 .19743 .54293 .20505 .55423 .20093 .54822 .19327 Metetra
.656 .751 .919 r
.54822 .19327 .55423 .20093 .56559 .19679 .5596 .1891 Metetra
.656 .751 .919 r
.5596 .1891 .56559 .19679 .57698 .19263 .57103 .18491 Metetra
.656 .751 .919 r
.57103 .18491 .57698 .19263 .58843 .18846 .58251 .1807 Metetra
.656 .751 .919 r
.58251 .1807 .58843 .18846 .59992 .18426 .59403 .17648 Metetra
.656 .751 .919 r
.59403 .17648 .59992 .18426 .61146 .18006 .60561 .17224 Metetra
.656 .751 .919 r
.60561 .17224 .61146 .18006 .62305 .17583 .61723 .16798 Metetra
.656 .751 .919 r
.61723 .16798 .62305 .17583 .63469 .17158 .6289 .1637 Metetra
.656 .751 .919 r
.6289 .1637 .63469 .17158 .64637 .16732 .64061 .15941 Metetra
.656 .751 .919 r
.64061 .15941 .64637 .16732 .65811 .16304 .65238 .15509 Metetra
.656 .751 .919 r
.65238 .15509 .65811 .16304 .66989 .15874 .6642 .15076 Metetra
.656 .751 .919 r
.6642 .15076 .66989 .15874 .68172 .15443 .67607 .14641 Metetra
.656 .751 .919 r
.67607 .14641 .68172 .15443 .69361 .15009 .68798 .14204 Metetra
.656 .751 .919 r
.68798 .14204 .69361 .15009 .70554 .14574 .69995 .13766 Metetra
.656 .751 .919 r
.69995 .13766 .70554 .14574 .71752 .14137 .71197 .13325 Metetra
0 0 .243 r
.02281 .45376 .05348 .3061 .05195 .37517 .04471 .36878 Metetra
.656 .751 .919 r
.04471 .36878 .05195 .37517 .06138 .37172 .05416 .3653 Metetra
.656 .751 .919 r
.05416 .3653 .06138 .37172 .07084 .36825 .06364 .36181 Metetra
.656 .751 .919 r
.06364 .36181 .07084 .36825 .08034 .36477 .07316 .35831 Metetra
.656 .751 .919 r
.07316 .35831 .08034 .36477 .08987 .36127 .08271 .35479 Metetra
.656 .751 .919 r
.08271 .35479 .08987 .36127 .09944 .35777 .0923 .35125 Metetra
.656 .751 .919 r
.0923 .35125 .09944 .35777 .10905 .35424 .10193 .34771 Metetra
.656 .751 .919 r
.10193 .34771 .10905 .35424 .11869 .35071 .11159 .34415 Metetra
.656 .751 .919 r
.11159 .34415 .11869 .35071 .12837 .34716 .1213 .34058 Metetra
.656 .751 .919 r
.1213 .34058 .12837 .34716 .13809 .3436 .13103 .33699 Metetra
.656 .751 .919 r
.13103 .33699 .13809 .3436 .14784 .34003 .14081 .33339 Metetra
.656 .751 .919 r
.14081 .33339 .14784 .34003 .15763 .33644 .15062 .32977 Metetra
.656 .751 .919 r
.15062 .32977 .15763 .33644 .16746 .33283 .16047 .32615 Metetra
.656 .751 .919 r
.16047 .32615 .16746 .33283 .17733 .32922 .17036 .3225 Metetra
.656 .751 .919 r
.17036 .3225 .17733 .32922 .18723 .32559 .18028 .31885 Metetra
.656 .751 .919 r
.18028 .31885 .18723 .32559 .19718 .32194 .19025 .31518 Metetra
.656 .751 .919 r
.19025 .31518 .19718 .32194 .20716 .31828 .20025 .31149 Metetra
.656 .751 .919 r
.20025 .31149 .20716 .31828 .21718 .31461 .21029 .30779 Metetra
.656 .751 .919 r
.21029 .30779 .21718 .31461 .22723 .31093 .22037 .30408 Metetra
.656 .751 .919 r
.22037 .30408 .22723 .31093 .23733 .30722 .23049 .30035 Metetra
.656 .751 .919 r
.23049 .30035 .23733 .30722 .24747 .30351 .24065 .29661 Metetra
.656 .751 .919 r
.24065 .29661 .24747 .30351 .25764 .29978 .25085 .29285 Metetra
.656 .751 .919 r
.25085 .29285 .25764 .29978 .26786 .29603 .26109 .28908 Metetra
.656 .751 .919 r
.26109 .28908 .26786 .29603 .27811 .29228 .27137 .2853 Metetra
.656 .751 .919 r
.27137 .2853 .27811 .29228 .28841 .2885 .28169 .2815 Metetra
.656 .751 .919 r
.28169 .2815 .28841 .2885 .29875 .28471 .29205 .27768 Metetra
.656 .751 .919 r
.29205 .27768 .29875 .28471 .30912 .28091 .30245 .27385 Metetra
.656 .751 .919 r
.30245 .27385 .30912 .28091 .31954 .27709 .3129 .27 Metetra
.656 .751 .919 r
.3129 .27 .31954 .27709 .33 .27326 .32338 .26614 Metetra
.656 .751 .919 r
.32338 .26614 .33 .27326 .3405 .26941 .33391 .26226 Metetra
.656 .751 .919 r
.33391 .26226 .3405 .26941 .35104 .26554 .34447 .25837 Metetra
.656 .751 .919 r
.34447 .25837 .35104 .26554 .36163 .26166 .35508 .25446 Metetra
.656 .751 .919 r
.35508 .25446 .36163 .26166 .37225 .25777 .36574 .25054 Metetra
.656 .751 .919 r
.36574 .25054 .37225 .25777 .38292 .25386 .37643 .2466 Metetra
.656 .751 .919 r
.37643 .2466 .38292 .25386 .39363 .24993 .38717 .24264 Metetra
.656 .751 .919 r
.38717 .24264 .39363 .24993 .40439 .24599 .39795 .23867 Metetra
.656 .751 .919 r
.39795 .23867 .40439 .24599 .41519 .24203 .40878 .23469 Metetra
.656 .751 .919 r
.40878 .23469 .41519 .24203 .42603 .23806 .41964 .23068 Metetra
.656 .751 .919 r
.41964 .23068 .42603 .23806 .43691 .23407 .43056 .22666 Metetra
.656 .751 .919 r
.43056 .22666 .43691 .23407 .44784 .23007 .44151 .22263 Metetra
.656 .751 .919 r
.44151 .22263 .44784 .23007 .45881 .22604 .45251 .21858 Metetra
.656 .751 .919 r
.45251 .21858 .45881 .22604 .46983 .22201 .46356 .21451 Metetra
.656 .751 .919 r
.46356 .21451 .46983 .22201 .48089 .21795 .47465 .21042 Metetra
.656 .751 .919 r
.47465 .21042 .48089 .21795 .492 .21388 .48579 .20632 Metetra
.656 .751 .919 r
.48579 .20632 .492 .21388 .50315 .20979 .49697 .2022 Metetra
.656 .751 .919 r
.49697 .2022 .50315 .20979 .51435 .20569 .50819 .19807 Metetra
.656 .751 .919 r
.50819 .19807 .51435 .20569 .52559 .20157 .51947 .19391 Metetra
.656 .751 .919 r
.51947 .19391 .52559 .20157 .53688 .19743 .53079 .18974 Metetra
.656 .751 .919 r
.53079 .18974 .53688 .19743 .54822 .19327 .54216 .18556 Metetra
.656 .751 .919 r
.54216 .18556 .54822 .19327 .5596 .1891 .55357 .18135 Metetra
.656 .751 .919 r
.55357 .18135 .5596 .1891 .57103 .18491 .56503 .17713 Metetra
.656 .751 .919 r
.56503 .17713 .57103 .18491 .58251 .1807 .57654 .17289 Metetra
.656 .751 .919 r
.57654 .17289 .58251 .1807 .59403 .17648 .5881 .16863 Metetra
.656 .751 .919 r
.5881 .16863 .59403 .17648 .60561 .17224 .5997 .16436 Metetra
.656 .751 .919 r
.5997 .16436 .60561 .17224 .61723 .16798 .61136 .16007 Metetra
.656 .751 .919 r
.61136 .16007 .61723 .16798 .6289 .1637 .62306 .15576 Metetra
.656 .751 .919 r
.62306 .15576 .6289 .1637 .64061 .15941 .63481 .15143 Metetra
.656 .751 .919 r
.63481 .15143 .64061 .15941 .65238 .15509 .64661 .14708 Metetra
.656 .751 .919 r
.64661 .14708 .65238 .15509 .6642 .15076 .65846 .14272 Metetra
.656 .751 .919 r
.65846 .14272 .6642 .15076 .67607 .14641 .67036 .13833 Metetra
.656 .751 .919 r
.67036 .13833 .67607 .14641 .68798 .14204 .68231 .13393 Metetra
.656 .751 .919 r
.68231 .13393 .68798 .14204 .69995 .13766 .69431 .12951 Metetra
.656 .751 .919 r
.69431 .12951 .69995 .13766 .71197 .13325 .70637 .12507 Metetra
.235 .067 .438 r
.03583 .3156 .02281 .45376 .04471 .36878 .03743 .36235 Metetra
.656 .751 .919 r
.03743 .36235 .04471 .36878 .05416 .3653 .04689 .35885 Metetra
.656 .751 .919 r
.04689 .35885 .05416 .3653 .06364 .36181 .05639 .35533 Metetra
.656 .751 .919 r
.05639 .35533 .06364 .36181 .07316 .35831 .06593 .3518 Metetra
.656 .751 .919 r
.06593 .3518 .07316 .35831 .08271 .35479 .07551 .34825 Metetra
.656 .751 .919 r
.07551 .34825 .08271 .35479 .0923 .35125 .08512 .3447 Metetra
.656 .751 .919 r
.08512 .3447 .0923 .35125 .10193 .34771 .09476 .34113 Metetra
.656 .751 .919 r
.09476 .34113 .10193 .34771 .11159 .34415 .10445 .33754 Metetra
.656 .751 .919 r
.10445 .33754 .11159 .34415 .1213 .34058 .11417 .33394 Metetra
.656 .751 .919 r
.11417 .33394 .1213 .34058 .13103 .33699 .12393 .33033 Metetra
.656 .751 .919 r
.12393 .33033 .13103 .33699 .14081 .33339 .13372 .32671 Metetra
.656 .751 .919 r
.13372 .32671 .14081 .33339 .15062 .32977 .14356 .32307 Metetra
.656 .751 .919 r
.14356 .32307 .15062 .32977 .16047 .32615 .15343 .31941 Metetra
.656 .751 .919 r
.15343 .31941 .16047 .32615 .17036 .3225 .16334 .31574 Metetra
.656 .751 .919 r
.16334 .31574 .17036 .3225 .18028 .31885 .17328 .31206 Metetra
.656 .751 .919 r
.17328 .31206 .18028 .31885 .19025 .31518 .18327 .30836 Metetra
.656 .751 .919 r
.18327 .30836 .19025 .31518 .20025 .31149 .1933 .30465 Metetra
.656 .751 .919 r
.1933 .30465 .20025 .31149 .21029 .30779 .20336 .30093 Metetra
.656 .751 .919 r
.20336 .30093 .21029 .30779 .22037 .30408 .21346 .29719 Metetra
.656 .751 .919 r
.21346 .29719 .22037 .30408 .23049 .30035 .22361 .29343 Metetra
.656 .751 .919 r
.22361 .29343 .23049 .30035 .24065 .29661 .23379 .28966 Metetra
.656 .751 .919 r
.23379 .28966 .24065 .29661 .25085 .29285 .24401 .28588 Metetra
.656 .751 .919 r
.24401 .28588 .25085 .29285 .26109 .28908 .25428 .28208 Metetra
.656 .751 .919 r
.25428 .28208 .26109 .28908 .27137 .2853 .26458 .27827 Metetra
.656 .751 .919 r
.26458 .27827 .27137 .2853 .28169 .2815 .27492 .27444 Metetra
.656 .751 .919 r
.27492 .27444 .28169 .2815 .29205 .27768 .28531 .27059 Metetra
.656 .751 .919 r
.28531 .27059 .29205 .27768 .30245 .27385 .29574 .26673 Metetra
.656 .751 .919 r
.29574 .26673 .30245 .27385 .3129 .27 .3062 .26286 Metetra
.656 .751 .919 r
.3062 .26286 .3129 .27 .32338 .26614 .31671 .25897 Metetra
.656 .751 .919 r
.31671 .25897 .32338 .26614 .33391 .26226 .32726 .25506 Metetra
.656 .751 .919 r
.32726 .25506 .33391 .26226 .34447 .25837 .33786 .25114 Metetra
.656 .751 .919 r
.33786 .25114 .34447 .25837 .35508 .25446 .34849 .24721 Metetra
.656 .751 .919 r
.34849 .24721 .35508 .25446 .36574 .25054 .35917 .24325 Metetra
.656 .751 .919 r
.35917 .24325 .36574 .25054 .37643 .2466 .36989 .23928 Metetra
.656 .751 .919 r
.36989 .23928 .37643 .2466 .38717 .24264 .38066 .2353 Metetra
.656 .751 .919 r
.38066 .2353 .38717 .24264 .39795 .23867 .39147 .2313 Metetra
.656 .751 .919 r
.39147 .2313 .39795 .23867 .40878 .23469 .40232 .22728 Metetra
.656 .751 .919 r
.40232 .22728 .40878 .23469 .41964 .23068 .41321 .22325 Metetra
.656 .751 .919 r
.41321 .22325 .41964 .23068 .43056 .22666 .42415 .2192 Metetra
.656 .751 .919 r
.42415 .2192 .43056 .22666 .44151 .22263 .43514 .21513 Metetra
.656 .751 .919 r
.43514 .21513 .44151 .22263 .45251 .21858 .44617 .21105 Metetra
.656 .751 .919 r
.44617 .21105 .45251 .21858 .46356 .21451 .45724 .20695 Metetra
.656 .751 .919 r
.45724 .20695 .46356 .21451 .47465 .21042 .46836 .20284 Metetra
.656 .751 .919 r
.46836 .20284 .47465 .21042 .48579 .20632 .47953 .1987 Metetra
.656 .751 .919 r
.47953 .1987 .48579 .20632 .49697 .2022 .49074 .19455 Metetra
.656 .751 .919 r
.49074 .19455 .49697 .2022 .50819 .19807 .502 .19039 Metetra
.656 .751 .919 r
.502 .19039 .50819 .19807 .51947 .19391 .5133 .1862 Metetra
.656 .751 .919 r
.5133 .1862 .51947 .19391 .53079 .18974 .52465 .182 Metetra
.656 .751 .919 r
.52465 .182 .53079 .18974 .54216 .18556 .53605 .17778 Metetra
.656 .751 .919 r
.53605 .17778 .54216 .18556 .55357 .18135 .54749 .17354 Metetra
.656 .751 .919 r
.54749 .17354 .55357 .18135 .56503 .17713 .55899 .16929 Metetra
.656 .751 .919 r
.55899 .16929 .56503 .17713 .57654 .17289 .57053 .16502 Metetra
.656 .751 .919 r
.57053 .16502 .57654 .17289 .5881 .16863 .58211 .16073 Metetra
.656 .751 .919 r
.58211 .16073 .5881 .16863 .5997 .16436 .59375 .15642 Metetra
.656 .751 .919 r
.59375 .15642 .5997 .16436 .61136 .16007 .60544 .1521 Metetra
.656 .751 .919 r
.60544 .1521 .61136 .16007 .62306 .15576 .61717 .14775 Metetra
.656 .751 .919 r
.61717 .14775 .62306 .15576 .63481 .15143 .62896 .14339 Metetra
.656 .751 .919 r
.62896 .14339 .63481 .15143 .64661 .14708 .64079 .13901 Metetra
.656 .751 .919 r
.64079 .13901 .64661 .14708 .65846 .14272 .65268 .13461 Metetra
.656 .751 .919 r
.65268 .13461 .65846 .14272 .67036 .13833 .66461 .13019 Metetra
.656 .751 .919 r
.66461 .13019 .67036 .13833 .68231 .13393 .6766 .12576 Metetra
.656 .751 .919 r
.6766 .12576 .68231 .13393 .69431 .12951 .68864 .1213 Metetra
.656 .751 .919 r
.68864 .1213 .69431 .12951 .70637 .12507 .70072 .11682 Metetra
.43 .131 .354 r
.02064 .35939 .03583 .3156 .03743 .36235 .03009 .35587 Metetra
.656 .751 .919 r
.03009 .35587 .03743 .36235 .04689 .35885 .03957 .35234 Metetra
.656 .751 .919 r
.03957 .35234 .04689 .35885 .05639 .35533 .0491 .3488 Metetra
.656 .751 .919 r
.0491 .3488 .05639 .35533 .06593 .3518 .05865 .34525 Metetra
.656 .751 .919 r
.05865 .34525 .06593 .3518 .07551 .34825 .06825 .34168 Metetra
.656 .751 .919 r
.06825 .34168 .07551 .34825 .08512 .3447 .07788 .33809 Metetra
.656 .751 .919 r
.07788 .33809 .08512 .3447 .09476 .34113 .08754 .3345 Metetra
.656 .751 .919 r
.08754 .3345 .09476 .34113 .10445 .33754 .09725 .33089 Metetra
.656 .751 .919 r
.09725 .33089 .10445 .33754 .11417 .33394 .10699 .32726 Metetra
.656 .751 .919 r
.10699 .32726 .11417 .33394 .12393 .33033 .11677 .32363 Metetra
.656 .751 .919 r
.11677 .32363 .12393 .33033 .13372 .32671 .12659 .31997 Metetra
.656 .751 .919 r
.12659 .31997 .13372 .32671 .14356 .32307 .13644 .31631 Metetra
.656 .751 .919 r
.13644 .31631 .14356 .32307 .15343 .31941 .14633 .31263 Metetra
.656 .751 .919 r
.14633 .31263 .15343 .31941 .16334 .31574 .15627 .30893 Metetra
.656 .751 .919 r
.15627 .30893 .16334 .31574 .17328 .31206 .16623 .30523 Metetra
.656 .751 .919 r
.16623 .30523 .17328 .31206 .18327 .30836 .17624 .3015 Metetra
.656 .751 .919 r
.17624 .3015 .18327 .30836 .1933 .30465 .18629 .29776 Metetra
.656 .751 .919 r
.18629 .29776 .1933 .30465 .20336 .30093 .19638 .29401 Metetra
.656 .751 .919 r
.19638 .29401 .20336 .30093 .21346 .29719 .2065 .29025 Metetra
.656 .751 .919 r
.2065 .29025 .21346 .29719 .22361 .29343 .21667 .28646 Metetra
.656 .751 .919 r
.21667 .28646 .22361 .29343 .23379 .28966 .22688 .28267 Metetra
.656 .751 .919 r
.22688 .28267 .23379 .28966 .24401 .28588 .23712 .27886 Metetra
.656 .751 .919 r
.23712 .27886 .24401 .28588 .25428 .28208 .24741 .27503 Metetra
.656 .751 .919 r
.24741 .27503 .25428 .28208 .26458 .27827 .25774 .27119 Metetra
.656 .751 .919 r
.25774 .27119 .26458 .27827 .27492 .27444 .26811 .26733 Metetra
.656 .751 .919 r
.26811 .26733 .27492 .27444 .28531 .27059 .27852 .26346 Metetra
.656 .751 .919 r
.27852 .26346 .28531 .27059 .29574 .26673 .28897 .25957 Metetra
.656 .751 .919 r
.28897 .25957 .29574 .26673 .3062 .26286 .29946 .25567 Metetra
.656 .751 .919 r
.29946 .25567 .3062 .26286 .31671 .25897 .30999 .25175 Metetra
.656 .751 .919 r
.30999 .25175 .31671 .25897 .32726 .25506 .32057 .24781 Metetra
.656 .751 .919 r
.32057 .24781 .32726 .25506 .33786 .25114 .33119 .24386 Metetra
.656 .751 .919 r
.33119 .24386 .33786 .25114 .34849 .24721 .34185 .2399 Metetra
.656 .751 .919 r
.34185 .2399 .34849 .24721 .35917 .24325 .35256 .23591 Metetra
.656 .751 .919 r
.35256 .23591 .35917 .24325 .36989 .23928 .36331 .23192 Metetra
.656 .751 .919 r
.36331 .23192 .36989 .23928 .38066 .2353 .3741 .2279 Metetra
.656 .751 .919 r
.3741 .2279 .38066 .2353 .39147 .2313 .38493 .22387 Metetra
.656 .751 .919 r
.38493 .22387 .39147 .2313 .40232 .22728 .39581 .21982 Metetra
.656 .751 .919 r
.39581 .21982 .40232 .22728 .41321 .22325 .40674 .21576 Metetra
.656 .751 .919 r
.40674 .21576 .41321 .22325 .42415 .2192 .4177 .21168 Metetra
.656 .751 .919 r
.4177 .21168 .42415 .2192 .43514 .21513 .42872 .20758 Metetra
.656 .751 .919 r
.42872 .20758 .43514 .21513 .44617 .21105 .43977 .20347 Metetra
.656 .751 .919 r
.43977 .20347 .44617 .21105 .45724 .20695 .45088 .19934 Metetra
.656 .751 .919 r
.45088 .19934 .45724 .20695 .46836 .20284 .46203 .19519 Metetra
.656 .751 .919 r
.46203 .19519 .46836 .20284 .47953 .1987 .47322 .19103 Metetra
.656 .751 .919 r
.47322 .19103 .47953 .1987 .49074 .19455 .48446 .18685 Metetra
.656 .751 .919 r
.48446 .18685 .49074 .19455 .502 .19039 .49575 .18265 Metetra
.656 .751 .919 r
.49575 .18265 .502 .19039 .5133 .1862 .50708 .17843 Metetra
.656 .751 .919 r
.50708 .17843 .5133 .1862 .52465 .182 .51846 .1742 Metetra
.656 .751 .919 r
.51846 .1742 .52465 .182 .53605 .17778 .52989 .16995 Metetra
.656 .751 .919 r
.52989 .16995 .53605 .17778 .54749 .17354 .54137 .16568 Metetra
.656 .751 .919 r
.54137 .16568 .54749 .17354 .55899 .16929 .55289 .16139 Metetra
.656 .751 .919 r
.55289 .16139 .55899 .16929 .57053 .16502 .56447 .15709 Metetra
.656 .751 .919 r
.56447 .15709 .57053 .16502 .58211 .16073 .57609 .15276 Metetra
.656 .751 .919 r
.57609 .15276 .58211 .16073 .59375 .15642 .58776 .14842 Metetra
.656 .751 .919 r
.58776 .14842 .59375 .15642 .60544 .1521 .59948 .14406 Metetra
.656 .751 .919 r
.59948 .14406 .60544 .1521 .61717 .14775 .61124 .13968 Metetra
.656 .751 .919 r
.61124 .13968 .61717 .14775 .62896 .14339 .62306 .13529 Metetra
.656 .751 .919 r
.62306 .13529 .62896 .14339 .64079 .13901 .63493 .13087 Metetra
.656 .751 .919 r
.63493 .13087 .64079 .13901 .65268 .13461 .64685 .12644 Metetra
.656 .751 .919 r
.64685 .12644 .65268 .13461 .66461 .13019 .65882 .12199 Metetra
.656 .751 .919 r
.65882 .12199 .66461 .13019 .6766 .12576 .67084 .11751 Metetra
.656 .751 .919 r
.67084 .11751 .6766 .12576 .68864 .1213 .68291 .11302 Metetra
.656 .751 .919 r
.68291 .11302 .68864 .1213 .70072 .11682 .69504 .10851 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 233.562},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GQ000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo2goo00IcW248000002U:Li`4Ool015[F248003W>V7oo
003oOol;Ool01RU:>Lioogoo>LhYBP=oo`06HaPHaW>LLi`@Q5:DUgoo003oOol;Ool00`Q2Oomoo`02
Ool01P00Oomoogoo8@QBU09oo`03DY@HaWoo09Ioo`00ogoo2goo00<007>LOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo09Eoo`00ogoo2goo00H002U:LiaoocW>:DX3Ool00`00Oomoo`02Ool00`00
Oomoo`2EOol00?moo`]oo`0648@icP00000YBW>L0goo00<007ooOol00Woo00<007ooOol0UGoo003o
Ool;Ool00d8@<Haoo`06Ool01R48DYAoogooDY@Q29Moo`00ogoo37oo00<HaS6<JeX01Goo00IS61S6
LiacW1S6HaPDOol20021Ool00?moo`eoo`04>Lh8@P0048@4Ool015[F2488@V<H4Woo0`0000=oo`00
Ool0P7oo003oOolYOol20004Ool20020Ool00?moobIoo`<000Ioo`03001oo`0007moo`00ogoo8goo
0`002Goo00<007oo0000Ogoo003oOolQOol2000<Ool01000Oomoo`00OWoo003oOolNOol3000>Ool0
1@00Oomoogoo0000OGoo003oOolLOol2000AOol01@00Oomoogoo0000OGoo003oOolIOol300000goo
001oo`0@Ool00`00Oomoo`02Ool00`00Oomoo`1jOol00?mooaMoo`8000Eoo`03001oogoo00ioo`03
001oogoo00=oo`03001oogoo07Uoo`00ogoo57oo0`0067oo00<007ooOol00goo00<007ooOol0NGoo
003oOolBOol2000LOol00`00Oomoo`03Ool00`00Oomoo`1hOol00?moo`moo`<001ioo`03001oogoo
00=oo`03001oogoo07Qoo`00ogoo37oo0`008Goo00<007ooOol017oo00<007ooOol0Mgoo003oOol:
Ool2000TOol00`00Oomoo`03Ool00`00Ool0001hOol00?moo`Moo`<002Ioo`03001oogoo00Eoo`03
001oogoo07Ioo`00ogoo1Goo0P00:Goo00<007ooOol01Woo00<007ooOol0MGoo003oOol2Ool30002
Ool00`00Oomoo`0VOol00`00Oomoo`07Ool00`00Oomoo`1dOol00?moo`8002ioo`03001oogoo00Mo
o`03001oogoo07Aoo`00o7oo0`00<7oo00<007ooOol027oo00<007ooOol0Lgoo003iOol3000cOol0
0`00Oomoo`09Ool00`00Oomoo`1bOol00?Moo`8003Ioo`03001oogoo00Uoo`03001oogoo079oo`00
m7oo0`00>7oo00<007ooOol02Woo00<007ooOol0LGoo003bOol2000kOol00`00Oomoo`0;Ool00`00
Oomoo`1`Ool00>moo`<003eoo`03001oogoo00]oo`03001oogoo071oo`00kGoo0P00@7oo00<007oo
Ool037oo00<007ooOol0Kgoo003ZOol30002Ool00`00Oomoo`0mOol00`00Oomoo`0=Ool00`00Oomo
o`1^Ool00;Aoo`800003249oogoo009oo`04F]H8@P00>LhXOol30015Ool00`00Oomoo`0=Ool00`00
Oomoo`1^Ool00;Eoo`03001oogoo009oo`06HaPHaW>LLi`@Q5:D9Goo0P00B7oo00<007ooOol03Woo
00<007ooOol0KGoo002aOol60003Ool01R48DYAoogooDY@HaR9oo`<004Yoo`03001oogoo00ioo`80
06ioo`00/Goo00DicU:DOomoo`0000Aoo`03001oogoo009oo`03001oogoo01ioo`8004ioo`03001o
ogoo00aoo`03001oo`0006ioo`00/Goo00EcW1S6Liaoo`0000Aoo`03001oogoo009oo`03001oogoo
01]oo`<0051oo`03001oogoo00moo`03001oogoo06]oo`00/Woo00ABU36<Ool000Aoo`03001oogoo
009oo`03001oogoo01Uoo`8005=oo`03001oogoo00moo`03001oogoo06]oo`00/goo00<Q26<H0000
17oo00HQ25:DOomooe:D8@PHOol3001EOol00`00Oomoo`0@Ool00`00Oomoo`1ZOol00;=oo`03JeXQ
200000Aoo`06HaPHaW>LLi`HaV<H5Woo0P000Woo00<007ooOol0Dgoo00<007ooOol04Goo00<007oo
Ool0JGoo002dOol00cW>249oo`04Ool015[F2488@V<H57oo0`00FWoo00<007ooOol04Goo00<007oo
Ool0JGoo003@Ool3001MOol00`00Oomoo`0BOol00`00Oomoo`1XOol00<ioo`80061oo`03001oogoo
01=oo`03001oogoo06Moo`00bgoo0`00HWoo00<007ooOol04goo00<007ooOol0Igoo0039Ool2001U
Ool00`00Oomoo`0DOol00`00Oomoo`1VOol00<Ioo`<006Moo`03001oogoo01Eoo`03001oogoo06Eo
o`00`goo0`00JWoo00<007ooOol05Goo00<007ooOol0IGoo0031Ool3001/Ool00`00Oomoo`0FOol0
0`00Oomoo`1TOol00;ioo`<000=oo`03001oogoo06Qoo`8001Uoo`03001oogoo06=oo`00_7oo0P00
1goo00<007ooOol0I7oo0`0000=C7@00Ool067oo00<007ooOol0Hgoo002iOol3001^Ool20004Dad2
000GOol3001TOol00;Moo`8006moo`80009C7@04001C7E<MDad3000IOol00`00Oomoo`1QOol00;Ao
o`<006ioo`<000EC7@06001C7@00001C7@006Goo00<007ooOol0HGoo002bOol2001]Ool40002Dad0
0`00DaeC7@03Dad200001E<M001C7E<M00006Goo00<007ooOol0H7oo002_Ool3001/Ool300000e<M
001C7@04Dad00`00Dad0000200001E<M001C7E<M00000U<M00<007ooOol05Woo00<007ooOol0H7oo
002/Ool4001/Ool20005Dad00`00DaeC7@02Dad20005Dad01000Dad005<M0`0067oo00<007ooOol0
Ggoo002ZOol20004Ool00`00Oomoo`1VOol300000e<M001C7@04Dad00`00Dad0000200000e<M001C
7@04Dad40002Dad00`00Oomoo`0GOol00`00Oomoo`1NOol00:Moo`<006eoo`8000EC7@04001C7E<M
Dad30005Dad00`00Dad0000200000e<M00000004Dad00`00Oomoo`0FOol00`00Oomoo`09Ool60004
Ool015[F248003W>Agoo002UOol2001^Ool20002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@03
Dad20005Dad00`00DaeC7@02Dad2000HOol00`00Oomoo`08Ool00dYB001S6002Ool01PQ2Oomoogoo
HaPHaP9cW00348ABU7oo04Eoo`00XWoo0`00KGoo0`001E<M00H005<M000005<M0005Dad00`00Dad0
000200000e<M001C7@04Dad00`00Dad0000200000e<M001oo`0HOol00`00Oomoo`08Ool00dYB001S
6005Ool01R48DYAoogooDY@HaTIoo`00X7oo0P00K7oo10000U<M00<005<MDad00e<M0P0015<M00<0
05<MDad00U<M0P001E<M00@005<MDaeC7@<000EC7@03001oogoo01Ioo`03001oogoo00Uoo`03DY@8
@V<H00Aoo`03001oogoo009oo`03001oogoo04Aoo`00WGoo0`00Jgoo0`0000=C7@00Dad015<M00<0
05<M00000P0000=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C7@@00003Dad0000000EC
7@8001Qoo`03001oogoo00Uoo`03HaP8@V<H00=oo`03001oogoo009oo`03001oogoo04Aoo`00Vgoo
0P00K7oo0P001E<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@<000EC7@06001C7@00001C7@00
0e<M00@005<M001C7@<00003Dad007oo01Qoo`03001oogoo00Uoo`03DY@HaWoo009oo`03001oogoo
009oo`03001oogoo04Aoo`00V7oo0`00K7oo0P000U<M00<005<MDad00U<M00<005<M00000P0000=C
7@00Dad015<M10000U<M00<005<MDad00e<M0P0015<M00D005<MDad005<M008000EC7@03001oogoo
01Ioo`03001oogoo00Yoo`06001oogooOolQ25:D0Woo00=BU248Ool0AGoo001NOol60004Ool015[F
248003W>:Goo0`000goo00<007ooOol0Igoo0P001E<M00<005<MDad00`001E<M00<005<M00000P00
00=C7@00Dad015<M00<005<M00000P0000=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C
7@8001Qoo`8000Eoo`06001247>LOolicQS60goo00IS61S6LiacW1S6HaQ6Ool005ioo`03BU8006<H
009oo`06249oogooOomS61S60W>L00<@Q5:DOol09Goo0P00KGoo0`0000=C7@00Dad015<M0`000e<M
00<005<MDad00U<M0P001E<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@@000AC7@04001C7@00
0002Dad00`00Oomoo`0COol200000goo001oo`04Ool01U:D6<H00000:DYcW0Aoo`04F]H8@PQ2HaQ7
Ool005moo`03BU8006<H00Eoo`068@QBU7ooOomBU1S68goo0`00K7oo0`001E<M00<005<M00000P00
00=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00AC
7@@0009C7@8000AC7@8000EC7@03001oogoo01Eoo`03001oogoo05Qoo`00H7oo00=BU0Q2HaP017oo
00<007ooOol00Woo00<007ooOol07goo0P00Jgoo10000U<M00<005<MDad00e<M0P001E<M00<005<M
Dad00U<M0P001E<M00<005<MDad00`001E<M00<005<M00000P0000=C7@00Dad015<M00<005<M0000
0P0000=C7@00Dad015<M0P005goo00<007ooOol0Egoo001QOol00f<H249S6003Ool00`00Oomoo`02
Ool00`00Oomoo`0LOol3001[Ool20002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@04
Dad00`00Dad0000200000e<M001C7@04Dad30003Dad00`00DaeC7@02Dad20005Dad01000DaeC7E<M
0`001E<M00<005<M00000P0000=C7@00Ool05goo00<007ooOol0EWoo001ROol00e:D6<Ioo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0JOol2001/Ool20005Dad00`00DaeC7@030005Dad01000DaeC7E<M
0`001E<M00<005<M00000P0000=C7@00Dad015<M00H005<M000005<M0005Dad400000e<M00000005
Dad20005Dad00`00Oomoo`0EOol00`00Oomoo`1FOol006=oo`06001oogooOolQ25:D0Woo00=BU248
Ool067oo0`00Jgoo0`0000=C7@00Dad015<M0`000e<M00<005<MDad00U<M10000U<M00<005<MDad0
0e<M0P001E<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad005<M009C7@04001C7@00Dad3
00000e<M001C7@04Dad00`00Oomoo`0FOol00`00Oomoo`1EOol005ioo`06001247>LOolicQS60goo
00IS61S6LiacW1S6HaPFOol4001ZOol30005Dad00`00Dad0000200000e<M001C7@04Dad01000Dad0
00000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad015<M10000U<M00<005<MDad00U<M
0P001E<M00D005<MDad005<M008000EC7@04001C7E<MDad3000HOol00`00Oomoo`1DOol005ioo`06
DY@HaP00000YBW>L17oo00AJePQ2249S61Eoo`8000Aoo`03001oogoo06Aoo`<000=C7@03001C7E<M
009C7@8000EC7@03001C7E<M009C7@8000EC7@03001C7E<M00<000EC7@03001C7@0000800003Dad0
05<M00AC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad40002
Dad00`00Oomoo`0FOol00`00Oomoo`1DOol007ioo`<006Yoo`<00003Dad005<M00AC7@04001C7@00
0002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad30003Dad00`00DaeC7@02Dad2
0005Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@0300000e<M001C7@02Dad00`00Dad000020000
0e<M001C7@04Dad00`00Oomoo`0FOol00`00Oomoo`1COol007aoo`8006]oo`8000EC7@03001C7E<M
009C7@8000EC7@03001C7E<M00<000EC7@03001C7@0000800003Dad005<M00AC7@04001C7@000002
Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad30003Dad00`00Dad00002Dad20005
Dad01000DaeC7E<M0`005goo00<007ooOol0Dgoo001iOol3001[Ool200000e<M001C7@04Dad00`00
Dad0000200000e<M001C7@04Dad30002Dad00`00DaeC7@03Dad20005Dad01000DaeC7E<M0`001E<M
00<005<MDad00`001E<M00<005<M00000P0000=C7@00Dad015<M100000=C7@00Dad015<M10000U<M
00<007ooOol05Woo00<007ooOol0DWoo001gOol2001/Ool20004Dad01000DaeC7E<M0`001E<M00<0
05<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad015<M10000U<M00<005<MDad0
0e<M0`000U<M00<005<MDad00e<M0P001E<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad0
05<M00AC7@03001oogoo01Ioo`03001oogoo055oo`00M7oo0`00Jgoo0`0000=C7@00Dad00e<M1000
0U<M00<005<MDad00e<M0P001E<M00<005<MDad00`001E<M00<005<M00000P0000=C7@00Dad015<M
00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad015<M10000U<M00<005<M
Dad00U<M0P001E<M00<005<MDad00U<M0P005goo00<007ooOol0DGoo001bOol2001[Ool30005Dad0
1000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad015<M0`000e<M00<005<M
Dad00U<M0P001E<M00<005<MDad00U<M0P001E<M00<005<MDad00`001E<M00<005<M00000P0000=C
7@00Dad00e<M0P0000=C7@0000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Ool05goo
00<007ooOol0D7oo001_Ool300000goo001oo`1WOol30002Dad00`00DaeC7@03Dad20005Dad00`00
DaeC7@030005Dad00`00Dad0000200000e<M001C7@04Dad01000Dad000000U<M00<005<MDad00U<M
00<005<M00000P0000=C7@00Dad015<M0`000e<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@<0
00EC7@03001C7E<M00<000EC7@03001oogoo01Eoo`80055oo`00K7oo0`001Goo00<007ooOol0HWoo
0`0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad015<M0`000e<M00<005<MDad00U<M0P00
1E<M00@005<MDaeC7@<000EC7@03001C7E<M00<000EC7@03001C7@0000800003Dad005<M00AC7@06
001C7@00001C7@001E<M1@0000=C7@00Dad015<M0`000U<M00<005<MDad00e<M0P005goo00<007oo
Ool0Cgoo001ZOol2001ZOol30005Dad00`00DaeC7@030005Dad00`00Dad0000200000e<M001C7@04
Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<005<MDad00e<M0`000e<M00<005<MDad0
0U<M0P001E<M00@005<MDaeC7@<000AC7@03001C7@0000800005Dad005<MDad00002Dad00`00Dad0
000200000e<M001C7@03Dad00`00Dad0000200000e<M001oo`0GOol00`00Oomoo`1>Ool006Moo`<0
06Uoo`<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@8000EC7@04001C7E<MDad30005
Dad01P00Dad00000Dad000EC7@03001C7@0000800003Dad005<M00AC7@06001C7@00001C7@001E<M
10000U<M00<005<MDad00U<M0P001E<M00<005<M00000U<M0P001E<M00<005<MDad00`001E<M00<0
07ooOol05Woo00<007ooOol0CGoo001UOol2001YOol300000e<M001C7@04Dad01P00Dad00000Dad0
00EC7@04001C7@000002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@03Dad20004Dad00`00DaeC
7@02Dad20005Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad015<M00@005<M0000
009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00AC7@<0009C7@03001C7E<M00=C7@80
01Moo`03001oogoo04eoo`00HWoo0`00JGoo0P001E<M00<005<MDad00U<M0P0015<M00@005<MDaeC
7@<000EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad01000
Dad000000U<M00<005<MDad00U<M10000U<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@<000EC
7@03001C7E<M00@000AC7@03001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad007oo
01Moo`03001oogoo04aoo`00H7oo0P00JWoo0P000U<M00<005<MDad00U<M00<005<M00000P0000=C
7@00Dad00e<M10000U<M00<005<MDad00e<M0P001E<M00<005<MDad00`001E<M00@005<MDaeC7@<0
00EC7@06001C7@00001C7@001E<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C7E<M
00=C7@<0009C7@8000AC7@8000EC7@03001C7E<M00<000EC7@03001oogoo01Ioo`03001oogoo04]o
o`00GGoo0`00JGoo0`001E<M00<005<MDad00`001E<M00@005<M0000009C7@03001C7E<M009C7@03
001C7@0000800003Dad005<M00AC7@<000=C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@80
00AC7@04001C7E<MDad30005Dad01P00Dad00000Dad000EC7@03001C7@0000800003Dad005<M00=C
7@03001C7@0000800003Dad005<M00AC7@<000=C7@03001C7E<M009C7@8001Moo`03001oogoo04]o
o`00FWoo0`000goo00<007ooOol0HWoo10000U<M00<005<MDad00e<M0`000e<M00<005<MDad00U<M
0P001E<M00<005<MDad00`001E<M00<005<M00000P0000=C7@00Dad015<M00H005<M000005<M0005
Dad00`00Dad0000200000e<M001C7@03Dad40002Dad00`00DaeC7@03Dad20004Dad01000DaeC7E<M
0`001E<M00<005<MDad00`001E<M00<005<M00000P0000=C7@00Dad015<M00H005<M000005<M000H
Ool00`00Oomoo`1:Ool005Qoo`8006Uoo`80009C7@03001C7E<M009C7@03001C7@0000800003Dad0
05<M00AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad20005Dad01000
DaeC7E<M0`0015<M00@005<MDaeC7@<000EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0
000200000e<M001C7@03Dad40002Dad00`00DaeC7@03Dad3000015<M001C7@0015<M0P001E<M00@0
05<MDaeC7@<000AC7@03001oogoo01Ioo`03001oogoo04Uoo`00EGoo0`00JGoo0P001E<M00<005<M
Dad00`001E<M00@005<MDaeC7@<000EC7@06001C7@00001C7@001E<M00@005<M0000009C7@03001C
7E<M009C7@@0009C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@8000EC7@03001C7E<M00<0
00EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200001E<M001C7E<M00000U<M00H0
05<M000005<M0005Dad40002Dad00`00DaeC7@02Dad2000GOol00`00Oomoo`19Ool005=oo`8006Yo
o`80009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@8000AC
7@04001C7E<MDad30005Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C
7E<M009C7@03001C7@0000800003Dad005<M00AC7@<0009C7@03001C7E<M00=C7@8000EC7@03001C
7E<M00<000EC7@04001C7@00Dad30004Dad00`00Dad0000200000e<M001C7@04Dad01P00Dad00000
Dad001Qoo`03001oogoo04Qoo`00D7oo0`00JGoo0`001E<M00H005<M000005<M0005Dad01000Dad0
00000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00e<M
0P001E<M00<005<MDad00`001E<M00<005<MDad00`001E<M00<005<M00000P0000=C7@00Dad00e<M
00<005<M00000P0000=C7@00Dad015<M0`000U<M00<005<MDad00e<M10000U<M00<005<MDad00U<M
0P001E<M00@005<MDaeC7@<000AC7@03001oogoo01Ioo`03001oogoo04Moo`00CWoo0P00J7oo1000
0U<M00<005<MDad00e<M0P0015<M00@005<MDaeC7@<000EC7@03001C7E<M00<000EC7@04001C7@00
0002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad30002Dad00`00DaeC7@03Dad3
0003Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@030005Dad00`00Dad0000200000e<M001C7@03
Dad00`00Dad0000200000e<M00000004Dad01P00Dad00000Dad000EC7@@0009C7@03001C7E<M009C
7@8001Moo`03001oogoo04Moo`00Bgoo0`00J7oo0P000U<M00<005<MDad00U<M00<005<M00000P00
00=C7@00Dad00e<M10000U<M00<005<MDad00e<M0`000e<M00<005<MDad00U<M0P001E<M00<005<M
Dad00`001E<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad015<M00H0
05<M000005<M0005Dad30003Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@030005Dad20002Dad3
0004Dad00`00Dad0000200000e<M001C7@04Dad01P00Dad00000Dad001Moo`8004Qoo`00B7oo0`00
0Woo00<007ooOol0Hgoo0`001E<M00<005<MDad00`001E<M00@005<M0000009C7@03001C7E<M009C
7@03001C7@0000800003Dad005<M00AC7@06001C7@00001C7@001E<M0`000e<M00<005<MDad00U<M
0P001E<M00<005<MDad00`001E<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad005<M00AC
7@06001C7@00001C7@001E<M0`000e<M00<005<MDad00U<M10000e<M00<005<MDad00`001E<M00@0
05<MDaeC7@<000AC7@03001oogoo01Eoo`03001oogoo04Ioo`00AWoo0P00J7oo0`000e<M00<005<M
Dad00U<M0`000e<M00<005<MDad00U<M0P001E<M00<005<MDad00`001E<M00@005<MDaeC7@<000AC
7@03001C7@0000800003Dad005<M00AC7@06001C7@00001C7@001E<M0`000e<M00<005<MDad00U<M
10000e<M00<005<MDad00`001E<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dad005<M00AC
7@06001C7@00001C7@001E<M0`000e<M00<005<MDad00U<M10000U<M00<005<MDad00U<M0P005goo
00<007ooOol0AGoo0013Ool3001WOol300000e<M001C7@04Dad01P00Dad00000Dad000EC7@04001C
7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad0
1000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad015<M00H005<M000005<M0005Dad30003
Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@02Dad20005Dad01000DaeC7E<M0`000e<M0P0000IC
7@00000005<M0005Dad01P00Dad00000Dad000EC7@06001C7@00001C7@0067oo00<007ooOol0A7oo
0011Ool2001XOol20005Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000EC7@06001C7@00001C
7@001E<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@@0009C7@03001C
7E<M009C7@8000EC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M001C7@04Dad01P00Dad0
0000Dad000EC7@04001C7@000002Dad00`00DaeC7@02Dad40002Dad01000DaeC7E<M0`001E<M00@0
05<MDaeC7@<000AC7@04001C7E<MDad30004Dad00`00Oomoo`0EOol00`00Oomoo`14Ool003ioo`<0
06Qoo`80009C7@03001C7E<M009C7@@0009C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@80
00AC7@04001C7E<MDad30005Dad01P00Dad00000Dad000EC7@04001C7@000002Dad00`00DaeC7@02
Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<005<MDad00U<M0P001E<M00@005<MDaeC
7@<000AC7@04001C7E<MDad30005Dad01P00Dad00000Dad000EC7@06001C7@00001C7@001E<M1000
0U<M00<005<MDad00U<M10000U<M00<005<MDad00U<M0P005goo00<007ooOol0@goo000lOol2001X
Ool30005Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@03
001C7@0000800003Dad005<M00=C7@@0009C7@03001C7E<M00=C7@8000AC7@04001C7E<MDad30005
Dad00`00DaeC7@030005Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C
7E<M009C7@@0009C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@8000AC7@04001C7E<MDad3
00001U<M001C7E<M001C7@<00003Dad005<M00AC7@06001C7@00001C7@001E<M00H005<M000005<M
000HOol00`00Oomoo`12Ool003Uoo`<006Moo`<000=C7@03001C7E<M009C7@8000EC7@03001C7E<M
00<000EC7@03001C7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad000020000
0e<M001C7@03Dad40002Dad00`00DaeC7@03Dad30003Dad01000DaeC7E<M0`001E<M00<005<MDad0
0`001E<M00H005<M000005<M0005Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000P00
00=C7@00Dad00e<M10000U<M00<005<M00000U<M0P001E<M00@005<MDaeC7@<000AC7@04001C7E<M
Dad30004Dad00`00Oomoo`0EOol00`00Oomoo`12Ool003Moo`<006Moo`800003Dad005<M00AC7@04
001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005
Dad00`00DaeC7@030005Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00
Dad00e<M10000U<M00<005<MDad00e<M0`000U<M00<005<MDad00e<M0P0015<M00@005<MDaeC7@<0
00EC7@03001C7E<M00<000EC7@06001C7@00001C7@001E<M100000=C7@00Dad015<M10000U<M00<0
05<MDad00U<M10000e<M00<005<MDad00`005goo00<007ooOol0@Goo000dOol30003Ool00`00Oomo
o`1QOol30004Dad01000DaeC7E<M0`001E<M00H005<M000005<M0005Dad01P00Dad00000Dad000EC
7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@8000EC7@03001C7E<M00<000EC7@04
001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@03Dad00`00Dad000020000
0e<M001C7@03Dad40002Dad00`00DaeC7@03Dad30003Dad01000DaeC7E<M0`0015<M00@005<MDaeC
7@<000AC7@03001C7@0000800003Dad005<M00AC7@06001C7@00001C7@001E<M0`000U<M00<007oo
Ool05Woo00<007ooOol0@7oo000aOol3001VOol40002Dad00`00DaeC7@02Dad40002Dad00`00DaeC
7@03Dad20004Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad015<M00H005<M0000
05<M0005Dad01P00Dad00000Dad000EC7@<000=C7@03001C7E<M009C7@8000EC7@03001C7E<M00<0
00EC7@03001C7E<M00<000EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M
001C7@03Dad40002Dad00`00DaeC7@02Dad500000e<M001C7@03Dad20005Dad01000DaeC7E<M0`00
15<M00<005<M00000P0000=C7@00Dad00e<M00<007ooOol05Goo00<007ooOol0@7oo000_Ool2001W
Ool20002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C
7@00Dad00e<M10000U<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@<000AC7@04001C7E<MDad3
0004Dad00`00Dad0000200000e<M001C7@04Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M
00=C7@<000=C7@04001C7E<MDad30005Dad00`00DaeC7@030005Dad01P00Dad00000Dad000EC7@03
001C7@0000<000EC7@04001C7@000002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@02Dad20005
Dad00`00DaeC7@03000GOol00`00Oomoo`0oOol002aoo`<006Moo`8000EC7@03001C7E<M00<000EC
7@03001C7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<M
Dad00U<M10000U<M00<005<MDad00U<M10000e<M00<005<MDad00`001E<M00@005<MDaeC7@<000AC
7@03001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad005<M00=C7@@0009C7@03001C
7E<M00=C7@<0009C7@03001C7E<M00=C7@8000AC7@04001C7E<MDad40003Dad01000DaeC7E<M0`00
1E<M00H005<M000005<M0005Dad01P00Dad00000Dad000EC7@<0009C7@03001oogoo01Ioo`03001o
ogoo03ioo`00:goo0P00Igoo0P000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M
00<005<MDad00`001E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C
7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad0
0`00DaeC7@030005Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad0
0e<M00<005<M00000P0000=C7@00Dad00e<M1@0000=C7@00Dad00e<M10000e<M00@005<MDaeC7@<0
00AC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M001C7@03Dad00`00Oomoo`0EOol2000o
Ool002]oo`03001oo`0006=oo`@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad00000
0U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad00`001E<M00<005<M
Dad00`001E<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad3
0003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@030005Dad00`00
DaeC7@030005Dad00`00Dad000030005Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<0
05<MDad00U<M10000e<M00<005<MDad00`001E<M00<005<MDad00`005Goo00<007oo0000?goo000[
Ool01000Oomoo`00Ggoo0`0015<M00<005<MDad00`001E<M00<005<MDad00`001E<M00H005<M0000
05<M0005Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M009C
7@8000EC7@03001C7E<M00<000EC7@06001C7@00001C7@001E<M00H005<M000005<M0005Dad01P00
Dad00000Dad000EC7@<0009C7@03001C7E<M00=C7@<000=C7@04001C7E<MDad40003Dad01000DaeC
7E<M0`001E<M00H005<M000005<M0005Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M00=C
7@<0009C7@03001oogoo01Ioo`03001oogoo03aoo`00:goo00D007ooOomoo`0005aoo`800003Dad0
05<M00AC7@<0009C7@03001C7E<M00=C7@<000=C7@04001C7E<MDad30004Dad01000DaeC7E<M0`00
15<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad015<M00H005<M0000
05<M0005Dad30002Dad00`00DaeC7@03Dad20004Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<0
00AC7@03001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad005<M00=C7@D00003Dad0
05<M00=C7@@000=C7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C
7@00Dad00e<M00<005<M00000P0000=C7@00Dad00e<M00<007ooOol05Goo00<007ooOol0?7oo000Z
Ool20004Ool00`00Oomoo`1FOol30004Dad00`00Dad0000200000e<M001C7@03Dad00`00Dad00002
00000e<M001C7@03Dad40002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@02Dad20005Dad00`00
DaeC7@030005Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad00e<M00<005<M0000
0P0000=C7@00Dad00e<M10000U<M00<005<MDad00U<M10000e<M00<005<MDad00`001E<M00<005<M
Dad0100015<M00<005<M0000100015<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C
7E<M009C7@@0009C7@03001C7E<M009C7@8000EC7@03001C7E<M00<000EC7@03001C7E<M00<001Mo
o`03001oogoo03]oo`00:Woo00<007ooOol017oo00<007ooOol0DGoo10000e<M00<005<MDad00`00
1E<M00<005<MDad00`001E<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00
DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M10000e<M00<0
05<MDad00`001E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@00
0002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@050003Dad00`00
DaeC7@030005Dad01P00Dad00000Dad000EC7@06001C7@00001C7@001E<M00H005<M000005<M0005
Dad30002Dad00`00DaeC7@03Dad30003Dad00`00Oomoo`0DOol00`00Oomoo`0kOol002Yoo`03001o
ogoo00Eoo`03001oogoo04ioo`80009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000=C
7@03001C7E<M009C7@8000EC7@03001C7E<M00<000EC7@03001C7E<M00@000AC7@04001C7@000002
Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`00
15<M00<005<MDad00`001E<M00<005<MDad00`001E<M00H005<M000005<M0005Dad01P00Dad00000
Dad000EC7@H000EC7@<0009C7@03001C7E<M00=C7@8000AC7@04001C7E<MDad30004Dad01000DaeC
7E<M0`0015<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad00e<M0P00
5Woo00<007ooOol02goo0P0000<8@WooOol00Woo00AJePQ2000icRAoo`00:Woo00<007ooOol01Woo
00<007ooOol0BWoo0`001E<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00
DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M00<0
05<MDad00`001E<M00<005<MDad00`001E<M00H005<M000005<M0005Dad01P00Dad00000Dad000EC
7@<0009C7@03001C7E<M00=C7@<000=C7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00<0
05<M0000100015<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad00e<M
10000U<M00<005<MDad00U<M10000e<M00<005<MDad00`001E<M00<005<MDad00`001E<M00H005<M
000005<M000GOol00`00Oomoo`0;Ool00`00Oomoo`02Ool01V<H6<IcW7>L48ABU2=oo`00:Woo00<0
07ooOol01goo00<007ooOol0AWoo0`000e<M00<005<MDad00U<M0P001E<M00<005<MDad00`001E<M
00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC
7@02Dad30002Dad00`00DaeC7@03Dad30003Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000AC
7@03001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad005<M00=C7@@0009C7@03001C
7E<M009C7@@0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00<000EC7@03001C7E<M00<000EC
7@06001C7@00001C7@001E<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@03Dad30003Dad0
1000DaeC7E<M0`0015<M00<007ooOol057oo00<007ooOol01goo1P000goo00HQ25:DOomooe:D6<HS
Ool002Yoo`8000Uoo`03001oogoo04=oo`80009C7@03001C7E<M009C7@04001C7@000002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@030005
Dad01P00Dad00000Dad000AC7@03001C7@0000800003Dad005<M00=C7@@0009C7@03001C7E<M009C
7@@000=C7@03001C7E<M00<000EC7@03001C7E<M00<000EC7@04001C7@000002Dad00`00DaeC7@02
Dad01P00Dad00000Dad000EC7@03001C7@0000<000EC7@<0009C7@03001C7E<M00=C7@<000=C7@04
001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad00e<M00<005<M
00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00U<M0P005Woo00<007ooOol01Woo00DicU:D
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo025oo`00:Goo00<007ooOol02Woo00<007ooOol0
?goo0`001E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002
Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@03Dad30003Dad01000DaeC7E<M0`0015<M00<005<M
Dad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad3
0003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@030004Dad01000
DaeC7E<M10000e<M00<005<M00000P0000=C7@00Dad00e<M00<005<M00000P0000=C7@00Dad00e<M
10000U<M00<005<MDad00U<M10000e<M00<005<MDad00`001E<M00<005<MDad00`001E<M00H005<M
000005<M0005Dad01P00Dad00000Dad001Moo`03001oogoo00Eoo`05Li`HaW>LOol00004Ool00`00
Oomoo`02Ool00`00Oomoo`0QOol002Uoo`03001oogoo00]oo`03001oogoo03]oo`<000=C7@03001C
7E<M009C7@<000AC7@03001C7E<M00<000EC7@03001C7E<M00<000EC7@06001C7@00001C7@0015<M
00<005<M00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00U<M0`0015<M00<005<MDad00`00
1E<M00<005<MDad0100015<M00H005<M000005<M0005Dad01P00Dad00000Dad000EC7@06001C7@00
001C7@001E<M0`000U<M00<005<MDad00U<M1@000U<M00<005<MDad00`001E<M00<005<MDad01000
15<M00H005<M000005<M0005Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M00=C7@<000=C
7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00<007ooOol057oo00<007ooOol01Woo00AB
U36<Ool000Aoo`03001oogoo009oo`03001oogoo025oo`00:Goo00<007ooOol037oo00<007ooOol0
>7oo0P000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M
009C7@<000=C7@04001C7E<MDad30004Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<M
Dad00U<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C
7E<M00<000AC7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00
Dad00e<M00<005<M0000100015<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad00`0015<M
00@005<MDaeC7@<000AC7@03001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad005<M
00=C7@@0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00<001Ioo`03001oogoo00Ioo`038@QS
600000Aoo`068@QBU7ooOomBU2488goo000YOol00`00Oomoo`0=Ool00`00Oomoo`0dOol30005Dad0
0`00DaeC7@040004Dad01P00Dad00000Dad000EC7@06001C7@00001C7@0015<M10000U<M00<005<M
Dad00U<M0`0015<M00<005<MDad00`001E<M00<005<MDad0100015<M00H005<M000005<M0005Dad0
1P00Dad00000Dad000EC7@<0009C7@03001C7E<M009C7@@0009C7@03001C7E<M009C7@@000=C7@03
001C7E<M00<000EC7@03001C7E<M00@000AC7@06001C7@00001C7@001E<M00H005<M000005<M0005
Dad30002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad01P00
Dad00000Dad000EC7@06001C7@00001C7@001E<M0`000U<M00<007ooOol057oo0P001goo00=[FR48
000017oo00IS61S6LiacW1S6HaPSOol002Uoo`<000ioo`03001oogoo031oo`<000=C7@03001C7E<M
009C7@<000AC7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad01000Dad000000U<M00<005<M
Dad00U<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C
7E<M00<000AC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M001C7@03Dad01000Dad00000
0U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M00=C7@@0
009C7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad00e<M
00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M00=C7@<000=C7@04001C7E<MDad3
0004Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad00e<M00<007ooOol04Woo00<0
07oo000027oo00<icPQ2Ool017oo00AJePQ2249S62Aoo`00:7oo0P004Goo0P00;Woo0P000U<M00<0
05<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@@000=C7@03
001C7E<M00<000EC7@03001C7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad0
0000Dad000EC7@<0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00<000EC7@03001C7E<M00<0
00EC7@03001C7E<M00<000EC7@06001C7@00001C7@0015<M00<005<M0000100015<M10000U<M00<0
05<MDad00U<M10000e<M00<005<MDad00`001E<M00<005<MDad00`001E<M00H005<M000005<M0004
Dad00`00Dad0000200000e<M001C7@03Dad40002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@03
0005Dad00`00DaeC7@03000FOol00`00Oomoo`0dOol002Uoo`03001oogoo015oo`03001oogoo02Qo
o`<000EC7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@03001C7E<M
009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC7@03001C7E<M00<000AC7@03
001C7@0000800003Dad005<M00=C7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC
7@02Dad30003Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad0100015<M
00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00e<M
0`000e<M00@005<MDaeC7@<000AC7@03001C7E<M00<000EC7@06001C7@00001C7@001E<M00H005<M
000005<M0005Dad30002Dad00`00DaeC7@02Dad40002Dad00`00Oomoo`0EOol00`00Oomoo`0cOol0
00Yoo`06BU88@P00000Q27>L17oo00AJePQ2000icPEoo`04F]H8@P00>Lh7Ool00`00Oomoo`0COol0
0`00Oomoo`0TOol30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030004Dad00`00DaeC7@04
0004Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<0009C
7@03001C7E<M00=C7@<000=C7@03001C7E<M00<000EC7@03001C7E<M00@000AC7@06001C7@00001C
7@001E<M00H005<M000005<M0005Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@D0
009C7@03001C7E<M00<000EC7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C7@03
001C7@0000800003Dad005<M00=C7@@0009C7@03001C7E<M009C7@<000=C7@04001C7E<MDad30004
Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00Dad00e<M00H005<M000005<M0005Dad0
0`00Oomoo`0DOol00`00Oomoo`0cOol000Yoo`06249247ooOolicR480goo00IS61S6LiacW124DY@3
Ool01V<H6<IcW7>L48ABU0Ioo`03001oogoo01Aoo`03001oogoo025oo`80009C7@03001C7E<M009C
7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@03
0005Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@03001C7@0000800003Dad005<M00=C
7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad01000
DaeC7E<M0`0015<M00@005<M0000009C7@03001C7E<M009C7@03001C7@0000<000EC7@<0009C7@03
001C7E<M00=C7@<000=C7@03001C7E<M00<000EC7@03001C7E<M00<000EC7@06001C7@00001C7@00
1E<M00H005<M000005<M0004Dad40002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad0
0`00DaeC7@030004Dad01000DaeC7E<M0`005Woo00<007ooOol0<Woo000?Ool01P00Oomoogoo8@QB
U09oo`03DY@HaWoo009oo`068@QBU7ooOomBU1S61Woo00<007ooOol05Goo00<007ooOol07Goo1000
15<M00<005<MDad0100015<M00H005<M000005<M0004Dad01000Dad000000U<M00<005<MDad00U<M
0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad00`0015<M00<005<MDad0100015<M00@005<M
0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02
Dad40003Dad00`00DaeC7@050003Dad00`00DaeC7@030005Dad00`00DaeC7@040003Dad00`00Dad0
000200000e<M001C7@03Dad00`00Dad0000200000e<M001C7@03Dad30003Dad00`00DaeC7@02Dad3
0003Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000AC7@06001C7@00001C7@001E<M00H005<M
000005<M0005Dad30002Dad00`00DaeC7@03Dad30003Dad00`00DaeC7@050003Dad00`00Oomoo`0D
Ool00`00Oomoo`0aOol00003Ool0000000D000Ioo`03Li`007oo009oo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`04Ool2000GOol00`00Oomoo`0IOol30004Dad00`00DaeC7@040004
Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<MDad00U<M00H0
05<M000005<M0005Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005Dad00`00DaeC
7@030005Dad01P00Dad00000Dad000AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00
DaeC7@02Dad30003Dad01000DaeC7E<M1@000U<M00<005<MDad00`001E<M00<005<MDad0100015<M
00H005<M000005<M0005Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@@000=C7@03
001C7E<M00<000AC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M001C7@03Dad00`00Dad0
000200000e<M001C7@03Dad30002Dad00`00DaeC7@03Dad2000EOol00`00Oomoo`0aOol000Yoo`06
249:DWooOolicS6<0goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oogoo00ioo`03001oogoo01Ioo`80009C7@03001C7E<M009C7@<000=C7@03001C
7E<M009C7@<0009C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC7@03001C7E<M00<000AC
7@03001C7@0000800003Dad005<M00=C7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00
DaeC7@02Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad0100015<M00H005<M000005<M0005
Dad01P00Dad00000Dad000AC7@L000AC7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<0
00AC7@04001C7E<MDad30004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0005
Dad30002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad40000
0e<M001C7@03Dad00`00Dad0000200000e<M001oo`0EOol00`00Oomoo`0`Ool000Yoo`05000@Q000
000aS004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol03goo00<007ooOol04Woo100015<M00@005<M0000009C7@03001C7E<M009C7@06001C
7@00001C7@0015<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000=C
7@03001C7E<M00<000EC7@03001C7E<M00@000AC7@06001C7@00001C7@001E<M00H005<M000005<M
0004Dad40002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030004Dad01000DaeC7E<M0`0015<M
00D005<M000005<M008000AC7@06001C7@00001C7@001E<M00H005<M000005<M0005Dad30002Dad0
0`00DaeC7@02Dad40003Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad00`00Dad000020000
0e<M001C7@03Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M
00<000EC7@03001C7E<M00<000EC7@03001oogoo01Aoo`03001oogoo02moo`002Woo00<007ooOol0
1Woo00HQ25:DOomooe:D8@P3Ool01R48DYAoogooDY@Q20Eoo`03001oogoo00Moo`03001oogoo011o
o`03001oogoo00ioo`<000AC7@03001C7E<M00<000EC7@03001C7E<M00<000AC7@03001C7E<M00@0
00AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M
009C7@<000AC7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad01000Dad000000U<M00<005<M
Dad00U<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@@000=C7@03001C
7E<M00H0009C7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M001C
7@03Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00<000EC
7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad005<M
00=C7@<0009C7@03001C7E<M00=C7@<000=C7@04001C7E<MDad3000EOol00`00Oomoo`0_Ool000Yo
o`03001oogoo00Ioo`06HaPHaW>LLi`HaV<H0goo00IS61S6LiacW1S6HaP5Ool01000Oomoo`001Goo
0P004goo00<007ooOol02goo0P000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`000e<M
00<005<MDad0100015<M00<005<MDad0100015<M00<005<MDad00`0015<M00@005<M0000009C7@03
001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad40003Dad0
0`00DaeC7@030005Dad00`00DaeC7@030005Dad01P00Dad00000Dad000AC7@04001C7@000002Dad0
0`00DaeC7@02Dad70004Dad30003Dad00`00DaeC7@050003Dad00`00DaeC7@030005Dad00`00DaeC
7@030004Dad00`00Dad0000200000e<M001C7@03Dad00`00Dad0000200000e<M001C7@03Dad30002
Dad00`00DaeC7@03Dad30003Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad01P00Dad00000
Dad000AC7@03001C7@0000800003Dad005<M00=C7@@0009C7@03001oogoo01Aoo`03001oogoo02io
o`002Woo1@001Goo00AJePQ2249S60Eoo`04F]H8@PQ2HaP6Ool200000goo001oo`04Ool2000DOol0
0`00Oomoo`07Ool40004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004Dad3
0003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC
7@040004Dad01P00Dad00000Dad000AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00
DaeC7@02Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad0100015<M00<005<M0000100015<M
00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M10000e<M00<0
05<MDad0100015<M00<005<MDad00`001E<M00H005<M000005<M0004Dad00`00Dad0000200000e<M
001C7@03Dad30002Dad00`00DaeC7@03Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad00`00
1E<M00H005<M000005<M0005Dad00`00Oomoo`0COol2000_Ool002Moo`04001oo`000005Ool2000E
Ool00`00Oomoo`03Ool30004Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad01000Dad00000
0U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<0
00AC7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@04001C7@000002
Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@<000AC7@03001C
7E<M00D0009C7@04001C7E<MDad30004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M0000
05<M0004Dad40002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad01000DaeC7E<M0`00
15<M00<005<MDad00`001E<M00H005<M000005<M0004Dad00`00Dad0000200000e<M001C7@03Dad4
0002Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad00`005Goo0P00;goo
000WOol01000Ool000001Goo0P005Woo00<007ooOol00P000U<M00<005<MDad00U<M0`000e<M00<0
05<MDad00U<M0`000e<M00<005<MDad00`001E<M00<005<MDad0100015<M00H005<M000005<M0004
Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad0
100015<M00<005<MDad00`001E<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C
7@06001C7@00001C7@001E<M1P0015<M10000e<M00<005<MDad00`001E<M00<005<MDad00`0015<M
00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M
10000e<M00<005<MDad010000e<M00@005<MDaeC7@<000AC7@03001C7E<M00<000EC7@06001C7@00
001C7@001E<M00H005<M000005<M0004Dad40002Dad00`00DaeC7@02Dad30003Dad00`00Oomoo`0D
Ool00`00Oomoo`0/Ool002Moo`04001oo`000005Ool2000FOol40004Dad01000Dad000000U<M00<0
05<MDad00U<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@03
0004Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004
Dad30003Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M10000e<M00<005<MDad0100015<M00<0
05<MDad00`0015<M00<005<M0000100015<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03
001C7E<M00=C7@<000=C7@03001C7E<M00<000EC7@03001C7E<M00<000AC7@03001C7@0000800003
Dad005<M00=C7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M10000e<M00<005<MDad0
10000e<M00@005<MDaeC7@<000AC7@04001C7E<MDad30004Dad01P00Dad00000Dad000EC7@06001C
7@00001C7@0015<M0P005Goo00<007ooOol0;7oo000VOol01@00Ool003B;000017oo00<000070000
4goo0`0015<M00<005<MDad0100015<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M
009C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC
7@030005Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M000005<M
0004Dad40002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@050003Dad0
0`00DaeC7@030005Dad01P00Dad00000Dad000AC7@03001C7@0000800003Dad005<M00=C7@<0009C
7@03001C7E<M00=C7@<000=C7@03001C7E<M00<000EC7@03001C7E<M00<000AC7@03001C7@000080
0003Dad005<M00=C7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M10000e<M00<005<M
Dad01@000U<M00@005<MDaeC7@<000AC7@04001C7E<MDad30004Dad01P00Dad00000Dad001Ioo`03
001oogoo02]oo`009Woo0`0000<dR`00Ool00goo00<00007000047oo0`000U<M00<005<MDad00U<M
0`0015<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad0100015<M00H005<M0000
05<M0004Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`000e<M00<0
05<MDad00`001E<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@00
0002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad6000015<M001C7E<M10000e<M00@005<M
DaeC7@<000AC7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00<005<M00000P0000=C7@00
Dad00e<M0`000U<M00<005<MDad00e<M0`000e<M00<005<MDad00`001E<M00<005<MDad00`0015<M
00<005<M00000P0000=C7@00Dad00e<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@02Dad4
0003Dad00`00DaeC7@050002Dad01000DaeC7E<M0`0015<M00<007ooOol057oo00<007ooOol0:Woo
000VOol01@00Ool003B;000017oo00<0000700003Woo0P0000=C7@00Dad00e<M00@005<M0000009C
7@03001C7E<M009C7@<000=C7@04001C7E<MDad30004Dad00`00DaeC7@040004Dad00`00DaeC7@03
0004Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004
Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@030005Dad00`00DaeC7@030005Dad01P00
Dad00000Dad000AC7@03001C7@0000@000AC7@<0009C7@03001C7E<M009C7@@000=C7@03001C7E<M
00@000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00<005<M
00000P0000=C7@00Dad00e<M0`000U<M00<005<MDad00e<M0`000e<M00<005<MDad00`001E<M00<0
05<MDad00`0015<M00<005<M00000P0000=C7@00Dad00e<M00H005<M000005<M0005Dad30002Dad0
0`00DaeC7@02Dad40003Dad00`00DaeC7@03000EOol00`00Oomoo`0ZOol002Ioo`80008dR`03001o
ogoo009oo`0300001`0000]oo`<000AC7@03001C7E<M00@000AC7@04001C7@000002Dad00`00DaeC
7@02Dad00`00Dad00002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC
7@040004Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad0
0U<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M0`0015<M
00<005<MDad01@000e<M00H005<M000005<M0004Dad01000Dad000000U<M00<005<MDad00U<M0`00
0U<M00<005<MDad00e<M0`000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<MDad0
100015<M00H005<M000005<M0004Dad00`00Dad0000200000e<M001C7@03Dad30002Dad00`00DaeC
7@03Dad30003Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M001C
7@03Dad01P00Dad00000Dad000EC7@<0009C7@03001oogoo01Aoo`03001oogoo02Uoo`009Woo0P00
0SB;00<007ooOol00Woo00<00007000027oo0`000e<M00@005<MDaeC7@<000AC7@03001C7E<M00<0
00EC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC
7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C
7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@@0009C7@03
001C7E<M009C7@D0009C7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@06001C7@00001C7@00
15<M00<005<M00000P0000=C7@00Dad00e<M0`000U<M00<005<MDad00e<M0`000e<M00<005<MDad0
100015<M00<005<MDad00`0015<M00<005<MDad0100015<M00H005<M000005<M0004Dad00`00Dad0
000200000e<M001C7@03Dad30002Dad00`00DaeC7@03Dad30002Dad20002Dad30005Dad00`00DaeC
7@030004Dad00`00Dad0000200000e<M001C7@03Dad00`00Oomoo`0DOol00`00Oomoo`0XOol002Io
o`8000<dR`04001oogoo000200L00`00Oomoo`04Ool20002Dad00`00DaeC7@02Dad00`00Dad00002
Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040004Dad00`00DaeC
7@040003Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<0
009C7@03001C7E<M009C7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M
00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad000030005Dad30002Dad00`00DaeC
7@02Dad30004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@03
001C7@0000800003Dad005<M00=C7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00@000AC
7@03001C7E<M00<000AC7@03001C7E<M00<000EC7@06001C7@00001C7@0015<M00<005<M00000P00
00=C7@00Dad00e<M0`000U<M00<005<MDad00e<M0`000e<M00<005<MDad00`001E<M00<005<MDad0
0`005Goo00<007ooOol0:7oo000UOol20004=8/01000Oomoo`000P0700@007ooOomoo`@000AC7@03
001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000AC
7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@06001C7@00001C7@00
15<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000AC7@03001C7E<M
00@000=C7@03001C7E<M00@000AC7@03001C7E<M00@000=C7@03001C7@0000800003Dad005<M00=C
7@06001C7@00001C7@001E<M0`000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<M
Dad0100015<M00H005<M000005<M0004Dad00`00Dad0000200000e<M001C7@03Dad30002Dad00`00
DaeC7@03Dad30003Dad00`00DaeC7@040003Dad01000DaeC7E<M0`0015<M00<005<MDad00`001E<M
00H005<M000005<M0004Dad00`00Dad0000200000e<M001C7@03Dad30003Dad01000DaeC7E<M1000
0e<M00<007ooOol04goo00<007ooOol09goo000UOol20004=8/01000Oomoo`000P07100015<M00<0
05<MDad010000e<M00<005<MDad0100015<M00<005<MDad010000e<M00@005<M0000009C7@03001C
7E<M009C7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC
7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@03001C7E<M009C7@<0
009C7@03001C7E<M009C7@<000AC7@03001C7E<M00H00004Dad005<MDad40004Dad00`00DaeC7@03
0004Dad00`00Dad0000200000e<M001C7@03Dad30002Dad00`00DaeC7@03Dad30003Dad00`00DaeC
7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@030005Dad01P00Dad00000Dad000AC7@03001C
7@0000800003Dad005<M00=C7@<0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00@000=C7@04
001C7E<MDad30004Dad00`00DaeC7@030005Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M
009C7@8001Eoo`03001oogoo02Ioo`009Goo0P0013B;00D007ooOol000070080009C7@03001C7E<M
009C7@<000=C7@04001C7E<MDad30004Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01000
Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30003
Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad0
00AC7@04001C7@000002Dad00`00DaeC7@02Dad60004Dad30004Dad00`00DaeC7@040003Dad00`00
DaeC7@040004Dad01P00Dad00000Dad000AC7@03001C7@0000800003Dad005<M00=C7@<0009C7@03
001C7E<M00=C7@<000=C7@03001C7E<M00@000=C7@04001C7E<MDad30004Dad00`00DaeC7@030005
Dad01P00Dad00000Dad000AC7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M10000e<M
00<005<MDad010000e<M00@005<MDaeC7@<000AC7@06001C7@00001C7@001E<M100000=C7@00Ool0
57oo00<007ooOol09Woo000UOol00`00=8/dR`03=8/00`00Oomoo`030004Dad01000Dad000000U<M
00<005<MDad00U<M00<005<M00000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`000e<M
00<005<MDad0100015<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@06001C
7@00001C7@0015<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad0100015<M00<005<MDad0
0`0015<M00<005<MDad0100015<M00<005<M000010000e<M00@005<M0000009C7@03001C7E<M009C
7@<0009C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@06001C
7@00001C7@0015<M00<005<M00000P0000=C7@00Dad00e<M0`000U<M00<005<MDad00U<M10000e<M
00<005<MDad010000e<M00@005<MDaeC7@<000AC7@03001C7E<M00<000AC7@03001C7@0000800003
Dad005<M00=C7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M10000U<M00@005<MDaeC
7@<000AC7@03001C7E<M00<000EC7@03001oogoo019oo`8002Moo`009Goo00<003B;=8/00SB;1000
0e<M00<005<MDad0100015<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@06
001C7@00001C7@0015<M0`0015<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad0
0`0015<M00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@0015<M0`000e<M00<005<M
Dad00U<M0`000e<M00<005<MDad0100015<M00<005<MDad01@000U<M00<005<MDad0100015<M00H0
05<M000005<M0004Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad0100015<M
00<005<MDad00`0015<M00<005<MDad0100015<M00H005<M000005<M0004Dad01000Dad000000U<M
00<005<MDad00U<M0`000U<M00<005<MDad00U<M10000e<M00<005<MDad010000e<M00<005<MDad0
0`001E<M00<005<MDad00`0015<M00<005<M00000P0000=C7@00Dad00e<M00H005<M000005<M0004
Dad40003Dad00`00DaeC7@040003Dad01000DaeC7E<M0`005Goo00<007ooOol097oo000UOol00`00
=8/000020003Dad01000DaeC7E<M0`0015<M00<005<MDad010000e<M00<005<MDad0100015<M00<0
05<MDad010000e<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000AC
7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@04001C7@000002Dad0
0`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M009C7@D00004Dad005<MDad4
0004Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@<000=C7@03
001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00<000EC
7@06001C7@00001C7@0015<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@02Dad30003Dad0
1000DaeC7E<M10000e<M00<005<MDad00`001E<M00<005<MDad00`0015<M00H005<M000005<M0005
Dad30002Dad00`00DaeC7@02Dad40002Dad00`00Oomoo`0COol00`00Oomoo`0TOol002Aoo`H000AC
7@03001C7@00009C7@03001C7E<M009C7@<000=C7@04001C7E<MDad30004Dad00`00DaeC7@040004
Dad00`00DaeC7@030004Dad01000Dad000000U<M00H005<MDaeC7@00Dad20002Dad00`00DaeC7@02
Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00
DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000`0015<M0`000e<M00<0
05<MDad00U<M0`000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00H005<M000005<M0005
Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00@000=C7@04
001C7E<MDad30004Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M001C7@03Dad01P00Dad0
0000Dad000AC7@@0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00D0009C7@80009C7@<000AC
7@03001C7@0000800003Dad005<M00=C7@06001C7@00001C7@0015<M0P005Goo00<007ooOol08goo
000TOol20002Ool00`0074h00002Dad30004Dad01000Dad000000U<M00<005<MDad00U<M00<005<M
00000U<M00<005<MDad00U<M0`0015<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<M
Dad00`0015<M00@005<M0000009C7@06001C7E<MDad005<M0P000U<M00<005<MDad00U<M0`000U<M
00<005<MDad00U<M0`0015<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad01000
0e<M00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@0015<M0`0015<M00<005<MDad0
10000e<M00<005<MDad00`0015<M00@005<MDaeC7@<000AC7@06001C7@00001C7@0015<M00<005<M
00000P0000=C7@00Dad00e<M0`000U<M00<005<MDad00U<M10000e<M00<005<MDad010000e<M00<0
05<MDad00`001E<M00<005<MDad00`0015<M00H005<M000005<M0005Dad01P00Dad00000Dad000AC
7@<000=C7@04001C7E<MDad40003Dad00`00DaeC7@030005Dad00`00DaeC7@030004Dad01P00Dad0
0000Dad001Ioo`03001oogoo029oo`0097oo00D007ooOomoo`00008LCP8000=C7@03001C7E<M00@0
00AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02
Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01P00Dad0
0000Dad000AC7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30004Dad0
0`00DaeC7@06000015<M001C7E<M100015<M00<005<MDad00`0015<M00H005<M000005<M0005Dad3
0002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@050003Dad00`00DaeC7@030004Dad00`00DaeC
7@040004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M
0`000e<M00@005<MDaeC7@@000=C7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad01P00Dad0
0000Dad000AC7@@0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00D000=C7@03001C7E<M00<0
00AC7@03001oogoo01=oo`03001oogoo029oo`0067oo00AJePQ2000icPQoo`05001oogooOol00003
74h01000DaeC7E<M0`0015<M00<005<MDad010000e<M00<005<MDad0100015<M00H005<M000005<M
0004Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M0`0015<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad0100015<M00H005<M000005<M0004Dad01000
Dad000000U<M00<005<MDad00U<M1P0015<M0`0015<M00<005<MDad010000e<M00<005<MDad00`00
15<M00<005<M00000P0000=C7@00Dad00e<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02
Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad00`00Dad0
000200000e<M001C7@03Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@<000=C7@03
001C7E<M00D000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0P0000EC7@00001C7@00
00AC7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00<001Eoo`03001oogoo025oo`005goo
00IS61S6LiacW124DY@7Ool01@00Oomoogoo000011a>00<005<M00000U<M00<005<MDad00U<M0`00
15<M00<005<MDad00`0015<M00<005<MDad010000e<M00<005<MDad0100015<M00H005<M000005<M
0004Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M0`0015<M00<005<M
Dad00`0015<M00<005<MDad00`0015<M00<005<MDad0100015<M00<005<M000010000e<M00@005<M
0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C
7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<0009C7@03
001C7E<M00=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC
7@06001C7@00001C7@001E<M00H005<M000005<M0004Dad30003Dad01000DaeC7E<M10000e<M00<0
05<MDad00`0015<M00@005<MDaeC7@<000AC7@06001C7@00001C7@0015<M00<005<M00000P0000=C
7@00Dad00e<M0`000U<M00<007ooOol04goo00<007ooOol08Goo000GOol01R48DYAoogooDY@HaPMo
o`05001oogooOol0000574h20003Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<M
Dad00U<M0`0015<M00<005<MDad00`0015<M00<005<MDad010000e<M00<005<MDad0100015<M00H0
05<M000005<M0004Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M0`00
0e<M00<005<MDad0100015<M00<005<MDad01@000U<M00<005<MDad0100015<M00H005<M000005<M
0004Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000AC7@03001C7@0000800003Dad005<M00=C7@<0009C
7@03001C7E<M009C7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@04001C7E<MDad3
0004Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00D0009C
7@04001C7E<MDad30004Dad00`00DaeC7@030005Dad400000e<M001C7@03Dad00`00Oomoo`0COol0
0`00Oomoo`0POol001Moo`03001oogoo009oo`03001oogoo00Aoo`<0009oo`03000LCQa>00<LCP<0
009C7@<000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03
001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC
7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30004Dad00`00DaeC7@06000015<M001C
7E<M100015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01000Dad000000U<M00<005<M
Dad00U<M0`000U<M00<005<MDad00U<M0`0015<M00<005<MDad010000e<M00<005<MDad00`0015<M
00<005<MDad0100015<M00H005<M000005<M0004Dad01P00Dad00000Dad000EC7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00D000=C7@03001C7E<M00<000AC7@06001C7@00001C7@001E<M00H0
05<M000005<M0004Dad30002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@040003Dad00`00DaeC
7@030005Dad00`00DaeC7@03000EOol00`00Oomoo`0OOol001Moo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo009oo`03000LCQa>00<LCP80000300X0000000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@03001C7E<M009C7@<0009C
7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00@0
00=C7@04001C7@000002Dad00`00DaeC7@02Dad300000e<M00000004Dad30004Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@06001C7@00
001C7@001E<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad0100015<M00<005<MDad00`00
15<M00<005<MDad00`0015<M00<005<M00000P0000=C7@00Dad00e<M0`000U<M00<005<MDad00U<M
0`000e<M00@005<MDaeC7@@000=C7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad01P00Dad0
0000Dad000AC7@06001C7@00001C7@001E<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad0
1@000e<M00<007ooOol04Woo00<007ooOol07goo000GOol00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`0074hLCP0274h01@00Ool0000:000015<M0`0015<M00<005<MDad00`0015<M
00<005<MDad010000e<M00<005<MDad0100015<M00H005<M000005<M0004Dad01000Dad000000U<M
00@005<MDaeC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC
7@05001C7@00001C7@030002Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad0
0U<M0`000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<M
00000P0000=C7@00Dad00e<M00H005<M000005<M0004Dad30004Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M
10000U<M00<005<MDad00U<M0`000e<M00<005<MDad01@000U<M00@005<MDaeC7@<000AC7@03001C
7E<M00<000AC7@03001C7@0000800003Dad005<M00=C7@06001C7@00001C7@0015<M0`000e<M00@0
05<MDaeC7@<001Aoo`8001moo`005goo00HQ25:DOomooe:D8@P6Ool00`00Oomoo`02Ool00`0074hL
CP0274h00`00Ool0000200X01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M
0`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<MDad0100015<M00<005<M0000
0U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M0`0015<M00<005<MDad010000e<M00<005<M
Dad01P0000AC7@00DaeC7@@000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003
Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@03
0004Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC
7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@001E<M00H005<M000005<M
0004Dad30002Dad00`00DaeC7@02Dad40003Dad00`00DaeC7@040003Dad00`00DaeC7@030005Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000AC7@@0009C7@03001oogoo019oo`8001moo`005goo
00IS61S6LiacW1S6HaP6Ool00`00Oomoo`02Ool00`0074hLCP0274h2000400X20004Dad01000Dad0
00000U<M00H005<MDaeC7@00Dad20002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@04001C7@000002Dad0
0`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad70002Dad40004Dad00`00DaeC7@030004Dad00`00
DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004Dad30003Dad0
0`00DaeC7@040004Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad0000200000e<M
001C7@03Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00=C7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad01P00Dad00000Dad000AC7@06001C7@00
001C7@001E<M0`000e<M00<005<MDad010000U<M0P000U<M1@000U<M00@005<MDaeC7@<000AC7@06
001C7@00001C7@001E<M00<007ooOol04Woo00<007ooOol07Goo000HOol015[F2488@V<H1goo0P00
0Woo00<001a>74h00Qa>00<007oo0000100:00<006m/00000U<M100015<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad30003Dad01000DaeC7E<M0`0015<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad0100015<M00H005<M000005<M0004Dad00`00Dad000040003Dad30004
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@030004
Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00<005<M00000P0000=C
7@00Dad00e<M0`000e<M00<005<MDad010000e<M00<005<MDad01@000e<M00<005<MDad00`0015<M
00<005<MDad00`0015<M00<005<M00000P0000=C7@00Dad00e<M0`000U<M00<005<MDad00U<M0`00
0e<M00<005<MDad01@000e<M00<005<MDad00`0015<M00<005<MDad00`005Goo00<007ooOol077oo
000ROol20003Ool00`0074hLCP0274h00`00Ool0000300X00`00Kfa_K0030004Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000U<M00<0
05<MDad00U<M0`000U<M00<005<MDad00U<M0`0015<M00<005<MDad00`0015<M00<005<MDad00`00
15<M00<005<MDad01@000e<M00<005<M00000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M
0`000e<M00<005<MDad0100015<M00<005<MDad010000e<M00<005<MDad00`0015<M00@005<M0000
009C7@03001C7E<M009C7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`0015<M00<0
05<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`001E<M00H005<M000005<M0004Dad3
0002Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M10000e<M00<005<MDad010000e<M00<005<M
Dad00`001E<M100000=C7@00Dad00e<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@03Dad3
0003Dad00`00DaeC7@040003Dad00`00Oomoo`0COol00`00Oomoo`0KOol0029oo`03001oogoo009o
o`03000LCQa>008LCP03001oo`0000<02P03001_K000009oo`03001C7E<M009C7@<000=C7@03001C
7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@04001C7@000002Dad01P00DaeC
7E<M001C7@80009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00H0009C
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00@005<M0000009C7@04001C7E<MDad30003
Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@03
0004Dad01P00Dad00000Dad000AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad01000DaeC7E<M0`0015<M00H005<M000005<M0004Dad01P00
Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000EC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00<005<M00000P0000=C7@00Dad0
0e<M0`000e<M00<005<MDad00`0057oo00<007ooOol02Goo00IcW248000002U:Li`4Ool015[F2480
03W>17oo000ROol00`00Oomoo`02Ool00`0074hLCP0274h00`00Ool0000300X20003Ool200000e<M
00000002Dad01000DaeC7E<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<0
05<MDad0100015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02
Dad300001E<M000005<M00000U<M10000e<M00<005<MDad00`0015<M00<005<MDad0100015<M00<0
05<M00000U<M00<005<MDad00U<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30004
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@040004Dad01P00Dad00000Dad0
00AC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00D000=C7@03001C7E<M00<000AC7@03
001C7E<M00<000AC7@06001C7@00001C7@001E<M00H005<M000005<M0004Dad30002Dad00`00DaeC
7@02Dad30003Dad01000DaeC7E<M10000e<M00<005<MDad00`0015<M00<005<MDad00`001E<M1000
00=C7@00Dad00e<M0`000U<M00<007ooOol04goo00<007ooOol027oo00HYBSW>OomoocW>:DX3Ool0
1V<H6<IcW7>L48ABU0=oo`008Woo00<007ooOol00Woo00D001a>74hLCP00009oo`0300002P0:0080
00Aoo`04000LCP000004Dad00`00Dad00002Dad00`00DaeC7@02Dad01P00Dad00000Dad000AC7@<0
00AC7@03001C7E<M00<000AC7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@04001C7@000002
Dad01P00DaeC7E<M001C7@800004Dad000000003Dad30002Dad00`00DaeC7@02Dad30003Dad00`00
DaeC7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@04
001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<M
Dad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00@005<MDaeC7@<000AC7@06
001C7@00001C7@0015<M00H005<M000005<M0004Dad40002Dad01000DaeC7E<M10000U<M0P000U<M
10000e<M00<005<MDad00`001E<M100000=C7@00Dad00e<M00<007ooOol04goo00<007ooOol01goo
00<8@WooOol00Woo00H007ooOomoob48DY@2Ool00e:D6<Ioo`02Ool0029oo`03001oogoo009oo`05
000LCQa>74h00002Ool00`0000X02P020004Ool01@0074hLCQa>00000U<M0`0015<M00<005<MDad0
10000e<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00D0009C7@06001C7@00001C7@0015<M00H0
05<M000005<M0004Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@<000=C
7@04001C7E<MDad40003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00EC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad01@000e<M00<0
05<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad40002Dad00`00DaeC7@02
Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030005Dad00`00DaeC7@03000DOol00`00Oomo
o`07Ool00`00Liaoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Goo000ROol20003Ool01@00
74hLCQa>00000Woo00@0000:00X000Eoo`03000LCQa>008LCP8000=C7@03001C7E<M00@000AC7@03
001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30004Dad00`00DaeC
7@030004Dad00`00DaeC7@06000015<M001C7E<M0`0015<M00<005<MDad010000e<M00@005<M0000
009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad4
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01000DaeC7E<M
0`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad01000DaeC7E<M1000
0e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0005Dad400000e<M001C
7@03Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@050002Dad00`00Oomoo`0COol00`00Oomo
o`06Ool01P00:DYcW7oo>LhYBP=oo`03001oogoo009oo`03001oogoo005oo`008Goo0P0017oo00D0
01a>74hLCP00009oo`0400002P000005Ool00`0074hLCP0274h30002Dad30004Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<MDad00U<M
0`000U<M00<005<MDad00U<M1`000U<M10000e<M00<005<MDad0100015<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000AC7@03001C7E<M00<000AC7@03001C
7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC
7@02Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@050003Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M10000U<M00@005<M
DaeC7@@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@D00003
Dad005<M00=C7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00<001Eoo`03001oogoo00Eo
o`0648@icP00000YBW>L0goo00<007ooOol00Woo00<007ooOol00Goo000ROol00`00Oomoo`02Ool0
100074hLCP000goo00@0000:000000Eoo`03000LCQa>008LCP80000300`00000009C7@03001C7E<M
009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C
7@00001C7@0015<M00<005<M000010000e<M0`000e<M00@005<MDaeC7@<000AC7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad3
0002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@040004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M
0`000e<M00@005<MDaeC7@@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00
001C7@0015<M10000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00`001E<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<0009C7@03
001oogoo01=oo`03001oogoo00Eoo`03@Q0aS7oo00Ioo`068@QBU7ooOomBU2480goo000QOol00`00
Oomoo`03Ool0100074hLCP000goo00<0000:00001Goo00<001a>74h00Qa>00D007oo0000300000AC
7@04001C7@000002Dad01000DaeC7E<M0`000e<M00@005<MDaeC7@<000AC7@03001C7E<M00@000=C
7@03001C7E<M00<000AC7@03001C7E<M00D0009C7@04001C7@000002Dad00`00DaeC7@02Dad00`00
Dad00002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad0
0U<M0`000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M
000005<M0004Dad01P00Dad00000Dad000AC7@@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@06001C7@00001C7@001E<M00H005<M000005<M0004Dad30002Dad0
0`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad01000DaeC7E<M0`0015<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad00`00Oomoo`0AOol40006Ool00aS6<Ha[FP05Ool01V<H6<IcW7>L
6<IS60=oo`008Goo00<007ooOol00goo00@001a>74h000=oo`<000Eoo`03000LCQa>008LCP06001o
ogoo000030000U<M100015<M00<005<M00000U<M00<005<MDad00U<M00<005<M00000U<M00<005<M
Dad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad01`0000AC7@00DaeC7@<000AC7@03001C
7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`0015<M00<005<MDad0
0`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00Dad0
0000Dad000AC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad3
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01000DaeC7E<M0`0015<M00H005<M0000
05<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00D0009C7@04001C7E<MDad40002
Dad01000DaeC7E<M0`0015<M00<005<MDad00`0057oo00<007ooOol01Woo00@icPQ2000@Q0Aoo`04
F]H8@PQ2HaP4Ool0025oo`03001oogoo009oo`04000LCQa>0003Ool00`0000X00006Ool00`0074hL
CP0274h01@00Oomoo`0000`00`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00@005<M
0000009C7@04001C7E<MDad30003Dad01000DaeC7E<M0`0000=C7@0000000P000U<M10000e<M00<0
05<MDad010000e<M00<005<MDad00`0015<M00@005<M0000009C7@06001C7E<MDad005<M0P000U<M
00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
15<M00<005<MDad010000e<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C
7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000EC7@06001C7@00
001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@050002
Dad01000DaeC7E<M0`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00
DaeC7@02Dad40002Dad00`00DaeC7@050002Dad01000DaeC7E<M10000e<M00<007ooOol04Woo00<0
07ooOol05Goo000QOol20003Ool0100074hLCP000goo00<0000:00001Woo00D001a>74hLCP0000=o
o`8000=9]003001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7@00
009C7@03001C7E<M009C7@04001C7@00Dad30003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C
7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<0
00AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad01000DaeC7E<M0`0015<M00<005<MDad00`0015<M00H005<M000005<M0004
Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@050002Dad01000DaeC7E<M10000e<M00<0
05<MDad00`0015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M
00D0009C7@04001C7E<MDad3000DOol00`00Oomoo`0DOol0025oo`03001oogoo009oo`04000LCQa>
0003Ool20007Ool01@0074hLCQa>00000goo00<004VdBK@00dVd0P0015<M00<005<MDad00`0015<M
00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<MDad01@000U<M00H005<M000005<M0004
Dad30002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030004Dad00`00DaeC7@040003Dad00`00
DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0
100015<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@050003Dad00`00DaeC7@040003
Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<0
05<MDad01@000U<M00@005<MDaeC7@@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06
001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M10000U<M00<007ooOol04Woo00<007ooOol0
57oo000QOol00`00Oomoo`02Ool0100074hLCP000goo0P001goo00D001a>74hLCP0000=oo`030019
]4Vd00=9]08000AC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00H00004Dad005<MDad40003Dad01000Dad000000U<M00H005<MDaeC7@00Dad20002Dad00`00DaeC
7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00
DaeC7@030004Dad01000Dad000000U<M00@005<MDaeC7@<000=C7@03001C7E<M009C7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M
00H005<M000005<M0004Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@@0
009C7@04001C7E<MDad40003Dad00`00DaeC7@040002Dad20002Dad30004Dad01P00Dad00000Dad0
00AC7@06001C7@00001C7@0015<M0P0057oo00<007ooOol04goo000POol00`00Oomoo`03Ool00`00
74h00004Ool20007Ool0100074hLCP0017oo00<004VdBK@00TVd00D007oo000005<M00800003Dad0
05<M00=C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad020000U<M100015<M00<005<MDad0
0`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00Dad00002Dad0
0`00DaeC7@02Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@001E<M0`000U<M00<0
05<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@@0009C7@04001C7E<MDad40003Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad001Eoo`03
001oogoo019oo`0087oo00<007ooOol00goo00<001a>000017oo00<007ooOol01Woo00@001a>74h0
00Aoo`030019]4Vd0099]004001oo`0042l20003Dad00`00DaeC7@040003Dad01000Dad000000U<M
00@005<MDaeC7@<0009C7@8000=C7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad0
0000Dad000AC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad40002Dad00`00DaeC7@02Dad30002Dad20002Dad40003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Oomoo`0BOol00`00Oomoo`0BOol0021oo`<0
00=oo`03000LCP0000eoo`04000LCQa>0004Ool01@00BKA9]4Vd00000Woo00D0010_42l@;`00009C
7@<000AC7@03001C7E<M00<000AC7@03001C7@00009C7@<0009C7@03001C7@00009C7@03001C7E<M
009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C
7E<M00@000=C7@04001C7@000002Dad01000DaeC7E<M0`000e<M00<005<MDad00U<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad0
1P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M
0005Dad400000e<M001C7@02Dad40002Dad01000DaeC7E<M10000e<M00<005<MDad010000e<M00<0
05<MDad00`0057oo00<007ooOol04Goo000POol00`00Oomoo`03Ool00`0074h0000=Ool00`0074h0
0005Ool01@00BKA9]4Vd00000Woo00<0010_42l00Q0_0P000e<M00<005<MDad010000e<M00<005<M
Dad01P0000AC7@00DaeC7@<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`00
0e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00<005<M00000U<M
00<005<MDad00U<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03
001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030005Dad60003Dad40002Dad00`00DaeC
7@02Dad30002Dad01000DaeC7E<M10000e<M00<007ooOol047oo0`004Woo000POol00`00Oomoo`03
Ool2000>Ool00`0074h00006Ool00`00BK@00003Ool00`0042l@;`0242l00`00DaeC7@02Dad30003
Dad00`00DaeC7@080002Dad40003Dad00`00DaeC7@040003Dad01000Dad000000U<M00H005<MDaeC
7@00Dad20002Dad01000DaeC7E<M0`0015<M00<005<MDad00`0015<M00<005<MDad010000e<M00<0
05<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02
Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad0
0000Dad000AC7@06001C7@00001C7@0015<M0`0015<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad4
00000e<M001C7@04Dad400000e<M001C7@02Dad40002Dad01000DaeC7E<M0`003Woo0`000Woo00<0
07ooOol047oo00000gooBU88@P0200000b48Liaoo`03Ool015[F248003W>1Goo00AJePQ2000icPQo
o`03001oogoo00=oo`8000ioo`03000LCP0000Ioo`030019]00000=oo`08000@;a0_42l006na001C
7@80009C7@04001C7E<MDad300000e<M000000020002Dad30004Dad00`00DaeC7@030004Dad00`00
DaeC7@030004Dad00`00DaeC7@030004Dad00`00Dad00002Dad00`00DaeC7@02Dad30002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M
009C7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030005Dad300000e<M
001C7@03Dad40002Dad00`00Oomoo`09Ool30005Ool00`00Oomoo`0@Ool00003Ool8@T8@009oo`03
>LhQ27oo009oo`06HaPHaW>LLi`@Q5:D0goo00IS61S6LiacW124DY@6Ool00`00Oomoo`04Ool2000>
Ool20007Ool00`00BK@00003Ool01P0042l@;a0_001_/@<000AC7@04001C7@00Dad30003Dad30003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004
Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad3
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004
Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad20002Dad40003Dad00`00DaeC7@03
0004Dad01P00Dad00000Dad000EC7@03001oogoo00Aoo`@000Qoo`03001oogoo011oo`001Woo00H0
07ooOomoob48DY@2Ool00e:D6<Ioo`02Ool01R48DYAoogooDY@HaPIoo`03001oogoo00=oo`8000mo
o`8000Moo`8000Aoo`03000@;a0_00<00004Ool002SB0002Dad50002Dad01P00Dad00000Dad000AC
7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M
0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad0
0`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00
001C7@0015<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00`0015<M00<005<MDad00`000goo0`0037oo00<007ooOol047oo0005Ool00g>L
001oo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo0P0017oo0P003goo
0P001goo0P0017oo00D0010_001_/@00009oo`03000XdRSB00H0009C7@@000=C7@06001C7@00001C
7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad01000Dad000000U<M00@005<MDaeC7@<0009C7@03
001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@04001C7@000002Dad01P00DaeC7E<M001C7@80009C7@04001C7E<MDad30004Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000
Dad000AC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30002Dad20002
Dad40003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad3000@Ool00`00Oomoo`0?Ool00003
Ool8@TYB009oo`03>LhaS7oo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool2000?Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0100042l000000goo00<0
02SB00000`000U<M0`0015<M00<005<MDad00`000e<M00<005<MDad010000e<M00@005<M0000009C
7@04001C7E<MDad30003Dad01000DaeC7E<M0`0015<M00<005<MDad00`0015<M00<005<MDad00`00
15<M00<005<MDad00`0015<M00<005<M00000U<M00H005<MDaeC7@00Dad20002Dad01000DaeC7E<M
0`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<MDad0
0`0015<M00<005<M00000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M0`000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00
Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`000e<M
00<005<MDad010000e<M00<005<MDad00`004Goo00<007ooOol03goo00000goo000@Q00200000c6<
Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol00goo
0P003goo00<007ooOol037oo0`000goo0`0012SB0P000e<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00<005<MDad00`0015<M00<005<M00000U<M00<005<MDad00U<M00<005<M00000U<M00<0
05<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M
00<005<MDad00`0015<M00<005<M00000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004
Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01000
0U<M00@005<MDaeC7@@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@0000<0
00AC7@06001C7@00001C7@0015<M0`000U<M00@005<MDaeC7@@0009C7@03001oogoo00moo`03001o
ogoo00moo`0000=oo`00Ool01goo00HQ25:DOomooe:D8@P3Ool01R48DYAoogooDY@Q20Ioo`03001o
ogoo00=oo`03001oogoo01eoo`800006Ool00000001oo`001BSB00<005<MDad00U<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@<000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC
7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad01000DaeC7E<M1000
0U<M00@005<MDaeC7@@0009C7@04001C7E<MDad40002Dad01000DaeC7E<M0`000e<M0P000U<M0`00
15<M100000=C7@00Dad00U<M10000U<M00<005<MDad00`0047oo00<007ooOol03goo00000goo001o
o`07Ool01V<H6<IcW7>L6<IS60=oo`06HaPHaW>LLi`HaV<H1Goo00<007ooOol017oo00<007ooOol0
7Goo0`001Goo00@002SB:=8XdP<00005Dad00000Dad00004Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC
7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000
Dad000AC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@0009C7@04001C7E<MDad40002
Dad01000DaeC7E<M0`0015<M100000=C7@00Dad00e<M0`0000=C7@00Dad00e<M10000U<M00<005<M
Dad01@000U<M00<005<MDad01@000U<M00<005<MDad01@000U<M00<005<MDad00`001E<M0`0000=C
7@00Dad00e<M0`000U<M00<007ooOol03Woo00<007ooOol03goo00000goo000000030005Ool015[F
2488@V<H1Goo00AJePQ2249S60Ioo`03001oogoo025oo`<000Qoo`04000XdRSB:=8200000`be0000
0003Dad01000Dad000000U<M00@005<MDaeC7@<000AC7@03001C7E<M00<000AC7@03001C7E<M00<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M0000
05<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M
000005<M0004Dad30002Dad00`00DaeC7@050002Dad00`00DaeC7@050002Dad00`00DaeC7@030005
Dad00`00Dad000020004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C
7E<M00@0009C7@80009C7@@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00<007oo
Ool03Goo00<007ooOol03goo000NOol2000POol2000;Ool01P00:=8XdP00Ool000<<]@03001C7E<M
00<000AC7@03001C7@00009C7@03001C7E<M009C7@<0009C7@03001C7E<M009C7@<000=C7@03001C
7E<M00<000AC7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@06001C
7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`00
3Woo00<007ooOol03goo000NOol00`00Oomoo`0LOol3000=Ool01000:=8XdP000Woo00<000be0000
0`000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@03001C7E<M00<000=C
7@04001C7@000002Dad01000DaeC7E<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@<00003Dad005<M00=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M
0004Dad30002Dad20002Dad40003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00Oomo
o`0<Ool00`00Oomoo`0>Ool001ioo`03001oogoo01Uoo`<0011oo`03000XdP0000=oo`8000=9mP03
001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00<005<M00000U<M00@005<MDaeC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00
001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000U<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00
Dad00000Dad000AC7@<000=C7@03001C7E<M00@0009C7@04001C7E<MDad40002Dad01000DaeC7E<M
0`003Goo00<007ooOol03Woo000NOol00`00Oomoo`0FOol3000COol00`00:=800003Ool00`00BOI9
mP03BOH20004Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00
Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@03001C7@00009C7@06001C7E<MDad005<M0P000U<M00@005<MDaeC
7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad00`000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@03001C7@0000<000AC7@<0009C7@03001C7E<M00D0009C7@03001C7E<M00D0009C
7@03001oogoo00]oo`03001oogoo00ioo`007Woo00<007ooOol04goo0`005Woo0P0017oo00<004Wf
BOH00dWf00<0023c00000U<M10000e<M00<005<MDad00`0015<M00<005<MDad00`000e<M00<005<M
Dad010000e<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad00`00Dad00002
Dad01000DaeC7E<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@D00003Dad005<M009C7@<0009C7@03001C7E<M009C7@<000=C
7@03001C7E<M00<000aoo`03001oogoo00ioo`007Goo00<007ooOol04Goo0`006Goo0P001Goo00P0
04WfBOI9mP00Ool0023c0P000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00<005<MDad00`000e<M00@005<M0000009C7@06001C7E<MDad005<M0P0000=C7@00Dad0
0e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad00`0015<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M
000005<M0004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C
7E<M00@0009C7@04001C7E<MDad40002Dad00`00DaeC7@030005Dad300000e<M001C7@03Dad01P00
Dad00000Dad000AC7@<000=C7@03001oogoo00Uoo`03001oogoo00ioo`007Goo0P0047oo0P0077oo
00<007ooOol017oo00@004WfBOH0009oo`04000Plb3c0003Dad30002Dad00`00DaeC7@02Dad30003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030003
Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@00009C7@04001C7E<MDad30002Dad00`00DaeC
7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00
DaeC7@030004Dad01P00Dad00000Dad000=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<0
05<MDad00U<M0`000U<M00<005<MDad01@000U<M00<005<MDad010000e<M00<005<MDad00`0015<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad2000:Ool00`00Oomoo`0>Ool001eoo`03001o
ogoo00aoo`<002Eoo`040019mTWf0002Ool01`008?<Plb3c001C7@00009C7@06001C7E<MDad005<M
0P000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@04001C7@000002Dad01000DaeC7E<M0`000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M0000
0U<M00H005<MDaeC7@00Dad200000e<M001C7@03Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01@00Dad005<M000015<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad400000e<M001C7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000Yoo`03001o
ogoo00ioo`007Goo00<007ooOol02Goo0`00:Goo0P000goo00<0023c8?<00R3c00<005<MDad00U<M
00<005<MDad00`0015<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@00009C7@04001C
7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@030004Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C
7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad00`0015<M00<005<M00000P001E<M0`0000=C7@00Dad00e<M0`000e<M00<005<MDad01000
0U<M0P000U<M10000e<M00<005<MDad010000U<M00@005<MDaeC7@<000AC7@03001oogoo00Moo`03
001oogoo00ioo`007Goo00<007ooOol01Woo0`00;7oo00<007ooOol00Woo00L0023c8?<Pl`00Lk/0
0002Dad40003Dad00`00DaeC7@030004Dad00`00Dad00002Dad01000DaeC7E<M0`0015<M00<005<M
Dad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M
00000U<M00@005<MDaeC7@<0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M008000AC7@06001C7@00001C7@0015<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC
7@<000=C7@03001C7E<M00@0009C7@04001C7E<MDad40002Dad00`00DaeC7@050002Dad00`00DaeC
7@03000:Ool00`00Oomoo`0=Ool001eoo`03001oogoo00=oo`<003Eoo`03000Pl`00009c^`<000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@00009C7@03001C7E<M009C7@<000=C
7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@03001C7@00009C7@06001C7E<MDad005<M0P0000=C7@00Dad00e<M0`000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M00H005<M000005<M
0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00
DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0
10000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad300000e<M00000002Dad50002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00Oomoo`07Ool00`00Oomoo`0=Ool001aoo`04001oogooOol3000hOol200001G>k00000000=ED0
0P000U<M0`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad3
0003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0004Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000=C
7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000Qoo`03001oogoo
00eoo`0077oo1000>goo0`000Woo00@003EE=EDeE@8000=C7@03001C7E<M00<000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad010000U<M00@005<MDaeC7@<000AC7@<00003Dad005<M00=C7@<000=C7@03001C7E<M00@000=C
7@03001C7E<M00@0009C7@03001oogoo00Ioo`03001oogoo00eoo`0077oo0P00@goo00D003EE=EDe
E@00009C7@@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@06
001C7@00001C7@0015<M0`000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad30002Dad01000DaeC7E<M0`000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M0`0000=C7@00Dad00e<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad01@000U<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad30002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@030007Ool00`00
Oomoo`0=Ool001ioo`03001oogoo041oo`03000eECEE008eE@8000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M
00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0
10000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad01@00Dad005<M000015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000U<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad0
0000Dad000AC7@@00003Dad005<M009C7@<000=C7@03001oogoo00Aoo`03001oogoo00eoo`007goo
00<007ooOol0?goo00<003EE=ED00SEE0P000e<M0`000e<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad00`000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00<005<M0000
0U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M008000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<0
05<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`000e<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@0009C7@80009C7@<000AC7@03001C7@00008000EC7@<00003
Dad005<M00=C7@8000Eoo`03001oogoo00eoo`0087oo00<007ooOol0?Woo00@003EE=EDeE@@00005
Dad005<MDad00003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad00002Dad01000DaeC7E<M0`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00@0
05<MDaeC7@@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@001Woo
00<007ooOol037oo000QOol2000nOol01`00=EDeE@00Ool003Ym008000AC7@03001C7@00009C7@04
001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad00002Dad01000DaeC7E<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03
001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@<0
0003Dad005<M00=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00D00003Dad00000009C7@@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001oogoo00=oo`03001oogoo00aoo`00
8goo00<007ooOol0?7oo0P000goo00@003Ym>Wd0009C7@<000AC7@03001C7@00009C7@04001C7E<M
Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC
7@040003Dad00`00DaeC7@030004Dad00`00Dad00002Dad01000DaeC7E<M0`000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`0015<M00H005<M0000
05<M0004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00
001C7@0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000U<M00<005<MDad00`001Goo00<007ooOol037oo000TOol00`00Oomoo`0kOol0
0`00Oomoo`03Ool50003Dad00`00DaeC7@030004Dad00`00Dad00002Dad01000DaeC7E<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M
00<005<MDad00`0015<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@000e<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad0
10000e<M00<005<MDad00`0015<M00H005<M000005<M0003Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000=C
7@<000=C7@03001C7E<M00@0009C7@80009C7@@0009C7@04001C7E<MDad40002Dad00`00DaeC7@04
0003Dad00`00Oomoo`02Ool00`00Oomoo`0<Ool002Eoo`03001oogoo041oo`03001:>4Xh009:>003
001C7E<M00<000=C7@03001C7E<M00<000AC7@03001C7@00009C7@04001C7E<MDad30003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00
DaeC7@030004Dad01@00Dad005<M000015<M0`000e<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad010000e<M00<005<MDad00`0015<M00D005<M001C7@0000AC7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@<00003Dad005<M00=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@<00003Dad005<M00=C7@<000=C7@03001C7E<M
00@0009C7@03001C7E<M00D0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=oo`03001oogoo
00aoo`009Woo0P00@Goo00@004XhBSQ:>0<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC
7@03001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC
7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M00H005<M000005<M0004
Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000AC7@<00003Dad00000009C7@@000=C7@03001C7E<M00@000=C
7@03001C7E<M00@0009C7@05001oogooOol0000>Ool002Qoo`03001oogoo03ioo`04001:>4Xh0002
EmL00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004Dad00`00Dad00002Dad0
1000DaeC7E<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00<005<MDad010000e<M00<005<MDad00`000e<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad01P00Dad0
0000Dad000AC7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@06001C7@00001C7@000e<M0`000e<M00<005<M
Dad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M
000005<M0003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@030002
Ool00`00Oomoo`0<Ool002Uoo`03001oogoo03eoo`03001:>00000H000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@03001C7@00009C7@04001C7E<MDad30003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@020004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M
00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M
00<005<MDad00`0015<M0`0000=C7@00Dad00e<M0`000e<M00<005<MDad010000U<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad00`0015<M0`0000=C7@00Dad00e<M0`000e<M00<0
05<MDad010000U<M00<005<MDad010000e<M00@007ooOol000eoo`00:Woo00<007ooOol0?Goo0P00
00=oo`00?QX00chJ00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<0
05<MDad00`0015<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@04001C
7@000002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000=C7@<000=C7@03001C7E<M00@000=C
7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M008000AC
7@04001C7@000002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040002Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M
00@000=C7@03001C7E<M00<00003Ool007oo00aoo`00:goo0P00@Goo00@003hJ?QXn6P<000=C7@03
001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@03
001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004Dad30003Dad00`00DaeC7@030003
Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030004
Dad01@00Dad005<M000015<M0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000U<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M
100000=C7@00Dad00U<M0`000e<M00<005<MDad010000U<M00<007oo00003Goo000]Ool00`00Oomo
o`0nOol01000?QX000000U/L00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00`000e<M00<005<MDad00`0015<M00D005<M001C7@0000AC7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C
7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad010000e<M00<005<MDad00`000e<M00H005<M000005<M0004Dad30003Dad00`00
DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad01P00
Dad00000Dad000=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
00=C7@03001C7E<M00@0009C7@03001C7E<M00<000EC7@<00003Dad005<M00=C7@<0009C7@03001C
7E<M00@000eoo`00;Woo00<007ooOol0?Woo00<005/LFa`00U/L0`000e<M00<005<MDad00`000e<M
00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M
00H005<M000005<M0004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC
7@040002Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C
7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC
7@06001C7@00001C7@0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00D005<M001C7@0000AC7@<000=C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@06001C7@00001C7@000e<M0`000e<M00<007ooOol02goo000_Ool00`00Oomoo`0nOol01P00Fa`0
0000Fih000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@04001C7@000002Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@06001C7@00001C7@000U<M10000e<M
00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00H005<M000005<M0004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC
7@040002Dad20002Dad40003Dad00`00DaeC7@030004Dad30002Dad00`00DaeC7@03000<Ool0031o
o`8003moo`<0009KWP06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<005<MDad0
10000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M0`000e<M00<0
05<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<0
05<MDad00`0015<M00D005<M001C7@0000AC7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
00=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C
7E<M00<000AC7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000U<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`0000=oo`00Ool0
37oo000bOol00`00Oomoo`0oOol50003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@05001C7@00Dad0
0004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@05001C7@00Dad0
0004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad300000e<M001C7@03Dad30002Dad00`00DaeC7@040003
Dad00`00DaeC7@040002Dad20002Dad40002Dad00`00DaeC7@040003Dad01000Dad0000017oo00<0
07ooOol02goo000cOol00`00Oomoo`0nOol00`00BYa:W002BY`00`00DaeC7@030003Dad01000Dad0
00000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad0
10000e<M00<005<MDad00`000e<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad0
1000Dad000000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<0
05<MDad010000e<M00<005<MDad00`000e<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@04
0003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@03
0004Dad01000Dad000000U<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad01000
0U<M00<005<MDad010000e<M00<005<MDad00`001goo00<007ooOol02Woo000dOol00`00Oomoo`0n
Ool00`00BYa:W0040003Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@040002Dad00`00DaeC
7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad0
0000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00
001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M
00<005<MDad00`000e<M00<005<MDad00`0015<M0`000U<M00<005<MDad010000e<M00<005<MDad0
100000=C7@0000000U<M10000e<M00<005<MDad010002Woo00<007ooOol02Woo000eOol2000oOol2
0003Ecd00`00DaeC7@040003Dad01@00Dad005<M000015<M0`000e<M00<005<MDad00`000e<M00<0
05<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00P0015<M00@0
05<M0000009C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`000U<M00<005<MDad01000
0e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`00
15<M00<005<M00000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M
00<005<MDad010000U<M00<005<MDad010000e<M00H005<M000005<M0003Dad30003Dad00`00DaeC
7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@04000>Ool00`00Oomoo`0:Ool003Moo`03001o
ogoo03ioo`03001G?ELm00<000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`000e<M
00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M
00<005<MDad00`0015<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad0
10000e<M00<005<MDad010000U<M00<005<MDad00`0015<M00H005<M000005<M0003Dad30003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad300000e<M001C7@03Dad30002Dad00`00
DaeC7@040002Dad20002Dad4000BOol00`00Oomoo`0:Ool003Qoo`03001oogoo03ioo`80009Fo003
001C7E<M00@000=C7@03001C7E<M00<000=C7@04001C7@000002Dad00`00DaeC7@040003Dad00`00
DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00
Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000=C7@03001C7E<M00<000AC7@<0009C7@03001C7E<M00@000=C7@03001C
7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@06001C
7@00001C7@0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad01000
0e<M00<005<MDad010000U<M00<005<MDad00`0015<M00H005<M000005<M0002Dad40003Dad00`00
DaeC7@04000FOol00`00Oomoo`0:Ool003Uoo`03001oogoo03ioo`03001Fo5Kl00<000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M008000AC7@06001C7@00001C7@00
0e<M0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00P0015<M0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M
00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00P0015<M00H005<M000005<M0003
Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC
7@040003Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@0400000goo001oo`0GOol00`00Oomo
o`0:Ool003Yoo`03001oogoo03ioo`8000=GOP03001C7E<M00<000=C7@03001C7E<M00@000=C7@05
001C7@00Dad00004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad00`00Dad00002Dad00`00DaeC7@040003
Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040002
Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C
7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@03001C7@00009C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M
00@0009C7@06001C7@00001C7@0015<M0`001Woo00<007ooOol05Goo00<007ooOol02Woo000kOol2
0010Ool60003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad01000Dad000000U<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<M
Dad00`000e<M00<005<MDad00`000e<M0`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00P0015<M00@005<M0000009C7@03
001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@04001C7@00000:
Ool00`00Oomoo`0EOol00`00Oomoo`09Ool003eoo`03001oogoo03eoo`03001:VdZK009:V`03001C
7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@05001C7@00Dad00004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC
7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad30002Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad0
1P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000aoo`03001oogoo01Eoo`03001oogoo00Uo
o`00?Woo00<007ooOol0?Goo00@004ZKBY]:V`<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0
00=C7@05001C7@00Dad00004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad01000Dad000000U<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<M
Dad00`000e<M00H005<M000005<M0003Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040003
Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
009C7@@000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C
7E<M00@0011oo`03001oogoo01Aoo`03001oogoo00Uoo`00?goo00<007ooOol0?Goo00<004ZK0000
0U/L00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00@005<M0000009C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@03001C7@00
009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
00=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C
7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@001Eoo`03001oogoo01=oo`03001oogoo
00Uoo`00@7oo0P00?Woo00@005/LFaaK70<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C
7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7@00009C7@03001C7E<M00@0
00=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<0
00=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C
7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@04001C7@000002Dad00`00DaeC
7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@04000JOol00`00Oomo
o`0BOol00`00Oomoo`09Ool0049oo`03001oogoo03aoo`03001K700000@0009C7@<000=C7@03001C
7E<M00@0009C7@03001C7E<M00@000=C7@05001C7@00Dad00004Dad30003Dad00`00DaeC7@030003
Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003
Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC
7@040002Dad00`00DaeC7@040002Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C
7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M008000AC
7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@001ioo`03001oogoo
019oo`03001oogoo00Uoo`00@goo00<007ooOol0?7oo00<007oo00000T7G0`000e<M00<005<MDad0
0`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00@005<M0000009C7@03001C7E<M00@0
009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
00=C7@05001C7@00Dad00004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00
DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad01000Dad000000U<M00<005<M
Dad00`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<M
Dad010000U<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@040002Dad00`00DaeC7@04000S
Ool00`00Oomoo`0AOol00`00Oomoo`09Ool004Aoo`03001oogoo03ioo`050011ed7G@ML00002Dad4
0002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad30003Dad00`00
DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00
DaeC7@030003Dad01000Dad000000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000U<M
00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000U<M
00<005<MDad00`0015<M00H005<M000005<M0002Dad40002Dad00`00DaeC7@04000XOol00`00Oomo
o`0@Ool00`00Oomoo`09Ool004Eoo`8003ioo`040011ed7G@ML30003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00Dad00002Dad00`00DaeC7@040003Dad00`00
DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00
DaeC7@020004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040002
Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad0009C7@@000=C7@03001C
7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C
7E<M00<000=C7@<000=C7@03001C7E<M00<002aoo`03001oogoo015oo`03001oogoo00Qoo`00Agoo
00<007ooOol0>goo00@0047G@ML0009SnP03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C
7E<M00<000=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@04001C7@000002Dad0
0`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040002Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad01000Dad00000
0U<M00<005<MDad01000<7oo00<007ooOol047oo00<007ooOol027oo0018Ool00`00Oomoo`0kOol8
0003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00Dad00002
Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002
Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC
7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00Dad0
0002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad3000eOol00`00Oomoo`0?Ool00`00Oomo
o`08Ool004Uoo`03001oogoo03Yoo`80009oo`05000k7c/O>al00002Dad30003Dad00`00DaeC7@03
0003Dad00`00DaeC7@040002Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad01000
Dad000000U<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M0`000e<M00<005<MDad00`000e<M
00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M
00@005<M000003Uoo`03001oogoo00ioo`03001oogoo00Qoo`00BWoo0P00?goo1P000U<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<M00000e<M00<005<MDad0
0`000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad0
10000e<M00<005<MDad00P0015<M0`000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<0
05<MDad00`000e<M00<005<MDad010000U<M00<005<MDad010000U<M00@005<M0000009C7@03001C
7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C
7E<M00@0009C7@03001C7E<M00<003]oo`03001oogoo00ioo`03001oogoo00Qoo`00C7oo00<007oo
Ool0?7oo00<004GFAMH00TGF00<005<MDad00`000e<M00<005<MDad010000U<M00<005<MDad01000
0U<M00<005<MDad00`0015<M0`000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<M
Dad00`000e<M00<005<MDad00`000e<M00<005<MDad010000U<M00@005<M0000009C7@03001C7E<M
00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@03001C7E<M008000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03
001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@003moo`03001oogoo00eoo`03001o
ogoo00Qoo`00CGoo00<007ooOol0>goo00<004GFAMH00dGF0P000e<M00<005<MDad00`000e<M00<0
05<MDad00`000e<M00<005<MDad00`000e<M00@005<M0000009C7@03001C7E<M00<000=C7@03001C
7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C
7E<M00<0009C7@@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C
7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@04001C7@000002Dad00`00DaeC7@030003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030014Ool0
0`00Oomoo`0<Ool00`00Oomoo`08Ool004ioo`03001oogoo03]oo`030015eTGF0095eP80009C7@@0
009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<0009C7@@0009C7@03001C
7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C
7E<M00@0009C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C
7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<0009C7@@0009C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@004Qoo`03001oogoo
00aoo`03001oogoo00Moo`00Cgoo0P00>goo00@004GFAMI5eP800003;GL0000000=C7@03001C7E<M
00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@<000=C7@03001C7E<M00<000=C7@03
001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03
001C7@00009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C
7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@<000=C7@03001C7E<M00<000=C
7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@004aoo`03001oogoo00aoo`03
001oogoo00Moo`00DGoo00<007ooOol0>7oo00H004GFAMH007oo0002;GL00`00DaeC7@040002Dad0
0`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00Dad00002Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00
DaeC7@030003Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002
Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad01000Dad000000U<M00<005<MDad010000U<M
00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad01000DGoo00<007ooOol02goo00<0
07ooOol01goo001BOol00`00Oomoo`0hOol20002Ool00`00;GL]M`030003Dad00`00DaeC7@030003
Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC
7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00Dad0
0002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@040002Dad00`00
DaeC7@040003Dad00`00DaeC7@03001FOol00`00Oomoo`0:Ool00`00Oomoo`07Ool005=oo`03001o
ogoo03Moo`03001oogoo009oo`8000=JN003001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C
7E<M00<000=C7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C
7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<0009C7@@000=C7@03001C7E<M
00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M
00@0009C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00@005Uoo`03
001oogoo00Yoo`03001oogoo00Moo`00E7oo0P00?7oo00<005YhFWP00eYh0P000U<M00<005<MDad0
10000U<M00<005<MDad010000U<M00@005<M0000009C7@03001C7E<M00<000=C7@03001C7E<M00@0
009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0
009C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C
7E<M00@0009C7@03001C7E<M00@000=C7@03001C7@00009C7@03001C7E<M00@0009C7@03001C7E<M
00@0009C7@03001C7E<M00@005ioo`03001oogoo00Uoo`03001oogoo00Moo`00EWoo00<007ooOol0
>Goo00<005YhFWP00UYh00<0034c00000U<M0`000e<M00<005<MDad00`000e<M00<005<MDad00`00
0U<M10000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<M
Dad00`000e<M00<005<MDad00`000e<M00<005<M00000U<M00<005<MDad010000U<M00<005<MDad0
10000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad0
0`000U<M10000U<M00<005<MDad010000U<M00<005<MDad01000Hgoo00<007ooOol027oo00<007oo
Ool01goo001GOol00`00Oomoo`0iOol00`00FWQJN0020002<C<20002Dad00`00DaeC7@040002Dad0
0`00DaeC7@040002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad30003Dad00`00
DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00
DaeC7@040002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@03001XOol00`00Oomoo`08Ool0
0`00Oomoo`06Ool005Qoo`03001oogoo03Qoo`05001JN000Ool00003<C<00`00DaeC7@030003Dad0
0`00DaeC7@030003Dad00`00Dad00003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00
DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad40002
Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030003
Dad00`00DaeC7@030003Dad00`00Dad00002Dad00`00DaeC7@040002Dad00`00DaeC7@04001[Ool0
0`00Oomoo`08Ool00`00Oomoo`06Ool005Uoo`8003Uoo`05001oogooOol00003<C<20002Dad00`00
DaeC7@040003Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@040002Dad00`00DaeC7@040002
Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad30003Dad00`00DaeC
7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC
7@040002Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@04001`Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool005]oo`03001oogoo03Yoo`04000a<c4c<C<20002Dad30003Dad00`00DaeC7@040002
Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC
7@030003Dad00`00DaeC7@030003Dad00`00Dad00002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad30003Dad00`00DaeC7@03001eOol00`00Oomoo`06Ool00`00Oomoo`06Ool005aoo`03001o
ogoo03Uoo`03000a<c4c00D000=C7@03001C7E<M00<0009C7@@0009C7@03001C7E<M00@0009C7@03
001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03
001C7E<M00@0009C7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<0
00=C7@03001C7E<M00<000=C7@03001C7E<M00<0009C7@@0009C7@03001C7E<M00@007Uoo`03001o
ogoo00Eoo`03001oogoo00Ioo`00GGoo00<007ooOol0>7oo00P0034c000007oo000iD`000U<M1000
0U<M0`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<M
Dad00`000e<M00<005<MDad00`000e<M00<005<MDad00`000U<M10000U<M00<005<MDad010000U<M
00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad010000U<M
0`000e<M00<005<MDad00`00OGoo00<007ooOol01Goo00<007ooOol01Woo001NOol2000hOol00`00
<C<00002Ool00`00>E<iD`020003Dad00`00Dad00002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@04
0002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00
DaeC7@030003Dad00`00DaeC7@030003Dad00`00Dad00002Dad00`00DaeC7@040021Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool0061oo`03001oogoo03Eoo`8000=oo`05000iDcUC>E<00002Dad40002
Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC
7@030003Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad0
0`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@030002Dad4
0026Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0065oo`03001oogoo03Aoo`03001oogoo009oo`03
000iDcUC008iD`80009C7@@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M
00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@<000=C7@03001C7E<M00<000=C7@03
001C7E<M00<000=C7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03
001C7E<M00@0009C7@<008Yoo`03001oogoo00Aoo`03001oogoo00Eoo`00HWoo00<007ooOol0>7oo
00<003UC>E<00SUC00@001Bd000000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@03001C
7E<M00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<000=C7@<0009C7@03001C7E<M00@0009C
7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00<000=C7@03001C7E<M00<000=C
7@03001C7E<M00<0009C7@@008ioo`03001oogoo00=oo`03001oogoo00Eoo`00Hgoo0P00>Goo00<0
03UC>E<00P000aBd00<005<MDad00`000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<0
05<MDad010000U<M00<005<MDad010000U<M00@005<M0000009C7@03001C7E<M00<000=C7@03001C
7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C
7E<M00@0009C7@<009=oo`03001oogoo009oo`03001oogoo00Eoo`00IGoo00<007ooOol0=Woo00L0
03UC>E<007oo000D]0040002Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@03
0003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@040002Dad00`00
DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad4002G
Ool01@00Oomoogoo00001goo001VOol00`00Oomoo`0eOol00`00>E<00002Ool20003COD00`00DaeC
7@030003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC
7@040002Dad30003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad0
0`00DaeC7@040002Dad00`00DaeC7@040002Dad3002KOol01@00Oomoogoo00001goo001WOol00`00
Oomoo`0dOol00`00>E<00002Ool00`00COE=m@03COD20002Dad00`00DaeC7@040002Dad00`00DaeC
7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@040002Dad0
0`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad4
002OOol01000Oomoo`001goo001XOol2000dOol00`00>E<00002Ool00`00COE=m@03COD20002Dad3
0003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad30003Dad00`00
DaeC7@030003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00
DaeC7@0400000e<M00000002002TOol00`00Ool00007Ool006Yoo`03001oogoo035oo`8000Aoo`05
001=mDgeCOD00002:=420002Dad00`00DaeC7@040002Dad00`00DaeC7@030003Dad00`00DaeC7@03
0002Dad40002Dad00`00DaeC7@040002Dad00`00DaeC7@040002Dad00`00DaeC7@030003Dad00`00
DaeC7@030003Dad00`00DaeC7@030002Dad3002XOol01000Oomoo`001Woo001[Ool00`00Oomoo`0`
Ool20004Ool01@00COE=mDge00000bSA00<005<MDad00`000e<M00<005<MDad00`000e<M00<005<M
Dad00`000U<M0`000e<M00<005<MDad00`000e<M00<005<MDad00`000U<M00<005<MDad010000U<M
00<005<MDad010000U<M00<005<MDad0100000=C7@0000000P00[7oo00<007oo00001Woo001/Ool0
0`00Oomoo`0_Ool00`00Oomoo`03Ool01P00COE=m@00Ool000<Xd@80009C7@03001C7E<M00@0009C
7@03001C7E<M00@0009C7@<0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M
00<000=C7@03001C7E<M00<000=C7@03001C7E<M00<0009C7@<00;5oo`8000Ioo`00KGoo00<007oo
Ool0=7oo00H004geCOD007oo0003:=420002Dad30002Dad70002Dad40002Dad00`00DaeC7@030003
Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@040002
Dad3002cOol30006Ool006ioo`8003Aoo`06001=mDge001oo`000RSA1@000U<M0`000e<M00<005<M
Dad00`000e<M00<005<MDad00`000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<M
Dad00`000e<M00<005<MDad00`000U<M1000/Woo10002Goo001`Ool00`00Oomoo`0bOol20002Ool0
1P00:=4Xd@00Ool0008e4P80009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C7E<M
00<000=C7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@<00;9oo`@0
00eoo`00LGoo00<007ooOol0<Goo0P000Woo00H002SA:=4007oo0003=A800`00DaeC7@030003Dad0
0`00DaeC7@030003Dad00`00DaeC7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@030003Dad0
0`00DaeC7@030002Dad4002bOol3000AOol0079oo`03001oogoo031oo`07001oogooOol002SA0000
0Woo00<003DB=A800SDB0P000U<M00<005<MDad010000U<M00<005<MDad010000U<M00<005<MDad0
0`000e<M00<005<MDad00`000U<M1`000U<M0`00/Woo100057oo001cOol2000dOol00`00:=400002
Ool00`00=A8e4P02=A820002Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@030002Dad00`00
DaeC7@040002Dad30002Dad00`00DaeC7@04002aOol4000HOol007Eoo`03001oogoo035oo`03000X
d@00009oo`03000e4SDB008e4P@0009C7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@03001C
7E<M00<0009C7@@0009C7@03001C7E<M00<00;5oo`@001aoo`00MWoo00<007ooOol0<7oo0P000goo
00T003DB=A8e4P00Ool000``00000U<M0`000e<M00<005<MDad00`000U<M00<005<MDad010000U<M
0`000e<M00<005<MDad00`00/7oo100087oo001gOol00`00Oomoo`0_Ool20003Ool02000=A8e4SDB
001oo`0033030002Dad00`00DaeC7@040002Dad00`00DaeC7@030002Dad40002Dad00`00DaeC7@04
002_Ool4000TOol007Qoo`8002moo`8000Aoo`05000e4SDB001oo`020002CK<00`00DaeC7@030002
Dad70002Dad30003Dad00`00DaeC7@03002_Ool4000XOol007Yoo`03001oogoo02aoo`03001oogoo
00=oo`06000e4SDB001oo`0014fc0P000U<M0`000e<M00<005<MDad00`000U<M00<005<MDad01000
[goo0`00;7oo001kOol00`00Oomoo`0aOol01P00=A8e4P00Ool000A=/`04000`l@000002Dad00`00
DaeC7@040002Dad00`00DaeC7@03002_Ool4000_Ool007aoo`03001oogoo031oo`03000e4P00009o
o`03001=/dfc009=/`04000`lC3a0002Dad30003Dad00`00DaeC7@03002^Ool4000cOol007eoo`80
031oo`03000e4P00009oo`04001=/dfcCK<20003<?420002Dad00`00DaeC7@04002]Ool4000gOol0
07moo`03001oogoo02eoo`03000e4P00009oo`04001=/dfcCK<20003<?420002Dad3002]Ool4000k
Ool0081oo`03001oogoo02aoo`03000e4P00009oo`04001=/dfcCK<20003<?401000Ool00000[7oo
1000?goo0021Ool00`00Oomoo`0[Ool00`00=A800002Ool01000CK==/dfc0P000c3a00<007ooOol0
ZGoo1000@goo0022Ool2000[Ool20003Ool01000CK==/dfc0P000c3a00<007ooOol0YWoo0`00Agoo
0024Ool00`00Oomoo`0XOol20003Ool01P00CK==/`00Ool000<`l@03001oogoo0:9oo`@004Yoo`00
QGoo00<007ooOol09goo0P000goo00<004fcCK<00P000c3a00<007ooOol0Wgoo1000CWoo0026Ool0
0`00Oomoo`0VOol20004Ool01000CK<000000c3a00<007ooOol0Vgoo1000DWoo0027Ool2000VOol2
0004Ool01000CK<000000c3a00<007ooOol0Ugoo1000EWoo0029Ool00`00Oomoo`0SOol00`00Oomo
o`03Ool01000CK<000000c3a00<007ooOol0Tgoo1000FWoo002:Ool00`00Oomoo`0ROol00`00Oomo
o`03Ool200000goo000`l@02<?400`00Oomoo`2?Ool4001NOol008]oo`03001oogoo025oo`03001o
ogoo00=oo`800003Ool0033a008`l@03001oogoo08aoo`<0069oo`00S7oo0P009goo0P0000=oo`00
<?400S3a00<007ooOol0R7oo1000IGoo002>Ool00`00Oomoo`0TOol200000goo000`l@02<?400`00
Oomoo`24Ool4001YOol008moo`03001oogoo02=oo`800003Ool0033a008`l@03001oogoo081oo`@0
06eoo`00T7oo00<007ooOol08Woo00@007ooOol0008`l@03001oogoo07eoo`@0075oo`00TGoo0P00
8Woo00@007ooOol0008`l@03001oogoo07Uoo`@007Eoo`00Tgoo00<007ooOol08Woo00@0033a<?40
07Moo`@007Uoo`00U7oo00<007ooOol08Goo00@0033a<?4007Aoo`<007eoo`00UGoo00<007ooOol0
87oo00@0033a<?40071oo`@0081oo`00UWoo0P0087oo00@0033a<?4006aoo`@008Aoo`00V7oo00<0
07ooOol07Goo00@0033a<?4006Qoo`@008Qoo`00VGoo00<007ooOol077oo00@0033a<?4006Aoo`@0
08aoo`00VWoo00<007ooOol06goo00@0033a<?40061oo`@0091oo`00Vgoo0P006goo00@0033a0000
05aoo`@009Aoo`00WGoo00<007ooOol067oo00@0033a000005Uoo`<009Qoo`00WWoo00<007ooOol0
5goo00@0033a000005Eoo`@009]oo`00Wgoo00<007ooOol05Woo00@0033a0000055oo`@009moo`00
X7oo00<007ooOol05Goo00@0033a000004eoo`@00:=oo`00XGoo0P005Goo00@0033a000004Uoo`@0
0:Moo`00Xgoo00<007ooOol04Woo00@0033a000004Eoo`@00:]oo`00Y7oo00<007ooOol04Goo00@0
033a0000045oo`@00:moo`00YGoo00<007ooOol047oo00@0033a000003ioo`<00;=oo`00YWoo0P00
47oo0P0000=oo`00Ool0>Goo1000]Woo002XOol00`00Oomoo`0=Ool200000goo001oo`0eOol4002j
Ool00:Uoo`03001oogoo00aoo`800003Ool007oo035oo`@00;ioo`00ZWoo00<007ooOol02goo0`00
;goo1000`Woo002[Ool2000;Ool3000[Ool40036Ool00:eoo`03001oogoo00Qoo`<002Moo`@00<Yo
o`00[Woo00<007ooOol01goo0`0097oo0`00cWoo002_Ool00`00Oomoo`06Ool3000POol4003AOol0
0;1oo`8000Ioo`<001aoo`@00=Eoo`00/Woo00<007ooOol00goo00<007oo000067oo1000fGoo002c
Ool00`00Oomoo`02Ool00`00Ool0000DOol4003MOol00;Aoo`07001oogooOol007oo000047oo1000
hGoo002eOol2000017oo001oo`0037oo1000iGoo002gOol200000goo001oo`08Ool3003YOol00;Qo
o`03001oo`0000Eoo`@00>aoo`00^Goo0P0000=oo`0000000P00l7oo002jOol2003dOol00?mook5o
o`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000
\
\>"],
   ImageRangeCache->{{{0, 431}, {349.312, 0}} -> {-0.0680253, 0.0199243,
   0.00359389, 0.00359389}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
     \(\(Filtdata = Fourier[FiltFdata]; \)\)], "Input"],

Cell[BoxData[
     \(General::"spell1" \( : \ \)
       "Possible spelling error: new symbol name \"\!\(Filtdata\)\" is similar \
to existing symbol \"\!\(FiltFdata\)\"."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
     \(ListPlot3D[Re[Filtdata], {PlotRange \[Rule] All}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.2083 .17506 -11.6698 -9 ]
[.2083 .17506 .33019 0 ]
[.41321 .09446 -10.8756 -9 ]
[.41321 .09446 1.12444 0 ]
[.63499 .00731 -10.0813 -9 ]
[.63499 .00731 1.9187 0 ]
[.79894 .14525 0 -6.11522 ]
[.79894 .14525 12 2.88478 ]
[.88874 .28276 0 -5.98496 ]
[.88874 .28276 12 3.01504 ]
[.96735 .40315 0 -5.87414 ]
[.96735 .40315 12 3.12586 ]
[.02373 .26749 -24 -2.74433 ]
[.02373 .26749 0 6.25567 ]
[.01282 .3359 -18 -2.80221 ]
[.01282 .3359 0 6.19779 ]
[.00141 .40742 -6 -2.86298 ]
[.00141 .40742 0 6.13702 ]
[-0.01053 .48226 -12 -2.92688 ]
[-0.01053 .48226 0 6.07312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78659 .14969 m
.78042 .1519 L
s
[(20)] .79894 .14525 -1 .35894 Mshowa
.87628 .28687 m
.87005 .28893 L
s
[(40)] .88874 .28276 -1 .32999 Mshowa
.9548 .40699 m
.94853 .4089 L
s
[(60)] .96735 .40315 -1 .30537 Mshowa
.125 Mabswid
.7105 .03329 m
.70682 .0347 L
s
.7368 .07352 m
.73311 .0749 L
s
.76215 .11229 m
.75845 .11365 L
s
.81019 .18578 m
.80647 .18708 L
s
.83297 .22063 m
.82925 .22191 L
s
.85499 .25431 m
.85126 .25557 L
s
.89687 .31837 m
.89312 .31958 L
s
.9168 .34886 m
.91305 .35005 L
s
.9361 .37838 m
.93234 .37955 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03596 .26272 m
.04207 .26034 L
s
[(-100)] .02373 .26749 1 -0.39015 Mshowa
.0251 .33127 m
.03123 .32895 L
s
[(-50)] .01282 .3359 1 -0.37729 Mshowa
.01374 .40293 m
.0199 .40069 L
s
[(0)] .00141 .40742 1 -0.36378 Mshowa
.00185 .47793 m
.00805 .47576 L
s
[(50)] -0.01053 .48226 1 -0.34958 Mshowa
.125 Mabswid
.03382 .27619 m
.03749 .27477 L
s
.03167 .28978 m
.03534 .28837 L
s
.0295 .30349 m
.03317 .30208 L
s
.02731 .31732 m
.03099 .31592 L
s
.02286 .34535 m
.02655 .34397 L
s
.02061 .35955 m
.0243 .35818 L
s
.01834 .37388 m
.02204 .37252 L
s
.01605 .38834 m
.01975 .38699 L
s
.01141 .41766 m
.01511 .41632 L
s
.00905 .43252 m
.01276 .43119 L
s
.00667 .44751 m
.01038 .4462 L
s
.00428 .46265 m
.00799 .46134 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.654 .752 .922 r
.39586 .72057 .40088 .72493 .40929 .72259 .40429 .71822 Metetra
.654 .752 .922 r
.40429 .71822 .40929 .72259 .41773 .72025 .41274 .71587 Metetra
.654 .752 .922 r
.41274 .71587 .41773 .72025 .42619 .7179 .42122 .71351 Metetra
.654 .752 .922 r
.42122 .71351 .42619 .7179 .43468 .71554 .42972 .71114 Metetra
.654 .752 .922 r
.42972 .71114 .43468 .71554 .44319 .71318 .43825 .70876 Metetra
.654 .752 .922 r
.43825 .70876 .44319 .71318 .45173 .71081 .44681 .70637 Metetra
.654 .752 .922 r
.44681 .70637 .45173 .71081 .4603 .70843 .4554 .70398 Metetra
.654 .752 .922 r
.4554 .70398 .4603 .70843 .4689 .70604 .46401 .70158 Metetra
.654 .752 .922 r
.46401 .70158 .4689 .70604 .47752 .70365 .47265 .69917 Metetra
.654 .752 .922 r
.47265 .69917 .47752 .70365 .48617 .70124 .48132 .69675 Metetra
.654 .752 .922 r
.48132 .69675 .48617 .70124 .49485 .69883 .49001 .69433 Metetra
.654 .752 .922 r
.49001 .69433 .49485 .69883 .50355 .69642 .49873 .6919 Metetra
.654 .752 .922 r
.49873 .6919 .50355 .69642 .51228 .69399 .50748 .68946 Metetra
.654 .752 .922 r
.50748 .68946 .51228 .69399 .52105 .69156 .51626 .68701 Metetra
.654 .752 .922 r
.51626 .68701 .52105 .69156 .52983 .68912 .52507 .68456 Metetra
.654 .752 .922 r
.52507 .68456 .52983 .68912 .53865 .68667 .53391 .68209 Metetra
.654 .752 .922 r
.53391 .68209 .53865 .68667 .5475 .68421 .54277 .67962 Metetra
.654 .752 .922 r
.54277 .67962 .5475 .68421 .55637 .68175 .55166 .67714 Metetra
.654 .752 .922 r
.55166 .67714 .55637 .68175 .56527 .67928 .56058 .67466 Metetra
.654 .752 .922 r
.56058 .67466 .56527 .67928 .5742 .6768 .56953 .67216 Metetra
.654 .752 .922 r
.56953 .67216 .5742 .6768 .58316 .67431 .57851 .66966 Metetra
.654 .752 .922 r
.57851 .66966 .58316 .67431 .59215 .67181 .58752 .66715 Metetra
.654 .752 .922 r
.58752 .66715 .59215 .67181 .60117 .66931 .59656 .66463 Metetra
.654 .752 .922 r
.59656 .66463 .60117 .66931 .61022 .6668 .60562 .6621 Metetra
.654 .752 .922 r
.60562 .6621 .61022 .6668 .61929 .66428 .61472 .65957 Metetra
.654 .752 .922 r
.61472 .65957 .61929 .66428 .6284 .66175 .62385 .65702 Metetra
.654 .752 .922 r
.62385 .65702 .6284 .66175 .63753 .65921 .633 .65447 Metetra
.654 .752 .922 r
.633 .65447 .63753 .65921 .6467 .65667 .64219 .65191 Metetra
.654 .752 .922 r
.64219 .65191 .6467 .65667 .6559 .65411 .6514 .64934 Metetra
.654 .752 .922 r
.6514 .64934 .6559 .65411 .66512 .65155 .66065 .64676 Metetra
.654 .752 .922 r
.66065 .64676 .66512 .65155 .67438 .64898 .66993 .64418 Metetra
.654 .752 .922 r
.66993 .64418 .67438 .64898 .68366 .6464 .67923 .64158 Metetra
.654 .752 .922 r
.67923 .64158 .68366 .6464 .69298 .64382 .68857 .63898 Metetra
.654 .752 .922 r
.68857 .63898 .69298 .64382 .70233 .64122 .69794 .63637 Metetra
.654 .752 .922 r
.69794 .63637 .70233 .64122 .71171 .63862 .70734 .63375 Metetra
.654 .752 .922 r
.70734 .63375 .71171 .63862 .72112 .636 .71677 .63112 Metetra
.654 .752 .922 r
.71677 .63112 .72112 .636 .73056 .63338 .72623 .62848 Metetra
.654 .752 .922 r
.72623 .62848 .73056 .63338 .74003 .63075 .73573 .62583 Metetra
.654 .752 .922 r
.73573 .62583 .74003 .63075 .74953 .62811 .74525 .62318 Metetra
.654 .752 .922 r
.74525 .62318 .74953 .62811 .75907 .62546 .75481 .62051 Metetra
.654 .752 .922 r
.75481 .62051 .75907 .62546 .76864 .62281 .7644 .61784 Metetra
.654 .752 .922 r
.7644 .61784 .76864 .62281 .77823 .62014 .77402 .61516 Metetra
.654 .752 .922 r
.77402 .61516 .77823 .62014 .78787 .61747 .78368 .61247 Metetra
.654 .752 .922 r
.78368 .61247 .78787 .61747 .79753 .61478 .79336 .60977 Metetra
.654 .752 .922 r
.79336 .60977 .79753 .61478 .80723 .61209 .80308 .60706 Metetra
.654 .752 .922 r
.80308 .60706 .80723 .61209 .81695 .60939 .81283 .60434 Metetra
.654 .752 .922 r
.81283 .60434 .81695 .60939 .82672 .60668 .82262 .60161 Metetra
.654 .752 .922 r
.82262 .60161 .82672 .60668 .83651 .60396 .83244 .59888 Metetra
.654 .752 .922 r
.83244 .59888 .83651 .60396 .84634 .60123 .84229 .59613 Metetra
.654 .752 .922 r
.84229 .59613 .84634 .60123 .8562 .59849 .85217 .59337 Metetra
.654 .752 .922 r
.85217 .59337 .8562 .59849 .86609 .59574 .86209 .59061 Metetra
.654 .752 .922 r
.86209 .59061 .86609 .59574 .87602 .59299 .87204 .58783 Metetra
.654 .752 .922 r
.87204 .58783 .87602 .59299 .88598 .59022 .88203 .58505 Metetra
.654 .752 .922 r
.88203 .58505 .88598 .59022 .89598 .58745 .89205 .58226 Metetra
.654 .752 .922 r
.89205 .58226 .89598 .58745 .90601 .58466 .9021 .57945 Metetra
.654 .752 .922 r
.9021 .57945 .90601 .58466 .91607 .58187 .91219 .57664 Metetra
.654 .752 .922 r
.91219 .57664 .91607 .58187 .92617 .57906 .92232 .57382 Metetra
.654 .752 .922 r
.92232 .57382 .92617 .57906 .9363 .57625 .93248 .57099 Metetra
.654 .752 .922 r
.93248 .57099 .9363 .57625 .94647 .57342 .94267 .56815 Metetra
.654 .752 .922 r
.94267 .56815 .94647 .57342 .95668 .57059 .9529 .5653 Metetra
.654 .752 .922 r
.9529 .5653 .95668 .57059 .96691 .56775 .96316 .56243 Metetra
.654 .752 .922 r
.96316 .56243 .96691 .56775 .97719 .56489 .97346 .55956 Metetra
.654 .752 .922 r
.97346 .55956 .97719 .56489 .9875 .56203 .9838 .55668 Metetra
.654 .75 .92 r
.39081 .71614 .39586 .72057 .40429 .71822 .39925 .71378 Metetra
.654 .75 .92 r
.39925 .71378 .40429 .71822 .41274 .71587 .40772 .71141 Metetra
.654 .75 .92 r
.40772 .71141 .41274 .71587 .42122 .71351 .41622 .70904 Metetra
.654 .75 .92 r
.41622 .70904 .42122 .71351 .42972 .71114 .42474 .70665 Metetra
.654 .75 .92 r
.42474 .70665 .42972 .71114 .43825 .70876 .43328 .70426 Metetra
.654 .75 .92 r
.43328 .70426 .43825 .70876 .44681 .70637 .44186 .70186 Metetra
.654 .75 .92 r
.44186 .70186 .44681 .70637 .4554 .70398 .45046 .69945 Metetra
.654 .75 .92 r
.45046 .69945 .4554 .70398 .46401 .70158 .45909 .69704 Metetra
.654 .75 .92 r
.45909 .69704 .46401 .70158 .47265 .69917 .46775 .69461 Metetra
.654 .75 .92 r
.46775 .69461 .47265 .69917 .48132 .69675 .47643 .69218 Metetra
.654 .75 .92 r
.47643 .69218 .48132 .69675 .49001 .69433 .48515 .68975 Metetra
.654 .75 .92 r
.48515 .68975 .49001 .69433 .49873 .6919 .49389 .6873 Metetra
.654 .75 .92 r
.49389 .6873 .49873 .6919 .50748 .68946 .50266 .68485 Metetra
.654 .75 .92 r
.50266 .68485 .50748 .68946 .51626 .68701 .51145 .68238 Metetra
.654 .75 .92 r
.51145 .68238 .51626 .68701 .52507 .68456 .52028 .67991 Metetra
.654 .75 .92 r
.52028 .67991 .52507 .68456 .53391 .68209 .52913 .67744 Metetra
.654 .75 .92 r
.52913 .67744 .53391 .68209 .54277 .67962 .53802 .67495 Metetra
.654 .75 .92 r
.53802 .67495 .54277 .67962 .55166 .67714 .54693 .67246 Metetra
.654 .75 .92 r
.54693 .67246 .55166 .67714 .56058 .67466 .55587 .66996 Metetra
.654 .75 .92 r
.55587 .66996 .56058 .67466 .56953 .67216 .56483 .66745 Metetra
.654 .75 .92 r
.56483 .66745 .56953 .67216 .57851 .66966 .57383 .66493 Metetra
.654 .75 .92 r
.57383 .66493 .57851 .66966 .58752 .66715 .58286 .6624 Metetra
.654 .75 .92 r
.58286 .6624 .58752 .66715 .59656 .66463 .59192 .65987 Metetra
.654 .75 .92 r
.59192 .65987 .59656 .66463 .60562 .6621 .601 .65732 Metetra
.654 .75 .92 r
.601 .65732 .60562 .6621 .61472 .65957 .61012 .65477 Metetra
.654 .75 .92 r
.61012 .65477 .61472 .65957 .62385 .65702 .61926 .65221 Metetra
.654 .75 .92 r
.61926 .65221 .62385 .65702 .633 .65447 .62844 .64965 Metetra
.654 .75 .92 r
.62844 .64965 .633 .65447 .64219 .65191 .63765 .64707 Metetra
.654 .75 .92 r
.63765 .64707 .64219 .65191 .6514 .64934 .64688 .64448 Metetra
.654 .75 .92 r
.64688 .64448 .6514 .64934 .66065 .64676 .65615 .64189 Metetra
.654 .75 .92 r
.65615 .64189 .66065 .64676 .66993 .64418 .66545 .63929 Metetra
.654 .75 .92 r
.66545 .63929 .66993 .64418 .67923 .64158 .67477 .63668 Metetra
.654 .75 .92 r
.67477 .63668 .67923 .64158 .68857 .63898 .68413 .63406 Metetra
.654 .75 .92 r
.68413 .63406 .68857 .63898 .69794 .63637 .69352 .63143 Metetra
.654 .75 .92 r
.69352 .63143 .69794 .63637 .70734 .63375 .70294 .6288 Metetra
.654 .75 .92 r
.70294 .6288 .70734 .63375 .71677 .63112 .7124 .62615 Metetra
.654 .75 .92 r
.7124 .62615 .71677 .63112 .72623 .62848 .72188 .6235 Metetra
.654 .75 .92 r
.72188 .6235 .72623 .62848 .73573 .62583 .7314 .62083 Metetra
.654 .75 .92 r
.7314 .62083 .73573 .62583 .74525 .62318 .74094 .61816 Metetra
.654 .75 .92 r
.74094 .61816 .74525 .62318 .75481 .62051 .75052 .61548 Metetra
.654 .75 .92 r
.75052 .61548 .75481 .62051 .7644 .61784 .76014 .61279 Metetra
.654 .75 .92 r
.76014 .61279 .7644 .61784 .77402 .61516 .76978 .61009 Metetra
.654 .75 .92 r
.76978 .61009 .77402 .61516 .78368 .61247 .77946 .60738 Metetra
.654 .75 .92 r
.77946 .60738 .78368 .61247 .79336 .60977 .78916 .60467 Metetra
.654 .75 .92 r
.78916 .60467 .79336 .60977 .80308 .60706 .79891 .60194 Metetra
.654 .75 .92 r
.79891 .60194 .80308 .60706 .81283 .60434 .80868 .59921 Metetra
.654 .75 .92 r
.80868 .59921 .81283 .60434 .82262 .60161 .81849 .59646 Metetra
.654 .75 .92 r
.81849 .59646 .82262 .60161 .83244 .59888 .82833 .59371 Metetra
.654 .75 .92 r
.82833 .59371 .83244 .59888 .84229 .59613 .83821 .59094 Metetra
.654 .75 .92 r
.83821 .59094 .84229 .59613 .85217 .59337 .84812 .58817 Metetra
.654 .75 .92 r
.84812 .58817 .85217 .59337 .86209 .59061 .85806 .58539 Metetra
.654 .75 .92 r
.85806 .58539 .86209 .59061 .87204 .58783 .86803 .5826 Metetra
.654 .75 .92 r
.86803 .5826 .87204 .58783 .88203 .58505 .87805 .5798 Metetra
.654 .75 .92 r
.87805 .5798 .88203 .58505 .89205 .58226 .88809 .57698 Metetra
.654 .75 .92 r
.88809 .57698 .89205 .58226 .9021 .57945 .89817 .57416 Metetra
.654 .75 .92 r
.89817 .57416 .9021 .57945 .91219 .57664 .90828 .57133 Metetra
.654 .75 .92 r
.90828 .57133 .91219 .57664 .92232 .57382 .91843 .56849 Metetra
.654 .75 .92 r
.91843 .56849 .92232 .57382 .93248 .57099 .92862 .56564 Metetra
.654 .75 .92 r
.92862 .56564 .93248 .57099 .94267 .56815 .93884 .56278 Metetra
.654 .75 .92 r
.93884 .56278 .94267 .56815 .9529 .5653 .94909 .55991 Metetra
.654 .75 .92 r
.94909 .55991 .9529 .5653 .96316 .56243 .95938 .55703 Metetra
.654 .75 .92 r
.95938 .55703 .96316 .56243 .97346 .55956 .96971 .55414 Metetra
.654 .75 .92 r
.96971 .55414 .97346 .55956 .9838 .55668 .98007 .55124 Metetra
.654 .751 .921 r
.38573 .7117 .39081 .71614 .39925 .71378 .39419 .70932 Metetra
.654 .751 .921 r
.39419 .70932 .39925 .71378 .40772 .71141 .40267 .70694 Metetra
.654 .751 .921 r
.40267 .70694 .40772 .71141 .41622 .70904 .41118 .70455 Metetra
.654 .751 .921 r
.41118 .70455 .41622 .70904 .42474 .70665 .41972 .70215 Metetra
.654 .751 .921 r
.41972 .70215 .42474 .70665 .43328 .70426 .42829 .69974 Metetra
.654 .751 .921 r
.42829 .69974 .43328 .70426 .44186 .70186 .43688 .69733 Metetra
.654 .751 .921 r
.43688 .69733 .44186 .70186 .45046 .69945 .4455 .69491 Metetra
.654 .751 .921 r
.4455 .69491 .45046 .69945 .45909 .69704 .45415 .69248 Metetra
.654 .751 .921 r
.45415 .69248 .45909 .69704 .46775 .69461 .46282 .69004 Metetra
.654 .751 .921 r
.46282 .69004 .46775 .69461 .47643 .69218 .47152 .6876 Metetra
.654 .751 .921 r
.47152 .6876 .47643 .69218 .48515 .68975 .48026 .68514 Metetra
.654 .751 .921 r
.48026 .68514 .48515 .68975 .49389 .6873 .48901 .68268 Metetra
.654 .751 .921 r
.48901 .68268 .49389 .6873 .50266 .68485 .4978 .68022 Metetra
.654 .751 .921 r
.4978 .68022 .50266 .68485 .51145 .68238 .50662 .67774 Metetra
.654 .751 .921 r
.50662 .67774 .51145 .68238 .52028 .67991 .51546 .67525 Metetra
.654 .751 .921 r
.51546 .67525 .52028 .67991 .52913 .67744 .52433 .67276 Metetra
.654 .751 .921 r
.52433 .67276 .52913 .67744 .53802 .67495 .53323 .67026 Metetra
.654 .751 .921 r
.53323 .67026 .53802 .67495 .54693 .67246 .54216 .66775 Metetra
.654 .751 .921 r
.54216 .66775 .54693 .67246 .55587 .66996 .55112 .66524 Metetra
.654 .751 .921 r
.55112 .66524 .55587 .66996 .56483 .66745 .56011 .66271 Metetra
.654 .751 .921 r
.56011 .66271 .56483 .66745 .57383 .66493 .56913 .66018 Metetra
.654 .751 .921 r
.56913 .66018 .57383 .66493 .58286 .6624 .57817 .65764 Metetra
.654 .751 .921 r
.57817 .65764 .58286 .6624 .59192 .65987 .58725 .65509 Metetra
.654 .751 .921 r
.58725 .65509 .59192 .65987 .601 .65732 .59635 .65253 Metetra
.654 .751 .921 r
.59635 .65253 .601 .65732 .61012 .65477 .60549 .64996 Metetra
.654 .751 .921 r
.60549 .64996 .61012 .65477 .61926 .65221 .61466 .64739 Metetra
.654 .751 .921 r
.61466 .64739 .61926 .65221 .62844 .64965 .62385 .6448 Metetra
.654 .751 .921 r
.62385 .6448 .62844 .64965 .63765 .64707 .63308 .64221 Metetra
.654 .751 .921 r
.63308 .64221 .63765 .64707 .64688 .64448 .64233 .63961 Metetra
.654 .751 .921 r
.64233 .63961 .64688 .64448 .65615 .64189 .65162 .637 Metetra
.654 .751 .921 r
.65162 .637 .65615 .64189 .66545 .63929 .66094 .63438 Metetra
.654 .751 .921 r
.66094 .63438 .66545 .63929 .67477 .63668 .67029 .63176 Metetra
.654 .751 .921 r
.67029 .63176 .67477 .63668 .68413 .63406 .67967 .62912 Metetra
.654 .751 .921 r
.67967 .62912 .68413 .63406 .69352 .63143 .68908 .62648 Metetra
.654 .751 .921 r
.68908 .62648 .69352 .63143 .70294 .6288 .69852 .62383 Metetra
.654 .751 .921 r
.69852 .62383 .70294 .6288 .7124 .62615 .708 .62116 Metetra
.654 .751 .921 r
.708 .62116 .7124 .62615 .72188 .6235 .7175 .61849 Metetra
.654 .751 .921 r
.7175 .61849 .72188 .6235 .7314 .62083 .72704 .61581 Metetra
.654 .751 .921 r
.72704 .61581 .7314 .62083 .74094 .61816 .73661 .61313 Metetra
.654 .751 .921 r
.73661 .61313 .74094 .61816 .75052 .61548 .74621 .61043 Metetra
.654 .751 .921 r
.74621 .61043 .75052 .61548 .76014 .61279 .75584 .60772 Metetra
.654 .751 .921 r
.75584 .60772 .76014 .61279 .76978 .61009 .76551 .60501 Metetra
.654 .751 .921 r
.76551 .60501 .76978 .61009 .77946 .60738 .77521 .60228 Metetra
.654 .751 .921 r
.77521 .60228 .77946 .60738 .78916 .60467 .78494 .59955 Metetra
.654 .751 .921 r
.78494 .59955 .78916 .60467 .79891 .60194 .79471 .5968 Metetra
.654 .751 .921 r
.79471 .5968 .79891 .60194 .80868 .59921 .80451 .59405 Metetra
.654 .751 .921 r
.80451 .59405 .80868 .59921 .81849 .59646 .81434 .59129 Metetra
.654 .751 .921 r
.81434 .59129 .81849 .59646 .82833 .59371 .8242 .58852 Metetra
.654 .751 .921 r
.8242 .58852 .82833 .59371 .83821 .59094 .8341 .58574 Metetra
.654 .751 .921 r
.8341 .58574 .83821 .59094 .84812 .58817 .84403 .58294 Metetra
.654 .751 .921 r
.84403 .58294 .84812 .58817 .85806 .58539 .854 .58014 Metetra
.654 .751 .921 r
.854 .58014 .85806 .58539 .86803 .5826 .864 .57734 Metetra
.654 .751 .921 r
.864 .57734 .86803 .5826 .87805 .5798 .87404 .57452 Metetra
.654 .751 .921 r
.87404 .57452 .87805 .5798 .88809 .57698 .88411 .57169 Metetra
.654 .751 .921 r
.88411 .57169 .88809 .57698 .89817 .57416 .89421 .56885 Metetra
.654 .751 .921 r
.89421 .56885 .89817 .57416 .90828 .57133 .90435 .566 Metetra
.654 .751 .921 r
.90435 .566 .90828 .57133 .91843 .56849 .91453 .56314 Metetra
.654 .751 .921 r
.91453 .56314 .91843 .56849 .92862 .56564 .92474 .56027 Metetra
.654 .751 .921 r
.92474 .56027 .92862 .56564 .93884 .56278 .93498 .55739 Metetra
.654 .751 .921 r
.93498 .55739 .93884 .56278 .94909 .55991 .94526 .55451 Metetra
.654 .751 .921 r
.94526 .55451 .94909 .55991 .95938 .55703 .95558 .55161 Metetra
.654 .751 .921 r
.95558 .55161 .95938 .55703 .96971 .55414 .96593 .5487 Metetra
.654 .751 .921 r
.96593 .5487 .96971 .55414 .98007 .55124 .97632 .54578 Metetra
.654 .747 .918 r
.38063 .70715 .38573 .7117 .39419 .70932 .3891 .70476 Metetra
.654 .747 .918 r
.3891 .70476 .39419 .70932 .40267 .70694 .3976 .70236 Metetra
.654 .747 .918 r
.3976 .70236 .40267 .70694 .41118 .70455 .40613 .69996 Metetra
.654 .747 .918 r
.40613 .69996 .41118 .70455 .41972 .70215 .41468 .69755 Metetra
.654 .747 .918 r
.41468 .69755 .41972 .70215 .42829 .69974 .42326 .69513 Metetra
.654 .747 .918 r
.42326 .69513 .42829 .69974 .43688 .69733 .43187 .6927 Metetra
.654 .747 .918 r
.43187 .6927 .43688 .69733 .4455 .69491 .44051 .69026 Metetra
.654 .747 .918 r
.44051 .69026 .4455 .69491 .45415 .69248 .44918 .68782 Metetra
.654 .747 .918 r
.44918 .68782 .45415 .69248 .46282 .69004 .45787 .68537 Metetra
.654 .747 .918 r
.45787 .68537 .46282 .69004 .47152 .6876 .46659 .68291 Metetra
.654 .747 .918 r
.46659 .68291 .47152 .6876 .48026 .68514 .47534 .68044 Metetra
.654 .747 .918 r
.47534 .68044 .48026 .68514 .48901 .68268 .48411 .67796 Metetra
.654 .747 .918 r
.48411 .67796 .48901 .68268 .4978 .68022 .49292 .67548 Metetra
.654 .747 .918 r
.49292 .67548 .4978 .68022 .50662 .67774 .50175 .67299 Metetra
.654 .747 .918 r
.50175 .67299 .50662 .67774 .51546 .67525 .51061 .67049 Metetra
.654 .747 .918 r
.51061 .67049 .51546 .67525 .52433 .67276 .5195 .66798 Metetra
.654 .747 .918 r
.5195 .66798 .52433 .67276 .53323 .67026 .52842 .66547 Metetra
.654 .747 .918 r
.52842 .66547 .53323 .67026 .54216 .66775 .53737 .66294 Metetra
.654 .747 .918 r
.53737 .66294 .54216 .66775 .55112 .66524 .54635 .66041 Metetra
.654 .747 .918 r
.54635 .66041 .55112 .66524 .56011 .66271 .55535 .65787 Metetra
.654 .747 .918 r
.55535 .65787 .56011 .66271 .56913 .66018 .56439 .65532 Metetra
.654 .747 .918 r
.56439 .65532 .56913 .66018 .57817 .65764 .57345 .65276 Metetra
.654 .747 .918 r
.57345 .65276 .57817 .65764 .58725 .65509 .58255 .6502 Metetra
.654 .747 .918 r
.58255 .6502 .58725 .65509 .59635 .65253 .59168 .64762 Metetra
.654 .747 .918 r
.59168 .64762 .59635 .65253 .60549 .64996 .60083 .64504 Metetra
.654 .747 .918 r
.60083 .64504 .60549 .64996 .61466 .64739 .61002 .64245 Metetra
.654 .747 .918 r
.61002 .64245 .61466 .64739 .62385 .6448 .61923 .63985 Metetra
.654 .747 .918 r
.61923 .63985 .62385 .6448 .63308 .64221 .62848 .63724 Metetra
.654 .747 .918 r
.62848 .63724 .63308 .64221 .64233 .63961 .63776 .63463 Metetra
.654 .747 .918 r
.63776 .63463 .64233 .63961 .65162 .637 .64706 .632 Metetra
.654 .747 .918 r
.64706 .632 .65162 .637 .66094 .63438 .6564 .62937 Metetra
.654 .747 .918 r
.6564 .62937 .66094 .63438 .67029 .63176 .66577 .62673 Metetra
.654 .747 .918 r
.66577 .62673 .67029 .63176 .67967 .62912 .67517 .62407 Metetra
.654 .747 .918 r
.67517 .62407 .67967 .62912 .68908 .62648 .6846 .62141 Metetra
.654 .747 .918 r
.6846 .62141 .68908 .62648 .69852 .62383 .69407 .61874 Metetra
.654 .747 .918 r
.69407 .61874 .69852 .62383 .708 .62116 .70356 .61607 Metetra
.654 .747 .918 r
.70356 .61607 .708 .62116 .7175 .61849 .71309 .61338 Metetra
.654 .747 .918 r
.71309 .61338 .7175 .61849 .72704 .61581 .72265 .61068 Metetra
.654 .747 .918 r
.72265 .61068 .72704 .61581 .73661 .61313 .73224 .60798 Metetra
.654 .747 .918 r
.73224 .60798 .73661 .61313 .74621 .61043 .74187 .60526 Metetra
.654 .747 .918 r
.74187 .60526 .74621 .61043 .75584 .60772 .75152 .60254 Metetra
.654 .747 .918 r
.75152 .60254 .75584 .60772 .76551 .60501 .76121 .59981 Metetra
.654 .747 .918 r
.76121 .59981 .76551 .60501 .77521 .60228 .77093 .59706 Metetra
.654 .747 .918 r
.77093 .59706 .77521 .60228 .78494 .59955 .78069 .59431 Metetra
.654 .747 .918 r
.78069 .59431 .78494 .59955 .79471 .5968 .79048 .59155 Metetra
.654 .747 .918 r
.79048 .59155 .79471 .5968 .80451 .59405 .8003 .58878 Metetra
.654 .747 .918 r
.8003 .58878 .80451 .59405 .81434 .59129 .81015 .586 Metetra
.654 .747 .918 r
.81015 .586 .81434 .59129 .8242 .58852 .82004 .58321 Metetra
.654 .747 .918 r
.82004 .58321 .8242 .58852 .8341 .58574 .82996 .58041 Metetra
.654 .747 .918 r
.82996 .58041 .8341 .58574 .84403 .58294 .83992 .57761 Metetra
.654 .747 .918 r
.83992 .57761 .84403 .58294 .854 .58014 .84991 .57479 Metetra
.654 .747 .918 r
.84991 .57479 .854 .58014 .864 .57734 .85994 .57196 Metetra
.654 .747 .918 r
.85994 .57196 .864 .57734 .87404 .57452 .87 .56912 Metetra
.654 .747 .918 r
.87 .56912 .87404 .57452 .88411 .57169 .88009 .56628 Metetra
.654 .747 .918 r
.88009 .56628 .88411 .57169 .89421 .56885 .89022 .56342 Metetra
.654 .747 .918 r
.89022 .56342 .89421 .56885 .90435 .566 .90038 .56055 Metetra
.654 .747 .918 r
.90038 .56055 .90435 .566 .91453 .56314 .91058 .55767 Metetra
.654 .747 .918 r
.91058 .55767 .91453 .56314 .92474 .56027 .92082 .55479 Metetra
.654 .747 .918 r
.92082 .55479 .92474 .56027 .93498 .55739 .93109 .55189 Metetra
.654 .747 .918 r
.93109 .55189 .93498 .55739 .94526 .55451 .9414 .54898 Metetra
.654 .747 .918 r
.9414 .54898 .94526 .55451 .95558 .55161 .95174 .54607 Metetra
.654 .747 .918 r
.95174 .54607 .95558 .55161 .96593 .5487 .96212 .54314 Metetra
.654 .747 .918 r
.96212 .54314 .96593 .5487 .97632 .54578 .97253 .5402 Metetra
.654 .748 .919 r
.37549 .70261 .38063 .70715 .3891 .70476 .38398 .7002 Metetra
.654 .748 .919 r
.38398 .7002 .3891 .70476 .3976 .70236 .3925 .69779 Metetra
.654 .748 .919 r
.3925 .69779 .3976 .70236 .40613 .69996 .40104 .69537 Metetra
.654 .748 .919 r
.40104 .69537 .40613 .69996 .41468 .69755 .40961 .69294 Metetra
.654 .748 .919 r
.40961 .69294 .41468 .69755 .42326 .69513 .41821 .69051 Metetra
.654 .748 .919 r
.41821 .69051 .42326 .69513 .43187 .6927 .42684 .68807 Metetra
.654 .748 .919 r
.42684 .68807 .43187 .6927 .44051 .69026 .43549 .68562 Metetra
.654 .748 .919 r
.43549 .68562 .44051 .69026 .44918 .68782 .44417 .68316 Metetra
.654 .748 .919 r
.44417 .68316 .44918 .68782 .45787 .68537 .45288 .68069 Metetra
.654 .748 .919 r
.45288 .68069 .45787 .68537 .46659 .68291 .46162 .67822 Metetra
.654 .748 .919 r
.46162 .67822 .46659 .68291 .47534 .68044 .47039 .67573 Metetra
.654 .748 .919 r
.47039 .67573 .47534 .68044 .48411 .67796 .47918 .67324 Metetra
.654 .748 .919 r
.47918 .67324 .48411 .67796 .49292 .67548 .488 .67075 Metetra
.654 .748 .919 r
.488 .67075 .49292 .67548 .50175 .67299 .49685 .66824 Metetra
.654 .748 .919 r
.49685 .66824 .50175 .67299 .51061 .67049 .50573 .66572 Metetra
.654 .748 .919 r
.50573 .66572 .51061 .67049 .5195 .66798 .51464 .6632 Metetra
.654 .748 .919 r
.51464 .6632 .5195 .66798 .52842 .66547 .52358 .66067 Metetra
.654 .748 .919 r
.52358 .66067 .52842 .66547 .53737 .66294 .53255 .65813 Metetra
.654 .748 .919 r
.53255 .65813 .53737 .66294 .54635 .66041 .54154 .65558 Metetra
.654 .748 .919 r
.54154 .65558 .54635 .66041 .55535 .65787 .55057 .65303 Metetra
.654 .748 .919 r
.55057 .65303 .55535 .65787 .56439 .65532 .55963 .65046 Metetra
.654 .748 .919 r
.55963 .65046 .56439 .65532 .57345 .65276 .56871 .64789 Metetra
.654 .748 .919 r
.56871 .64789 .57345 .65276 .58255 .6502 .57782 .64531 Metetra
.654 .748 .919 r
.57782 .64531 .58255 .6502 .59168 .64762 .58697 .64272 Metetra
.654 .748 .919 r
.58697 .64272 .59168 .64762 .60083 .64504 .59614 .64012 Metetra
.654 .748 .919 r
.59614 .64012 .60083 .64504 .61002 .64245 .60535 .63752 Metetra
.654 .748 .919 r
.60535 .63752 .61002 .64245 .61923 .63985 .61459 .6349 Metetra
.654 .748 .919 r
.61459 .6349 .61923 .63985 .62848 .63724 .62385 .63228 Metetra
.654 .748 .919 r
.62385 .63228 .62848 .63724 .63776 .63463 .63315 .62964 Metetra
.654 .748 .919 r
.63315 .62964 .63776 .63463 .64706 .632 .64248 .627 Metetra
.654 .748 .919 r
.64248 .627 .64706 .632 .6564 .62937 .65184 .62435 Metetra
.654 .748 .919 r
.65184 .62435 .6564 .62937 .66577 .62673 .66123 .62169 Metetra
.654 .748 .919 r
.66123 .62169 .66577 .62673 .67517 .62407 .67065 .61902 Metetra
.654 .748 .919 r
.67065 .61902 .67517 .62407 .6846 .62141 .6801 .61635 Metetra
.654 .748 .919 r
.6801 .61635 .6846 .62141 .69407 .61874 .68959 .61366 Metetra
.654 .748 .919 r
.68959 .61366 .69407 .61874 .70356 .61607 .69911 .61097 Metetra
.654 .748 .919 r
.69911 .61097 .70356 .61607 .71309 .61338 .70865 .60826 Metetra
.654 .748 .919 r
.70865 .60826 .71309 .61338 .72265 .61068 .71824 .60555 Metetra
.654 .748 .919 r
.71824 .60555 .72265 .61068 .73224 .60798 .72785 .60283 Metetra
.654 .748 .919 r
.72785 .60283 .73224 .60798 .74187 .60526 .7375 .6001 Metetra
.654 .748 .919 r
.7375 .6001 .74187 .60526 .75152 .60254 .74717 .59735 Metetra
.654 .748 .919 r
.74717 .59735 .75152 .60254 .76121 .59981 .75689 .5946 Metetra
.654 .748 .919 r
.75689 .5946 .76121 .59981 .77093 .59706 .76663 .59184 Metetra
.654 .748 .919 r
.76663 .59184 .77093 .59706 .78069 .59431 .77641 .58908 Metetra
.654 .748 .919 r
.77641 .58908 .78069 .59431 .79048 .59155 .78622 .5863 Metetra
.654 .748 .919 r
.78622 .5863 .79048 .59155 .8003 .58878 .79606 .58351 Metetra
.654 .748 .919 r
.79606 .58351 .8003 .58878 .81015 .586 .80594 .58071 Metetra
.654 .748 .919 r
.80594 .58071 .81015 .586 .82004 .58321 .81586 .57791 Metetra
.654 .748 .919 r
.81586 .57791 .82004 .58321 .82996 .58041 .8258 .57509 Metetra
.654 .748 .919 r
.8258 .57509 .82996 .58041 .83992 .57761 .83578 .57226 Metetra
.654 .748 .919 r
.83578 .57226 .83992 .57761 .84991 .57479 .8458 .56943 Metetra
.654 .748 .919 r
.8458 .56943 .84991 .57479 .85994 .57196 .85585 .56658 Metetra
.654 .748 .919 r
.85585 .56658 .85994 .57196 .87 .56912 .86593 .56372 Metetra
.654 .748 .919 r
.86593 .56372 .87 .56912 .88009 .56628 .87605 .56086 Metetra
.654 .748 .919 r
.87605 .56086 .88009 .56628 .89022 .56342 .88621 .55798 Metetra
.654 .748 .919 r
.88621 .55798 .89022 .56342 .90038 .56055 .89639 .5551 Metetra
.654 .748 .919 r
.89639 .5551 .90038 .56055 .91058 .55767 .90662 .5522 Metetra
.654 .748 .919 r
.90662 .5522 .91058 .55767 .92082 .55479 .91688 .5493 Metetra
.654 .748 .919 r
.91688 .5493 .92082 .55479 .93109 .55189 .92718 .54638 Metetra
.654 .748 .919 r
.92718 .54638 .93109 .55189 .9414 .54898 .93751 .54346 Metetra
.654 .748 .919 r
.93751 .54346 .9414 .54898 .95174 .54607 .94788 .54052 Metetra
.654 .748 .919 r
.94788 .54052 .95174 .54607 .96212 .54314 .95829 .53757 Metetra
.654 .748 .919 r
.95829 .53757 .96212 .54314 .97253 .5402 .96873 .53462 Metetra
.655 .744 .915 r
.37033 .69792 .37549 .70261 .38398 .7002 .37884 .6955 Metetra
.655 .744 .915 r
.37884 .6955 .38398 .7002 .3925 .69779 .38737 .69308 Metetra
.655 .744 .915 r
.38737 .69308 .3925 .69779 .40104 .69537 .39593 .69064 Metetra
.655 .744 .915 r
.39593 .69064 .40104 .69537 .40961 .69294 .40452 .6882 Metetra
.655 .744 .915 r
.40452 .6882 .40961 .69294 .41821 .69051 .41313 .68575 Metetra
.655 .744 .915 r
.41313 .68575 .41821 .69051 .42684 .68807 .42178 .68329 Metetra
.655 .744 .915 r
.42178 .68329 .42684 .68807 .43549 .68562 .43045 .68083 Metetra
.655 .744 .915 r
.43045 .68083 .43549 .68562 .44417 .68316 .43915 .67835 Metetra
.655 .744 .915 r
.43915 .67835 .44417 .68316 .45288 .68069 .44787 .67587 Metetra
.655 .744 .915 r
.44787 .67587 .45288 .68069 .46162 .67822 .45663 .67338 Metetra
.655 .744 .915 r
.45663 .67338 .46162 .67822 .47039 .67573 .46541 .67089 Metetra
.655 .744 .915 r
.46541 .67089 .47039 .67573 .47918 .67324 .47422 .66838 Metetra
.655 .744 .915 r
.47422 .66838 .47918 .67324 .488 .67075 .48306 .66587 Metetra
.655 .744 .915 r
.48306 .66587 .488 .67075 .49685 .66824 .49193 .66335 Metetra
.655 .744 .915 r
.49193 .66335 .49685 .66824 .50573 .66572 .50083 .66082 Metetra
.655 .744 .915 r
.50083 .66082 .50573 .66572 .51464 .6632 .50976 .65828 Metetra
.655 .744 .915 r
.50976 .65828 .51464 .6632 .52358 .66067 .51871 .65573 Metetra
.655 .744 .915 r
.51871 .65573 .52358 .66067 .53255 .65813 .5277 .65318 Metetra
.655 .744 .915 r
.5277 .65318 .53255 .65813 .54154 .65558 .53671 .65061 Metetra
.655 .744 .915 r
.53671 .65061 .54154 .65558 .55057 .65303 .54576 .64804 Metetra
.655 .744 .915 r
.54576 .64804 .55057 .65303 .55963 .65046 .55483 .64546 Metetra
.655 .744 .915 r
.55483 .64546 .55963 .65046 .56871 .64789 .56394 .64287 Metetra
.655 .744 .915 r
.56394 .64287 .56871 .64789 .57782 .64531 .57307 .64028 Metetra
.655 .744 .915 r
.57307 .64028 .57782 .64531 .58697 .64272 .58223 .63767 Metetra
.655 .744 .915 r
.58223 .63767 .58697 .64272 .59614 .64012 .59143 .63506 Metetra
.655 .744 .915 r
.59143 .63506 .59614 .64012 .60535 .63752 .60065 .63243 Metetra
.655 .744 .915 r
.60065 .63243 .60535 .63752 .61459 .6349 .60991 .6298 Metetra
.655 .744 .915 r
.60991 .6298 .61459 .6349 .62385 .63228 .6192 .62716 Metetra
.655 .744 .915 r
.6192 .62716 .62385 .63228 .63315 .62964 .62851 .62451 Metetra
.655 .744 .915 r
.62851 .62451 .63315 .62964 .64248 .627 .63786 .62185 Metetra
.655 .744 .915 r
.63786 .62185 .64248 .627 .65184 .62435 .64724 .61919 Metetra
.655 .744 .915 r
.64724 .61919 .65184 .62435 .66123 .62169 .65665 .61651 Metetra
.655 .744 .915 r
.65665 .61651 .66123 .62169 .67065 .61902 .6661 .61383 Metetra
.655 .744 .915 r
.6661 .61383 .67065 .61902 .6801 .61635 .67557 .61113 Metetra
.655 .744 .915 r
.67557 .61113 .6801 .61635 .68959 .61366 .68508 .60843 Metetra
.655 .744 .915 r
.68508 .60843 .68959 .61366 .69911 .61097 .69461 .60572 Metetra
.655 .744 .915 r
.69461 .60572 .69911 .61097 .70865 .60826 .70418 .603 Metetra
.655 .744 .915 r
.70418 .603 .70865 .60826 .71824 .60555 .71379 .60027 Metetra
.655 .744 .915 r
.71379 .60027 .71824 .60555 .72785 .60283 .72342 .59753 Metetra
.655 .744 .915 r
.72342 .59753 .72785 .60283 .7375 .6001 .73309 .59478 Metetra
.655 .744 .915 r
.73309 .59478 .7375 .6001 .74717 .59735 .74279 .59202 Metetra
.655 .744 .915 r
.74279 .59202 .74717 .59735 .75689 .5946 .75253 .58925 Metetra
.655 .744 .915 r
.75253 .58925 .75689 .5946 .76663 .59184 .76229 .58647 Metetra
.655 .744 .915 r
.76229 .58647 .76663 .59184 .77641 .58908 .77209 .58369 Metetra
.655 .744 .915 r
.77209 .58369 .77641 .58908 .78622 .5863 .78193 .58089 Metetra
.655 .744 .915 r
.78193 .58089 .78622 .5863 .79606 .58351 .7918 .57809 Metetra
.655 .744 .915 r
.7918 .57809 .79606 .58351 .80594 .58071 .8017 .57527 Metetra
.655 .744 .915 r
.8017 .57527 .80594 .58071 .81586 .57791 .81163 .57245 Metetra
.655 .744 .915 r
.81163 .57245 .81586 .57791 .8258 .57509 .8216 .56961 Metetra
.655 .744 .915 r
.8216 .56961 .8258 .57509 .83578 .57226 .83161 .56677 Metetra
.655 .744 .915 r
.83161 .56677 .83578 .57226 .8458 .56943 .84165 .56391 Metetra
.655 .744 .915 r
.84165 .56391 .8458 .56943 .85585 .56658 .85172 .56105 Metetra
.655 .744 .915 r
.85172 .56105 .85585 .56658 .86593 .56372 .86183 .55817 Metetra
.655 .744 .915 r
.86183 .55817 .86593 .56372 .87605 .56086 .87197 .55529 Metetra
.655 .744 .915 r
.87197 .55529 .87605 .56086 .88621 .55798 .88215 .5524 Metetra
.655 .744 .915 r
.88215 .5524 .88621 .55798 .89639 .5551 .89237 .54949 Metetra
.655 .744 .915 r
.89237 .54949 .89639 .5551 .90662 .5522 .90262 .54658 Metetra
.655 .744 .915 r
.90262 .54658 .90662 .5522 .91688 .5493 .9129 .54365 Metetra
.655 .744 .915 r
.9129 .54365 .91688 .5493 .92718 .54638 .92323 .54072 Metetra
.655 .744 .915 r
.92323 .54072 .92718 .54638 .93751 .54346 .93359 .53777 Metetra
.655 .744 .915 r
.93359 .53777 .93751 .54346 .94788 .54052 .94398 .53482 Metetra
.655 .744 .915 r
.94398 .53482 .94788 .54052 .95829 .53757 .95441 .53185 Metetra
.655 .744 .915 r
.95441 .53185 .95829 .53757 .96873 .53462 .96488 .52887 Metetra
.655 .746 .917 r
.36514 .69326 .37033 .69792 .37884 .6955 .37366 .69083 Metetra
.655 .746 .917 r
.37366 .69083 .37884 .6955 .38737 .69308 .38221 .68839 Metetra
.655 .746 .917 r
.38221 .68839 .38737 .69308 .39593 .69064 .39079 .68594 Metetra
.655 .746 .917 r
.39079 .68594 .39593 .69064 .40452 .6882 .39939 .68348 Metetra
.655 .746 .917 r
.39939 .68348 .40452 .6882 .41313 .68575 .40802 .68102 Metetra
.655 .746 .917 r
.40802 .68102 .41313 .68575 .42178 .68329 .41668 .67854 Metetra
.655 .746 .917 r
.41668 .67854 .42178 .68329 .43045 .68083 .42537 .67606 Metetra
.655 .746 .917 r
.42537 .67606 .43045 .68083 .43915 .67835 .43409 .67358 Metetra
.655 .746 .917 r
.43409 .67358 .43915 .67835 .44787 .67587 .44283 .67108 Metetra
.655 .746 .917 r
.44283 .67108 .44787 .67587 .45663 .67338 .4516 .66858 Metetra
.655 .746 .917 r
.4516 .66858 .45663 .67338 .46541 .67089 .4604 .66606 Metetra
.655 .746 .917 r
.4604 .66606 .46541 .67089 .47422 .66838 .46923 .66354 Metetra
.655 .746 .917 r
.46923 .66354 .47422 .66838 .48306 .66587 .47809 .66101 Metetra
.655 .746 .917 r
.47809 .66101 .48306 .66587 .49193 .66335 .48698 .65848 Metetra
.655 .746 .917 r
.48698 .65848 .49193 .66335 .50083 .66082 .4959 .65593 Metetra
.655 .746 .917 r
.4959 .65593 .50083 .66082 .50976 .65828 .50484 .65338 Metetra
.655 .746 .917 r
.50484 .65338 .50976 .65828 .51871 .65573 .51382 .65082 Metetra
.655 .746 .917 r
.51382 .65082 .51871 .65573 .5277 .65318 .52282 .64824 Metetra
.655 .746 .917 r
.52282 .64824 .5277 .65318 .53671 .65061 .53185 .64567 Metetra
.655 .746 .917 r
.53185 .64567 .53671 .65061 .54576 .64804 .54092 .64308 Metetra
.655 .746 .917 r
.54092 .64308 .54576 .64804 .55483 .64546 .55001 .64048 Metetra
.655 .746 .917 r
.55001 .64048 .55483 .64546 .56394 .64287 .55913 .63788 Metetra
.655 .746 .917 r
.55913 .63788 .56394 .64287 .57307 .64028 .56829 .63527 Metetra
.655 .746 .917 r
.56829 .63527 .57307 .64028 .58223 .63767 .57747 .63264 Metetra
.655 .746 .917 r
.57747 .63264 .58223 .63767 .59143 .63506 .58668 .63001 Metetra
.655 .746 .917 r
.58668 .63001 .59143 .63506 .60065 .63243 .59593 .62737 Metetra
.655 .746 .917 r
.59593 .62737 .60065 .63243 .60991 .6298 .60521 .62473 Metetra
.655 .746 .917 r
.60521 .62473 .60991 .6298 .6192 .62716 .61451 .62207 Metetra
.655 .746 .917 r
.61451 .62207 .6192 .62716 .62851 .62451 .62385 .6194 Metetra
.655 .746 .917 r
.62385 .6194 .62851 .62451 .63786 .62185 .63322 .61673 Metetra
.655 .746 .917 r
.63322 .61673 .63786 .62185 .64724 .61919 .64262 .61404 Metetra
.655 .746 .917 r
.64262 .61404 .64724 .61919 .65665 .61651 .65205 .61135 Metetra
.655 .746 .917 r
.65205 .61135 .65665 .61651 .6661 .61383 .66152 .60865 Metetra
.655 .746 .917 r
.66152 .60865 .6661 .61383 .67557 .61113 .67101 .60594 Metetra
.655 .746 .917 r
.67101 .60594 .67557 .61113 .68508 .60843 .68054 .60322 Metetra
.655 .746 .917 r
.68054 .60322 .68508 .60843 .69461 .60572 .6901 .60049 Metetra
.655 .746 .917 r
.6901 .60049 .69461 .60572 .70418 .603 .69969 .59775 Metetra
.655 .746 .917 r
.69969 .59775 .70418 .603 .71379 .60027 .70932 .595 Metetra
.655 .746 .917 r
.70932 .595 .71379 .60027 .72342 .59753 .71897 .59225 Metetra
.655 .746 .917 r
.71897 .59225 .72342 .59753 .73309 .59478 .72866 .58948 Metetra
.655 .746 .917 r
.72866 .58948 .73309 .59478 .74279 .59202 .73839 .58671 Metetra
.655 .746 .917 r
.73839 .58671 .74279 .59202 .75253 .58925 .74814 .58392 Metetra
.655 .746 .917 r
.74814 .58392 .75253 .58925 .76229 .58647 .75793 .58113 Metetra
.655 .746 .917 r
.75793 .58113 .76229 .58647 .77209 .58369 .76776 .57832 Metetra
.655 .746 .917 r
.76776 .57832 .77209 .58369 .78193 .58089 .77761 .57551 Metetra
.655 .746 .917 r
.77761 .57551 .78193 .58089 .7918 .57809 .78751 .57268 Metetra
.655 .746 .917 r
.78751 .57268 .7918 .57809 .8017 .57527 .79743 .56985 Metetra
.655 .746 .917 r
.79743 .56985 .8017 .57527 .81163 .57245 .80739 .56701 Metetra
.655 .746 .917 r
.80739 .56701 .81163 .57245 .8216 .56961 .81738 .56415 Metetra
.655 .746 .917 r
.81738 .56415 .8216 .56961 .83161 .56677 .82741 .56129 Metetra
.655 .746 .917 r
.82741 .56129 .83161 .56677 .84165 .56391 .83748 .55842 Metetra
.655 .746 .917 r
.83748 .55842 .84165 .56391 .85172 .56105 .84757 .55554 Metetra
.655 .746 .917 r
.84757 .55554 .85172 .56105 .86183 .55817 .85771 .55264 Metetra
.655 .746 .917 r
.85771 .55264 .86183 .55817 .87197 .55529 .86788 .54974 Metetra
.655 .746 .917 r
.86788 .54974 .87197 .55529 .88215 .5524 .87808 .54683 Metetra
.655 .746 .917 r
.87808 .54683 .88215 .5524 .89237 .54949 .88832 .5439 Metetra
.655 .746 .917 r
.88832 .5439 .89237 .54949 .90262 .54658 .8986 .54097 Metetra
.655 .746 .917 r
.8986 .54097 .90262 .54658 .9129 .54365 .90891 .53803 Metetra
.655 .746 .917 r
.90891 .53803 .9129 .54365 .92323 .54072 .91926 .53507 Metetra
.655 .746 .917 r
.91926 .53507 .92323 .54072 .93359 .53777 .92964 .53211 Metetra
.655 .746 .917 r
.92964 .53211 .93359 .53777 .94398 .53482 .94006 .52913 Metetra
.655 .746 .917 r
.94006 .52913 .94398 .53482 .95441 .53185 .95052 .52615 Metetra
.655 .746 .917 r
.95052 .52615 .95441 .53185 .96488 .52887 .96102 .52315 Metetra
.655 .739 .912 r
.35992 .68841 .36514 .69326 .37366 .69083 .36846 .68596 Metetra
.655 .739 .912 r
.36846 .68596 .37366 .69083 .38221 .68839 .37702 .6835 Metetra
.655 .739 .912 r
.37702 .6835 .38221 .68839 .39079 .68594 .38562 .68104 Metetra
.655 .739 .912 r
.38562 .68104 .39079 .68594 .39939 .68348 .39424 .67857 Metetra
.655 .739 .912 r
.39424 .67857 .39939 .68348 .40802 .68102 .40289 .67609 Metetra
.655 .739 .912 r
.40289 .67609 .40802 .68102 .41668 .67854 .41156 .6736 Metetra
.655 .739 .912 r
.41156 .6736 .41668 .67854 .42537 .67606 .42027 .67111 Metetra
.655 .739 .912 r
.42027 .67111 .42537 .67606 .43409 .67358 .429 .6686 Metetra
.655 .739 .912 r
.429 .6686 .43409 .67358 .44283 .67108 .43776 .66609 Metetra
.655 .739 .912 r
.43776 .66609 .44283 .67108 .4516 .66858 .44655 .66357 Metetra
.655 .739 .912 r
.44655 .66357 .4516 .66858 .4604 .66606 .45537 .66104 Metetra
.655 .739 .912 r
.45537 .66104 .4604 .66606 .46923 .66354 .46422 .65851 Metetra
.655 .739 .912 r
.46422 .65851 .46923 .66354 .47809 .66101 .47309 .65596 Metetra
.655 .739 .912 r
.47309 .65596 .47809 .66101 .48698 .65848 .482 .65341 Metetra
.655 .739 .912 r
.482 .65341 .48698 .65848 .4959 .65593 .49093 .65085 Metetra
.655 .739 .912 r
.49093 .65085 .4959 .65593 .50484 .65338 .4999 .64828 Metetra
.655 .739 .912 r
.4999 .64828 .50484 .65338 .51382 .65082 .50889 .6457 Metetra
.655 .739 .912 r
.50889 .6457 .51382 .65082 .52282 .64824 .51791 .64311 Metetra
.655 .739 .912 r
.51791 .64311 .52282 .64824 .53185 .64567 .52696 .64052 Metetra
.655 .739 .912 r
.52696 .64052 .53185 .64567 .54092 .64308 .53605 .63792 Metetra
.655 .739 .912 r
.53605 .63792 .54092 .64308 .55001 .64048 .54516 .6353 Metetra
.655 .739 .912 r
.54516 .6353 .55001 .64048 .55913 .63788 .5543 .63268 Metetra
.655 .739 .912 r
.5543 .63268 .55913 .63788 .56829 .63527 .56347 .63005 Metetra
.655 .739 .912 r
.56347 .63005 .56829 .63527 .57747 .63264 .57268 .62742 Metetra
.655 .739 .912 r
.57268 .62742 .57747 .63264 .58668 .63001 .58191 .62477 Metetra
.655 .739 .912 r
.58191 .62477 .58668 .63001 .59593 .62737 .59117 .62211 Metetra
.655 .739 .912 r
.59117 .62211 .59593 .62737 .60521 .62473 .60047 .61945 Metetra
.655 .739 .912 r
.60047 .61945 .60521 .62473 .61451 .62207 .6098 .61677 Metetra
.655 .739 .912 r
.6098 .61677 .61451 .62207 .62385 .6194 .61915 .61409 Metetra
.655 .739 .912 r
.61915 .61409 .62385 .6194 .63322 .61673 .62854 .6114 Metetra
.655 .739 .912 r
.62854 .6114 .63322 .61673 .64262 .61404 .63796 .6087 Metetra
.655 .739 .912 r
.63796 .6087 .64262 .61404 .65205 .61135 .64742 .60599 Metetra
.655 .739 .912 r
.64742 .60599 .65205 .61135 .66152 .60865 .6569 .60327 Metetra
.655 .739 .912 r
.6569 .60327 .66152 .60865 .67101 .60594 .66642 .60054 Metetra
.655 .739 .912 r
.66642 .60054 .67101 .60594 .68054 .60322 .67597 .59781 Metetra
.655 .739 .912 r
.67597 .59781 .68054 .60322 .6901 .60049 .68555 .59506 Metetra
.655 .739 .912 r
.68555 .59506 .6901 .60049 .69969 .59775 .69516 .5923 Metetra
.655 .739 .912 r
.69516 .5923 .69969 .59775 .70932 .595 .70481 .58954 Metetra
.655 .739 .912 r
.70481 .58954 .70932 .595 .71897 .59225 .71449 .58676 Metetra
.655 .739 .912 r
.71449 .58676 .71897 .59225 .72866 .58948 .7242 .58398 Metetra
.655 .739 .912 r
.7242 .58398 .72866 .58948 .73839 .58671 .73394 .58119 Metetra
.655 .739 .912 r
.73394 .58119 .73839 .58671 .74814 .58392 .74372 .57838 Metetra
.655 .739 .912 r
.74372 .57838 .74814 .58392 .75793 .58113 .75353 .57557 Metetra
.655 .739 .912 r
.75353 .57557 .75793 .58113 .76776 .57832 .76338 .57275 Metetra
.655 .739 .912 r
.76338 .57275 .76776 .57832 .77761 .57551 .77326 .56991 Metetra
.655 .739 .912 r
.77326 .56991 .77761 .57551 .78751 .57268 .78317 .56707 Metetra
.655 .739 .912 r
.78317 .56707 .78751 .57268 .79743 .56985 .79312 .56422 Metetra
.655 .739 .912 r
.79312 .56422 .79743 .56985 .80739 .56701 .80311 .56136 Metetra
.655 .739 .912 r
.80311 .56136 .80739 .56701 .81738 .56415 .81312 .55849 Metetra
.655 .739 .912 r
.81312 .55849 .81738 .56415 .82741 .56129 .82318 .55561 Metetra
.655 .739 .912 r
.82318 .55561 .82741 .56129 .83748 .55842 .83326 .55271 Metetra
.655 .739 .912 r
.83326 .55271 .83748 .55842 .84757 .55554 .84338 .54981 Metetra
.655 .739 .912 r
.84338 .54981 .84757 .55554 .85771 .55264 .85354 .5469 Metetra
.655 .739 .912 r
.85354 .5469 .85771 .55264 .86788 .54974 .86374 .54398 Metetra
.655 .739 .912 r
.86374 .54398 .86788 .54974 .87808 .54683 .87396 .54105 Metetra
.655 .739 .912 r
.87396 .54105 .87808 .54683 .88832 .5439 .88423 .5381 Metetra
.655 .739 .912 r
.88423 .5381 .88832 .5439 .8986 .54097 .89453 .53515 Metetra
.655 .739 .912 r
.89453 .53515 .8986 .54097 .90891 .53803 .90487 .53219 Metetra
.655 .739 .912 r
.90487 .53219 .90891 .53803 .91926 .53507 .91524 .52921 Metetra
.655 .739 .912 r
.91524 .52921 .91926 .53507 .92964 .53211 .92565 .52623 Metetra
.655 .739 .912 r
.92565 .52623 .92964 .53211 .94006 .52913 .9361 .52323 Metetra
.655 .739 .912 r
.9361 .52323 .94006 .52913 .95052 .52615 .94658 .52023 Metetra
.655 .739 .912 r
.94658 .52023 .95052 .52615 .96102 .52315 .9571 .51721 Metetra
.655 .742 .914 r
.35467 .6836 .35992 .68841 .36846 .68596 .36323 .68114 Metetra
.655 .742 .914 r
.36323 .68114 .36846 .68596 .37702 .6835 .37181 .67867 Metetra
.655 .742 .914 r
.37181 .67867 .37702 .6835 .38562 .68104 .38042 .67619 Metetra
.655 .742 .914 r
.38042 .67619 .38562 .68104 .39424 .67857 .38906 .67371 Metetra
.655 .742 .914 r
.38906 .67371 .39424 .67857 .40289 .67609 .39772 .67121 Metetra
.655 .742 .914 r
.39772 .67121 .40289 .67609 .41156 .6736 .40641 .66871 Metetra
.655 .742 .914 r
.40641 .66871 .41156 .6736 .42027 .67111 .41514 .6662 Metetra
.655 .742 .914 r
.41514 .6662 .42027 .67111 .429 .6686 .42389 .66368 Metetra
.655 .742 .914 r
.42389 .66368 .429 .6686 .43776 .66609 .43266 .66115 Metetra
.655 .742 .914 r
.43266 .66115 .43776 .66609 .44655 .66357 .44147 .65862 Metetra
.655 .742 .914 r
.44147 .65862 .44655 .66357 .45537 .66104 .45031 .65607 Metetra
.655 .742 .914 r
.45031 .65607 .45537 .66104 .46422 .65851 .45917 .65352 Metetra
.655 .742 .914 r
.45917 .65352 .46422 .65851 .47309 .65596 .46807 .65096 Metetra
.655 .742 .914 r
.46807 .65096 .47309 .65596 .482 .65341 .47699 .64839 Metetra
.655 .742 .914 r
.47699 .64839 .482 .65341 .49093 .65085 .48594 .64582 Metetra
.655 .742 .914 r
.48594 .64582 .49093 .65085 .4999 .64828 .49492 .64323 Metetra
.655 .742 .914 r
.49492 .64323 .4999 .64828 .50889 .6457 .50393 .64064 Metetra
.655 .742 .914 r
.50393 .64064 .50889 .6457 .51791 .64311 .51298 .63804 Metetra
.655 .742 .914 r
.51298 .63804 .51791 .64311 .52696 .64052 .52205 .63542 Metetra
.655 .742 .914 r
.52205 .63542 .52696 .64052 .53605 .63792 .53115 .63281 Metetra
.655 .742 .914 r
.53115 .63281 .53605 .63792 .54516 .6353 .54028 .63018 Metetra
.655 .742 .914 r
.54028 .63018 .54516 .6353 .5543 .63268 .54944 .62754 Metetra
.655 .742 .914 r
.54944 .62754 .5543 .63268 .56347 .63005 .55863 .62489 Metetra
.655 .742 .914 r
.55863 .62489 .56347 .63005 .57268 .62742 .56785 .62224 Metetra
.655 .742 .914 r
.56785 .62224 .57268 .62742 .58191 .62477 .57711 .61958 Metetra
.655 .742 .914 r
.57711 .61958 .58191 .62477 .59117 .62211 .58639 .6169 Metetra
.655 .742 .914 r
.58639 .6169 .59117 .62211 .60047 .61945 .59571 .61422 Metetra
.655 .742 .914 r
.59571 .61422 .60047 .61945 .6098 .61677 .60505 .61153 Metetra
.655 .742 .914 r
.60505 .61153 .6098 .61677 .61915 .61409 .61443 .60883 Metetra
.655 .742 .914 r
.61443 .60883 .61915 .61409 .62854 .6114 .62384 .60612 Metetra
.655 .742 .914 r
.62384 .60612 .62854 .6114 .63796 .6087 .63328 .60341 Metetra
.655 .742 .914 r
.63328 .60341 .63796 .6087 .64742 .60599 .64276 .60068 Metetra
.655 .742 .914 r
.64276 .60068 .64742 .60599 .6569 .60327 .65226 .59794 Metetra
.655 .742 .914 r
.65226 .59794 .6569 .60327 .66642 .60054 .6618 .5952 Metetra
.655 .742 .914 r
.6618 .5952 .66642 .60054 .67597 .59781 .67137 .59244 Metetra
.655 .742 .914 r
.67137 .59244 .67597 .59781 .68555 .59506 .68097 .58968 Metetra
.655 .742 .914 r
.68097 .58968 .68555 .59506 .69516 .5923 .69061 .58691 Metetra
.655 .742 .914 r
.69061 .58691 .69516 .5923 .70481 .58954 .70027 .58412 Metetra
.655 .742 .914 r
.70027 .58412 .70481 .58954 .71449 .58676 .70998 .58133 Metetra
.655 .742 .914 r
.70998 .58133 .71449 .58676 .7242 .58398 .71971 .57853 Metetra
.655 .742 .914 r
.71971 .57853 .7242 .58398 .73394 .58119 .72948 .57572 Metetra
.655 .742 .914 r
.72948 .57572 .73394 .58119 .74372 .57838 .73928 .57289 Metetra
.655 .742 .914 r
.73928 .57289 .74372 .57838 .75353 .57557 .74911 .57006 Metetra
.655 .742 .914 r
.74911 .57006 .75353 .57557 .76338 .57275 .75898 .56722 Metetra
.655 .742 .914 r
.75898 .56722 .76338 .57275 .77326 .56991 .76889 .56437 Metetra
.655 .742 .914 r
.76889 .56437 .77326 .56991 .78317 .56707 .77882 .56151 Metetra
.655 .742 .914 r
.77882 .56151 .78317 .56707 .79312 .56422 .7888 .55864 Metetra
.655 .742 .914 r
.7888 .55864 .79312 .56422 .80311 .56136 .7988 .55576 Metetra
.655 .742 .914 r
.7988 .55576 .80311 .56136 .81312 .55849 .80884 .55287 Metetra
.655 .742 .914 r
.80884 .55287 .81312 .55849 .82318 .55561 .81892 .54997 Metetra
.655 .742 .914 r
.81892 .54997 .82318 .55561 .83326 .55271 .82903 .54706 Metetra
.655 .742 .914 r
.82903 .54706 .83326 .55271 .84338 .54981 .83918 .54414 Metetra
.655 .742 .914 r
.83918 .54414 .84338 .54981 .85354 .5469 .84936 .54121 Metetra
.655 .742 .914 r
.84936 .54121 .85354 .5469 .86374 .54398 .85958 .53827 Metetra
.655 .742 .914 r
.85958 .53827 .86374 .54398 .87396 .54105 .86983 .53532 Metetra
.655 .742 .914 r
.86983 .53532 .87396 .54105 .88423 .5381 .88012 .53235 Metetra
.655 .742 .914 r
.88012 .53235 .88423 .5381 .89453 .53515 .89045 .52938 Metetra
.655 .742 .914 r
.89045 .52938 .89453 .53515 .90487 .53219 .90081 .5264 Metetra
.655 .742 .914 r
.90081 .5264 .90487 .53219 .91524 .52921 .91121 .5234 Metetra
.655 .742 .914 r
.91121 .5234 .91524 .52921 .92565 .52623 .92165 .5204 Metetra
.655 .742 .914 r
.92165 .5204 .92565 .52623 .9361 .52323 .93212 .51739 Metetra
.655 .742 .914 r
.93212 .51739 .9361 .52323 .94658 .52023 .94263 .51436 Metetra
.655 .742 .914 r
.94263 .51436 .94658 .52023 .9571 .51721 .95318 .51132 Metetra
.655 .733 .906 r
.3494 .67853 .35467 .6836 .36323 .68114 .35797 .67605 Metetra
.655 .733 .906 r
.35797 .67605 .36323 .68114 .37181 .67867 .36657 .67356 Metetra
.655 .733 .906 r
.36657 .67356 .37181 .67867 .38042 .67619 .3752 .67107 Metetra
.655 .733 .906 r
.3752 .67107 .38042 .67619 .38906 .67371 .38385 .66857 Metetra
.655 .733 .906 r
.38385 .66857 .38906 .67371 .39772 .67121 .39253 .66606 Metetra
.655 .733 .906 r
.39253 .66606 .39772 .67121 .40641 .66871 .40124 .66354 Metetra
.655 .733 .906 r
.40124 .66354 .40641 .66871 .41514 .6662 .40998 .66101 Metetra
.655 .733 .906 r
.40998 .66101 .41514 .6662 .42389 .66368 .41875 .65848 Metetra
.655 .733 .906 r
.41875 .65848 .42389 .66368 .43266 .66115 .42754 .65594 Metetra
.655 .733 .906 r
.42754 .65594 .43266 .66115 .44147 .65862 .43637 .65339 Metetra
.655 .733 .906 r
.43637 .65339 .44147 .65862 .45031 .65607 .44522 .65083 Metetra
.655 .733 .906 r
.44522 .65083 .45031 .65607 .45917 .65352 .4541 .64826 Metetra
.655 .733 .906 r
.4541 .64826 .45917 .65352 .46807 .65096 .46301 .64568 Metetra
.655 .733 .906 r
.46301 .64568 .46807 .65096 .47699 .64839 .47195 .6431 Metetra
.655 .733 .906 r
.47195 .6431 .47699 .64839 .48594 .64582 .48092 .64051 Metetra
.655 .733 .906 r
.48092 .64051 .48594 .64582 .49492 .64323 .48992 .6379 Metetra
.655 .733 .906 r
.48992 .6379 .49492 .64323 .50393 .64064 .49895 .63529 Metetra
.655 .733 .906 r
.49895 .63529 .50393 .64064 .51298 .63804 .50801 .63268 Metetra
.655 .733 .906 r
.50801 .63268 .51298 .63804 .52205 .63542 .5171 .63005 Metetra
.655 .733 .906 r
.5171 .63005 .52205 .63542 .53115 .63281 .52622 .62741 Metetra
.655 .733 .906 r
.52622 .62741 .53115 .63281 .54028 .63018 .53537 .62477 Metetra
.655 .733 .906 r
.53537 .62477 .54028 .63018 .54944 .62754 .54455 .62211 Metetra
.655 .733 .906 r
.54455 .62211 .54944 .62754 .55863 .62489 .55376 .61945 Metetra
.655 .733 .906 r
.55376 .61945 .55863 .62489 .56785 .62224 .563 .61678 Metetra
.655 .733 .906 r
.563 .61678 .56785 .62224 .57711 .61958 .57227 .6141 Metetra
.655 .733 .906 r
.57227 .6141 .57711 .61958 .58639 .6169 .58158 .61141 Metetra
.655 .733 .906 r
.58158 .61141 .58639 .6169 .59571 .61422 .59091 .60871 Metetra
.655 .733 .906 r
.59091 .60871 .59571 .61422 .60505 .61153 .60028 .606 Metetra
.655 .733 .906 r
.60028 .606 .60505 .61153 .61443 .60883 .60967 .60329 Metetra
.655 .733 .906 r
.60967 .60329 .61443 .60883 .62384 .60612 .6191 .60056 Metetra
.655 .733 .906 r
.6191 .60056 .62384 .60612 .63328 .60341 .62857 .59782 Metetra
.655 .733 .906 r
.62857 .59782 .63328 .60341 .64276 .60068 .63806 .59508 Metetra
.655 .733 .906 r
.63806 .59508 .64276 .60068 .65226 .59794 .64758 .59233 Metetra
.655 .733 .906 r
.64758 .59233 .65226 .59794 .6618 .5952 .65714 .58956 Metetra
.655 .733 .906 r
.65714 .58956 .6618 .5952 .67137 .59244 .66673 .58679 Metetra
.655 .733 .906 r
.66673 .58679 .67137 .59244 .68097 .58968 .67636 .58401 Metetra
.655 .733 .906 r
.67636 .58401 .68097 .58968 .69061 .58691 .68601 .58122 Metetra
.655 .733 .906 r
.68601 .58122 .69061 .58691 .70027 .58412 .6957 .57842 Metetra
.655 .733 .906 r
.6957 .57842 .70027 .58412 .70998 .58133 .70542 .57561 Metetra
.655 .733 .906 r
.70542 .57561 .70998 .58133 .71971 .57853 .71518 .57279 Metetra
.655 .733 .906 r
.71518 .57279 .71971 .57853 .72948 .57572 .72497 .56996 Metetra
.655 .733 .906 r
.72497 .56996 .72948 .57572 .73928 .57289 .73479 .56712 Metetra
.655 .733 .906 r
.73479 .56712 .73928 .57289 .74911 .57006 .74465 .56427 Metetra
.655 .733 .906 r
.74465 .56427 .74911 .57006 .75898 .56722 .75454 .56141 Metetra
.655 .733 .906 r
.75454 .56141 .75898 .56722 .76889 .56437 .76447 .55854 Metetra
.655 .733 .906 r
.76447 .55854 .76889 .56437 .77882 .56151 .77443 .55566 Metetra
.655 .733 .906 r
.77443 .55566 .77882 .56151 .7888 .55864 .78442 .55277 Metetra
.655 .733 .906 r
.78442 .55277 .7888 .55864 .7988 .55576 .79445 .54987 Metetra
.655 .733 .906 r
.79445 .54987 .7988 .55576 .80884 .55287 .80451 .54696 Metetra
.655 .733 .906 r
.80451 .54696 .80884 .55287 .81892 .54997 .81461 .54404 Metetra
.655 .733 .906 r
.81461 .54404 .81892 .54997 .82903 .54706 .82475 .54111 Metetra
.655 .733 .906 r
.82475 .54111 .82903 .54706 .83918 .54414 .83492 .53817 Metetra
.655 .733 .906 r
.83492 .53817 .83918 .54414 .84936 .54121 .84513 .53522 Metetra
.655 .733 .906 r
.84513 .53522 .84936 .54121 .85958 .53827 .85537 .53226 Metetra
.655 .733 .906 r
.85537 .53226 .85958 .53827 .86983 .53532 .86565 .52929 Metetra
.655 .733 .906 r
.86565 .52929 .86983 .53532 .88012 .53235 .87596 .52631 Metetra
.655 .733 .906 r
.87596 .52631 .88012 .53235 .89045 .52938 .88631 .52331 Metetra
.655 .733 .906 r
.88631 .52331 .89045 .52938 .90081 .5264 .8967 .52031 Metetra
.655 .733 .906 r
.8967 .52031 .90081 .5264 .91121 .5234 .90712 .5173 Metetra
.655 .733 .906 r
.90712 .5173 .91121 .5234 .92165 .5204 .91758 .51427 Metetra
.655 .733 .906 r
.91758 .51427 .92165 .5204 .93212 .51739 .92808 .51124 Metetra
.655 .733 .906 r
.92808 .51124 .93212 .51739 .94263 .51436 .93862 .50819 Metetra
.655 .733 .906 r
.93862 .50819 .94263 .51436 .95318 .51132 .94919 .50514 Metetra
.655 .737 .91 r
.3441 .67354 .3494 .67853 .35797 .67605 .35269 .67105 Metetra
.655 .737 .91 r
.35269 .67105 .35797 .67605 .36657 .67356 .3613 .66855 Metetra
.655 .737 .91 r
.3613 .66855 .36657 .67356 .3752 .67107 .36994 .66604 Metetra
.655 .737 .91 r
.36994 .66604 .3752 .67107 .38385 .66857 .37861 .66352 Metetra
.655 .737 .91 r
.37861 .66352 .38385 .66857 .39253 .66606 .38731 .661 Metetra
.655 .737 .91 r
.38731 .661 .39253 .66606 .40124 .66354 .39604 .65846 Metetra
.655 .737 .91 r
.39604 .65846 .40124 .66354 .40998 .66101 .40479 .65592 Metetra
.655 .737 .91 r
.40479 .65592 .40998 .66101 .41875 .65848 .41358 .65337 Metetra
.655 .737 .91 r
.41358 .65337 .41875 .65848 .42754 .65594 .42239 .65081 Metetra
.655 .737 .91 r
.42239 .65081 .42754 .65594 .43637 .65339 .43123 .64825 Metetra
.655 .737 .91 r
.43123 .64825 .43637 .65339 .44522 .65083 .4401 .64567 Metetra
.655 .737 .91 r
.4401 .64567 .44522 .65083 .4541 .64826 .449 .64309 Metetra
.655 .737 .91 r
.449 .64309 .4541 .64826 .46301 .64568 .45793 .6405 Metetra
.655 .737 .91 r
.45793 .6405 .46301 .64568 .47195 .6431 .46689 .6379 Metetra
.655 .737 .91 r
.46689 .6379 .47195 .6431 .48092 .64051 .47587 .63529 Metetra
.655 .737 .91 r
.47587 .63529 .48092 .64051 .48992 .6379 .48489 .63267 Metetra
.655 .737 .91 r
.48489 .63267 .48992 .6379 .49895 .63529 .49394 .63004 Metetra
.655 .737 .91 r
.49394 .63004 .49895 .63529 .50801 .63268 .50302 .62741 Metetra
.655 .737 .91 r
.50302 .62741 .50801 .63268 .5171 .63005 .51212 .62476 Metetra
.655 .737 .91 r
.51212 .62476 .5171 .63005 .52622 .62741 .52126 .62211 Metetra
.655 .737 .91 r
.52126 .62211 .52622 .62741 .53537 .62477 .53043 .61945 Metetra
.655 .737 .91 r
.53043 .61945 .53537 .62477 .54455 .62211 .53963 .61678 Metetra
.655 .737 .91 r
.53963 .61678 .54455 .62211 .55376 .61945 .54886 .6141 Metetra
.655 .737 .91 r
.54886 .6141 .55376 .61945 .563 .61678 .55812 .61141 Metetra
.655 .737 .91 r
.55812 .61141 .563 .61678 .57227 .6141 .56741 .60871 Metetra
.655 .737 .91 r
.56741 .60871 .57227 .6141 .58158 .61141 .57673 .60601 Metetra
.655 .737 .91 r
.57673 .60601 .58158 .61141 .59091 .60871 .58609 .60329 Metetra
.655 .737 .91 r
.58609 .60329 .59091 .60871 .60028 .606 .59547 .60056 Metetra
.655 .737 .91 r
.59547 .60056 .60028 .606 .60967 .60329 .60489 .59783 Metetra
.655 .737 .91 r
.60489 .59783 .60967 .60329 .6191 .60056 .61434 .59509 Metetra
.655 .737 .91 r
.61434 .59509 .6191 .60056 .62857 .59782 .62382 .59233 Metetra
.655 .737 .91 r
.62382 .59233 .62857 .59782 .63806 .59508 .63334 .58957 Metetra
.655 .737 .91 r
.63334 .58957 .63806 .59508 .64758 .59233 .64288 .5868 Metetra
.655 .737 .91 r
.64288 .5868 .64758 .59233 .65714 .58956 .65246 .58402 Metetra
.655 .737 .91 r
.65246 .58402 .65714 .58956 .66673 .58679 .66207 .58123 Metetra
.655 .737 .91 r
.66207 .58123 .66673 .58679 .67636 .58401 .67172 .57843 Metetra
.655 .737 .91 r
.67172 .57843 .67636 .58401 .68601 .58122 .6814 .57562 Metetra
.655 .737 .91 r
.6814 .57562 .68601 .58122 .6957 .57842 .69111 .5728 Metetra
.655 .737 .91 r
.69111 .5728 .6957 .57842 .70542 .57561 .70085 .56997 Metetra
.655 .737 .91 r
.70085 .56997 .70542 .57561 .71518 .57279 .71063 .56713 Metetra
.655 .737 .91 r
.71063 .56713 .71518 .57279 .72497 .56996 .72044 .56429 Metetra
.655 .737 .91 r
.72044 .56429 .72497 .56996 .73479 .56712 .73029 .56143 Metetra
.655 .737 .91 r
.73029 .56143 .73479 .56712 .74465 .56427 .74017 .55856 Metetra
.655 .737 .91 r
.74017 .55856 .74465 .56427 .75454 .56141 .75008 .55568 Metetra
.655 .737 .91 r
.75008 .55568 .75454 .56141 .76447 .55854 .76003 .55279 Metetra
.655 .737 .91 r
.76003 .55279 .76447 .55854 .77443 .55566 .77001 .54989 Metetra
.655 .737 .91 r
.77001 .54989 .77443 .55566 .78442 .55277 .78003 .54699 Metetra
.655 .737 .91 r
.78003 .54699 .78442 .55277 .79445 .54987 .79008 .54407 Metetra
.655 .737 .91 r
.79008 .54407 .79445 .54987 .80451 .54696 .80017 .54114 Metetra
.655 .737 .91 r
.80017 .54114 .80451 .54696 .81461 .54404 .81029 .5382 Metetra
.655 .737 .91 r
.81029 .5382 .81461 .54404 .82475 .54111 .82045 .53525 Metetra
.655 .737 .91 r
.82045 .53525 .82475 .54111 .83492 .53817 .83065 .53229 Metetra
.655 .737 .91 r
.83065 .53229 .83492 .53817 .84513 .53522 .84088 .52932 Metetra
.655 .737 .91 r
.84088 .52932 .84513 .53522 .85537 .53226 .85114 .52634 Metetra
.655 .737 .91 r
.85114 .52634 .85537 .53226 .86565 .52929 .86145 .52335 Metetra
.655 .737 .91 r
.86145 .52335 .86565 .52929 .87596 .52631 .87179 .52035 Metetra
.655 .737 .91 r
.87179 .52035 .87596 .52631 .88631 .52331 .88216 .51734 Metetra
.655 .737 .91 r
.88216 .51734 .88631 .52331 .8967 .52031 .89258 .51431 Metetra
.655 .737 .91 r
.89258 .51431 .8967 .52031 .90712 .5173 .90303 .51128 Metetra
.655 .737 .91 r
.90303 .51128 .90712 .5173 .91758 .51427 .91351 .50823 Metetra
.655 .737 .91 r
.91351 .50823 .91758 .51427 .92808 .51124 .92404 .50518 Metetra
.655 .737 .91 r
.92404 .50518 .92808 .51124 .93862 .50819 .9346 .50211 Metetra
.655 .737 .91 r
.9346 .50211 .93862 .50819 .94919 .50514 .9452 .49904 Metetra
.655 .723 .898 r
.33879 .66815 .3441 .67354 .35269 .67105 .34739 .66564 Metetra
.655 .723 .898 r
.34739 .66564 .35269 .67105 .3613 .66855 .35602 .66312 Metetra
.655 .723 .898 r
.35602 .66312 .3613 .66855 .36994 .66604 .36468 .6606 Metetra
.655 .723 .898 r
.36468 .6606 .36994 .66604 .37861 .66352 .37336 .65806 Metetra
.655 .723 .898 r
.37336 .65806 .37861 .66352 .38731 .661 .38208 .65552 Metetra
.655 .723 .898 r
.38208 .65552 .38731 .661 .39604 .65846 .39082 .65297 Metetra
.655 .723 .898 r
.39082 .65297 .39604 .65846 .40479 .65592 .39959 .65041 Metetra
.655 .723 .898 r
.39959 .65041 .40479 .65592 .41358 .65337 .40839 .64785 Metetra
.655 .723 .898 r
.40839 .64785 .41358 .65337 .42239 .65081 .41722 .64527 Metetra
.655 .723 .898 r
.41722 .64527 .42239 .65081 .43123 .64825 .42607 .64269 Metetra
.655 .723 .898 r
.42607 .64269 .43123 .64825 .4401 .64567 .43496 .6401 Metetra
.655 .723 .898 r
.43496 .6401 .4401 .64567 .449 .64309 .44388 .6375 Metetra
.655 .723 .898 r
.44388 .6375 .449 .64309 .45793 .6405 .45282 .63489 Metetra
.655 .723 .898 r
.45282 .63489 .45793 .6405 .46689 .6379 .4618 .63227 Metetra
.655 .723 .898 r
.4618 .63227 .46689 .6379 .47587 .63529 .4708 .62965 Metetra
.655 .723 .898 r
.4708 .62965 .47587 .63529 .48489 .63267 .47984 .62701 Metetra
.655 .723 .898 r
.47984 .62701 .48489 .63267 .49394 .63004 .4889 .62437 Metetra
.655 .723 .898 r
.4889 .62437 .49394 .63004 .50302 .62741 .498 .62172 Metetra
.655 .723 .898 r
.498 .62172 .50302 .62741 .51212 .62476 .50712 .61906 Metetra
.655 .723 .898 r
.50712 .61906 .51212 .62476 .52126 .62211 .51628 .61639 Metetra
.655 .723 .898 r
.51628 .61639 .52126 .62211 .53043 .61945 .52546 .61371 Metetra
.655 .723 .898 r
.52546 .61371 .53043 .61945 .53963 .61678 .53468 .61102 Metetra
.655 .723 .898 r
.53468 .61102 .53963 .61678 .54886 .6141 .54393 .60832 Metetra
.655 .723 .898 r
.54393 .60832 .54886 .6141 .55812 .61141 .55321 .60562 Metetra
.655 .723 .898 r
.55321 .60562 .55812 .61141 .56741 .60871 .56252 .6029 Metetra
.655 .723 .898 r
.56252 .6029 .56741 .60871 .57673 .60601 .57186 .60018 Metetra
.655 .723 .898 r
.57186 .60018 .57673 .60601 .58609 .60329 .58123 .59744 Metetra
.655 .723 .898 r
.58123 .59744 .58609 .60329 .59547 .60056 .59064 .5947 Metetra
.655 .723 .898 r
.59064 .5947 .59547 .60056 .60489 .59783 .60007 .59195 Metetra
.655 .723 .898 r
.60007 .59195 .60489 .59783 .61434 .59509 .60954 .58919 Metetra
.655 .723 .898 r
.60954 .58919 .61434 .59509 .62382 .59233 .61904 .58642 Metetra
.655 .723 .898 r
.61904 .58642 .62382 .59233 .63334 .58957 .62858 .58364 Metetra
.655 .723 .898 r
.62858 .58364 .63334 .58957 .64288 .5868 .63814 .58085 Metetra
.655 .723 .898 r
.63814 .58085 .64288 .5868 .65246 .58402 .64774 .57805 Metetra
.655 .723 .898 r
.64774 .57805 .65246 .58402 .66207 .58123 .65737 .57524 Metetra
.655 .723 .898 r
.65737 .57524 .66207 .58123 .67172 .57843 .66704 .57242 Metetra
.655 .723 .898 r
.66704 .57242 .67172 .57843 .6814 .57562 .67674 .56959 Metetra
.655 .723 .898 r
.67674 .56959 .6814 .57562 .69111 .5728 .68647 .56676 Metetra
.655 .723 .898 r
.68647 .56676 .69111 .5728 .70085 .56997 .69623 .56391 Metetra
.655 .723 .898 r
.69623 .56391 .70085 .56997 .71063 .56713 .70603 .56105 Metetra
.655 .723 .898 r
.70603 .56105 .71063 .56713 .72044 .56429 .71586 .55818 Metetra
.655 .723 .898 r
.71586 .55818 .72044 .56429 .73029 .56143 .72573 .55531 Metetra
.655 .723 .898 r
.72573 .55531 .73029 .56143 .74017 .55856 .73563 .55242 Metetra
.655 .723 .898 r
.73563 .55242 .74017 .55856 .75008 .55568 .74557 .54952 Metetra
.655 .723 .898 r
.74557 .54952 .75008 .55568 .76003 .55279 .75554 .54661 Metetra
.655 .723 .898 r
.75554 .54661 .76003 .55279 .77001 .54989 .76554 .5437 Metetra
.655 .723 .898 r
.76554 .5437 .77001 .54989 .78003 .54699 .77558 .54077 Metetra
.655 .723 .898 r
.77558 .54077 .78003 .54699 .79008 .54407 .78566 .53783 Metetra
.655 .723 .898 r
.78566 .53783 .79008 .54407 .80017 .54114 .79577 .53488 Metetra
.655 .723 .898 r
.79577 .53488 .80017 .54114 .81029 .5382 .80591 .53192 Metetra
.655 .723 .898 r
.80591 .53192 .81029 .5382 .82045 .53525 .81609 .52895 Metetra
.655 .723 .898 r
.81609 .52895 .82045 .53525 .83065 .53229 .82631 .52597 Metetra
.655 .723 .898 r
.82631 .52597 .83065 .53229 .84088 .52932 .83656 .52298 Metetra
.655 .723 .898 r
.83656 .52298 .84088 .52932 .85114 .52634 .84685 .51998 Metetra
.655 .723 .898 r
.84685 .51998 .85114 .52634 .86145 .52335 .85718 .51697 Metetra
.655 .723 .898 r
.85718 .51697 .86145 .52335 .87179 .52035 .86754 .51395 Metetra
.655 .723 .898 r
.86754 .51395 .87179 .52035 .88216 .51734 .87794 .51092 Metetra
.655 .723 .898 r
.87794 .51092 .88216 .51734 .89258 .51431 .88838 .50787 Metetra
.655 .723 .898 r
.88838 .50787 .89258 .51431 .90303 .51128 .89886 .50482 Metetra
.655 .723 .898 r
.89886 .50482 .90303 .51128 .91351 .50823 .90937 .50175 Metetra
.655 .723 .898 r
.90937 .50175 .91351 .50823 .92404 .50518 .91992 .49868 Metetra
.655 .723 .898 r
.91992 .49868 .92404 .50518 .9346 .50211 .93051 .49559 Metetra
.655 .723 .898 r
.93051 .49559 .9346 .50211 .9452 .49904 .94113 .49249 Metetra
.655 .73 .904 r
.33344 .6629 .33879 .66815 .34739 .66564 .34205 .66038 Metetra
.655 .73 .904 r
.34205 .66038 .34739 .66564 .35602 .66312 .3507 .65784 Metetra
.655 .73 .904 r
.3507 .65784 .35602 .66312 .36468 .6606 .35937 .6553 Metetra
.655 .73 .904 r
.35937 .6553 .36468 .6606 .37336 .65806 .36807 .65276 Metetra
.655 .73 .904 r
.36807 .65276 .37336 .65806 .38208 .65552 .3768 .6502 Metetra
.655 .73 .904 r
.3768 .6502 .38208 .65552 .39082 .65297 .38556 .64763 Metetra
.655 .73 .904 r
.38556 .64763 .39082 .65297 .39959 .65041 .39435 .64506 Metetra
.655 .73 .904 r
.39435 .64506 .39959 .65041 .40839 .64785 .40316 .64248 Metetra
.655 .73 .904 r
.40316 .64248 .40839 .64785 .41722 .64527 .41201 .63989 Metetra
.655 .73 .904 r
.41201 .63989 .41722 .64527 .42607 .64269 .42088 .63729 Metetra
.655 .73 .904 r
.42088 .63729 .42607 .64269 .43496 .6401 .42979 .63468 Metetra
.655 .73 .904 r
.42979 .63468 .43496 .6401 .44388 .6375 .43872 .63206 Metetra
.655 .73 .904 r
.43872 .63206 .44388 .6375 .45282 .63489 .44768 .62944 Metetra
.655 .73 .904 r
.44768 .62944 .45282 .63489 .4618 .63227 .45667 .6268 Metetra
.655 .73 .904 r
.45667 .6268 .4618 .63227 .4708 .62965 .4657 .62416 Metetra
.655 .73 .904 r
.4657 .62416 .4708 .62965 .47984 .62701 .47475 .62151 Metetra
.655 .73 .904 r
.47475 .62151 .47984 .62701 .4889 .62437 .48383 .61885 Metetra
.655 .73 .904 r
.48383 .61885 .4889 .62437 .498 .62172 .49294 .61618 Metetra
.655 .73 .904 r
.49294 .61618 .498 .62172 .50712 .61906 .50209 .6135 Metetra
.655 .73 .904 r
.50209 .6135 .50712 .61906 .51628 .61639 .51126 .61082 Metetra
.655 .73 .904 r
.51126 .61082 .51628 .61639 .52546 .61371 .52047 .60812 Metetra
.655 .73 .904 r
.52047 .60812 .52546 .61371 .53468 .61102 .5297 .60541 Metetra
.655 .73 .904 r
.5297 .60541 .53468 .61102 .54393 .60832 .53897 .6027 Metetra
.655 .73 .904 r
.53897 .6027 .54393 .60832 .55321 .60562 .54827 .59998 Metetra
.655 .73 .904 r
.54827 .59998 .55321 .60562 .56252 .6029 .55759 .59724 Metetra
.655 .73 .904 r
.55759 .59724 .56252 .6029 .57186 .60018 .56696 .5945 Metetra
.655 .73 .904 r
.56696 .5945 .57186 .60018 .58123 .59744 .57635 .59175 Metetra
.655 .73 .904 r
.57635 .59175 .58123 .59744 .59064 .5947 .58577 .58899 Metetra
.655 .73 .904 r
.58577 .58899 .59064 .5947 .60007 .59195 .59523 .58622 Metetra
.655 .73 .904 r
.59523 .58622 .60007 .59195 .60954 .58919 .60472 .58344 Metetra
.655 .73 .904 r
.60472 .58344 .60954 .58919 .61904 .58642 .61424 .58065 Metetra
.655 .73 .904 r
.61424 .58065 .61904 .58642 .62858 .58364 .62379 .57785 Metetra
.655 .73 .904 r
.62379 .57785 .62858 .58364 .63814 .58085 .63338 .57505 Metetra
.655 .73 .904 r
.63338 .57505 .63814 .58085 .64774 .57805 .643 .57223 Metetra
.655 .73 .904 r
.643 .57223 .64774 .57805 .65737 .57524 .65265 .5694 Metetra
.655 .73 .904 r
.65265 .5694 .65737 .57524 .66704 .57242 .66234 .56657 Metetra
.655 .73 .904 r
.66234 .56657 .66704 .57242 .67674 .56959 .67205 .56372 Metetra
.655 .73 .904 r
.67205 .56372 .67674 .56959 .68647 .56676 .68181 .56086 Metetra
.655 .73 .904 r
.68181 .56086 .68647 .56676 .69623 .56391 .69159 .558 Metetra
.655 .73 .904 r
.69159 .558 .69623 .56391 .70603 .56105 .70141 .55512 Metetra
.655 .73 .904 r
.70141 .55512 .70603 .56105 .71586 .55818 .71127 .55223 Metetra
.655 .73 .904 r
.71127 .55223 .71586 .55818 .72573 .55531 .72116 .54934 Metetra
.655 .73 .904 r
.72116 .54934 .72573 .55531 .73563 .55242 .73108 .54643 Metetra
.655 .73 .904 r
.73108 .54643 .73563 .55242 .74557 .54952 .74104 .54351 Metetra
.655 .73 .904 r
.74104 .54351 .74557 .54952 .75554 .54661 .75103 .54059 Metetra
.655 .73 .904 r
.75103 .54059 .75554 .54661 .76554 .5437 .76106 .53765 Metetra
.655 .73 .904 r
.76106 .53765 .76554 .5437 .77558 .54077 .77112 .5347 Metetra
.655 .73 .904 r
.77112 .5347 .77558 .54077 .78566 .53783 .78122 .53175 Metetra
.655 .73 .904 r
.78122 .53175 .78566 .53783 .79577 .53488 .79135 .52878 Metetra
.655 .73 .904 r
.79135 .52878 .79577 .53488 .80591 .53192 .80152 .5258 Metetra
.655 .73 .904 r
.80152 .5258 .80591 .53192 .81609 .52895 .81172 .52281 Metetra
.655 .73 .904 r
.81172 .52281 .81609 .52895 .82631 .52597 .82197 .51981 Metetra
.655 .73 .904 r
.82197 .51981 .82631 .52597 .83656 .52298 .83224 .5168 Metetra
.655 .73 .904 r
.83224 .5168 .83656 .52298 .84685 .51998 .84256 .51378 Metetra
.655 .73 .904 r
.84256 .51378 .84685 .51998 .85718 .51697 .85291 .51075 Metetra
.655 .73 .904 r
.85291 .51075 .85718 .51697 .86754 .51395 .8633 .5077 Metetra
.655 .73 .904 r
.8633 .5077 .86754 .51395 .87794 .51092 .87372 .50465 Metetra
.655 .73 .904 r
.87372 .50465 .87794 .51092 .88838 .50787 .88418 .50159 Metetra
.655 .73 .904 r
.88418 .50159 .88838 .50787 .89886 .50482 .89468 .49851 Metetra
.655 .73 .904 r
.89468 .49851 .89886 .50482 .90937 .50175 .90522 .49542 Metetra
.655 .73 .904 r
.90522 .49542 .90937 .50175 .91992 .49868 .9158 .49233 Metetra
.655 .73 .904 r
.9158 .49233 .91992 .49868 .93051 .49559 .92641 .48922 Metetra
.655 .73 .904 r
.92641 .48922 .93051 .49559 .94113 .49249 .93706 .4861 Metetra
.655 .707 .885 r
.32809 .65699 .33344 .6629 .34205 .66038 .33672 .65445 Metetra
.655 .707 .885 r
.33672 .65445 .34205 .66038 .3507 .65784 .34538 .65191 Metetra
.655 .707 .885 r
.34538 .65191 .3507 .65784 .35937 .6553 .35407 .64935 Metetra
.655 .707 .885 r
.35407 .64935 .35937 .6553 .36807 .65276 .36278 .64678 Metetra
.655 .707 .885 r
.36278 .64678 .36807 .65276 .3768 .6502 .37153 .64421 Metetra
.655 .707 .885 r
.37153 .64421 .3768 .6502 .38556 .64763 .3803 .64163 Metetra
.655 .707 .885 r
.3803 .64163 .38556 .64763 .39435 .64506 .3891 .63904 Metetra
.655 .707 .885 r
.3891 .63904 .39435 .64506 .40316 .64248 .39793 .63644 Metetra
.655 .707 .885 r
.39793 .63644 .40316 .64248 .41201 .63989 .40679 .63383 Metetra
.655 .707 .885 r
.40679 .63383 .41201 .63989 .42088 .63729 .41568 .63122 Metetra
.655 .707 .885 r
.41568 .63122 .42088 .63729 .42979 .63468 .4246 .62859 Metetra
.655 .707 .885 r
.4246 .62859 .42979 .63468 .43872 .63206 .43355 .62596 Metetra
.655 .707 .885 r
.43355 .62596 .43872 .63206 .44768 .62944 .44253 .62331 Metetra
.655 .707 .885 r
.44253 .62331 .44768 .62944 .45667 .6268 .45154 .62066 Metetra
.655 .707 .885 r
.45154 .62066 .45667 .6268 .4657 .62416 .46057 .618 Metetra
.655 .707 .885 r
.46057 .618 .4657 .62416 .47475 .62151 .46964 .61533 Metetra
.655 .707 .885 r
.46964 .61533 .47475 .62151 .48383 .61885 .47874 .61266 Metetra
.655 .707 .885 r
.47874 .61266 .48383 .61885 .49294 .61618 .48787 .60997 Metetra
.655 .707 .885 r
.48787 .60997 .49294 .61618 .50209 .6135 .49703 .60727 Metetra
.655 .707 .885 r
.49703 .60727 .50209 .6135 .51126 .61082 .50622 .60457 Metetra
.655 .707 .885 r
.50622 .60457 .51126 .61082 .52047 .60812 .51544 .60186 Metetra
.655 .707 .885 r
.51544 .60186 .52047 .60812 .5297 .60541 .52469 .59913 Metetra
.655 .707 .885 r
.52469 .59913 .5297 .60541 .53897 .6027 .53398 .5964 Metetra
.655 .707 .885 r
.53398 .5964 .53897 .6027 .54827 .59998 .54329 .59366 Metetra
.655 .707 .885 r
.54329 .59366 .54827 .59998 .55759 .59724 .55264 .59091 Metetra
.655 .707 .885 r
.55264 .59091 .55759 .59724 .56696 .5945 .56202 .58815 Metetra
.655 .707 .885 r
.56202 .58815 .56696 .5945 .57635 .59175 .57143 .58538 Metetra
.655 .707 .885 r
.57143 .58538 .57635 .59175 .58577 .58899 .58087 .5826 Metetra
.655 .707 .885 r
.58087 .5826 .58577 .58899 .59523 .58622 .59034 .57981 Metetra
.655 .707 .885 r
.59034 .57981 .59523 .58622 .60472 .58344 .59985 .57701 Metetra
.655 .707 .885 r
.59985 .57701 .60472 .58344 .61424 .58065 .60939 .57421 Metetra
.655 .707 .885 r
.60939 .57421 .61424 .58065 .62379 .57785 .61896 .57139 Metetra
.655 .707 .885 r
.61896 .57139 .62379 .57785 .63338 .57505 .62857 .56856 Metetra
.655 .707 .885 r
.62857 .56856 .63338 .57505 .643 .57223 .6382 .56573 Metetra
.655 .707 .885 r
.6382 .56573 .643 .57223 .65265 .5694 .64788 .56288 Metetra
.655 .707 .885 r
.64788 .56288 .65265 .5694 .66234 .56657 .65758 .56002 Metetra
.655 .707 .885 r
.65758 .56002 .66234 .56657 .67205 .56372 .66732 .55716 Metetra
.655 .707 .885 r
.66732 .55716 .67205 .56372 .68181 .56086 .67709 .55428 Metetra
.655 .707 .885 r
.67709 .55428 .68181 .56086 .69159 .558 .6869 .5514 Metetra
.655 .707 .885 r
.6869 .5514 .69159 .558 .70141 .55512 .69673 .5485 Metetra
.655 .707 .885 r
.69673 .5485 .70141 .55512 .71127 .55223 .70661 .54559 Metetra
.655 .707 .885 r
.70661 .54559 .71127 .55223 .72116 .54934 .71652 .54268 Metetra
.655 .707 .885 r
.71652 .54268 .72116 .54934 .73108 .54643 .72646 .53975 Metetra
.655 .707 .885 r
.72646 .53975 .73108 .54643 .74104 .54351 .73644 .53681 Metetra
.655 .707 .885 r
.73644 .53681 .74104 .54351 .75103 .54059 .74645 .53387 Metetra
.655 .707 .885 r
.74645 .53387 .75103 .54059 .76106 .53765 .7565 .53091 Metetra
.655 .707 .885 r
.7565 .53091 .76106 .53765 .77112 .5347 .76658 .52794 Metetra
.655 .707 .885 r
.76658 .52794 .77112 .5347 .78122 .53175 .7767 .52496 Metetra
.655 .707 .885 r
.7767 .52496 .78122 .53175 .79135 .52878 .78686 .52198 Metetra
.655 .707 .885 r
.78686 .52198 .79135 .52878 .80152 .5258 .79705 .51898 Metetra
.655 .707 .885 r
.79705 .51898 .80152 .5258 .81172 .52281 .80727 .51597 Metetra
.655 .707 .885 r
.80727 .51597 .81172 .52281 .82197 .51981 .81754 .51295 Metetra
.655 .707 .885 r
.81754 .51295 .82197 .51981 .83224 .5168 .82784 .50992 Metetra
.655 .707 .885 r
.82784 .50992 .83224 .5168 .84256 .51378 .83817 .50687 Metetra
.655 .707 .885 r
.83817 .50687 .84256 .51378 .85291 .51075 .84854 .50382 Metetra
.655 .707 .885 r
.84854 .50382 .85291 .51075 .8633 .5077 .85896 .50076 Metetra
.655 .707 .885 r
.85896 .50076 .8633 .5077 .87372 .50465 .8694 .49768 Metetra
.655 .707 .885 r
.8694 .49768 .87372 .50465 .88418 .50159 .87989 .4946 Metetra
.655 .707 .885 r
.87989 .4946 .88418 .50159 .89468 .49851 .89041 .4915 Metetra
.655 .707 .885 r
.89041 .4915 .89468 .49851 .90522 .49542 .90097 .48839 Metetra
.655 .707 .885 r
.90097 .48839 .90522 .49542 .9158 .49233 .91157 .48527 Metetra
.655 .707 .885 r
.91157 .48527 .9158 .49233 .92641 .48922 .92221 .48214 Metetra
.655 .707 .885 r
.92221 .48214 .92641 .48922 .93706 .4861 .93288 .479 Metetra
.655 .717 .893 r
.3227 .65134 .32809 .65699 .33672 .65445 .33134 .64878 Metetra
.655 .717 .893 r
.33134 .64878 .33672 .65445 .34538 .65191 .34002 .64622 Metetra
.655 .717 .893 r
.34002 .64622 .34538 .65191 .35407 .64935 .34872 .64364 Metetra
.655 .717 .893 r
.34872 .64364 .35407 .64935 .36278 .64678 .35745 .64106 Metetra
.655 .717 .893 r
.35745 .64106 .36278 .64678 .37153 .64421 .36621 .63847 Metetra
.655 .717 .893 r
.36621 .63847 .37153 .64421 .3803 .64163 .375 .63587 Metetra
.655 .717 .893 r
.375 .63587 .3803 .64163 .3891 .63904 .38382 .63327 Metetra
.655 .717 .893 r
.38382 .63327 .3891 .63904 .39793 .63644 .39266 .63065 Metetra
.655 .717 .893 r
.39266 .63065 .39793 .63644 .40679 .63383 .40154 .62803 Metetra
.655 .717 .893 r
.40154 .62803 .40679 .63383 .41568 .63122 .41045 .62539 Metetra
.655 .717 .893 r
.41045 .62539 .41568 .63122 .4246 .62859 .41938 .62275 Metetra
.655 .717 .893 r
.41938 .62275 .4246 .62859 .43355 .62596 .42835 .6201 Metetra
.655 .717 .893 r
.42835 .6201 .43355 .62596 .44253 .62331 .43734 .61744 Metetra
.655 .717 .893 r
.43734 .61744 .44253 .62331 .45154 .62066 .44636 .61477 Metetra
.655 .717 .893 r
.44636 .61477 .45154 .62066 .46057 .618 .45542 .6121 Metetra
.655 .717 .893 r
.45542 .6121 .46057 .618 .46964 .61533 .4645 .60941 Metetra
.655 .717 .893 r
.4645 .60941 .46964 .61533 .47874 .61266 .47362 .60671 Metetra
.655 .717 .893 r
.47362 .60671 .47874 .61266 .48787 .60997 .48277 .60401 Metetra
.655 .717 .893 r
.48277 .60401 .48787 .60997 .49703 .60727 .49194 .6013 Metetra
.655 .717 .893 r
.49194 .6013 .49703 .60727 .50622 .60457 .50115 .59857 Metetra
.655 .717 .893 r
.50115 .59857 .50622 .60457 .51544 .60186 .51039 .59584 Metetra
.655 .717 .893 r
.51039 .59584 .51544 .60186 .52469 .59913 .51966 .5931 Metetra
.655 .717 .893 r
.51966 .5931 .52469 .59913 .53398 .5964 .52896 .59035 Metetra
.655 .717 .893 r
.52896 .59035 .53398 .5964 .54329 .59366 .53829 .58759 Metetra
.655 .717 .893 r
.53829 .58759 .54329 .59366 .55264 .59091 .54766 .58482 Metetra
.655 .717 .893 r
.54766 .58482 .55264 .59091 .56202 .58815 .55705 .58204 Metetra
.655 .717 .893 r
.55705 .58204 .56202 .58815 .57143 .58538 .56648 .57926 Metetra
.655 .717 .893 r
.56648 .57926 .57143 .58538 .58087 .5826 .57594 .57646 Metetra
.655 .717 .893 r
.57594 .57646 .58087 .5826 .59034 .57981 .58544 .57365 Metetra
.655 .717 .893 r
.58544 .57365 .59034 .57981 .59985 .57701 .59496 .57084 Metetra
.655 .717 .893 r
.59496 .57084 .59985 .57701 .60939 .57421 .60452 .56801 Metetra
.655 .717 .893 r
.60452 .56801 .60939 .57421 .61896 .57139 .61411 .56517 Metetra
.655 .717 .893 r
.61411 .56517 .61896 .57139 .62857 .56856 .62374 .56233 Metetra
.655 .717 .893 r
.62374 .56233 .62857 .56856 .6382 .56573 .63339 .55947 Metetra
.655 .717 .893 r
.63339 .55947 .6382 .56573 .64788 .56288 .64308 .55661 Metetra
.655 .717 .893 r
.64308 .55661 .64788 .56288 .65758 .56002 .65281 .55373 Metetra
.655 .717 .893 r
.65281 .55373 .65758 .56002 .66732 .55716 .66257 .55085 Metetra
.655 .717 .893 r
.66257 .55085 .66732 .55716 .67709 .55428 .67236 .54795 Metetra
.655 .717 .893 r
.67236 .54795 .67709 .55428 .6869 .5514 .68218 .54505 Metetra
.655 .717 .893 r
.68218 .54505 .6869 .5514 .69673 .5485 .69204 .54213 Metetra
.655 .717 .893 r
.69204 .54213 .69673 .5485 .70661 .54559 .70194 .53921 Metetra
.655 .717 .893 r
.70194 .53921 .70661 .54559 .71652 .54268 .71187 .53627 Metetra
.655 .717 .893 r
.71187 .53627 .71652 .54268 .72646 .53975 .72183 .53332 Metetra
.655 .717 .893 r
.72183 .53332 .72646 .53975 .73644 .53681 .73183 .53037 Metetra
.655 .717 .893 r
.73183 .53037 .73644 .53681 .74645 .53387 .74187 .5274 Metetra
.655 .717 .893 r
.74187 .5274 .74645 .53387 .7565 .53091 .75194 .52442 Metetra
.655 .717 .893 r
.75194 .52442 .7565 .53091 .76658 .52794 .76204 .52143 Metetra
.655 .717 .893 r
.76204 .52143 .76658 .52794 .7767 .52496 .77218 .51844 Metetra
.655 .717 .893 r
.77218 .51844 .7767 .52496 .78686 .52198 .78236 .51543 Metetra
.655 .717 .893 r
.78236 .51543 .78686 .52198 .79705 .51898 .79257 .51241 Metetra
.655 .717 .893 r
.79257 .51241 .79705 .51898 .80727 .51597 .80282 .50938 Metetra
.655 .717 .893 r
.80282 .50938 .80727 .51597 .81754 .51295 .81311 .50634 Metetra
.655 .717 .893 r
.81311 .50634 .81754 .51295 .82784 .50992 .82343 .50328 Metetra
.655 .717 .893 r
.82343 .50328 .82784 .50992 .83817 .50687 .83379 .50022 Metetra
.655 .717 .893 r
.83379 .50022 .83817 .50687 .84854 .50382 .84418 .49715 Metetra
.655 .717 .893 r
.84418 .49715 .84854 .50382 .85896 .50076 .85462 .49406 Metetra
.655 .717 .893 r
.85462 .49406 .85896 .50076 .8694 .49768 .86509 .49097 Metetra
.655 .717 .893 r
.86509 .49097 .8694 .49768 .87989 .4946 .8756 .48786 Metetra
.655 .717 .893 r
.8756 .48786 .87989 .4946 .89041 .4915 .88614 .48474 Metetra
.655 .717 .893 r
.88614 .48474 .89041 .4915 .90097 .48839 .89673 .48161 Metetra
.655 .717 .893 r
.89673 .48161 .90097 .48839 .91157 .48527 .90735 .47847 Metetra
.655 .717 .893 r
.90735 .47847 .91157 .48527 .92221 .48214 .91801 .47532 Metetra
.655 .717 .893 r
.91801 .47532 .92221 .48214 .93288 .479 .92871 .47215 Metetra
.653 .679 .862 r
.31734 .6445 .3227 .65134 .33134 .64878 .326 .64192 Metetra
.653 .679 .862 r
.326 .64192 .33134 .64878 .34002 .64622 .33469 .63934 Metetra
.653 .679 .862 r
.33469 .63934 .34002 .64622 .34872 .64364 .3434 .63675 Metetra
.653 .679 .862 r
.3434 .63675 .34872 .64364 .35745 .64106 .35215 .63415 Metetra
.653 .679 .862 r
.35215 .63415 .35745 .64106 .36621 .63847 .36092 .63154 Metetra
.653 .679 .862 r
.36092 .63154 .36621 .63847 .375 .63587 .36972 .62893 Metetra
.653 .679 .862 r
.36972 .62893 .375 .63587 .38382 .63327 .37855 .6263 Metetra
.653 .679 .862 r
.37855 .6263 .38382 .63327 .39266 .63065 .38741 .62367 Metetra
.653 .679 .862 r
.38741 .62367 .39266 .63065 .40154 .62803 .3963 .62103 Metetra
.653 .679 .862 r
.3963 .62103 .40154 .62803 .41045 .62539 .40522 .61838 Metetra
.653 .679 .862 r
.40522 .61838 .41045 .62539 .41938 .62275 .41417 .61572 Metetra
.653 .679 .862 r
.41417 .61572 .41938 .62275 .42835 .6201 .42315 .61305 Metetra
.653 .679 .862 r
.42315 .61305 .42835 .6201 .43734 .61744 .43215 .61037 Metetra
.653 .679 .862 r
.43215 .61037 .43734 .61744 .44636 .61477 .44119 .60768 Metetra
.653 .679 .862 r
.44119 .60768 .44636 .61477 .45542 .6121 .45026 .60499 Metetra
.653 .679 .862 r
.45026 .60499 .45542 .6121 .4645 .60941 .45936 .60228 Metetra
.653 .679 .862 r
.45936 .60228 .4645 .60941 .47362 .60671 .46849 .59957 Metetra
.653 .679 .862 r
.46849 .59957 .47362 .60671 .48277 .60401 .47765 .59685 Metetra
.653 .679 .862 r
.47765 .59685 .48277 .60401 .49194 .6013 .48684 .59411 Metetra
.653 .679 .862 r
.48684 .59411 .49194 .6013 .50115 .59857 .49606 .59137 Metetra
.653 .679 .862 r
.49606 .59137 .50115 .59857 .51039 .59584 .50531 .58862 Metetra
.653 .679 .862 r
.50531 .58862 .51039 .59584 .51966 .5931 .5146 .58586 Metetra
.653 .679 .862 r
.5146 .58586 .51966 .5931 .52896 .59035 .52391 .58309 Metetra
.653 .679 .862 r
.52391 .58309 .52896 .59035 .53829 .58759 .53326 .58031 Metetra
.653 .679 .862 r
.53326 .58031 .53829 .58759 .54766 .58482 .54264 .57752 Metetra
.653 .679 .862 r
.54264 .57752 .54766 .58482 .55705 .58204 .55205 .57473 Metetra
.653 .679 .862 r
.55205 .57473 .55705 .58204 .56648 .57926 .5615 .57192 Metetra
.653 .679 .862 r
.5615 .57192 .56648 .57926 .57594 .57646 .57097 .5691 Metetra
.653 .679 .862 r
.57097 .5691 .57594 .57646 .58544 .57365 .58048 .56628 Metetra
.653 .679 .862 r
.58048 .56628 .58544 .57365 .59496 .57084 .59002 .56344 Metetra
.653 .679 .862 r
.59002 .56344 .59496 .57084 .60452 .56801 .5996 .56059 Metetra
.653 .679 .862 r
.5996 .56059 .60452 .56801 .61411 .56517 .6092 .55774 Metetra
.653 .679 .862 r
.6092 .55774 .61411 .56517 .62374 .56233 .61884 .55487 Metetra
.653 .679 .862 r
.61884 .55487 .62374 .56233 .63339 .55947 .62852 .552 Metetra
.653 .679 .862 r
.62852 .552 .63339 .55947 .64308 .55661 .63822 .54911 Metetra
.653 .679 .862 r
.63822 .54911 .64308 .55661 .65281 .55373 .64797 .54622 Metetra
.653 .679 .862 r
.64797 .54622 .65281 .55373 .66257 .55085 .65774 .54331 Metetra
.653 .679 .862 r
.65774 .54331 .66257 .55085 .67236 .54795 .66755 .54039 Metetra
.653 .679 .862 r
.66755 .54039 .67236 .54795 .68218 .54505 .67739 .53747 Metetra
.653 .679 .862 r
.67739 .53747 .68218 .54505 .69204 .54213 .68727 .53453 Metetra
.653 .679 .862 r
.68727 .53453 .69204 .54213 .70194 .53921 .69718 .53159 Metetra
.653 .679 .862 r
.69718 .53159 .70194 .53921 .71187 .53627 .70713 .52863 Metetra
.653 .679 .862 r
.70713 .52863 .71187 .53627 .72183 .53332 .71711 .52566 Metetra
.653 .679 .862 r
.71711 .52566 .72183 .53332 .73183 .53037 .72713 .52268 Metetra
.653 .679 .862 r
.72713 .52268 .73183 .53037 .74187 .5274 .73718 .5197 Metetra
.653 .679 .862 r
.73718 .5197 .74187 .5274 .75194 .52442 .74727 .5167 Metetra
.653 .679 .862 r
.74727 .5167 .75194 .52442 .76204 .52143 .75739 .51369 Metetra
.653 .679 .862 r
.75739 .51369 .76204 .52143 .77218 .51844 .76755 .51067 Metetra
.653 .679 .862 r
.76755 .51067 .77218 .51844 .78236 .51543 .77774 .50764 Metetra
.653 .679 .862 r
.77774 .50764 .78236 .51543 .79257 .51241 .78797 .5046 Metetra
.653 .679 .862 r
.78797 .5046 .79257 .51241 .80282 .50938 .79824 .50154 Metetra
.653 .679 .862 r
.79824 .50154 .80282 .50938 .81311 .50634 .80855 .49848 Metetra
.653 .679 .862 r
.80855 .49848 .81311 .50634 .82343 .50328 .81889 .49541 Metetra
.653 .679 .862 r
.81889 .49541 .82343 .50328 .83379 .50022 .82927 .49232 Metetra
.653 .679 .862 r
.82927 .49232 .83379 .50022 .84418 .49715 .83968 .48922 Metetra
.653 .679 .862 r
.83968 .48922 .84418 .49715 .85462 .49406 .85014 .48612 Metetra
.653 .679 .862 r
.85014 .48612 .85462 .49406 .86509 .49097 .86063 .483 Metetra
.653 .679 .862 r
.86063 .483 .86509 .49097 .8756 .48786 .87115 .47987 Metetra
.653 .679 .862 r
.87115 .47987 .8756 .48786 .88614 .48474 .88172 .47673 Metetra
.653 .679 .862 r
.88172 .47673 .88614 .48474 .89673 .48161 .89233 .47357 Metetra
.653 .679 .862 r
.89233 .47357 .89673 .48161 .90735 .47847 .90297 .47041 Metetra
.653 .679 .862 r
.90297 .47041 .90735 .47847 .91801 .47532 .91365 .46724 Metetra
.653 .679 .862 r
.91365 .46724 .91801 .47532 .92871 .47215 .92437 .46405 Metetra
.655 .693 .874 r
.31194 .63809 .31734 .6445 .326 .64192 .32061 .6355 Metetra
.655 .693 .874 r
.32061 .6355 .326 .64192 .33469 .63934 .32931 .6329 Metetra
.655 .693 .874 r
.32931 .6329 .33469 .63934 .3434 .63675 .33804 .63029 Metetra
.655 .693 .874 r
.33804 .63029 .3434 .63675 .35215 .63415 .34679 .62767 Metetra
.655 .693 .874 r
.34679 .62767 .35215 .63415 .36092 .63154 .35558 .62505 Metetra
.655 .693 .874 r
.35558 .62505 .36092 .63154 .36972 .62893 .3644 .62241 Metetra
.655 .693 .874 r
.3644 .62241 .36972 .62893 .37855 .6263 .37324 .61977 Metetra
.655 .693 .874 r
.37324 .61977 .37855 .6263 .38741 .62367 .38211 .61712 Metetra
.655 .693 .874 r
.38211 .61712 .38741 .62367 .3963 .62103 .39102 .61446 Metetra
.655 .693 .874 r
.39102 .61446 .3963 .62103 .40522 .61838 .39995 .61179 Metetra
.655 .693 .874 r
.39995 .61179 .40522 .61838 .41417 .61572 .40891 .60911 Metetra
.655 .693 .874 r
.40891 .60911 .41417 .61572 .42315 .61305 .41791 .60643 Metetra
.655 .693 .874 r
.41791 .60643 .42315 .61305 .43215 .61037 .42693 .60373 Metetra
.655 .693 .874 r
.42693 .60373 .43215 .61037 .44119 .60768 .43598 .60103 Metetra
.655 .693 .874 r
.43598 .60103 .44119 .60768 .45026 .60499 .44506 .59831 Metetra
.655 .693 .874 r
.44506 .59831 .45026 .60499 .45936 .60228 .45418 .59559 Metetra
.655 .693 .874 r
.45418 .59559 .45936 .60228 .46849 .59957 .46332 .59286 Metetra
.655 .693 .874 r
.46332 .59286 .46849 .59957 .47765 .59685 .4725 .59011 Metetra
.655 .693 .874 r
.4725 .59011 .47765 .59685 .48684 .59411 .4817 .58736 Metetra
.655 .693 .874 r
.4817 .58736 .48684 .59411 .49606 .59137 .49094 .5846 Metetra
.655 .693 .874 r
.49094 .5846 .49606 .59137 .50531 .58862 .50021 .58183 Metetra
.655 .693 .874 r
.50021 .58183 .50531 .58862 .5146 .58586 .50951 .57906 Metetra
.655 .693 .874 r
.50951 .57906 .5146 .58586 .52391 .58309 .51884 .57627 Metetra
.655 .693 .874 r
.51884 .57627 .52391 .58309 .53326 .58031 .52821 .57347 Metetra
.655 .693 .874 r
.52821 .57347 .53326 .58031 .54264 .57752 .5376 .57066 Metetra
.655 .693 .874 r
.5376 .57066 .54264 .57752 .55205 .57473 .54703 .56785 Metetra
.655 .693 .874 r
.54703 .56785 .55205 .57473 .5615 .57192 .55649 .56502 Metetra
.655 .693 .874 r
.55649 .56502 .5615 .57192 .57097 .5691 .56598 .56218 Metetra
.655 .693 .874 r
.56598 .56218 .57097 .5691 .58048 .56628 .57551 .55934 Metetra
.655 .693 .874 r
.57551 .55934 .58048 .56628 .59002 .56344 .58507 .55648 Metetra
.655 .693 .874 r
.58507 .55648 .59002 .56344 .5996 .56059 .59466 .55361 Metetra
.655 .693 .874 r
.59466 .55361 .5996 .56059 .6092 .55774 .60428 .55074 Metetra
.655 .693 .874 r
.60428 .55074 .6092 .55774 .61884 .55487 .61394 .54785 Metetra
.655 .693 .874 r
.61394 .54785 .61884 .55487 .62852 .552 .62363 .54496 Metetra
.655 .693 .874 r
.62363 .54496 .62852 .552 .63822 .54911 .63336 .54205 Metetra
.655 .693 .874 r
.63336 .54205 .63822 .54911 .64797 .54622 .64311 .53914 Metetra
.655 .693 .874 r
.64311 .53914 .64797 .54622 .65774 .54331 .65291 .53621 Metetra
.655 .693 .874 r
.65291 .53621 .65774 .54331 .66755 .54039 .66273 .53327 Metetra
.655 .693 .874 r
.66273 .53327 .66755 .54039 .67739 .53747 .6726 .53033 Metetra
.655 .693 .874 r
.6726 .53033 .67739 .53747 .68727 .53453 .68249 .52737 Metetra
.655 .693 .874 r
.68249 .52737 .68727 .53453 .69718 .53159 .69242 .5244 Metetra
.655 .693 .874 r
.69242 .5244 .69718 .53159 .70713 .52863 .70239 .52143 Metetra
.655 .693 .874 r
.70239 .52143 .70713 .52863 .71711 .52566 .71239 .51844 Metetra
.655 .693 .874 r
.71239 .51844 .71711 .52566 .72713 .52268 .72242 .51544 Metetra
.655 .693 .874 r
.72242 .51544 .72713 .52268 .73718 .5197 .7325 .51243 Metetra
.655 .693 .874 r
.7325 .51243 .73718 .5197 .74727 .5167 .7426 .50941 Metetra
.655 .693 .874 r
.7426 .50941 .74727 .5167 .75739 .51369 .75274 .50638 Metetra
.655 .693 .874 r
.75274 .50638 .75739 .51369 .76755 .51067 .76292 .50334 Metetra
.655 .693 .874 r
.76292 .50334 .76755 .51067 .77774 .50764 .77314 .50029 Metetra
.655 .693 .874 r
.77314 .50029 .77774 .50764 .78797 .5046 .78339 .49722 Metetra
.655 .693 .874 r
.78339 .49722 .78797 .5046 .79824 .50154 .79368 .49415 Metetra
.655 .693 .874 r
.79368 .49415 .79824 .50154 .80855 .49848 .804 .49107 Metetra
.655 .693 .874 r
.804 .49107 .80855 .49848 .81889 .49541 .81437 .48797 Metetra
.655 .693 .874 r
.81437 .48797 .81889 .49541 .82927 .49232 .82477 .48486 Metetra
.655 .693 .874 r
.82477 .48486 .82927 .49232 .83968 .48922 .8352 .48174 Metetra
.655 .693 .874 r
.8352 .48174 .83968 .48922 .85014 .48612 .84568 .47861 Metetra
.655 .693 .874 r
.84568 .47861 .85014 .48612 .86063 .483 .85619 .47547 Metetra
.655 .693 .874 r
.85619 .47547 .86063 .483 .87115 .47987 .86674 .47232 Metetra
.655 .693 .874 r
.86674 .47232 .87115 .47987 .88172 .47673 .87733 .46916 Metetra
.655 .693 .874 r
.87733 .46916 .88172 .47673 .89233 .47357 .88795 .46598 Metetra
.655 .693 .874 r
.88795 .46598 .89233 .47357 .90297 .47041 .89862 .4628 Metetra
.655 .693 .874 r
.89862 .4628 .90297 .47041 .91365 .46724 .90932 .4596 Metetra
.655 .693 .874 r
.90932 .4596 .91365 .46724 .92437 .46405 .92007 .45639 Metetra
.646 .626 .815 r
.30666 .62913 .31194 .63809 .32061 .6355 .31534 .62652 Metetra
.646 .626 .815 r
.31534 .62652 .32061 .6355 .32931 .6329 .32405 .6239 Metetra
.646 .626 .815 r
.32405 .6239 .32931 .6329 .33804 .63029 .33278 .62127 Metetra
.646 .626 .815 r
.33278 .62127 .33804 .63029 .34679 .62767 .34155 .61864 Metetra
.646 .626 .815 r
.34155 .61864 .34679 .62767 .35558 .62505 .35034 .61599 Metetra
.646 .626 .815 r
.35034 .61599 .35558 .62505 .3644 .62241 .35916 .61334 Metetra
.646 .626 .815 r
.35916 .61334 .3644 .62241 .37324 .61977 .36802 .61068 Metetra
.646 .626 .815 r
.36802 .61068 .37324 .61977 .38211 .61712 .3769 .608 Metetra
.646 .626 .815 r
.3769 .608 .38211 .61712 .39102 .61446 .38581 .60532 Metetra
.646 .626 .815 r
.38581 .60532 .39102 .61446 .39995 .61179 .39475 .60264 Metetra
.646 .626 .815 r
.39475 .60264 .39995 .61179 .40891 .60911 .40372 .59994 Metetra
.646 .626 .815 r
.40372 .59994 .40891 .60911 .41791 .60643 .41272 .59723 Metetra
.646 .626 .815 r
.41272 .59723 .41791 .60643 .42693 .60373 .42175 .59451 Metetra
.646 .626 .815 r
.42175 .59451 .42693 .60373 .43598 .60103 .43081 .59179 Metetra
.646 .626 .815 r
.43081 .59179 .43598 .60103 .44506 .59831 .4399 .58905 Metetra
.646 .626 .815 r
.4399 .58905 .44506 .59831 .45418 .59559 .44903 .58631 Metetra
.646 .626 .815 r
.44903 .58631 .45418 .59559 .46332 .59286 .45818 .58356 Metetra
.646 .626 .815 r
.45818 .58356 .46332 .59286 .4725 .59011 .46736 .58079 Metetra
.646 .626 .815 r
.46736 .58079 .4725 .59011 .4817 .58736 .47658 .57802 Metetra
.646 .626 .815 r
.47658 .57802 .4817 .58736 .49094 .5846 .48582 .57524 Metetra
.646 .626 .815 r
.48582 .57524 .49094 .5846 .50021 .58183 .4951 .57245 Metetra
.646 .626 .815 r
.4951 .57245 .50021 .58183 .50951 .57906 .50441 .56965 Metetra
.646 .626 .815 r
.50441 .56965 .50951 .57906 .51884 .57627 .51375 .56684 Metetra
.646 .626 .815 r
.51375 .56684 .51884 .57627 .52821 .57347 .52313 .56402 Metetra
.646 .626 .815 r
.52313 .56402 .52821 .57347 .5376 .57066 .53253 .56119 Metetra
.646 .626 .815 r
.53253 .56119 .5376 .57066 .54703 .56785 .54197 .55836 Metetra
.646 .626 .815 r
.54197 .55836 .54703 .56785 .55649 .56502 .55144 .55551 Metetra
.646 .626 .815 r
.55144 .55551 .55649 .56502 .56598 .56218 .56094 .55265 Metetra
.646 .626 .815 r
.56094 .55265 .56598 .56218 .57551 .55934 .57047 .54978 Metetra
.646 .626 .815 r
.57047 .54978 .57551 .55934 .58507 .55648 .58004 .5469 Metetra
.646 .626 .815 r
.58004 .5469 .58507 .55648 .59466 .55361 .58964 .54402 Metetra
.646 .626 .815 r
.58964 .54402 .59466 .55361 .60428 .55074 .59928 .54112 Metetra
.646 .626 .815 r
.59928 .54112 .60428 .55074 .61394 .54785 .60895 .53821 Metetra
.646 .626 .815 r
.60895 .53821 .61394 .54785 .62363 .54496 .61865 .53529 Metetra
.646 .626 .815 r
.61865 .53529 .62363 .54496 .63336 .54205 .62838 .53236 Metetra
.646 .626 .815 r
.62838 .53236 .63336 .54205 .64311 .53914 .63815 .52943 Metetra
.646 .626 .815 r
.63815 .52943 .64311 .53914 .65291 .53621 .64795 .52648 Metetra
.646 .626 .815 r
.64795 .52648 .65291 .53621 .66273 .53327 .65779 .52352 Metetra
.646 .626 .815 r
.65779 .52352 .66273 .53327 .6726 .53033 .66766 .52055 Metetra
.646 .626 .815 r
.66766 .52055 .6726 .53033 .68249 .52737 .67757 .51757 Metetra
.646 .626 .815 r
.67757 .51757 .68249 .52737 .69242 .5244 .68751 .51458 Metetra
.646 .626 .815 r
.68751 .51458 .69242 .5244 .70239 .52143 .69749 .51158 Metetra
.646 .626 .815 r
.69749 .51158 .70239 .52143 .71239 .51844 .7075 .50857 Metetra
.646 .626 .815 r
.7075 .50857 .71239 .51844 .72242 .51544 .71754 .50555 Metetra
.646 .626 .815 r
.71754 .50555 .72242 .51544 .7325 .51243 .72763 .50251 Metetra
.646 .626 .815 r
.72763 .50251 .7325 .51243 .7426 .50941 .73775 .49947 Metetra
.646 .626 .815 r
.73775 .49947 .7426 .50941 .75274 .50638 .7479 .49642 Metetra
.646 .626 .815 r
.7479 .49642 .75274 .50638 .76292 .50334 .75809 .49335 Metetra
.646 .626 .815 r
.75809 .49335 .76292 .50334 .77314 .50029 .76832 .49027 Metetra
.646 .626 .815 r
.76832 .49027 .77314 .50029 .78339 .49722 .77858 .48719 Metetra
.646 .626 .815 r
.77858 .48719 .78339 .49722 .79368 .49415 .78888 .48409 Metetra
.646 .626 .815 r
.78888 .48409 .79368 .49415 .804 .49107 .79922 .48098 Metetra
.646 .626 .815 r
.79922 .48098 .804 .49107 .81437 .48797 .80959 .47786 Metetra
.646 .626 .815 r
.80959 .47786 .81437 .48797 .82477 .48486 .82 .47473 Metetra
.646 .626 .815 r
.82 .47473 .82477 .48486 .8352 .48174 .83045 .47159 Metetra
.646 .626 .815 r
.83045 .47159 .8352 .48174 .84568 .47861 .84094 .46843 Metetra
.646 .626 .815 r
.84094 .46843 .84568 .47861 .85619 .47547 .85146 .46527 Metetra
.646 .626 .815 r
.85146 .46527 .85619 .47547 .86674 .47232 .86203 .46209 Metetra
.646 .626 .815 r
.86203 .46209 .86674 .47232 .87733 .46916 .87263 .4589 Metetra
.646 .626 .815 r
.87263 .4589 .87733 .46916 .88795 .46598 .88327 .4557 Metetra
.646 .626 .815 r
.88327 .4557 .88795 .46598 .89862 .4628 .89395 .45249 Metetra
.646 .626 .815 r
.89395 .45249 .89862 .4628 .90932 .4596 .90466 .44926 Metetra
.646 .626 .815 r
.90466 .44926 .90932 .4596 .92007 .45639 .91542 .44603 Metetra
.65 .646 .833 r
.30131 .62101 .30666 .62913 .31534 .62652 .31 .61838 Metetra
.65 .646 .833 r
.31 .61838 .31534 .62652 .32405 .6239 .31872 .61574 Metetra
.65 .646 .833 r
.31872 .61574 .32405 .6239 .33278 .62127 .32746 .61309 Metetra
.65 .646 .833 r
.32746 .61309 .33278 .62127 .34155 .61864 .33624 .61044 Metetra
.65 .646 .833 r
.33624 .61044 .34155 .61864 .35034 .61599 .34504 .60777 Metetra
.65 .646 .833 r
.34504 .60777 .35034 .61599 .35916 .61334 .35387 .6051 Metetra
.65 .646 .833 r
.35387 .6051 .35916 .61334 .36802 .61068 .36273 .60242 Metetra
.65 .646 .833 r
.36273 .60242 .36802 .61068 .3769 .608 .37162 .59973 Metetra
.65 .646 .833 r
.37162 .59973 .3769 .608 .38581 .60532 .38055 .59703 Metetra
.65 .646 .833 r
.38055 .59703 .38581 .60532 .39475 .60264 .3895 .59432 Metetra
.65 .646 .833 r
.3895 .59432 .39475 .60264 .40372 .59994 .39848 .5916 Metetra
.65 .646 .833 r
.39848 .5916 .40372 .59994 .41272 .59723 .40749 .58888 Metetra
.65 .646 .833 r
.40749 .58888 .41272 .59723 .42175 .59451 .41653 .58614 Metetra
.65 .646 .833 r
.41653 .58614 .42175 .59451 .43081 .59179 .4256 .58339 Metetra
.65 .646 .833 r
.4256 .58339 .43081 .59179 .4399 .58905 .4347 .58064 Metetra
.65 .646 .833 r
.4347 .58064 .4399 .58905 .44903 .58631 .44384 .57788 Metetra
.65 .646 .833 r
.44384 .57788 .44903 .58631 .45818 .58356 .453 .5751 Metetra
.65 .646 .833 r
.453 .5751 .45818 .58356 .46736 .58079 .46219 .57232 Metetra
.65 .646 .833 r
.46219 .57232 .46736 .58079 .47658 .57802 .47142 .56953 Metetra
.65 .646 .833 r
.47142 .56953 .47658 .57802 .48582 .57524 .48068 .56673 Metetra
.65 .646 .833 r
.48068 .56673 .48582 .57524 .4951 .57245 .48997 .56392 Metetra
.65 .646 .833 r
.48997 .56392 .4951 .57245 .50441 .56965 .49929 .5611 Metetra
.65 .646 .833 r
.49929 .5611 .50441 .56965 .51375 .56684 .50864 .55826 Metetra
.65 .646 .833 r
.50864 .55826 .51375 .56684 .52313 .56402 .51802 .55542 Metetra
.65 .646 .833 r
.51802 .55542 .52313 .56402 .53253 .56119 .52744 .55258 Metetra
.65 .646 .833 r
.52744 .55258 .53253 .56119 .54197 .55836 .53689 .54972 Metetra
.65 .646 .833 r
.53689 .54972 .54197 .55836 .55144 .55551 .54637 .54685 Metetra
.65 .646 .833 r
.54637 .54685 .55144 .55551 .56094 .55265 .55589 .54397 Metetra
.65 .646 .833 r
.55589 .54397 .56094 .55265 .57047 .54978 .56543 .54108 Metetra
.65 .646 .833 r
.56543 .54108 .57047 .54978 .58004 .5469 .57501 .53818 Metetra
.65 .646 .833 r
.57501 .53818 .58004 .5469 .58964 .54402 .58463 .53527 Metetra
.65 .646 .833 r
.58463 .53527 .58964 .54402 .59928 .54112 .59427 .53235 Metetra
.65 .646 .833 r
.59427 .53235 .59928 .54112 .60895 .53821 .60395 .52942 Metetra
.65 .646 .833 r
.60395 .52942 .60895 .53821 .61865 .53529 .61367 .52648 Metetra
.65 .646 .833 r
.61367 .52648 .61865 .53529 .62838 .53236 .62341 .52353 Metetra
.65 .646 .833 r
.62341 .52353 .62838 .53236 .63815 .52943 .6332 .52057 Metetra
.65 .646 .833 r
.6332 .52057 .63815 .52943 .64795 .52648 .64301 .5176 Metetra
.65 .646 .833 r
.64301 .5176 .64795 .52648 .65779 .52352 .65286 .51462 Metetra
.65 .646 .833 r
.65286 .51462 .65779 .52352 .66766 .52055 .66275 .51163 Metetra
.65 .646 .833 r
.66275 .51163 .66766 .52055 .67757 .51757 .67267 .50863 Metetra
.65 .646 .833 r
.67267 .50863 .67757 .51757 .68751 .51458 .68262 .50561 Metetra
.65 .646 .833 r
.68262 .50561 .68751 .51458 .69749 .51158 .69261 .50259 Metetra
.65 .646 .833 r
.69261 .50259 .69749 .51158 .7075 .50857 .70264 .49956 Metetra
.65 .646 .833 r
.70264 .49956 .7075 .50857 .71754 .50555 .7127 .49651 Metetra
.65 .646 .833 r
.7127 .49651 .71754 .50555 .72763 .50251 .72279 .49346 Metetra
.65 .646 .833 r
.72279 .49346 .72763 .50251 .73775 .49947 .73293 .49039 Metetra
.65 .646 .833 r
.73293 .49039 .73775 .49947 .7479 .49642 .74309 .48731 Metetra
.65 .646 .833 r
.74309 .48731 .7479 .49642 .75809 .49335 .7533 .48423 Metetra
.65 .646 .833 r
.7533 .48423 .75809 .49335 .76832 .49027 .76354 .48113 Metetra
.65 .646 .833 r
.76354 .48113 .76832 .49027 .77858 .48719 .77382 .47802 Metetra
.65 .646 .833 r
.77382 .47802 .77858 .48719 .78888 .48409 .78413 .47489 Metetra
.65 .646 .833 r
.78413 .47489 .78888 .48409 .79922 .48098 .79449 .47176 Metetra
.65 .646 .833 r
.79449 .47176 .79922 .48098 .80959 .47786 .80487 .46862 Metetra
.65 .646 .833 r
.80487 .46862 .80959 .47786 .82 .47473 .8153 .46546 Metetra
.65 .646 .833 r
.8153 .46546 .82 .47473 .83045 .47159 .82577 .4623 Metetra
.65 .646 .833 r
.82577 .4623 .83045 .47159 .84094 .46843 .83627 .45912 Metetra
.65 .646 .833 r
.83627 .45912 .84094 .46843 .85146 .46527 .84681 .45593 Metetra
.65 .646 .833 r
.84681 .45593 .85146 .46527 .86203 .46209 .85739 .45273 Metetra
.65 .646 .833 r
.85739 .45273 .86203 .46209 .87263 .4589 .868 .44951 Metetra
.65 .646 .833 r
.868 .44951 .87263 .4589 .88327 .4557 .87866 .44629 Metetra
.65 .646 .833 r
.87866 .44629 .88327 .4557 .89395 .45249 .88936 .44305 Metetra
.65 .646 .833 r
.88936 .44305 .89395 .45249 .90466 .44926 .90009 .4398 Metetra
.65 .646 .833 r
.90009 .4398 .90466 .44926 .91542 .44603 .91086 .43654 Metetra
.622 .523 .721 r
.29646 .60498 .30131 .62101 .31 .61838 .30514 .60233 Metetra
.622 .523 .721 r
.30514 .60233 .31 .61838 .31872 .61574 .31385 .59967 Metetra
.622 .523 .721 r
.31385 .59967 .31872 .61574 .32746 .61309 .32258 .59699 Metetra
.622 .523 .721 r
.32258 .59699 .32746 .61309 .33624 .61044 .33135 .59431 Metetra
.622 .523 .721 r
.33135 .59431 .33624 .61044 .34504 .60777 .34014 .59162 Metetra
.622 .523 .721 r
.34014 .59162 .34504 .60777 .35387 .6051 .34896 .58892 Metetra
.622 .523 .721 r
.34896 .58892 .35387 .6051 .36273 .60242 .35781 .58621 Metetra
.622 .523 .721 r
.35781 .58621 .36273 .60242 .37162 .59973 .3667 .5835 Metetra
.622 .523 .721 r
.3667 .5835 .37162 .59973 .38055 .59703 .37561 .58077 Metetra
.622 .523 .721 r
.37561 .58077 .38055 .59703 .3895 .59432 .38455 .57804 Metetra
.622 .523 .721 r
.38455 .57804 .3895 .59432 .39848 .5916 .39352 .57529 Metetra
.622 .523 .721 r
.39352 .57529 .39848 .5916 .40749 .58888 .40252 .57254 Metetra
.622 .523 .721 r
.40252 .57254 .40749 .58888 .41653 .58614 .41155 .56978 Metetra
.622 .523 .721 r
.41155 .56978 .41653 .58614 .4256 .58339 .42061 .567 Metetra
.622 .523 .721 r
.42061 .567 .4256 .58339 .4347 .58064 .4297 .56422 Metetra
.622 .523 .721 r
.4297 .56422 .4347 .58064 .44384 .57788 .43882 .56143 Metetra
.622 .523 .721 r
.43882 .56143 .44384 .57788 .453 .5751 .44798 .55863 Metetra
.622 .523 .721 r
.44798 .55863 .453 .5751 .46219 .57232 .45716 .55582 Metetra
.622 .523 .721 r
.45716 .55582 .46219 .57232 .47142 .56953 .46638 .553 Metetra
.622 .523 .721 r
.46638 .553 .47142 .56953 .48068 .56673 .47562 .55017 Metetra
.622 .523 .721 r
.47562 .55017 .48068 .56673 .48997 .56392 .4849 .54733 Metetra
.622 .523 .721 r
.4849 .54733 .48997 .56392 .49929 .5611 .49421 .54449 Metetra
.622 .523 .721 r
.49421 .54449 .49929 .5611 .50864 .55826 .50355 .54163 Metetra
.622 .523 .721 r
.50355 .54163 .50864 .55826 .51802 .55542 .51293 .53876 Metetra
.622 .523 .721 r
.51293 .53876 .51802 .55542 .52744 .55258 .52233 .53588 Metetra
.622 .523 .721 r
.52233 .53588 .52744 .55258 .53689 .54972 .53177 .53299 Metetra
.622 .523 .721 r
.53177 .53299 .53689 .54972 .54637 .54685 .54124 .5301 Metetra
.622 .523 .721 r
.54124 .5301 .54637 .54685 .55589 .54397 .55075 .52719 Metetra
.622 .523 .721 r
.55075 .52719 .55589 .54397 .56543 .54108 .56028 .52427 Metetra
.622 .523 .721 r
.56028 .52427 .56543 .54108 .57501 .53818 .56985 .52134 Metetra
.622 .523 .721 r
.56985 .52134 .57501 .53818 .58463 .53527 .57945 .51841 Metetra
.622 .523 .721 r
.57945 .51841 .58463 .53527 .59427 .53235 .58909 .51546 Metetra
.622 .523 .721 r
.58909 .51546 .59427 .53235 .60395 .52942 .59876 .5125 Metetra
.622 .523 .721 r
.59876 .5125 .60395 .52942 .61367 .52648 .60846 .50953 Metetra
.622 .523 .721 r
.60846 .50953 .61367 .52648 .62341 .52353 .6182 .50655 Metetra
.622 .523 .721 r
.6182 .50655 .62341 .52353 .6332 .52057 .62797 .50356 Metetra
.622 .523 .721 r
.62797 .50356 .6332 .52057 .64301 .5176 .63777 .50056 Metetra
.622 .523 .721 r
.63777 .50056 .64301 .5176 .65286 .51462 .64761 .49755 Metetra
.622 .523 .721 r
.64761 .49755 .65286 .51462 .66275 .51163 .65748 .49453 Metetra
.622 .523 .721 r
.65748 .49453 .66275 .51163 .67267 .50863 .66739 .4915 Metetra
.622 .523 .721 r
.66739 .4915 .67267 .50863 .68262 .50561 .67734 .48846 Metetra
.622 .523 .721 r
.67734 .48846 .68262 .50561 .69261 .50259 .68731 .48541 Metetra
.622 .523 .721 r
.68731 .48541 .69261 .50259 .70264 .49956 .69733 .48234 Metetra
.622 .523 .721 r
.69733 .48234 .70264 .49956 .7127 .49651 .70738 .47927 Metetra
.622 .523 .721 r
.70738 .47927 .7127 .49651 .72279 .49346 .71746 .47618 Metetra
.622 .523 .721 r
.71746 .47618 .72279 .49346 .73293 .49039 .72758 .47309 Metetra
.622 .523 .721 r
.72758 .47309 .73293 .49039 .74309 .48731 .73774 .46998 Metetra
.622 .523 .721 r
.73774 .46998 .74309 .48731 .7533 .48423 .74793 .46686 Metetra
.622 .523 .721 r
.74793 .46686 .7533 .48423 .76354 .48113 .75816 .46373 Metetra
.622 .523 .721 r
.75816 .46373 .76354 .48113 .77382 .47802 .76843 .46059 Metetra
.622 .523 .721 r
.76843 .46059 .77382 .47802 .78413 .47489 .77873 .45744 Metetra
.622 .523 .721 r
.77873 .45744 .78413 .47489 .79449 .47176 .78907 .45428 Metetra
.622 .523 .721 r
.78907 .45428 .79449 .47176 .80487 .46862 .79945 .4511 Metetra
.622 .523 .721 r
.79945 .4511 .80487 .46862 .8153 .46546 .80986 .44792 Metetra
.622 .523 .721 r
.80986 .44792 .8153 .46546 .82577 .4623 .82031 .44472 Metetra
.622 .523 .721 r
.82031 .44472 .82577 .4623 .83627 .45912 .8308 .44151 Metetra
.622 .523 .721 r
.8308 .44151 .83627 .45912 .84681 .45593 .84133 .43829 Metetra
.622 .523 .721 r
.84133 .43829 .84681 .45593 .85739 .45273 .8519 .43505 Metetra
.622 .523 .721 r
.8519 .43505 .85739 .45273 .868 .44951 .8625 .43181 Metetra
.622 .523 .721 r
.8625 .43181 .868 .44951 .87866 .44629 .87315 .42855 Metetra
.622 .523 .721 r
.87315 .42855 .87866 .44629 .88936 .44305 .88383 .42529 Metetra
.622 .523 .721 r
.88383 .42529 .88936 .44305 .90009 .4398 .89455 .42201 Metetra
.622 .523 .721 r
.89455 .42201 .90009 .4398 .91086 .43654 .90531 .41871 Metetra
.628 .546 .742 r
.29147 .59112 .29646 .60498 .30514 .60233 .30014 .58844 Metetra
.628 .546 .742 r
.30014 .58844 .30514 .60233 .31385 .59967 .30884 .58576 Metetra
.628 .546 .742 r
.30884 .58576 .31385 .59967 .32258 .59699 .31758 .58306 Metetra
.628 .546 .742 r
.31758 .58306 .32258 .59699 .33135 .59431 .32633 .58035 Metetra
.628 .546 .742 r
.32633 .58035 .33135 .59431 .34014 .59162 .33512 .57764 Metetra
.628 .546 .742 r
.33512 .57764 .34014 .59162 .34896 .58892 .34394 .57492 Metetra
.628 .546 .742 r
.34394 .57492 .34896 .58892 .35781 .58621 .35279 .57218 Metetra
.628 .546 .742 r
.35279 .57218 .35781 .58621 .3667 .5835 .36167 .56944 Metetra
.628 .546 .742 r
.36167 .56944 .3667 .5835 .37561 .58077 .37057 .56669 Metetra
.628 .546 .742 r
.37057 .56669 .37561 .58077 .38455 .57804 .37951 .56393 Metetra
.628 .546 .742 r
.37951 .56393 .38455 .57804 .39352 .57529 .38847 .56116 Metetra
.628 .546 .742 r
.38847 .56116 .39352 .57529 .40252 .57254 .39747 .55838 Metetra
.628 .546 .742 r
.39747 .55838 .40252 .57254 .41155 .56978 .4065 .5556 Metetra
.628 .546 .742 r
.4065 .5556 .41155 .56978 .42061 .567 .41555 .5528 Metetra
.628 .546 .742 r
.41555 .5528 .42061 .567 .4297 .56422 .42464 .54999 Metetra
.628 .546 .742 r
.42464 .54999 .4297 .56422 .43882 .56143 .43376 .54718 Metetra
.628 .546 .742 r
.43376 .54718 .43882 .56143 .44798 .55863 .44291 .54435 Metetra
.628 .546 .742 r
.44291 .54435 .44798 .55863 .45716 .55582 .45209 .54152 Metetra
.628 .546 .742 r
.45209 .54152 .45716 .55582 .46638 .553 .4613 .53867 Metetra
.628 .546 .742 r
.4613 .53867 .46638 .553 .47562 .55017 .47054 .53582 Metetra
.628 .546 .742 r
.47054 .53582 .47562 .55017 .4849 .54733 .47981 .53295 Metetra
.628 .546 .742 r
.47981 .53295 .4849 .54733 .49421 .54449 .48912 .53008 Metetra
.628 .546 .742 r
.48912 .53008 .49421 .54449 .50355 .54163 .49845 .52719 Metetra
.628 .546 .742 r
.49845 .52719 .50355 .54163 .51293 .53876 .50782 .5243 Metetra
.628 .546 .742 r
.50782 .5243 .51293 .53876 .52233 .53588 .51722 .5214 Metetra
.628 .546 .742 r
.51722 .5214 .52233 .53588 .53177 .53299 .52666 .51848 Metetra
.628 .546 .742 r
.52666 .51848 .53177 .53299 .54124 .5301 .53612 .51556 Metetra
.628 .546 .742 r
.53612 .51556 .54124 .5301 .55075 .52719 .54562 .51263 Metetra
.628 .546 .742 r
.54562 .51263 .55075 .52719 .56028 .52427 .55515 .50968 Metetra
.628 .546 .742 r
.55515 .50968 .56028 .52427 .56985 .52134 .56472 .50673 Metetra
.628 .546 .742 r
.56472 .50673 .56985 .52134 .57945 .51841 .57432 .50376 Metetra
.628 .546 .742 r
.57432 .50376 .57945 .51841 .58909 .51546 .58395 .50079 Metetra
.628 .546 .742 r
.58395 .50079 .58909 .51546 .59876 .5125 .59361 .4978 Metetra
.628 .546 .742 r
.59361 .4978 .59876 .5125 .60846 .50953 .60331 .49481 Metetra
.628 .546 .742 r
.60331 .49481 .60846 .50953 .6182 .50655 .61304 .4918 Metetra
.628 .546 .742 r
.61304 .4918 .6182 .50655 .62797 .50356 .62281 .48879 Metetra
.628 .546 .742 r
.62281 .48879 .62797 .50356 .63777 .50056 .63261 .48576 Metetra
.628 .546 .742 r
.63261 .48576 .63777 .50056 .64761 .49755 .64244 .48272 Metetra
.628 .546 .742 r
.64244 .48272 .64761 .49755 .65748 .49453 .65231 .47967 Metetra
.628 .546 .742 r
.65231 .47967 .65748 .49453 .66739 .4915 .66221 .47661 Metetra
.628 .546 .742 r
.66221 .47661 .66739 .4915 .67734 .48846 .67215 .47354 Metetra
.628 .546 .742 r
.67215 .47354 .67734 .48846 .68731 .48541 .68213 .47046 Metetra
.628 .546 .742 r
.68213 .47046 .68731 .48541 .69733 .48234 .69213 .46737 Metetra
.628 .546 .742 r
.69213 .46737 .69733 .48234 .70738 .47927 .70218 .46427 Metetra
.628 .546 .742 r
.70218 .46427 .70738 .47927 .71746 .47618 .71226 .46116 Metetra
.628 .546 .742 r
.71226 .46116 .71746 .47618 .72758 .47309 .72237 .45803 Metetra
.628 .546 .742 r
.72237 .45803 .72758 .47309 .73774 .46998 .73253 .4549 Metetra
.628 .546 .742 r
.73253 .4549 .73774 .46998 .74793 .46686 .74272 .45175 Metetra
.628 .546 .742 r
.74272 .45175 .74793 .46686 .75816 .46373 .75294 .44859 Metetra
.628 .546 .742 r
.75294 .44859 .75816 .46373 .76843 .46059 .7632 .44542 Metetra
.628 .546 .742 r
.7632 .44542 .76843 .46059 .77873 .45744 .7735 .44224 Metetra
.628 .546 .742 r
.7735 .44224 .77873 .45744 .78907 .45428 .78383 .43905 Metetra
.628 .546 .742 r
.78383 .43905 .78907 .45428 .79945 .4511 .79421 .43585 Metetra
.628 .546 .742 r
.79421 .43585 .79945 .4511 .80986 .44792 .80462 .43263 Metetra
.628 .546 .742 r
.80462 .43263 .80986 .44792 .82031 .44472 .81506 .4294 Metetra
.628 .546 .742 r
.81506 .4294 .82031 .44472 .8308 .44151 .82555 .42617 Metetra
.628 .546 .742 r
.82555 .42617 .8308 .44151 .84133 .43829 .83607 .42292 Metetra
.628 .546 .742 r
.83607 .42292 .84133 .43829 .8519 .43505 .84663 .41965 Metetra
.628 .546 .742 r
.84663 .41965 .8519 .43505 .8625 .43181 .85724 .41638 Metetra
.628 .546 .742 r
.85724 .41638 .8625 .43181 .87315 .42855 .86787 .41309 Metetra
.628 .546 .742 r
.86787 .41309 .87315 .42855 .88383 .42529 .87855 .4098 Metetra
.628 .546 .742 r
.87855 .4098 .88383 .42529 .89455 .42201 .88927 .40649 Metetra
.628 .546 .742 r
.88927 .40649 .89455 .42201 .90531 .41871 .90002 .40316 Metetra
.57 .375 .578 r
.292 .49839 .29147 .59112 .30014 .58844 .30048 .49562 Metetra
.57 .375 .578 r
.30048 .49562 .30014 .58844 .30884 .58576 .30898 .49284 Metetra
.57 .375 .578 r
.30898 .49284 .30884 .58576 .31758 .58306 .31751 .49006 Metetra
.57 .375 .578 r
.31751 .49006 .31758 .58306 .32633 .58035 .32607 .48726 Metetra
.57 .375 .578 r
.32607 .48726 .32633 .58035 .33512 .57764 .33466 .48446 Metetra
.57 .375 .578 r
.33466 .48446 .33512 .57764 .34394 .57492 .34327 .48165 Metetra
.57 .375 .578 r
.34327 .48165 .34394 .57492 .35279 .57218 .35191 .47883 Metetra
.57 .375 .578 r
.35191 .47883 .35279 .57218 .36167 .56944 .36058 .476 Metetra
.57 .375 .578 r
.36058 .476 .36167 .56944 .37057 .56669 .36928 .47316 Metetra
.57 .375 .578 r
.36928 .47316 .37057 .56669 .37951 .56393 .37801 .47031 Metetra
.57 .375 .578 r
.37801 .47031 .37951 .56393 .38847 .56116 .38676 .46745 Metetra
.57 .375 .578 r
.38676 .46745 .38847 .56116 .39747 .55838 .39555 .46458 Metetra
.57 .375 .578 r
.39555 .46458 .39747 .55838 .4065 .5556 .40436 .46171 Metetra
.57 .375 .578 r
.40436 .46171 .4065 .5556 .41555 .5528 .4132 .45882 Metetra
.57 .375 .578 r
.4132 .45882 .41555 .5528 .42464 .54999 .42208 .45592 Metetra
.57 .375 .578 r
.42208 .45592 .42464 .54999 .43376 .54718 .43098 .45302 Metetra
.57 .375 .578 r
.43098 .45302 .43376 .54718 .44291 .54435 .43991 .4501 Metetra
.57 .375 .578 r
.43991 .4501 .44291 .54435 .45209 .54152 .44886 .44718 Metetra
.57 .375 .578 r
.44886 .44718 .45209 .54152 .4613 .53867 .45785 .44425 Metetra
.57 .375 .578 r
.45785 .44425 .4613 .53867 .47054 .53582 .46687 .4413 Metetra
.57 .375 .578 r
.46687 .4413 .47054 .53582 .47981 .53295 .47592 .43835 Metetra
.57 .375 .578 r
.47592 .43835 .47981 .53295 .48912 .53008 .485 .43538 Metetra
.57 .375 .578 r
.485 .43538 .48912 .53008 .49845 .52719 .49411 .43241 Metetra
.57 .375 .578 r
.49411 .43241 .49845 .52719 .50782 .5243 .50325 .42943 Metetra
.57 .375 .578 r
.50325 .42943 .50782 .5243 .51722 .5214 .51242 .42643 Metetra
.57 .375 .578 r
.51242 .42643 .51722 .5214 .52666 .51848 .52162 .42343 Metetra
.57 .375 .578 r
.52162 .42343 .52666 .51848 .53612 .51556 .53085 .42042 Metetra
.57 .375 .578 r
.53085 .42042 .53612 .51556 .54562 .51263 .54012 .41739 Metetra
.57 .375 .578 r
.54012 .41739 .54562 .51263 .55515 .50968 .54941 .41436 Metetra
.57 .375 .578 r
.54941 .41436 .55515 .50968 .56472 .50673 .55874 .41131 Metetra
.57 .375 .578 r
.55874 .41131 .56472 .50673 .57432 .50376 .56809 .40826 Metetra
.57 .375 .578 r
.56809 .40826 .57432 .50376 .58395 .50079 .57748 .40519 Metetra
.57 .375 .578 r
.57748 .40519 .58395 .50079 .59361 .4978 .5869 .40212 Metetra
.57 .375 .578 r
.5869 .40212 .59361 .4978 .60331 .49481 .59636 .39903 Metetra
.57 .375 .578 r
.59636 .39903 .60331 .49481 .61304 .4918 .60584 .39594 Metetra
.57 .375 .578 r
.60584 .39594 .61304 .4918 .62281 .48879 .61536 .39283 Metetra
.57 .375 .578 r
.61536 .39283 .62281 .48879 .63261 .48576 .62491 .38971 Metetra
.57 .375 .578 r
.62491 .38971 .63261 .48576 .64244 .48272 .63449 .38658 Metetra
.57 .375 .578 r
.63449 .38658 .64244 .48272 .65231 .47967 .64411 .38345 Metetra
.57 .375 .578 r
.64411 .38345 .65231 .47967 .66221 .47661 .65375 .3803 Metetra
.57 .375 .578 r
.65375 .3803 .66221 .47661 .67215 .47354 .66344 .37714 Metetra
.57 .375 .578 r
.66344 .37714 .67215 .47354 .68213 .47046 .67315 .37396 Metetra
.57 .375 .578 r
.67315 .37396 .68213 .47046 .69213 .46737 .6829 .37078 Metetra
.57 .375 .578 r
.6829 .37078 .69213 .46737 .70218 .46427 .69268 .36759 Metetra
.57 .375 .578 r
.69268 .36759 .70218 .46427 .71226 .46116 .7025 .36438 Metetra
.57 .375 .578 r
.7025 .36438 .71226 .46116 .72237 .45803 .71235 .36117 Metetra
.57 .375 .578 r
.71235 .36117 .72237 .45803 .73253 .4549 .72223 .35794 Metetra
.57 .375 .578 r
.72223 .35794 .73253 .4549 .74272 .45175 .73215 .3547 Metetra
.57 .375 .578 r
.73215 .3547 .74272 .45175 .75294 .44859 .7421 .35145 Metetra
.57 .375 .578 r
.7421 .35145 .75294 .44859 .7632 .44542 .75209 .34819 Metetra
.57 .375 .578 r
.75209 .34819 .7632 .44542 .7735 .44224 .76211 .34492 Metetra
.57 .375 .578 r
.76211 .34492 .7735 .44224 .78383 .43905 .77217 .34164 Metetra
.57 .375 .578 r
.77217 .34164 .78383 .43905 .79421 .43585 .78227 .33834 Metetra
.57 .375 .578 r
.78227 .33834 .79421 .43585 .80462 .43263 .7924 .33504 Metetra
.57 .375 .578 r
.7924 .33504 .80462 .43263 .81506 .4294 .80256 .33172 Metetra
.57 .375 .578 r
.80256 .33172 .81506 .4294 .82555 .42617 .81276 .32839 Metetra
.57 .375 .578 r
.81276 .32839 .82555 .42617 .83607 .42292 .823 .32505 Metetra
.57 .375 .578 r
.823 .32505 .83607 .42292 .84663 .41965 .83327 .32169 Metetra
.57 .375 .578 r
.83327 .32169 .84663 .41965 .85724 .41638 .84358 .31833 Metetra
.57 .375 .578 r
.84358 .31833 .85724 .41638 .86787 .41309 .85393 .31495 Metetra
.57 .375 .578 r
.85393 .31495 .86787 .41309 .87855 .4098 .86431 .31156 Metetra
.57 .375 .578 r
.86431 .31156 .87855 .4098 .88927 .40649 .87473 .30816 Metetra
.57 .375 .578 r
.87473 .30816 .88927 .40649 .90002 .40316 .88519 .30475 Metetra
.543 .313 .517 r
.27636 .63441 .292 .49839 .30048 .49562 .2852 .63174 Metetra
.543 .313 .517 r
.2852 .63174 .30048 .49562 .30898 .49284 .29407 .62907 Metetra
.543 .313 .517 r
.29407 .62907 .30898 .49284 .31751 .49006 .30296 .62639 Metetra
.543 .313 .517 r
.30296 .62639 .31751 .49006 .32607 .48726 .31189 .6237 Metetra
.543 .313 .517 r
.31189 .6237 .32607 .48726 .33466 .48446 .32085 .621 Metetra
.543 .313 .517 r
.32085 .621 .33466 .48446 .34327 .48165 .32984 .61829 Metetra
.543 .313 .517 r
.32984 .61829 .34327 .48165 .35191 .47883 .33886 .61557 Metetra
.543 .313 .517 r
.33886 .61557 .35191 .47883 .36058 .476 .34791 .61284 Metetra
.543 .313 .517 r
.34791 .61284 .36058 .476 .36928 .47316 .35699 .6101 Metetra
.543 .313 .517 r
.35699 .6101 .36928 .47316 .37801 .47031 .3661 .60735 Metetra
.543 .313 .517 r
.3661 .60735 .37801 .47031 .38676 .46745 .37524 .6046 Metetra
.543 .313 .517 r
.37524 .6046 .38676 .46745 .39555 .46458 .38441 .60183 Metetra
.543 .313 .517 r
.38441 .60183 .39555 .46458 .40436 .46171 .39362 .59906 Metetra
.543 .313 .517 r
.39362 .59906 .40436 .46171 .4132 .45882 .40286 .59627 Metetra
.543 .313 .517 r
.40286 .59627 .4132 .45882 .42208 .45592 .41212 .59348 Metetra
.543 .313 .517 r
.41212 .59348 .42208 .45592 .43098 .45302 .42142 .59067 Metetra
.543 .313 .517 r
.42142 .59067 .43098 .45302 .43991 .4501 .43076 .58786 Metetra
.543 .313 .517 r
.43076 .58786 .43991 .4501 .44886 .44718 .44012 .58503 Metetra
.543 .313 .517 r
.44012 .58503 .44886 .44718 .45785 .44425 .44952 .5822 Metetra
.543 .313 .517 r
.44952 .5822 .45785 .44425 .46687 .4413 .45895 .57936 Metetra
.543 .313 .517 r
.45895 .57936 .46687 .4413 .47592 .43835 .46842 .5765 Metetra
.543 .313 .517 r
.46842 .5765 .47592 .43835 .485 .43538 .47791 .57364 Metetra
.543 .313 .517 r
.47791 .57364 .485 .43538 .49411 .43241 .48744 .57077 Metetra
.543 .313 .517 r
.48744 .57077 .49411 .43241 .50325 .42943 .497 .56788 Metetra
.543 .313 .517 r
.497 .56788 .50325 .42943 .51242 .42643 .5066 .56499 Metetra
.543 .313 .517 r
.5066 .56499 .51242 .42643 .52162 .42343 .51623 .56209 Metetra
.543 .313 .517 r
.51623 .56209 .52162 .42343 .53085 .42042 .5259 .55917 Metetra
.543 .313 .517 r
.5259 .55917 .53085 .42042 .54012 .41739 .53559 .55625 Metetra
.543 .313 .517 r
.53559 .55625 .54012 .41739 .54941 .41436 .54533 .55331 Metetra
.543 .313 .517 r
.54533 .55331 .54941 .41436 .55874 .41131 .55509 .55037 Metetra
.543 .313 .517 r
.55509 .55037 .55874 .41131 .56809 .40826 .56489 .54741 Metetra
.543 .313 .517 r
.56489 .54741 .56809 .40826 .57748 .40519 .57473 .54445 Metetra
.543 .313 .517 r
.57473 .54445 .57748 .40519 .5869 .40212 .5846 .54147 Metetra
.543 .313 .517 r
.5846 .54147 .5869 .40212 .59636 .39903 .59451 .53849 Metetra
.543 .313 .517 r
.59451 .53849 .59636 .39903 .60584 .39594 .60445 .53549 Metetra
.543 .313 .517 r
.60445 .53549 .60584 .39594 .61536 .39283 .61443 .53248 Metetra
.543 .313 .517 r
.61443 .53248 .61536 .39283 .62491 .38971 .62444 .52946 Metetra
.543 .313 .517 r
.62444 .52946 .62491 .38971 .63449 .38658 .63449 .52643 Metetra
.543 .313 .517 r
.63449 .52643 .63449 .38658 .64411 .38345 .64458 .52339 Metetra
.543 .313 .517 r
.64458 .52339 .64411 .38345 .65375 .3803 .6547 .52034 Metetra
.543 .313 .517 r
.6547 .52034 .65375 .3803 .66344 .37714 .66486 .51728 Metetra
.543 .313 .517 r
.66486 .51728 .66344 .37714 .67315 .37396 .67505 .5142 Metetra
.543 .313 .517 r
.67505 .5142 .67315 .37396 .6829 .37078 .68528 .51112 Metetra
.543 .313 .517 r
.68528 .51112 .6829 .37078 .69268 .36759 .69555 .50802 Metetra
.543 .313 .517 r
.69555 .50802 .69268 .36759 .7025 .36438 .70586 .50491 Metetra
.543 .313 .517 r
.70586 .50491 .7025 .36438 .71235 .36117 .7162 .50179 Metetra
.543 .313 .517 r
.7162 .50179 .71235 .36117 .72223 .35794 .72658 .49866 Metetra
.543 .313 .517 r
.72658 .49866 .72223 .35794 .73215 .3547 .737 .49552 Metetra
.543 .313 .517 r
.737 .49552 .73215 .3547 .7421 .35145 .74746 .49237 Metetra
.543 .313 .517 r
.74746 .49237 .7421 .35145 .75209 .34819 .75795 .4892 Metetra
.543 .313 .517 r
.75795 .4892 .75209 .34819 .76211 .34492 .76849 .48603 Metetra
.543 .313 .517 r
.76849 .48603 .76211 .34492 .77217 .34164 .77906 .48284 Metetra
.543 .313 .517 r
.77906 .48284 .77217 .34164 .78227 .33834 .78968 .47964 Metetra
.543 .313 .517 r
.78968 .47964 .78227 .33834 .7924 .33504 .80033 .47643 Metetra
.543 .313 .517 r
.80033 .47643 .7924 .33504 .80256 .33172 .81102 .47321 Metetra
.543 .313 .517 r
.81102 .47321 .80256 .33172 .81276 .32839 .82175 .46997 Metetra
.543 .313 .517 r
.82175 .46997 .81276 .32839 .823 .32505 .83252 .46672 Metetra
.543 .313 .517 r
.83252 .46672 .823 .32505 .83327 .32169 .84333 .46346 Metetra
.543 .313 .517 r
.84333 .46346 .83327 .32169 .84358 .31833 .85418 .46019 Metetra
.543 .313 .517 r
.85418 .46019 .84358 .31833 .85393 .31495 .86507 .45691 Metetra
.543 .313 .517 r
.86507 .45691 .85393 .31495 .86431 .31156 .876 .45361 Metetra
.543 .313 .517 r
.876 .45361 .86431 .31156 .87473 .30816 .88698 .4503 Metetra
.543 .313 .517 r
.88698 .4503 .87473 .30816 .88519 .30475 .89799 .44698 Metetra
.521 .266 .468 r
.26653 .68428 .27636 .63441 .2852 .63174 .27552 .68165 Metetra
.521 .266 .468 r
.27552 .68165 .2852 .63174 .29407 .62907 .28454 .67901 Metetra
.521 .266 .468 r
.28454 .67901 .29407 .62907 .30296 .62639 .29359 .67636 Metetra
.521 .266 .468 r
.29359 .67636 .30296 .62639 .31189 .6237 .30267 .67371 Metetra
.521 .266 .468 r
.30267 .67371 .31189 .6237 .32085 .621 .31179 .67104 Metetra
.521 .266 .468 r
.31179 .67104 .32085 .621 .32984 .61829 .32093 .66837 Metetra
.521 .266 .468 r
.32093 .66837 .32984 .61829 .33886 .61557 .33011 .66568 Metetra
.521 .266 .468 r
.33011 .66568 .33886 .61557 .34791 .61284 .33932 .66299 Metetra
.521 .266 .468 r
.33932 .66299 .34791 .61284 .35699 .6101 .34856 .66028 Metetra
.521 .266 .468 r
.34856 .66028 .35699 .6101 .3661 .60735 .35783 .65757 Metetra
.521 .266 .468 r
.35783 .65757 .3661 .60735 .37524 .6046 .36714 .65485 Metetra
.521 .266 .468 r
.36714 .65485 .37524 .6046 .38441 .60183 .37648 .65212 Metetra
.521 .266 .468 r
.37648 .65212 .38441 .60183 .39362 .59906 .38585 .64937 Metetra
.521 .266 .468 r
.38585 .64937 .39362 .59906 .40286 .59627 .39525 .64662 Metetra
.521 .266 .468 r
.39525 .64662 .40286 .59627 .41212 .59348 .40469 .64386 Metetra
.521 .266 .468 r
.40469 .64386 .41212 .59348 .42142 .59067 .41416 .64109 Metetra
.521 .266 .468 r
.41416 .64109 .42142 .59067 .43076 .58786 .42366 .63831 Metetra
.521 .266 .468 r
.42366 .63831 .43076 .58786 .44012 .58503 .4332 .63552 Metetra
.521 .266 .468 r
.4332 .63552 .44012 .58503 .44952 .5822 .44277 .63272 Metetra
.521 .266 .468 r
.44277 .63272 .44952 .5822 .45895 .57936 .45237 .62991 Metetra
.521 .266 .468 r
.45237 .62991 .45895 .57936 .46842 .5765 .46201 .62709 Metetra
.521 .266 .468 r
.46201 .62709 .46842 .5765 .47791 .57364 .47168 .62426 Metetra
.521 .266 .468 r
.47168 .62426 .47791 .57364 .48744 .57077 .48139 .62142 Metetra
.521 .266 .468 r
.48139 .62142 .48744 .57077 .497 .56788 .49113 .61857 Metetra
.521 .266 .468 r
.49113 .61857 .497 .56788 .5066 .56499 .50091 .61571 Metetra
.521 .266 .468 r
.50091 .61571 .5066 .56499 .51623 .56209 .51072 .61284 Metetra
.521 .266 .468 r
.51072 .61284 .51623 .56209 .5259 .55917 .52057 .60996 Metetra
.521 .266 .468 r
.52057 .60996 .5259 .55917 .53559 .55625 .53045 .60707 Metetra
.521 .266 .468 r
.53045 .60707 .53559 .55625 .54533 .55331 .54037 .60417 Metetra
.521 .266 .468 r
.54037 .60417 .54533 .55331 .55509 .55037 .55032 .60126 Metetra
.521 .266 .468 r
.55032 .60126 .55509 .55037 .56489 .54741 .56031 .59833 Metetra
.521 .266 .468 r
.56031 .59833 .56489 .54741 .57473 .54445 .57034 .5954 Metetra
.521 .266 .468 r
.57034 .5954 .57473 .54445 .5846 .54147 .5804 .59246 Metetra
.521 .266 .468 r
.5804 .59246 .5846 .54147 .59451 .53849 .5905 .5895 Metetra
.521 .266 .468 r
.5905 .5895 .59451 .53849 .60445 .53549 .60064 .58654 Metetra
.521 .266 .468 r
.60064 .58654 .60445 .53549 .61443 .53248 .61081 .58356 Metetra
.521 .266 .468 r
.61081 .58356 .61443 .53248 .62444 .52946 .62102 .58057 Metetra
.521 .266 .468 r
.62102 .58057 .62444 .52946 .63449 .52643 .63127 .57757 Metetra
.521 .266 .468 r
.63127 .57757 .63449 .52643 .64458 .52339 .64155 .57457 Metetra
.521 .266 .468 r
.64155 .57457 .64458 .52339 .6547 .52034 .65187 .57155 Metetra
.521 .266 .468 r
.65187 .57155 .6547 .52034 .66486 .51728 .66223 .56851 Metetra
.521 .266 .468 r
.66223 .56851 .66486 .51728 .67505 .5142 .67263 .56547 Metetra
.521 .266 .468 r
.67263 .56547 .67505 .5142 .68528 .51112 .68307 .56242 Metetra
.521 .266 .468 r
.68307 .56242 .68528 .51112 .69555 .50802 .69355 .55935 Metetra
.521 .266 .468 r
.69355 .55935 .69555 .50802 .70586 .50491 .70406 .55628 Metetra
.521 .266 .468 r
.70406 .55628 .70586 .50491 .7162 .50179 .71462 .55319 Metetra
.521 .266 .468 r
.71462 .55319 .7162 .50179 .72658 .49866 .72521 .55009 Metetra
.521 .266 .468 r
.72521 .55009 .72658 .49866 .737 .49552 .73584 .54698 Metetra
.521 .266 .468 r
.73584 .54698 .737 .49552 .74746 .49237 .74652 .54386 Metetra
.521 .266 .468 r
.74652 .54386 .74746 .49237 .75795 .4892 .75723 .54072 Metetra
.521 .266 .468 r
.75723 .54072 .75795 .4892 .76849 .48603 .76798 .53758 Metetra
.521 .266 .468 r
.76798 .53758 .76849 .48603 .77906 .48284 .77877 .53442 Metetra
.521 .266 .468 r
.77877 .53442 .77906 .48284 .78968 .47964 .78961 .53125 Metetra
.521 .266 .468 r
.78961 .53125 .78968 .47964 .80033 .47643 .80048 .52807 Metetra
.521 .266 .468 r
.80048 .52807 .80033 .47643 .81102 .47321 .8114 .52487 Metetra
.521 .266 .468 r
.8114 .52487 .81102 .47321 .82175 .46997 .82236 .52167 Metetra
.521 .266 .468 r
.82236 .52167 .82175 .46997 .83252 .46672 .83336 .51845 Metetra
.521 .266 .468 r
.83336 .51845 .83252 .46672 .84333 .46346 .8444 .51522 Metetra
.521 .266 .468 r
.8444 .51522 .84333 .46346 .85418 .46019 .85548 .51198 Metetra
.521 .266 .468 r
.85548 .51198 .85418 .46019 .86507 .45691 .8666 .50872 Metetra
.521 .266 .468 r
.8666 .50872 .86507 .45691 .876 .45361 .87777 .50546 Metetra
.521 .266 .468 r
.87777 .50546 .876 .45361 .88698 .4503 .88898 .50218 Metetra
.521 .266 .468 r
.88898 .50218 .88698 .4503 .89799 .44698 .90024 .49888 Metetra
.499 .886 .962 r
.26027 .68369 .26653 .68428 .27552 .68165 .26929 .68105 Metetra
.499 .886 .962 r
.26929 .68105 .27552 .68165 .28454 .67901 .27834 .6784 Metetra
.499 .886 .962 r
.27834 .6784 .28454 .67901 .29359 .67636 .28742 .67573 Metetra
.499 .886 .962 r
.28742 .67573 .29359 .67636 .30267 .67371 .29653 .67306 Metetra
.499 .886 .962 r
.29653 .67306 .30267 .67371 .31179 .67104 .30568 .67039 Metetra
.499 .886 .962 r
.30568 .67039 .31179 .67104 .32093 .66837 .31485 .6677 Metetra
.499 .886 .962 r
.31485 .6677 .32093 .66837 .33011 .66568 .32406 .665 Metetra
.499 .886 .962 r
.32406 .665 .33011 .66568 .33932 .66299 .3333 .66229 Metetra
.499 .886 .962 r
.3333 .66229 .33932 .66299 .34856 .66028 .34257 .65957 Metetra
.499 .886 .962 r
.34257 .65957 .34856 .66028 .35783 .65757 .35187 .65685 Metetra
.499 .886 .962 r
.35187 .65685 .35783 .65757 .36714 .65485 .36121 .65411 Metetra
.499 .886 .962 r
.36121 .65411 .36714 .65485 .37648 .65212 .37058 .65137 Metetra
.499 .886 .962 r
.37058 .65137 .37648 .65212 .38585 .64937 .37998 .64861 Metetra
.499 .886 .962 r
.37998 .64861 .38585 .64937 .39525 .64662 .38942 .64585 Metetra
.499 .886 .962 r
.38942 .64585 .39525 .64662 .40469 .64386 .39889 .64307 Metetra
.499 .886 .962 r
.39889 .64307 .40469 .64386 .41416 .64109 .40839 .64029 Metetra
.499 .886 .962 r
.40839 .64029 .41416 .64109 .42366 .63831 .41792 .63749 Metetra
.499 .886 .962 r
.41792 .63749 .42366 .63831 .4332 .63552 .42749 .63469 Metetra
.499 .886 .962 r
.42749 .63469 .4332 .63552 .44277 .63272 .4371 .63188 Metetra
.499 .886 .962 r
.4371 .63188 .44277 .63272 .45237 .62991 .44674 .62905 Metetra
.499 .886 .962 r
.44674 .62905 .45237 .62991 .46201 .62709 .45641 .62622 Metetra
.499 .886 .962 r
.45641 .62622 .46201 .62709 .47168 .62426 .46612 .62337 Metetra
.499 .886 .962 r
.46612 .62337 .47168 .62426 .48139 .62142 .47586 .62052 Metetra
.499 .886 .962 r
.47586 .62052 .48139 .62142 .49113 .61857 .48563 .61765 Metetra
.499 .886 .962 r
.48563 .61765 .49113 .61857 .50091 .61571 .49545 .61478 Metetra
.499 .886 .962 r
.49545 .61478 .50091 .61571 .51072 .61284 .50529 .61189 Metetra
.499 .886 .962 r
.50529 .61189 .51072 .61284 .52057 .60996 .51518 .609 Metetra
.499 .886 .962 r
.51518 .609 .52057 .60996 .53045 .60707 .52509 .60609 Metetra
.499 .886 .962 r
.52509 .60609 .53045 .60707 .54037 .60417 .53505 .60317 Metetra
.499 .886 .962 r
.53505 .60317 .54037 .60417 .55032 .60126 .54504 .60025 Metetra
.499 .886 .962 r
.54504 .60025 .55032 .60126 .56031 .59833 .55507 .59731 Metetra
.499 .886 .962 r
.55507 .59731 .56031 .59833 .57034 .5954 .56513 .59436 Metetra
.499 .886 .962 r
.56513 .59436 .57034 .5954 .5804 .59246 .57523 .5914 Metetra
.499 .886 .962 r
.57523 .5914 .5804 .59246 .5905 .5895 .58537 .58843 Metetra
.499 .886 .962 r
.58537 .58843 .5905 .5895 .60064 .58654 .59554 .58545 Metetra
.499 .886 .962 r
.59554 .58545 .60064 .58654 .61081 .58356 .60575 .58246 Metetra
.499 .886 .962 r
.60575 .58246 .61081 .58356 .62102 .58057 .616 .57945 Metetra
.499 .886 .962 r
.616 .57945 .62102 .58057 .63127 .57757 .62629 .57644 Metetra
.499 .886 .962 r
.62629 .57644 .63127 .57757 .64155 .57457 .63661 .57341 Metetra
.499 .886 .962 r
.63661 .57341 .64155 .57457 .65187 .57155 .64697 .57038 Metetra
.499 .886 .962 r
.64697 .57038 .65187 .57155 .66223 .56851 .65737 .56733 Metetra
.499 .886 .962 r
.65737 .56733 .66223 .56851 .67263 .56547 .66781 .56427 Metetra
.499 .886 .962 r
.66781 .56427 .67263 .56547 .68307 .56242 .67829 .5612 Metetra
.499 .886 .962 r
.67829 .5612 .68307 .56242 .69355 .55935 .68881 .55812 Metetra
.499 .886 .962 r
.68881 .55812 .69355 .55935 .70406 .55628 .69936 .55503 Metetra
.499 .886 .962 r
.69936 .55503 .70406 .55628 .71462 .55319 .70996 .55192 Metetra
.499 .886 .962 r
.70996 .55192 .71462 .55319 .72521 .55009 .72059 .5488 Metetra
.499 .886 .962 r
.72059 .5488 .72521 .55009 .73584 .54698 .73127 .54568 Metetra
.499 .886 .962 r
.73127 .54568 .73584 .54698 .74652 .54386 .74199 .54254 Metetra
.499 .886 .962 r
.74199 .54254 .74652 .54386 .75723 .54072 .75274 .53939 Metetra
.499 .886 .962 r
.75274 .53939 .75723 .54072 .76798 .53758 .76354 .53622 Metetra
.499 .886 .962 r
.76354 .53622 .76798 .53758 .77877 .53442 .77437 .53305 Metetra
.499 .886 .962 r
.77437 .53305 .77877 .53442 .78961 .53125 .78525 .52986 Metetra
.499 .886 .962 r
.78525 .52986 .78961 .53125 .80048 .52807 .79617 .52666 Metetra
.499 .886 .962 r
.79617 .52666 .80048 .52807 .8114 .52487 .80713 .52345 Metetra
.499 .886 .962 r
.80713 .52345 .8114 .52487 .82236 .52167 .81813 .52022 Metetra
.499 .886 .962 r
.81813 .52022 .82236 .52167 .83336 .51845 .82918 .51699 Metetra
.499 .886 .962 r
.82918 .51699 .83336 .51845 .8444 .51522 .84027 .51374 Metetra
.499 .886 .962 r
.84027 .51374 .8444 .51522 .85548 .51198 .85139 .51048 Metetra
.499 .886 .962 r
.85139 .51048 .85548 .51198 .8666 .50872 .86257 .5072 Metetra
.499 .886 .962 r
.86257 .5072 .8666 .50872 .87777 .50546 .87378 .50392 Metetra
.499 .886 .962 r
.87378 .50392 .87777 .50546 .88898 .50218 .88504 .50062 Metetra
.499 .886 .962 r
.88504 .50062 .88898 .50218 .90024 .49888 .89634 .49731 Metetra
.25375 .68579 .26027 .68369 .26929 .68105 .2628 .68314 Metetra
.2628 .68314 .26929 .68105 .27834 .6784 .27189 .68047 Metetra
.27189 .68047 .27834 .6784 .28742 .67573 .28101 .6778 Metetra
.28101 .6778 .28742 .67573 .29653 .67306 .29015 .67512 Metetra
.29015 .67512 .29653 .67306 .30568 .67039 .29933 .67243 Metetra
.29933 .67243 .30568 .67039 .31485 .6677 .30855 .66973 Metetra
.30855 .66973 .31485 .6677 .32406 .665 .31779 .66703 Metetra
.31779 .66703 .32406 .665 .3333 .66229 .32707 .66431 Metetra
.32707 .66431 .3333 .66229 .34257 .65957 .33638 .66158 Metetra
.33638 .66158 .34257 .65957 .35187 .65685 .34572 .65884 Metetra
.34572 .65884 .35187 .65685 .36121 .65411 .35509 .6561 Metetra
.35509 .6561 .36121 .65411 .37058 .65137 .3645 .65334 Metetra
.3645 .65334 .37058 .65137 .37998 .64861 .37394 .65057 Metetra
.37394 .65057 .37998 .64861 .38942 .64585 .38342 .6478 Metetra
.38342 .6478 .38942 .64585 .39889 .64307 .39293 .64501 Metetra
.39293 .64501 .39889 .64307 .40839 .64029 .40247 .64222 Metetra
.40247 .64222 .40839 .64029 .41792 .63749 .41205 .63941 Metetra
.41205 .63941 .41792 .63749 .42749 .63469 .42166 .63659 Metetra
.42166 .63659 .42749 .63469 .4371 .63188 .4313 .63377 Metetra
.4313 .63377 .4371 .63188 .44674 .62905 .44098 .63093 Metetra
.44098 .63093 .44674 .62905 .45641 .62622 .4507 .62809 Metetra
.4507 .62809 .45641 .62622 .46612 .62337 .46045 .62523 Metetra
.46045 .62523 .46612 .62337 .47586 .62052 .47023 .62236 Metetra
.47023 .62236 .47586 .62052 .48563 .61765 .48005 .61949 Metetra
.48005 .61949 .48563 .61765 .49545 .61478 .4899 .6166 Metetra
.4899 .6166 .49545 .61478 .50529 .61189 .49979 .6137 Metetra
.49979 .6137 .50529 .61189 .51518 .609 .50972 .61079 Metetra
.50972 .61079 .51518 .609 .52509 .60609 .51968 .60787 Metetra
.51968 .60787 .52509 .60609 .53505 .60317 .52968 .60494 Metetra
.52968 .60494 .53505 .60317 .54504 .60025 .53972 .602 Metetra
.53972 .602 .54504 .60025 .55507 .59731 .54979 .59905 Metetra
.54979 .59905 .55507 .59731 .56513 .59436 .5599 .59609 Metetra
.5599 .59609 .56513 .59436 .57523 .5914 .57004 .59312 Metetra
.57004 .59312 .57523 .5914 .58537 .58843 .58023 .59014 Metetra
.58023 .59014 .58537 .58843 .59554 .58545 .59045 .58714 Metetra
.59045 .58714 .59554 .58545 .60575 .58246 .60071 .58414 Metetra
.60071 .58414 .60575 .58246 .616 .57945 .611 .58112 Metetra
.611 .58112 .616 .57945 .62629 .57644 .62134 .57809 Metetra
.62134 .57809 .62629 .57644 .63661 .57341 .63171 .57505 Metetra
.63171 .57505 .63661 .57341 .64697 .57038 .64212 .572 Metetra
.64212 .572 .64697 .57038 .65737 .56733 .65257 .56894 Metetra
.65257 .56894 .65737 .56733 .66781 .56427 .66306 .56587 Metetra
.66306 .56587 .66781 .56427 .67829 .5612 .67359 .56278 Metetra
.67359 .56278 .67829 .5612 .68881 .55812 .68415 .55969 Metetra
.68415 .55969 .68881 .55812 .69936 .55503 .69476 .55658 Metetra
.69476 .55658 .69936 .55503 .70996 .55192 .70541 .55346 Metetra
.70541 .55346 .70996 .55192 .72059 .5488 .71609 .55033 Metetra
.71609 .55033 .72059 .5488 .73127 .54568 .72682 .54719 Metetra
.72682 .54719 .73127 .54568 .74199 .54254 .73759 .54403 Metetra
.73759 .54403 .74199 .54254 .75274 .53939 .7484 .54086 Metetra
.7484 .54086 .75274 .53939 .76354 .53622 .75925 .53769 Metetra
.75925 .53769 .76354 .53622 .77437 .53305 .77014 .53449 Metetra
.77014 .53449 .77437 .53305 .78525 .52986 .78107 .53129 Metetra
.78107 .53129 .78525 .52986 .79617 .52666 .79204 .52808 Metetra
.79204 .52808 .79617 .52666 .80713 .52345 .80306 .52485 Metetra
.80306 .52485 .80713 .52345 .81813 .52022 .81412 .52161 Metetra
.81412 .52161 .81813 .52022 .82918 .51699 .82522 .51836 Metetra
.82522 .51836 .82918 .51699 .84027 .51374 .83636 .51509 Metetra
.83636 .51509 .84027 .51374 .85139 .51048 .84755 .51182 Metetra
.84755 .51182 .85139 .51048 .86257 .5072 .85877 .50853 Metetra
.85877 .50853 .86257 .5072 .87378 .50392 .87005 .50522 Metetra
.87005 .50522 .87378 .50392 .88504 .50062 .88136 .50191 Metetra
.88136 .50191 .88504 .50062 .89634 .49731 .89272 .49858 Metetra
.645 .657 .848 r
.24797 .67763 .25375 .68579 .2628 .68314 .25704 .67496 Metetra
.645 .657 .848 r
.25704 .67496 .2628 .68314 .27189 .68047 .26613 .67227 Metetra
.645 .657 .848 r
.26613 .67227 .27189 .68047 .28101 .6778 .27526 .66958 Metetra
.645 .657 .848 r
.27526 .66958 .28101 .6778 .29015 .67512 .28442 .66688 Metetra
.645 .657 .848 r
.28442 .66688 .29015 .67512 .29933 .67243 .29361 .66417 Metetra
.645 .657 .848 r
.29361 .66417 .29933 .67243 .30855 .66973 .30284 .66145 Metetra
.645 .657 .848 r
.30284 .66145 .30855 .66973 .31779 .66703 .31209 .65872 Metetra
.645 .657 .848 r
.31209 .65872 .31779 .66703 .32707 .66431 .32138 .65598 Metetra
.645 .657 .848 r
.32138 .65598 .32707 .66431 .33638 .66158 .3307 .65324 Metetra
.645 .657 .848 r
.3307 .65324 .33638 .66158 .34572 .65884 .34005 .65048 Metetra
.645 .657 .848 r
.34005 .65048 .34572 .65884 .35509 .6561 .34944 .64771 Metetra
.645 .657 .848 r
.34944 .64771 .35509 .6561 .3645 .65334 .35886 .64493 Metetra
.645 .657 .848 r
.35886 .64493 .3645 .65334 .37394 .65057 .36831 .64214 Metetra
.645 .657 .848 r
.36831 .64214 .37394 .65057 .38342 .6478 .3778 .63935 Metetra
.645 .657 .848 r
.3778 .63935 .38342 .6478 .39293 .64501 .38732 .63654 Metetra
.645 .657 .848 r
.38732 .63654 .39293 .64501 .40247 .64222 .39688 .63372 Metetra
.645 .657 .848 r
.39688 .63372 .40247 .64222 .41205 .63941 .40647 .6309 Metetra
.645 .657 .848 r
.40647 .6309 .41205 .63941 .42166 .63659 .41609 .62806 Metetra
.645 .657 .848 r
.41609 .62806 .42166 .63659 .4313 .63377 .42575 .62521 Metetra
.645 .657 .848 r
.42575 .62521 .4313 .63377 .44098 .63093 .43544 .62235 Metetra
.645 .657 .848 r
.43544 .62235 .44098 .63093 .4507 .62809 .44517 .61948 Metetra
.645 .657 .848 r
.44517 .61948 .4507 .62809 .46045 .62523 .45493 .6166 Metetra
.645 .657 .848 r
.45493 .6166 .46045 .62523 .47023 .62236 .46473 .61372 Metetra
.645 .657 .848 r
.46473 .61372 .47023 .62236 .48005 .61949 .47456 .61082 Metetra
.645 .657 .848 r
.47456 .61082 .48005 .61949 .4899 .6166 .48443 .60791 Metetra
.645 .657 .848 r
.48443 .60791 .4899 .6166 .49979 .6137 .49433 .60499 Metetra
.645 .657 .848 r
.49433 .60499 .49979 .6137 .50972 .61079 .50427 .60206 Metetra
.645 .657 .848 r
.50427 .60206 .50972 .61079 .51968 .60787 .51425 .59911 Metetra
.645 .657 .848 r
.51425 .59911 .51968 .60787 .52968 .60494 .52426 .59616 Metetra
.645 .657 .848 r
.52426 .59616 .52968 .60494 .53972 .602 .53431 .5932 Metetra
.645 .657 .848 r
.53431 .5932 .53972 .602 .54979 .59905 .5444 .59022 Metetra
.645 .657 .848 r
.5444 .59022 .54979 .59905 .5599 .59609 .55452 .58724 Metetra
.645 .657 .848 r
.55452 .58724 .5599 .59609 .57004 .59312 .56468 .58424 Metetra
.645 .657 .848 r
.56468 .58424 .57004 .59312 .58023 .59014 .57488 .58124 Metetra
.645 .657 .848 r
.57488 .58124 .58023 .59014 .59045 .58714 .58511 .57822 Metetra
.645 .657 .848 r
.58511 .57822 .59045 .58714 .60071 .58414 .59539 .57519 Metetra
.645 .657 .848 r
.59539 .57519 .60071 .58414 .611 .58112 .6057 .57215 Metetra
.645 .657 .848 r
.6057 .57215 .611 .58112 .62134 .57809 .61605 .5691 Metetra
.645 .657 .848 r
.61605 .5691 .62134 .57809 .63171 .57505 .62643 .56603 Metetra
.645 .657 .848 r
.62643 .56603 .63171 .57505 .64212 .572 .63686 .56296 Metetra
.645 .657 .848 r
.63686 .56296 .64212 .572 .65257 .56894 .64733 .55987 Metetra
.645 .657 .848 r
.64733 .55987 .65257 .56894 .66306 .56587 .65783 .55677 Metetra
.645 .657 .848 r
.65783 .55677 .66306 .56587 .67359 .56278 .66837 .55367 Metetra
.645 .657 .848 r
.66837 .55367 .67359 .56278 .68415 .55969 .67896 .55054 Metetra
.645 .657 .848 r
.67896 .55054 .68415 .55969 .69476 .55658 .68958 .54741 Metetra
.645 .657 .848 r
.68958 .54741 .69476 .55658 .70541 .55346 .70025 .54427 Metetra
.645 .657 .848 r
.70025 .54427 .70541 .55346 .71609 .55033 .71095 .54111 Metetra
.645 .657 .848 r
.71095 .54111 .71609 .55033 .72682 .54719 .72169 .53794 Metetra
.645 .657 .848 r
.72169 .53794 .72682 .54719 .73759 .54403 .73248 .53476 Metetra
.645 .657 .848 r
.73248 .53476 .73759 .54403 .7484 .54086 .7433 .53157 Metetra
.645 .657 .848 r
.7433 .53157 .7484 .54086 .75925 .53769 .75417 .52837 Metetra
.645 .657 .848 r
.75417 .52837 .75925 .53769 .77014 .53449 .76508 .52515 Metetra
.645 .657 .848 r
.76508 .52515 .77014 .53449 .78107 .53129 .77603 .52192 Metetra
.645 .657 .848 r
.77603 .52192 .78107 .53129 .79204 .52808 .78702 .51868 Metetra
.645 .657 .848 r
.78702 .51868 .79204 .52808 .80306 .52485 .79805 .51543 Metetra
.645 .657 .848 r
.79805 .51543 .80306 .52485 .81412 .52161 .80913 .51216 Metetra
.645 .657 .848 r
.80913 .51216 .81412 .52161 .82522 .51836 .82025 .50888 Metetra
.645 .657 .848 r
.82025 .50888 .82522 .51836 .83636 .51509 .83141 .50559 Metetra
.645 .657 .848 r
.83141 .50559 .83636 .51509 .84755 .51182 .84261 .50229 Metetra
.645 .657 .848 r
.84261 .50229 .84755 .51182 .85877 .50853 .85386 .49897 Metetra
.645 .657 .848 r
.85386 .49897 .85877 .50853 .87005 .50522 .86515 .49564 Metetra
.645 .657 .848 r
.86515 .49564 .87005 .50522 .88136 .50191 .87649 .4923 Metetra
.645 .657 .848 r
.87649 .4923 .88136 .50191 .89272 .49858 .88787 .48894 Metetra
.498 .886 .961 r
.24155 .67705 .24797 .67763 .25704 .67496 .25065 .67437 Metetra
.498 .886 .961 r
.25065 .67437 .25704 .67496 .26613 .67227 .25977 .67167 Metetra
.498 .886 .961 r
.25977 .67167 .26613 .67227 .27526 .66958 .26893 .66897 Metetra
.498 .886 .961 r
.26893 .66897 .27526 .66958 .28442 .66688 .27812 .66625 Metetra
.498 .886 .961 r
.27812 .66625 .28442 .66688 .29361 .66417 .28734 .66353 Metetra
.498 .886 .961 r
.28734 .66353 .29361 .66417 .30284 .66145 .2966 .6608 Metetra
.498 .886 .961 r
.2966 .6608 .30284 .66145 .31209 .65872 .30588 .65805 Metetra
.498 .886 .961 r
.30588 .65805 .31209 .65872 .32138 .65598 .3152 .6553 Metetra
.498 .886 .961 r
.3152 .6553 .32138 .65598 .3307 .65324 .32455 .65254 Metetra
.498 .886 .961 r
.32455 .65254 .3307 .65324 .34005 .65048 .33394 .64977 Metetra
.498 .886 .961 r
.33394 .64977 .34005 .65048 .34944 .64771 .34336 .64699 Metetra
.498 .886 .961 r
.34336 .64699 .34944 .64771 .35886 .64493 .35281 .64419 Metetra
.498 .886 .961 r
.35281 .64419 .35886 .64493 .36831 .64214 .3623 .64139 Metetra
.498 .886 .961 r
.3623 .64139 .36831 .64214 .3778 .63935 .37182 .63858 Metetra
.498 .886 .961 r
.37182 .63858 .3778 .63935 .38732 .63654 .38137 .63576 Metetra
.498 .886 .961 r
.38137 .63576 .38732 .63654 .39688 .63372 .39096 .63293 Metetra
.498 .886 .961 r
.39096 .63293 .39688 .63372 .40647 .6309 .40058 .63009 Metetra
.498 .886 .961 r
.40058 .63009 .40647 .6309 .41609 .62806 .41024 .62723 Metetra
.498 .886 .961 r
.41024 .62723 .41609 .62806 .42575 .62521 .41993 .62437 Metetra
.498 .886 .961 r
.41993 .62437 .42575 .62521 .43544 .62235 .42965 .6215 Metetra
.498 .886 .961 r
.42965 .6215 .43544 .62235 .44517 .61948 .43942 .61862 Metetra
.498 .886 .961 r
.43942 .61862 .44517 .61948 .45493 .6166 .44921 .61572 Metetra
.498 .886 .961 r
.44921 .61572 .45493 .6166 .46473 .61372 .45905 .61282 Metetra
.498 .886 .961 r
.45905 .61282 .46473 .61372 .47456 .61082 .46891 .6099 Metetra
.498 .886 .961 r
.46891 .6099 .47456 .61082 .48443 .60791 .47882 .60698 Metetra
.498 .886 .961 r
.47882 .60698 .48443 .60791 .49433 .60499 .48876 .60404 Metetra
.498 .886 .961 r
.48876 .60404 .49433 .60499 .50427 .60206 .49873 .6011 Metetra
.498 .886 .961 r
.49873 .6011 .50427 .60206 .51425 .59911 .50875 .59814 Metetra
.498 .886 .961 r
.50875 .59814 .51425 .59911 .52426 .59616 .5188 .59517 Metetra
.498 .886 .961 r
.5188 .59517 .52426 .59616 .53431 .5932 .52888 .59219 Metetra
.498 .886 .961 r
.52888 .59219 .53431 .5932 .5444 .59022 .53901 .5892 Metetra
.498 .886 .961 r
.53901 .5892 .5444 .59022 .55452 .58724 .54917 .5862 Metetra
.498 .886 .961 r
.54917 .5862 .55452 .58724 .56468 .58424 .55937 .58319 Metetra
.498 .886 .961 r
.55937 .58319 .56468 .58424 .57488 .58124 .5696 .58016 Metetra
.498 .886 .961 r
.5696 .58016 .57488 .58124 .58511 .57822 .57988 .57713 Metetra
.498 .886 .961 r
.57988 .57713 .58511 .57822 .59539 .57519 .59019 .57408 Metetra
.498 .886 .961 r
.59019 .57408 .59539 .57519 .6057 .57215 .60054 .57103 Metetra
.498 .886 .961 r
.60054 .57103 .6057 .57215 .61605 .5691 .61093 .56796 Metetra
.498 .886 .961 r
.61093 .56796 .61605 .5691 .62643 .56603 .62136 .56488 Metetra
.498 .886 .961 r
.62136 .56488 .62643 .56603 .63686 .56296 .63183 .56179 Metetra
.498 .886 .961 r
.63183 .56179 .63686 .56296 .64733 .55987 .64233 .55868 Metetra
.498 .886 .961 r
.64233 .55868 .64733 .55987 .65783 .55677 .65288 .55557 Metetra
.498 .886 .961 r
.65288 .55557 .65783 .55677 .66837 .55367 .66346 .55244 Metetra
.498 .886 .961 r
.66346 .55244 .66837 .55367 .67896 .55054 .67409 .54931 Metetra
.498 .886 .961 r
.67409 .54931 .67896 .55054 .68958 .54741 .68475 .54616 Metetra
.498 .886 .961 r
.68475 .54616 .68958 .54741 .70025 .54427 .69546 .54299 Metetra
.498 .886 .961 r
.69546 .54299 .70025 .54427 .71095 .54111 .70621 .53982 Metetra
.498 .886 .961 r
.70621 .53982 .71095 .54111 .72169 .53794 .71699 .53663 Metetra
.498 .886 .961 r
.71699 .53663 .72169 .53794 .73248 .53476 .72782 .53344 Metetra
.498 .886 .961 r
.72782 .53344 .73248 .53476 .7433 .53157 .73869 .53023 Metetra
.498 .886 .961 r
.73869 .53023 .7433 .53157 .75417 .52837 .7496 .527 Metetra
.498 .886 .961 r
.7496 .527 .75417 .52837 .76508 .52515 .76056 .52377 Metetra
.498 .886 .961 r
.76056 .52377 .76508 .52515 .77603 .52192 .77155 .52052 Metetra
.498 .886 .961 r
.77155 .52052 .77603 .52192 .78702 .51868 .78259 .51726 Metetra
.498 .886 .961 r
.78259 .51726 .78702 .51868 .79805 .51543 .79367 .51399 Metetra
.498 .886 .961 r
.79367 .51399 .79805 .51543 .80913 .51216 .80479 .5107 Metetra
.498 .886 .961 r
.80479 .5107 .80913 .51216 .82025 .50888 .81595 .50741 Metetra
.498 .886 .961 r
.81595 .50741 .82025 .50888 .83141 .50559 .82716 .5041 Metetra
.498 .886 .961 r
.82716 .5041 .83141 .50559 .84261 .50229 .83842 .50077 Metetra
.498 .886 .961 r
.83842 .50077 .84261 .50229 .85386 .49897 .84971 .49744 Metetra
.498 .886 .961 r
.84971 .49744 .85386 .49897 .86515 .49564 .86105 .49409 Metetra
.498 .886 .961 r
.86105 .49409 .86515 .49564 .87649 .4923 .87243 .49073 Metetra
.498 .886 .961 r
.87243 .49073 .87649 .4923 .88787 .48894 .88386 .48735 Metetra
.647 .752 .926 r
.23546 .67181 .24155 .67705 .25065 .67437 .24458 .6691 Metetra
.647 .752 .926 r
.24458 .6691 .25065 .67437 .25977 .67167 .25372 .66639 Metetra
.647 .752 .926 r
.25372 .66639 .25977 .67167 .26893 .66897 .26289 .66367 Metetra
.647 .752 .926 r
.26289 .66367 .26893 .66897 .27812 .66625 .2721 .66094 Metetra
.647 .752 .926 r
.2721 .66094 .27812 .66625 .28734 .66353 .28134 .65819 Metetra
.647 .752 .926 r
.28134 .65819 .28734 .66353 .2966 .6608 .29061 .65544 Metetra
.647 .752 .926 r
.29061 .65544 .2966 .6608 .30588 .65805 .29992 .65268 Metetra
.647 .752 .926 r
.29992 .65268 .30588 .65805 .3152 .6553 .30926 .64991 Metetra
.647 .752 .926 r
.30926 .64991 .3152 .6553 .32455 .65254 .31863 .64713 Metetra
.647 .752 .926 r
.31863 .64713 .32455 .65254 .33394 .64977 .32804 .64434 Metetra
.647 .752 .926 r
.32804 .64434 .33394 .64977 .34336 .64699 .33747 .64154 Metetra
.647 .752 .926 r
.33747 .64154 .34336 .64699 .35281 .64419 .34695 .63873 Metetra
.647 .752 .926 r
.34695 .63873 .35281 .64419 .3623 .64139 .35645 .63591 Metetra
.647 .752 .926 r
.35645 .63591 .3623 .64139 .37182 .63858 .36599 .63308 Metetra
.647 .752 .926 r
.36599 .63308 .37182 .63858 .38137 .63576 .37557 .63024 Metetra
.647 .752 .926 r
.37557 .63024 .38137 .63576 .39096 .63293 .38517 .62739 Metetra
.647 .752 .926 r
.38517 .62739 .39096 .63293 .40058 .63009 .39482 .62453 Metetra
.647 .752 .926 r
.39482 .62453 .40058 .63009 .41024 .62723 .40449 .62165 Metetra
.647 .752 .926 r
.40449 .62165 .41024 .62723 .41993 .62437 .41421 .61877 Metetra
.647 .752 .926 r
.41421 .61877 .41993 .62437 .42965 .6215 .42396 .61588 Metetra
.647 .752 .926 r
.42396 .61588 .42965 .6215 .43942 .61862 .43374 .61298 Metetra
.647 .752 .926 r
.43374 .61298 .43942 .61862 .44921 .61572 .44356 .61006 Metetra
.647 .752 .926 r
.44356 .61006 .44921 .61572 .45905 .61282 .45341 .60714 Metetra
.647 .752 .926 r
.45341 .60714 .45905 .61282 .46891 .6099 .4633 .60421 Metetra
.647 .752 .926 r
.4633 .60421 .46891 .6099 .47882 .60698 .47323 .60126 Metetra
.647 .752 .926 r
.47323 .60126 .47882 .60698 .48876 .60404 .48319 .59831 Metetra
.647 .752 .926 r
.48319 .59831 .48876 .60404 .49873 .6011 .49319 .59534 Metetra
.647 .752 .926 r
.49319 .59534 .49873 .6011 .50875 .59814 .50323 .59236 Metetra
.647 .752 .926 r
.50323 .59236 .50875 .59814 .5188 .59517 .5133 .58937 Metetra
.647 .752 .926 r
.5133 .58937 .5188 .59517 .52888 .59219 .52341 .58637 Metetra
.647 .752 .926 r
.52341 .58637 .52888 .59219 .53901 .5892 .53356 .58336 Metetra
.647 .752 .926 r
.53356 .58336 .53901 .5892 .54917 .5862 .54374 .58034 Metetra
.647 .752 .926 r
.54374 .58034 .54917 .5862 .55937 .58319 .55396 .57731 Metetra
.647 .752 .926 r
.55396 .57731 .55937 .58319 .5696 .58016 .56422 .57426 Metetra
.647 .752 .926 r
.56422 .57426 .5696 .58016 .57988 .57713 .57452 .57121 Metetra
.647 .752 .926 r
.57452 .57121 .57988 .57713 .59019 .57408 .58486 .56814 Metetra
.647 .752 .926 r
.58486 .56814 .59019 .57408 .60054 .57103 .59524 .56506 Metetra
.647 .752 .926 r
.59524 .56506 .60054 .57103 .61093 .56796 .60565 .56197 Metetra
.647 .752 .926 r
.60565 .56197 .61093 .56796 .62136 .56488 .6161 .55887 Metetra
.647 .752 .926 r
.6161 .55887 .62136 .56488 .63183 .56179 .6266 .55576 Metetra
.647 .752 .926 r
.6266 .55576 .63183 .56179 .64233 .55868 .63713 .55263 Metetra
.647 .752 .926 r
.63713 .55263 .64233 .55868 .65288 .55557 .6477 .5495 Metetra
.647 .752 .926 r
.6477 .5495 .65288 .55557 .66346 .55244 .65831 .54635 Metetra
.647 .752 .926 r
.65831 .54635 .66346 .55244 .67409 .54931 .66896 .54319 Metetra
.647 .752 .926 r
.66896 .54319 .67409 .54931 .68475 .54616 .67966 .54001 Metetra
.647 .752 .926 r
.67966 .54001 .68475 .54616 .69546 .54299 .69039 .53683 Metetra
.647 .752 .926 r
.69039 .53683 .69546 .54299 .70621 .53982 .70116 .53363 Metetra
.647 .752 .926 r
.70116 .53363 .70621 .53982 .71699 .53663 .71198 .53043 Metetra
.647 .752 .926 r
.71198 .53043 .71699 .53663 .72782 .53344 .72283 .5272 Metetra
.647 .752 .926 r
.72283 .5272 .72782 .53344 .73869 .53023 .73373 .52397 Metetra
.647 .752 .926 r
.73373 .52397 .73869 .53023 .7496 .527 .74467 .52073 Metetra
.647 .752 .926 r
.74467 .52073 .7496 .527 .76056 .52377 .75565 .51747 Metetra
.647 .752 .926 r
.75565 .51747 .76056 .52377 .77155 .52052 .76667 .5142 Metetra
.647 .752 .926 r
.76667 .5142 .77155 .52052 .78259 .51726 .77774 .51091 Metetra
.647 .752 .926 r
.77774 .51091 .78259 .51726 .79367 .51399 .78885 .50762 Metetra
.647 .752 .926 r
.78885 .50762 .79367 .51399 .80479 .5107 .8 .50431 Metetra
.647 .752 .926 r
.8 .50431 .80479 .5107 .81595 .50741 .8112 .50099 Metetra
.647 .752 .926 r
.8112 .50099 .81595 .50741 .82716 .5041 .82243 .49765 Metetra
.647 .752 .926 r
.82243 .49765 .82716 .5041 .83842 .50077 .83372 .49431 Metetra
.647 .752 .926 r
.83372 .49431 .83842 .50077 .84971 .49744 .84504 .49095 Metetra
.647 .752 .926 r
.84504 .49095 .84971 .49744 .86105 .49409 .85641 .48757 Metetra
.647 .752 .926 r
.85641 .48757 .86105 .49409 .87243 .49073 .86783 .48418 Metetra
.647 .752 .926 r
.86783 .48418 .87243 .49073 .88386 .48735 .87929 .48078 Metetra
.622 .838 .983 r
.22915 .66875 .23546 .67181 .24458 .6691 .23828 .66603 Metetra
.622 .838 .983 r
.23828 .66603 .24458 .6691 .25372 .66639 .24745 .6633 Metetra
.622 .838 .983 r
.24745 .6633 .25372 .66639 .26289 .66367 .25665 .66057 Metetra
.622 .838 .983 r
.25665 .66057 .26289 .66367 .2721 .66094 .26588 .65782 Metetra
.622 .838 .983 r
.26588 .65782 .2721 .66094 .28134 .65819 .27514 .65506 Metetra
.622 .838 .983 r
.27514 .65506 .28134 .65819 .29061 .65544 .28444 .65229 Metetra
.622 .838 .983 r
.28444 .65229 .29061 .65544 .29992 .65268 .29377 .64952 Metetra
.622 .838 .983 r
.29377 .64952 .29992 .65268 .30926 .64991 .30314 .64673 Metetra
.622 .838 .983 r
.30314 .64673 .30926 .64991 .31863 .64713 .31253 .64393 Metetra
.622 .838 .983 r
.31253 .64393 .31863 .64713 .32804 .64434 .32196 .64113 Metetra
.622 .838 .983 r
.32196 .64113 .32804 .64434 .33747 .64154 .33143 .63831 Metetra
.622 .838 .983 r
.33143 .63831 .33747 .64154 .34695 .63873 .34092 .63548 Metetra
.622 .838 .983 r
.34092 .63548 .34695 .63873 .35645 .63591 .35046 .63264 Metetra
.622 .838 .983 r
.35046 .63264 .35645 .63591 .36599 .63308 .36002 .6298 Metetra
.622 .838 .983 r
.36002 .6298 .36599 .63308 .37557 .63024 .36962 .62694 Metetra
.622 .838 .983 r
.36962 .62694 .37557 .63024 .38517 .62739 .37926 .62407 Metetra
.622 .838 .983 r
.37926 .62407 .38517 .62739 .39482 .62453 .38893 .62119 Metetra
.622 .838 .983 r
.38893 .62119 .39482 .62453 .40449 .62165 .39863 .6183 Metetra
.622 .838 .983 r
.39863 .6183 .40449 .62165 .41421 .61877 .40837 .61541 Metetra
.622 .838 .983 r
.40837 .61541 .41421 .61877 .42396 .61588 .41815 .6125 Metetra
.622 .838 .983 r
.41815 .6125 .42396 .61588 .43374 .61298 .42796 .60958 Metetra
.622 .838 .983 r
.42796 .60958 .43374 .61298 .44356 .61006 .43781 .60664 Metetra
.622 .838 .983 r
.43781 .60664 .44356 .61006 .45341 .60714 .44769 .6037 Metetra
.622 .838 .983 r
.44769 .6037 .45341 .60714 .4633 .60421 .45761 .60075 Metetra
.622 .838 .983 r
.45761 .60075 .4633 .60421 .47323 .60126 .46756 .59779 Metetra
.622 .838 .983 r
.46756 .59779 .47323 .60126 .48319 .59831 .47756 .59481 Metetra
.622 .838 .983 r
.47756 .59481 .48319 .59831 .49319 .59534 .48759 .59183 Metetra
.622 .838 .983 r
.48759 .59183 .49319 .59534 .50323 .59236 .49765 .58883 Metetra
.622 .838 .983 r
.49765 .58883 .50323 .59236 .5133 .58937 .50775 .58583 Metetra
.622 .838 .983 r
.50775 .58583 .5133 .58937 .52341 .58637 .51789 .58281 Metetra
.622 .838 .983 r
.51789 .58281 .52341 .58637 .53356 .58336 .52807 .57978 Metetra
.622 .838 .983 r
.52807 .57978 .53356 .58336 .54374 .58034 .53829 .57674 Metetra
.622 .838 .983 r
.53829 .57674 .54374 .58034 .55396 .57731 .54854 .57369 Metetra
.622 .838 .983 r
.54854 .57369 .55396 .57731 .56422 .57426 .55883 .57062 Metetra
.622 .838 .983 r
.55883 .57062 .56422 .57426 .57452 .57121 .56916 .56755 Metetra
.622 .838 .983 r
.56916 .56755 .57452 .57121 .58486 .56814 .57953 .56446 Metetra
.622 .838 .983 r
.57953 .56446 .58486 .56814 .59524 .56506 .58994 .56136 Metetra
.622 .838 .983 r
.58994 .56136 .59524 .56506 .60565 .56197 .60039 .55825 Metetra
.622 .838 .983 r
.60039 .55825 .60565 .56197 .6161 .55887 .61087 .55513 Metetra
.622 .838 .983 r
.61087 .55513 .6161 .55887 .6266 .55576 .6214 .552 Metetra
.622 .838 .983 r
.6214 .552 .6266 .55576 .63713 .55263 .63196 .54885 Metetra
.622 .838 .983 r
.63196 .54885 .63713 .55263 .6477 .5495 .64257 .5457 Metetra
.622 .838 .983 r
.64257 .5457 .6477 .5495 .65831 .54635 .65321 .54253 Metetra
.622 .838 .983 r
.65321 .54253 .65831 .54635 .66896 .54319 .6639 .53935 Metetra
.622 .838 .983 r
.6639 .53935 .66896 .54319 .67966 .54001 .67463 .53616 Metetra
.622 .838 .983 r
.67463 .53616 .67966 .54001 .69039 .53683 .68539 .53295 Metetra
.622 .838 .983 r
.68539 .53295 .69039 .53683 .70116 .53363 .6962 .52973 Metetra
.622 .838 .983 r
.6962 .52973 .70116 .53363 .71198 .53043 .70705 .52651 Metetra
.622 .838 .983 r
.70705 .52651 .71198 .53043 .72283 .5272 .71794 .52326 Metetra
.622 .838 .983 r
.71794 .52326 .72283 .5272 .73373 .52397 .72888 .52001 Metetra
.622 .838 .983 r
.72888 .52001 .73373 .52397 .74467 .52073 .73985 .51674 Metetra
.622 .838 .983 r
.73985 .51674 .74467 .52073 .75565 .51747 .75087 .51346 Metetra
.622 .838 .983 r
.75087 .51346 .75565 .51747 .76667 .5142 .76193 .51017 Metetra
.622 .838 .983 r
.76193 .51017 .76667 .5142 .77774 .51091 .77303 .50687 Metetra
.622 .838 .983 r
.77303 .50687 .77774 .51091 .78885 .50762 .78418 .50355 Metetra
.622 .838 .983 r
.78418 .50355 .78885 .50762 .8 .50431 .79537 .50022 Metetra
.622 .838 .983 r
.79537 .50022 .8 .50431 .8112 .50099 .8066 .49687 Metetra
.622 .838 .983 r
.8066 .49687 .8112 .50099 .82243 .49765 .81788 .49352 Metetra
.622 .838 .983 r
.81788 .49352 .82243 .49765 .83372 .49431 .8292 .49015 Metetra
.622 .838 .983 r
.8292 .49015 .83372 .49431 .84504 .49095 .84057 .48677 Metetra
.622 .838 .983 r
.84057 .48677 .84504 .49095 .85641 .48757 .85198 .48337 Metetra
.622 .838 .983 r
.85198 .48337 .85641 .48757 .86783 .48418 .86343 .47996 Metetra
.622 .838 .983 r
.86343 .47996 .86783 .48418 .87929 .48078 .87493 .47654 Metetra
.646 .762 .934 r
.22295 .66372 .22915 .66875 .23828 .66603 .2321 .66099 Metetra
.646 .762 .934 r
.2321 .66099 .23828 .66603 .24745 .6633 .24129 .65824 Metetra
.646 .762 .934 r
.24129 .65824 .24745 .6633 .25665 .66057 .25051 .65549 Metetra
.646 .762 .934 r
.25051 .65549 .25665 .66057 .26588 .65782 .25976 .65272 Metetra
.646 .762 .934 r
.25976 .65272 .26588 .65782 .27514 .65506 .26904 .64994 Metetra
.646 .762 .934 r
.26904 .64994 .27514 .65506 .28444 .65229 .27836 .64716 Metetra
.646 .762 .934 r
.27836 .64716 .28444 .65229 .29377 .64952 .28771 .64436 Metetra
.646 .762 .934 r
.28771 .64436 .29377 .64952 .30314 .64673 .29709 .64156 Metetra
.646 .762 .934 r
.29709 .64156 .30314 .64673 .31253 .64393 .30651 .63874 Metetra
.646 .762 .934 r
.30651 .63874 .31253 .64393 .32196 .64113 .31596 .63592 Metetra
.646 .762 .934 r
.31596 .63592 .32196 .64113 .33143 .63831 .32545 .63308 Metetra
.646 .762 .934 r
.32545 .63308 .33143 .63831 .34092 .63548 .33496 .63024 Metetra
.646 .762 .934 r
.33496 .63024 .34092 .63548 .35046 .63264 .34452 .62738 Metetra
.646 .762 .934 r
.34452 .62738 .35046 .63264 .36002 .6298 .3541 .62451 Metetra
.646 .762 .934 r
.3541 .62451 .36002 .6298 .36962 .62694 .36373 .62164 Metetra
.646 .762 .934 r
.36373 .62164 .36962 .62694 .37926 .62407 .37338 .61875 Metetra
.646 .762 .934 r
.37338 .61875 .37926 .62407 .38893 .62119 .38307 .61585 Metetra
.646 .762 .934 r
.38307 .61585 .38893 .62119 .39863 .6183 .3928 .61294 Metetra
.646 .762 .934 r
.3928 .61294 .39863 .6183 .40837 .61541 .40256 .61003 Metetra
.646 .762 .934 r
.40256 .61003 .40837 .61541 .41815 .6125 .41236 .6071 Metetra
.646 .762 .934 r
.41236 .6071 .41815 .6125 .42796 .60958 .4222 .60416 Metetra
.646 .762 .934 r
.4222 .60416 .42796 .60958 .43781 .60664 .43207 .60121 Metetra
.646 .762 .934 r
.43207 .60121 .43781 .60664 .44769 .6037 .44197 .59824 Metetra
.646 .762 .934 r
.44197 .59824 .44769 .6037 .45761 .60075 .45191 .59527 Metetra
.646 .762 .934 r
.45191 .59527 .45761 .60075 .46756 .59779 .46189 .59229 Metetra
.646 .762 .934 r
.46189 .59229 .46756 .59779 .47756 .59481 .47191 .58929 Metetra
.646 .762 .934 r
.47191 .58929 .47756 .59481 .48759 .59183 .48196 .58629 Metetra
.646 .762 .934 r
.48196 .58629 .48759 .59183 .49765 .58883 .49205 .58327 Metetra
.646 .762 .934 r
.49205 .58327 .49765 .58883 .50775 .58583 .50218 .58024 Metetra
.646 .762 .934 r
.50218 .58024 .50775 .58583 .51789 .58281 .51234 .57721 Metetra
.646 .762 .934 r
.51234 .57721 .51789 .58281 .52807 .57978 .52254 .57416 Metetra
.646 .762 .934 r
.52254 .57416 .52807 .57978 .53829 .57674 .53278 .57109 Metetra
.646 .762 .934 r
.53278 .57109 .53829 .57674 .54854 .57369 .54306 .56802 Metetra
.646 .762 .934 r
.54306 .56802 .54854 .57369 .55883 .57062 .55338 .56494 Metetra
.646 .762 .934 r
.55338 .56494 .55883 .57062 .56916 .56755 .56374 .56184 Metetra
.646 .762 .934 r
.56374 .56184 .56916 .56755 .57953 .56446 .57413 .55873 Metetra
.646 .762 .934 r
.57413 .55873 .57953 .56446 .58994 .56136 .58456 .55561 Metetra
.646 .762 .934 r
.58456 .55561 .58994 .56136 .60039 .55825 .59504 .55248 Metetra
.646 .762 .934 r
.59504 .55248 .60039 .55825 .61087 .55513 .60555 .54934 Metetra
.646 .762 .934 r
.60555 .54934 .61087 .55513 .6214 .552 .6161 .54618 Metetra
.646 .762 .934 r
.6161 .54618 .6214 .552 .63196 .54885 .62669 .54302 Metetra
.646 .762 .934 r
.62669 .54302 .63196 .54885 .64257 .5457 .63733 .53984 Metetra
.646 .762 .934 r
.63733 .53984 .64257 .5457 .65321 .54253 .648 .53665 Metetra
.646 .762 .934 r
.648 .53665 .65321 .54253 .6639 .53935 .65871 .53345 Metetra
.646 .762 .934 r
.65871 .53345 .6639 .53935 .67463 .53616 .66947 .53023 Metetra
.646 .762 .934 r
.66947 .53023 .67463 .53616 .68539 .53295 .68026 .527 Metetra
.646 .762 .934 r
.68026 .527 .68539 .53295 .6962 .52973 .6911 .52376 Metetra
.646 .762 .934 r
.6911 .52376 .6962 .52973 .70705 .52651 .70198 .52051 Metetra
.646 .762 .934 r
.70198 .52051 .70705 .52651 .71794 .52326 .7129 .51725 Metetra
.646 .762 .934 r
.7129 .51725 .71794 .52326 .72888 .52001 .72386 .51397 Metetra
.646 .762 .934 r
.72386 .51397 .72888 .52001 .73985 .51674 .73487 .51068 Metetra
.646 .762 .934 r
.73487 .51068 .73985 .51674 .75087 .51346 .74591 .50738 Metetra
.646 .762 .934 r
.74591 .50738 .75087 .51346 .76193 .51017 .757 .50406 Metetra
.646 .762 .934 r
.757 .50406 .76193 .51017 .77303 .50687 .76814 .50073 Metetra
.646 .762 .934 r
.76814 .50073 .77303 .50687 .78418 .50355 .77931 .49739 Metetra
.646 .762 .934 r
.77931 .49739 .78418 .50355 .79537 .50022 .79053 .49404 Metetra
.646 .762 .934 r
.79053 .49404 .79537 .50022 .8066 .49687 .8018 .49067 Metetra
.646 .762 .934 r
.8018 .49067 .8066 .49687 .81788 .49352 .81311 .48729 Metetra
.646 .762 .934 r
.81311 .48729 .81788 .49352 .8292 .49015 .82446 .48389 Metetra
.646 .762 .934 r
.82446 .48389 .8292 .49015 .84057 .48677 .83586 .48049 Metetra
.646 .762 .934 r
.83586 .48049 .84057 .48677 .85198 .48337 .8473 .47706 Metetra
.646 .762 .934 r
.8473 .47706 .85198 .48337 .86343 .47996 .85879 .47363 Metetra
.646 .762 .934 r
.85879 .47363 .86343 .47996 .87493 .47654 .87032 .47018 Metetra
.647 .696 .881 r
.21689 .65671 .22295 .66372 .2321 .66099 .22605 .65396 Metetra
.647 .696 .881 r
.22605 .65396 .2321 .66099 .24129 .65824 .23525 .65119 Metetra
.647 .696 .881 r
.23525 .65119 .24129 .65824 .25051 .65549 .24449 .64841 Metetra
.647 .696 .881 r
.24449 .64841 .25051 .65549 .25976 .65272 .25375 .64563 Metetra
.647 .696 .881 r
.25375 .64563 .25976 .65272 .26904 .64994 .26305 .64283 Metetra
.647 .696 .881 r
.26305 .64283 .26904 .64994 .27836 .64716 .27238 .64003 Metetra
.647 .696 .881 r
.27238 .64003 .27836 .64716 .28771 .64436 .28175 .63721 Metetra
.647 .696 .881 r
.28175 .63721 .28771 .64436 .29709 .64156 .29114 .63439 Metetra
.647 .696 .881 r
.29114 .63439 .29709 .64156 .30651 .63874 .30058 .63155 Metetra
.647 .696 .881 r
.30058 .63155 .30651 .63874 .31596 .63592 .31004 .6287 Metetra
.647 .696 .881 r
.31004 .6287 .31596 .63592 .32545 .63308 .31954 .62585 Metetra
.647 .696 .881 r
.31954 .62585 .32545 .63308 .33496 .63024 .32908 .62298 Metetra
.647 .696 .881 r
.32908 .62298 .33496 .63024 .34452 .62738 .33865 .6201 Metetra
.647 .696 .881 r
.33865 .6201 .34452 .62738 .3541 .62451 .34825 .61722 Metetra
.647 .696 .881 r
.34825 .61722 .3541 .62451 .36373 .62164 .35789 .61432 Metetra
.647 .696 .881 r
.35789 .61432 .36373 .62164 .37338 .61875 .36756 .61141 Metetra
.647 .696 .881 r
.36756 .61141 .37338 .61875 .38307 .61585 .37727 .60849 Metetra
.647 .696 .881 r
.37727 .60849 .38307 .61585 .3928 .61294 .38701 .60556 Metetra
.647 .696 .881 r
.38701 .60556 .3928 .61294 .40256 .61003 .39679 .60262 Metetra
.647 .696 .881 r
.39679 .60262 .40256 .61003 .41236 .6071 .4066 .59967 Metetra
.647 .696 .881 r
.4066 .59967 .41236 .6071 .4222 .60416 .41646 .59671 Metetra
.647 .696 .881 r
.41646 .59671 .4222 .60416 .43207 .60121 .42634 .59374 Metetra
.647 .696 .881 r
.42634 .59374 .43207 .60121 .44197 .59824 .43627 .59075 Metetra
.647 .696 .881 r
.43627 .59075 .44197 .59824 .45191 .59527 .44622 .58776 Metetra
.647 .696 .881 r
.44622 .58776 .45191 .59527 .46189 .59229 .45622 .58475 Metetra
.647 .696 .881 r
.45622 .58475 .46189 .59229 .47191 .58929 .46625 .58174 Metetra
.647 .696 .881 r
.46625 .58174 .47191 .58929 .48196 .58629 .47632 .57871 Metetra
.647 .696 .881 r
.47632 .57871 .48196 .58629 .49205 .58327 .48643 .57567 Metetra
.647 .696 .881 r
.48643 .57567 .49205 .58327 .50218 .58024 .49658 .57262 Metetra
.647 .696 .881 r
.49658 .57262 .50218 .58024 .51234 .57721 .50676 .56956 Metetra
.647 .696 .881 r
.50676 .56956 .51234 .57721 .52254 .57416 .51698 .56648 Metetra
.647 .696 .881 r
.51698 .56648 .52254 .57416 .53278 .57109 .52724 .5634 Metetra
.647 .696 .881 r
.52724 .5634 .53278 .57109 .54306 .56802 .53754 .5603 Metetra
.647 .696 .881 r
.53754 .5603 .54306 .56802 .55338 .56494 .54788 .5572 Metetra
.647 .696 .881 r
.54788 .5572 .55338 .56494 .56374 .56184 .55825 .55408 Metetra
.647 .696 .881 r
.55825 .55408 .56374 .56184 .57413 .55873 .56866 .55095 Metetra
.647 .696 .881 r
.56866 .55095 .57413 .55873 .58456 .55561 .57912 .5478 Metetra
.647 .696 .881 r
.57912 .5478 .58456 .55561 .59504 .55248 .58961 .54465 Metetra
.647 .696 .881 r
.58961 .54465 .59504 .55248 .60555 .54934 .60014 .54148 Metetra
.647 .696 .881 r
.60014 .54148 .60555 .54934 .6161 .54618 .61072 .5383 Metetra
.647 .696 .881 r
.61072 .5383 .6161 .54618 .62669 .54302 .62133 .53511 Metetra
.647 .696 .881 r
.62133 .53511 .62669 .54302 .63733 .53984 .63198 .53191 Metetra
.647 .696 .881 r
.63198 .53191 .63733 .53984 .648 .53665 .64268 .52869 Metetra
.647 .696 .881 r
.64268 .52869 .648 .53665 .65871 .53345 .65341 .52546 Metetra
.647 .696 .881 r
.65341 .52546 .65871 .53345 .66947 .53023 .66419 .52223 Metetra
.647 .696 .881 r
.66419 .52223 .66947 .53023 .68026 .527 .675 .51897 Metetra
.647 .696 .881 r
.675 .51897 .68026 .527 .6911 .52376 .68586 .51571 Metetra
.647 .696 .881 r
.68586 .51571 .6911 .52376 .70198 .52051 .69676 .51243 Metetra
.647 .696 .881 r
.69676 .51243 .70198 .52051 .7129 .51725 .7077 .50914 Metetra
.647 .696 .881 r
.7077 .50914 .7129 .51725 .72386 .51397 .71869 .50584 Metetra
.647 .696 .881 r
.71869 .50584 .72386 .51397 .73487 .51068 .72972 .50252 Metetra
.647 .696 .881 r
.72972 .50252 .73487 .51068 .74591 .50738 .74079 .49919 Metetra
.647 .696 .881 r
.74079 .49919 .74591 .50738 .757 .50406 .7519 .49585 Metetra
.647 .696 .881 r
.7519 .49585 .757 .50406 .76814 .50073 .76306 .4925 Metetra
.647 .696 .881 r
.76306 .4925 .76814 .50073 .77931 .49739 .77426 .48913 Metetra
.647 .696 .881 r
.77426 .48913 .77931 .49739 .79053 .49404 .7855 .48575 Metetra
.647 .696 .881 r
.7855 .48575 .79053 .49404 .8018 .49067 .79679 .48236 Metetra
.647 .696 .881 r
.79679 .48236 .8018 .49067 .81311 .48729 .80812 .47895 Metetra
.647 .696 .881 r
.80812 .47895 .81311 .48729 .82446 .48389 .8195 .47553 Metetra
.647 .696 .881 r
.8195 .47553 .82446 .48389 .83586 .48049 .83092 .47209 Metetra
.647 .696 .881 r
.83092 .47209 .83586 .48049 .8473 .47706 .84239 .46865 Metetra
.647 .696 .881 r
.84239 .46865 .8473 .47706 .85879 .47363 .8539 .46518 Metetra
.647 .696 .881 r
.8539 .46518 .85879 .47363 .87032 .47018 .86546 .46171 Metetra
.645 .773 .941 r
.21059 .6519 .21689 .65671 .22605 .65396 .21977 .64913 Metetra
.645 .773 .941 r
.21977 .64913 .22605 .65396 .23525 .65119 .22899 .64634 Metetra
.645 .773 .941 r
.22899 .64634 .23525 .65119 .24449 .64841 .23825 .64355 Metetra
.645 .773 .941 r
.23825 .64355 .24449 .64841 .25375 .64563 .24753 .64074 Metetra
.645 .773 .941 r
.24753 .64074 .25375 .64563 .26305 .64283 .25685 .63793 Metetra
.645 .773 .941 r
.25685 .63793 .26305 .64283 .27238 .64003 .2662 .63511 Metetra
.645 .773 .941 r
.2662 .63511 .27238 .64003 .28175 .63721 .27559 .63227 Metetra
.645 .773 .941 r
.27559 .63227 .28175 .63721 .29114 .63439 .28501 .62943 Metetra
.645 .773 .941 r
.28501 .62943 .29114 .63439 .30058 .63155 .29446 .62657 Metetra
.645 .773 .941 r
.29446 .62657 .30058 .63155 .31004 .6287 .30395 .62371 Metetra
.645 .773 .941 r
.30395 .62371 .31004 .6287 .31954 .62585 .31347 .62083 Metetra
.645 .773 .941 r
.31347 .62083 .31954 .62585 .32908 .62298 .32302 .61795 Metetra
.645 .773 .941 r
.32302 .61795 .32908 .62298 .33865 .6201 .33261 .61505 Metetra
.645 .773 .941 r
.33261 .61505 .33865 .6201 .34825 .61722 .34224 .61215 Metetra
.645 .773 .941 r
.34224 .61215 .34825 .61722 .35789 .61432 .3519 .60923 Metetra
.645 .773 .941 r
.3519 .60923 .35789 .61432 .36756 .61141 .3616 .6063 Metetra
.645 .773 .941 r
.3616 .6063 .36756 .61141 .37727 .60849 .37133 .60336 Metetra
.645 .773 .941 r
.37133 .60336 .37727 .60849 .38701 .60556 .38109 .60041 Metetra
.645 .773 .941 r
.38109 .60041 .38701 .60556 .39679 .60262 .39089 .59745 Metetra
.645 .773 .941 r
.39089 .59745 .39679 .60262 .4066 .59967 .40073 .59448 Metetra
.645 .773 .941 r
.40073 .59448 .4066 .59967 .41646 .59671 .41061 .5915 Metetra
.645 .773 .941 r
.41061 .5915 .41646 .59671 .42634 .59374 .42052 .58851 Metetra
.645 .773 .941 r
.42052 .58851 .42634 .59374 .43627 .59075 .43046 .58551 Metetra
.645 .773 .941 r
.43046 .58551 .43627 .59075 .44622 .58776 .44045 .58249 Metetra
.645 .773 .941 r
.44045 .58249 .44622 .58776 .45622 .58475 .45047 .57947 Metetra
.645 .773 .941 r
.45047 .57947 .45622 .58475 .46625 .58174 .46053 .57643 Metetra
.645 .773 .941 r
.46053 .57643 .46625 .58174 .47632 .57871 .47062 .57338 Metetra
.645 .773 .941 r
.47062 .57338 .47632 .57871 .48643 .57567 .48075 .57032 Metetra
.645 .773 .941 r
.48075 .57032 .48643 .57567 .49658 .57262 .49092 .56725 Metetra
.645 .773 .941 r
.49092 .56725 .49658 .57262 .50676 .56956 .50113 .56417 Metetra
.645 .773 .941 r
.50113 .56417 .50676 .56956 .51698 .56648 .51138 .56107 Metetra
.645 .773 .941 r
.51138 .56107 .51698 .56648 .52724 .5634 .52166 .55797 Metetra
.645 .773 .941 r
.52166 .55797 .52724 .5634 .53754 .5603 .53199 .55485 Metetra
.645 .773 .941 r
.53199 .55485 .53754 .5603 .54788 .5572 .54235 .55172 Metetra
.645 .773 .941 r
.54235 .55172 .54788 .5572 .55825 .55408 .55275 .54858 Metetra
.645 .773 .941 r
.55275 .54858 .55825 .55408 .56866 .55095 .56319 .54543 Metetra
.645 .773 .941 r
.56319 .54543 .56866 .55095 .57912 .5478 .57367 .54226 Metetra
.645 .773 .941 r
.57367 .54226 .57912 .5478 .58961 .54465 .58419 .53909 Metetra
.645 .773 .941 r
.58419 .53909 .58961 .54465 .60014 .54148 .59475 .5359 Metetra
.645 .773 .941 r
.59475 .5359 .60014 .54148 .61072 .5383 .60536 .5327 Metetra
.645 .773 .941 r
.60536 .5327 .61072 .5383 .62133 .53511 .616 .52948 Metetra
.645 .773 .941 r
.616 .52948 .62133 .53511 .63198 .53191 .62668 .52626 Metetra
.645 .773 .941 r
.62668 .52626 .63198 .53191 .64268 .52869 .6374 .52302 Metetra
.645 .773 .941 r
.6374 .52302 .64268 .52869 .65341 .52546 .64816 .51977 Metetra
.645 .773 .941 r
.64816 .51977 .65341 .52546 .66419 .52223 .65897 .51651 Metetra
.645 .773 .941 r
.65897 .51651 .66419 .52223 .675 .51897 .66981 .51323 Metetra
.645 .773 .941 r
.66981 .51323 .675 .51897 .68586 .51571 .6807 .50994 Metetra
.645 .773 .941 r
.6807 .50994 .68586 .51571 .69676 .51243 .69163 .50664 Metetra
.645 .773 .941 r
.69163 .50664 .69676 .51243 .7077 .50914 .70261 .50333 Metetra
.645 .773 .941 r
.70261 .50333 .7077 .50914 .71869 .50584 .71362 .5 Metetra
.645 .773 .941 r
.71362 .5 .71869 .50584 .72972 .50252 .72468 .49666 Metetra
.645 .773 .941 r
.72468 .49666 .72972 .50252 .74079 .49919 .73578 .49331 Metetra
.645 .773 .941 r
.73578 .49331 .74079 .49919 .7519 .49585 .74693 .48995 Metetra
.645 .773 .941 r
.74693 .48995 .7519 .49585 .76306 .4925 .75811 .48657 Metetra
.645 .773 .941 r
.75811 .48657 .76306 .4925 .77426 .48913 .76935 .48318 Metetra
.645 .773 .941 r
.76935 .48318 .77426 .48913 .7855 .48575 .78062 .47977 Metetra
.645 .773 .941 r
.78062 .47977 .7855 .48575 .79679 .48236 .79194 .47635 Metetra
.645 .773 .941 r
.79194 .47635 .79679 .48236 .80812 .47895 .80331 .47292 Metetra
.645 .773 .941 r
.80331 .47292 .80812 .47895 .8195 .47553 .81472 .46948 Metetra
.645 .773 .941 r
.81472 .46948 .8195 .47553 .83092 .47209 .82617 .46602 Metetra
.645 .773 .941 r
.82617 .46602 .83092 .47209 .84239 .46865 .83767 .46255 Metetra
.645 .773 .941 r
.83767 .46255 .84239 .46865 .8539 .46518 .84922 .45906 Metetra
.645 .773 .941 r
.84922 .45906 .8539 .46518 .86546 .46171 .86081 .45556 Metetra
.64 .632 .826 r
.20468 .64236 .21059 .6519 .21977 .64913 .21387 .63956 Metetra
.64 .632 .826 r
.21387 .63956 .21977 .64913 .22899 .64634 .2231 .63676 Metetra
.64 .632 .826 r
.2231 .63676 .22899 .64634 .23825 .64355 .23236 .63394 Metetra
.64 .632 .826 r
.23236 .63394 .23825 .64355 .24753 .64074 .24166 .63111 Metetra
.64 .632 .826 r
.24166 .63111 .24753 .64074 .25685 .63793 .25098 .62828 Metetra
.64 .632 .826 r
.25098 .62828 .25685 .63793 .2662 .63511 .26034 .62543 Metetra
.64 .632 .826 r
.26034 .62543 .2662 .63511 .27559 .63227 .26974 .62257 Metetra
.64 .632 .826 r
.26974 .62257 .27559 .63227 .28501 .62943 .27917 .6197 Metetra
.64 .632 .826 r
.27917 .6197 .28501 .62943 .29446 .62657 .28863 .61683 Metetra
.64 .632 .826 r
.28863 .61683 .29446 .62657 .30395 .62371 .29812 .61394 Metetra
.64 .632 .826 r
.29812 .61394 .30395 .62371 .31347 .62083 .30765 .61104 Metetra
.64 .632 .826 r
.30765 .61104 .31347 .62083 .32302 .61795 .31722 .60813 Metetra
.64 .632 .826 r
.31722 .60813 .32302 .61795 .33261 .61505 .32682 .60521 Metetra
.64 .632 .826 r
.32682 .60521 .33261 .61505 .34224 .61215 .33645 .60228 Metetra
.64 .632 .826 r
.33645 .60228 .34224 .61215 .3519 .60923 .34612 .59934 Metetra
.64 .632 .826 r
.34612 .59934 .3519 .60923 .3616 .6063 .35583 .59639 Metetra
.64 .632 .826 r
.35583 .59639 .3616 .6063 .37133 .60336 .36557 .59343 Metetra
.64 .632 .826 r
.36557 .59343 .37133 .60336 .38109 .60041 .37534 .59045 Metetra
.64 .632 .826 r
.37534 .59045 .38109 .60041 .39089 .59745 .38515 .58747 Metetra
.64 .632 .826 r
.38515 .58747 .39089 .59745 .40073 .59448 .395 .58447 Metetra
.64 .632 .826 r
.395 .58447 .40073 .59448 .41061 .5915 .40489 .58147 Metetra
.64 .632 .826 r
.40489 .58147 .41061 .5915 .42052 .58851 .41481 .57845 Metetra
.64 .632 .826 r
.41481 .57845 .42052 .58851 .43046 .58551 .42476 .57542 Metetra
.64 .632 .826 r
.42476 .57542 .43046 .58551 .44045 .58249 .43476 .57238 Metetra
.64 .632 .826 r
.43476 .57238 .44045 .58249 .45047 .57947 .44479 .56933 Metetra
.64 .632 .826 r
.44479 .56933 .45047 .57947 .46053 .57643 .45486 .56627 Metetra
.64 .632 .826 r
.45486 .56627 .46053 .57643 .47062 .57338 .46496 .56319 Metetra
.64 .632 .826 r
.46496 .56319 .47062 .57338 .48075 .57032 .47511 .56011 Metetra
.64 .632 .826 r
.47511 .56011 .48075 .57032 .49092 .56725 .48529 .55701 Metetra
.64 .632 .826 r
.48529 .55701 .49092 .56725 .50113 .56417 .49551 .5539 Metetra
.64 .632 .826 r
.49551 .5539 .50113 .56417 .51138 .56107 .50576 .55078 Metetra
.64 .632 .826 r
.50576 .55078 .51138 .56107 .52166 .55797 .51606 .54765 Metetra
.64 .632 .826 r
.51606 .54765 .52166 .55797 .53199 .55485 .5264 .54451 Metetra
.64 .632 .826 r
.5264 .54451 .53199 .55485 .54235 .55172 .53677 .54135 Metetra
.64 .632 .826 r
.53677 .54135 .54235 .55172 .55275 .54858 .54718 .53819 Metetra
.64 .632 .826 r
.54718 .53819 .55275 .54858 .56319 .54543 .55764 .53501 Metetra
.64 .632 .826 r
.55764 .53501 .56319 .54543 .57367 .54226 .56813 .53182 Metetra
.64 .632 .826 r
.56813 .53182 .57367 .54226 .58419 .53909 .57866 .52861 Metetra
.64 .632 .826 r
.57866 .52861 .58419 .53909 .59475 .5359 .58923 .5254 Metetra
.64 .632 .826 r
.58923 .5254 .59475 .5359 .60536 .5327 .59985 .52217 Metetra
.64 .632 .826 r
.59985 .52217 .60536 .5327 .616 .52948 .6105 .51893 Metetra
.64 .632 .826 r
.6105 .51893 .616 .52948 .62668 .52626 .62119 .51568 Metetra
.64 .632 .826 r
.62119 .51568 .62668 .52626 .6374 .52302 .63193 .51241 Metetra
.64 .632 .826 r
.63193 .51241 .6374 .52302 .64816 .51977 .64271 .50914 Metetra
.64 .632 .826 r
.64271 .50914 .64816 .51977 .65897 .51651 .65352 .50584 Metetra
.64 .632 .826 r
.65352 .50584 .65897 .51651 .66981 .51323 .66438 .50254 Metetra
.64 .632 .826 r
.66438 .50254 .66981 .51323 .6807 .50994 .67528 .49923 Metetra
.64 .632 .826 r
.67528 .49923 .6807 .50994 .69163 .50664 .68623 .4959 Metetra
.64 .632 .826 r
.68623 .4959 .69163 .50664 .70261 .50333 .69721 .49256 Metetra
.64 .632 .826 r
.69721 .49256 .70261 .50333 .71362 .5 .70824 .4892 Metetra
.64 .632 .826 r
.70824 .4892 .71362 .5 .72468 .49666 .71932 .48583 Metetra
.64 .632 .826 r
.71932 .48583 .72468 .49666 .73578 .49331 .73043 .48245 Metetra
.64 .632 .826 r
.73043 .48245 .73578 .49331 .74693 .48995 .74159 .47906 Metetra
.64 .632 .826 r
.74159 .47906 .74693 .48995 .75811 .48657 .75279 .47565 Metetra
.64 .632 .826 r
.75279 .47565 .75811 .48657 .76935 .48318 .76404 .47223 Metetra
.64 .632 .826 r
.76404 .47223 .76935 .48318 .78062 .47977 .77533 .4688 Metetra
.64 .632 .826 r
.77533 .4688 .78062 .47977 .79194 .47635 .78666 .46535 Metetra
.64 .632 .826 r
.78666 .46535 .79194 .47635 .80331 .47292 .79804 .46189 Metetra
.64 .632 .826 r
.79804 .46189 .80331 .47292 .81472 .46948 .80947 .45841 Metetra
.64 .632 .826 r
.80947 .45841 .81472 .46948 .82617 .46602 .82094 .45493 Metetra
.64 .632 .826 r
.82094 .45493 .82617 .46602 .83767 .46255 .83245 .45142 Metetra
.64 .632 .826 r
.83245 .45142 .83767 .46255 .84922 .45906 .84402 .44791 Metetra
.64 .632 .826 r
.84402 .44791 .84922 .45906 .86081 .45556 .85562 .44438 Metetra
.582 .879 .993 r
.19802 .64049 .20468 .64236 .21387 .63956 .20724 .63768 Metetra
.582 .879 .993 r
.20724 .63768 .21387 .63956 .2231 .63676 .2165 .63486 Metetra
.582 .879 .993 r
.2165 .63486 .2231 .63676 .23236 .63394 .22578 .63202 Metetra
.582 .879 .993 r
.22578 .63202 .23236 .63394 .24166 .63111 .23511 .62918 Metetra
.582 .879 .993 r
.23511 .62918 .24166 .63111 .25098 .62828 .24446 .62633 Metetra
.582 .879 .993 r
.24446 .62633 .25098 .62828 .26034 .62543 .25385 .62347 Metetra
.582 .879 .993 r
.25385 .62347 .26034 .62543 .26974 .62257 .26327 .62059 Metetra
.582 .879 .993 r
.26327 .62059 .26974 .62257 .27917 .6197 .27273 .61771 Metetra
.582 .879 .993 r
.27273 .61771 .27917 .6197 .28863 .61683 .28222 .61482 Metetra
.582 .879 .993 r
.28222 .61482 .28863 .61683 .29812 .61394 .29175 .61191 Metetra
.582 .879 .993 r
.29175 .61191 .29812 .61394 .30765 .61104 .30131 .609 Metetra
.582 .879 .993 r
.30131 .609 .30765 .61104 .31722 .60813 .3109 .60607 Metetra
.582 .879 .993 r
.3109 .60607 .31722 .60813 .32682 .60521 .32053 .60314 Metetra
.582 .879 .993 r
.32053 .60314 .32682 .60521 .33645 .60228 .3302 .60019 Metetra
.582 .879 .993 r
.3302 .60019 .33645 .60228 .34612 .59934 .3399 .59723 Metetra
.582 .879 .993 r
.3399 .59723 .34612 .59934 .35583 .59639 .34963 .59426 Metetra
.582 .879 .993 r
.34963 .59426 .35583 .59639 .36557 .59343 .3594 .59128 Metetra
.582 .879 .993 r
.3594 .59128 .36557 .59343 .37534 .59045 .36921 .58829 Metetra
.582 .879 .993 r
.36921 .58829 .37534 .59045 .38515 .58747 .37905 .58529 Metetra
.582 .879 .993 r
.37905 .58529 .38515 .58747 .395 .58447 .38893 .58228 Metetra
.582 .879 .993 r
.38893 .58228 .395 .58447 .40489 .58147 .39885 .57926 Metetra
.582 .879 .993 r
.39885 .57926 .40489 .58147 .41481 .57845 .4088 .57622 Metetra
.582 .879 .993 r
.4088 .57622 .41481 .57845 .42476 .57542 .41879 .57318 Metetra
.582 .879 .993 r
.41879 .57318 .42476 .57542 .43476 .57238 .42882 .57012 Metetra
.582 .879 .993 r
.42882 .57012 .43476 .57238 .44479 .56933 .43888 .56705 Metetra
.582 .879 .993 r
.43888 .56705 .44479 .56933 .45486 .56627 .44899 .56397 Metetra
.582 .879 .993 r
.44899 .56397 .45486 .56627 .46496 .56319 .45913 .56088 Metetra
.582 .879 .993 r
.45913 .56088 .46496 .56319 .47511 .56011 .4693 .55778 Metetra
.582 .879 .993 r
.4693 .55778 .47511 .56011 .48529 .55701 .47952 .55466 Metetra
.582 .879 .993 r
.47952 .55466 .48529 .55701 .49551 .5539 .48977 .55153 Metetra
.582 .879 .993 r
.48977 .55153 .49551 .5539 .50576 .55078 .50007 .5484 Metetra
.582 .879 .993 r
.50007 .5484 .50576 .55078 .51606 .54765 .5104 .54525 Metetra
.582 .879 .993 r
.5104 .54525 .51606 .54765 .5264 .54451 .52077 .54208 Metetra
.582 .879 .993 r
.52077 .54208 .5264 .54451 .53677 .54135 .53118 .53891 Metetra
.582 .879 .993 r
.53118 .53891 .53677 .54135 .54718 .53819 .54163 .53572 Metetra
.582 .879 .993 r
.54163 .53572 .54718 .53819 .55764 .53501 .55212 .53253 Metetra
.582 .879 .993 r
.55212 .53253 .55764 .53501 .56813 .53182 .56265 .52931 Metetra
.582 .879 .993 r
.56265 .52931 .56813 .53182 .57866 .52861 .57322 .52609 Metetra
.582 .879 .993 r
.57322 .52609 .57866 .52861 .58923 .5254 .58383 .52286 Metetra
.582 .879 .993 r
.58383 .52286 .58923 .5254 .59985 .52217 .59448 .51961 Metetra
.582 .879 .993 r
.59448 .51961 .59985 .52217 .6105 .51893 .60517 .51635 Metetra
.582 .879 .993 r
.60517 .51635 .6105 .51893 .62119 .51568 .61591 .51308 Metetra
.582 .879 .993 r
.61591 .51308 .62119 .51568 .63193 .51241 .62668 .50979 Metetra
.582 .879 .993 r
.62668 .50979 .63193 .51241 .64271 .50914 .63749 .50649 Metetra
.582 .879 .993 r
.63749 .50649 .64271 .50914 .65352 .50584 .64835 .50318 Metetra
.582 .879 .993 r
.64835 .50318 .65352 .50584 .66438 .50254 .65925 .49986 Metetra
.582 .879 .993 r
.65925 .49986 .66438 .50254 .67528 .49923 .67019 .49652 Metetra
.582 .879 .993 r
.67019 .49652 .67528 .49923 .68623 .4959 .68118 .49318 Metetra
.582 .879 .993 r
.68118 .49318 .68623 .4959 .69721 .49256 .69221 .48981 Metetra
.582 .879 .993 r
.69221 .48981 .69721 .49256 .70824 .4892 .70328 .48644 Metetra
.582 .879 .993 r
.70328 .48644 .70824 .4892 .71932 .48583 .71439 .48305 Metetra
.582 .879 .993 r
.71439 .48305 .71932 .48583 .73043 .48245 .72555 .47965 Metetra
.582 .879 .993 r
.72555 .47965 .73043 .48245 .74159 .47906 .73675 .47623 Metetra
.582 .879 .993 r
.73675 .47623 .74159 .47906 .75279 .47565 .748 .4728 Metetra
.582 .879 .993 r
.748 .4728 .75279 .47565 .76404 .47223 .75928 .46936 Metetra
.582 .879 .993 r
.75928 .46936 .76404 .47223 .77533 .4688 .77062 .46591 Metetra
.582 .879 .993 r
.77062 .46591 .77533 .4688 .78666 .46535 .782 .46244 Metetra
.582 .879 .993 r
.782 .46244 .78666 .46535 .79804 .46189 .79342 .45895 Metetra
.582 .879 .993 r
.79342 .45895 .79804 .46189 .80947 .45841 .80489 .45546 Metetra
.582 .879 .993 r
.80489 .45546 .80947 .45841 .82094 .45493 .81641 .45194 Metetra
.582 .879 .993 r
.81641 .45194 .82094 .45493 .83245 .45142 .82797 .44842 Metetra
.582 .879 .993 r
.82797 .44842 .83245 .45142 .84402 .44791 .83958 .44488 Metetra
.582 .879 .993 r
.83958 .44488 .84402 .44791 .85562 .44438 .85123 .44133 Metetra
.629 .58 .78 r
.19231 .62818 .19802 .64049 .20724 .63768 .20153 .62534 Metetra
.629 .58 .78 r
.20153 .62534 .20724 .63768 .2165 .63486 .21079 .6225 Metetra
.629 .58 .78 r
.21079 .6225 .2165 .63486 .22578 .63202 .22008 .61964 Metetra
.629 .58 .78 r
.22008 .61964 .22578 .63202 .23511 .62918 .2294 .61677 Metetra
.629 .58 .78 r
.2294 .61677 .23511 .62918 .24446 .62633 .23876 .61389 Metetra
.629 .58 .78 r
.23876 .61389 .24446 .62633 .25385 .62347 .24815 .611 Metetra
.629 .58 .78 r
.24815 .611 .25385 .62347 .26327 .62059 .25757 .6081 Metetra
.629 .58 .78 r
.25757 .6081 .26327 .62059 .27273 .61771 .26703 .60519 Metetra
.629 .58 .78 r
.26703 .60519 .27273 .61771 .28222 .61482 .27652 .60227 Metetra
.629 .58 .78 r
.27652 .60227 .28222 .61482 .29175 .61191 .28605 .59934 Metetra
.629 .58 .78 r
.28605 .59934 .29175 .61191 .30131 .609 .29561 .5964 Metetra
.629 .58 .78 r
.29561 .5964 .30131 .609 .3109 .60607 .30521 .59345 Metetra
.629 .58 .78 r
.30521 .59345 .3109 .60607 .32053 .60314 .31484 .59049 Metetra
.629 .58 .78 r
.31484 .59049 .32053 .60314 .3302 .60019 .32451 .58751 Metetra
.629 .58 .78 r
.32451 .58751 .3302 .60019 .3399 .59723 .33421 .58453 Metetra
.629 .58 .78 r
.33421 .58453 .3399 .59723 .34963 .59426 .34394 .58153 Metetra
.629 .58 .78 r
.34394 .58153 .34963 .59426 .3594 .59128 .35372 .57853 Metetra
.629 .58 .78 r
.35372 .57853 .3594 .59128 .36921 .58829 .36353 .57551 Metetra
.629 .58 .78 r
.36353 .57551 .36921 .58829 .37905 .58529 .37337 .57248 Metetra
.629 .58 .78 r
.37337 .57248 .37905 .58529 .38893 .58228 .38326 .56944 Metetra
.629 .58 .78 r
.38326 .56944 .38893 .58228 .39885 .57926 .39317 .56639 Metetra
.629 .58 .78 r
.39317 .56639 .39885 .57926 .4088 .57622 .40313 .56333 Metetra
.629 .58 .78 r
.40313 .56333 .4088 .57622 .41879 .57318 .41312 .56025 Metetra
.629 .58 .78 r
.41312 .56025 .41879 .57318 .42882 .57012 .42315 .55717 Metetra
.629 .58 .78 r
.42315 .55717 .42882 .57012 .43888 .56705 .43322 .55407 Metetra
.629 .58 .78 r
.43322 .55407 .43888 .56705 .44899 .56397 .44332 .55096 Metetra
.629 .58 .78 r
.44332 .55096 .44899 .56397 .45913 .56088 .45346 .54784 Metetra
.629 .58 .78 r
.45346 .54784 .45913 .56088 .4693 .55778 .46365 .54471 Metetra
.629 .58 .78 r
.46365 .54471 .4693 .55778 .47952 .55466 .47386 .54157 Metetra
.629 .58 .78 r
.47386 .54157 .47952 .55466 .48977 .55153 .48412 .53841 Metetra
.629 .58 .78 r
.48412 .53841 .48977 .55153 .50007 .5484 .49442 .53525 Metetra
.629 .58 .78 r
.49442 .53525 .50007 .5484 .5104 .54525 .50475 .53207 Metetra
.629 .58 .78 r
.50475 .53207 .5104 .54525 .52077 .54208 .51513 .52888 Metetra
.629 .58 .78 r
.51513 .52888 .52077 .54208 .53118 .53891 .52554 .52567 Metetra
.629 .58 .78 r
.52554 .52567 .53118 .53891 .54163 .53572 .53599 .52246 Metetra
.629 .58 .78 r
.53599 .52246 .54163 .53572 .55212 .53253 .54648 .51923 Metetra
.629 .58 .78 r
.54648 .51923 .55212 .53253 .56265 .52931 .55702 .51599 Metetra
.629 .58 .78 r
.55702 .51599 .56265 .52931 .57322 .52609 .56759 .51274 Metetra
.629 .58 .78 r
.56759 .51274 .57322 .52609 .58383 .52286 .5782 .50947 Metetra
.629 .58 .78 r
.5782 .50947 .58383 .52286 .59448 .51961 .58886 .50619 Metetra
.629 .58 .78 r
.58886 .50619 .59448 .51961 .60517 .51635 .59955 .5029 Metetra
.629 .58 .78 r
.59955 .5029 .60517 .51635 .61591 .51308 .61029 .4996 Metetra
.629 .58 .78 r
.61029 .4996 .61591 .51308 .62668 .50979 .62107 .49629 Metetra
.629 .58 .78 r
.62107 .49629 .62668 .50979 .63749 .50649 .63189 .49296 Metetra
.629 .58 .78 r
.63189 .49296 .63749 .50649 .64835 .50318 .64275 .48962 Metetra
.629 .58 .78 r
.64275 .48962 .64835 .50318 .65925 .49986 .65365 .48626 Metetra
.629 .58 .78 r
.65365 .48626 .65925 .49986 .67019 .49652 .6646 .4829 Metetra
.629 .58 .78 r
.6646 .4829 .67019 .49652 .68118 .49318 .67559 .47952 Metetra
.629 .58 .78 r
.67559 .47952 .68118 .49318 .69221 .48981 .68662 .47612 Metetra
.629 .58 .78 r
.68662 .47612 .69221 .48981 .70328 .48644 .69769 .47272 Metetra
.629 .58 .78 r
.69769 .47272 .70328 .48644 .71439 .48305 .70881 .4693 Metetra
.629 .58 .78 r
.70881 .4693 .71439 .48305 .72555 .47965 .71997 .46586 Metetra
.629 .58 .78 r
.71997 .46586 .72555 .47965 .73675 .47623 .73118 .46241 Metetra
.629 .58 .78 r
.73118 .46241 .73675 .47623 .748 .4728 .74243 .45895 Metetra
.629 .58 .78 r
.74243 .45895 .748 .4728 .75928 .46936 .75372 .45548 Metetra
.629 .58 .78 r
.75372 .45548 .75928 .46936 .77062 .46591 .76506 .45199 Metetra
.629 .58 .78 r
.76506 .45199 .77062 .46591 .782 .46244 .77644 .44849 Metetra
.629 .58 .78 r
.77644 .44849 .782 .46244 .79342 .45895 .78787 .44497 Metetra
.629 .58 .78 r
.78787 .44497 .79342 .45895 .80489 .45546 .79935 .44144 Metetra
.629 .58 .78 r
.79935 .44144 .80489 .45546 .81641 .45194 .81087 .4379 Metetra
.629 .58 .78 r
.81087 .4379 .81641 .45194 .82797 .44842 .82243 .43434 Metetra
.629 .58 .78 r
.82243 .43434 .82797 .44842 .83958 .44488 .83405 .43077 Metetra
.629 .58 .78 r
.83405 .43077 .83958 .44488 .85123 .44133 .84571 .42718 Metetra
.64 .633 .827 r
.18631 .61857 .19231 .62818 .20153 .62534 .19554 .61571 Metetra
.64 .633 .827 r
.19554 .61571 .20153 .62534 .21079 .6225 .20481 .61284 Metetra
.64 .633 .827 r
.20481 .61284 .21079 .6225 .22008 .61964 .21411 .60996 Metetra
.64 .633 .827 r
.21411 .60996 .22008 .61964 .2294 .61677 .22344 .60707 Metetra
.64 .633 .827 r
.22344 .60707 .2294 .61677 .23876 .61389 .2328 .60417 Metetra
.64 .633 .827 r
.2328 .60417 .23876 .61389 .24815 .611 .2422 .60126 Metetra
.64 .633 .827 r
.2422 .60126 .24815 .611 .25757 .6081 .25164 .59833 Metetra
.64 .633 .827 r
.25164 .59833 .25757 .6081 .26703 .60519 .2611 .5954 Metetra
.64 .633 .827 r
.2611 .5954 .26703 .60519 .27652 .60227 .2706 .59246 Metetra
.64 .633 .827 r
.2706 .59246 .27652 .60227 .28605 .59934 .28014 .5895 Metetra
.64 .633 .827 r
.28014 .5895 .28605 .59934 .29561 .5964 .28971 .58654 Metetra
.64 .633 .827 r
.28971 .58654 .29561 .5964 .30521 .59345 .29932 .58356 Metetra
.64 .633 .827 r
.29932 .58356 .30521 .59345 .31484 .59049 .30896 .58057 Metetra
.64 .633 .827 r
.30896 .58057 .31484 .59049 .32451 .58751 .31863 .57757 Metetra
.64 .633 .827 r
.31863 .57757 .32451 .58751 .33421 .58453 .32834 .57457 Metetra
.64 .633 .827 r
.32834 .57457 .33421 .58453 .34394 .58153 .33809 .57155 Metetra
.64 .633 .827 r
.33809 .57155 .34394 .58153 .35372 .57853 .34787 .56851 Metetra
.64 .633 .827 r
.34787 .56851 .35372 .57853 .36353 .57551 .35769 .56547 Metetra
.64 .633 .827 r
.35769 .56547 .36353 .57551 .37337 .57248 .36755 .56242 Metetra
.64 .633 .827 r
.36755 .56242 .37337 .57248 .38326 .56944 .37744 .55935 Metetra
.64 .633 .827 r
.37744 .55935 .38326 .56944 .39317 .56639 .38737 .55628 Metetra
.64 .633 .827 r
.38737 .55628 .39317 .56639 .40313 .56333 .39734 .55319 Metetra
.64 .633 .827 r
.39734 .55319 .40313 .56333 .41312 .56025 .40734 .55009 Metetra
.64 .633 .827 r
.40734 .55009 .41312 .56025 .42315 .55717 .41738 .54698 Metetra
.64 .633 .827 r
.41738 .54698 .42315 .55717 .43322 .55407 .42746 .54386 Metetra
.64 .633 .827 r
.42746 .54386 .43322 .55407 .44332 .55096 .43757 .54072 Metetra
.64 .633 .827 r
.43757 .54072 .44332 .55096 .45346 .54784 .44772 .53758 Metetra
.64 .633 .827 r
.44772 .53758 .45346 .54784 .46365 .54471 .45792 .53442 Metetra
.64 .633 .827 r
.45792 .53442 .46365 .54471 .47386 .54157 .46815 .53125 Metetra
.64 .633 .827 r
.46815 .53125 .47386 .54157 .48412 .53841 .47841 .52807 Metetra
.64 .633 .827 r
.47841 .52807 .48412 .53841 .49442 .53525 .48872 .52487 Metetra
.64 .633 .827 r
.48872 .52487 .49442 .53525 .50475 .53207 .49907 .52167 Metetra
.64 .633 .827 r
.49907 .52167 .50475 .53207 .51513 .52888 .50945 .51845 Metetra
.64 .633 .827 r
.50945 .51845 .51513 .52888 .52554 .52567 .51988 .51522 Metetra
.64 .633 .827 r
.51988 .51522 .52554 .52567 .53599 .52246 .53034 .51198 Metetra
.64 .633 .827 r
.53034 .51198 .53599 .52246 .54648 .51923 .54085 .50872 Metetra
.64 .633 .827 r
.54085 .50872 .54648 .51923 .55702 .51599 .55139 .50546 Metetra
.64 .633 .827 r
.55139 .50546 .55702 .51599 .56759 .51274 .56198 .50218 Metetra
.64 .633 .827 r
.56198 .50218 .56759 .51274 .5782 .50947 .5726 .49888 Metetra
.64 .633 .827 r
.5726 .49888 .5782 .50947 .58886 .50619 .58327 .49558 Metetra
.64 .633 .827 r
.58327 .49558 .58886 .50619 .59955 .5029 .59398 .49226 Metetra
.64 .633 .827 r
.59398 .49226 .59955 .5029 .61029 .4996 .60473 .48893 Metetra
.64 .633 .827 r
.60473 .48893 .61029 .4996 .62107 .49629 .61552 .48559 Metetra
.64 .633 .827 r
.61552 .48559 .62107 .49629 .63189 .49296 .62635 .48223 Metetra
.64 .633 .827 r
.62635 .48223 .63189 .49296 .64275 .48962 .63722 .47886 Metetra
.64 .633 .827 r
.63722 .47886 .64275 .48962 .65365 .48626 .64814 .47548 Metetra
.64 .633 .827 r
.64814 .47548 .65365 .48626 .6646 .4829 .6591 .47208 Metetra
.64 .633 .827 r
.6591 .47208 .6646 .4829 .67559 .47952 .6701 .46868 Metetra
.64 .633 .827 r
.6701 .46868 .67559 .47952 .68662 .47612 .68115 .46525 Metetra
.64 .633 .827 r
.68115 .46525 .68662 .47612 .69769 .47272 .69224 .46182 Metetra
.64 .633 .827 r
.69224 .46182 .69769 .47272 .70881 .4693 .70337 .45837 Metetra
.64 .633 .827 r
.70337 .45837 .70881 .4693 .71997 .46586 .71454 .45491 Metetra
.64 .633 .827 r
.71454 .45491 .71997 .46586 .73118 .46241 .72576 .45143 Metetra
.64 .633 .827 r
.72576 .45143 .73118 .46241 .74243 .45895 .73703 .44794 Metetra
.64 .633 .827 r
.73703 .44794 .74243 .45895 .75372 .45548 .74834 .44444 Metetra
.64 .633 .827 r
.74834 .44444 .75372 .45548 .76506 .45199 .75969 .44092 Metetra
.64 .633 .827 r
.75969 .44092 .76506 .45199 .77644 .44849 .77109 .43739 Metetra
.64 .633 .827 r
.77109 .43739 .77644 .44849 .78787 .44497 .78253 .43384 Metetra
.64 .633 .827 r
.78253 .43384 .78787 .44497 .79935 .44144 .79402 .43028 Metetra
.64 .633 .827 r
.79402 .43028 .79935 .44144 .81087 .4379 .80556 .42671 Metetra
.64 .633 .827 r
.80556 .42671 .81087 .4379 .82243 .43434 .81714 .42312 Metetra
.64 .633 .827 r
.81714 .42312 .82243 .43434 .83405 .43077 .82877 .41951 Metetra
.64 .633 .827 r
.82877 .41951 .83405 .43077 .84571 .42718 .84045 .4159 Metetra
.563 .377 .587 r
.18549 .55715 .18631 .61857 .19554 .61571 .1946 .55422 Metetra
.563 .377 .587 r
.1946 .55422 .19554 .61571 .20481 .61284 .20374 .55128 Metetra
.563 .377 .587 r
.20374 .55128 .20481 .61284 .21411 .60996 .21292 .54832 Metetra
.563 .377 .587 r
.21292 .54832 .21411 .60996 .22344 .60707 .22212 .54536 Metetra
.563 .377 .587 r
.22212 .54536 .22344 .60707 .2328 .60417 .23136 .54239 Metetra
.563 .377 .587 r
.23136 .54239 .2328 .60417 .2422 .60126 .24064 .53941 Metetra
.563 .377 .587 r
.24064 .53941 .2422 .60126 .25164 .59833 .24994 .53641 Metetra
.563 .377 .587 r
.24994 .53641 .25164 .59833 .2611 .5954 .25928 .53341 Metetra
.563 .377 .587 r
.25928 .53341 .2611 .5954 .2706 .59246 .26865 .53039 Metetra
.563 .377 .587 r
.26865 .53039 .2706 .59246 .28014 .5895 .27806 .52736 Metetra
.563 .377 .587 r
.27806 .52736 .28014 .5895 .28971 .58654 .2875 .52433 Metetra
.563 .377 .587 r
.2875 .52433 .28971 .58654 .29932 .58356 .29697 .52128 Metetra
.563 .377 .587 r
.29697 .52128 .29932 .58356 .30896 .58057 .30648 .51822 Metetra
.563 .377 .587 r
.30648 .51822 .30896 .58057 .31863 .57757 .31602 .51515 Metetra
.563 .377 .587 r
.31602 .51515 .31863 .57757 .32834 .57457 .32559 .51207 Metetra
.563 .377 .587 r
.32559 .51207 .32834 .57457 .33809 .57155 .3352 .50897 Metetra
.563 .377 .587 r
.3352 .50897 .33809 .57155 .34787 .56851 .34485 .50587 Metetra
.563 .377 .587 r
.34485 .50587 .34787 .56851 .35769 .56547 .35453 .50275 Metetra
.563 .377 .587 r
.35453 .50275 .35769 .56547 .36755 .56242 .36425 .49963 Metetra
.563 .377 .587 r
.36425 .49963 .36755 .56242 .37744 .55935 .374 .49649 Metetra
.563 .377 .587 r
.374 .49649 .37744 .55935 .38737 .55628 .38379 .49334 Metetra
.563 .377 .587 r
.38379 .49334 .38737 .55628 .39734 .55319 .39361 .49018 Metetra
.563 .377 .587 r
.39361 .49018 .39734 .55319 .40734 .55009 .40347 .48701 Metetra
.563 .377 .587 r
.40347 .48701 .40734 .55009 .41738 .54698 .41337 .48382 Metetra
.563 .377 .587 r
.41337 .48382 .41738 .54698 .42746 .54386 .4233 .48063 Metetra
.563 .377 .587 r
.4233 .48063 .42746 .54386 .43757 .54072 .43327 .47742 Metetra
.563 .377 .587 r
.43327 .47742 .43757 .54072 .44772 .53758 .44327 .4742 Metetra
.563 .377 .587 r
.44327 .4742 .44772 .53758 .45792 .53442 .45332 .47097 Metetra
.563 .377 .587 r
.45332 .47097 .45792 .53442 .46815 .53125 .4634 .46772 Metetra
.563 .377 .587 r
.4634 .46772 .46815 .53125 .47841 .52807 .47351 .46447 Metetra
.563 .377 .587 r
.47351 .46447 .47841 .52807 .48872 .52487 .48367 .4612 Metetra
.563 .377 .587 r
.48367 .4612 .48872 .52487 .49907 .52167 .49386 .45792 Metetra
.563 .377 .587 r
.49386 .45792 .49907 .52167 .50945 .51845 .50409 .45463 Metetra
.563 .377 .587 r
.50409 .45463 .50945 .51845 .51988 .51522 .51436 .45132 Metetra
.563 .377 .587 r
.51436 .45132 .51988 .51522 .53034 .51198 .52467 .44801 Metetra
.563 .377 .587 r
.52467 .44801 .53034 .51198 .54085 .50872 .53502 .44468 Metetra
.563 .377 .587 r
.53502 .44468 .54085 .50872 .55139 .50546 .54541 .44133 Metetra
.563 .377 .587 r
.54541 .44133 .55139 .50546 .56198 .50218 .55583 .43798 Metetra
.563 .377 .587 r
.55583 .43798 .56198 .50218 .5726 .49888 .5663 .43461 Metetra
.563 .377 .587 r
.5663 .43461 .5726 .49888 .58327 .49558 .5768 .43123 Metetra
.563 .377 .587 r
.5768 .43123 .58327 .49558 .59398 .49226 .58734 .42784 Metetra
.563 .377 .587 r
.58734 .42784 .59398 .49226 .60473 .48893 .59793 .42443 Metetra
.563 .377 .587 r
.59793 .42443 .60473 .48893 .61552 .48559 .60855 .42101 Metetra
.563 .377 .587 r
.60855 .42101 .61552 .48559 .62635 .48223 .61922 .41758 Metetra
.563 .377 .587 r
.61922 .41758 .62635 .48223 .63722 .47886 .62993 .41414 Metetra
.563 .377 .587 r
.62993 .41414 .63722 .47886 .64814 .47548 .64067 .41068 Metetra
.563 .377 .587 r
.64067 .41068 .64814 .47548 .6591 .47208 .65146 .40721 Metetra
.563 .377 .587 r
.65146 .40721 .6591 .47208 .6701 .46868 .66229 .40372 Metetra
.563 .377 .587 r
.66229 .40372 .6701 .46868 .68115 .46525 .67316 .40022 Metetra
.563 .377 .587 r
.67316 .40022 .68115 .46525 .69224 .46182 .68408 .39671 Metetra
.563 .377 .587 r
.68408 .39671 .69224 .46182 .70337 .45837 .69503 .39318 Metetra
.563 .377 .587 r
.69503 .39318 .70337 .45837 .71454 .45491 .70603 .38965 Metetra
.563 .377 .587 r
.70603 .38965 .71454 .45491 .72576 .45143 .71707 .38609 Metetra
.563 .377 .587 r
.71707 .38609 .72576 .45143 .73703 .44794 .72816 .38253 Metetra
.563 .377 .587 r
.72816 .38253 .73703 .44794 .74834 .44444 .73929 .37894 Metetra
.563 .377 .587 r
.73929 .37894 .74834 .44444 .75969 .44092 .75046 .37535 Metetra
.563 .377 .587 r
.75046 .37535 .75969 .44092 .77109 .43739 .76167 .37174 Metetra
.563 .377 .587 r
.76167 .37174 .77109 .43739 .78253 .43384 .77293 .36812 Metetra
.563 .377 .587 r
.77293 .36812 .78253 .43384 .79402 .43028 .78424 .36448 Metetra
.563 .377 .587 r
.78424 .36448 .79402 .43028 .80556 .42671 .79558 .36083 Metetra
.563 .377 .587 r
.79558 .36083 .80556 .42671 .81714 .42312 .80698 .35716 Metetra
.563 .377 .587 r
.80698 .35716 .81714 .42312 .82877 .41951 .81841 .35348 Metetra
.563 .377 .587 r
.81841 .35348 .82877 .41951 .84045 .4159 .8299 .34979 Metetra
.547 .338 .549 r
.19394 .40708 .18549 .55715 .1946 .55422 .2027 .40401 Metetra
.547 .338 .549 r
.2027 .40401 .1946 .55422 .20374 .55128 .21149 .40093 Metetra
.547 .338 .549 r
.21149 .40093 .20374 .55128 .21292 .54832 .22031 .39784 Metetra
.547 .338 .549 r
.22031 .39784 .21292 .54832 .22212 .54536 .22916 .39474 Metetra
.547 .338 .549 r
.22916 .39474 .22212 .54536 .23136 .54239 .23805 .39163 Metetra
.547 .338 .549 r
.23805 .39163 .23136 .54239 .24064 .53941 .24696 .38851 Metetra
.547 .338 .549 r
.24696 .38851 .24064 .53941 .24994 .53641 .2559 .38538 Metetra
.547 .338 .549 r
.2559 .38538 .24994 .53641 .25928 .53341 .26487 .38224 Metetra
.547 .338 .549 r
.26487 .38224 .25928 .53341 .26865 .53039 .27387 .37908 Metetra
.547 .338 .549 r
.27387 .37908 .26865 .53039 .27806 .52736 .28291 .37592 Metetra
.547 .338 .549 r
.28291 .37592 .27806 .52736 .2875 .52433 .29197 .37274 Metetra
.547 .338 .549 r
.29197 .37274 .2875 .52433 .29697 .52128 .30107 .36955 Metetra
.547 .338 .549 r
.30107 .36955 .29697 .52128 .30648 .51822 .3102 .36636 Metetra
.547 .338 .549 r
.3102 .36636 .30648 .51822 .31602 .51515 .31936 .36315 Metetra
.547 .338 .549 r
.31936 .36315 .31602 .51515 .32559 .51207 .32855 .35993 Metetra
.547 .338 .549 r
.32855 .35993 .32559 .51207 .3352 .50897 .33777 .3567 Metetra
.547 .338 .549 r
.33777 .3567 .3352 .50897 .34485 .50587 .34703 .35346 Metetra
.547 .338 .549 r
.34703 .35346 .34485 .50587 .35453 .50275 .35632 .3502 Metetra
.547 .338 .549 r
.35632 .3502 .35453 .50275 .36425 .49963 .36564 .34694 Metetra
.547 .338 .549 r
.36564 .34694 .36425 .49963 .374 .49649 .37499 .34366 Metetra
.547 .338 .549 r
.37499 .34366 .374 .49649 .38379 .49334 .38438 .34037 Metetra
.547 .338 .549 r
.38438 .34037 .38379 .49334 .39361 .49018 .39379 .33707 Metetra
.547 .338 .549 r
.39379 .33707 .39361 .49018 .40347 .48701 .40325 .33376 Metetra
.547 .338 .549 r
.40325 .33376 .40347 .48701 .41337 .48382 .41273 .33044 Metetra
.547 .338 .549 r
.41273 .33044 .41337 .48382 .4233 .48063 .42225 .32711 Metetra
.547 .338 .549 r
.42225 .32711 .4233 .48063 .43327 .47742 .4318 .32376 Metetra
.547 .338 .549 r
.4318 .32376 .43327 .47742 .44327 .4742 .44139 .3204 Metetra
.547 .338 .549 r
.44139 .3204 .44327 .4742 .45332 .47097 .45101 .31703 Metetra
.547 .338 .549 r
.45101 .31703 .45332 .47097 .4634 .46772 .46066 .31365 Metetra
.547 .338 .549 r
.46066 .31365 .4634 .46772 .47351 .46447 .47035 .31025 Metetra
.547 .338 .549 r
.47035 .31025 .47351 .46447 .48367 .4612 .48008 .30685 Metetra
.547 .338 .549 r
.48008 .30685 .48367 .4612 .49386 .45792 .48984 .30343 Metetra
.547 .338 .549 r
.48984 .30343 .49386 .45792 .50409 .45463 .49963 .3 Metetra
.547 .338 .549 r
.49963 .3 .50409 .45463 .51436 .45132 .50946 .29656 Metetra
.547 .338 .549 r
.50946 .29656 .51436 .45132 .52467 .44801 .51932 .2931 Metetra
.547 .338 .549 r
.51932 .2931 .52467 .44801 .53502 .44468 .52922 .28963 Metetra
.547 .338 .549 r
.52922 .28963 .53502 .44468 .54541 .44133 .53916 .28615 Metetra
.547 .338 .549 r
.53916 .28615 .54541 .44133 .55583 .43798 .54913 .28266 Metetra
.547 .338 .549 r
.54913 .28266 .55583 .43798 .5663 .43461 .55914 .27915 Metetra
.547 .338 .549 r
.55914 .27915 .5663 .43461 .5768 .43123 .56918 .27564 Metetra
.547 .338 .549 r
.56918 .27564 .5768 .43123 .58734 .42784 .57926 .27211 Metetra
.547 .338 .549 r
.57926 .27211 .58734 .42784 .59793 .42443 .58938 .26856 Metetra
.547 .338 .549 r
.58938 .26856 .59793 .42443 .60855 .42101 .59953 .265 Metetra
.547 .338 .549 r
.59953 .265 .60855 .42101 .61922 .41758 .60972 .26143 Metetra
.547 .338 .549 r
.60972 .26143 .61922 .41758 .62993 .41414 .61995 .25785 Metetra
.547 .338 .549 r
.61995 .25785 .62993 .41414 .64067 .41068 .63022 .25426 Metetra
.547 .338 .549 r
.63022 .25426 .64067 .41068 .65146 .40721 .64052 .25065 Metetra
.547 .338 .549 r
.64052 .25065 .65146 .40721 .66229 .40372 .65086 .24702 Metetra
.547 .338 .549 r
.65086 .24702 .66229 .40372 .67316 .40022 .66124 .24339 Metetra
.547 .338 .549 r
.66124 .24339 .67316 .40022 .68408 .39671 .67166 .23974 Metetra
.547 .338 .549 r
.67166 .23974 .68408 .39671 .69503 .39318 .68212 .23608 Metetra
.547 .338 .549 r
.68212 .23608 .69503 .39318 .70603 .38965 .69261 .2324 Metetra
.547 .338 .549 r
.69261 .2324 .70603 .38965 .71707 .38609 .70315 .22871 Metetra
.547 .338 .549 r
.70315 .22871 .71707 .38609 .72816 .38253 .71372 .225 Metetra
.547 .338 .549 r
.71372 .225 .72816 .38253 .73929 .37894 .72433 .22129 Metetra
.547 .338 .549 r
.72433 .22129 .73929 .37894 .75046 .37535 .73499 .21756 Metetra
.547 .338 .549 r
.73499 .21756 .75046 .37535 .76167 .37174 .74568 .21381 Metetra
.547 .338 .549 r
.74568 .21381 .76167 .37174 .77293 .36812 .75641 .21005 Metetra
.547 .338 .549 r
.75641 .21005 .77293 .36812 .78424 .36448 .76719 .20628 Metetra
.547 .338 .549 r
.76719 .20628 .78424 .36448 .79558 .36083 .778 .20249 Metetra
.547 .338 .549 r
.778 .20249 .79558 .36083 .80698 .35716 .78885 .19869 Metetra
.547 .338 .549 r
.78885 .19869 .80698 .35716 .81841 .35348 .79975 .19487 Metetra
.547 .338 .549 r
.79975 .19487 .81841 .35348 .8299 .34979 .81069 .19104 Metetra
.511 .261 .472 r
.17842 .49157 .19394 .40708 .2027 .40401 .18743 .48855 Metetra
.511 .261 .472 r
.18743 .48855 .2027 .40401 .21149 .40093 .19647 .48553 Metetra
.511 .261 .472 r
.19647 .48553 .21149 .40093 .22031 .39784 .20554 .48249 Metetra
.511 .261 .472 r
.20554 .48249 .22031 .39784 .22916 .39474 .21464 .47944 Metetra
.511 .261 .472 r
.21464 .47944 .22916 .39474 .23805 .39163 .22378 .47638 Metetra
.511 .261 .472 r
.22378 .47638 .23805 .39163 .24696 .38851 .23294 .47331 Metetra
.511 .261 .472 r
.23294 .47331 .24696 .38851 .2559 .38538 .24214 .47023 Metetra
.511 .261 .472 r
.24214 .47023 .2559 .38538 .26487 .38224 .25137 .46713 Metetra
.511 .261 .472 r
.25137 .46713 .26487 .38224 .27387 .37908 .26064 .46403 Metetra
.511 .261 .472 r
.26064 .46403 .27387 .37908 .28291 .37592 .26994 .46092 Metetra
.511 .261 .472 r
.26994 .46092 .28291 .37592 .29197 .37274 .27927 .45779 Metetra
.511 .261 .472 r
.27927 .45779 .29197 .37274 .30107 .36955 .28863 .45466 Metetra
.511 .261 .472 r
.28863 .45466 .30107 .36955 .3102 .36636 .29803 .45151 Metetra
.511 .261 .472 r
.29803 .45151 .3102 .36636 .31936 .36315 .30746 .44835 Metetra
.511 .261 .472 r
.30746 .44835 .31936 .36315 .32855 .35993 .31692 .44518 Metetra
.511 .261 .472 r
.31692 .44518 .32855 .35993 .33777 .3567 .32642 .442 Metetra
.511 .261 .472 r
.32642 .442 .33777 .3567 .34703 .35346 .33595 .4388 Metetra
.511 .261 .472 r
.33595 .4388 .34703 .35346 .35632 .3502 .34552 .4356 Metetra
.511 .261 .472 r
.34552 .4356 .35632 .3502 .36564 .34694 .35512 .43238 Metetra
.511 .261 .472 r
.35512 .43238 .36564 .34694 .37499 .34366 .36476 .42916 Metetra
.511 .261 .472 r
.36476 .42916 .37499 .34366 .38438 .34037 .37443 .42592 Metetra
.511 .261 .472 r
.37443 .42592 .38438 .34037 .39379 .33707 .38414 .42267 Metetra
.511 .261 .472 r
.38414 .42267 .39379 .33707 .40325 .33376 .39388 .4194 Metetra
.511 .261 .472 r
.39388 .4194 .40325 .33376 .41273 .33044 .40366 .41613 Metetra
.511 .261 .472 r
.40366 .41613 .41273 .33044 .42225 .32711 .41347 .41284 Metetra
.511 .261 .472 r
.41347 .41284 .42225 .32711 .4318 .32376 .42332 .40954 Metetra
.511 .261 .472 r
.42332 .40954 .4318 .32376 .44139 .3204 .4332 .40623 Metetra
.511 .261 .472 r
.4332 .40623 .44139 .3204 .45101 .31703 .44312 .40291 Metetra
.511 .261 .472 r
.44312 .40291 .45101 .31703 .46066 .31365 .45308 .39957 Metetra
.511 .261 .472 r
.45308 .39957 .46066 .31365 .47035 .31025 .46307 .39622 Metetra
.511 .261 .472 r
.46307 .39622 .47035 .31025 .48008 .30685 .47311 .39286 Metetra
.511 .261 .472 r
.47311 .39286 .48008 .30685 .48984 .30343 .48317 .38949 Metetra
.511 .261 .472 r
.48317 .38949 .48984 .30343 .49963 .3 .49328 .38611 Metetra
.511 .261 .472 r
.49328 .38611 .49963 .3 .50946 .29656 .50342 .38271 Metetra
.511 .261 .472 r
.50342 .38271 .50946 .29656 .51932 .2931 .5136 .3793 Metetra
.511 .261 .472 r
.5136 .3793 .51932 .2931 .52922 .28963 .52382 .37588 Metetra
.511 .261 .472 r
.52382 .37588 .52922 .28963 .53916 .28615 .53408 .37244 Metetra
.511 .261 .472 r
.53408 .37244 .53916 .28615 .54913 .28266 .54437 .36899 Metetra
.511 .261 .472 r
.54437 .36899 .54913 .28266 .55914 .27915 .55471 .36553 Metetra
.511 .261 .472 r
.55471 .36553 .55914 .27915 .56918 .27564 .56508 .36206 Metetra
.511 .261 .472 r
.56508 .36206 .56918 .27564 .57926 .27211 .57549 .35857 Metetra
.511 .261 .472 r
.57549 .35857 .57926 .27211 .58938 .26856 .58594 .35507 Metetra
.511 .261 .472 r
.58594 .35507 .58938 .26856 .59953 .265 .59643 .35156 Metetra
.511 .261 .472 r
.59643 .35156 .59953 .265 .60972 .26143 .60696 .34803 Metetra
.511 .261 .472 r
.60696 .34803 .60972 .26143 .61995 .25785 .61753 .34449 Metetra
.511 .261 .472 r
.61753 .34449 .61995 .25785 .63022 .25426 .62814 .34094 Metetra
.511 .261 .472 r
.62814 .34094 .63022 .25426 .64052 .25065 .63879 .33737 Metetra
.511 .261 .472 r
.63879 .33737 .64052 .25065 .65086 .24702 .64948 .33379 Metetra
.511 .261 .472 r
.64948 .33379 .65086 .24702 .66124 .24339 .66021 .33019 Metetra
.511 .261 .472 r
.66021 .33019 .66124 .24339 .67166 .23974 .67098 .32659 Metetra
.511 .261 .472 r
.67098 .32659 .67166 .23974 .68212 .23608 .68179 .32296 Metetra
.511 .261 .472 r
.68179 .32296 .68212 .23608 .69261 .2324 .69265 .31933 Metetra
.511 .261 .472 r
.69265 .31933 .69261 .2324 .70315 .22871 .70354 .31568 Metetra
.511 .261 .472 r
.70354 .31568 .70315 .22871 .71372 .225 .71448 .31201 Metetra
.511 .261 .472 r
.71448 .31201 .71372 .225 .72433 .22129 .72546 .30834 Metetra
.511 .261 .472 r
.72546 .30834 .72433 .22129 .73499 .21756 .73649 .30464 Metetra
.511 .261 .472 r
.73649 .30464 .73499 .21756 .74568 .21381 .74755 .30094 Metetra
.511 .261 .472 r
.74755 .30094 .74568 .21381 .75641 .21005 .75866 .29722 Metetra
.511 .261 .472 r
.75866 .29722 .75641 .21005 .76719 .20628 .76981 .29348 Metetra
.511 .261 .472 r
.76981 .29348 .76719 .20628 .778 .20249 .78101 .28973 Metetra
.511 .261 .472 r
.78101 .28973 .778 .20249 .78885 .19869 .79225 .28597 Metetra
.511 .261 .472 r
.79225 .28597 .78885 .19869 .79975 .19487 .80353 .28219 Metetra
.511 .261 .472 r
.80353 .28219 .79975 .19487 .81069 .19104 .81486 .27839 Metetra
.1711 .49523 .17842 .49157 .18743 .48855 .18015 .4922 Metetra
.18015 .4922 .18743 .48855 .19647 .48553 .18923 .48916 Metetra
.18923 .48916 .19647 .48553 .20554 .48249 .19835 .48611 Metetra
.19835 .48611 .20554 .48249 .21464 .47944 .20749 .48305 Metetra
.20749 .48305 .21464 .47944 .22378 .47638 .21667 .47998 Metetra
.21667 .47998 .22378 .47638 .23294 .47331 .22588 .4769 Metetra
.22588 .4769 .23294 .47331 .24214 .47023 .23512 .4738 Metetra
.23512 .4738 .24214 .47023 .25137 .46713 .2444 .4707 Metetra
.2444 .4707 .25137 .46713 .26064 .46403 .25371 .46758 Metetra
.25371 .46758 .26064 .46403 .26994 .46092 .26305 .46446 Metetra
.26305 .46446 .26994 .46092 .27927 .45779 .27242 .46132 Metetra
.27242 .46132 .27927 .45779 .28863 .45466 .28183 .45817 Metetra
.28183 .45817 .28863 .45466 .29803 .45151 .29128 .45501 Metetra
.29128 .45501 .29803 .45151 .30746 .44835 .30075 .45184 Metetra
.30075 .45184 .30746 .44835 .31692 .44518 .31026 .44865 Metetra
.31026 .44865 .31692 .44518 .32642 .442 .31981 .44546 Metetra
.31981 .44546 .32642 .442 .33595 .4388 .32939 .44225 Metetra
.32939 .44225 .33595 .4388 .34552 .4356 .339 .43903 Metetra
.339 .43903 .34552 .4356 .35512 .43238 .34865 .4358 Metetra
.34865 .4358 .35512 .43238 .36476 .42916 .35834 .43256 Metetra
.35834 .43256 .36476 .42916 .37443 .42592 .36806 .42931 Metetra
.36806 .42931 .37443 .42592 .38414 .42267 .37781 .42604 Metetra
.37781 .42604 .38414 .42267 .39388 .4194 .38761 .42276 Metetra
.38761 .42276 .39388 .4194 .40366 .41613 .39743 .41947 Metetra
.39743 .41947 .40366 .41613 .41347 .41284 .4073 .41617 Metetra
.4073 .41617 .41347 .41284 .42332 .40954 .4172 .41286 Metetra
.4172 .41286 .42332 .40954 .4332 .40623 .42713 .40953 Metetra
.42713 .40953 .4332 .40623 .44312 .40291 .4371 .4062 Metetra
.4371 .4062 .44312 .40291 .45308 .39957 .44711 .40285 Metetra
.44711 .40285 .45308 .39957 .46307 .39622 .45716 .39948 Metetra
.45716 .39948 .46307 .39622 .47311 .39286 .46724 .39611 Metetra
.46724 .39611 .47311 .39286 .48317 .38949 .47737 .39272 Metetra
.47737 .39272 .48317 .38949 .49328 .38611 .48753 .38932 Metetra
.48753 .38932 .49328 .38611 .50342 .38271 .49772 .38591 Metetra
.49772 .38591 .50342 .38271 .5136 .3793 .50796 .38248 Metetra
.50796 .38248 .5136 .3793 .52382 .37588 .51823 .37904 Metetra
.51823 .37904 .52382 .37588 .53408 .37244 .52854 .37559 Metetra
.52854 .37559 .53408 .37244 .54437 .36899 .53889 .37212 Metetra
.53889 .37212 .54437 .36899 .55471 .36553 .54928 .36865 Metetra
.54928 .36865 .55471 .36553 .56508 .36206 .55971 .36516 Metetra
.55971 .36516 .56508 .36206 .57549 .35857 .57018 .36165 Metetra
.57018 .36165 .57549 .35857 .58594 .35507 .58069 .35813 Metetra
.58069 .35813 .58594 .35507 .59643 .35156 .59124 .3546 Metetra
.59124 .3546 .59643 .35156 .60696 .34803 .60183 .35106 Metetra
.60183 .35106 .60696 .34803 .61753 .34449 .61246 .3475 Metetra
.61246 .3475 .61753 .34449 .62814 .34094 .62313 .34393 Metetra
.62313 .34393 .62814 .34094 .63879 .33737 .63384 .34035 Metetra
.63384 .34035 .63879 .33737 .64948 .33379 .64459 .33675 Metetra
.64459 .33675 .64948 .33379 .66021 .33019 .65538 .33313 Metetra
.65538 .33313 .66021 .33019 .67098 .32659 .66621 .32951 Metetra
.66621 .32951 .67098 .32659 .68179 .32296 .67709 .32587 Metetra
.67709 .32587 .68179 .32296 .69265 .31933 .68801 .32221 Metetra
.68801 .32221 .69265 .31933 .70354 .31568 .69897 .31854 Metetra
.69897 .31854 .70354 .31568 .71448 .31201 .70997 .31486 Metetra
.70997 .31486 .71448 .31201 .72546 .30834 .72102 .31116 Metetra
.72102 .31116 .72546 .30834 .73649 .30464 .7321 .30745 Metetra
.7321 .30745 .73649 .30464 .74755 .30094 .74324 .30373 Metetra
.74324 .30373 .74755 .30094 .75866 .29722 .75441 .29999 Metetra
.75441 .29999 .75866 .29722 .76981 .29348 .76563 .29623 Metetra
.76563 .29623 .76981 .29348 .78101 .28973 .77689 .29246 Metetra
.77689 .29246 .78101 .28973 .79225 .28597 .7882 .28868 Metetra
.7882 .28868 .79225 .28597 .80353 .28219 .79955 .28488 Metetra
.79955 .28488 .80353 .28219 .81486 .27839 .81095 .28106 Metetra
.104 0 0 r
.16345 .50119 .1711 .49523 .18015 .4922 .17255 .49815 Metetra
.104 0 0 r
.17255 .49815 .18015 .4922 .18923 .48916 .18167 .4951 Metetra
.104 0 0 r
.18167 .4951 .18923 .48916 .19835 .48611 .19084 .49204 Metetra
.104 0 0 r
.19084 .49204 .19835 .48611 .20749 .48305 .20003 .48897 Metetra
.104 0 0 r
.20003 .48897 .20749 .48305 .21667 .47998 .20926 .48589 Metetra
.104 0 0 r
.20926 .48589 .21667 .47998 .22588 .4769 .21852 .4828 Metetra
.104 0 0 r
.21852 .4828 .22588 .4769 .23512 .4738 .22781 .47969 Metetra
.104 0 0 r
.22781 .47969 .23512 .4738 .2444 .4707 .23714 .47658 Metetra
.104 0 0 r
.23714 .47658 .2444 .4707 .25371 .46758 .2465 .47345 Metetra
.104 0 0 r
.2465 .47345 .25371 .46758 .26305 .46446 .25589 .47031 Metetra
.104 0 0 r
.25589 .47031 .26305 .46446 .27242 .46132 .26532 .46716 Metetra
.104 0 0 r
.26532 .46716 .27242 .46132 .28183 .45817 .27478 .464 Metetra
.104 0 0 r
.27478 .464 .28183 .45817 .29128 .45501 .28427 .46083 Metetra
.104 0 0 r
.28427 .46083 .29128 .45501 .30075 .45184 .2938 .45765 Metetra
.104 0 0 r
.2938 .45765 .30075 .45184 .31026 .44865 .30337 .45445 Metetra
.104 0 0 r
.30337 .45445 .31026 .44865 .31981 .44546 .31297 .45124 Metetra
.104 0 0 r
.31297 .45124 .31981 .44546 .32939 .44225 .3226 .44803 Metetra
.104 0 0 r
.3226 .44803 .32939 .44225 .339 .43903 .33227 .4448 Metetra
.104 0 0 r
.33227 .4448 .339 .43903 .34865 .4358 .34197 .44155 Metetra
.104 0 0 r
.34197 .44155 .34865 .4358 .35834 .43256 .35172 .4383 Metetra
.104 0 0 r
.35172 .4383 .35834 .43256 .36806 .42931 .36149 .43503 Metetra
.104 0 0 r
.36149 .43503 .36806 .42931 .37781 .42604 .3713 .43176 Metetra
.104 0 0 r
.3713 .43176 .37781 .42604 .38761 .42276 .38115 .42847 Metetra
.104 0 0 r
.38115 .42847 .38761 .42276 .39743 .41947 .39104 .42516 Metetra
.104 0 0 r
.39104 .42516 .39743 .41947 .4073 .41617 .40096 .42185 Metetra
.104 0 0 r
.40096 .42185 .4073 .41617 .4172 .41286 .41092 .41852 Metetra
.104 0 0 r
.41092 .41852 .4172 .41286 .42713 .40953 .42091 .41518 Metetra
.104 0 0 r
.42091 .41518 .42713 .40953 .4371 .4062 .43094 .41183 Metetra
.104 0 0 r
.43094 .41183 .4371 .4062 .44711 .40285 .44101 .40847 Metetra
.104 0 0 r
.44101 .40847 .44711 .40285 .45716 .39948 .45112 .40509 Metetra
.104 0 0 r
.45112 .40509 .45716 .39948 .46724 .39611 .46126 .4017 Metetra
.104 0 0 r
.46126 .4017 .46724 .39611 .47737 .39272 .47145 .3983 Metetra
.104 0 0 r
.47145 .3983 .47737 .39272 .48753 .38932 .48167 .39489 Metetra
.104 0 0 r
.48167 .39489 .48753 .38932 .49772 .38591 .49193 .39146 Metetra
.104 0 0 r
.49193 .39146 .49772 .38591 .50796 .38248 .50222 .38802 Metetra
.104 0 0 r
.50222 .38802 .50796 .38248 .51823 .37904 .51256 .38457 Metetra
.104 0 0 r
.51256 .38457 .51823 .37904 .52854 .37559 .52294 .3811 Metetra
.104 0 0 r
.52294 .3811 .52854 .37559 .53889 .37212 .53335 .37762 Metetra
.104 0 0 r
.53335 .37762 .53889 .37212 .54928 .36865 .54381 .37413 Metetra
.104 0 0 r
.54381 .37413 .54928 .36865 .55971 .36516 .5543 .37062 Metetra
.104 0 0 r
.5543 .37062 .55971 .36516 .57018 .36165 .56484 .3671 Metetra
.104 0 0 r
.56484 .3671 .57018 .36165 .58069 .35813 .57541 .36357 Metetra
.104 0 0 r
.57541 .36357 .58069 .35813 .59124 .3546 .58603 .36003 Metetra
.104 0 0 r
.58603 .36003 .59124 .3546 .60183 .35106 .59668 .35647 Metetra
.104 0 0 r
.59668 .35647 .60183 .35106 .61246 .3475 .60738 .35289 Metetra
.104 0 0 r
.60738 .35289 .61246 .3475 .62313 .34393 .61812 .34931 Metetra
.104 0 0 r
.61812 .34931 .62313 .34393 .63384 .34035 .6289 .3457 Metetra
.104 0 0 r
.6289 .3457 .63384 .34035 .64459 .33675 .63972 .34209 Metetra
.104 0 0 r
.63972 .34209 .64459 .33675 .65538 .33313 .65058 .33846 Metetra
.104 0 0 r
.65058 .33846 .65538 .33313 .66621 .32951 .66149 .33482 Metetra
.104 0 0 r
.66149 .33482 .66621 .32951 .67709 .32587 .67243 .33116 Metetra
.104 0 0 r
.67243 .33116 .67709 .32587 .68801 .32221 .68342 .32749 Metetra
.104 0 0 r
.68342 .32749 .68801 .32221 .69897 .31854 .69446 .3238 Metetra
.104 0 0 r
.69446 .3238 .69897 .31854 .70997 .31486 .70553 .3201 Metetra
.104 0 0 r
.70553 .3201 .70997 .31486 .72102 .31116 .71665 .31639 Metetra
.104 0 0 r
.71665 .31639 .72102 .31116 .7321 .30745 .72781 .31266 Metetra
.104 0 0 r
.72781 .31266 .7321 .30745 .74324 .30373 .73902 .30892 Metetra
.104 0 0 r
.73902 .30892 .74324 .30373 .75441 .29999 .75027 .30516 Metetra
.104 0 0 r
.75027 .30516 .75441 .29999 .76563 .29623 .76157 .30138 Metetra
.104 0 0 r
.76157 .30138 .76563 .29623 .77689 .29246 .77291 .2976 Metetra
.104 0 0 r
.77291 .2976 .77689 .29246 .7882 .28868 .78429 .29379 Metetra
.104 0 0 r
.78429 .29379 .7882 .28868 .79955 .28488 .79572 .28997 Metetra
.104 0 0 r
.79572 .28997 .79955 .28488 .81095 .28106 .8072 .28614 Metetra
.611 .877 .991 r
.1566 .499 .16345 .50119 .17255 .49815 .16573 .49594 Metetra
.611 .877 .991 r
.16573 .49594 .17255 .49815 .18167 .4951 .17488 .49288 Metetra
.611 .877 .991 r
.17488 .49288 .18167 .4951 .19084 .49204 .18407 .4898 Metetra
.611 .877 .991 r
.18407 .4898 .19084 .49204 .20003 .48897 .1933 .48671 Metetra
.611 .877 .991 r
.1933 .48671 .20003 .48897 .20926 .48589 .20255 .48361 Metetra
.611 .877 .991 r
.20255 .48361 .20926 .48589 .21852 .4828 .21184 .4805 Metetra
.611 .877 .991 r
.21184 .4805 .21852 .4828 .22781 .47969 .22116 .47738 Metetra
.611 .877 .991 r
.22116 .47738 .22781 .47969 .23714 .47658 .23051 .47425 Metetra
.611 .877 .991 r
.23051 .47425 .23714 .47658 .2465 .47345 .2399 .4711 Metetra
.611 .877 .991 r
.2399 .4711 .2465 .47345 .25589 .47031 .24933 .46794 Metetra
.611 .877 .991 r
.24933 .46794 .25589 .47031 .26532 .46716 .25878 .46478 Metetra
.611 .877 .991 r
.25878 .46478 .26532 .46716 .27478 .464 .26827 .4616 Metetra
.611 .877 .991 r
.26827 .4616 .27478 .464 .28427 .46083 .2778 .45841 Metetra
.611 .877 .991 r
.2778 .45841 .28427 .46083 .2938 .45765 .28736 .45521 Metetra
.611 .877 .991 r
.28736 .45521 .2938 .45765 .30337 .45445 .29695 .45199 Metetra
.611 .877 .991 r
.29695 .45199 .30337 .45445 .31297 .45124 .30658 .44877 Metetra
.611 .877 .991 r
.30658 .44877 .31297 .45124 .3226 .44803 .31625 .44553 Metetra
.611 .877 .991 r
.31625 .44553 .3226 .44803 .33227 .4448 .32595 .44228 Metetra
.611 .877 .991 r
.32595 .44228 .33227 .4448 .34197 .44155 .33569 .43902 Metetra
.611 .877 .991 r
.33569 .43902 .34197 .44155 .35172 .4383 .34546 .43575 Metetra
.611 .877 .991 r
.34546 .43575 .35172 .4383 .36149 .43503 .35527 .43246 Metetra
.611 .877 .991 r
.35527 .43246 .36149 .43503 .3713 .43176 .36511 .42916 Metetra
.611 .877 .991 r
.36511 .42916 .3713 .43176 .38115 .42847 .37499 .42585 Metetra
.611 .877 .991 r
.37499 .42585 .38115 .42847 .39104 .42516 .38491 .42253 Metetra
.611 .877 .991 r
.38491 .42253 .39104 .42516 .40096 .42185 .39487 .4192 Metetra
.611 .877 .991 r
.39487 .4192 .40096 .42185 .41092 .41852 .40486 .41585 Metetra
.611 .877 .991 r
.40486 .41585 .41092 .41852 .42091 .41518 .41489 .41249 Metetra
.611 .877 .991 r
.41489 .41249 .42091 .41518 .43094 .41183 .42495 .40912 Metetra
.611 .877 .991 r
.42495 .40912 .43094 .41183 .44101 .40847 .43506 .40574 Metetra
.611 .877 .991 r
.43506 .40574 .44101 .40847 .45112 .40509 .4452 .40234 Metetra
.611 .877 .991 r
.4452 .40234 .45112 .40509 .46126 .4017 .45538 .39893 Metetra
.611 .877 .991 r
.45538 .39893 .46126 .4017 .47145 .3983 .4656 .39551 Metetra
.611 .877 .991 r
.4656 .39551 .47145 .3983 .48167 .39489 .47585 .39207 Metetra
.611 .877 .991 r
.47585 .39207 .48167 .39489 .49193 .39146 .48615 .38863 Metetra
.611 .877 .991 r
.48615 .38863 .49193 .39146 .50222 .38802 .49648 .38516 Metetra
.611 .877 .991 r
.49648 .38516 .50222 .38802 .51256 .38457 .50686 .38169 Metetra
.611 .877 .991 r
.50686 .38169 .51256 .38457 .52294 .3811 .51727 .3782 Metetra
.611 .877 .991 r
.51727 .3782 .52294 .3811 .53335 .37762 .52772 .3747 Metetra
.611 .877 .991 r
.52772 .3747 .53335 .37762 .54381 .37413 .53821 .37119 Metetra
.611 .877 .991 r
.53821 .37119 .54381 .37413 .5543 .37062 .54875 .36766 Metetra
.611 .877 .991 r
.54875 .36766 .5543 .37062 .56484 .3671 .55932 .36412 Metetra
.611 .877 .991 r
.55932 .36412 .56484 .3671 .57541 .36357 .56993 .36056 Metetra
.611 .877 .991 r
.56993 .36056 .57541 .36357 .58603 .36003 .58059 .35699 Metetra
.611 .877 .991 r
.58059 .35699 .58603 .36003 .59668 .35647 .59128 .35341 Metetra
.611 .877 .991 r
.59128 .35341 .59668 .35647 .60738 .35289 .60202 .34982 Metetra
.611 .877 .991 r
.60202 .34982 .60738 .35289 .61812 .34931 .6128 .34621 Metetra
.611 .877 .991 r
.6128 .34621 .61812 .34931 .6289 .3457 .62362 .34258 Metetra
.611 .877 .991 r
.62362 .34258 .6289 .3457 .63972 .34209 .63448 .33894 Metetra
.611 .877 .991 r
.63448 .33894 .63972 .34209 .65058 .33846 .64538 .33529 Metetra
.611 .877 .991 r
.64538 .33529 .65058 .33846 .66149 .33482 .65633 .33163 Metetra
.611 .877 .991 r
.65633 .33163 .66149 .33482 .67243 .33116 .66732 .32795 Metetra
.611 .877 .991 r
.66732 .32795 .67243 .33116 .68342 .32749 .67835 .32425 Metetra
.611 .877 .991 r
.67835 .32425 .68342 .32749 .69446 .3238 .68943 .32054 Metetra
.611 .877 .991 r
.68943 .32054 .69446 .3238 .70553 .3201 .70055 .31682 Metetra
.611 .877 .991 r
.70055 .31682 .70553 .3201 .71665 .31639 .71171 .31308 Metetra
.611 .877 .991 r
.71171 .31308 .71665 .31639 .72781 .31266 .72291 .30932 Metetra
.611 .877 .991 r
.72291 .30932 .72781 .31266 .73902 .30892 .73417 .30556 Metetra
.611 .877 .991 r
.73417 .30556 .73902 .30892 .75027 .30516 .74546 .30177 Metetra
.611 .877 .991 r
.74546 .30177 .75027 .30516 .76157 .30138 .7568 .29797 Metetra
.611 .877 .991 r
.7568 .29797 .76157 .30138 .77291 .2976 .76819 .29416 Metetra
.611 .877 .991 r
.76819 .29416 .77291 .2976 .78429 .29379 .77962 .29033 Metetra
.611 .877 .991 r
.77962 .29033 .78429 .29379 .79572 .28997 .79109 .28649 Metetra
.611 .877 .991 r
.79109 .28649 .79572 .28997 .8072 .28614 .80261 .28263 Metetra
.573 .897 .985 r
.1496 .4977 .1566 .499 .16573 .49594 .15875 .49462 Metetra
.573 .897 .985 r
.15875 .49462 .16573 .49594 .17488 .49288 .16794 .49154 Metetra
.573 .897 .985 r
.16794 .49154 .17488 .49288 .18407 .4898 .17716 .48845 Metetra
.573 .897 .985 r
.17716 .48845 .18407 .4898 .1933 .48671 .18641 .48534 Metetra
.573 .897 .985 r
.18641 .48534 .1933 .48671 .20255 .48361 .19569 .48222 Metetra
.573 .897 .985 r
.19569 .48222 .20255 .48361 .21184 .4805 .20501 .4791 Metetra
.573 .897 .985 r
.20501 .4791 .21184 .4805 .22116 .47738 .21436 .47596 Metetra
.573 .897 .985 r
.21436 .47596 .22116 .47738 .23051 .47425 .22375 .47281 Metetra
.573 .897 .985 r
.22375 .47281 .23051 .47425 .2399 .4711 .23317 .46965 Metetra
.573 .897 .985 r
.23317 .46965 .2399 .4711 .24933 .46794 .24263 .46647 Metetra
.573 .897 .985 r
.24263 .46647 .24933 .46794 .25878 .46478 .25212 .46329 Metetra
.573 .897 .985 r
.25212 .46329 .25878 .46478 .26827 .4616 .26164 .46009 Metetra
.573 .897 .985 r
.26164 .46009 .26827 .4616 .2778 .45841 .2712 .45688 Metetra
.573 .897 .985 r
.2712 .45688 .2778 .45841 .28736 .45521 .28079 .45366 Metetra
.573 .897 .985 r
.28079 .45366 .28736 .45521 .29695 .45199 .29042 .45043 Metetra
.573 .897 .985 r
.29042 .45043 .29695 .45199 .30658 .44877 .30008 .44719 Metetra
.573 .897 .985 r
.30008 .44719 .30658 .44877 .31625 .44553 .30978 .44393 Metetra
.573 .897 .985 r
.30978 .44393 .31625 .44553 .32595 .44228 .31952 .44066 Metetra
.573 .897 .985 r
.31952 .44066 .32595 .44228 .33569 .43902 .32929 .43738 Metetra
.573 .897 .985 r
.32929 .43738 .33569 .43902 .34546 .43575 .3391 .43409 Metetra
.573 .897 .985 r
.3391 .43409 .34546 .43575 .35527 .43246 .34894 .43079 Metetra
.573 .897 .985 r
.34894 .43079 .35527 .43246 .36511 .42916 .35882 .42747 Metetra
.573 .897 .985 r
.35882 .42747 .36511 .42916 .37499 .42585 .36874 .42414 Metetra
.573 .897 .985 r
.36874 .42414 .37499 .42585 .38491 .42253 .37869 .4208 Metetra
.573 .897 .985 r
.37869 .4208 .38491 .42253 .39487 .4192 .38868 .41745 Metetra
.573 .897 .985 r
.38868 .41745 .39487 .4192 .40486 .41585 .39871 .41408 Metetra
.573 .897 .985 r
.39871 .41408 .40486 .41585 .41489 .41249 .40877 .41071 Metetra
.573 .897 .985 r
.40877 .41071 .41489 .41249 .42495 .40912 .41888 .40731 Metetra
.573 .897 .985 r
.41888 .40731 .42495 .40912 .43506 .40574 .42902 .40391 Metetra
.573 .897 .985 r
.42902 .40391 .43506 .40574 .4452 .40234 .4392 .40049 Metetra
.573 .897 .985 r
.4392 .40049 .4452 .40234 .45538 .39893 .44942 .39706 Metetra
.573 .897 .985 r
.44942 .39706 .45538 .39893 .4656 .39551 .45967 .39362 Metetra
.573 .897 .985 r
.45967 .39362 .4656 .39551 .47585 .39207 .46997 .39017 Metetra
.573 .897 .985 r
.46997 .39017 .47585 .39207 .48615 .38863 .4803 .3867 Metetra
.573 .897 .985 r
.4803 .3867 .48615 .38863 .49648 .38516 .49068 .38321 Metetra
.573 .897 .985 r
.49068 .38321 .49648 .38516 .50686 .38169 .50109 .37972 Metetra
.573 .897 .985 r
.50109 .37972 .50686 .38169 .51727 .3782 .51154 .37621 Metetra
.573 .897 .985 r
.51154 .37621 .51727 .3782 .52772 .3747 .52204 .37269 Metetra
.573 .897 .985 r
.52204 .37269 .52772 .3747 .53821 .37119 .53257 .36915 Metetra
.573 .897 .985 r
.53257 .36915 .53821 .37119 .54875 .36766 .54315 .3656 Metetra
.573 .897 .985 r
.54315 .3656 .54875 .36766 .55932 .36412 .55376 .36204 Metetra
.573 .897 .985 r
.55376 .36204 .55932 .36412 .56993 .36056 .56442 .35847 Metetra
.573 .897 .985 r
.56442 .35847 .56993 .36056 .58059 .35699 .57511 .35487 Metetra
.573 .897 .985 r
.57511 .35487 .58059 .35699 .59128 .35341 .58585 .35127 Metetra
.573 .897 .985 r
.58585 .35127 .59128 .35341 .60202 .34982 .59663 .34765 Metetra
.573 .897 .985 r
.59663 .34765 .60202 .34982 .6128 .34621 .60745 .34402 Metetra
.573 .897 .985 r
.60745 .34402 .6128 .34621 .62362 .34258 .61832 .34037 Metetra
.573 .897 .985 r
.61832 .34037 .62362 .34258 .63448 .33894 .62922 .33671 Metetra
.573 .897 .985 r
.62922 .33671 .63448 .33894 .64538 .33529 .64017 .33304 Metetra
.573 .897 .985 r
.64017 .33304 .64538 .33529 .65633 .33163 .65116 .32935 Metetra
.573 .897 .985 r
.65116 .32935 .65633 .33163 .66732 .32795 .6622 .32565 Metetra
.573 .897 .985 r
.6622 .32565 .66732 .32795 .67835 .32425 .67327 .32193 Metetra
.573 .897 .985 r
.67327 .32193 .67835 .32425 .68943 .32054 .6844 .31819 Metetra
.573 .897 .985 r
.6844 .31819 .68943 .32054 .70055 .31682 .69556 .31445 Metetra
.573 .897 .985 r
.69556 .31445 .70055 .31682 .71171 .31308 .70677 .31068 Metetra
.573 .897 .985 r
.70677 .31068 .71171 .31308 .72291 .30932 .71803 .30691 Metetra
.573 .897 .985 r
.71803 .30691 .72291 .30932 .73417 .30556 .72932 .30311 Metetra
.573 .897 .985 r
.72932 .30311 .73417 .30556 .74546 .30177 .74067 .29931 Metetra
.573 .897 .985 r
.74067 .29931 .74546 .30177 .7568 .29797 .75206 .29548 Metetra
.573 .897 .985 r
.75206 .29548 .7568 .29797 .76819 .29416 .76349 .29165 Metetra
.573 .897 .985 r
.76349 .29165 .76819 .29416 .77962 .29033 .77497 .28779 Metetra
.573 .897 .985 r
.77497 .28779 .77962 .29033 .79109 .28649 .7865 .28392 Metetra
.573 .897 .985 r
.7865 .28392 .79109 .28649 .80261 .28263 .79807 .28004 Metetra
.646 .817 .965 r
.14283 .49375 .1496 .4977 .15875 .49462 .15201 .49065 Metetra
.646 .817 .965 r
.15201 .49065 .15875 .49462 .16794 .49154 .16122 .48755 Metetra
.646 .817 .965 r
.16122 .48755 .16794 .49154 .17716 .48845 .17046 .48444 Metetra
.646 .817 .965 r
.17046 .48444 .17716 .48845 .18641 .48534 .17973 .48131 Metetra
.646 .817 .965 r
.17973 .48131 .18641 .48534 .19569 .48222 .18904 .47818 Metetra
.646 .817 .965 r
.18904 .47818 .19569 .48222 .20501 .4791 .19839 .47503 Metetra
.646 .817 .965 r
.19839 .47503 .20501 .4791 .21436 .47596 .20776 .47187 Metetra
.646 .817 .965 r
.20776 .47187 .21436 .47596 .22375 .47281 .21717 .4687 Metetra
.646 .817 .965 r
.21717 .4687 .22375 .47281 .23317 .46965 .22662 .46552 Metetra
.646 .817 .965 r
.22662 .46552 .23317 .46965 .24263 .46647 .2361 .46233 Metetra
.646 .817 .965 r
.2361 .46233 .24263 .46647 .25212 .46329 .24561 .45912 Metetra
.646 .817 .965 r
.24561 .45912 .25212 .46329 .26164 .46009 .25516 .45591 Metetra
.646 .817 .965 r
.25516 .45591 .26164 .46009 .2712 .45688 .26474 .45268 Metetra
.646 .817 .965 r
.26474 .45268 .2712 .45688 .28079 .45366 .27436 .44944 Metetra
.646 .817 .965 r
.27436 .44944 .28079 .45366 .29042 .45043 .28402 .44619 Metetra
.646 .817 .965 r
.28402 .44619 .29042 .45043 .30008 .44719 .29371 .44292 Metetra
.646 .817 .965 r
.29371 .44292 .30008 .44719 .30978 .44393 .30343 .43964 Metetra
.646 .817 .965 r
.30343 .43964 .30978 .44393 .31952 .44066 .3132 .43636 Metetra
.646 .817 .965 r
.3132 .43636 .31952 .44066 .32929 .43738 .32299 .43306 Metetra
.646 .817 .965 r
.32299 .43306 .32929 .43738 .3391 .43409 .33283 .42974 Metetra
.646 .817 .965 r
.33283 .42974 .3391 .43409 .34894 .43079 .3427 .42642 Metetra
.646 .817 .965 r
.3427 .42642 .34894 .43079 .35882 .42747 .35261 .42308 Metetra
.646 .817 .965 r
.35261 .42308 .35882 .42747 .36874 .42414 .36255 .41973 Metetra
.646 .817 .965 r
.36255 .41973 .36874 .42414 .37869 .4208 .37253 .41637 Metetra
.646 .817 .965 r
.37253 .41637 .37869 .4208 .38868 .41745 .38255 .41299 Metetra
.646 .817 .965 r
.38255 .41299 .38868 .41745 .39871 .41408 .39261 .4096 Metetra
.646 .817 .965 r
.39261 .4096 .39871 .41408 .40877 .41071 .4027 .4062 Metetra
.646 .817 .965 r
.4027 .4062 .40877 .41071 .41888 .40731 .41284 .40279 Metetra
.646 .817 .965 r
.41284 .40279 .41888 .40731 .42902 .40391 .42301 .39936 Metetra
.646 .817 .965 r
.42301 .39936 .42902 .40391 .4392 .40049 .43322 .39593 Metetra
.646 .817 .965 r
.43322 .39593 .4392 .40049 .44942 .39706 .44347 .39247 Metetra
.646 .817 .965 r
.44347 .39247 .44942 .39706 .45967 .39362 .45375 .38901 Metetra
.646 .817 .965 r
.45375 .38901 .45967 .39362 .46997 .39017 .46408 .38553 Metetra
.646 .817 .965 r
.46408 .38553 .46997 .39017 .4803 .3867 .47444 .38204 Metetra
.646 .817 .965 r
.47444 .38204 .4803 .3867 .49068 .38321 .48485 .37853 Metetra
.646 .817 .965 r
.48485 .37853 .49068 .38321 .50109 .37972 .49529 .37501 Metetra
.646 .817 .965 r
.49529 .37501 .50109 .37972 .51154 .37621 .50578 .37148 Metetra
.646 .817 .965 r
.50578 .37148 .51154 .37621 .52204 .37269 .51631 .36794 Metetra
.646 .817 .965 r
.51631 .36794 .52204 .37269 .53257 .36915 .52687 .36438 Metetra
.646 .817 .965 r
.52687 .36438 .53257 .36915 .54315 .3656 .53748 .3608 Metetra
.646 .817 .965 r
.53748 .3608 .54315 .3656 .55376 .36204 .54813 .35722 Metetra
.646 .817 .965 r
.54813 .35722 .55376 .36204 .56442 .35847 .55881 .35362 Metetra
.646 .817 .965 r
.55881 .35362 .56442 .35847 .57511 .35487 .56954 .35 Metetra
.646 .817 .965 r
.56954 .35 .57511 .35487 .58585 .35127 .58032 .34637 Metetra
.646 .817 .965 r
.58032 .34637 .58585 .35127 .59663 .34765 .59113 .34273 Metetra
.646 .817 .965 r
.59113 .34273 .59663 .34765 .60745 .34402 .60199 .33907 Metetra
.646 .817 .965 r
.60199 .33907 .60745 .34402 .61832 .34037 .61288 .3354 Metetra
.646 .817 .965 r
.61288 .3354 .61832 .34037 .62922 .33671 .62383 .33172 Metetra
.646 .817 .965 r
.62383 .33172 .62922 .33671 .64017 .33304 .63481 .32802 Metetra
.646 .817 .965 r
.63481 .32802 .64017 .33304 .65116 .32935 .64584 .3243 Metetra
.646 .817 .965 r
.64584 .3243 .65116 .32935 .6622 .32565 .65691 .32057 Metetra
.646 .817 .965 r
.65691 .32057 .6622 .32565 .67327 .32193 .66802 .31683 Metetra
.646 .817 .965 r
.66802 .31683 .67327 .32193 .6844 .31819 .67918 .31307 Metetra
.646 .817 .965 r
.67918 .31307 .6844 .31819 .69556 .31445 .69038 .3093 Metetra
.646 .817 .965 r
.69038 .3093 .69556 .31445 .70677 .31068 .70163 .30551 Metetra
.646 .817 .965 r
.70163 .30551 .70677 .31068 .71803 .30691 .71292 .3017 Metetra
.646 .817 .965 r
.71292 .3017 .71803 .30691 .72932 .30311 .72426 .29789 Metetra
.646 .817 .965 r
.72426 .29789 .72932 .30311 .74067 .29931 .73564 .29405 Metetra
.646 .817 .965 r
.73564 .29405 .74067 .29931 .75206 .29548 .74707 .2902 Metetra
.646 .817 .965 r
.74707 .2902 .75206 .29548 .76349 .29165 .75854 .28634 Metetra
.646 .817 .965 r
.75854 .28634 .76349 .29165 .77497 .28779 .77006 .28246 Metetra
.646 .817 .965 r
.77006 .28246 .77497 .28779 .7865 .28392 .78163 .27856 Metetra
.646 .817 .965 r
.78163 .27856 .7865 .28392 .79807 .28004 .79324 .27465 Metetra
.64 .835 .976 r
.13595 .49025 .14283 .49375 .15201 .49065 .14515 .48714 Metetra
.64 .835 .976 r
.14515 .48714 .15201 .49065 .16122 .48755 .15439 .48402 Metetra
.64 .835 .976 r
.15439 .48402 .16122 .48755 .17046 .48444 .16365 .48089 Metetra
.64 .835 .976 r
.16365 .48089 .17046 .48444 .17973 .48131 .17295 .47774 Metetra
.64 .835 .976 r
.17295 .47774 .17973 .48131 .18904 .47818 .18229 .47459 Metetra
.64 .835 .976 r
.18229 .47459 .18904 .47818 .19839 .47503 .19166 .47142 Metetra
.64 .835 .976 r
.19166 .47142 .19839 .47503 .20776 .47187 .20106 .46824 Metetra
.64 .835 .976 r
.20106 .46824 .20776 .47187 .21717 .4687 .2105 .46505 Metetra
.64 .835 .976 r
.2105 .46505 .21717 .4687 .22662 .46552 .21997 .46185 Metetra
.64 .835 .976 r
.21997 .46185 .22662 .46552 .2361 .46233 .22947 .45864 Metetra
.64 .835 .976 r
.22947 .45864 .2361 .46233 .24561 .45912 .23901 .45542 Metetra
.64 .835 .976 r
.23901 .45542 .24561 .45912 .25516 .45591 .24859 .45218 Metetra
.64 .835 .976 r
.24859 .45218 .25516 .45591 .26474 .45268 .2582 .44893 Metetra
.64 .835 .976 r
.2582 .44893 .26474 .45268 .27436 .44944 .26785 .44567 Metetra
.64 .835 .976 r
.26785 .44567 .27436 .44944 .28402 .44619 .27753 .4424 Metetra
.64 .835 .976 r
.27753 .4424 .28402 .44619 .29371 .44292 .28725 .43911 Metetra
.64 .835 .976 r
.28725 .43911 .29371 .44292 .30343 .43964 .297 .43582 Metetra
.64 .835 .976 r
.297 .43582 .30343 .43964 .3132 .43636 .30679 .43251 Metetra
.64 .835 .976 r
.30679 .43251 .3132 .43636 .32299 .43306 .31662 .42919 Metetra
.64 .835 .976 r
.31662 .42919 .32299 .43306 .33283 .42974 .32648 .42585 Metetra
.64 .835 .976 r
.32648 .42585 .33283 .42974 .3427 .42642 .33638 .42251 Metetra
.64 .835 .976 r
.33638 .42251 .3427 .42642 .35261 .42308 .34632 .41915 Metetra
.64 .835 .976 r
.34632 .41915 .35261 .42308 .36255 .41973 .35629 .41578 Metetra
.64 .835 .976 r
.35629 .41578 .36255 .41973 .37253 .41637 .3663 .41239 Metetra
.64 .835 .976 r
.3663 .41239 .37253 .41637 .38255 .41299 .37635 .40899 Metetra
.64 .835 .976 r
.37635 .40899 .38255 .41299 .39261 .4096 .38644 .40559 Metetra
.64 .835 .976 r
.38644 .40559 .39261 .4096 .4027 .4062 .39657 .40216 Metetra
.64 .835 .976 r
.39657 .40216 .4027 .4062 .41284 .40279 .40673 .39873 Metetra
.64 .835 .976 r
.40673 .39873 .41284 .40279 .42301 .39936 .41693 .39528 Metetra
.64 .835 .976 r
.41693 .39528 .42301 .39936 .43322 .39593 .42717 .39182 Metetra
.64 .835 .976 r
.42717 .39182 .43322 .39593 .44347 .39247 .43745 .38834 Metetra
.64 .835 .976 r
.43745 .38834 .44347 .39247 .45375 .38901 .44777 .38486 Metetra
.64 .835 .976 r
.44777 .38486 .45375 .38901 .46408 .38553 .45813 .38135 Metetra
.64 .835 .976 r
.45813 .38135 .46408 .38553 .47444 .38204 .46853 .37784 Metetra
.64 .835 .976 r
.46853 .37784 .47444 .38204 .48485 .37853 .47897 .37431 Metetra
.64 .835 .976 r
.47897 .37431 .48485 .37853 .49529 .37501 .48945 .37077 Metetra
.64 .835 .976 r
.48945 .37077 .49529 .37501 .50578 .37148 .49996 .36721 Metetra
.64 .835 .976 r
.49996 .36721 .50578 .37148 .51631 .36794 .51052 .36365 Metetra
.64 .835 .976 r
.51052 .36365 .51631 .36794 .52687 .36438 .52112 .36006 Metetra
.64 .835 .976 r
.52112 .36006 .52687 .36438 .53748 .3608 .53176 .35647 Metetra
.64 .835 .976 r
.53176 .35647 .53748 .3608 .54813 .35722 .54245 .35286 Metetra
.64 .835 .976 r
.54245 .35286 .54813 .35722 .55881 .35362 .55317 .34923 Metetra
.64 .835 .976 r
.55317 .34923 .55881 .35362 .56954 .35 .56394 .34559 Metetra
.64 .835 .976 r
.56394 .34559 .56954 .35 .58032 .34637 .57474 .34194 Metetra
.64 .835 .976 r
.57474 .34194 .58032 .34637 .59113 .34273 .58559 .33827 Metetra
.64 .835 .976 r
.58559 .33827 .59113 .34273 .60199 .33907 .59649 .33459 Metetra
.64 .835 .976 r
.59649 .33459 .60199 .33907 .61288 .3354 .60742 .33089 Metetra
.64 .835 .976 r
.60742 .33089 .61288 .3354 .62383 .33172 .6184 .32718 Metetra
.64 .835 .976 r
.6184 .32718 .62383 .33172 .63481 .32802 .62942 .32346 Metetra
.64 .835 .976 r
.62942 .32346 .63481 .32802 .64584 .3243 .64048 .31972 Metetra
.64 .835 .976 r
.64048 .31972 .64584 .3243 .65691 .32057 .65159 .31596 Metetra
.64 .835 .976 r
.65159 .31596 .65691 .32057 .66802 .31683 .66275 .31219 Metetra
.64 .835 .976 r
.66275 .31219 .66802 .31683 .67918 .31307 .67394 .30841 Metetra
.64 .835 .976 r
.67394 .30841 .67918 .31307 .69038 .3093 .68518 .30461 Metetra
.64 .835 .976 r
.68518 .30461 .69038 .3093 .70163 .30551 .69647 .3008 Metetra
.64 .835 .976 r
.69647 .3008 .70163 .30551 .71292 .3017 .7078 .29697 Metetra
.64 .835 .976 r
.7078 .29697 .71292 .3017 .72426 .29789 .71918 .29312 Metetra
.64 .835 .976 r
.71918 .29312 .72426 .29789 .73564 .29405 .7306 .28926 Metetra
.64 .835 .976 r
.7306 .28926 .73564 .29405 .74707 .2902 .74207 .28538 Metetra
.64 .835 .976 r
.74207 .28538 .74707 .2902 .75854 .28634 .75359 .28149 Metetra
.64 .835 .976 r
.75359 .28149 .75854 .28634 .77006 .28246 .76515 .27758 Metetra
.64 .835 .976 r
.76515 .27758 .77006 .28246 .78163 .27856 .77675 .27366 Metetra
.64 .835 .976 r
.77675 .27366 .78163 .27856 .79324 .27465 .78841 .26972 Metetra
.651 .79 .948 r
.12917 .48551 .13595 .49025 .14515 .48714 .13839 .48238 Metetra
.651 .79 .948 r
.13839 .48238 .14515 .48714 .15439 .48402 .14764 .47924 Metetra
.651 .79 .948 r
.14764 .47924 .15439 .48402 .16365 .48089 .15693 .47609 Metetra
.651 .79 .948 r
.15693 .47609 .16365 .48089 .17295 .47774 .16625 .47293 Metetra
.651 .79 .948 r
.16625 .47293 .17295 .47774 .18229 .47459 .17561 .46975 Metetra
.651 .79 .948 r
.17561 .46975 .18229 .47459 .19166 .47142 .185 .46656 Metetra
.651 .79 .948 r
.185 .46656 .19166 .47142 .20106 .46824 .19443 .46336 Metetra
.651 .79 .948 r
.19443 .46336 .20106 .46824 .2105 .46505 .20389 .46015 Metetra
.651 .79 .948 r
.20389 .46015 .2105 .46505 .21997 .46185 .21338 .45693 Metetra
.651 .79 .948 r
.21338 .45693 .21997 .46185 .22947 .45864 .22291 .4537 Metetra
.651 .79 .948 r
.22291 .4537 .22947 .45864 .23901 .45542 .23247 .45045 Metetra
.651 .79 .948 r
.23247 .45045 .23901 .45542 .24859 .45218 .24207 .44719 Metetra
.651 .79 .948 r
.24207 .44719 .24859 .45218 .2582 .44893 .25171 .44392 Metetra
.651 .79 .948 r
.25171 .44392 .2582 .44893 .26785 .44567 .26138 .44064 Metetra
.651 .79 .948 r
.26138 .44064 .26785 .44567 .27753 .4424 .27108 .43735 Metetra
.651 .79 .948 r
.27108 .43735 .27753 .4424 .28725 .43911 .28083 .43404 Metetra
.651 .79 .948 r
.28083 .43404 .28725 .43911 .297 .43582 .2906 .43072 Metetra
.651 .79 .948 r
.2906 .43072 .297 .43582 .30679 .43251 .30042 .42739 Metetra
.651 .79 .948 r
.30042 .42739 .30679 .43251 .31662 .42919 .31027 .42405 Metetra
.651 .79 .948 r
.31027 .42405 .31662 .42919 .32648 .42585 .32016 .42069 Metetra
.651 .79 .948 r
.32016 .42069 .32648 .42585 .33638 .42251 .33008 .41733 Metetra
.651 .79 .948 r
.33008 .41733 .33638 .42251 .34632 .41915 .34005 .41394 Metetra
.651 .79 .948 r
.34005 .41394 .34632 .41915 .35629 .41578 .35005 .41055 Metetra
.651 .79 .948 r
.35005 .41055 .35629 .41578 .3663 .41239 .36009 .40714 Metetra
.651 .79 .948 r
.36009 .40714 .3663 .41239 .37635 .40899 .37016 .40372 Metetra
.651 .79 .948 r
.37016 .40372 .37635 .40899 .38644 .40559 .38028 .40029 Metetra
.651 .79 .948 r
.38028 .40029 .38644 .40559 .39657 .40216 .39043 .39685 Metetra
.651 .79 .948 r
.39043 .39685 .39657 .40216 .40673 .39873 .40062 .39339 Metetra
.651 .79 .948 r
.40062 .39339 .40673 .39873 .41693 .39528 .41085 .38992 Metetra
.651 .79 .948 r
.41085 .38992 .41693 .39528 .42717 .39182 .42112 .38643 Metetra
.651 .79 .948 r
.42112 .38643 .42717 .39182 .43745 .38834 .43143 .38293 Metetra
.651 .79 .948 r
.43143 .38293 .43745 .38834 .44777 .38486 .44177 .37942 Metetra
.651 .79 .948 r
.44177 .37942 .44777 .38486 .45813 .38135 .45216 .3759 Metetra
.651 .79 .948 r
.45216 .3759 .45813 .38135 .46853 .37784 .46259 .37236 Metetra
.651 .79 .948 r
.46259 .37236 .46853 .37784 .47897 .37431 .47305 .3688 Metetra
.651 .79 .948 r
.47305 .3688 .47897 .37431 .48945 .37077 .48356 .36524 Metetra
.651 .79 .948 r
.48356 .36524 .48945 .37077 .49996 .36721 .49411 .36166 Metetra
.651 .79 .948 r
.49411 .36166 .49996 .36721 .51052 .36365 .5047 .35807 Metetra
.651 .79 .948 r
.5047 .35807 .51052 .36365 .52112 .36006 .51533 .35446 Metetra
.651 .79 .948 r
.51533 .35446 .52112 .36006 .53176 .35647 .526 .35084 Metetra
.651 .79 .948 r
.526 .35084 .53176 .35647 .54245 .35286 .53671 .3472 Metetra
.651 .79 .948 r
.53671 .3472 .54245 .35286 .55317 .34923 .54747 .34355 Metetra
.651 .79 .948 r
.54747 .34355 .55317 .34923 .56394 .34559 .55827 .33989 Metetra
.651 .79 .948 r
.55827 .33989 .56394 .34559 .57474 .34194 .5691 .33621 Metetra
.651 .79 .948 r
.5691 .33621 .57474 .34194 .58559 .33827 .57999 .33251 Metetra
.651 .79 .948 r
.57999 .33251 .58559 .33827 .59649 .33459 .59091 .32881 Metetra
.651 .79 .948 r
.59091 .32881 .59649 .33459 .60742 .33089 .60188 .32509 Metetra
.651 .79 .948 r
.60188 .32509 .60742 .33089 .6184 .32718 .61289 .32135 Metetra
.651 .79 .948 r
.61289 .32135 .6184 .32718 .62942 .32346 .62394 .3176 Metetra
.651 .79 .948 r
.62394 .3176 .62942 .32346 .64048 .31972 .63504 .31383 Metetra
.651 .79 .948 r
.63504 .31383 .64048 .31972 .65159 .31596 .64618 .31005 Metetra
.651 .79 .948 r
.64618 .31005 .65159 .31596 .66275 .31219 .65737 .30625 Metetra
.651 .79 .948 r
.65737 .30625 .66275 .31219 .67394 .30841 .6686 .30244 Metetra
.651 .79 .948 r
.6686 .30244 .67394 .30841 .68518 .30461 .67988 .29861 Metetra
.651 .79 .948 r
.67988 .29861 .68518 .30461 .69647 .3008 .6912 .29477 Metetra
.651 .79 .948 r
.6912 .29477 .69647 .3008 .7078 .29697 .70257 .29091 Metetra
.651 .79 .948 r
.70257 .29091 .7078 .29697 .71918 .29312 .71398 .28704 Metetra
.651 .79 .948 r
.71398 .28704 .71918 .29312 .7306 .28926 .72544 .28315 Metetra
.651 .79 .948 r
.72544 .28315 .7306 .28926 .74207 .28538 .73694 .27925 Metetra
.651 .79 .948 r
.73694 .27925 .74207 .28538 .75359 .28149 .74849 .27533 Metetra
.651 .79 .948 r
.74849 .27533 .75359 .28149 .76515 .27758 .76009 .27139 Metetra
.651 .79 .948 r
.76009 .27139 .76515 .27758 .77675 .27366 .77174 .26744 Metetra
.651 .79 .948 r
.77174 .26744 .77675 .27366 .78841 .26972 .78343 .26347 Metetra
.65 .801 .955 r
.12229 .48103 .12917 .48551 .13839 .48238 .13154 .47789 Metetra
.65 .801 .955 r
.13154 .47789 .13839 .48238 .14764 .47924 .14082 .47472 Metetra
.65 .801 .955 r
.14082 .47472 .14764 .47924 .15693 .47609 .15013 .47155 Metetra
.65 .801 .955 r
.15013 .47155 .15693 .47609 .16625 .47293 .15947 .46837 Metetra
.65 .801 .955 r
.15947 .46837 .16625 .47293 .17561 .46975 .16885 .46517 Metetra
.65 .801 .955 r
.16885 .46517 .17561 .46975 .185 .46656 .17826 .46197 Metetra
.65 .801 .955 r
.17826 .46197 .185 .46656 .19443 .46336 .18771 .45875 Metetra
.65 .801 .955 r
.18771 .45875 .19443 .46336 .20389 .46015 .1972 .45552 Metetra
.65 .801 .955 r
.1972 .45552 .20389 .46015 .21338 .45693 .20671 .45227 Metetra
.65 .801 .955 r
.20671 .45227 .21338 .45693 .22291 .4537 .21627 .44902 Metetra
.65 .801 .955 r
.21627 .44902 .22291 .4537 .23247 .45045 .22585 .44575 Metetra
.65 .801 .955 r
.22585 .44575 .23247 .45045 .24207 .44719 .23548 .44247 Metetra
.65 .801 .955 r
.23548 .44247 .24207 .44719 .25171 .44392 .24514 .43918 Metetra
.65 .801 .955 r
.24514 .43918 .25171 .44392 .26138 .44064 .25483 .43588 Metetra
.65 .801 .955 r
.25483 .43588 .26138 .44064 .27108 .43735 .26456 .43256 Metetra
.65 .801 .955 r
.26456 .43256 .27108 .43735 .28083 .43404 .27433 .42923 Metetra
.65 .801 .955 r
.27433 .42923 .28083 .43404 .2906 .43072 .28414 .42589 Metetra
.65 .801 .955 r
.28414 .42589 .2906 .43072 .30042 .42739 .29398 .42254 Metetra
.65 .801 .955 r
.29398 .42254 .30042 .42739 .31027 .42405 .30385 .41918 Metetra
.65 .801 .955 r
.30385 .41918 .31027 .42405 .32016 .42069 .31377 .4158 Metetra
.65 .801 .955 r
.31377 .4158 .32016 .42069 .33008 .41733 .32372 .41241 Metetra
.65 .801 .955 r
.32372 .41241 .33008 .41733 .34005 .41394 .33371 .409 Metetra
.65 .801 .955 r
.33371 .409 .34005 .41394 .35005 .41055 .34374 .40559 Metetra
.65 .801 .955 r
.34374 .40559 .35005 .41055 .36009 .40714 .3538 .40216 Metetra
.65 .801 .955 r
.3538 .40216 .36009 .40714 .37016 .40372 .36391 .39871 Metetra
.65 .801 .955 r
.36391 .39871 .37016 .40372 .38028 .40029 .37405 .39526 Metetra
.65 .801 .955 r
.37405 .39526 .38028 .40029 .39043 .39685 .38423 .39179 Metetra
.65 .801 .955 r
.38423 .39179 .39043 .39685 .40062 .39339 .39445 .38831 Metetra
.65 .801 .955 r
.39445 .38831 .40062 .39339 .41085 .38992 .40471 .38481 Metetra
.65 .801 .955 r
.40471 .38481 .41085 .38992 .42112 .38643 .415 .38131 Metetra
.65 .801 .955 r
.415 .38131 .42112 .38643 .43143 .38293 .42534 .37778 Metetra
.65 .801 .955 r
.42534 .37778 .43143 .38293 .44177 .37942 .43572 .37425 Metetra
.65 .801 .955 r
.43572 .37425 .44177 .37942 .45216 .3759 .44614 .3707 Metetra
.65 .801 .955 r
.44614 .3707 .45216 .3759 .46259 .37236 .45659 .36714 Metetra
.65 .801 .955 r
.45659 .36714 .46259 .37236 .47305 .3688 .46709 .36356 Metetra
.65 .801 .955 r
.46709 .36356 .47305 .3688 .48356 .36524 .47763 .35997 Metetra
.65 .801 .955 r
.47763 .35997 .48356 .36524 .49411 .36166 .48821 .35636 Metetra
.65 .801 .955 r
.48821 .35636 .49411 .36166 .5047 .35807 .49883 .35275 Metetra
.65 .801 .955 r
.49883 .35275 .5047 .35807 .51533 .35446 .50949 .34911 Metetra
.65 .801 .955 r
.50949 .34911 .51533 .35446 .526 .35084 .52019 .34547 Metetra
.65 .801 .955 r
.52019 .34547 .526 .35084 .53671 .3472 .53094 .34181 Metetra
.65 .801 .955 r
.53094 .34181 .53671 .3472 .54747 .34355 .54172 .33813 Metetra
.65 .801 .955 r
.54172 .33813 .54747 .34355 .55827 .33989 .55255 .33444 Metetra
.65 .801 .955 r
.55255 .33444 .55827 .33989 .5691 .33621 .56342 .33074 Metetra
.65 .801 .955 r
.56342 .33074 .5691 .33621 .57999 .33251 .57434 .32702 Metetra
.65 .801 .955 r
.57434 .32702 .57999 .33251 .59091 .32881 .5853 .32328 Metetra
.65 .801 .955 r
.5853 .32328 .59091 .32881 .60188 .32509 .5963 .31954 Metetra
.65 .801 .955 r
.5963 .31954 .60188 .32509 .61289 .32135 .60734 .31577 Metetra
.65 .801 .955 r
.60734 .31577 .61289 .32135 .62394 .3176 .61843 .312 Metetra
.65 .801 .955 r
.61843 .312 .62394 .3176 .63504 .31383 .62956 .3082 Metetra
.65 .801 .955 r
.62956 .3082 .63504 .31383 .64618 .31005 .64074 .30439 Metetra
.65 .801 .955 r
.64074 .30439 .64618 .31005 .65737 .30625 .65196 .30057 Metetra
.65 .801 .955 r
.65196 .30057 .65737 .30625 .6686 .30244 .66323 .29673 Metetra
.65 .801 .955 r
.66323 .29673 .6686 .30244 .67988 .29861 .67454 .29288 Metetra
.65 .801 .955 r
.67454 .29288 .67988 .29861 .6912 .29477 .6859 .28901 Metetra
.65 .801 .955 r
.6859 .28901 .6912 .29477 .70257 .29091 .6973 .28512 Metetra
.65 .801 .955 r
.6973 .28512 .70257 .29091 .71398 .28704 .70875 .28122 Metetra
.65 .801 .955 r
.70875 .28122 .71398 .28704 .72544 .28315 .72025 .2773 Metetra
.65 .801 .955 r
.72025 .2773 .72544 .28315 .73694 .27925 .73179 .27337 Metetra
.65 .801 .955 r
.73179 .27337 .73694 .27925 .74849 .27533 .74338 .26942 Metetra
.65 .801 .955 r
.74338 .26942 .74849 .27533 .76009 .27139 .75502 .26546 Metetra
.65 .801 .955 r
.75502 .26546 .76009 .27139 .77174 .26744 .7667 .26148 Metetra
.65 .801 .955 r
.7667 .26148 .77174 .26744 .78343 .26347 .77843 .25748 Metetra
.653 .776 .939 r
.11545 .47586 .12229 .48103 .13154 .47789 .12472 .47269 Metetra
.653 .776 .939 r
.12472 .47269 .13154 .47789 .14082 .47472 .13402 .4695 Metetra
.653 .776 .939 r
.13402 .4695 .14082 .47472 .15013 .47155 .14335 .46631 Metetra
.653 .776 .939 r
.14335 .46631 .15013 .47155 .15947 .46837 .15271 .46311 Metetra
.653 .776 .939 r
.15271 .46311 .15947 .46837 .16885 .46517 .16211 .45989 Metetra
.653 .776 .939 r
.16211 .45989 .16885 .46517 .17826 .46197 .17155 .45666 Metetra
.653 .776 .939 r
.17155 .45666 .17826 .46197 .18771 .45875 .18102 .45342 Metetra
.653 .776 .939 r
.18102 .45342 .18771 .45875 .1972 .45552 .19052 .45017 Metetra
.653 .776 .939 r
.19052 .45017 .1972 .45552 .20671 .45227 .20006 .4469 Metetra
.653 .776 .939 r
.20006 .4469 .20671 .45227 .21627 .44902 .20964 .44363 Metetra
.653 .776 .939 r
.20964 .44363 .21627 .44902 .22585 .44575 .21925 .44034 Metetra
.653 .776 .939 r
.21925 .44034 .22585 .44575 .23548 .44247 .2289 .43704 Metetra
.653 .776 .939 r
.2289 .43704 .23548 .44247 .24514 .43918 .23858 .43372 Metetra
.653 .776 .939 r
.23858 .43372 .24514 .43918 .25483 .43588 .2483 .4304 Metetra
.653 .776 .939 r
.2483 .4304 .25483 .43588 .26456 .43256 .25805 .42706 Metetra
.653 .776 .939 r
.25805 .42706 .26456 .43256 .27433 .42923 .26784 .42371 Metetra
.653 .776 .939 r
.26784 .42371 .27433 .42923 .28414 .42589 .27767 .42035 Metetra
.653 .776 .939 r
.27767 .42035 .28414 .42589 .29398 .42254 .28753 .41697 Metetra
.653 .776 .939 r
.28753 .41697 .29398 .42254 .30385 .41918 .29744 .41358 Metetra
.653 .776 .939 r
.29744 .41358 .30385 .41918 .31377 .4158 .30738 .41018 Metetra
.653 .776 .939 r
.30738 .41018 .31377 .4158 .32372 .41241 .31735 .40677 Metetra
.653 .776 .939 r
.31735 .40677 .32372 .41241 .33371 .409 .32737 .40334 Metetra
.653 .776 .939 r
.32737 .40334 .33371 .409 .34374 .40559 .33742 .3999 Metetra
.653 .776 .939 r
.33742 .3999 .34374 .40559 .3538 .40216 .34751 .39645 Metetra
.653 .776 .939 r
.34751 .39645 .3538 .40216 .36391 .39871 .35764 .39298 Metetra
.653 .776 .939 r
.35764 .39298 .36391 .39871 .37405 .39526 .36781 .3895 Metetra
.653 .776 .939 r
.36781 .3895 .37405 .39526 .38423 .39179 .37801 .38601 Metetra
.653 .776 .939 r
.37801 .38601 .38423 .39179 .39445 .38831 .38826 .38251 Metetra
.653 .776 .939 r
.38826 .38251 .39445 .38831 .40471 .38481 .39854 .37899 Metetra
.653 .776 .939 r
.39854 .37899 .40471 .38481 .415 .38131 .40887 .37545 Metetra
.653 .776 .939 r
.40887 .37545 .415 .38131 .42534 .37778 .41923 .37191 Metetra
.653 .776 .939 r
.41923 .37191 .42534 .37778 .43572 .37425 .42964 .36835 Metetra
.653 .776 .939 r
.42964 .36835 .43572 .37425 .44614 .3707 .44008 .36477 Metetra
.653 .776 .939 r
.44008 .36477 .44614 .3707 .45659 .36714 .45057 .36119 Metetra
.653 .776 .939 r
.45057 .36119 .45659 .36714 .46709 .36356 .46109 .35758 Metetra
.653 .776 .939 r
.46109 .35758 .46709 .36356 .47763 .35997 .47166 .35397 Metetra
.653 .776 .939 r
.47166 .35397 .47763 .35997 .48821 .35636 .48227 .35034 Metetra
.653 .776 .939 r
.48227 .35034 .48821 .35636 .49883 .35275 .49291 .34669 Metetra
.653 .776 .939 r
.49291 .34669 .49883 .35275 .50949 .34911 .5036 .34304 Metetra
.653 .776 .939 r
.5036 .34304 .50949 .34911 .52019 .34547 .51434 .33936 Metetra
.653 .776 .939 r
.51434 .33936 .52019 .34547 .53094 .34181 .52511 .33568 Metetra
.653 .776 .939 r
.52511 .33568 .53094 .34181 .54172 .33813 .53593 .33198 Metetra
.653 .776 .939 r
.53593 .33198 .54172 .33813 .55255 .33444 .54679 .32826 Metetra
.653 .776 .939 r
.54679 .32826 .55255 .33444 .56342 .33074 .55769 .32453 Metetra
.653 .776 .939 r
.55769 .32453 .56342 .33074 .57434 .32702 .56864 .32078 Metetra
.653 .776 .939 r
.56864 .32078 .57434 .32702 .5853 .32328 .57963 .31702 Metetra
.653 .776 .939 r
.57963 .31702 .5853 .32328 .5963 .31954 .59066 .31325 Metetra
.653 .776 .939 r
.59066 .31325 .5963 .31954 .60734 .31577 .60173 .30946 Metetra
.653 .776 .939 r
.60173 .30946 .60734 .31577 .61843 .312 .61286 .30565 Metetra
.653 .776 .939 r
.61286 .30565 .61843 .312 .62956 .3082 .62402 .30183 Metetra
.653 .776 .939 r
.62402 .30183 .62956 .3082 .64074 .30439 .63523 .298 Metetra
.653 .776 .939 r
.63523 .298 .64074 .30439 .65196 .30057 .64649 .29414 Metetra
.653 .776 .939 r
.64649 .29414 .65196 .30057 .66323 .29673 .65779 .29028 Metetra
.653 .776 .939 r
.65779 .29028 .66323 .29673 .67454 .29288 .66913 .28639 Metetra
.653 .776 .939 r
.66913 .28639 .67454 .29288 .6859 .28901 .68052 .2825 Metetra
.653 .776 .939 r
.68052 .2825 .6859 .28901 .6973 .28512 .69196 .27858 Metetra
.653 .776 .939 r
.69196 .27858 .6973 .28512 .70875 .28122 .70344 .27465 Metetra
.653 .776 .939 r
.70344 .27465 .70875 .28122 .72025 .2773 .71498 .27071 Metetra
.653 .776 .939 r
.71498 .27071 .72025 .2773 .73179 .27337 .72655 .26675 Metetra
.653 .776 .939 r
.72655 .26675 .73179 .27337 .74338 .26942 .73818 .26277 Metetra
.653 .776 .939 r
.73818 .26277 .74338 .26942 .75502 .26546 .74985 .25877 Metetra
.653 .776 .939 r
.74985 .25877 .75502 .26546 .7667 .26148 .76157 .25476 Metetra
.653 .776 .939 r
.76157 .25476 .7667 .26148 .77843 .25748 .77334 .25074 Metetra
.652 .783 .944 r
.10854 .47083 .11545 .47586 .12472 .47269 .11782 .46764 Metetra
.652 .783 .944 r
.11782 .46764 .12472 .47269 .13402 .4695 .12714 .46444 Metetra
.652 .783 .944 r
.12714 .46444 .13402 .4695 .14335 .46631 .1365 .46123 Metetra
.652 .783 .944 r
.1365 .46123 .14335 .46631 .15271 .46311 .14588 .458 Metetra
.652 .783 .944 r
.14588 .458 .15271 .46311 .16211 .45989 .15531 .45476 Metetra
.652 .783 .944 r
.15531 .45476 .16211 .45989 .17155 .45666 .16476 .45151 Metetra
.652 .783 .944 r
.16476 .45151 .17155 .45666 .18102 .45342 .17426 .44825 Metetra
.652 .783 .944 r
.17426 .44825 .18102 .45342 .19052 .45017 .18378 .44498 Metetra
.652 .783 .944 r
.18378 .44498 .19052 .45017 .20006 .4469 .19335 .44169 Metetra
.652 .783 .944 r
.19335 .44169 .20006 .4469 .20964 .44363 .20294 .43839 Metetra
.652 .783 .944 r
.20294 .43839 .20964 .44363 .21925 .44034 .21258 .43508 Metetra
.652 .783 .944 r
.21258 .43508 .21925 .44034 .2289 .43704 .22225 .43176 Metetra
.652 .783 .944 r
.22225 .43176 .2289 .43704 .23858 .43372 .23195 .42842 Metetra
.652 .783 .944 r
.23195 .42842 .23858 .43372 .2483 .4304 .24169 .42508 Metetra
.652 .783 .944 r
.24169 .42508 .2483 .4304 .25805 .42706 .25147 .42172 Metetra
.652 .783 .944 r
.25147 .42172 .25805 .42706 .26784 .42371 .26129 .41834 Metetra
.652 .783 .944 r
.26129 .41834 .26784 .42371 .27767 .42035 .27114 .41496 Metetra
.652 .783 .944 r
.27114 .41496 .27767 .42035 .28753 .41697 .28103 .41156 Metetra
.652 .783 .944 r
.28103 .41156 .28753 .41697 .29744 .41358 .29096 .40815 Metetra
.652 .783 .944 r
.29096 .40815 .29744 .41358 .30738 .41018 .30092 .40472 Metetra
.652 .783 .944 r
.30092 .40472 .30738 .41018 .31735 .40677 .31092 .40129 Metetra
.652 .783 .944 r
.31092 .40129 .31735 .40677 .32737 .40334 .32096 .39784 Metetra
.652 .783 .944 r
.32096 .39784 .32737 .40334 .33742 .3999 .33104 .39437 Metetra
.652 .783 .944 r
.33104 .39437 .33742 .3999 .34751 .39645 .34116 .3909 Metetra
.652 .783 .944 r
.34116 .3909 .34751 .39645 .35764 .39298 .35131 .38741 Metetra
.652 .783 .944 r
.35131 .38741 .35764 .39298 .36781 .3895 .36151 .3839 Metetra
.652 .783 .944 r
.36151 .3839 .36781 .3895 .37801 .38601 .37174 .38039 Metetra
.652 .783 .944 r
.37174 .38039 .37801 .38601 .38826 .38251 .38201 .37686 Metetra
.652 .783 .944 r
.38201 .37686 .38826 .38251 .39854 .37899 .39233 .37331 Metetra
.652 .783 .944 r
.39233 .37331 .39854 .37899 .40887 .37545 .40268 .36976 Metetra
.652 .783 .944 r
.40268 .36976 .40887 .37545 .41923 .37191 .41307 .36618 Metetra
.652 .783 .944 r
.41307 .36618 .41923 .37191 .42964 .36835 .4235 .3626 Metetra
.652 .783 .944 r
.4235 .3626 .42964 .36835 .44008 .36477 .43397 .359 Metetra
.652 .783 .944 r
.43397 .359 .44008 .36477 .45057 .36119 .44449 .35539 Metetra
.652 .783 .944 r
.44449 .35539 .45057 .36119 .46109 .35758 .45504 .35176 Metetra
.652 .783 .944 r
.45504 .35176 .46109 .35758 .47166 .35397 .46564 .34812 Metetra
.652 .783 .944 r
.46564 .34812 .47166 .35397 .48227 .35034 .47628 .34446 Metetra
.652 .783 .944 r
.47628 .34446 .48227 .35034 .49291 .34669 .48695 .34079 Metetra
.652 .783 .944 r
.48695 .34079 .49291 .34669 .5036 .34304 .49767 .33711 Metetra
.652 .783 .944 r
.49767 .33711 .5036 .34304 .51434 .33936 .50844 .33341 Metetra
.652 .783 .944 r
.50844 .33341 .51434 .33936 .52511 .33568 .51924 .3297 Metetra
.652 .783 .944 r
.51924 .3297 .52511 .33568 .53593 .33198 .53009 .32597 Metetra
.652 .783 .944 r
.53009 .32597 .53593 .33198 .54679 .32826 .54098 .32223 Metetra
.652 .783 .944 r
.54098 .32223 .54679 .32826 .55769 .32453 .55191 .31847 Metetra
.652 .783 .944 r
.55191 .31847 .55769 .32453 .56864 .32078 .56289 .3147 Metetra
.652 .783 .944 r
.56289 .3147 .56864 .32078 .57963 .31702 .57391 .31091 Metetra
.652 .783 .944 r
.57391 .31091 .57963 .31702 .59066 .31325 .58498 .30711 Metetra
.652 .783 .944 r
.58498 .30711 .59066 .31325 .60173 .30946 .59609 .30329 Metetra
.652 .783 .944 r
.59609 .30329 .60173 .30946 .61286 .30565 .60724 .29946 Metetra
.652 .783 .944 r
.60724 .29946 .61286 .30565 .62402 .30183 .61844 .29561 Metetra
.652 .783 .944 r
.61844 .29561 .62402 .30183 .63523 .298 .62968 .29175 Metetra
.652 .783 .944 r
.62968 .29175 .63523 .298 .64649 .29414 .64097 .28787 Metetra
.652 .783 .944 r
.64097 .28787 .64649 .29414 .65779 .29028 .65231 .28397 Metetra
.652 .783 .944 r
.65231 .28397 .65779 .29028 .66913 .28639 .66369 .28006 Metetra
.652 .783 .944 r
.66369 .28006 .66913 .28639 .68052 .2825 .67511 .27614 Metetra
.652 .783 .944 r
.67511 .27614 .68052 .2825 .69196 .27858 .68659 .27219 Metetra
.652 .783 .944 r
.68659 .27219 .69196 .27858 .70344 .27465 .6981 .26823 Metetra
.652 .783 .944 r
.6981 .26823 .70344 .27465 .71498 .27071 .70967 .26426 Metetra
.652 .783 .944 r
.70967 .26426 .71498 .27071 .72655 .26675 .72128 .26027 Metetra
.652 .783 .944 r
.72128 .26027 .72655 .26675 .73818 .26277 .73295 .25626 Metetra
.652 .783 .944 r
.73295 .25626 .73818 .26277 .74985 .25877 .74465 .25224 Metetra
.652 .783 .944 r
.74465 .25224 .74985 .25877 .76157 .25476 .75641 .2482 Metetra
.652 .783 .944 r
.75641 .2482 .76157 .25476 .77334 .25074 .76822 .24414 Metetra
.653 .769 .934 r
.10163 .46537 .10854 .47083 .11782 .46764 .11093 .46215 Metetra
.653 .769 .934 r
.11093 .46215 .11782 .46764 .12714 .46444 .12027 .45893 Metetra
.653 .769 .934 r
.12027 .45893 .12714 .46444 .1365 .46123 .12965 .45569 Metetra
.653 .769 .934 r
.12965 .45569 .1365 .46123 .14588 .458 .13905 .45245 Metetra
.653 .769 .934 r
.13905 .45245 .14588 .458 .15531 .45476 .1485 .44919 Metetra
.653 .769 .934 r
.1485 .44919 .15531 .45476 .16476 .45151 .15798 .44591 Metetra
.653 .769 .934 r
.15798 .44591 .16476 .45151 .17426 .44825 .16749 .44263 Metetra
.653 .769 .934 r
.16749 .44263 .17426 .44825 .18378 .44498 .17704 .43933 Metetra
.653 .769 .934 r
.17704 .43933 .18378 .44498 .19335 .44169 .18662 .43603 Metetra
.653 .769 .934 r
.18662 .43603 .19335 .44169 .20294 .43839 .19624 .43271 Metetra
.653 .769 .934 r
.19624 .43271 .20294 .43839 .21258 .43508 .2059 .42937 Metetra
.653 .769 .934 r
.2059 .42937 .21258 .43508 .22225 .43176 .21559 .42603 Metetra
.653 .769 .934 r
.21559 .42603 .22225 .43176 .23195 .42842 .22532 .42267 Metetra
.653 .769 .934 r
.22532 .42267 .23195 .42842 .24169 .42508 .23508 .4193 Metetra
.653 .769 .934 r
.23508 .4193 .24169 .42508 .25147 .42172 .24488 .41592 Metetra
.653 .769 .934 r
.24488 .41592 .25147 .42172 .26129 .41834 .25472 .41252 Metetra
.653 .769 .934 r
.25472 .41252 .26129 .41834 .27114 .41496 .2646 .40911 Metetra
.653 .769 .934 r
.2646 .40911 .27114 .41496 .28103 .41156 .27451 .40569 Metetra
.653 .769 .934 r
.27451 .40569 .28103 .41156 .29096 .40815 .28446 .40225 Metetra
.653 .769 .934 r
.28446 .40225 .29096 .40815 .30092 .40472 .29445 .39881 Metetra
.653 .769 .934 r
.29445 .39881 .30092 .40472 .31092 .40129 .30447 .39535 Metetra
.653 .769 .934 r
.30447 .39535 .31092 .40129 .32096 .39784 .31454 .39187 Metetra
.653 .769 .934 r
.31454 .39187 .32096 .39784 .33104 .39437 .32464 .38838 Metetra
.653 .769 .934 r
.32464 .38838 .33104 .39437 .34116 .3909 .33478 .38488 Metetra
.653 .769 .934 r
.33478 .38488 .34116 .3909 .35131 .38741 .34496 .38137 Metetra
.653 .769 .934 r
.34496 .38137 .35131 .38741 .36151 .3839 .35518 .37784 Metetra
.653 .769 .934 r
.35518 .37784 .36151 .3839 .37174 .38039 .36544 .3743 Metetra
.653 .769 .934 r
.36544 .3743 .37174 .38039 .38201 .37686 .37574 .37075 Metetra
.653 .769 .934 r
.37574 .37075 .38201 .37686 .39233 .37331 .38608 .36718 Metetra
.653 .769 .934 r
.38608 .36718 .39233 .37331 .40268 .36976 .39646 .36359 Metetra
.653 .769 .934 r
.39646 .36359 .40268 .36976 .41307 .36618 .40688 .36 Metetra
.653 .769 .934 r
.40688 .36 .41307 .36618 .4235 .3626 .41733 .35639 Metetra
.653 .769 .934 r
.41733 .35639 .4235 .3626 .43397 .359 .42783 .35276 Metetra
.653 .769 .934 r
.42783 .35276 .43397 .359 .44449 .35539 .43838 .34912 Metetra
.653 .769 .934 r
.43838 .34912 .44449 .35539 .45504 .35176 .44896 .34547 Metetra
.653 .769 .934 r
.44896 .34547 .45504 .35176 .46564 .34812 .45958 .34181 Metetra
.653 .769 .934 r
.45958 .34181 .46564 .34812 .47628 .34446 .47025 .33812 Metetra
.653 .769 .934 r
.47025 .33812 .47628 .34446 .48695 .34079 .48095 .33443 Metetra
.653 .769 .934 r
.48095 .33443 .48695 .34079 .49767 .33711 .4917 .33072 Metetra
.653 .769 .934 r
.4917 .33072 .49767 .33711 .50844 .33341 .50249 .32699 Metetra
.653 .769 .934 r
.50249 .32699 .50844 .33341 .51924 .3297 .51333 .32325 Metetra
.653 .769 .934 r
.51333 .32325 .51924 .3297 .53009 .32597 .52421 .3195 Metetra
.653 .769 .934 r
.52421 .3195 .53009 .32597 .54098 .32223 .53513 .31573 Metetra
.653 .769 .934 r
.53513 .31573 .54098 .32223 .55191 .31847 .54609 .31194 Metetra
.653 .769 .934 r
.54609 .31194 .55191 .31847 .56289 .3147 .5571 .30814 Metetra
.653 .769 .934 r
.5571 .30814 .56289 .3147 .57391 .31091 .56815 .30433 Metetra
.653 .769 .934 r
.56815 .30433 .57391 .31091 .58498 .30711 .57925 .3005 Metetra
.653 .769 .934 r
.57925 .3005 .58498 .30711 .59609 .30329 .59039 .29665 Metetra
.653 .769 .934 r
.59039 .29665 .59609 .30329 .60724 .29946 .60157 .29279 Metetra
.653 .769 .934 r
.60157 .29279 .60724 .29946 .61844 .29561 .6128 .28892 Metetra
.653 .769 .934 r
.6128 .28892 .61844 .29561 .62968 .29175 .62408 .28502 Metetra
.653 .769 .934 r
.62408 .28502 .62968 .29175 .64097 .28787 .6354 .28112 Metetra
.653 .769 .934 r
.6354 .28112 .64097 .28787 .65231 .28397 .64677 .27719 Metetra
.653 .769 .934 r
.64677 .27719 .65231 .28397 .66369 .28006 .65818 .27325 Metetra
.653 .769 .934 r
.65818 .27325 .66369 .28006 .67511 .27614 .66964 .2693 Metetra
.653 .769 .934 r
.66964 .2693 .67511 .27614 .68659 .27219 .68114 .26532 Metetra
.653 .769 .934 r
.68114 .26532 .68659 .27219 .6981 .26823 .6927 .26134 Metetra
.653 .769 .934 r
.6927 .26134 .6981 .26823 .70967 .26426 .7043 .25733 Metetra
.653 .769 .934 r
.7043 .25733 .70967 .26426 .72128 .26027 .71595 .25331 Metetra
.653 .769 .934 r
.71595 .25331 .72128 .26027 .73295 .25626 .72764 .24927 Metetra
.653 .769 .934 r
.72764 .24927 .73295 .25626 .74465 .25224 .73939 .24522 Metetra
.653 .769 .934 r
.73939 .24522 .74465 .25224 .75641 .2482 .75118 .24115 Metetra
.653 .769 .934 r
.75118 .24115 .75641 .2482 .76822 .24414 .76302 .23706 Metetra
.653 .773 .937 r
.09465 .45999 .10163 .46537 .11093 .46215 .10398 .45675 Metetra
.653 .773 .937 r
.10398 .45675 .11093 .46215 .12027 .45893 .11334 .45351 Metetra
.653 .773 .937 r
.11334 .45351 .12027 .45893 .12965 .45569 .12273 .45025 Metetra
.653 .773 .937 r
.12273 .45025 .12965 .45569 .13905 .45245 .13216 .44698 Metetra
.653 .773 .937 r
.13216 .44698 .13905 .45245 .1485 .44919 .14162 .4437 Metetra
.653 .773 .937 r
.14162 .4437 .1485 .44919 .15798 .44591 .15112 .44041 Metetra
.653 .773 .937 r
.15112 .44041 .15798 .44591 .16749 .44263 .16066 .4371 Metetra
.653 .773 .937 r
.16066 .4371 .16749 .44263 .17704 .43933 .17023 .43378 Metetra
.653 .773 .937 r
.17023 .43378 .17704 .43933 .18662 .43603 .17983 .43045 Metetra
.653 .773 .937 r
.17983 .43045 .18662 .43603 .19624 .43271 .18948 .42711 Metetra
.653 .773 .937 r
.18948 .42711 .19624 .43271 .2059 .42937 .19915 .42375 Metetra
.653 .773 .937 r
.19915 .42375 .2059 .42937 .21559 .42603 .20887 .42039 Metetra
.653 .773 .937 r
.20887 .42039 .21559 .42603 .22532 .42267 .21862 .41701 Metetra
.653 .773 .937 r
.21862 .41701 .22532 .42267 .23508 .4193 .22841 .41361 Metetra
.653 .773 .937 r
.22841 .41361 .23508 .4193 .24488 .41592 .23823 .41021 Metetra
.653 .773 .937 r
.23823 .41021 .24488 .41592 .25472 .41252 .24809 .40679 Metetra
.653 .773 .937 r
.24809 .40679 .25472 .41252 .2646 .40911 .25799 .40335 Metetra
.653 .773 .937 r
.25799 .40335 .2646 .40911 .27451 .40569 .26793 .39991 Metetra
.653 .773 .937 r
.26793 .39991 .27451 .40569 .28446 .40225 .2779 .39645 Metetra
.653 .773 .937 r
.2779 .39645 .28446 .40225 .29445 .39881 .28792 .39298 Metetra
.653 .773 .937 r
.28792 .39298 .29445 .39881 .30447 .39535 .29797 .38949 Metetra
.653 .773 .937 r
.29797 .38949 .30447 .39535 .31454 .39187 .30806 .386 Metetra
.653 .773 .937 r
.30806 .386 .31454 .39187 .32464 .38838 .31819 .38248 Metetra
.653 .773 .937 r
.31819 .38248 .32464 .38838 .33478 .38488 .32835 .37896 Metetra
.653 .773 .937 r
.32835 .37896 .33478 .38488 .34496 .38137 .33856 .37542 Metetra
.653 .773 .937 r
.33856 .37542 .34496 .38137 .35518 .37784 .3488 .37187 Metetra
.653 .773 .937 r
.3488 .37187 .35518 .37784 .36544 .3743 .35909 .3683 Metetra
.653 .773 .937 r
.35909 .3683 .36544 .3743 .37574 .37075 .36941 .36472 Metetra
.653 .773 .937 r
.36941 .36472 .37574 .37075 .38608 .36718 .37978 .36113 Metetra
.653 .773 .937 r
.37978 .36113 .38608 .36718 .39646 .36359 .39018 .35752 Metetra
.653 .773 .937 r
.39018 .35752 .39646 .36359 .40688 .36 .40063 .3539 Metetra
.653 .773 .937 r
.40063 .3539 .40688 .36 .41733 .35639 .41112 .35026 Metetra
.653 .773 .937 r
.41112 .35026 .41733 .35639 .42783 .35276 .42164 .34661 Metetra
.653 .773 .937 r
.42164 .34661 .42783 .35276 .43838 .34912 .43221 .34295 Metetra
.653 .773 .937 r
.43221 .34295 .43838 .34912 .44896 .34547 .44282 .33927 Metetra
.653 .773 .937 r
.44282 .33927 .44896 .34547 .45958 .34181 .45347 .33558 Metetra
.653 .773 .937 r
.45347 .33558 .45958 .34181 .47025 .33812 .46417 .33187 Metetra
.653 .773 .937 r
.46417 .33187 .47025 .33812 .48095 .33443 .4749 .32815 Metetra
.653 .773 .937 r
.4749 .32815 .48095 .33443 .4917 .33072 .48568 .32441 Metetra
.653 .773 .937 r
.48568 .32441 .4917 .33072 .50249 .32699 .4965 .32066 Metetra
.653 .773 .937 r
.4965 .32066 .50249 .32699 .51333 .32325 .50737 .31689 Metetra
.653 .773 .937 r
.50737 .31689 .51333 .32325 .52421 .3195 .51828 .31311 Metetra
.653 .773 .937 r
.51828 .31311 .52421 .3195 .53513 .31573 .52923 .30931 Metetra
.653 .773 .937 r
.52923 .30931 .53513 .31573 .54609 .31194 .54022 .3055 Metetra
.653 .773 .937 r
.54022 .3055 .54609 .31194 .5571 .30814 .55126 .30167 Metetra
.653 .773 .937 r
.55126 .30167 .5571 .30814 .56815 .30433 .56234 .29783 Metetra
.653 .773 .937 r
.56234 .29783 .56815 .30433 .57925 .3005 .57347 .29397 Metetra
.653 .773 .937 r
.57347 .29397 .57925 .3005 .59039 .29665 .58464 .2901 Metetra
.653 .773 .937 r
.58464 .2901 .59039 .29665 .60157 .29279 .59586 .28621 Metetra
.653 .773 .937 r
.59586 .28621 .60157 .29279 .6128 .28892 .60712 .2823 Metetra
.653 .773 .937 r
.60712 .2823 .6128 .28892 .62408 .28502 .61843 .27838 Metetra
.653 .773 .937 r
.61843 .27838 .62408 .28502 .6354 .28112 .62979 .27445 Metetra
.653 .773 .937 r
.62979 .27445 .6354 .28112 .64677 .27719 .64119 .27049 Metetra
.653 .773 .937 r
.64119 .27049 .64677 .27719 .65818 .27325 .65263 .26652 Metetra
.653 .773 .937 r
.65263 .26652 .65818 .27325 .66964 .2693 .66413 .26254 Metetra
.653 .773 .937 r
.66413 .26254 .66964 .2693 .68114 .26532 .67567 .25854 Metetra
.653 .773 .937 r
.67567 .25854 .68114 .26532 .6927 .26134 .68726 .25452 Metetra
.653 .773 .937 r
.68726 .25452 .6927 .26134 .7043 .25733 .69889 .25048 Metetra
.653 .773 .937 r
.69889 .25048 .7043 .25733 .71595 .25331 .71058 .24643 Metetra
.653 .773 .937 r
.71058 .24643 .71595 .25331 .72764 .24927 .72231 .24237 Metetra
.653 .773 .937 r
.72231 .24237 .72764 .24927 .73939 .24522 .73409 .23828 Metetra
.653 .773 .937 r
.73409 .23828 .73939 .24522 .75118 .24115 .74592 .23418 Metetra
.653 .773 .937 r
.74592 .23418 .75118 .24115 .76302 .23706 .7578 .23006 Metetra
.654 .764 .93 r
.08766 .45431 .09465 .45999 .10398 .45675 .097 .45105 Metetra
.654 .764 .93 r
.097 .45105 .10398 .45675 .11334 .45351 .10638 .44778 Metetra
.654 .764 .93 r
.10638 .44778 .11334 .45351 .12273 .45025 .1158 .4445 Metetra
.654 .764 .93 r
.1158 .4445 .12273 .45025 .13216 .44698 .12525 .44121 Metetra
.654 .764 .93 r
.12525 .44121 .13216 .44698 .14162 .4437 .13473 .43791 Metetra
.654 .764 .93 r
.13473 .43791 .14162 .4437 .15112 .44041 .14425 .43459 Metetra
.654 .764 .93 r
.14425 .43459 .15112 .44041 .16066 .4371 .15381 .43127 Metetra
.654 .764 .93 r
.15381 .43127 .16066 .4371 .17023 .43378 .1634 .42792 Metetra
.654 .764 .93 r
.1634 .42792 .17023 .43378 .17983 .43045 .17303 .42457 Metetra
.654 .764 .93 r
.17303 .42457 .17983 .43045 .18948 .42711 .18269 .4212 Metetra
.654 .764 .93 r
.18269 .4212 .18948 .42711 .19915 .42375 .19239 .41783 Metetra
.654 .764 .93 r
.19239 .41783 .19915 .42375 .20887 .42039 .20213 .41443 Metetra
.654 .764 .93 r
.20213 .41443 .20887 .42039 .21862 .41701 .2119 .41103 Metetra
.654 .764 .93 r
.2119 .41103 .21862 .41701 .22841 .41361 .22171 .40761 Metetra
.654 .764 .93 r
.22171 .40761 .22841 .41361 .23823 .41021 .23156 .40418 Metetra
.654 .764 .93 r
.23156 .40418 .23823 .41021 .24809 .40679 .24144 .40074 Metetra
.654 .764 .93 r
.24144 .40074 .24809 .40679 .25799 .40335 .25136 .39728 Metetra
.654 .764 .93 r
.25136 .39728 .25799 .40335 .26793 .39991 .26132 .39382 Metetra
.654 .764 .93 r
.26132 .39382 .26793 .39991 .2779 .39645 .27132 .39033 Metetra
.654 .764 .93 r
.27132 .39033 .2779 .39645 .28792 .39298 .28136 .38684 Metetra
.654 .764 .93 r
.28136 .38684 .28792 .39298 .29797 .38949 .29143 .38333 Metetra
.654 .764 .93 r
.29143 .38333 .29797 .38949 .30806 .386 .30155 .3798 Metetra
.654 .764 .93 r
.30155 .3798 .30806 .386 .31819 .38248 .3117 .37627 Metetra
.654 .764 .93 r
.3117 .37627 .31819 .38248 .32835 .37896 .32189 .37272 Metetra
.654 .764 .93 r
.32189 .37272 .32835 .37896 .33856 .37542 .33212 .36915 Metetra
.654 .764 .93 r
.33212 .36915 .33856 .37542 .3488 .37187 .34239 .36558 Metetra
.654 .764 .93 r
.34239 .36558 .3488 .37187 .35909 .3683 .3527 .36199 Metetra
.654 .764 .93 r
.3527 .36199 .35909 .3683 .36941 .36472 .36305 .35838 Metetra
.654 .764 .93 r
.36305 .35838 .36941 .36472 .37978 .36113 .37344 .35476 Metetra
.654 .764 .93 r
.37344 .35476 .37978 .36113 .39018 .35752 .38388 .35113 Metetra
.654 .764 .93 r
.38388 .35113 .39018 .35752 .40063 .3539 .39435 .34748 Metetra
.654 .764 .93 r
.39435 .34748 .40063 .3539 .41112 .35026 .40486 .34382 Metetra
.654 .764 .93 r
.40486 .34382 .41112 .35026 .42164 .34661 .41542 .34014 Metetra
.654 .764 .93 r
.41542 .34014 .42164 .34661 .43221 .34295 .42601 .33645 Metetra
.654 .764 .93 r
.42601 .33645 .43221 .34295 .44282 .33927 .43665 .33275 Metetra
.654 .764 .93 r
.43665 .33275 .44282 .33927 .45347 .33558 .44733 .32903 Metetra
.654 .764 .93 r
.44733 .32903 .45347 .33558 .46417 .33187 .45805 .32529 Metetra
.654 .764 .93 r
.45805 .32529 .46417 .33187 .4749 .32815 .46881 .32154 Metetra
.654 .764 .93 r
.46881 .32154 .4749 .32815 .48568 .32441 .47962 .31778 Metetra
.654 .764 .93 r
.47962 .31778 .48568 .32441 .4965 .32066 .49047 .314 Metetra
.654 .764 .93 r
.49047 .314 .4965 .32066 .50737 .31689 .50136 .3102 Metetra
.654 .764 .93 r
.50136 .3102 .50737 .31689 .51828 .31311 .5123 .30639 Metetra
.654 .764 .93 r
.5123 .30639 .51828 .31311 .52923 .30931 .52328 .30257 Metetra
.654 .764 .93 r
.52328 .30257 .52923 .30931 .54022 .3055 .53431 .29873 Metetra
.654 .764 .93 r
.53431 .29873 .54022 .3055 .55126 .30167 .54538 .29487 Metetra
.654 .764 .93 r
.54538 .29487 .55126 .30167 .56234 .29783 .55649 .291 Metetra
.654 .764 .93 r
.55649 .291 .56234 .29783 .57347 .29397 .56765 .28712 Metetra
.654 .764 .93 r
.56765 .28712 .57347 .29397 .58464 .2901 .57885 .28321 Metetra
.654 .764 .93 r
.57885 .28321 .58464 .2901 .59586 .28621 .5901 .2793 Metetra
.654 .764 .93 r
.5901 .2793 .59586 .28621 .60712 .2823 .60139 .27536 Metetra
.654 .764 .93 r
.60139 .27536 .60712 .2823 .61843 .27838 .61273 .27141 Metetra
.654 .764 .93 r
.61273 .27141 .61843 .27838 .62979 .27445 .62412 .26745 Metetra
.654 .764 .93 r
.62412 .26745 .62979 .27445 .64119 .27049 .63555 .26346 Metetra
.654 .764 .93 r
.63555 .26346 .64119 .27049 .65263 .26652 .64703 .25946 Metetra
.654 .764 .93 r
.64703 .25946 .65263 .26652 .66413 .26254 .65856 .25545 Metetra
.654 .764 .93 r
.65856 .25545 .66413 .26254 .67567 .25854 .67013 .25142 Metetra
.654 .764 .93 r
.67013 .25142 .67567 .25854 .68726 .25452 .68176 .24737 Metetra
.654 .764 .93 r
.68176 .24737 .68726 .25452 .69889 .25048 .69343 .2433 Metetra
.654 .764 .93 r
.69343 .2433 .69889 .25048 .71058 .24643 .70514 .23922 Metetra
.654 .764 .93 r
.70514 .23922 .71058 .24643 .72231 .24237 .71691 .23512 Metetra
.654 .764 .93 r
.71691 .23512 .72231 .24237 .73409 .23828 .72873 .23101 Metetra
.654 .764 .93 r
.72873 .23101 .73409 .23828 .74592 .23418 .74059 .22688 Metetra
.654 .764 .93 r
.74059 .22688 .74592 .23418 .7578 .23006 .75251 .22273 Metetra
.654 .767 .933 r
.08061 .44867 .08766 .45431 .097 .45105 .08997 .4454 Metetra
.654 .767 .933 r
.08997 .4454 .097 .45105 .10638 .44778 .09937 .44211 Metetra
.654 .767 .933 r
.09937 .44211 .10638 .44778 .1158 .4445 .10881 .4388 Metetra
.654 .767 .933 r
.10881 .4388 .1158 .4445 .12525 .44121 .11828 .43549 Metetra
.654 .767 .933 r
.11828 .43549 .12525 .44121 .13473 .43791 .12778 .43216 Metetra
.654 .767 .933 r
.12778 .43216 .13473 .43791 .14425 .43459 .13732 .42883 Metetra
.654 .767 .933 r
.13732 .42883 .14425 .43459 .15381 .43127 .1469 .42547 Metetra
.654 .767 .933 r
.1469 .42547 .15381 .43127 .1634 .42792 .15651 .42211 Metetra
.654 .767 .933 r
.15651 .42211 .1634 .42792 .17303 .42457 .16616 .41873 Metetra
.654 .767 .933 r
.16616 .41873 .17303 .42457 .18269 .4212 .17585 .41535 Metetra
.654 .767 .933 r
.17585 .41535 .18269 .4212 .19239 .41783 .18557 .41194 Metetra
.654 .767 .933 r
.18557 .41194 .19239 .41783 .20213 .41443 .19533 .40853 Metetra
.654 .767 .933 r
.19533 .40853 .20213 .41443 .2119 .41103 .20512 .4051 Metetra
.654 .767 .933 r
.20512 .4051 .2119 .41103 .22171 .40761 .21496 .40166 Metetra
.654 .767 .933 r
.21496 .40166 .22171 .40761 .23156 .40418 .22483 .39821 Metetra
.654 .767 .933 r
.22483 .39821 .23156 .40418 .24144 .40074 .23473 .39474 Metetra
.654 .767 .933 r
.23473 .39474 .24144 .40074 .25136 .39728 .24468 .39126 Metetra
.654 .767 .933 r
.24468 .39126 .25136 .39728 .26132 .39382 .25466 .38777 Metetra
.654 .767 .933 r
.25466 .38777 .26132 .39382 .27132 .39033 .26469 .38426 Metetra
.654 .767 .933 r
.26469 .38426 .27132 .39033 .28136 .38684 .27475 .38074 Metetra
.654 .767 .933 r
.27475 .38074 .28136 .38684 .29143 .38333 .28485 .3772 Metetra
.654 .767 .933 r
.28485 .3772 .29143 .38333 .30155 .3798 .29498 .37366 Metetra
.654 .767 .933 r
.29498 .37366 .30155 .3798 .3117 .37627 .30516 .3701 Metetra
.654 .767 .933 r
.30516 .3701 .3117 .37627 .32189 .37272 .31538 .36652 Metetra
.654 .767 .933 r
.31538 .36652 .32189 .37272 .33212 .36915 .32563 .36293 Metetra
.654 .767 .933 r
.32563 .36293 .33212 .36915 .34239 .36558 .33593 .35933 Metetra
.654 .767 .933 r
.33593 .35933 .34239 .36558 .3527 .36199 .34627 .35571 Metetra
.654 .767 .933 r
.34627 .35571 .3527 .36199 .36305 .35838 .35664 .35208 Metetra
.654 .767 .933 r
.35664 .35208 .36305 .35838 .37344 .35476 .36706 .34844 Metetra
.654 .767 .933 r
.36706 .34844 .37344 .35476 .38388 .35113 .37752 .34478 Metetra
.654 .767 .933 r
.37752 .34478 .38388 .35113 .39435 .34748 .38802 .3411 Metetra
.654 .767 .933 r
.38802 .3411 .39435 .34748 .40486 .34382 .39856 .33741 Metetra
.654 .767 .933 r
.39856 .33741 .40486 .34382 .41542 .34014 .40914 .33371 Metetra
.654 .767 .933 r
.40914 .33371 .41542 .34014 .42601 .33645 .41976 .32999 Metetra
.654 .767 .933 r
.41976 .32999 .42601 .33645 .43665 .33275 .43043 .32626 Metetra
.654 .767 .933 r
.43043 .32626 .43665 .33275 .44733 .32903 .44113 .32252 Metetra
.654 .767 .933 r
.44113 .32252 .44733 .32903 .45805 .32529 .45188 .31875 Metetra
.654 .767 .933 r
.45188 .31875 .45805 .32529 .46881 .32154 .46268 .31498 Metetra
.654 .767 .933 r
.46268 .31498 .46881 .32154 .47962 .31778 .47351 .31119 Metetra
.654 .767 .933 r
.47351 .31119 .47962 .31778 .49047 .314 .48439 .30738 Metetra
.654 .767 .933 r
.48439 .30738 .49047 .314 .50136 .3102 .49531 .30356 Metetra
.654 .767 .933 r
.49531 .30356 .50136 .3102 .5123 .30639 .50628 .29972 Metetra
.654 .767 .933 r
.50628 .29972 .5123 .30639 .52328 .30257 .51729 .29587 Metetra
.654 .767 .933 r
.51729 .29587 .52328 .30257 .53431 .29873 .52835 .292 Metetra
.654 .767 .933 r
.52835 .292 .53431 .29873 .54538 .29487 .53945 .28811 Metetra
.654 .767 .933 r
.53945 .28811 .54538 .29487 .55649 .291 .55059 .28421 Metetra
.654 .767 .933 r
.55059 .28421 .55649 .291 .56765 .28712 .56178 .2803 Metetra
.654 .767 .933 r
.56178 .2803 .56765 .28712 .57885 .28321 .57301 .27637 Metetra
.654 .767 .933 r
.57301 .27637 .57885 .28321 .5901 .2793 .5843 .27242 Metetra
.654 .767 .933 r
.5843 .27242 .5901 .2793 .60139 .27536 .59562 .26846 Metetra
.654 .767 .933 r
.59562 .26846 .60139 .27536 .61273 .27141 .60699 .26448 Metetra
.654 .767 .933 r
.60699 .26448 .61273 .27141 .62412 .26745 .61841 .26048 Metetra
.654 .767 .933 r
.61841 .26048 .62412 .26745 .63555 .26346 .62988 .25647 Metetra
.654 .767 .933 r
.62988 .25647 .63555 .26346 .64703 .25946 .64139 .25244 Metetra
.654 .767 .933 r
.64139 .25244 .64703 .25946 .65856 .25545 .65295 .2484 Metetra
.654 .767 .933 r
.65295 .2484 .65856 .25545 .67013 .25142 .66456 .24433 Metetra
.654 .767 .933 r
.66456 .24433 .67013 .25142 .68176 .24737 .67622 .24025 Metetra
.654 .767 .933 r
.67622 .24025 .68176 .24737 .69343 .2433 .68792 .23616 Metetra
.654 .767 .933 r
.68792 .23616 .69343 .2433 .70514 .23922 .69968 .23205 Metetra
.654 .767 .933 r
.69968 .23205 .70514 .23922 .71691 .23512 .71148 .22792 Metetra
.654 .767 .933 r
.71148 .22792 .71691 .23512 .72873 .23101 .72333 .22377 Metetra
.654 .767 .933 r
.72333 .22377 .72873 .23101 .74059 .22688 .73523 .21961 Metetra
.654 .767 .933 r
.73523 .21961 .74059 .22688 .75251 .22273 .74718 .21542 Metetra
.654 .761 .928 r
.07353 .44282 .08061 .44867 .08997 .4454 .08291 .43952 Metetra
.654 .761 .928 r
.08291 .43952 .08997 .4454 .09937 .44211 .09233 .43621 Metetra
.654 .761 .928 r
.09233 .43621 .09937 .44211 .10881 .4388 .10179 .43288 Metetra
.654 .761 .928 r
.10179 .43288 .10881 .4388 .11828 .43549 .11128 .42955 Metetra
.654 .761 .928 r
.11128 .42955 .11828 .43549 .12778 .43216 .1208 .4262 Metetra
.654 .761 .928 r
.1208 .4262 .12778 .43216 .13732 .42883 .13037 .42284 Metetra
.654 .761 .928 r
.13037 .42284 .13732 .42883 .1469 .42547 .13996 .41946 Metetra
.654 .761 .928 r
.13996 .41946 .1469 .42547 .15651 .42211 .1496 .41607 Metetra
.654 .761 .928 r
.1496 .41607 .15651 .42211 .16616 .41873 .15927 .41267 Metetra
.654 .761 .928 r
.15927 .41267 .16616 .41873 .17585 .41535 .16897 .40926 Metetra
.654 .761 .928 r
.16897 .40926 .17585 .41535 .18557 .41194 .17872 .40584 Metetra
.654 .761 .928 r
.17872 .40584 .18557 .41194 .19533 .40853 .1885 .4024 Metetra
.654 .761 .928 r
.1885 .4024 .19533 .40853 .20512 .4051 .19832 .39895 Metetra
.654 .761 .928 r
.19832 .39895 .20512 .4051 .21496 .40166 .20817 .39548 Metetra
.654 .761 .928 r
.20817 .39548 .21496 .40166 .22483 .39821 .21806 .392 Metetra
.654 .761 .928 r
.21806 .392 .22483 .39821 .23473 .39474 .22799 .38851 Metetra
.654 .761 .928 r
.22799 .38851 .23473 .39474 .24468 .39126 .23796 .38501 Metetra
.654 .761 .928 r
.23796 .38501 .24468 .39126 .25466 .38777 .24797 .38149 Metetra
.654 .761 .928 r
.24797 .38149 .25466 .38777 .26469 .38426 .25802 .37796 Metetra
.654 .761 .928 r
.25802 .37796 .26469 .38426 .27475 .38074 .2681 .37441 Metetra
.654 .761 .928 r
.2681 .37441 .27475 .38074 .28485 .3772 .27822 .37085 Metetra
.654 .761 .928 r
.27822 .37085 .28485 .3772 .29498 .37366 .28838 .36728 Metetra
.654 .761 .928 r
.28838 .36728 .29498 .37366 .30516 .3701 .29859 .36369 Metetra
.654 .761 .928 r
.29859 .36369 .30516 .3701 .31538 .36652 .30883 .36009 Metetra
.654 .761 .928 r
.30883 .36009 .31538 .36652 .32563 .36293 .31911 .35648 Metetra
.654 .761 .928 r
.31911 .35648 .32563 .36293 .33593 .35933 .32943 .35285 Metetra
.654 .761 .928 r
.32943 .35285 .33593 .35933 .34627 .35571 .33979 .34921 Metetra
.654 .761 .928 r
.33979 .34921 .34627 .35571 .35664 .35208 .35019 .34555 Metetra
.654 .761 .928 r
.35019 .34555 .35664 .35208 .36706 .34844 .36064 .34188 Metetra
.654 .761 .928 r
.36064 .34188 .36706 .34844 .37752 .34478 .37112 .33819 Metetra
.654 .761 .928 r
.37112 .33819 .37752 .34478 .38802 .3411 .38164 .33449 Metetra
.654 .761 .928 r
.38164 .33449 .38802 .3411 .39856 .33741 .39221 .33078 Metetra
.654 .761 .928 r
.39221 .33078 .39856 .33741 .40914 .33371 .40282 .32705 Metetra
.654 .761 .928 r
.40282 .32705 .40914 .33371 .41976 .32999 .41347 .3233 Metetra
.654 .761 .928 r
.41347 .3233 .41976 .32999 .43043 .32626 .42416 .31955 Metetra
.654 .761 .928 r
.42416 .31955 .43043 .32626 .44113 .32252 .4349 .31577 Metetra
.654 .761 .928 r
.4349 .31577 .44113 .32252 .45188 .31875 .44568 .31198 Metetra
.654 .761 .928 r
.44568 .31198 .45188 .31875 .46268 .31498 .4565 .30818 Metetra
.654 .761 .928 r
.4565 .30818 .46268 .31498 .47351 .31119 .46736 .30436 Metetra
.654 .761 .928 r
.46736 .30436 .47351 .31119 .48439 .30738 .47827 .30052 Metetra
.654 .761 .928 r
.47827 .30052 .48439 .30738 .49531 .30356 .48922 .29667 Metetra
.654 .761 .928 r
.48922 .29667 .49531 .30356 .50628 .29972 .50022 .29281 Metetra
.654 .761 .928 r
.50022 .29281 .50628 .29972 .51729 .29587 .51126 .28893 Metetra
.654 .761 .928 r
.51126 .28893 .51729 .29587 .52835 .292 .52234 .28503 Metetra
.654 .761 .928 r
.52234 .28503 .52835 .292 .53945 .28811 .53347 .28112 Metetra
.654 .761 .928 r
.53347 .28112 .53945 .28811 .55059 .28421 .54464 .27719 Metetra
.654 .761 .928 r
.54464 .27719 .55059 .28421 .56178 .2803 .55586 .27324 Metetra
.654 .761 .928 r
.55586 .27324 .56178 .2803 .57301 .27637 .56713 .26928 Metetra
.654 .761 .928 r
.56713 .26928 .57301 .27637 .5843 .27242 .57844 .2653 Metetra
.654 .761 .928 r
.57844 .2653 .5843 .27242 .59562 .26846 .5898 .26131 Metetra
.654 .761 .928 r
.5898 .26131 .59562 .26846 .60699 .26448 .60121 .2573 Metetra
.654 .761 .928 r
.60121 .2573 .60699 .26448 .61841 .26048 .61266 .25328 Metetra
.654 .761 .928 r
.61266 .25328 .61841 .26048 .62988 .25647 .62416 .24923 Metetra
.654 .761 .928 r
.62416 .24923 .62988 .25647 .64139 .25244 .6357 .24517 Metetra
.654 .761 .928 r
.6357 .24517 .64139 .25244 .65295 .2484 .6473 .2411 Metetra
.654 .761 .928 r
.6473 .2411 .65295 .2484 .66456 .24433 .65894 .237 Metetra
.654 .761 .928 r
.65894 .237 .66456 .24433 .67622 .24025 .67063 .23289 Metetra
.654 .761 .928 r
.67063 .23289 .67622 .24025 .68792 .23616 .68237 .22877 Metetra
.654 .761 .928 r
.68237 .22877 .68792 .23616 .69968 .23205 .69415 .22462 Metetra
.654 .761 .928 r
.69415 .22462 .69968 .23205 .71148 .22792 .70599 .22046 Metetra
.654 .761 .928 r
.70599 .22046 .71148 .22792 .72333 .22377 .71788 .21628 Metetra
.654 .761 .928 r
.71788 .21628 .72333 .22377 .73523 .21961 .72981 .21209 Metetra
.654 .761 .928 r
.72981 .21209 .73523 .21961 .74718 .21542 .7418 .20787 Metetra
.654 .763 .93 r
.06639 .43698 .07353 .44282 .08291 .43952 .0758 .43366 Metetra
.654 .763 .93 r
.0758 .43366 .08291 .43952 .09233 .43621 .08524 .43032 Metetra
.654 .763 .93 r
.08524 .43032 .09233 .43621 .10179 .43288 .09471 .42698 Metetra
.654 .763 .93 r
.09471 .42698 .10179 .43288 .11128 .42955 .10422 .42362 Metetra
.654 .763 .93 r
.10422 .42362 .11128 .42955 .1208 .4262 .11377 .42024 Metetra
.654 .763 .93 r
.11377 .42024 .1208 .4262 .13037 .42284 .12335 .41686 Metetra
.654 .763 .93 r
.12335 .41686 .13037 .42284 .13996 .41946 .13297 .41346 Metetra
.654 .763 .93 r
.13297 .41346 .13996 .41946 .1496 .41607 .14263 .41005 Metetra
.654 .763 .93 r
.14263 .41005 .1496 .41607 .15927 .41267 .15232 .40663 Metetra
.654 .763 .93 r
.15232 .40663 .15927 .41267 .16897 .40926 .16205 .40319 Metetra
.654 .763 .93 r
.16205 .40319 .16897 .40926 .17872 .40584 .17181 .39974 Metetra
.654 .763 .93 r
.17181 .39974 .17872 .40584 .1885 .4024 .18161 .39628 Metetra
.654 .763 .93 r
.18161 .39628 .1885 .4024 .19832 .39895 .19145 .3928 Metetra
.654 .763 .93 r
.19145 .3928 .19832 .39895 .20817 .39548 .20133 .38932 Metetra
.654 .763 .93 r
.20133 .38932 .20817 .39548 .21806 .392 .21125 .38581 Metetra
.654 .763 .93 r
.21125 .38581 .21806 .392 .22799 .38851 .2212 .3823 Metetra
.654 .763 .93 r
.2212 .3823 .22799 .38851 .23796 .38501 .23119 .37877 Metetra
.654 .763 .93 r
.23119 .37877 .23796 .38501 .24797 .38149 .24122 .37522 Metetra
.654 .763 .93 r
.24122 .37522 .24797 .38149 .25802 .37796 .25129 .37167 Metetra
.654 .763 .93 r
.25129 .37167 .25802 .37796 .2681 .37441 .2614 .3681 Metetra
.654 .763 .93 r
.2614 .3681 .2681 .37441 .27822 .37085 .27155 .36451 Metetra
.654 .763 .93 r
.27155 .36451 .27822 .37085 .28838 .36728 .28173 .36092 Metetra
.654 .763 .93 r
.28173 .36092 .28838 .36728 .29859 .36369 .29196 .3573 Metetra
.654 .763 .93 r
.29196 .3573 .29859 .36369 .30883 .36009 .30222 .35368 Metetra
.654 .763 .93 r
.30222 .35368 .30883 .36009 .31911 .35648 .31253 .35004 Metetra
.654 .763 .93 r
.31253 .35004 .31911 .35648 .32943 .35285 .32288 .34638 Metetra
.654 .763 .93 r
.32288 .34638 .32943 .35285 .33979 .34921 .33326 .34271 Metetra
.654 .763 .93 r
.33326 .34271 .33979 .34921 .35019 .34555 .34369 .33903 Metetra
.654 .763 .93 r
.34369 .33903 .35019 .34555 .36064 .34188 .35416 .33533 Metetra
.654 .763 .93 r
.35416 .33533 .36064 .34188 .37112 .33819 .36467 .33162 Metetra
.654 .763 .93 r
.36467 .33162 .37112 .33819 .38164 .33449 .37522 .32789 Metetra
.654 .763 .93 r
.37522 .32789 .38164 .33449 .39221 .33078 .38582 .32415 Metetra
.654 .763 .93 r
.38582 .32415 .39221 .33078 .40282 .32705 .39645 .32039 Metetra
.654 .763 .93 r
.39645 .32039 .40282 .32705 .41347 .3233 .40713 .31662 Metetra
.654 .763 .93 r
.40713 .31662 .41347 .3233 .42416 .31955 .41785 .31284 Metetra
.654 .763 .93 r
.41785 .31284 .42416 .31955 .4349 .31577 .42861 .30903 Metetra
.654 .763 .93 r
.42861 .30903 .4349 .31577 .44568 .31198 .43942 .30522 Metetra
.654 .763 .93 r
.43942 .30522 .44568 .31198 .4565 .30818 .45027 .30138 Metetra
.654 .763 .93 r
.45027 .30138 .4565 .30818 .46736 .30436 .46116 .29754 Metetra
.654 .763 .93 r
.46116 .29754 .46736 .30436 .47827 .30052 .4721 .29367 Metetra
.654 .763 .93 r
.4721 .29367 .47827 .30052 .48922 .29667 .48308 .28979 Metetra
.654 .763 .93 r
.48308 .28979 .48922 .29667 .50022 .29281 .4941 .2859 Metetra
.654 .763 .93 r
.4941 .2859 .50022 .29281 .51126 .28893 .50517 .28199 Metetra
.654 .763 .93 r
.50517 .28199 .51126 .28893 .52234 .28503 .51629 .27806 Metetra
.654 .763 .93 r
.51629 .27806 .52234 .28503 .53347 .28112 .52745 .27412 Metetra
.654 .763 .93 r
.52745 .27412 .53347 .28112 .54464 .27719 .53865 .27016 Metetra
.654 .763 .93 r
.53865 .27016 .54464 .27719 .55586 .27324 .5499 .26619 Metetra
.654 .763 .93 r
.5499 .26619 .55586 .27324 .56713 .26928 .5612 .2622 Metetra
.654 .763 .93 r
.5612 .2622 .56713 .26928 .57844 .2653 .57255 .25819 Metetra
.654 .763 .93 r
.57255 .25819 .57844 .2653 .5898 .26131 .58394 .25417 Metetra
.654 .763 .93 r
.58394 .25417 .5898 .26131 .60121 .2573 .59537 .25013 Metetra
.654 .763 .93 r
.59537 .25013 .60121 .2573 .61266 .25328 .60686 .24607 Metetra
.654 .763 .93 r
.60686 .24607 .61266 .25328 .62416 .24923 .61839 .242 Metetra
.654 .763 .93 r
.61839 .242 .62416 .24923 .6357 .24517 .62997 .23791 Metetra
.654 .763 .93 r
.62997 .23791 .6357 .24517 .6473 .2411 .64159 .2338 Metetra
.654 .763 .93 r
.64159 .2338 .6473 .2411 .65894 .237 .65327 .22968 Metetra
.654 .763 .93 r
.65327 .22968 .65894 .237 .67063 .23289 .66499 .22554 Metetra
.654 .763 .93 r
.66499 .22554 .67063 .23289 .68237 .22877 .67677 .22138 Metetra
.654 .763 .93 r
.67677 .22138 .68237 .22877 .69415 .22462 .68859 .2172 Metetra
.654 .763 .93 r
.68859 .2172 .69415 .22462 .70599 .22046 .70046 .21301 Metetra
.654 .763 .93 r
.70046 .21301 .70599 .22046 .71788 .21628 .71238 .2088 Metetra
.654 .763 .93 r
.71238 .2088 .71788 .21628 .72981 .21209 .72436 .20457 Metetra
.654 .763 .93 r
.72436 .20457 .72981 .21209 .7418 .20787 .73638 .20032 Metetra
.654 .758 .927 r
.05923 .43097 .06639 .43698 .0758 .43366 .06865 .42763 Metetra
.654 .758 .927 r
.06865 .42763 .0758 .43366 .08524 .43032 .07811 .42427 Metetra
.654 .758 .927 r
.07811 .42427 .08524 .43032 .09471 .42698 .0876 .4209 Metetra
.654 .758 .927 r
.0876 .4209 .09471 .42698 .10422 .42362 .09714 .41752 Metetra
.654 .758 .927 r
.09714 .41752 .10422 .42362 .11377 .42024 .1067 .41412 Metetra
.654 .758 .927 r
.1067 .41412 .11377 .42024 .12335 .41686 .11631 .41072 Metetra
.654 .758 .927 r
.11631 .41072 .12335 .41686 .13297 .41346 .12594 .40729 Metetra
.654 .758 .927 r
.12594 .40729 .13297 .41346 .14263 .41005 .13562 .40386 Metetra
.654 .758 .927 r
.13562 .40386 .14263 .41005 .15232 .40663 .14533 .40041 Metetra
.654 .758 .927 r
.14533 .40041 .15232 .40663 .16205 .40319 .15508 .39695 Metetra
.654 .758 .927 r
.15508 .39695 .16205 .40319 .17181 .39974 .16487 .39348 Metetra
.654 .758 .927 r
.16487 .39348 .17181 .39974 .18161 .39628 .17469 .38999 Metetra
.654 .758 .927 r
.17469 .38999 .18161 .39628 .19145 .3928 .18456 .38649 Metetra
.654 .758 .927 r
.18456 .38649 .19145 .3928 .20133 .38932 .19446 .38298 Metetra
.654 .758 .927 r
.19446 .38298 .20133 .38932 .21125 .38581 .20439 .37945 Metetra
.654 .758 .927 r
.20439 .37945 .21125 .38581 .2212 .3823 .21437 .37591 Metetra
.654 .758 .927 r
.21437 .37591 .2212 .3823 .23119 .37877 .22438 .37236 Metetra
.654 .758 .927 r
.22438 .37236 .23119 .37877 .24122 .37522 .23444 .36879 Metetra
.654 .758 .927 r
.23444 .36879 .24122 .37522 .25129 .37167 .24453 .36521 Metetra
.654 .758 .927 r
.24453 .36521 .25129 .37167 .2614 .3681 .25466 .36161 Metetra
.654 .758 .927 r
.25466 .36161 .2614 .3681 .27155 .36451 .26483 .358 Metetra
.654 .758 .927 r
.26483 .358 .27155 .36451 .28173 .36092 .27504 .35438 Metetra
.654 .758 .927 r
.27504 .35438 .28173 .36092 .29196 .3573 .28529 .35074 Metetra
.654 .758 .927 r
.28529 .35074 .29196 .3573 .30222 .35368 .29558 .34709 Metetra
.654 .758 .927 r
.29558 .34709 .30222 .35368 .31253 .35004 .30591 .34342 Metetra
.654 .758 .927 r
.30591 .34342 .31253 .35004 .32288 .34638 .31628 .33974 Metetra
.654 .758 .927 r
.31628 .33974 .32288 .34638 .33326 .34271 .3267 .33604 Metetra
.654 .758 .927 r
.3267 .33604 .33326 .34271 .34369 .33903 .33715 .33233 Metetra
.654 .758 .927 r
.33715 .33233 .34369 .33903 .35416 .33533 .34764 .32861 Metetra
.654 .758 .927 r
.34764 .32861 .35416 .33533 .36467 .33162 .35818 .32487 Metetra
.654 .758 .927 r
.35818 .32487 .36467 .33162 .37522 .32789 .36876 .32111 Metetra
.654 .758 .927 r
.36876 .32111 .37522 .32789 .38582 .32415 .37938 .31734 Metetra
.654 .758 .927 r
.37938 .31734 .38582 .32415 .39645 .32039 .39004 .31356 Metetra
.654 .758 .927 r
.39004 .31356 .39645 .32039 .40713 .31662 .40075 .30976 Metetra
.654 .758 .927 r
.40075 .30976 .40713 .31662 .41785 .31284 .41149 .30595 Metetra
.654 .758 .927 r
.41149 .30595 .41785 .31284 .42861 .30903 .42228 .30212 Metetra
.654 .758 .927 r
.42228 .30212 .42861 .30903 .43942 .30522 .43312 .29827 Metetra
.654 .758 .927 r
.43312 .29827 .43942 .30522 .45027 .30138 .444 .29441 Metetra
.654 .758 .927 r
.444 .29441 .45027 .30138 .46116 .29754 .45492 .29053 Metetra
.654 .758 .927 r
.45492 .29053 .46116 .29754 .4721 .29367 .46588 .28664 Metetra
.654 .758 .927 r
.46588 .28664 .4721 .29367 .48308 .28979 .47689 .28274 Metetra
.654 .758 .927 r
.47689 .28274 .48308 .28979 .4941 .2859 .48795 .27881 Metetra
.654 .758 .927 r
.48795 .27881 .4941 .2859 .50517 .28199 .49905 .27487 Metetra
.654 .758 .927 r
.49905 .27487 .50517 .28199 .51629 .27806 .51019 .27092 Metetra
.654 .758 .927 r
.51019 .27092 .51629 .27806 .52745 .27412 .52138 .26695 Metetra
.654 .758 .927 r
.52138 .26695 .52745 .27412 .53865 .27016 .53262 .26296 Metetra
.654 .758 .927 r
.53262 .26296 .53865 .27016 .5499 .26619 .5439 .25895 Metetra
.654 .758 .927 r
.5439 .25895 .5499 .26619 .5612 .2622 .55523 .25493 Metetra
.654 .758 .927 r
.55523 .25493 .5612 .2622 .57255 .25819 .5666 .2509 Metetra
.654 .758 .927 r
.5666 .2509 .57255 .25819 .58394 .25417 .57802 .24684 Metetra
.654 .758 .927 r
.57802 .24684 .58394 .25417 .59537 .25013 .58949 .24277 Metetra
.654 .758 .927 r
.58949 .24277 .59537 .25013 .60686 .24607 .60101 .23868 Metetra
.654 .758 .927 r
.60101 .23868 .60686 .24607 .61839 .242 .61257 .23458 Metetra
.654 .758 .927 r
.61257 .23458 .61839 .242 .62997 .23791 .62418 .23046 Metetra
.654 .758 .927 r
.62418 .23046 .62997 .23791 .64159 .2338 .63585 .22632 Metetra
.654 .758 .927 r
.63585 .22632 .64159 .2338 .65327 .22968 .64755 .22216 Metetra
.654 .758 .927 r
.64755 .22216 .65327 .22968 .66499 .22554 .65931 .21799 Metetra
.654 .758 .927 r
.65931 .21799 .66499 .22554 .67677 .22138 .67112 .2138 Metetra
.654 .758 .927 r
.67112 .2138 .67677 .22138 .68859 .2172 .68298 .20959 Metetra
.654 .758 .927 r
.68298 .20959 .68859 .2172 .70046 .21301 .69488 .20536 Metetra
.654 .758 .927 r
.69488 .20536 .70046 .21301 .71238 .2088 .70684 .20112 Metetra
.654 .758 .927 r
.70684 .20112 .71238 .2088 .72436 .20457 .71885 .19686 Metetra
.654 .758 .927 r
.71885 .19686 .72436 .20457 .73638 .20032 .73091 .19258 Metetra
.654 .76 .927 r
.052 .42496 .05923 .43097 .06865 .42763 .06145 .42159 Metetra
.654 .76 .927 r
.06145 .42159 .06865 .42763 .07811 .42427 .07093 .41821 Metetra
.654 .76 .927 r
.07093 .41821 .07811 .42427 .0876 .4209 .08044 .41482 Metetra
.654 .76 .927 r
.08044 .41482 .0876 .4209 .09714 .41752 .08999 .41141 Metetra
.654 .76 .927 r
.08999 .41141 .09714 .41752 .1067 .41412 .09958 .40799 Metetra
.654 .76 .927 r
.09958 .40799 .1067 .41412 .11631 .41072 .1092 .40456 Metetra
.654 .76 .927 r
.1092 .40456 .11631 .41072 .12594 .40729 .11886 .40112 Metetra
.654 .76 .927 r
.11886 .40112 .12594 .40729 .13562 .40386 .12856 .39766 Metetra
.654 .76 .927 r
.12856 .39766 .13562 .40386 .14533 .40041 .13829 .39419 Metetra
.654 .76 .927 r
.13829 .39419 .14533 .40041 .15508 .39695 .14807 .3907 Metetra
.654 .76 .927 r
.14807 .3907 .15508 .39695 .16487 .39348 .15787 .3872 Metetra
.654 .76 .927 r
.15787 .3872 .16487 .39348 .17469 .38999 .16772 .38369 Metetra
.654 .76 .927 r
.16772 .38369 .17469 .38999 .18456 .38649 .1776 .38017 Metetra
.654 .76 .927 r
.1776 .38017 .18456 .38649 .19446 .38298 .18753 .37663 Metetra
.654 .76 .927 r
.18753 .37663 .19446 .38298 .20439 .37945 .19749 .37308 Metetra
.654 .76 .927 r
.19749 .37308 .20439 .37945 .21437 .37591 .20749 .36951 Metetra
.654 .76 .927 r
.20749 .36951 .21437 .37591 .22438 .37236 .21752 .36593 Metetra
.654 .76 .927 r
.21752 .36593 .22438 .37236 .23444 .36879 .2276 .36234 Metetra
.654 .76 .927 r
.2276 .36234 .23444 .36879 .24453 .36521 .23772 .35873 Metetra
.654 .76 .927 r
.23772 .35873 .24453 .36521 .25466 .36161 .24787 .35511 Metetra
.654 .76 .927 r
.24787 .35511 .25466 .36161 .26483 .358 .25807 .35147 Metetra
.654 .76 .927 r
.25807 .35147 .26483 .358 .27504 .35438 .2683 .34782 Metetra
.654 .76 .927 r
.2683 .34782 .27504 .35438 .28529 .35074 .27857 .34416 Metetra
.654 .76 .927 r
.27857 .34416 .28529 .35074 .29558 .34709 .28889 .34048 Metetra
.654 .76 .927 r
.28889 .34048 .29558 .34709 .30591 .34342 .29925 .33679 Metetra
.654 .76 .927 r
.29925 .33679 .30591 .34342 .31628 .33974 .30964 .33308 Metetra
.654 .76 .927 r
.30964 .33308 .31628 .33974 .3267 .33604 .32008 .32936 Metetra
.654 .76 .927 r
.32008 .32936 .3267 .33604 .33715 .33233 .33056 .32562 Metetra
.654 .76 .927 r
.33056 .32562 .33715 .33233 .34764 .32861 .34108 .32187 Metetra
.654 .76 .927 r
.34108 .32187 .34764 .32861 .35818 .32487 .35164 .3181 Metetra
.654 .76 .927 r
.35164 .3181 .35818 .32487 .36876 .32111 .36225 .31432 Metetra
.654 .76 .927 r
.36225 .31432 .36876 .32111 .37938 .31734 .37289 .31052 Metetra
.654 .76 .927 r
.37289 .31052 .37938 .31734 .39004 .31356 .38358 .30671 Metetra
.654 .76 .927 r
.38358 .30671 .39004 .31356 .40075 .30976 .39431 .30288 Metetra
.654 .76 .927 r
.39431 .30288 .40075 .30976 .41149 .30595 .40509 .29904 Metetra
.654 .76 .927 r
.40509 .29904 .41149 .30595 .42228 .30212 .41591 .29518 Metetra
.654 .76 .927 r
.41591 .29518 .42228 .30212 .43312 .29827 .42677 .29131 Metetra
.654 .76 .927 r
.42677 .29131 .43312 .29827 .444 .29441 .43767 .28742 Metetra
.654 .76 .927 r
.43767 .28742 .444 .29441 .45492 .29053 .44862 .28351 Metetra
.654 .76 .927 r
.44862 .28351 .45492 .29053 .46588 .28664 .45962 .27959 Metetra
.654 .76 .927 r
.45962 .27959 .46588 .28664 .47689 .28274 .47066 .27565 Metetra
.654 .76 .927 r
.47066 .27565 .47689 .28274 .48795 .27881 .48174 .2717 Metetra
.654 .76 .927 r
.48174 .2717 .48795 .27881 .49905 .27487 .49287 .26773 Metetra
.654 .76 .927 r
.49287 .26773 .49905 .27487 .51019 .27092 .50405 .26375 Metetra
.654 .76 .927 r
.50405 .26375 .51019 .27092 .52138 .26695 .51527 .25975 Metetra
.654 .76 .927 r
.51527 .25975 .52138 .26695 .53262 .26296 .52653 .25573 Metetra
.654 .76 .927 r
.52653 .25573 .53262 .26296 .5439 .25895 .53785 .25169 Metetra
.654 .76 .927 r
.53785 .25169 .5439 .25895 .55523 .25493 .54921 .24764 Metetra
.654 .76 .927 r
.54921 .24764 .55523 .25493 .5666 .2509 .56061 .24357 Metetra
.654 .76 .927 r
.56061 .24357 .5666 .2509 .57802 .24684 .57207 .23949 Metetra
.654 .76 .927 r
.57207 .23949 .57802 .24684 .58949 .24277 .58357 .23539 Metetra
.654 .76 .927 r
.58357 .23539 .58949 .24277 .60101 .23868 .59512 .23127 Metetra
.654 .76 .927 r
.59512 .23127 .60101 .23868 .61257 .23458 .60671 .22713 Metetra
.654 .76 .927 r
.60671 .22713 .61257 .23458 .62418 .23046 .61836 .22298 Metetra
.654 .76 .927 r
.61836 .22298 .62418 .23046 .63585 .22632 .63005 .21881 Metetra
.654 .76 .927 r
.63005 .21881 .63585 .22632 .64755 .22216 .64179 .21462 Metetra
.654 .76 .927 r
.64179 .21462 .64755 .22216 .65931 .21799 .65359 .21042 Metetra
.654 .76 .927 r
.65359 .21042 .65931 .21799 .67112 .2138 .66543 .20619 Metetra
.654 .76 .927 r
.66543 .20619 .67112 .2138 .68298 .20959 .67732 .20195 Metetra
.654 .76 .927 r
.67732 .20195 .68298 .20959 .69488 .20536 .68926 .19769 Metetra
.654 .76 .927 r
.68926 .19769 .69488 .20536 .70684 .20112 .70126 .19342 Metetra
.654 .76 .927 r
.70126 .19342 .70684 .20112 .71885 .19686 .7133 .18912 Metetra
.654 .76 .927 r
.7133 .18912 .71885 .19686 .73091 .19258 .72539 .18481 Metetra
.654 .757 .925 r
.04474 .41882 .052 .42496 .06145 .42159 .05421 .41543 Metetra
.654 .757 .925 r
.05421 .41543 .06145 .42159 .07093 .41821 .0637 .41202 Metetra
.654 .757 .925 r
.0637 .41202 .07093 .41821 .08044 .41482 .07324 .40861 Metetra
.654 .757 .925 r
.07324 .40861 .08044 .41482 .08999 .41141 .08281 .40518 Metetra
.654 .757 .925 r
.08281 .40518 .08999 .41141 .09958 .40799 .09242 .40173 Metetra
.654 .757 .925 r
.09242 .40173 .09958 .40799 .1092 .40456 .10206 .39828 Metetra
.654 .757 .925 r
.10206 .39828 .1092 .40456 .11886 .40112 .11174 .39481 Metetra
.654 .757 .925 r
.11174 .39481 .11886 .40112 .12856 .39766 .12146 .39132 Metetra
.654 .757 .925 r
.12146 .39132 .12856 .39766 .13829 .39419 .13122 .38783 Metetra
.654 .757 .925 r
.13122 .38783 .13829 .39419 .14807 .3907 .14101 .38432 Metetra
.654 .757 .925 r
.14101 .38432 .14807 .3907 .15787 .3872 .15084 .3808 Metetra
.654 .757 .925 r
.15084 .3808 .15787 .3872 .16772 .38369 .16071 .37726 Metetra
.654 .757 .925 r
.16071 .37726 .16772 .38369 .1776 .38017 .17061 .37371 Metetra
.654 .757 .925 r
.17061 .37371 .1776 .38017 .18753 .37663 .18056 .37015 Metetra
.654 .757 .925 r
.18056 .37015 .18753 .37663 .19749 .37308 .19054 .36657 Metetra
.654 .757 .925 r
.19054 .36657 .19749 .37308 .20749 .36951 .20056 .36298 Metetra
.654 .757 .925 r
.20056 .36298 .20749 .36951 .21752 .36593 .21062 .35937 Metetra
.654 .757 .925 r
.21062 .35937 .21752 .36593 .2276 .36234 .22072 .35575 Metetra
.654 .757 .925 r
.22072 .35575 .2276 .36234 .23772 .35873 .23086 .35212 Metetra
.654 .757 .925 r
.23086 .35212 .23772 .35873 .24787 .35511 .24104 .34847 Metetra
.654 .757 .925 r
.24104 .34847 .24787 .35511 .25807 .35147 .25126 .34481 Metetra
.654 .757 .925 r
.25126 .34481 .25807 .35147 .2683 .34782 .26152 .34113 Metetra
.654 .757 .925 r
.26152 .34113 .2683 .34782 .27857 .34416 .27181 .33744 Metetra
.654 .757 .925 r
.27181 .33744 .27857 .34416 .28889 .34048 .28215 .33374 Metetra
.654 .757 .925 r
.28215 .33374 .28889 .34048 .29925 .33679 .29253 .33002 Metetra
.654 .757 .925 r
.29253 .33002 .29925 .33679 .30964 .33308 .30296 .32628 Metetra
.654 .757 .925 r
.30296 .32628 .30964 .33308 .32008 .32936 .31342 .32253 Metetra
.654 .757 .925 r
.31342 .32253 .32008 .32936 .33056 .32562 .32392 .31877 Metetra
.654 .757 .925 r
.32392 .31877 .33056 .32562 .34108 .32187 .33447 .31499 Metetra
.654 .757 .925 r
.33447 .31499 .34108 .32187 .35164 .3181 .34506 .31119 Metetra
.654 .757 .925 r
.34506 .31119 .35164 .3181 .36225 .31432 .35569 .30738 Metetra
.654 .757 .925 r
.35569 .30738 .36225 .31432 .37289 .31052 .36636 .30356 Metetra
.654 .757 .925 r
.36636 .30356 .37289 .31052 .38358 .30671 .37708 .29972 Metetra
.654 .757 .925 r
.37708 .29972 .38358 .30671 .39431 .30288 .38784 .29586 Metetra
.654 .757 .925 r
.38784 .29586 .39431 .30288 .40509 .29904 .39864 .29199 Metetra
.654 .757 .925 r
.39864 .29199 .40509 .29904 .41591 .29518 .40948 .28811 Metetra
.654 .757 .925 r
.40948 .28811 .41591 .29518 .42677 .29131 .42037 .2842 Metetra
.654 .757 .925 r
.42037 .2842 .42677 .29131 .43767 .28742 .43131 .28028 Metetra
.654 .757 .925 r
.43131 .28028 .43767 .28742 .44862 .28351 .44229 .27635 Metetra
.654 .757 .925 r
.44229 .27635 .44862 .28351 .45962 .27959 .45331 .2724 Metetra
.654 .757 .925 r
.45331 .2724 .45962 .27959 .47066 .27565 .46438 .26843 Metetra
.654 .757 .925 r
.46438 .26843 .47066 .27565 .48174 .2717 .47549 .26445 Metetra
.654 .757 .925 r
.47549 .26445 .48174 .2717 .49287 .26773 .48665 .26045 Metetra
.654 .757 .925 r
.48665 .26045 .49287 .26773 .50405 .26375 .49785 .25644 Metetra
.654 .757 .925 r
.49785 .25644 .50405 .26375 .51527 .25975 .50911 .2524 Metetra
.654 .757 .925 r
.50911 .2524 .51527 .25975 .52653 .25573 .5204 .24836 Metetra
.654 .757 .925 r
.5204 .24836 .52653 .25573 .53785 .25169 .53175 .24429 Metetra
.654 .757 .925 r
.53175 .24429 .53785 .25169 .54921 .24764 .54314 .24021 Metetra
.654 .757 .925 r
.54314 .24021 .54921 .24764 .56061 .24357 .55457 .23611 Metetra
.654 .757 .925 r
.55457 .23611 .56061 .24357 .57207 .23949 .56606 .23199 Metetra
.654 .757 .925 r
.56606 .23199 .57207 .23949 .58357 .23539 .57759 .22786 Metetra
.654 .757 .925 r
.57759 .22786 .58357 .23539 .59512 .23127 .58917 .22371 Metetra
.654 .757 .925 r
.58917 .22371 .59512 .23127 .60671 .22713 .6008 .21954 Metetra
.654 .757 .925 r
.6008 .21954 .60671 .22713 .61836 .22298 .61248 .21536 Metetra
.654 .757 .925 r
.61248 .21536 .61836 .22298 .63005 .21881 .62421 .21115 Metetra
.654 .757 .925 r
.62421 .21115 .63005 .21881 .64179 .21462 .63599 .20693 Metetra
.654 .757 .925 r
.63599 .20693 .64179 .21462 .65359 .21042 .64781 .2027 Metetra
.654 .757 .925 r
.64781 .2027 .65359 .21042 .66543 .20619 .65969 .19844 Metetra
.654 .757 .925 r
.65969 .19844 .66543 .20619 .67732 .20195 .67162 .19417 Metetra
.654 .757 .925 r
.67162 .19417 .67732 .20195 .68926 .19769 .68359 .18987 Metetra
.654 .757 .925 r
.68359 .18987 .68926 .19769 .70126 .19342 .69562 .18556 Metetra
.654 .757 .925 r
.69562 .18556 .70126 .19342 .7133 .18912 .7077 .18123 Metetra
.654 .757 .925 r
.7077 .18123 .7133 .18912 .72539 .18481 .71983 .17689 Metetra
.654 .757 .925 r
.03743 .41264 .04474 .41882 .05421 .41543 .04691 .40923 Metetra
.654 .757 .925 r
.04691 .40923 .05421 .41543 .0637 .41202 .05643 .4058 Metetra
.654 .757 .925 r
.05643 .4058 .0637 .41202 .07324 .40861 .06599 .40236 Metetra
.654 .757 .925 r
.06599 .40236 .07324 .40861 .08281 .40518 .07558 .39891 Metetra
.654 .757 .925 r
.07558 .39891 .08281 .40518 .09242 .40173 .0852 .39544 Metetra
.654 .757 .925 r
.0852 .39544 .09242 .40173 .10206 .39828 .09487 .39196 Metetra
.654 .757 .925 r
.09487 .39196 .10206 .39828 .11174 .39481 .10457 .38846 Metetra
.654 .757 .925 r
.10457 .38846 .11174 .39481 .12146 .39132 .11431 .38496 Metetra
.654 .757 .925 r
.11431 .38496 .12146 .39132 .13122 .38783 .12409 .38144 Metetra
.654 .757 .925 r
.12409 .38144 .13122 .38783 .14101 .38432 .1339 .3779 Metetra
.654 .757 .925 r
.1339 .3779 .14101 .38432 .15084 .3808 .14375 .37435 Metetra
.654 .757 .925 r
.14375 .37435 .15084 .3808 .16071 .37726 .15364 .37079 Metetra
.654 .757 .925 r
.15364 .37079 .16071 .37726 .17061 .37371 .16357 .36722 Metetra
.654 .757 .925 r
.16357 .36722 .17061 .37371 .18056 .37015 .17353 .36363 Metetra
.654 .757 .925 r
.17353 .36363 .18056 .37015 .19054 .36657 .18354 .36002 Metetra
.654 .757 .925 r
.18354 .36002 .19054 .36657 .20056 .36298 .19358 .35641 Metetra
.654 .757 .925 r
.19358 .35641 .20056 .36298 .21062 .35937 .20367 .35278 Metetra
.654 .757 .925 r
.20367 .35278 .21062 .35937 .22072 .35575 .21379 .34913 Metetra
.654 .757 .925 r
.21379 .34913 .22072 .35575 .23086 .35212 .22395 .34547 Metetra
.654 .757 .925 r
.22395 .34547 .23086 .35212 .24104 .34847 .23415 .3418 Metetra
.654 .757 .925 r
.23415 .3418 .24104 .34847 .25126 .34481 .2444 .33811 Metetra
.654 .757 .925 r
.2444 .33811 .25126 .34481 .26152 .34113 .25468 .33441 Metetra
.654 .757 .925 r
.25468 .33441 .26152 .34113 .27181 .33744 .265 .33069 Metetra
.654 .757 .925 r
.265 .33069 .27181 .33744 .28215 .33374 .27537 .32696 Metetra
.654 .757 .925 r
.27537 .32696 .28215 .33374 .29253 .33002 .28577 .32321 Metetra
.654 .757 .925 r
.28577 .32321 .29253 .33002 .30296 .32628 .29622 .31945 Metetra
.654 .757 .925 r
.29622 .31945 .30296 .32628 .31342 .32253 .30671 .31567 Metetra
.654 .757 .925 r
.30671 .31567 .31342 .32253 .32392 .31877 .31724 .31188 Metetra
.654 .757 .925 r
.31724 .31188 .32392 .31877 .33447 .31499 .32781 .30807 Metetra
.654 .757 .925 r
.32781 .30807 .33447 .31499 .34506 .31119 .33842 .30425 Metetra
.654 .757 .925 r
.33842 .30425 .34506 .31119 .35569 .30738 .34908 .30041 Metetra
.654 .757 .925 r
.34908 .30041 .35569 .30738 .36636 .30356 .35978 .29656 Metetra
.654 .757 .925 r
.35978 .29656 .36636 .30356 .37708 .29972 .37052 .29269 Metetra
.654 .757 .925 r
.37052 .29269 .37708 .29972 .38784 .29586 .38131 .2888 Metetra
.654 .757 .925 r
.38131 .2888 .38784 .29586 .39864 .29199 .39214 .2849 Metetra
.654 .757 .925 r
.39214 .2849 .39864 .29199 .40948 .28811 .40301 .28099 Metetra
.654 .757 .925 r
.40301 .28099 .40948 .28811 .42037 .2842 .41393 .27706 Metetra
.654 .757 .925 r
.41393 .27706 .42037 .2842 .43131 .28028 .42489 .27311 Metetra
.654 .757 .925 r
.42489 .27311 .43131 .28028 .44229 .27635 .4359 .26914 Metetra
.654 .757 .925 r
.4359 .26914 .44229 .27635 .45331 .2724 .44695 .26516 Metetra
.654 .757 .925 r
.44695 .26516 .45331 .2724 .46438 .26843 .45805 .26117 Metetra
.654 .757 .925 r
.45805 .26117 .46438 .26843 .47549 .26445 .46919 .25715 Metetra
.654 .757 .925 r
.46919 .25715 .47549 .26445 .48665 .26045 .48038 .25312 Metetra
.654 .757 .925 r
.48038 .25312 .48665 .26045 .49785 .25644 .49162 .24908 Metetra
.654 .757 .925 r
.49162 .24908 .49785 .25644 .50911 .2524 .5029 .24502 Metetra
.654 .757 .925 r
.5029 .24502 .50911 .2524 .5204 .24836 .51422 .24094 Metetra
.654 .757 .925 r
.51422 .24094 .5204 .24836 .53175 .24429 .5256 .23684 Metetra
.654 .757 .925 r
.5256 .23684 .53175 .24429 .54314 .24021 .53702 .23273 Metetra
.654 .757 .925 r
.53702 .23273 .54314 .24021 .55457 .23611 .54849 .2286 Metetra
.654 .757 .925 r
.54849 .2286 .55457 .23611 .56606 .23199 .56001 .22445 Metetra
.654 .757 .925 r
.56001 .22445 .56606 .23199 .57759 .22786 .57157 .22028 Metetra
.654 .757 .925 r
.57157 .22028 .57759 .22786 .58917 .22371 .58319 .2161 Metetra
.654 .757 .925 r
.58319 .2161 .58917 .22371 .6008 .21954 .59485 .2119 Metetra
.654 .757 .925 r
.59485 .2119 .6008 .21954 .61248 .21536 .60656 .20768 Metetra
.654 .757 .925 r
.60656 .20768 .61248 .21536 .62421 .21115 .61832 .20345 Metetra
.654 .757 .925 r
.61832 .20345 .62421 .21115 .63599 .20693 .63013 .1992 Metetra
.654 .757 .925 r
.63013 .1992 .63599 .20693 .64781 .2027 .64199 .19492 Metetra
.654 .757 .925 r
.64199 .19492 .64781 .2027 .65969 .19844 .6539 .19064 Metetra
.654 .757 .925 r
.6539 .19064 .65969 .19844 .67162 .19417 .66587 .18633 Metetra
.654 .757 .925 r
.66587 .18633 .67162 .19417 .68359 .18987 .67788 .182 Metetra
.654 .757 .925 r
.67788 .182 .68359 .18987 .69562 .18556 .68994 .17766 Metetra
.654 .757 .925 r
.68994 .17766 .69562 .18556 .7077 .18123 .70206 .17329 Metetra
.654 .757 .925 r
.70206 .17329 .7077 .18123 .71983 .17689 .71422 .16891 Metetra
.654 .755 .924 r
.03007 .40637 .03743 .41264 .04691 .40923 .03957 .40293 Metetra
.654 .755 .924 r
.03957 .40293 .04691 .40923 .05643 .4058 .04911 .39948 Metetra
.654 .755 .924 r
.04911 .39948 .05643 .4058 .06599 .40236 .05869 .39601 Metetra
.654 .755 .924 r
.05869 .39601 .06599 .40236 .07558 .39891 .0683 .39253 Metetra
.654 .755 .924 r
.0683 .39253 .07558 .39891 .0852 .39544 .07795 .38904 Metetra
.654 .755 .924 r
.07795 .38904 .0852 .39544 .09487 .39196 .08763 .38554 Metetra
.654 .755 .924 r
.08763 .38554 .09487 .39196 .10457 .38846 .09735 .38202 Metetra
.654 .755 .924 r
.09735 .38202 .10457 .38846 .11431 .38496 .10711 .37849 Metetra
.654 .755 .924 r
.10711 .37849 .11431 .38496 .12409 .38144 .11691 .37494 Metetra
.654 .755 .924 r
.11691 .37494 .12409 .38144 .1339 .3779 .12675 .37138 Metetra
.654 .755 .924 r
.12675 .37138 .1339 .3779 .14375 .37435 .13662 .36781 Metetra
.654 .755 .924 r
.13662 .36781 .14375 .37435 .15364 .37079 .14653 .36422 Metetra
.654 .755 .924 r
.14653 .36422 .15364 .37079 .16357 .36722 .15648 .36062 Metetra
.654 .755 .924 r
.15648 .36062 .16357 .36722 .17353 .36363 .16647 .35701 Metetra
.654 .755 .924 r
.16647 .35701 .17353 .36363 .18354 .36002 .1765 .35338 Metetra
.654 .755 .924 r
.1765 .35338 .18354 .36002 .19358 .35641 .18656 .34973 Metetra
.654 .755 .924 r
.18656 .34973 .19358 .35641 .20367 .35278 .19667 .34608 Metetra
.654 .755 .924 r
.19667 .34608 .20367 .35278 .21379 .34913 .20681 .34241 Metetra
.654 .755 .924 r
.20681 .34241 .21379 .34913 .22395 .34547 .217 .33872 Metetra
.654 .755 .924 r
.217 .33872 .22395 .34547 .23415 .3418 .22723 .33502 Metetra
.654 .755 .924 r
.22723 .33502 .23415 .3418 .2444 .33811 .23749 .3313 Metetra
.654 .755 .924 r
.23749 .3313 .2444 .33811 .25468 .33441 .2478 .32757 Metetra
.654 .755 .924 r
.2478 .32757 .25468 .33441 .265 .33069 .25815 .32383 Metetra
.654 .755 .924 r
.25815 .32383 .265 .33069 .27537 .32696 .26854 .32007 Metetra
.654 .755 .924 r
.26854 .32007 .27537 .32696 .28577 .32321 .27897 .31629 Metetra
.654 .755 .924 r
.27897 .31629 .28577 .32321 .29622 .31945 .28944 .3125 Metetra
.654 .755 .924 r
.28944 .3125 .29622 .31945 .30671 .31567 .29995 .3087 Metetra
.654 .755 .924 r
.29995 .3087 .30671 .31567 .31724 .31188 .31051 .30488 Metetra
.654 .755 .924 r
.31051 .30488 .31724 .31188 .32781 .30807 .3211 .30104 Metetra
.654 .755 .924 r
.3211 .30104 .32781 .30807 .33842 .30425 .33174 .29719 Metetra
.654 .755 .924 r
.33174 .29719 .33842 .30425 .34908 .30041 .34243 .29333 Metetra
.654 .755 .924 r
.34243 .29333 .34908 .30041 .35978 .29656 .35315 .28944 Metetra
.654 .755 .924 r
.35315 .28944 .35978 .29656 .37052 .29269 .36392 .28555 Metetra
.654 .755 .924 r
.36392 .28555 .37052 .29269 .38131 .2888 .37474 .28163 Metetra
.654 .755 .924 r
.37474 .28163 .38131 .2888 .39214 .2849 .38559 .2777 Metetra
.654 .755 .924 r
.38559 .2777 .39214 .2849 .40301 .28099 .3965 .27376 Metetra
.654 .755 .924 r
.3965 .27376 .40301 .28099 .41393 .27706 .40744 .2698 Metetra
.654 .755 .924 r
.40744 .2698 .41393 .27706 .42489 .27311 .41843 .26582 Metetra
.654 .755 .924 r
.41843 .26582 .42489 .27311 .4359 .26914 .42947 .26183 Metetra
.654 .755 .924 r
.42947 .26183 .4359 .26914 .44695 .26516 .44055 .25782 Metetra
.654 .755 .924 r
.44055 .25782 .44695 .26516 .45805 .26117 .45167 .25379 Metetra
.654 .755 .924 r
.45167 .25379 .45805 .26117 .46919 .25715 .46285 .24975 Metetra
.654 .755 .924 r
.46285 .24975 .46919 .25715 .48038 .25312 .47407 .24569 Metetra
.654 .755 .924 r
.47407 .24569 .48038 .25312 .49162 .24908 .48533 .24161 Metetra
.654 .755 .924 r
.48533 .24161 .49162 .24908 .5029 .24502 .49664 .23751 Metetra
.654 .755 .924 r
.49664 .23751 .5029 .24502 .51422 .24094 .508 .2334 Metetra
.654 .755 .924 r
.508 .2334 .51422 .24094 .5256 .23684 .5194 .22928 Metetra
.654 .755 .924 r
.5194 .22928 .5256 .23684 .53702 .23273 .53086 .22513 Metetra
.654 .755 .924 r
.53086 .22513 .53702 .23273 .54849 .2286 .54236 .22097 Metetra
.654 .755 .924 r
.54236 .22097 .54849 .2286 .56001 .22445 .55391 .21679 Metetra
.654 .755 .924 r
.55391 .21679 .56001 .22445 .57157 .22028 .56551 .21259 Metetra
.654 .755 .924 r
.56551 .21259 .57157 .22028 .58319 .2161 .57715 .20838 Metetra
.654 .755 .924 r
.57715 .20838 .58319 .2161 .59485 .2119 .58885 .20414 Metetra
.654 .755 .924 r
.58885 .20414 .59485 .2119 .60656 .20768 .60059 .19989 Metetra
.654 .755 .924 r
.60059 .19989 .60656 .20768 .61832 .20345 .61239 .19563 Metetra
.654 .755 .924 r
.61239 .19563 .61832 .20345 .63013 .1992 .62423 .19134 Metetra
.654 .755 .924 r
.62423 .19134 .63013 .1992 .64199 .19492 .63613 .18703 Metetra
.654 .755 .924 r
.63613 .18703 .64199 .19492 .6539 .19064 .64807 .18271 Metetra
.654 .755 .924 r
.64807 .18271 .6539 .19064 .66587 .18633 .66007 .17837 Metetra
.654 .755 .924 r
.66007 .17837 .66587 .18633 .67788 .182 .67211 .17401 Metetra
.654 .755 .924 r
.67211 .17401 .67788 .182 .68994 .17766 .68421 .16963 Metetra
.654 .755 .924 r
.68421 .16963 .68994 .17766 .70206 .17329 .69636 .16523 Metetra
.654 .755 .924 r
.69636 .16523 .70206 .17329 .71422 .16891 .70857 .16082 Metetra
.654 .755 .924 r
.02267 .40004 .03007 .40637 .03957 .40293 .03219 .39658 Metetra
.654 .755 .924 r
.03219 .39658 .03957 .40293 .04911 .39948 .04175 .3931 Metetra
.654 .755 .924 r
.04175 .3931 .04911 .39948 .05869 .39601 .05134 .38961 Metetra
.654 .755 .924 r
.05134 .38961 .05869 .39601 .0683 .39253 .06097 .38611 Metetra
.654 .755 .924 r
.06097 .38611 .0683 .39253 .07795 .38904 .07064 .38259 Metetra
.654 .755 .924 r
.07064 .38259 .07795 .38904 .08763 .38554 .08034 .37906 Metetra
.654 .755 .924 r
.08034 .37906 .08763 .38554 .09735 .38202 .09009 .37552 Metetra
.654 .755 .924 r
.09009 .37552 .09735 .38202 .10711 .37849 .09987 .37196 Metetra
.654 .755 .924 r
.09987 .37196 .10711 .37849 .11691 .37494 .10969 .36839 Metetra
.654 .755 .924 r
.10969 .36839 .11691 .37494 .12675 .37138 .11954 .36481 Metetra
.654 .755 .924 r
.11954 .36481 .12675 .37138 .13662 .36781 .12944 .36121 Metetra
.654 .755 .924 r
.12944 .36121 .13662 .36781 .14653 .36422 .13937 .3576 Metetra
.654 .755 .924 r
.13937 .3576 .14653 .36422 .15648 .36062 .14934 .35397 Metetra
.654 .755 .924 r
.14934 .35397 .15648 .36062 .16647 .35701 .15935 .35033 Metetra
.654 .755 .924 r
.15935 .35033 .16647 .35701 .1765 .35338 .1694 .34667 Metetra
.654 .755 .924 r
.1694 .34667 .1765 .35338 .18656 .34973 .17949 .343 Metetra
.654 .755 .924 r
.17949 .343 .18656 .34973 .19667 .34608 .18962 .33932 Metetra
.654 .755 .924 r
.18962 .33932 .19667 .34608 .20681 .34241 .19979 .33562 Metetra
.654 .755 .924 r
.19979 .33562 .20681 .34241 .217 .33872 .21 .33191 Metetra
.654 .755 .924 r
.21 .33191 .217 .33872 .22723 .33502 .22025 .32818 Metetra
.654 .755 .924 r
.22025 .32818 .22723 .33502 .23749 .3313 .23054 .32444 Metetra
.654 .755 .924 r
.23054 .32444 .23749 .3313 .2478 .32757 .24087 .32068 Metetra
.654 .755 .924 r
.24087 .32068 .2478 .32757 .25815 .32383 .25124 .31691 Metetra
.654 .755 .924 r
.25124 .31691 .25815 .32383 .26854 .32007 .26165 .31312 Metetra
.654 .755 .924 r
.26165 .31312 .26854 .32007 .27897 .31629 .27211 .30932 Metetra
.654 .755 .924 r
.27211 .30932 .27897 .31629 .28944 .3125 .28261 .3055 Metetra
.654 .755 .924 r
.28261 .3055 .28944 .3125 .29995 .3087 .29314 .30167 Metetra
.654 .755 .924 r
.29314 .30167 .29995 .3087 .31051 .30488 .30373 .29782 Metetra
.654 .755 .924 r
.30373 .29782 .31051 .30488 .3211 .30104 .31435 .29395 Metetra
.654 .755 .924 r
.31435 .29395 .3211 .30104 .33174 .29719 .32502 .29007 Metetra
.654 .755 .924 r
.32502 .29007 .33174 .29719 .34243 .29333 .33573 .28618 Metetra
.654 .755 .924 r
.33573 .28618 .34243 .29333 .35315 .28944 .34648 .28227 Metetra
.654 .755 .924 r
.34648 .28227 .35315 .28944 .36392 .28555 .35728 .27834 Metetra
.654 .755 .924 r
.35728 .27834 .36392 .28555 .37474 .28163 .36812 .2744 Metetra
.654 .755 .924 r
.36812 .2744 .37474 .28163 .38559 .2777 .379 .27044 Metetra
.654 .755 .924 r
.379 .27044 .38559 .2777 .3965 .27376 .38993 .26646 Metetra
.654 .755 .924 r
.38993 .26646 .3965 .27376 .40744 .2698 .4009 .26247 Metetra
.654 .755 .924 r
.4009 .26247 .40744 .2698 .41843 .26582 .41192 .25847 Metetra
.654 .755 .924 r
.41192 .25847 .41843 .26582 .42947 .26183 .42299 .25444 Metetra
.654 .755 .924 r
.42299 .25444 .42947 .26183 .44055 .25782 .4341 .2504 Metetra
.654 .755 .924 r
.4341 .2504 .44055 .25782 .45167 .25379 .44525 .24634 Metetra
.654 .755 .924 r
.44525 .24634 .45167 .25379 .46285 .24975 .45645 .24227 Metetra
.654 .755 .924 r
.45645 .24227 .46285 .24975 .47407 .24569 .4677 .23818 Metetra
.654 .755 .924 r
.4677 .23818 .47407 .24569 .48533 .24161 .479 .23407 Metetra
.654 .755 .924 r
.479 .23407 .48533 .24161 .49664 .23751 .49034 .22994 Metetra
.654 .755 .924 r
.49034 .22994 .49664 .23751 .508 .2334 .50173 .2258 Metetra
.654 .755 .924 r
.50173 .2258 .508 .2334 .5194 .22928 .51316 .22164 Metetra
.654 .755 .924 r
.51316 .22164 .5194 .22928 .53086 .22513 .52465 .21747 Metetra
.654 .755 .924 r
.52465 .21747 .53086 .22513 .54236 .22097 .53618 .21327 Metetra
.654 .755 .924 r
.53618 .21327 .54236 .22097 .55391 .21679 .54776 .20906 Metetra
.654 .755 .924 r
.54776 .20906 .55391 .21679 .56551 .21259 .55939 .20483 Metetra
.654 .755 .924 r
.55939 .20483 .56551 .21259 .57715 .20838 .57107 .20058 Metetra
.654 .755 .924 r
.57107 .20058 .57715 .20838 .58885 .20414 .5828 .19632 Metetra
.654 .755 .924 r
.5828 .19632 .58885 .20414 .60059 .19989 .59458 .19203 Metetra
.654 .755 .924 r
.59458 .19203 .60059 .19989 .61239 .19563 .6064 .18773 Metetra
.654 .755 .924 r
.6064 .18773 .61239 .19563 .62423 .19134 .61828 .18341 Metetra
.654 .755 .924 r
.61828 .18341 .62423 .19134 .63613 .18703 .63021 .17907 Metetra
.654 .755 .924 r
.63021 .17907 .63613 .18703 .64807 .18271 .64219 .17471 Metetra
.654 .755 .924 r
.64219 .17471 .64807 .18271 .66007 .17837 .65422 .17034 Metetra
.654 .755 .924 r
.65422 .17034 .66007 .17837 .67211 .17401 .6663 .16594 Metetra
.654 .755 .924 r
.6663 .16594 .67211 .17401 .68421 .16963 .67844 .16153 Metetra
.654 .755 .924 r
.67844 .16153 .68421 .16963 .69636 .16523 .69063 .1571 Metetra
.654 .755 .924 r
.69063 .1571 .69636 .16523 .70857 .16082 .70287 .15265 Metetra
.654 .754 .923 r
.01521 .39364 .02267 .40004 .03219 .39658 .02475 .39015 Metetra
.654 .754 .923 r
.02475 .39015 .03219 .39658 .04175 .3931 .03433 .38665 Metetra
.654 .754 .923 r
.03433 .38665 .04175 .3931 .05134 .38961 .04394 .38314 Metetra
.654 .754 .923 r
.04394 .38314 .05134 .38961 .06097 .38611 .0536 .37961 Metetra
.654 .754 .923 r
.0536 .37961 .06097 .38611 .07064 .38259 .06328 .37607 Metetra
.654 .754 .923 r
.06328 .37607 .07064 .38259 .08034 .37906 .07301 .37251 Metetra
.654 .754 .923 r
.07301 .37251 .08034 .37906 .09009 .37552 .08277 .36894 Metetra
.654 .754 .923 r
.08277 .36894 .09009 .37552 .09987 .37196 .09257 .36536 Metetra
.654 .754 .923 r
.09257 .36536 .09987 .37196 .10969 .36839 .10241 .36176 Metetra
.654 .754 .923 r
.10241 .36176 .10969 .36839 .11954 .36481 .11229 .35815 Metetra
.654 .754 .923 r
.11229 .35815 .11954 .36481 .12944 .36121 .12221 .35453 Metetra
.654 .754 .923 r
.12221 .35453 .12944 .36121 .13937 .3576 .13216 .35089 Metetra
.654 .754 .923 r
.13216 .35089 .13937 .3576 .14934 .35397 .14216 .34724 Metetra
.654 .754 .923 r
.14216 .34724 .14934 .35397 .15935 .35033 .15219 .34357 Metetra
.654 .754 .923 r
.15219 .34357 .15935 .35033 .1694 .34667 .16226 .33989 Metetra
.654 .754 .923 r
.16226 .33989 .1694 .34667 .17949 .343 .17237 .33619 Metetra
.654 .754 .923 r
.17237 .33619 .17949 .343 .18962 .33932 .18252 .33248 Metetra
.654 .754 .923 r
.18252 .33248 .18962 .33932 .19979 .33562 .19272 .32875 Metetra
.654 .754 .923 r
.19272 .32875 .19979 .33562 .21 .33191 .20295 .32501 Metetra
.654 .754 .923 r
.20295 .32501 .21 .33191 .22025 .32818 .21322 .32126 Metetra
.654 .754 .923 r
.21322 .32126 .22025 .32818 .23054 .32444 .22354 .31749 Metetra
.654 .754 .923 r
.22354 .31749 .23054 .32444 .24087 .32068 .23389 .3137 Metetra
.654 .754 .923 r
.23389 .3137 .24087 .32068 .25124 .31691 .24429 .3099 Metetra
.654 .754 .923 r
.24429 .3099 .25124 .31691 .26165 .31312 .25472 .30609 Metetra
.654 .754 .923 r
.25472 .30609 .26165 .31312 .27211 .30932 .2652 .30226 Metetra
.654 .754 .923 r
.2652 .30226 .27211 .30932 .28261 .3055 .27573 .29841 Metetra
.654 .754 .923 r
.27573 .29841 .28261 .3055 .29314 .30167 .28629 .29455 Metetra
.654 .754 .923 r
.28629 .29455 .29314 .30167 .30373 .29782 .2969 .29067 Metetra
.654 .754 .923 r
.2969 .29067 .30373 .29782 .31435 .29395 .30755 .28678 Metetra
.654 .754 .923 r
.30755 .28678 .31435 .29395 .32502 .29007 .31824 .28287 Metetra
.654 .754 .923 r
.31824 .28287 .32502 .29007 .33573 .28618 .32897 .27895 Metetra
.654 .754 .923 r
.32897 .27895 .33573 .28618 .34648 .28227 .33975 .27501 Metetra
.654 .754 .923 r
.33975 .27501 .34648 .28227 .35728 .27834 .35058 .27105 Metetra
.654 .754 .923 r
.35058 .27105 .35728 .27834 .36812 .2744 .36145 .26708 Metetra
.654 .754 .923 r
.36145 .26708 .36812 .2744 .379 .27044 .37236 .26309 Metetra
.654 .754 .923 r
.37236 .26309 .379 .27044 .38993 .26646 .38331 .25908 Metetra
.654 .754 .923 r
.38331 .25908 .38993 .26646 .4009 .26247 .39432 .25506 Metetra
.654 .754 .923 r
.39432 .25506 .4009 .26247 .41192 .25847 .40536 .25102 Metetra
.654 .754 .923 r
.40536 .25102 .41192 .25847 .42299 .25444 .41646 .24697 Metetra
.654 .754 .923 r
.41646 .24697 .42299 .25444 .4341 .2504 .42759 .2429 Metetra
.654 .754 .923 r
.42759 .2429 .4341 .2504 .44525 .24634 .43878 .23881 Metetra
.654 .754 .923 r
.43878 .23881 .44525 .24634 .45645 .24227 .45001 .2347 Metetra
.654 .754 .923 r
.45001 .2347 .45645 .24227 .4677 .23818 .46129 .23058 Metetra
.654 .754 .923 r
.46129 .23058 .4677 .23818 .479 .23407 .47261 .22644 Metetra
.654 .754 .923 r
.47261 .22644 .479 .23407 .49034 .22994 .48399 .22228 Metetra
.654 .754 .923 r
.48399 .22228 .49034 .22994 .50173 .2258 .4954 .21811 Metetra
.654 .754 .923 r
.4954 .21811 .50173 .2258 .51316 .22164 .50687 .21392 Metetra
.654 .754 .923 r
.50687 .21392 .51316 .22164 .52465 .21747 .51839 .20971 Metetra
.654 .754 .923 r
.51839 .20971 .52465 .21747 .53618 .21327 .52995 .20548 Metetra
.654 .754 .923 r
.52995 .20548 .53618 .21327 .54776 .20906 .54157 .20124 Metetra
.654 .754 .923 r
.54157 .20124 .54776 .20906 .55939 .20483 .55323 .19697 Metetra
.654 .754 .923 r
.55323 .19697 .55939 .20483 .57107 .20058 .56494 .19269 Metetra
.654 .754 .923 r
.56494 .19269 .57107 .20058 .5828 .19632 .5767 .18839 Metetra
.654 .754 .923 r
.5767 .18839 .5828 .19632 .59458 .19203 .58851 .18408 Metetra
.654 .754 .923 r
.58851 .18408 .59458 .19203 .6064 .18773 .60037 .17974 Metetra
.654 .754 .923 r
.60037 .17974 .6064 .18773 .61828 .18341 .61228 .17539 Metetra
.654 .754 .923 r
.61228 .17539 .61828 .18341 .63021 .17907 .62425 .17101 Metetra
.654 .754 .923 r
.62425 .17101 .63021 .17907 .64219 .17471 .63626 .16662 Metetra
.654 .754 .923 r
.63626 .16662 .64219 .17471 .65422 .17034 .64833 .16221 Metetra
.654 .754 .923 r
.64833 .16221 .65422 .17034 .6663 .16594 .66045 .15778 Metetra
.654 .754 .923 r
.66045 .15778 .6663 .16594 .67844 .16153 .67262 .15333 Metetra
.654 .754 .923 r
.67262 .15333 .67844 .16153 .69063 .1571 .68484 .14886 Metetra
.654 .754 .923 r
.68484 .14886 .69063 .1571 .70287 .15265 .69712 .14438 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21731 .1846 m
.22182 .18936 L
s
[(20)] .2083 .17506 .94497 1 Mshowa
.42148 .10465 m
.42562 .10974 L
s
[(40)] .41321 .09446 .81259 1 Mshowa
.64237 .01816 m
.64606 .02358 L
s
[(60)] .63499 .00731 .68022 1 Mshowa
.125 Mabswid
.07404 .2407 m
.07688 .24342 L
s
.12091 .22234 m
.12371 .22511 L
s
.16866 .20365 m
.17141 .20646 L
s
.26689 .16518 m
.26954 .16809 L
s
.31743 .14539 m
.32003 .14835 L
s
.36895 .12522 m
.37149 .12822 L
s
.47506 .08367 m
.47748 .08677 L
s
.52971 .06227 m
.53207 .06542 L
s
.58547 .04044 m
.58776 .04364 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 233.562},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GQ000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?moo`]oo`06Li`Q2000000YBW>L17oo00AJePQ2000icYQoo`00ogoo2goo
00HYBSW>OomoocW>:DX3Ool01V<H6<IcW7>L48ABU9Moo`00ogoo2goo00<8@WooOol00Woo00H007oo
Oomoob48DY@2Ool00e:D6<Ioo`2FOol00?moo`]oo`03001cW7oo009oo`05001oogooOol00004Ool0
0`00Oomoo`2EOol00?moo`]oo`06000YBW>LOolicRU:0goo00<007ooOol00Woo00<007ooOol0UGoo
003oOol;Ool01Q24>Lh00000:DYcW0=oo`03001oogoo009oo`03001oogoo09Eoo`00ogoo2goo00=2
436<Ool01Woo00HQ25:DOomooe:D8@RGOol00?moo`aoo`036<HaS6]J00Eoo`06HaPHaW>LLi`HaV<H
4goo0P00PWoo003oOol=Ool013W>2480012417oo00AJePQ2249S615oo`<00003Ool007oo085oo`00
ogoo:7oo0P0017oo0P00PGoo003oOolUOol30006Ool00`00Ool00020Ool00?moob=oo`8000Uoo`03
001oo`00081oo`00ogoo87oo0`002goo00@007ooOol007moo`00ogoo7Goo0`003Woo00D007ooOomo
o`0007ioo`00ogoo6goo0P004Goo00D007ooOomoo`0007ioo`00ogoo67oo0`0000=oo`00Ool047oo
00<007ooOol00Woo00<007ooOol0Ngoo003oOolFOol20005Ool00`00Oomoo`0?Ool00`00Oomoo`02
Ool00`00Oomoo`1jOol00?mooa=oo`<000Moo`03001oogoo00moo`03001oogoo009oo`03001oogoo
07Yoo`00ogoo4Goo0P0077oo00<007ooOol00goo00<007ooOol0NGoo003oOol>Ool3000NOol00`00
Oomoo`03Ool00`00Oomoo`1iOol00?moo`aoo`80025oo`03001oogoo00Aoo`8007Uoo`00ogoo2Goo
0`008goo00<007ooOol00goo00<007oo0000NGoo003oOol6Ool3000VOol00`00Oomoo`05Ool00`00
Oomoo`1gOol00?moo`Aoo`8002Uoo`03001oogoo00Ioo`03001oogoo07Ioo`00ogoo0Goo0`0000=o
o`00Ool0:7oo00<007ooOol01goo00<007ooOol0MGoo003nOol20005Ool00`00Oomoo`0VOol00`00
Oomoo`07Ool00`00Oomoo`1eOol00?]oo`<0031oo`03001oogoo00Qoo`03001oogoo07Aoo`00nGoo
0P00<goo00<007ooOol02Goo00<007ooOol0Lgoo003fOol3000eOol00`00Oomoo`09Ool00`00Oomo
o`1cOol00?Aoo`8003Qoo`03001oogoo00Yoo`03001oogoo079oo`00lGoo0`00>Woo00<007ooOol0
2goo00<007ooOol0LGoo003_Ool2000mOol00`00Oomoo`0;Ool00`00Oomoo`1aOol00>aoo`<0041o
o`03001oogoo00]oo`03001oogoo071oo`00jGoo0`000goo00<007ooOol0?Goo00<007ooOol037oo
00<007ooOol0Kgoo003WOol20016Ool00`00Oomoo`0<Ool00`00Oomoo`1_Ool00;=oo`800003249o
ogoo009oo`04F]H8@P00>LhVOol30018Ool00`00Oomoo`0=Ool00`00Oomoo`1^Ool00;Aoo`03001o
ogoo009oo`06HaPHaW>LLi`@Q5:D8goo0P00Bgoo00<007ooOol03Woo00<007ooOol0KGoo002`Ool6
0003Ool01R48DYAoogooDY@HaR1oo`<004eoo`03001oogoo00eoo`8006moo`00/7oo00DicU:DOomo
o`0000Aoo`03001oogoo009oo`03001oogoo01aoo`80051oo`03001oogoo00moo`03001oogoo06ao
o`00/7oo00EcW1S6Liaoo`0000Aoo`03001oogoo009oo`03001oogoo01Uoo`<0059oo`03001oogoo
011oo`03001oogoo06]oo`00/Goo00ABU36<Ool000Aoo`03001oogoo009oo`03001oogoo01Moo`80
05Eoo`03001oogoo011oo`03001oogoo06]oo`00/Woo00<Q26<H000017oo00HQ25:DOomooe:D8@PF
Ool4001FOol00`00Oomoo`0AOol00`00Oomoo`1ZOol00;9oo`03JeXQ200000Aoo`06HaPHaW>LLi`H
aV<H57oo0P0017oo00<007ooOol0Dgoo00<007ooOol04Goo00<007ooOol0JWoo002cOol00cW>249o
o`04Ool015[F2488@V<H4Woo0`00G7oo00<007ooOol04Woo00<007ooOol0JGoo003=Ool3001OOol0
0`00Oomoo`0COol00`00Oomoo`1XOol00<]oo`80069oo`03001oogoo01=oo`03001oogoo06Qoo`00
b7oo0`00I7oo00<007ooOol057oo00<007ooOol0Igoo0036Ool2001WOol00`00Oomoo`0EOol00`00
Oomoo`1VOol00<=oo`<006Uoo`03001oogoo01Eoo`03001oogoo06Ioo`00`Goo0P00KGoo00<007oo
Ool05Goo00<007ooOol0IGoo002nOol30002Ool00`00Oomoo`1ZOol00`00Oomoo`0FOol00`00Oomo
o`1TOol00;aoo`8000Ioo`03001oogoo06Uoo`03001oogoo01Ioo`03001oogoo06Aoo`00^Goo0`00
M7oo00<007ooOol05goo0P00I7oo002fOol3001gOol00`00Oomoo`0FOol00`00Ool0001TOol00;Ao
o`8007Yoo`03001oogoo01Qoo`03001oogoo069oo`00/Goo0`00O7oo00<007ooOol06Goo00<007oo
Ool0HGoo002_Ool2001oOol00`00Oomoo`0JOol00`00Oomoo`1POol00:aoo`<0085oo`03001oogoo
01Yoo`03001oogoo061oo`00ZWoo0P000Woo00<007ooOol0Ogoo00<007ooOol06goo00<007ooOol0
Ggoo002WOol30026Ool00`00Oomoo`0LOol00`00Oomoo`1NOol00:Eoo`8008Uoo`03001oogoo01ao
o`03001oogoo00Qoo`H000Aoo`04F]H8@P00>Li8Ool00:9oo`<008]oo`03001oogoo01eoo`03001o
ogoo00Moo`03BU8006<H009oo`06249oogooOomS61S60W>L00<@Q5:DOol0AWoo002POol2002>Ool0
0`00Oomoo`0MOol00`00Oomoo`08Ool00dYB001S6005Ool01R48DYAoogooDY@HaTMoo`00WGoo0`00
T7oo00<007ooOol07Woo00<007ooOol027oo00=BU0Q2HaP017oo00<007ooOol00Woo00<007ooOol0
AGoo002JOol3002COol00`00Oomoo`0OOol00`00Oomoo`08Ool00f<H249S6003Ool00`00Oomoo`02
Ool00`00Oomoo`15Ool009Qoo`8009Ioo`80021oo`03001oogoo00Uoo`03DY@HaWoo009oo`03001o
ogoo009oo`03001oogoo04Eoo`00UGoo0`000Woo00<007ooOol0T7oo0`0000=C7@00Ool087oo00<0
07ooOol02Goo00H007ooOomoob48DY@2Ool00e:D8@Qoo`16Ool005eoo`H000Aoo`04F]H8@P00>LhX
Ool2002EOol30004Dad2000POol20005Ool01P00@Q1cW7oo>LhHaP=oo`06HaPHaW>LLi`HaV<HAgoo
001MOol00dYB001S6002Ool01PQ2OomoogooHaPHaP9cW00348ABU7oo02=oo`<009=oo`@0009C7@03
001C7E<M009C7@<001ioo`03001oo`0000Eoo`06DY@HaP00000YBW>L17oo00AJePQ2249S64Qoo`00
GWoo00=:DP00HaP01Goo00HQ25:DOomooe:D6<HROol2002COol300000e<M001C7@04Dad00`00Dad0
000200000e<M001oo`0POol00`00Oomoo`1HOol005moo`03DY@8@V<H00Aoo`03001oogoo009oo`03
001oogoo01eoo`<009=oo`8000EC7@03001C7E<M009C7@80009C7@04001C7E<M000QOol00`00Oomo
o`1GOol0061oo`03HaP8@V<H00=oo`03001oogoo009oo`03001oogoo01]oo`8009=oo`<00003Dad0
05<M00AC7@03001C7@0000800005Dad005<MDad00002Dad2000POol00`00Oomoo`1GOol0065oo`03
DY@HaWoo009oo`03001oogoo009oo`03001oogoo01Qoo`<009=oo`8000EC7@04001C7E<MDad30005
Dad00`00Dad0000200000e<M001oo`0POol00`00Oomoo`1FOol0069oo`06001oogooOolQ25:D0Woo
00=BU248Ool05Woo0`00Tgoo0`0000=C7@00Dad015<M10000U<M00<005<MDad00e<M0`0015<M00<0
07ooOol07goo00<007ooOol0EGoo001MOol01P00@Q1cW7oo>LhHaP=oo`06HaPHaW>LLi`HaV<H5Goo
0P000goo00<007ooOol0SGoo0`001E<M00<005<M00000P0000=C7@00Dad015<M00<005<M00000P00
0U<M00<005<MDad00U<M00<007ooOol07goo00<007ooOol0EGoo001MOol01U:D6<H00000:DYcW0Ao
o`04F]H8@PQ2HaPCOol3002AOol40003Dad00`00DaeC7@02Dad20005Dad00`00DaeC7@02Dad20005
Dad20002Dad3000QOol00`00Oomoo`1DOol007aoo`80099oo`800003Dad005<M00EC7@04001C7@00
0002Dad00`00DaeC7@03Dad01000Dad000000U<M00<005<MDad00U<M10000e<M00<007ooOol07goo
00<007ooOol0Dgoo001iOol3002BOol20004Dad00`00DaeC7@03Dad20005Dad01000DaeC7E<M0`00
1E<M00<005<M00000P0000=C7@00Dad015<M00<007ooOol07Woo00<007ooOol0Dgoo001gOol2002B
Ool300000e<M001C7@04Dad00`00Dad0000200000e<M001C7@04Dad40002Dad00`00DaeC7@03Dad2
0002Dad01000DaeC7@0015<M0P0087oo00<007ooOol0DWoo001dOol3002BOol20005Dad01000DaeC
7E<M0`001E<M00<005<M00000P0000=C7@00Dad015<M00<005<M00000P0000EC7@00DaeC7@00009C
7@03001C7@0000800003Dad007oo021oo`03001oogoo055oo`00LWoo0P00TWoo0`0000=C7@00Dad0
15<M10000U<M00<005<MDad00e<M0P001E<M00<005<MDad00U<M0P001E<M00@005<M001C7@<000EC
7@03001oogoo01ioo`03001oogoo055oo`00Kgoo0`00TGoo0`001E<M00<005<M00000P0000=C7@00
Dad015<M00<005<M00000P0000=C7@00Dad015<M00<005<M00000P0000=C7@00Dad015<M10000U<M
00<005<MDad00e<M0P0087oo0P00DGoo001]Ool20003Ool00`00Oomoo`2:Ool40003Dad00`00DaeC
7@02Dad20005Dad00`00DaeC7@02Dad20005Dad01000DaeC7E<M0`001E<M00<005<M00000P0000AC
7@00Dad000=C7@03001C7@0000800003Dad007oo01ioo`03001oo`00055oo`00JWoo0`001Woo00<0
07ooOol0Qgoo0P0000=C7@00Dad01E<M00@005<M0000009C7@03001C7E<M009C7@03001C7@000080
009C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@8000EC7@80009C7@<000EC7@03001oogoo
01eoo`80055oo`00Igoo0`00TGoo0P0015<M00<005<MDad00e<M0P001E<M00<005<MDad00`001U<M
00@005<M0000009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00AC7@@0009C7@03001C
7E<M00=C7@8001aoo`800003@@l00000051oo`00IGoo0P00TGoo0`0000=C7@00Dad015<M00<005<M
00000P0000=C7@00Dad015<M0`000e<M00<005<MDad00e<M0P001E<M00<005<MDad00`001E<M00<0
05<M00000P0000=C7@00Dad015<M00<005<M00000P0000=C7@00Ool067oo0`000d4?0P00D7oo001R
Ool3002@Ool30005Dad01000DaeC7E<M0`001E<M00<005<M00000P0000=C7@00Dad015<M00<005<M
00000P0000=C7@00Dad015<M0`000e<M00<005<MDad00U<M0P0015<M0P000e<M0`001E<M00<007oo
Ool04Woo10000T4?00L0044?@@m13`00Ool0001?Ool0061oo`8008moo`@000=C7@03001C7E<M009C
7@@0009C7@03001C7E<M00=C7@8000EC7@04001C7E<MDad30005Dad00`00Dad0000200000e<M001C
7@04Dad01000Dad000000U<M00@005<MDaeC7@D0009C7@03001C7E<M00=C7@80015oo`800003@@l0
044?00=13`0500113d4?@@l00002Ool00`00Oomoo`1<Ool005eoo`<008moo`800003Dad005<M00EC
7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad40002Dad00`00
DaeC7@03Dad20005Dad01000DaeC7E<M0`001E<M00H005<M000005<M0005Dad00`00Dad000020000
0e<M001oo`0>Ool20003@@l00`00@@m13`02@@l01000@@m13d4?0P0000=oo`00Ool0CGoo001KOol2
00000goo001oo`2=Ool20004Dad00`00DaeC7@03Dad20005Dad00`00DaeC7@030005Dad00`00Dad0
000200000e<M001C7@04Dad00`00Dad0000200000e<M001C7@04Dad40002Dad00`00DaeC7@03Dad2
00001E<M001C7E<M000015<M0P001E<M00<007ooOol02Woo0P0000=13`00@@l00T4?00<0044?@@l0
0T4?00@0044?@@m13`80009oo`03001oogoo04]oo`00F7oo0`0017oo00<007ooOol0R7oo0`0000=C
7@00Dad015<M00<005<M00000P0000=C7@00Dad015<M0`000e<M00<005<MDad00U<M0P001E<M00@0
05<MDaeC7@<000EC7@03001C7@0000800003Dad005<M00AC7@03001C7@0000800004Dad005<M0003
Dad01000Dad000000U<M00<005<MDad00U<M0P0027oo0`000d4?00D0044?@@m13`0000A13`040011
3d4?@@l20003Ool00`00Oomoo`1:Ool005Ioo`80091oo`8000EC7@04001C7E<MDad30005Dad00`00
Dad0000200000e<M001C7@04Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<005<MDad0
0e<M0P001E<M00<005<MDad00U<M0P001E<M0P000U<M0`001E<M00@005<M0000009C7@04001oogoo
Ool40002@@l01@00@@m13d4?00000d4?00<0044?@@l00T4?00@0044?@@m13`8000=oo`03001oogoo
04Yoo`00Dgoo0`00T7oo0P000U<M00<005<MDad00U<M10000U<M00<005<MDad00e<M0P001E<M00@0
05<MDaeC7@<000EC7@06001C7@00001C7@001E<M00<005<M00000P0000=C7@00Dad015<M00<005<M
00000P0000=C7@00Dad015<M10000U<M00<005<MDad00e<M0P001E<M0`0000=13`00@@l00d4?00D0
044?@@m13`0000=13`0300113d4?00913`0400113d4?@@l20004Ool00`00Oomoo`19Ool0055oo`80
091oo`<000EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad4
0002Dad00`00DaeC7@03Dad20004Dad00`00DaeC7@02Dad20005Dad01000DaeC7E<M0`001E<M00<0
05<M00000P0000=C7@00Dad015<M00<005<M00000P0000=C7@00Dad015<M0P000T4?00<0044?@@l0
0T4?00D0044?@@m13`0000=13`0300113d4?00913`0300113d4?00913`03001oogoo00=oo`03001o
ogoo04Qoo`00CWoo0`00SWoo10000U<M00<005<MDad00e<M0P001E<M00<005<MDad00`001E<M00<0
05<M00000P0000=C7@00Dad015<M00<005<M00000P0000=C7@00Dad015<M00@005<M0000009C7@03
001C7E<M009C7@@0009C7@03001C7E<M00=C7@8000AC7@8000=C7@<000EC7@03001C7@0000800005
Dad0044?@@l00004@@l01@00@@m13d4?00000d4?00<0044?@@l00T4?00<0044?@@l00T4?00<007oo
Ool00goo00<007ooOol0B7oo001;Ool3002>Ool300000e<M001C7@04Dad00`00Dad0000200000e<M
001C7@04Dad30003Dad00`00DaeC7@02Dad20005Dad01000DaeC7E<M0`001E<M00@005<MDaeC7@<0
00EC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@03Dad50003Dad0
1000DaeC7E<M0`001E<M00<0044?0000144?00D0044?@@m13`0000=13`0300113d4?00913`030011
3d4?00913`03001oogoo00Aoo`8004Qoo`00BGoo0P00Sgoo0P001E<M00@005<MDaeC7@<000EC7@03
001C7@0000800003Dad005<M00AC7@04001C7@000002Dad00`00DaeC7@02Dad40002Dad00`00DaeC
7@03Dad40002Dad00`00DaeC7@03Dad20005Dad00`00DaeC7@040004Dad00`00Dad0000200000e<M
001C7@04Dad40002Dad00`00DaeC7@03Dad30004@@l01@00@@m13d4?0000144?00D0044?@@m13`00
00A13`8000Aoo`03001oo`0004Qoo`00AWoo0`000Woo00<007ooOol0RWoo0P000U<M00<005<MDad0
0U<M10000e<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@<000EC7@04001C7@000002Dad00`00
DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad00`00Dad0000200000e<M001C7@04Dad30004
Dad00`00DaeC7@030002Dad01@00DaeC7@00Dad00`0000=C7@00Dad015<M00<005<M00000P0000=C
7@000000144?00D0044?@@m13`0000A13`0500113d4?@@l00004@@l20006Ool00`00Oomoo`16Ool0
04Aoo`8008moo`<000EC7@04001C7@000002Dad00`00DaeC7@03Dad01000Dad000000U<M00<005<M
Dad00U<M10000U<M00<005<MDad00e<M0P001E<M00<005<MDad00`001E<M00@005<MDaeC7@<000EC
7@03001C7@0000800003Dad005<M00AC7@<000=C7@05001C7E<M001C7@020005Dad01000DaeC7E<M
0`001E<M00<0044?@@l00T4?00D0044?@@m13`0000A13`0500113d4?@@l00004@@l20007Ool00`00
Oomoo`15Ool0045oo`<008eoo`@0009C7@03001C7E<M00=C7@8000EC7@04001C7E<MDad30005Dad0
1000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad015<M0`000e<M00<005<M
Dad00U<M10000U<M00<005<MDad00e<M0P001E<M00<005<M00000P0000=C7@00Dad015<M00H005<M
000005<M0005Dad40002Dad00`00DaeC7@03Dad20003@@l01@00@@m13d4?0000144?00D0044?@@m1
3`0000A13`8000Qoo`03001oogoo04Aoo`00?goo0P00SWoo0P000U<M00<005<MDad00U<M00<005<M
00000P0000=C7@00Dad015<M10000U<M00<005<MDad00e<M0P001E<M00<005<MDad00`001E<M00<0
05<M00000P0000=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C7@03001C7@0000800003
Dad005<M00AC7@8000EC7@04001C7E<MDad40003Dad00`00Dad0000200000e<M001C7@04Dad00`00
Dad0000200000e<M00113`02@@l01@00@@m13d4?0000144?00D0044?@@m13`0000A13`8000Qoo`03
001oogoo04Aoo`00?7oo0`00SWoo0P001E<M00<005<MDad00`001E<M00<005<M00000P0000=C7@00
Dad015<M00<005<M00000P0000=C7@00Dad015<M0`000e<M00<005<MDad00U<M0P001E<M00@005<M
DaeC7@<000EC7@03001C7E<M00@000AC7@03001C7@0000800003Dad005<M00AC7@@0009C7@8000=C
7@8000EC7@04001C7E<MDad30005Dad01000@@m13`000d4?00<0044?@@l00T4?00D0044?@@m13`00
00A13`8000Uoo`03001oogoo04=oo`00>Woo0P00SWoo0`0000=C7@00Dad015<M0`000e<M00<005<M
Dad00U<M0P001E<M00@005<MDaeC7@<000EC7@03001C7@0000800003Dad005<M00AC7@04001C7@00
0002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@03Dad30004Dad00`00DaeC7@030005Dad00`00
Dad0000200000e<M001C7@04Dad01000Dad000000U<M00<005<MDad00U<M10000e<M00@005<MDaeC
7@<00003@@l0044?00913`0300113d4?00913`0500113d4?@@l00004@@l2000:Ool00`00Oomoo`12
Ool003Moo`<008eoo`<000EC7@03001C7@0000800003Dad005<M00AC7@04001C7@000002Dad00`00
DaeC7@02Dad40002Dad00`00DaeC7@03Dad20005Dad01000DaeC7E<M0`001E<M00H005<M000005<M
0005Dad00`00Dad0000200000e<M001C7@04Dad30003Dad00`00DaeC7@02Dad20005Dad01000DaeC
7E<M0`001E<M00H005<M000005<M0005Dad40002Dad00`00@@l00003@@l00`00@@m13`02@@l00`00
@@m13`02@@l01000@@m13d4?0P002Woo00<007ooOol0@Woo000dOol30002Ool00`00Oomoo`28Ool3
0003Dad00`00DaeC7@02Dad20005Dad01000DaeC7E<M0`001E<M00@005<M0000009C7@03001C7E<M
009C7@03001C7@0000800003Dad005<M00AC7@@0009C7@03001C7E<M00=C7@8000AC7@04001C7E<M
Dad30005Dad00`00Dad0000200000e<M001C7@04Dad01P00Dad00000Dad000EC7@@00003Dad00000
00EC7@8000AC7@03001C7@0000800003Dad005<M00AC7@8000=13`0300113d4?00913`0300113d4?
00913`0700113d4?@@l004EA00002Woo00<007ooOol0@Goo000bOol2002=Ool300000e<M001C7@04
Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<005<MDad00e<M0P001E<M00<005<MDad0
0`001E<M00<005<M00000P0000=C7@00Dad015<M00<005<M00000P0000=C7@00Dad00e<M10000U<M
00<005<MDad00e<M0P001E<M00@005<MDaeC7@<000AC7@03001C7@0000800004Dad005<MDad20000
0e<M001C7@0300000e<M001C7@03Dad20005Dad01000DaeC7E<M0`000d4?00<0044?@@l00T4?00<0
044?@@l00T4?00L0044?@@m13`00AE40000:Ool00`00Oomoo`11Ool002moo`<008aoo`<000EC7@04
001C7E<MDad30005Dad01000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad0
15<M0`000e<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@<000EC7@04001C7@000002Dad00`00
DaeC7@02Dad00`00Dad0000200000e<M001C7@04Dad40002Dad00`00DaeC7@02Dad20004Dad30000
0e<M000000020005Dad01000Dad000000U<M00<005<MDad00U<M10000e<n00D0044?@@m13`0000=1
3`0300113d4?00913`0700113d4?@@l004EA00002goo00<007ooOol0@7oo000]Ool2002<Ool30003
Dad00`00DaeC7@02Dad40003Dad01000DaeC7E<M0`001E<M00<005<MDad00`001E<M00<005<M0000
0P0000=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@80
00EC7@03001C7E<M00<000EC7@03001C7@0000800003Dad005<M00AC7@04001C7@000002Dad40000
0e<M000000030002Dad01000DaeC7E<M0`001E<M00H005<M000005<n0005Dch20002@@l01@00@@m1
3d4?0000144?00L0044?@@m13`00AE40000<Ool00`00Oomoo`0oOol002Yoo`<008aoo`80009C7@03
001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad40002Dad00`00DaeC7@03Dad30003Dad0
0`00DaeC7@02Dad20005Dad01000DaeC7E<M0`001E<M00@005<M0000009C7@03001C7E<M009C7@03
001C7@0000800003Dad005<M00AC7@<000=C7@03001C7E<M009C7@8000EC7@04001C7E<MDad30002
Dad400001E<M000005<M00000e<M00<005<M00000`000e<M00@005<MDaeC7@<000AC?P03001C?P00
00800005Dah0044?@@l00003@@l00`00@@m13`02@@l01`00@@m13d4?0015D@0000aoo`03001oogoo
03moo`00:Goo0P00S7oo0P001E<M00<005<MDad00`001E<M00@005<M0000009C7@03001C7E<M009C
7@03001C7@0000800003Dad005<M00AC7@04001C7@000002Dad00`00DaeC7@02Dad40002Dad00`00
DaeC7@03Dad20005Dad00`00DaeC7@040004Dad00`00Dad0000200000e<M001C7@04Dad01000Dad0
00000U<M00<005<MDad00U<M10000U<M0`000U<M0`0015<M00<005<M00000P0000=C7@00Dad015<M
10000e<n00<005<nDch00`001E<N00<0044?00000d4?00<0044?@@l00T4?00L0044?@@m13`00AE40
000<Ool3000oOol002Uoo`03001oo`0008Qoo`<00003Dad005<M00AC7@<000=C7@03001C7E<M009C
7@8000EC7@03001C7E<M00<000EC7@04001C7E<MDad30005Dad01000Dad000000U<M00<005<MDad0
0U<M00<005<M00000P0000=C7@00Dad015<M0`0015<M00<005<MDad00`001E<M00@005<MDaeC7@<0
00EC7@07001C7@00001C7@00Dad00`0000=C7@0000000P000U<M00<005<MDad00U<M0P000U<M00D0
05<MDad005<M00<00003Dch005<n00AC?P<0009C7P03001C7U<N00=C7P<000=13`0300113d4?0091
3`0300113d4?00913`8000ioo`03001oogoo03eoo`00:Goo1000Q7oo0`001E<M00<005<M00000P00
00=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@@000=C
7@04001C7E<MDad30005Dad00`00DaeC7@040004Dad00`00Dad0000200000e<M001C7@04Dad30003
Dad00`00DaeC7@02Dad40003Dad01000DaeC7E<M0`000U<M0`0000IC7@00000005<M0005Dad01000
Dad000000U<M00D005<MDad005<M008000EC?P03001C?P0000800003Dah005<N00=C7P03001C7P00
0080009C?P0500113d4?@@l00004@@l00`00@@m13`02@@l2000>Ool00`00Oomoo`0mOol002Qoo`80
00=oo`03001oogoo07ioo`<000=C7@03001C7E<M009C7@8000EC7@04001C7E<MDad30005Dad01000
Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C7E<M
00=C7@<000AC7@03001C7E<M00<000EC7@03001C7@0000800003Dad005<M00AC7@06001C7@00001C
7@001E<M10000U<M0`000U<M0P001E<M00@005<MDaeC7@<000EC7@06001C7@00001C?P001E<n0P00
1E<N00<005<NDah00`001E<n0P000T4?00<0044?@@l00T4?00<0044?@@l00T4?00<004EA00003Woo
00<007ooOol0?7oo000XOol00`00Oomoo`03Ool00`00Oomoo`1jOol300000e<M001C7@04Dad01000
Dad000000U<M00<005<MDad00U<M10000U<M00<005<MDad00e<M0P001E<M00<005<MDad00`001E<M
00@005<M0000009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00AC7@<000=C7@03001C
7E<M009C7@8000EC7@04001C7E<MDad30004Dad00`00Dad00002000015<M001C7E<M0P0000=C7@00
Dad00P000U<M00<005<MDad00U<M10000e<M00@005<MDaeC7@<00006Dch005<nDch005<n0`0000=C
7P00Dah015<N0`000e<n00<005<n00000P0000=C?P00@@l00T4?00D0044?@@m13`0000A13`030015
D@0000moo`03001oogoo03]oo`002goo100000<8@WooOol00Woo00AJePQ2000icPEoo`04F]H8@P00
>Lh7Ool00`00Oomoo`04Ool00`00Oomoo`1fOol30005Dad01000DaeC7E<M0`001E<M00@005<M0000
009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00AC7@<0009C7@03001C7E<M00=C7@80
00EC7@03001C7E<M00<000EC7@03001C7@0000800003Dad005<M00AC7@06001C7@00001C7@001E<M
10000U<M00<005<MDad00U<M0P0015<M0`000U<M0`001E<M00H005<M000005<M0005Dad40003Dch0
0`00Dch000030005Dah00`00Dah0000200000e<n001C?P03Dch20005Dch01000@@m13`000d4?00<0
044?@@l00T4?00<004EA00003goo00<007ooOol0>goo000=Ool00`00Oomoo`03Ool01V<H6<IcW7>L
48ABU0=oo`06HaPHaW>LLi`@Q5:D1Woo00<007ooOol01Goo00<007ooOol0LWoo0`000e<M00<005<M
Dad00U<M10000e<M00@005<MDaeC7@<000EC7@03001C7E<M00<000EC7@03001C7@0000800003Dad0
05<M00=C7@03001C7@0000800003Dad005<M00AC7@<000=C7@03001C7E<M009C7@8000EC7@04001C
7E<MDad30004Dad00`00Dad0000200000e<M001C7@04Dad01000Dad000000U<M100000=C7@000000
0P000e<M00@005<MDaeC7@<000AC7@03001C7@0000800003Dch005<n00AC?P@0009C7P04001C7U<N
Dah30005Dch01000Dch000000U<n00@005<nDciC?P<00003@@l0044?00913`0300113d4?00913`03
0015D@00011oo`03001oogoo00]oo`800003249oogoo009oo`04F]H8@P00>LhTOol000eoo`03001o
ogoo00=oo`068@QBU7ooOomBU1S60goo00HQ25:DOomooe:D6<H6Ool00`00Oomoo`06Ool00`00Oomo
o`1_Ool20002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<005<M
Dad00e<M0`000e<M00<005<MDad00U<M0P001E<M00<005<MDad0100015<M00<005<M00000P0000=C
7@00Dad015<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C7E<M009C7@8000EC7@04
001C7E<MDad30002Dad400001E<M000005<M00001E<M10000e<M00<005<MDad00`001E<n00<005<n
00000P0000IC7P00DaiC7P00Dah40003Dch01000DciC?U<n0`0015<n10000e=O0P000d4?00<0044?
@@l00T4?00<004EA00004Goo00<007ooOol02goo00<007ooOol00Woo00IS61S6LiacW124DY@SOol0
0003Ool0000000D000Eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`04Ool20008Ool00`00Oomoo`1/Ool20005Dad00`00DaeC7@030005Dad01000Dad000000U<M
00<005<MDad00U<M00<005<M00000P0000=C7@00Dad015<M00@005<M0000009C7@03001C7E<M009C
7@<000AC7@03001C7E<M00<000EC7@04001C7E<MDad30005Dad01P00Dad00000Dad000EC7@04001C
7@000002Dad00`00DaeC7@02Dad40002Dad30002Dad30004Dad00`00Dad0000200000e<M001C7@04
Dad30003Dch01000DciC?U<n0`001E<N00H005<N000005<n0005Dch40003Dch01000Dch000000U=O
00@005=ODemCG`<000=13`0300113d4?00913`030015D@00015oo`03001oogoo00Moo`H000=oo`06
8@QBU7ooOomBU1S68goo000=Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol017oo00<007ooOol027oo00<007ooOol0J7oo0`0000=C7@00Dad015<M0`000e<M00<0
05<MDad00U<M0P001E<M00<005<MDad00`001E<M00@005<MDaeC7@<000EC7@04001C7@000002Dad0
0`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad40003Dad01000DaeC7E<M0`0015<M00@005<MDaeC
7@<000EC7@04001C7@000002Dad400000e<M000000020003Dad00`00DaeC7@030005Dad00`00Dad0
000200000e<n001C?P03Dch40003Dah01000DaiC7U<N0`0000IC?P00DciC?P00Dch300000e<n001C
?P04Dch20004Del40003Deh01000@@m13`000d4?0P0000=5D@00Ool04Goo00<007ooOol01Woo00Di
cU:DOomoo`0000Aoo`03001oogoo009oo`03001oogoo025oo`003Goo00<007ooOol00goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo06Aoo`@0
00AC7@03001C7@0000800003Dad005<M00AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad0
0`00DaeC7@02Dad40003Dad01000DaeC7E<M0`001E<M00H005<M000005<M0005Dad01000Dad00000
0U<M00<005<MDad00U<M10000U<M00<005<MDad00U<M10000e<M00@005<MDaeC7@<0009C7@@00005
Dad00000Dad00005Dad30003Dad00`00DaeC7@02Dad20005Dch01000Dch000000U<N00<005<NDah0
0U<N10000e<n00<005<n00000`001E<n00<005<n00000P000U=O00H005=O000005=N0005Deh70003
AE400`00Oomoo`0AOol00`00Oomoo`05Ool01G>L6<IcW7oo000017oo00<007ooOol00Woo00<007oo
Ool08Goo000=Ool00`00Oomoo`03Ool01R48DYAoogooDY@Q20=oo`068@QBU7ooOomBU2481Goo00<0
07ooOol02goo00<007ooOol0H7oo0`0015<M00<005<MDad00`001E<M00@005<MDaeC7@<000EC7@04
001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<005<M
Dad00e<M0P0015<M00@005<MDaeC7@<000EC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad0
00000U<M00<005<MDad00U<M10000e<M0P000U<M0`0015<M00<005<M00000P0000=C7@00Dad015<M
00H005<M000005<n0005Dch20005Dah01P00Dah00000Dch000EC?P@0009C?P04001C?U<nDch40003
Del30004Deh00`00Deh000020002Bil300000``00015D@03AE400`00Oomoo`0@Ool00`00Oomoo`06
Ool015:D<Haoo`0017oo00<007ooOol00Woo00<007ooOol08Goo000;Ool00`008@P00005Ool01V<H
6<IcW7>L6<IS60=oo`06HaPHaW>LLi`HaV<H1Goo00<007ooOol037oo00<007ooOol0GGoo0P000U<M
00<005<MDad00U<M0`000e<M00<005<MDad00U<M10000e<M00@005<MDaeC7@<000EC7@03001C7E<M
00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@03Dad40002
Dad00`00DaeC7@03Dad20005Dad00`00DaeC7@030005Dad01000Dad000000U<M00<005<M00001P00
0U<M00<005<MDad00U<M0P001E<M00@005<MDaeC7@<000AC?P03001C?P0000800003Dah005<N00AC
7P8000AC?P03001C?P0000800004Dch005<n0002Dch40003Del40003Deh00`00DeiCGP04000014^O
000000000TnO0`0014EA00<007ooOol04Goo00<007ooOol01Woo00<Q26<H000017oo00HQ25:DOomo
oe:D8@PSOol000]oo`03HaPYBP0000Ioo`04F]H8@PQ2HaP5Ool015[F2488@V<H1Woo0P003Woo00<0
07ooOol0FGoo0`001E<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC
7@02Dad40002Dad00`00DaeC7@03Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@040004Dad0
1000Dad000000U<M00<005<MDad00U<M00<005<M00000P0000=C7@00Dad015<M0`000e<M00@005<M
DaeC7@<000=C7@<00005Dad00000Dad00005Dad01000Dad000000U<M00<005<MDad00U<M10000e<n
00<005<nDch0100015<N00<005<N00000P000U<n00<005<nDch00`001E<n00@005<n0000009CG`03
001CG`0000800003Deh005=N00ACGP<0009;W`@00004Cil000000002AE400`00AE55D@02AE400`00
Oomoo`0AOol20007Ool00f]J8@P00004Ool01V<H6<IcW7>L6<IS62=oo`009goo00<007ooOol03Woo
0P00EWoo0`000e<M00<005<MDad00U<M0P001E<M00<005<MDad00`001E<M00@005<M0000009C7@03
001C7E<M009C7@03001C7@0000800003Dad005<M00AC7@<0009C7@03001C7E<M00=C7@<000AC7@03
001C7E<M00<000EC7@03001C7E<M00@000AC7@03001C7@0000800003Dad005<M00=C7@@0009C7@@0
009C7@8000AC7@04001C7E<MDad30005Dad01P00Dad00000Dch000EC?P<000AC7P03001C7U<N00<0
00EC?P<000=C?P04001C?U<nDch3000015=O001CGe=O0P001E=N00<005=N00000P0000=;W`000000
0P000TnO100014EA00<004EAAE400TEA00<007ooOol047oo00<007oo000027oo00<icPQ2Ool017oo
00AJePQ2249S62Aoo`009goo00<007ooOol047oo00<007ooOol0D7oo0`0000=C7@00Dad015<M00@0
05<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@8000EC7@03001C7E<M00<000EC
7@03001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad005<M00AC7@<0009C7@03001C
7E<M00=C7@<000AC7@03001C7E<M00<000EC7@04001C7@000002Dad00`00Dad0000300001U<M0000
0000Dad000AC7@@000=C7@04001C7E<MDad30004Dch00`00Dch0000200000e<N001C7P04Dah30003
Dch00`00Dch0000200000e<n001C?P03Dch40003Del01000Del000000U=N00@005=NDeiCGP@00003
Bil00000009?W`@000=5D@030015DDEA0095D@030015DDEA0095D@03001oogoo01=oo`03001oogoo
03Aoo`009goo00<007ooOol04Goo00<007ooOol0C7oo0`001E<M00@005<MDaeC7@<000EC7@06001C
7@00001C7@001E<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@8000EC
7@03001C7E<M00<000EC7@03001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad005<M
00AC7@<000=C7@04001C7E<MDad30003Dad30002Dad30005Dad01000Dad000000U<M00<005<MDad0
0U<M10000e<n00<005<nDch00`001E<N00<005<N00000P000U<n00<005<nDch00`001E<n00@005<n
0000009CG`04001CGe=ODel40003Deh40002Bil400000dnO00000003AE401@00AE55DDEA000014EA
00<004EAAE400TEA00<007ooOol057oo00<007ooOol0<goo000VOol00`00Oomoo`0COol00`00Oomo
o`18Ool30003Dad00`00DaeC7@02Dad40003Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<000EC
7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<0
05<MDad00U<M0P001E<M00<005<MDad0100015<M00<005<M00000P0000=C7@00Dad00e<M10000U<M
10000U<M0`000e<M00@005<MDaeC7@<000EC7@06001C7@00001C?P001E<n0`000e<N00@005<NDaiC
7P<000EC?P<000=C?P04001C?U<nDch30004Del40003Deh40002Bil40003Cil30004AE401@00AE55
DDEA00001DEA00D004EAAE55D@0001Ioo`03001oogoo03=oo`009Woo00<007ooOol057oo00<007oo
Ool0AGoo0P000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@@0009C7@03001C
7E<M009C7@@000=C7@04001C7E<MDad30005Dad00`00DaeC7@030005Dad01000Dad000000U<M00<0
05<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC7@04001C
7@000002Dad00`00Dad0000300001U<M00000000Dad000AC7@@000=C7@04001C7E<MDad30004Dch0
0`00Dch0000200000e<N001C7P03Dah40003Dch00`00Dch0000200000e<n001C?P03Dch40003Del0
1000Del000000U=N00@005=NDeiCGP@00003Bil00000009?W`03001?W`0000800095D@030015DDEA
0095D@050015DDEAAE400005AE401@00AE55DDEA00005goo00<007ooOol0<Woo000VOol2000FOol0
0`00Oomoo`11Ool30005Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<MDad00U<M00@0
05<M0000009C7@03001C7E<M009C7@@0009C7@03001C7E<M00=C7@<000=C7@04001C7E<MDad30005
Dad00`00DaeC7@030005Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M
0P0015<M0P000U<M100015<M00@005<M0000009C7@03001C7E<M009C7@@000=C?P03001C?U<n00@0
00AC7P04001C7P000003Dch00`00DciC?P030005Dch01000Dch000000U=O00@005=ODemCG`<000AC
GP@0009;W`@0009?W`<00003AE4004EA00=5D@050015DDEAAE400004AE400`00AE55D@02AE400`00
AE55D@02AE400`00Oomoo`0DOol00`00Oomoo`0bOol002Ioo`03001oogoo01Ioo`03001oogoo03eo
o`<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC7@03001C7E<M00@000AC7@04001C
7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C7@03Dad40002Dad00`00DaeC7@03
Dad30003Dad01000DaeC7E<M0`001E<M00H005<M000005<M0005Dad01`00Dad00000Dad005<M00<0
0004Dad000000004Dad00`00DaeC7@030005Dad01P00Dad00000Dch000EC?P<000AC7P03001C7U<N
00<000EC?P<000=C?P04001C?U<nDch30004Del40003Deh01000Deh000000T^O10000TnO100014EA
00<004EAAE400TEA00<004EAAE400TEA00D004EAAE55D@0000A5D@030015DDEA0095D@03001oogoo
01=oo`<003=oo`009Woo00<007ooOol05goo00<007ooOol0>Woo0P000U<M00<005<MDad00U<M00@0
05<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC
7@03001C7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad00`00Dad0000200000e<M001C
7@03Dad40003Dad01000DaeC7E<M0`0015<M00@005<MDaeC7@<0009C7@<00006Dad00000001C7@00
1E<M0`000e<M00@005<MDaeC7@<000AC?P03001C?P0000800003Dah005<N00AC7P<000=C?P03001C
?P0000800003Dch005<n00=C?P@000=CG`04001CG`000002Deh01000DeiCGU=N100000=;W`000000
0TnO00<004nO00000`0000=5D@00AE400dEA00<004EAAE400TEA00<004EAAE400TEA00D004EAAE55
D@0000A5D@030015DDEA0095D@03001oogoo00moo`@00095D080039oo`009Woo00<007ooOol067oo
00<007ooOol0=Woo0`001E<M00<005<MDad00`001E<M00@005<M0000009C7@03001C7E<M009C7@04
001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005
Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<MDad00U<M10000U<M00<005<MDad00U<M
10000U<M0`0000=C7@0000000P0015<M00<005<M00000P0000=C7@00Dad00e<M10000e<n00<005<n
Dch0100015<N00<005<N00000P000U<n00<005<nDch00`001E<n00@005<n0000009CG`04001CGe=O
Del30004Deh40002Bil40002Cil300001dEA0015DDEA0015D@0000=5D@030015DDEA0095D@030015
DDEA0095D@050015DDEAAE400004AE400`00AE55D@02AE400`00Oomoo`0=Ool200000dE@0015D003
AE02000bOol002Eoo`03001oogoo01Yoo`03001oogoo035oo`@0009C7@03001C7E<M00=C7@<000=C
7@04001C7E<MDad30005Dad00`00DaeC7@030005Dad01000Dad000000U<M00<005<MDad00U<M00@0
05<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00@000AC
7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M100000AC7@00000000AC7@03001C
7E<M00@000AC7@04001C7@000002Dch00`00DciC?P02Dch30004Dah00`00DaiC7P030005Dch30003
Dch01000DciC?U<n0`0015=O10000e=N00@005=N0000009;W`@000=?W`<000E5D@050015D@00AE40
0004AE401@00AE55DDEA000014EA00D004EAAE55D@0000A5D@030015DDEA0095D@03001oogoo00Yo
o`<000=5D0030015D4E@0095D003001oo`00035oo`009Goo0P0077oo00<007ooOol0;Woo0P000U<M
00<005<MDad00U<M00<005<M00000P0000=C7@00Dad00e<M10000U<M00<005<MDad00e<M0`000e<M
00@005<MDaeC7@<000EC7@03001C7E<M00<000EC7@06001C7@00001C7@001E<M00H005<M000005<M
0005Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@030002Dad400001E<M000005<M00001E<M
0`0015<M00<005<MDad00`001E<n00H005<n000005<N0005Dah30003Dch00`00Dch0000200000e<n
001C?P03Dch40003Del01000Del000000U=N00@005=NDeiCGP@00003Bil00000009?W`03001?W`00
008000=5D@030015DDEA0095D@030015DDEA008000A5D@050015DDEAAE400004AE401@00AE55DDEA
000014EA00<004EAAE400TEA00<007ooOol01Woo10000TE@00D004E@AE15D00000A5D0800003Ool0
07oo02moo`009Goo00<007ooOol077oo00<007ooOol0:Woo0`001E<M00<005<MDad0100015<M00@0
05<M0000009C7@03001C7E<M009C7@03001C7@0000800003Dad005<M00=C7@@0009C7@03001C7E<M
00=C7@<000=C7@04001C7E<MDad30004Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C7@00
Dad015<M0`000U<M00<005<MDad00e<M0`000U<M0`000U<M0`0015<M00<005<M00000P0000=C7@00
Dad015<M0`000e<n00@005<nDciC?P<000AC7P03001C7P000080009C?P03001C?U<n00<000EC?P04
001C?P000002Del01000DemCGe=O0`0015=N10000T^O10000TnO0`0000=5D@00AE400dEA00<004EA
AE400TEA00D004EAAE55D@0000A5D@050015DDEAAE400004AE401@00AE55DDEA000014EA00<004EA
AE400TEA00<007ooOol00goo0`000TE@00D004E@AE15D00000=5D0030015D4E@0095D0800003Ool0
000002moo`009Goo00<007ooOol07Goo00<007ooOol09Woo0`000e<M00<005<MDad00U<M0`0015<M
00<005<MDad00`001E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@03001C
7@0000800003Dad005<M00=C7@@0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00@000AC7@03
001C7@0000800003Dad005<M00=C7@03001C7@0000800003Dad005<M00800003Dad00000008000=C
7@03001C7E<M00@000AC7@03001C7@0000800003Dch005<n00=C?P@000=C7P03001C7U<N00<000EC
?P<000=C?P04001C?U<nDch30004Del40003Deh01000Deh000000T^O10000TnO1@0014EA00D004EA
AE55D@0000A5D@040015DDEAAE420003AE401@00AE55DDEA000014EA00D004EAAE55D@0000E5D@05
0015DDEAAE400003Ool200000dE@0015D002AE001@00AE15D4E@00000dE@00<004E@AE000TE@0P00
00=oo`000000;goo000UOol00`00Oomoo`0NOol2000TOol20002Dad00`00DaeC7@02Dad01000Dad0
00000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad00`001E<M00<0
05<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02
Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@040002Dad300000e<M00000002Dad00`00DaeC
7@02Dad30004Dad00`00DaeC7@030005Dch01P00Dch00000Dah000EC7P<000=C?P03001C?P000080
0003Dch005<n00=C?P@000=CG`04001CG`000003Deh00`00DeiCGP0400000d^O00000002Cil50004
AE401@00AE55DDEA00000dEA00<004EAAE400TEA00@004EAAE55D@8000=5D@050015DDEAAE400004
AE401@00AE55DDEA00001DEA00<004EAAE400TEA0`000dE@00D004E@AE15D00000=5D0050015D4E@
AE000005AE001@00Oomoogoo0000;Woo000UOol00`00Oomoo`0POol00`00Oomoo`0NOol30005Dad0
0`00DaeC7@040004Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M
009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000EC7@03001C7E<M00@000AC7@04
001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30003Dad3000015<M00000000
1E<M00H005<M000005<M0005Dad30003Dch01000DciC?U<n0`0015<N00<005<N00000P000U<n00<0
05<nDch0100015<n00@005<n000000=CG`03001CGe=O00<000ECGP<0009;W`@00004Cil000000003
AE400`00AE55D@02AE401@00AE55DDEA00000dEA00<004EAAE400TEA00L004EAAE55D@00AE400002
AE401@00AE55DDEA000014EA00<004EAAE400TEA00<004EAAE400TEA00<004EAAE400TEA00<004E@
00000dE@00D004E@AE15D00000=5D0030015D4E@0095D0030015D4E@0095D005001oogooOol0000^
Ool002Aoo`03001oogoo029oo`03001oogoo01Yoo`<000=C7@03001C7E<M009C7@<000AC7@03001C
7E<M00<000EC7@03001C7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad00000
0U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad00`001E<M00H005<M
000005<M0005Dad01`00Dad00000Dad005<M00<00004Dad000000003Dad01000DaeC7E<M0`0015<M
00<005<M00000P0000=C?P00Dch00e<n10000e<N00<005<NDah0100015<n0`0015<n00<005<nDch0
0`001E=O0`000e=N00<005=N00000P000T^O0`000TnO0`000TEA00D004EAAE55D@0000A5D@050015
DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA00000TEA00<004EA000014EA00<004EAAE40
0TEA00D004EAAE55D@0000A5D@030015DDEA0095D@030015D00000=5D0050015D4E@AE000003AE00
0`00AE15D002AE000`00AE15D002AE000`00Oomoo`02Ool00`00Oomoo`0[Ool002Aoo`@0029oo`03
001oogoo01Moo`80009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad0
0`00DaeC7@02Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@040004Dad01000Dad000000U<M
00<005<MDad00U<M00H005<M000005<M0005Dad30003Dad01000DaeC7E<M0`0015<M00@005<MDaeC
7@<0009C7@<00006Dad00000001C7@0015<M10000e<M00<005<MDad0100015<n00@005<n0000009C
7P03001C7U<N009C7P<000AC?P06001C?P00001C?P001E<n0`000e=O00<005=O00000P000U=N00<0
05=NDeh0100000A;W`000000009?W`@000A5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA
00<004EAAE400TEA00D004EAAE55D@000095D@030015D@0000A5D@030015DDEA0095D@050015DDEA
AE400004AE400`00AE55D@02AE400`00AE000003AE001@00AE15D4E@000014E@00D004E@AE15D000
00A5D003001oogoo00=oo`03001oogoo02Yoo`0097oo00<007ooOol097oo00<007ooOol04goo0`00
1E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005Dad00`00DaeC7@030004
Dad00`00Dad0000200000e<M001C7@03Dad40002Dad00`00DaeC7@02Dad40002Dad300000e<M0000
00020004Dad01000Dad000000U<M00<005<MDad00U<M0`0015<n00<005<nDch00`001E<N00@005<N
0000009C?P04001C?U<nDch30004Dch00`00Dch000020002Del00`00DemCG`030005Deh30002Bil4
000014nO000000000dEA00<004EAAE400TEA00D004EAAE55D@0000A5D@050015DDEAAE400003AE40
0`00AE55D@02AE401@00AE55DDEA00000dEA0P0014EA00<004EAAE400TEA00D004EAAE55D@0000A5
D@030015DDEA0095D@030015D00000=5D0030015D4E@0095D0050015D4E@AE000003AE000`00AE15
D002AE020004Ool00`00Oomoo`0ZOol002Aoo`03001oogoo02Eoo`03001oogoo00moo`<000=C7@03
001C7E<M009C7@<000AC7@03001C7E<M00<000EC7@03001C7E<M00@000AC7@06001C7@00001C7@00
1E<M00H005<M000005<M0005Dad30002Dad00`00DaeC7@03Dad30003Dad00`00DaeC7@040004Dad0
1000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@@00004Dad000000004Dad00`00DaeC
7@040004Dad01000Dad000000U<n00<005<nDch00U<n0`000e<N00@005<NDaiC7P<000AC?P@000=C
?P03001C?U<n00@000ACG`<000=CGP03001CGP000080009;W`<0009?W`<00095D@050015DDEAAE40
0004AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@030015DDEA0095D@030015DDEA0095
D@040015DDEAAE420003AE400`00AE55D@02AE401@00AE55DDEA000014EA00<004EAAE400TEA00<0
04E@00000dE@00<004E@AE000TE@00D004E@AE15D00000=5D0030015D4E@0095D08000Eoo`03001o
ogoo02Uoo`003Woo00I:DPQ200000248Li`4Ool015[F248003W>27oo00<007ooOol09Woo00<007oo
Ool037oo0P000U<M00<005<MDad00U<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C
7E<M009C7@<000AC7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M
001C7@03Dad00`00Dad0000200000e<M001C7@03Dad30004Dad00`00DaeC7@040004Dad00`00DaeC
7@0400000e<M0000000200000e<M00000002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005
Dch01P00Dch00000Dah000AC7P@000=C?P04001C?P000002Dch00`00DciC?P02Dch30004Del01000
Del000000U=N00<005=NDeh01@0000=;W`0000000TnO0`0000=5D@00AE400TEA00D004EAAE55D@00
00A5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00<004EAAE400dEA00D004EAAE55D@00
00A5D@050015DDEAAE400004AE401@00AE55DDEA000014EA00<004EAAE400TEA00<004E@000014E@
00D004E@AE15D00000=5D0050015D4E@AE000004AE020006Ool00`00Oomoo`0XOol000ioo`062492
47ooOolicR480goo00IS61S6LiacW124DY@7Ool00`00Oomoo`0WOol00`00Oomoo`08Ool30005Dad0
0`00DaeC7@040004Dad01P00Dad00000Dad000EC7@06001C7@00001C7@001E<M0`000U<M00<005<M
Dad00U<M10000e<M00<005<MDad0100015<M00<005<MDad0100015<M00@005<M0000009C7@03001C
7E<M009C7@<000AC7@03001C7E<M00@000=C7@80009C7@<000EC7@06001C7@00001C7@001E<M0`00
0e<n00@005<nDciC?P<000AC7P04001C7P000003Dch00`00DciC?P030005Dch01000Dch000000U=O
00@005=ODemCG`<000ACGP<000=;W`@00003Cil0000000A5D@050015DDEAAE400003AE400`00AE55
D@02AE401@00AE55DDEA000014EA00D004EAAE55D@0000A5D@030015DDEA0095D@050015DDEAAE40
0004AE401@00AE55DDEA000014EA00D004EAAE55D@0000A5D@030015DDEA0095D@030015D00000A5
D0050015D4E@AE000003AE001@00AE15D4E@000014E@0P001Woo00<007ooOol0:7oo000COol01P00
Oomoogoo8@QBU09oo`03DY@HaWoo00Eoo`03001oogoo02Uoo`03001oogoo00Aoo`<000=C7@03001C
7E<M009C7@<000AC7@03001C7E<M00<000AC7@04001C7E<MDad30004Dad00`00Dad0000200000e<M
001C7@03Dad01000Dad000000U<M00<005<MDad00U<M0`0015<M00<005<MDad0100015<M00<005<M
Dad0100015<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C7@0000800004Dad00000
0003Dad01000DaeC7E<M0`0015<M00<005<M00000P0000=C?P00Dch00e<n10000e<N00<005<NDah0
0`001E<n0`000e<n00@005<nDciC?P@0009CG`D000=CGP05001CGP00001;W`050002Cil300000dEA
0015D@03AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EAAE55D@0000A5D@050015DDEA
AE400004AE400`00AE55D@02AE401@00AE55DDEA000014EA0P000TEA00<004EAAE400TEA00D004EA
AE55D@0000E5D@030015DDEA0095D@030015D00000=5D0050015D4E@AE000003AE001@00AE15D4E@
000014E@0P001goo00<007ooOol09goo0005Ool70006Ool00g>L001oo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool3000ZOol01000Oomoogoo0P000U<M00<005<MDad00U<M00@005<M0000009C7@03
001C7E<M009C7@<0009C7@03001C7E<M009C7@@000=C7@03001C7E<M00<000EC7@03001C7E<M00@0
00AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC
7@030005Dad01P00Dad00000Dad0009C7@<00006Dad00000001C7@0015<M10000e<M00<005<MDad0
100015<n00@005<n0000009C7P03001C7U<N009C7P<000=C?P03001C?P0000800003Dch005<n00=C
?P@000=CG`<000=CGP04001CGU=NDeh60003Cil50003AE400`00AE55D@02AE401@00AE55DDEA0000
0dEA00<004EAAE400TEA00<004EAAE400TEA00D004EAAE55D@0000A5D@050015DDEAAE400004AE40
1@00AE55DDEA000014EA00D004EA0015D@0000A5D@050015DDEAAE400005AE400`00AE55D@02AE40
0`00AE000003AE001@00AE15D4E@00000dE@00D004E@AE15D00000A5D08000Qoo`03001oogoo02Io
o`003Woo00H8@TYBOomoocW><H`3Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool3
0005Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@04001C7@000002Dad00`00DaeC7@02
Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<M
Dad00U<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@04001C7E<MDad30003Dad300000e<M
000000020004Dad01000Dad000000U<M00<005<MDad00U<M0`0015<n00<005<nDch00`001E<N00@0
05<N0000009C?P03001C?U<n00@000AC?P04001C?P000003Del01000Del000000U=N00<005=NDeh0
1@0000=;W`0000000TnO00<004nO00000P000dEA00D004EAAE55D@0000A5D@050015DDEAAE400003
AE400`00AE55D@03AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@030015DDEA0095D@05
0015DDEAAE400004AE400`00AE55D@020004AE400`00AE55D@02AE400`00AE55D@02AE400`00AE55
D@02AE400`00AE000003AE001@00AE15D4E@00000dE@00D004E@AE15D00000A5D0030019LP0000Mo
o`8002Moo`003Woo00D001240000036<00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
02Qoo`<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@03001C7E<M00@000AC7@04
001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`0015<M00<005<M
Dad00`001E<M00<005<MDad00`001E<M00H005<M000005<M0004Dad40003Dad70004Dad00`00DaeC
7@040004Dad01P00Dad00000Dch000EC?P<000=C7P04001C7U<NDah30004Dch30004Dch00`00DciC
?P040003Del30004Deh30003Bil40002Cil30002AE401@00AE55DDEA000014EA00D004EAAE55D@00
00=5D@050015DDEAAE400005AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@030015DDEA
0095D@050015DDEAAE400004AE400`00AE55D@020005AE401@00AE55DDEA000014EA00<004EAAE40
0`0000=5D000AE000TE@00D004E@AE15D00000=5D0050015D4E@AE000005AE020007Ool2000WOol0
00ioo`03001oogoo00Ioo`068@QBU7ooOomBU2481Woo00<007ooOol09Woo0P000U<M00<005<MDad0
0U<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00@0
00AC7@03001C7E<M00@000AC7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@02
Dad30003Dad01000DaeC7E<M0`0015<M00@005<M0000009C7@03001C7@0000D000AC7@03001C7E<M
00@000AC7@03001C7E<M00<000AC?P03001C?P000080009C7P03001C7U<N00D000=C?P06001C?P00
001C?P001E<n0`000e=O10000e=N00@005=N0000009;W`@000=?W`<00003AE4004EA0095D@050015
DDEAAE400004AE401@00AE55DDEA00000dEA00<004EAAE400TEA00<004EAAE400TEA00D004EAAE55
D@0000A5D@050015DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA000014EA00D004EAAE55
D@0000E5D@050015DDEAAE400003AE440002BI800`00AE000003AE001@00AE15D4E@00000dE@00<0
04E@AE000TE@00<004E@AE000TE@0P0027oo00<007ooOol09Goo000>Ool00`00Oomoo`06Ool01V<H
6<IcW7>L6<IS60Ioo`03001oogoo02=oo`@000AC7@03001C7E<M00@000AC7@06001C7@00001C7@00
15<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad0100015<M00<005<MDad0100015<M00H0
05<M000005<M0005Dad01P00Dad00000Dad000AC7@@000=C7@03001C7E<M00@0009C7@<00003Dad0
0000009C7@03001C7E<M009C7@<0009C7@03001C7E<M00=C7@<000=C?P03001C?U<n00@000AC7P<0
00AC?P03001C?U<n00<000AC?P03001C?P000080009CG`04001CG`000003Deh00`00DeiCGP040000
0d^O00000002Cil00`00Cil000030003AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@03
0015DDEA0095D@050015DDEAAE400004AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@03
0015DDEA0095D@050015DDEAAE400004AE400`00AE55D@02AE400`00AE55D@02AE401000AE55DDEA
100000=9TP00BI800dVB00<004E@00000dE@00D004E@AE15D00000=5D0030015D4E@0095D0030015
D4E@0095D08000Uoo`03001oogoo02Aoo`003Woo1@001Goo00AJePQ2249S60Moo`80025oo`<000AC
7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad01000
Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`0015<M00<005<MDad00`0015<M
00@005<MDaeC7@<000AC7@04001C7@000002Dad00`00DaeC7@02Dad30004Dad2000015<M00000000
1E<M00H005<M000005<M0004Dad00`00Dad000020002Dch00`00DciC?P040004Dah01P00Dah00000
Dch000EC?P<000=C?P03001C?U<n00D0009CG`<000ECGP<0009;W`@0009?W`<000=5D@050015DDEA
AE400004AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EAAE55D@0000=5D@030015DDEA
0095D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EAAE55D@00
00E5D@050015DDEAAE400004AE400`00AE4000020004BI800`00BI99TP02BI800`00AE000003AE00
1@00AE15D4E@000014E@00D004E@AE15D00000A5D08000Yoo`03001oogoo02=oo`008Woo00<007oo
Ool07goo0P000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad00`00
1E<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@050003Dad00`00DaeC7@040004Dad01000Dad000000U<M00<0
05<M00001@000e<M00@005<MDaeC7@<000AC7@03001C7E<M00@000AC?P<000AC7P03001C7U<N00<0
00AC?P03001C?P000080009C?P03001C?U<n00@000ACG`<000=CGP03001CGP000080009;W`<0009?
W`@00003AE4004EA00=5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00<004EAAE400TEA
00D004EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400004AE401@00AE55DDEA00000dEA
00<004EAAE400TEA00D004EAAE55D@0000E5D@040015DDEAAE420002AE430002BI800`00BI99TP02
BI800`00BI99TP03BI820003AE000`00AE15D002AE001@00AE15D4E@00000dE@00<004E@AE000TE@
0P002Woo00<007ooOol08goo000ROol00`00Oomoo`0LOol40004Dad01000Dad000000U<M00<005<M
Dad00U<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040004
Dad00`00DaeC7@030005Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M009C7@<000AC7@03
001C7E<M00<000=C7@<00005Dad00000Dad00004Dad40003Dad00`00DaeC7@040004Dch01P00Dch0
0000Dah000EC7P<000=C?P03001C?U<n00@000AC?P<000ACG`04001CG`000002Deh00`00DeiCGP04
000014^O000000000TnO0`0000=5D@00AE400TEA00<004EAAE400TEA00D004EAAE55D@0000A5D@05
0015DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EA
AE55D@0000A5D@050015DDEAAE400003AE400`00AE55D@02AE400`00AE55D@02AE400`00AE55D@02
AE401000AE55DDEA100000=9TP00BI800TVB00<004VBBI800dVB00<004VBBI800TVB0P000dE@00<0
04E@AE000TE@00D004E@AE15D00000=5D0030015D4E@0095D08000]oo`03001oogoo029oo`008Woo
00<007ooOol067oo100015<M00<005<MDad0100015<M00<005<MDad00`0015<M00@005<M0000009C
7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad0
1000DaeC7E<M0`0015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC
7@02Dad30003Dad3000015<M0000000015<M00@005<M0000009C7@03001C7E<M009C7@<000AC?P03
001C?U<n00<000AC7P03001C7P000080009C?P03001C?U<n00@000AC?P04001C?P000002Del01000
DemCGe=O0`0015=N0`000T^O1@0000A?W`00000000=5D@050015DDEAAE400004AE401@00AE55DDEA
000014EA00D004EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400003AE400`00AE55D@02
AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@030015DDEA00=5D@050015DDEAAE400004
AE400`00AE4000020002BI800`00BI800003BI800`00BI99TP03BI800`00BI99TP02BI820003AE00
0`00AE15D002AE001@00AE15D4E@00000dE@00<004E@AE000TE@00<004Ub00002goo00<007ooOol0
8Goo000ROol00`00Oomoo`0EOol30003Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad0
0`00DaeC7@040004Dad00`00DaeC7@040004Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M
00<005<MDad00U<M10000e<M00<005<MDad0100015<M00<005<MDad0100015<M00L005<M000005<M
001C7@070003Dad00`00DaeC7@040004Dad01000Dad000000U<n00<005<nDch00U<n0`000e<N00<0
05<NDah0100015<n0`0015<n00<005<nDch00`0015=O10000e=N00D005=N000004^O00@000=?W`<0
0095D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EAAE55D@00
00=5D@030015DDEA0095D@050015DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA000014EA
00D004EAAE55D@0000A5D@030015DDEA0095D@050015DDEAAE400003AE430002BI801P00BI99TP00
BI8000A9TP030019TTVB0099TP030019TTVB0099TP8000=5D0030015D4E@0095D0050015D4E@AE00
0003AE000`00AE15D002AE000`00BG80000;Ool00`00Oomoo`0QOol0029oo`03001oogoo01=oo`80
009C7@03001C7E<M009C7@04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad3
0004Dad00`00DaeC7@040004Dad00`00DaeC7@040004Dad01P00Dad00000Dad000AC7@04001C7@00
0002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040004Dad00`00DaeC7@030002Dad300000e<M
00000002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@030005Dch01P00Dch00000Dah000AC7P<0
00AC?P06001C?P00001C?P001E<n0`000e=O00@005=O000000=CGP03001CGU=N00H000=?W`@00003
AE4004EA0095D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EA
AE55D@0000=5D@030015DDEA0095D@050015DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA
000014EA00D004EAAE55D@0000A5D@030015DDEA0095D@040015DDEAAE4400000dVB0019TP02BI80
1`00BI99TTVB0019TP0000=9TP030019TTVB0099TP030019TTVB0099TP8000=5D0030015D4E@0095
D0050015D4E@AE000003AE000`00AE15D002AE000`00BG80000<Ool00`00Oomoo`0POol0025oo`<0
015oo`<000EC7@03001C7E<M00@000AC7@04001C7@000002Dad01P00DaeC7E<M001C7@80009C7@03
001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<000AC7@03001C7E<M00@0
00AC7@04001C7@000002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040002Dad300000e<M0000
00020004Dad01000Dad000000U<M00<005<MDad00U<M0`000e<n00@005<nDciC?P<000AC7P04001C
7P000003Dch00`00DciC?P030004Dch00`00Dch000020002Del00`00DemCG`040003Deh400000d^O
00000002Cil01P00Cil00000AE4000=5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00D0
04EAAE55D@0000A5D@050015DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA00000dEA00<0
04EAAE400TEA00D004EAAE55D@0000A5D@030015DDEA0095D@050015DDEAAE400004AE400`00AE40
00020004BI801@00BI99TTVB000014VB0P000dVB00<004VBBI800TVB00<004VBBI800TVB0P0014E@
00D004E@AE15D00000=5D0050015D4E@AE000004AE000`00BG80000=Ool00`00Oomoo`0OOol0025o
o`03001oogoo00ioo`<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00@000AC7@03001C7E<M
00<000AC7@04001C7@000002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`00
0e<M00<005<MDad0100015<M00<005<MDad0100015<M00H005<M000005<M0005Dad30002Dad40000
15<M0000000015<M00<005<MDad0100015<M00H005<M000005<n0004Dch40003Dah00`00DaiC7P04
0004Dch30003Dch00`00DciC?P050002Del40003Deh40002Bil40002Cil30003AE401@00AE55DDEA
00000dEA00<004EAAE400TEA00D004EAAE55D@0000=5D@050015DDEAAE400004AE401@00AE55DDEA
00000dEA00<004EAAE400TEA00D004EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400005
AE401@00AE55DDEA00000dEA00<004EAAE4010000TVB00<004VBBI800TVB00<004VBBI800TVB00<0
04VBBI800TVB00D004VBBI99TP0000A9TP030019TTVB0099TP8000A5D0050015D4E@AE000003AE00
1@00AE15D4E@000014E@00<004Ub00003Goo00<007ooOol07goo000QOol00`00Oomoo`0<Ool20002
Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`0015<M00<005<MDad010000e<M
00<005<MDad0100015<M00<005<MDad0100015<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@02Dad30004Dad00`00DaeC7@030004Dad00`00Dad00002000015<M001C7E<M0`0000=C7@000000
0e<M00<005<MDad0100015<M00<005<MDad00`0015<n00@005<n000000=C7P03001C7U<N00@000AC
?P04001C?P000002Dch00`00DciC?P040004Del30003Deh01000Deh000000d^O0`000TnO10000TEA
00D004EAAE55D@0000=5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00D004EAAE55D@00
00A5D@050015DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA00000dEA00<004EAAE400TEA
00<004EAAE400TEA00<004EAAE400TEA00D004EAAE55D@000095D@@00099TP050019TTVBBI800005
BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP030019TTVB00=9TP8000=5D0050015D4E@
AE000003AE001@00AE15D4E@00001DE@0P003Woo0P007goo000QOol00`00Oomoo`0:Ool30004Dad0
0`00DaeC7@040004Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<005<MDad00U<M0`00
15<M00<005<MDad0100015<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@04
001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad300000e<M000000020004
Dad30003Dad01000DaeC7E<M10000e<n00<005<nDch0100015<N0`000e<n00@005<nDciC?P<000AC
?P<000ACG`04001CG`000002Deh00`00DeiCGP0500000d^O00000002Cil30002AE401@00AE55DDEA
00000dEA00D004EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400003AE401@00AE55DDEA
000014EA00D004EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400003AE400`00AE55D@03
AE401@00AE55DDEA000014EA00@004EAAE55D@<00003BI8004VB00=9TP050019TTVBBI800005BI80
1@00BI99TTVB000014VB0P000TVB00<004VBBI800dVB00<004VBBI800TVB0P000dE@00D004E@AE15
D00000=5D0030015D4E@0095D0030015D4E@0095D0030019LP0000eoo`8001moo`008Goo00<007oo
Ool01goo0`000e<M00<005<MDad0100015<M00<005<MDad0100015<M00H005<M000005<M0004Dad0
1000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad01000
15<M00<005<MDad0100015<M00H005<M000005<M0004Dad30004Dad70004Dad01P00Dad00000Dad0
00AC7@@000=C?P03001C?U<n00@000AC7P04001C7P000002Dch00`00DciC?P050003Dch01000Dch0
00000U=O00@005=ODemCG`<000ACGP<000=;W`@00005Cil00000AE400003AE401@00AE55DDEA0000
0dEA00D004EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400003AE401@00AE55DDEA0000
14EA00D004EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400003AE400`00AE55D@03AE40
1@00AE55DDEA000014EA00<004EA00000P000dVB00<004VBBI800TVB00<004VBBI800TVB00<004VB
BI800TVB00D004VBBI99TP0000A9TP050019TP00BI800005BI800`00BI99TP02BI820003AE001@00
AE15D4E@00000dE@00<004E@AE000TE@00<004E@AE000TE@00<004Ub00003Woo00<007ooOol07Goo
000QOol00`00Oomoo`05Ool20002Dad01000DaeC7E<M0`000e<M00<005<MDad00U<M0`0015<M00<0
05<MDad010000e<M00<005<MDad0100015<M00@005<M0000009C7@03001C7E<M009C7@06001C7@00
001C7@0015<M0`0015<M00<005<MDad0100015<M00<005<MDad00`0015<M00@005<M0000009C7@03
001C7@0000D000AC7@03001C7E<M00<000AC7@04001C7@000002Dch00`00DciC?P02Dch30004Dah0
0`00DaiC7P030004Dch30004Dch00`00DciC?P030004Del40003Deh01@00Deh00000Bil01@000TnO
0`000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D004EA
AE55D@0000=5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EA
AE55D@0000A5D@030015DDEA0095D@050015DDEAAE400003AE430002BI801@00BI99TTVB00001DVB
00D004VBBI99TP0000A9TP050019TTVBBI800004BI801P00BI99TP00BI8000A9TP030019TTVB0099
TP8000=5D0050015D4E@AE000004AE001@00AE15D4E@000014E@00<004Ub00003goo00<007ooOol0
77oo000POol30003Ool40004Dad00`00Dad00002Dad00`00DaeC7@02Dad01000Dad000000U<M00<0
05<MDad00U<M0`0015<M00<005<MDad00`0015<M00<005<MDad0100015<M00<005<MDad010000e<M
00@005<M0000009C7@03001C7E<M009C7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@0009C
7@<00003Dad00000009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC?P04001C?P000002
Dah00`00DaiC7P02Dah30003Dch01000Dch000000U<n00<005<nDch00U<n0`000e=O00@005=O0000
00=CGP03001CGU=N00L0009?W`@00095D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D0
04EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D0
04EAAE55D@0000=5D@030015DDEA0095D@030015DDEA0095D@050015DDEAAE400004AE401000AE55
DDEA100000=9TP00BI800TVB00<004VBBI800TVB00<004VBBI800TVB00D004VBBI99TP0000A9TP05
0019TTVBBI800005BI801@00BI8004VB000014VB00<004VBBI800TVB0P000dE@00<004E@AE000TE@
00D004E@AE15D00000=5D0030015D4E@0095D0030019LP00011oo`03001oogoo01]oo`0087oo00<0
07oo00000`0015<M00<005<MDad00`0015<M00<005<MDad0100015<M00@005<M0000009C7@03001C
7E<M009C7@<0009C7@03001C7E<M009C7@<000AC7@03001C7E<M00@000AC7@03001C7E<M00<000AC
7@04001C7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad300000e<M00000002
0004Dad01P00Dad00000Dad000AC7@<000AC?P03001C?U<n00<000EC7P04001C7P000002Dch00`00
DciC?P040004Dch01000Dch000000U=O00<005=ODel01@000U=N100000=;W`0000000dnO0`000TEA
00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@00
00A5D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D004EAAE55D@0000A5D@030015DDEA
0095D@050015DDEAAE400003AE400`00AE55D@02AE400`00AE4000020004BI801@00BI99TTVB0000
14VB00<004VBBI800TVB00D004VBBI99TP0000A9TP050019TTVBBI800005BI800`00BI99TP020004
BI800`00BI99TP02BI820003AE000`00AE15D002AE001@00AE15D4E@00000dE@00<004E@AE000TE@
00<004Ub000047oo00<007ooOol02Goo00IcW248000002U:Li`4Ool015[F248003W>17oo000POol2
0003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@040004Dad01P00Dad0
0000Dad000AC7@04001C7@000002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad00`00
DaeC7@040004Dad01P00Dad00000Dad000AC7@<000AC7@L000AC7@03001C7E<M00<000AC7@04001C
7@000003Dch00`00DciC?P040003Dah01000DaiC7U<N0`0015<n0`0015<n00<005<nDch010000U=O
100015=N0`000T^O100000I?W`00000004EA0003AE401@00AE55DDEA00000dEA00D004EAAE55D@00
00=5D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@050015DDEA
AE400004AE400`00AE55D@02AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@040015DDEA
AE430002BI800`00BI99TP02BI801@00BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP00
00A9TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI800004BI800`00BI99TP03BI801@00
AE15D4E@000014E@00D004E@AE15D00000=5D0030015D4E@0095D0030019LP00015oo`03001oogoo
00Qoo`06:DXicWooOolicRU:0goo00IS61S6LiacW124DY@3Ool0021oo`8000AC7@04001C7@000002
Dad01000DaeC7E<M0`0015<M00<005<MDad0100015<M00<005<MDad010000e<M00<005<MDad01000
15<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00<0
00AC7@04001C7@000002Dad00`00DaeC7@050004Dad00`00DaeC7@040003Dad00`00DaeC7@040004
Dch30003Dah00`00DaiC7P050003Dch01000Dch000000e<n00<005<nDch010000e=O0`0015=N00D0
05=N000004^O00@0009?W`@000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EA
AE55D@0000=5D@050015DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA00000dEA00<004EA
AE400TEA00D004EAAE55D@0000A5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA100000=9
TP00BI800TVB00<004VBBI800TVB00<004VBBI800TVB00D004VBBI99TP0000A9TP050019TTVBBI80
0005BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP030019TTVB00=9TP050015D4E@AE00
0004AE001@00AE15D4E@00000dE@00<004E@AE000TE@00<004Ub00004Woo00<007ooOol01goo00<8
@WooOol00Woo00H007ooOomoob48DY@2Ool00e:D6<Ioo`02Ool0021oo`03001oo`00009C7@@000AC
7@03001C7@00009C7@03001C7E<M009C7@<000=C7@03001C7E<M009C7@<000AC7@03001C7E<M00<0
00AC7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00U<M0`000e<M
00<005<MDad010000e<M1@000U<M00<005<MDad00U<M0`000e<M00<005<MDad0100015<n00H005<n
000005<N0004Dah30004Dch00`00DciC?P030005Dch30003Del01000Del000000U=N00@005=NDeiC
GPH000=?W`<000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5
D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D004EAAE55D@0000A5D@050015DDEAAE40
0004AE401@00AE55DDEA00000dEA00<004EAAE400TEA00H004EAAE55D@00AE430004BI801@00BI99
TTVB00001DVB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800005BI801@00BI99
TTVB000014VB00@004VBBI99TP8000A9TP030019TTVB0099TP050015D4E@AE000004AE001@00AE15
D4E@00000dE@00<004E@AE000TE@00@004UbBG80015oo`03001oogoo00Moo`03001cW7oo009oo`05
001oogooOol00004Ool00`00Oomoo`01Ool0021oo`D000AC7@03001C7E<M00@000=C7@04001C7@00
0002Dad00`00DaeC7@02Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M00<005<MDad01000
15<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@04001C7@000002Dad01000
DaeC7E<M0`0015<M1`0015<M00H005<M000005<M0004Dad30004Dch00`00DciC?P030004Dah01000
Dah000000e<n00<005<nDch010000e<n00<005<n00000P000U=O00<005=ODel010000U=N1@0000=;
W`0000000TnO00@004nO00000095D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EA
AE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EA
AE55D@0000A5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00<004EAAE400TEA00<004EA
00000`000TVB00<004VBBI800TVB00D004VBBI99TP0000E9TP050019TTVBBI800003BI800`00BI99
TP02BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB000014VB00<004VBBI800TVB0P00
0dVB00<004VBBI800TVB00D004E@AE15D00000A5D0050015D4E@AE000003AE000`00AE15D002AE00
1000BG99LP004Woo00<007ooOol01Woo00H002U:LiaoocW>:DX3Ool00`00Oomoo`02Ool00`00Oomo
o`01Ool0021oo`03001oogoo009oo`03001C7E<M00@000AC7@03001C7E<M00<000AC7@03001C7E<M
00@000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00U<M0`000e<M00<005<MDad01000
15<M00<005<MDad0100015<M00<005<M00000U<M00<005<M00001@0015<M00<005<MDad00`0015<M
00@005<M0000009C?P03001C?U<n009C?P<000=C7P03001C7U<N00@000AC?P<000=C?P03001C?U<n
00D0009CG`@000=CGP@0009;W`@0009?W`@000=5D@050015DDEAAE400003AE401@00AE55DDEA0000
0dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00<004EAAE40
0TEA00D004EAAE55D@0000A5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00@004EAAE55
D@<00099TP050019TTVBBI800004BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB0000
0dVB00<004VBBI800dVB00D004VBBI99TP0000A9TP050019TTVBBI800004BI800`00BI99TP02BI80
0`00BI800002BI800`00BI99TP02BI801@00AE15D4E@000014E@00D004E@AE15D00000=5D0030015
D4E@0095D0@001=oo`03001oogoo00Eoo`0648@icP00000YBW>L0goo00<007ooOol00Woo00<007oo
Ool00Goo000POol00`00Oomoo`03Ool20003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040004
Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M00@005<M0000009C7@04001C
7E<MDad30004Dad00`00DaeC7@040004Dad00`00DaeC7@030002Dad300000e<M00000002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@040004Dch01P00Dch00000Dah000AC7P<000AC?P04001C?P00
0002Dch00`00DciC?P040004Del30003Deh01000Deh000000d^O0`000TnO10000dEA00D004EAAE55
D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015
DDEAAE400003AE401@00AE55DDEA000014EA00D004EAAE55D@0000A5D@050015DDEAAE400004AE40
1@00AE55DDEA00000dEA100000=9TP00BI800TVB00D004VBBI99TP0000E9TP050019TTVBBI800004
BI801@00BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP0000A9TP050019TTVBBI800005
BI801`00BI99TTVB0019TP000099TP030019TTVB0099TP050015D4E@AE000004AE001@00AE15D4E@
00000dE@00<004E@AE000TE@00@0058gDSL001=oo`03001oogoo00Eoo`03@Q0aS7oo00Ioo`068@QB
U7ooOomBU2480goo000DOol015[F248003W>1goo00<007ooOol01Goo00<005<MDad00U<M00H005<M
000005<M0004Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@040004
Dad00`00Dad00002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040002Dad300000e<M00000002
0004Dad01P00Dad00000Dad000AC7@<000AC?P03001C?U<n00<000AC7P04001C7P000003Dch00`00
DciC?P030004Dch30004Del01000Del000000U=N00<005=NDeh01@0000=;W`0000000TnO0`000dEA
00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@00
00=5D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D004EAAE55D@0000A5D@050015DDEA
AE400003AE400`00AE55D@02AE401P00AE55DDEA0015D@<000A9TP050019TTVBBI800004BI800`00
BI99TP02BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP030019TTVB0099TP050019TTVB
BI800004BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB00000TVB00<004VB000014VB
00D004E@AE15D00000A5D0050015D4E@AE000003AE000`00AE15D003AE001000DSMB=`004Goo0`00
1goo00<HaS6<JeX01Goo00IS61S6LiacW1S6HaP3Ool001=oo`06HaPHaW>LLi`@Q5:D1Woo00<007oo
Ool01Woo00<005<MDad010000e<M00@005<M0000009C7@03001C7E<M009C7@<000=C7@04001C7E<M
Dad30004Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad0
0U<M0`000e<M1`0015<M00<005<MDad00`0015<M00@005<M000000=C?P03001C?U<n00@000=C7P03
001C7U<N00D0009C?P@000=C?P04001C?P000003Del00`00DemCG`030004Deh40002Bil400000dnO
00000002AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00
AE55DDEA000014EA00@004EAAE4000=5D@050015DDEAAE400003AE400`00AE55D@02AE400`00AE55
D@02AE401@00AE55DDEA00000dEA00D004EAAE55D@0000A5D@030015DDEA00<00099TP030019TTVB
0099TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB000014VB00D004VBBI99TP00
00A9TP030019TTVB0099TP050019TTVBBI800005BI801@00BI99TTVB000014VB00D004VBBI99TP00
00=9TP8000E9TP050015D4E@AE000003AE001@00AE15D4E@000014E@00<004E@AE000TE@00@0058g
DSL001=oo`03001oogoo00Ioo`04>Lh8@P0048@4Ool015[F2488@V<H17oo000COol01R48DYAoogoo
DY@HaPIoo`03001oogoo00Moo`8000AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC
7@02Dad00`00Dad00002Dad00`00DaeC7@02Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@04
0004Dad01`00Dad00000Dad005<M00H000AC7@03001C7E<M00@000=C7@03001C7E<M00@000AC?P<0
00=C7P03001C7U<N00@000AC?P<000=C?P03001C?U<n00D0009CG`@000=CGP04001CGP000002Bil4
0002Cil40003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE40
1@00AE55DDEA000014EA00@004EAAE4000=5D@050015DDEAAE400004AE401@00AE55DDEA000014EA
00D004EAAE55D@0000=5D@050015DDEAAE400004AE4300000dVB0019TP02BI800`00BI99TP02BI80
0`00BI99TP02BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP050019TTVBBI800004BI80
0`00BI99TP02BI801@00BI99TTVB00001DVB00D004VBBI99TP0000A9TP050019TTVBBI800004BI80
0`00BI99TP03BI801@00AE15D4E@00000dE@00<004E@AE000TE@00D004E@AE15D00000A5D004001B
=e8g000DOol00`00Oomoo`0EOol001=oo`03001oogoo009oo`03001oogoo00Aoo`8000Yoo`03001C
7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC
7@02Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@030003Dad200000e<M00000002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@040004Dch01P00Dch00000Dah000AC7P<000AC?P06001C?P00
001C?P0015<n0`0015=O0`000e=N00<005=NDeh01`000TnO10000dEA00D004EAAE55D@0000=5D@05
0015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000A5D@050015DDEAAE400002
AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@030015DDEA0095D@050015DDEAAE400003
AE401@00AE55DDEA00000TEA0`000dVB00D004VBBI99TP0000E9TP050019TTVBBI800003BI800`00
BI99TP02BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP030019TTVB0099TP030019TTVB
0099TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB0P000dVB0P000dE@
00D004E@AE15D00000A5D0050015D4E@AE000004AE001@00DSMB=e8g000057oo00<007ooOol057oo
000COol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool20003Dad01000DaeC7E<M0`00
15<M00<005<MDad010000e<M00<005<MDad0100015<M00@005<M0000009C7@04001C7E<MDad30004
Dad00`00DaeC7@040003Dad70004Dad01P00Dad00000Dad000AC7@<000AC?P03001C?U<n00<000AC
7P04001C7P000003Dch00`00DciC?P030004Dch01000Dch000000e=O00@005=O0000009CGP03001C
GU=N00D00003Bil00000009?W`<000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D0
04EAAE55D@0000=5D@050015DDEAAE400003AE400`00AE55D@02AE401@00AE55DDEA00000TEA00<0
04EAAE400TEA00D004EAAE55D@0000=5D@050015DDEAAE400004AE401@00AE55DDEA00000dEA00<0
04EA000010000TVB00D004VBBI99TP0000=9TP030019TTVB00=9TP050019TTVBBI800003BI800`00
BI99TP02BI801@00BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP0000E9TP050019TTVB
BI800004BI801@00BI99TTVB000014VB00<004VBBI800TVB00<004VBBI800TVB100000=BVP00AE00
0TE@00<004E@AE000TE@00D004E@AE15D00000=5D0030015D4E@0095D003001B=e8g008001Aoo`03
001oogoo01Aoo`004goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02goo00<005<MDad0
0U<M00<005<M00000U<M00<005<MDad00U<M0`0015<M00<005<MDad00`0015<M00<005<MDad01000
15<M00<005<M00000U<M00<005<MDad00U<M0`0015<M1P0015<M00<005<MDad010000e<M00@005<M
000000=C?P03001C?U<n00@000=C7P03001C7U<N00@000AC?P<000=C?P03001C?U<n00D0009CG`<0
00ACGP@0009;W`@00003Cil000000095D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D0
04EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D004EAAE55D@000095
D@030015DDEA0095D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D004EAAE55D@000095
D@<00099TP030019TTVB0099TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB0000
0dVB00<004VBBI800TVB00D004VBBI99TP0000E9TP050019TTVBBI800003BI800`00BI99TP03BI80
1@00BI99TTVB000014VB00D004VBBI99TP0000A9TP030019TTVB0099TP030019TTVB00@000ABVP04
0015D4E@0004AE001@00AE15D4E@00000dE@00<004E@AE000TE@0`0000=>5`00Ool057oo00<007oo
Ool04goo000COol01R48DYAoogooDY@Q20Eoo`03001oogoo00eoo`03001C7E<M00<000AC7@04001C
7@000002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01000
Dad000000U<M00<005<M00001@000e<M00<005<MDad0100015<M00<005<MDad00`0015<n0`0015<N
00<005<NDah00`0015<n00@005<n0000009C?P03001C?U<n00D0009CG`@000=CGP04001CGP000002
Bil40002Cil40003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003
AE401@00AE55DDEA00000dEA00D004EAAE55D@0000A5D@050015DDEAAE400003AE401@00AE55DDEA
00000dEA00D004EAAE55D@0000=5D@030015DDEA0095D@040015DDEAAE4300000dVB0019TP02BI80
0`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP030019
TTVB0099TP050019TTVBBI800005BI801@00BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99
TP0000A9TP050019TTVBBI800005BI800`00BI99TP040002DYX20004DYX01000AE15D00014E@00D0
04E@AE15D00000=5D0030015D4E@0095D005001>5dhGCQL0000FOol00`00Oomoo`0BOol001=oo`06
HaPHaW>LLi`HaV<H1Goo00<007ooOol03Woo0P000e<M00<005<MDad0100015<M00H005<M000005<M
0004Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad300001E<M000005<M000015<M
0`0015<M00<005<MDad010000e<n00@005<n0000009C7P03001C7U<N009C7P<000=C?P03001C?U<n
00@000=C?P<000ACG`<000=CGP03001CGU=N00L0009?W`@000=5D@050015DDEAAE400003AE401@00
AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA
00<004EAAE400TEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA
00<004EAAE400TEA00<004EA00000P000dVB00D004VBBI99TP0000A9TP030019TTVB0099TP050019
TTVBBI800004BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP030019TTVB0099TP050019
TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB000014VB00<004VBBI800TVB00<004VBBI80
0TVB0`0000=BVP00DYX015:J0P000e:J00@004E@AE0000A5D0050015D4E@AE000003AE000`00AE15
D002AE000`00CQM>5`02CQL00`00Oomoo`0COol00`00Oomoo`0BOol001Aoo`04F]H8@PQ2HaP6Ool0
0`00Oomoo`0@Ool00`00DaeC7@030004Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<M
Dad00U<M0`000e<M00<005<MDad010000e<M0`0000AC7@00000000AC7@04001C7@000002Dad00`00
DaeC7@02Dad30003Dch00`00DciC?P040004Dah01000Dah000000U<n00<005<nDch0100015<n00<0
05<n00000e=O00@005=O0000009CGP03001CGU=N00D00003Bil00000009?W`<000=5D@050015DDEA
AE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00
AE55DDEA00000dEA00D004EAAE55D@0000A5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA
00D004EAAE55D@0000=5D@030015DDEA00@00099TP050019TTVBBI800003BI800`00BI99TP03BI80
1@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000A9TP030019TTVB0099TP050019
TTVBBI800004BI801@00BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP0000E9TP050019
TTVBBI800002BI830004DYX00`00DYYBVP02DYX01000DYX005:J0`0000=5D000AE000dE@00D004E@
AE15D00000=5D0030015D4E@0095D003001>5dhG009>5`03001oogoo01Aoo`03001oogoo015oo`00
7Woo0P004Woo0P000e<M00<005<MDad0100015<M00<005<MDad00`0015<M00@005<M0000009C7@04
001C7E<MDad30004Dad70003Dad00`00DaeC7@040004Dad01000Dad000000U<n00<005<nDch01000
15<N00<005<NDah00`0015<n0`0015<n00<005<nDch010000U=O10000e=N10000T^O100000=?W`00
00000TEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EA
AE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EA
AE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000TEA10000TVB00D004VBBI99TP00
00=9TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI801@00
BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP0000A9TP050019TTVBBI800004BI800`00
BI99TP02BI801@00BI99TTVB00001DVB00<004VB000010000U:J00<005:JDYX00e:J00@005:JDYYB
VP@0009BF0030015D00000A5D0050015D4E@AE000003AE000`00AE15D002AE000`00CQM>5`02CQL0
0`00Oomoo`0COol3000BOol001ioo`03001oogoo019oo`04001C7E<MDad30004Dad00`00DaeC7@04
0003Dad00`00DaeC7@040004Dad00`00Dad00002Dad00`00DaeC7@050004Dad00`00DaeC7@030004
Dad00`00DaeC7@030004Dch30004Dah00`00DaiC7P040003Dch01000Dch000000e<n00<005<nDch0
10000U=O100015=N00<005=N00000T^O10000TnO10000dEA00D004EAAE55D@0000=5D@050015DDEA
AE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00
AE55DDEA00000dEA00<004EAAE400TEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401000
AE55DDEA0`0000=9TP00BI800dVB00D004VBBI99TP0000A9TP050019TTVBBI800004BI801@00BI99
TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000A9TP030019TTVB0099TP050019TTVBBI80
0004BI801@00BI99TTVB000014VB00<004VBBI800TVB00<004VBBI800TVB00@004VBBI99TP<0009B
VP03001BVU:J00=BVP03001BVU:J009BVP08001BVP00001BF000DUP000=BF08000A5D0050015D4E@
AE000003AE000`00AE15D002AE020003CQL00`00Oomoo`0@Ool30002Ool00`00Oomoo`0@Ool001io
o`03001oogoo01=oo`03001C7@00009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000AC7@03
001C7E<M00<000=C7@D0009C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C?P04001C?P00
0002Dah00`00DaiC7P02Dah30003Dch00`00DciC?P040004Dch30003Del30004Deh00`00DeiCGP07
0002Cil40002AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE40
1@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA0000
14EA00D004EAAE55D@0000=5D@050015DDEAAE400003AE400`00AE4000020003BI800`00BI99TP02
BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP050019TTVBBI800003BI800`00BI99TP02
BI800`00BI99TP02BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP050019TTVBBI800004
BI800`00BI99TP03BI801000BI99TTVB100000=BVP00DYX00e:J00<005:JDYX00U:J00@005:JDYYB
VP<000ABF003001BF000009BF08000A5D0050015D4E@AE000003AE000`00AE15D003AE000`00CQM>
5`02CQL00`00Oomoo`0<Ool30005Ool00`00Oomoo`0@Ool001eoo`03001oogoo01Eoo`03001C7E<M
009C7@04001C7@000002Dad01000DaeC7E<M0`0015<M00<005<MDad010000e<M1`0015<M00H005<M
000005<M0004Dad30004Dch00`00DciC?P030004Dah01000Dah000000U<n00<005<nDch0100015<n
00@005<n0000009CG`04001CG`000003Deh00`00DeiCGP060004Cil30003AE401000AE55D@000dEA
00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@00
00=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00<004EAAE400TEA00D004EAAE55D@00
00=5D@060015DDEAAE4004EA10000TVB00D004VBBI99TP0000A9TP030019TTVB0099TP050019TTVB
BI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI800dVB00D004VBBI99TP00
00=9TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB00<004VBBI800dVB
00<004VB00000P001E:J00D005:JDYYBVP0000=BVPD0009BF003001BF59H009BF005001BF59H001B
F0020004AE001@00AE15D4E@000014E@00<004E@AE000TE@00<004hGCQL00`002Woo100027oo00<0
07ooOol047oo000MOol00`00Oomoo`0FOol00`00DaeC7@040004Dad00`00Dad00002Dad00`00DaeC
7@02Dad30004Dad60004Dad00`00DaeC7@030004Dad01000Dad000000e<n00<005<nDch010000e<N
00<005<NDah01@000U<n0`0015<n00<005<nDch010000U=O1@000U=N100000=;W`0000000dnO00@0
04nO00000095D@050015DDEAAE400002AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@05
0015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003
AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5D@030015DDEA00<00099TP050019TTVBBI80
0003BI800`00BI99TP02BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D0
04VBBI99TP0000=9TP030019TTVB00=9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00<0
04VBBI800TVB00<004VBBI800TVB00<004VBBI800TVB00@004VBBI99TP<0009BVP03001BVU:J00=B
VP04001BVU:JDYX40002DUP00`00DUQBF003DUP01@00DUQBF59H00000e9H0`0014E@00<004E@AE00
0TE@00D004E@AE15D00000A5D0<0009BVP03001oogoo00Eoo`<000eoo`03001oogoo00moo`007Goo
00<007ooOol05goo0P0015<M00<005<MDad010000e<M00@005<M0000009C7@03001C7@0000D000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000AC?P<000=C7P03001C7U<N00@000AC?P<000=C?P03
001C?U<n00@0009CG`@000ACGP<0009;W`D0009?W`@000=5D@050015DDEAAE400002AE401@00AE55
DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D0
04EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA000014EA00D004EAAE55D@0000=5
D@<00003BI8004VB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB00D004VBBI99TP00
00=9TP030019TTVB0099TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB000014VB
00D004VBBI99TP0000=9TP030019TTVB00=9TP050019TTVBBI800004BI8400000e:J001BVP03DYX0
0`00DYYBVP02DYX01P00DYX00000DUP000EBF003001BF59H009BF003001BF59H009BF0@0009;W`05
0015D4E@AE000004AE001@00AE15D4E@000014E@0P0015:J00@007ooOomoo`<0011oo`03001oogoo
00moo`007Goo0P006Woo00<005<MDad0100015<M00<005<MDad00`000U<M0`0000EC7@00001C7@00
00AC7@<000AC7@03001C7E<M00<000AC?P04001C?P000002Dah00`00DaiC7P040004Dch01000Dch0
00000U<n00<005<nDch010000e=O0`0015=N00@005=N0000009;W`@0009?W`@000=5D@050015DDEA
AE400003AE401000AE55D@000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55
DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00<0
04EAAE400TEA00H004EAAE55D@00AE430003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<0
04VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99
TTVB000014VB00D004VBBI99TP0000A9TP050019TTVBBI800003BI800`00BI99TP03BI801@00BI99
TTVB00000TVB0`001E:J00D005:JDYYBVP0000=BVP<000ABF003001BF59H009BF003001BF59H009B
F003001BF59H00@0009;W`@000=5D0050015D4E@AE000003AE000`00AE15D002AE020004DYX4000C
Ool00`00Oomoo`0?Ool001eoo`03001oogoo01Yoo`8000AC7@03001C7E<M00@0009C7@<00003Dad0
0000008000=C7@04001C7@000003Dad00`00DaeC7@040003Dch00`00DciC?P040003Dah30004Dch0
0`00DciC?P030004Dch30004Del00`00Del00003Deh00`00DeiCGP070002Cil40003AE401@00AE55
DDEA00000dEA00D004EAAE55D@000095D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D0
04EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5
D@050015DDEAAE400004AE400`00AE4000030002BI801@00BI99TTVB00000dVB00<004VBBI800TVB
00D004VBBI99TP0000A9TP050019TTVBBI800003BI801@00BI99TTVB00001DVB00D004VBBI99TP00
00=9TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB00<004VBBI800TVB
00<004VB000010000U:J00<005:JDYX00e:J00@005:JDYYBVP@0009BF003001BF59H009BF003001B
F59H009BF003001BF59H009BF0<0009;W`H00003DYX004E@0095D0050015D4E@AE000003AE000`00
AE15D00300000e:J0000000200000e:J001oo`0DOol00`00Oomoo`0?Ool001eoo`03001oogoo01]o
o`03001C7E<M009C7@<000=C7@L000AC7@03001C7E<M00<000AC7@<000=C?P03001C?U<n00@000AC
7P03001C7P0000=C?P03001C?U<n00@000=C?P04001C?P000003Del00`00DemCG`040002Deh50000
0d^O00000002Cil40002AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@040015DDEA0003
AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA
00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401000AE55DDEA0`000TVB00D004VB
BI99TP0000=9TP030019TTVB0099TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB
00000dVB00D004VBBI99TP0000E9TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB
000014VB00<004VBBI800TVB00D004VBBI99TP0000=9TP<0009BVP03001BVU:J00=BVP03001BVU:J
009BVP06001BVP00001BF0001E9H00<0059HDUP00U9H00<0059HDUP00U9H10000T^O0`000U:J00L0
05:JDYYBVP00DYX00002AE001P00AE15D4E@0015D0D000913P<000EBVP03001oogoo019oo`03001o
ogoo00moo`0077oo00<007ooOol07Goo00@005<M0000009C7@03001C7@0000@000AC7@03001C7E<M
00@000=C7@04001C7@000002Dch01000DciC?U<n0`0015<N00<005<NDah00`0015<n0`0015<n00<0
05<nDch010000U=O10000e=N10000T^O100000=?W`0000000dEA00@004EAAE4000=5D@050015DDEA
AE400003AE401@00AE55DDEA00000TEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00
AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA
00@004EAAE55D@@00003BI8004VB0099TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99
TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP030019TTVB0099
TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB000014VB00<004VBBI800TVB00@0
04VBBI99TP@00003DYX005:J00=BVP03001BVU:J009BVP04001BVU:JDYX30004DUP00`00DUQBF002
DUP00`00DUQBF002DUP00`00DUQBF00400001T^O00000000DYX000ABVP06001BVU:J001BVP000TE@
00<004E@AE000`000T4>00<0044>@@h00T4>00<005:J00001E:J00<007ooOol04Woo00<007ooOol0
3goo000LOol00`00Oomoo`0NOol20002Dad300000e<M001C7@02Dad00`00DaeC7@040003Dad00`00
DaeC7@040004Dch00`00Dch00003Dah00`00DaiC7P040003Dch01000Dch000000e<n00<005<nDch0
10000e=O0`000e=N00@005=N0000009;W`@0009?W`<00003AE4004EA0095D@040015DDEA0003AE40
1@00AE55DDEA00000dEA00D004EAAE55D@000095D@050015DDEAAE400003AE401@00AE55DDEA0000
0dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55
D@0000=5D@030015D@00008000A9TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D004VB
BI99TP0000=9TP030019TTVB0099TP050019TTVBBI800004BI801@00BI99TTVB000014VB00D004VB
BI99TP0000=9TP030019TTVB0099TP050019TTVBBI800004BI800`00BI99TP02BI800`00BI800002
0005DYX00`00DYYBVP02DYX00`00DYYBVP050002DUP00`00DUQBF002DUP00`00DUQBF002DUP01000
DUQBF59H10000T^O0`001E:J00D005:JDYYBVP0000=BVP<00006AE00000000113P000d4>00<0044>
@@h00T4>00@005:JDYX000ABVP8001=oo`03001oogoo00moo`0077oo00<007ooOol07goo0`0000AC
7@00000000AC7@<000AC7@03001C7E<M00<000AC?P03001C?U<n00<000AC7P<000=C?P03001C?U<n
00@000AC?P<000=CG`04001CG`000003Deh00`00DeiCGP070002Cil40003AE401@00AE55DDEA0000
0TEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401000AE55D@000dEA00D004EAAE55D@00
00=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEA
AE400003AE400`00AE4000030002BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<004VBBI80
0TVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI800`00BI99TP02BI801@00BI99TTVB0000
0dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP030019TTVB0099TP030019
TTVB0099TP030019TTVB00<0009BVP03001BVU:J00=BVP03001BVU:J009BVP<0009BF003001BF59H
00=BF005001BF59HDUP00004DUP40002Bil40002DYX00`00DYYBVP03DYX01P00DYYBVU:J001BVPL0
00=13P0500113T4>@@h00004@@h01@00DYYBVP00DYX00`0000=Bf`00Ool04goo00<007ooOol03Woo
000LOol2000MOol30002Ool20003Dad01000Dad000000U<M00<005<MDad00U<M0`000e<n00<005<n
Dch010000e<N00@005<N000000=C?P03001C?U<n00<000AC?P04001C?P000002Del00`00DemCG`05
0002Deh400000d^O00000002Cil50002AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@050015
DDEAAE400003AE401@00AE55DDEA00000TEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE40
1@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE400`00AE55D@030002
BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800003
BI801@00BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP05
0019TTVBBI800003BI800`00BI99TP03BI801@00BI99TTVB000014VB0`0000=BVP00DYX00e:J00<0
05:JDYX00U:J00<005:J00000P0000=BF000DUP00e9H00<0059HDUP00U9H00<0059HDUP00U9H1000
0T^O00H004^O000005:J0005DYX00`00DYYBVP02DYX00`00DYYBVP030003Dah01000Dah000000d4>
00D0044>@@i13P0000A13P03001BVP00008000EBf`03001oogoo015oo`03001oogoo00ioo`0077oo
00<007ooOol06Goo0`001goo00<005<MDad00`0015<M00@005<M0000009C?P03001C?U<n00@000=C
7P03001C7U<N00D0009C?P@000=C?P03001C?U<n00D0009CG`@0009CGP@0009;W`P000=5D@040015
DDEA0003AE401@00AE55DDEA00000TEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401000
AE55D@000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D0
04EAAE55D@0000=5D@040015DDEAAE4300000dVB0019TP02BI801@00BI99TTVB000014VB00D004VB
BI99TP0000A9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<004VB
BI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800003BI800`00BI99TP03
BI801@00BI99TTVB00000TVB0`0015:J00<005:JDYX00U:J00<005:JDYX00`001E9H00D0059HDUQB
F00000ABF003001BF59H00@000=;W`<000ABVP03001BVU:J009BVP04001BVU:JDYX40003Dah01000
DaiC7U<N0`000d4>00D0044>@@i13P0000A13P80009Bf`03001Bfe;K009Bf`8001=oo`03001oogoo
00ioo`0077oo00<007ooOol05Woo0`002goo0P000e<M00<005<MDad010000e<n0`0015<N00<005<N
Dah00`0015<n0`000e<n00<005<nDch01@000U=O10000e=N10000T^O100000=?W`0000000dEA00D0
04EAAE55D@000095D@050015DDEAAE400003AE401000AE55D@000dEA00D004EAAE55D@0000=5D@05
0015DDEAAE400002AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003
AE401@00AE55DDEA00000dEA00H004EAAE55D@00AE430003BI801@00BI99TTVB00000dVB00<004VB
BI800TVB00<004VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI800`00BI99TP02
BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800004
BI800`00BI99TP02BI800`00BI8000040002DYX00`00DYYBVP02DYX00`00DYYBVP02DYX30002DUP0
0`00DUQBF003DUP01@00DUQBF59H0000159H0`000T^O1@000U:J00<005:JDYX00e:J00@005:JDYYB
VP@000=C7P03001C7U<N00D00003D]`0000000=13P0500113T4>@@h00004@@h00`00D]]Bf`02D]/0
1P00D]/00000D[/001=oo`03001oogoo00ioo`0077oo00<007ooOol04goo0`003goo00<005<MDad0
100015<n00<005<n00000e<N00<005<NDah010000e<n00@005<n000000=C?P03001C?U<n00<000AC
G`<000=CGP04001CGP000002Bil40002Cil300000dEA0015D@02AE401@00AE55DDEA00000TEA00D0
04EAAE55D@0000=5D@040015DDEA0003AE401@00AE55DDEA00000dEA00D004EAAE55D@000095D@05
0015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003
AE400`00AE4000030002BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<004VBBI800TVB00D0
04VBBI99TP0000=9TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00<0
04VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI80
0003BI830002DYX00`00DYYBVP03DYX01P00DYYBVU:J001BVP<00003DUP0059H00=BF003001BF59H
009BF003001BF59H009BF0@0009;W`<0009BVP03001BVU:J00=BVP03001BVU:J009BVP06001BVP00
001C7P001E<N0`000U;L00<005;LD]`00U;L0P000T4>00D0044>@@i13P0000A13P80009Bf`<000AB
^`03001oogoo011oo`03001oogoo00ioo`006goo00<007ooOol04Woo0P004goo0P0015<n00<005<n
Dch00`0015<N0`000e<n00<005<nDch0100015<n0`000e=O00@005=O0000009CGP03001CGU=N00P0
009?W`<00005AE4004EAAE400003AE401@00AE55DDEA00000TEA00D004EAAE55D@0000=5D@040015
DDEA0003AE401@00AE55DDEA00000dEA00D004EAAE55D@000095D@050015DDEAAE400003AE401@00
AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400002AE430002BI801@00BI99TTVB
00000dVB00D004VBBI99TP0000A9TP030019TTVB0099TP050019TTVBBI800003BI801@00BI99TTVB
00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800003
BI800`00BI99TP03BI801@00BI99TTVB00000dVB100000=BVP00DYX00e:J00<005:JDYX00U:J00<0
05:JDYX00`001E9H00D0059HDUQBF00000EBF003001BF00000<00006Bil00000001BVP0015:J00<0
05:JDYX00U:J00@005:JDYYBVP<000AC7P03001C7P0000800003D]`005;L00=Bg004001Bg5;LD]`3
00000d4>00113P02@@h00`00@@i13P02@@h40002D[/00`00D[]B^`02D[/00`00Oomoo`0@Ool00`00
Oomoo`0>Ool001]oo`03001oogoo00moo`<001Moo`03001C?U<n00@000=C7P04001C7P000003Dch0
0`00DciC?P030004Dch01000Dch000000U=O00<005=ODel01@000U=N100000=;W`0000000dnO1000
0dEA00@004EAAE4000=5D@050015DDEAAE400002AE401@00AE55DDEA00000dEA00@004EAAE4000=5
D@050015DDEAAE400003AE401@00AE55DDEA00000TEA00D004EAAE55D@0000=5D@050015DDEAAE40
0003AE401@00AE55DDEA00000dEA00@004EAAE55D@<00003BI8004VB0099TP050019TTVBBI800003
BI801@00BI99TTVB000014VB00<004VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI800004
BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP050019TTVBBI800003BI800`00BI99TP03
BI801P00BI99TTVB0019TP<000EBVP05001BVU:JDYX00003DYX40002DUP00`00DUQBF003DUP01@00
DUQBF59H00000e9H10000T^O0`001E:J00D005:JDYYBVP0000=BVPD0009C7P04001C7U<NDah30005
D]`01000D]aBg5;L100000=C7@00Dad00P000d4>00<0044>@@h00T4>00<005:k000015:k00<005:k
D[/00`004Goo00<007ooOol03Woo000KOol3000<Ool3000KOol20004Dah00`00DaiC7P030004Dch3
0003Dch00`00DciC?P050002Del30004Deh30002Bil500000dnO00000003AE401@00AE55DDEA0000
0TEA00D004EAAE55D@0000=5D@040015DDEA0003AE401@00AE55DDEA00000TEA00D004EAAE55D@00
00=5D@050015DDEAAE400003AE401000AE55D@000dEA00D004EAAE55D@0000=5D@050015DDEAAE40
0003AE401P00AE55DDEA0015D@<000=9TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D0
04VBBI99TP0000A9TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9
TP050019TTVBBI800004BI801@00BI99TTVB000014VB00<004VBBI800TVB00<004VB00000`000U:J
00<005:JDYX00e:J00@005:JDYYBVP@0009BF003001BF59H009BF003001BF59H009BF004001BF59H
DUP40002Bil40002DYX00`00DYYBVP03DYX01000DYYBVU:J10000e<N00<005<NDah01@000U;L00<0
05;LD]`00e;L00H005;L000005<M0004Dad30003@@h00`00@@i13P03@@h00`00D[/00002D[/40003
D]`00`00Oomoo`0?Ool00`00Oomoo`0=Ool001]oo`03001oogoo00Uoo`<0021oo`03001C7U<N00@0
00=C?P04001C?P000002Dch00`00DciC?P050002Del40003Deh01000Deh000000T^O10000TnO0`00
00=5D@00AE400TEA00D004EAAE55D@000095D@050015DDEAAE400003AE401000AE55D@000dEA00D0
04EAAE55D@000095D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@05
0015DDEAAE400003AE401@00AE55DDEA00000dEA00<004EA00000`000TVB00D004VBBI99TP0000=9
TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9
TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000A9
TP050019TTVBBI800003BI830002DYX00`00DYYBVP02DYX00`00DYYBVP02DYX01P00DYX00000DUP0
00EBF005001BF59HDUP00005DUP30002Bil40002DYX00`00DYYBVP02DYX00`00DYYBVP02DYX01P00
DYX00000Dah000EC7P<0009Bg003001Bg5;L00=Bg004001Bg5;LD]`30004Dad00`00Dad000040004
@@h00`00@@i13P02@@h00`00D[/000020002D]`00`00D]aBg002D]`2000@Ool00`00Oomoo`0=Ool0
01]oo`03001oogoo00Ioo`<002Aoo`8000=C?P03001C?U<n00D0009C?P<000ACG`<000=CGP03001C
GU=N00L0009?W`D000=5D@050015DDEAAE400003AE401000AE55D@000dEA00D004EAAE55D@000095
D@050015DDEAAE400002AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE40
0002AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@030015D@0000<00099TP050019TTVB
BI800003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB
0099TP050019TTVBBI800003BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP030019TTVB
0099TP030019TTVB0099TP050019TTVBBI800003BI8400000e:J001BVP03DYX00`00DYYBVP02DYX0
0`00DYYBVP030004DUP00`00DUQBF002DUP01@00DUQBF59H00000e9H100000E;W`00001BVP0000EB
VP05001BVU:JDYX00003DYX30004Dah00`00Dah0000200000e;L001Bg003D]`01000D]aBg5;L1@00
0U<M00@005<MDaeC7@<000=?G`<000=13P0300113T4>00913P800003D]`005;L00=Bg0@00003D]`0
07oo00moo`03001oogoo00eoo`001Goo00I:DPQ200000248Li`4Ool015[F248003W>27oo00<007oo
Ool00goo0`00:Goo00<005<nDch00`0015<n0`000e=O00@005=O0000009CGP03001CGU=N00P0009?
W`<00005AE4004EAAE400003AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@050015DDEAAE40
0002AE401000AE55D@000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE401@00AE55DDEA
00000TEA00D004EAAE55D@0000=5D@050015DDEAAE400002AE430002BI801@00BI99TTVB00000dVB
00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800003BI801@00BI99TTVB000014VB
00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00<004VBBI800TVB
00<004VBBI800TVB00H004VBBI99TP00BI830005DYX01@00DYYBVU:J00000e:J10000U9H00<0059H
DUP00U9H00<0059HDUP00U9H00<0059HDUP01@000T^O0`0015:J00<005:JDYX00U:J00<005:JDYX0
1@000e<N00<005<NDah00`001E;L00@005;LD]aBg0@0009C7@03001C7E<M009C7@@000=?G`03001?
G`0000<000=13P0300113T4>00913P06001Bg5;LD]`005;L0`001E;L00<007ooOol03Goo00<007oo
Ool03Goo0005Ool01PQ2@Q1oogoo>LhQ20=oo`06HaPHaW>LLi`@Q5:D1Woo00@007ooOomoo`<002eo
o`8000=C?P04001C?P000002Del00`00DemCG`050002Deh400000d^O00000002Cil50003AE401000
AE55D@000dEA00D004EAAE55D@0000=5D@040015DDEA0003AE401@00AE55DDEA00000TEA00@004EA
AE4000=5D@050015DDEAAE400003AE401@00AE55DDEA00000dEA00D004EAAE55D@000095D@050015
DDEAAE400003AE401000AE55DDEA0`0000=9TP00BI800TVB00D004VBBI99TP0000=9TP050019TTVB
BI800004BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVB
BI800003BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP030019TTVB0099TP030019TTVB
0099TP030019TP0000<0009BVP03001BVU:J00=BVP04001BVU:JDYX40002DUP00`00DUQBF002DUP0
0`00DUQBF002DUP01000DUQBF59H0`000d^O10000U:J00<005:JDYX00U:J00<005:JDYX00U:J0`00
0U<N00<005<NDah00e<N0`000U;L00<005;LD]`00e;L00H005;L000005<M0005Dad01000Dad00000
0TmO00@004mOCem?G`<000=C7@8000913P0300113T4>00913P03001Bg00000<0009Bg003001Bg5;L
009Bg08000moo`03001oogoo00eoo`002Woo00H007ooOomoob48DY@2Ool00e:D6<Ioo`05Ool4000a
Ool00`00DciC?P050002Del40002Deh50002Bil600001DEA0015DDEA00000dEA00@004EAAE4000=5
D@050015DDEAAE400003AE401000AE55D@000dEA00D004EAAE55D@000095D@040015DDEA0003AE40
1@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400002AE401@00AE55DDEA0000
0dEA00<004EA00000P000dVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99TTVB
00000dVB00D004VBBI99TP0000=9TP030019TTVB0099TP050019TTVBBI800003BI801@00BI99TTVB
00000dVB00<004VBBI800TVB00D004VBBI99TP0000A9TP050019TTVBBI800003BI830002DYX00`00
DYYBVP02DYX00`00DYYBVP02DYX01P00DYX00000DUP000EBF005001BF59HDUP00004DUP01000DUP0
00000T^O00H004^O000005:J0005DYX01P00DYYBVU:J001BVP<00003Dah005<N00=C7P03001C7P00
00800003D]`005;L00=Bg004001Bg5;LD]`30004Dad01000DaeC7E<M10000TmO1@000e<M00<005<M
Dad01@00144>0P000U;L00<005;LD]`00U;L00H005;L000005;l000?Ool00`00Oomoo`0=Ool000Uo
o`03Li`007oo009oo`03001oogoo009oo`03001oogoo00Aoo`8003Aoo`<0009CG`@000=CGP@0009;
W`@00004Cil000000003AE401000AE55D@000dEA00@004EAAE4000=5D@050015DDEAAE400003AE40
1000AE55D@000dEA00@004EAAE4000=5D@040015DDEA0003AE401@00AE55DDEA00000dEA00D004EA
AE55D@0000=5D@050015DDEAAE400002AE401P00AE55DDEA0015D@@00099TP050019TTVBBI800003
BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI800003
BI800`00BI99TP02BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP050019TTVBBI800004
BI801@00BI99TTVB00000dVB100000=BVP00DYX00e:J00D005:JDYYBVP0000=BVP<000ABF003001B
F59H009BF005001BF59HDUP00003DUP40002Bil30004DYX00`00DYYBVP02DYX00`00DYYBVP030005
Dah00`00DaiC7P030005D]`00`00D]aBg0050003Dad00`00DaeC7@050003Cel30003Dad01000DaeC
7E<M1`0000=B^`00@@h00d4>00<005;LD]`00U;L00<005;LD]`00`0015;l00<007ooOol037oo00<0
07ooOol03Goo0005Ool01PQ2BU9oogoo>LhaS0=oo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo03Aoo`8000=CGP04001CGP000002Bil50002Cil20002AE401@00AE55DDEA00000TEA00D004EA
AE55D@000095D@050015DDEAAE400003AE401@00AE55DDEA00000TEA00@004EAAE4000=5D@050015
DDEAAE400002AE401@00AE55DDEA00000dEA00D004EAAE55D@0000=5D@050015DDEAAE400003AE40
1@00AE55D@00AE4010000TVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI800`00BI99TP02
BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99TTVB
00000dVB00D004VBBI99TP0000A9TP050019TTVBBI800004BI801P00BI99TTVB0019TP<000EBVP05
001BVU:JDYX00002DYX50002DUP00`00DUQBF002DUP00`00DUQBF002DUP00`00DUQBF0050002Bil4
0002DYX00`00DYYBVP03DYX01000DYYBVU:J0`000e<N00@005<NDaiC7P@0009Bg003001Bg5;L00=B
g0<0009C7@03001C7E<M00=C7@<000=?G`03001?G`0000800003Dad005<M00=C7@@00004?ih00000
0002D[/01000D[]B^`000d4>0P000U;L10000e;l00<005;lD_`00`003Woo00<007ooOol037oo0005
Ool01@0048@00000<H`017oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0=Goo00<005=N
Deh01`000TnO100000Eoo`00AE55D@000095D@050015DDEAAE400003AE401000AE55D@000dEA00D0
04EAAE55D@0000=5D@030015D@0000=5D@050015DDEAAE400003AE401000AE55D@000dEA00D004EA
AE55D@0000=5D@050015DDEAAE400003AE401P00AE55DDEA0015D@<00099TP050019TTVBBI800003
BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI800003
BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP030019TTVB0099TP05
0019TTVBBI800004BI801P00BI99TTVB0019TP@0009BVP03001BVU:J00=BVP04001BVU:JDYX30002
DUP00`00DUQBF003DUP01@00DUQBF59H0000159H0`000d^O10000U:J00<005:JDYX00U:J00<005:J
DYX00U:J00H005:J000005<N0004Dah40002D]`00`00D]aBg002D]`00`00D]`0000200000e<M001C
7@03Dad00`00Dad000020002Cel00`00Cem?G`030005Dad01@00Dad00000?ih010000U:k00L005:k
D[]B^`00D[/00003@@h40003D_`00`00D_aBo0040003D_`00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
00Eoo`03001oogoo00Ioo`068@QBU7ooOomBU2482Woo00<007ooOol0=Goo1@000TnO10001Goo00@0
04EAAE400095D@050015DDEAAE400003AE401000AE55D@000dEA00D004EAAE55D@000095D@040015
DDEA0003AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@050015DDEAAE400003AE401@00AE55
DDEA00000dEA00@004EAAE55D@800003BI8004VB0099TP050019TTVBBI800003BI801@00BI99TTVB
000014VB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VB
BI99TP0000A9TP050019TTVBBI800004BI801@00BI99TTVB00000dVB00<004VBBI800TVB00<004VB
BI800`000U:J00<005:JDYX00U:J00<005:JDYX00U:J00H005:J0000059H0004DUP00`00DUQBF002
DUP00`00DUQBF002DUP40002Bil01P00Bil00000DYX000EBVP05001BVU:JDYX00003DYX30004Dah0
1P00Dah00000D]`000EBg003001Bg5;L00<000EC7@03001C7E<M00@000=?G`@000=C7@04001C7E<M
Dad60002D[/00`00D[]B^`02D[/01@00D[]B^`00D[/01@0000=Bo000D_`00e;l0`000U;l00<005;l
D_`00U;l0P0037oo00<007ooOol037oo0005Ool00`00Oomoo`06Ool01V<H6<IcW7>L6<IS60]oo`80
03Yoo`8000Uoo`040015DDEA0002AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@040015DDEA
0003AE401000AE55D@000dEA00D004EAAE55D@0000=5D@040015DDEA0003AE401@00AE55DDEA0000
0dEA00D004EAAE55D@0000=5D@030015D@0000800099TP050019TTVBBI800003BI801@00BI99TTVB
000014VB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VB
BI99TP0000=9TP030019TTVB0099TP030019TTVB0099TP050019TTVBBI800003BI801@00BI99TTVB
000014VB0`0000=BVP00DYX00e:J00<005:JDYX00U:J00<005:JDYX00`00159H00<0059HDUP00U9H
00D0059HDUQBF000009BF0@000=;W`<000ABVP03001BVU:J009BVP03001BVU:J00D000=C7P03001C
7U<N00<000ABg004001Bg5;LD]`40003Dad01000DaeC7E<M10000dmO10000U<M00@005<MDaeC7@L0
0003D[/005:k00AB^`06001B^e:kD[/005:k1P0015;l100000=Bo000D_`00e;l100000=Bo@00Ool0
2goo00<007ooOol037oo0005Ool50005Ool015[F2488@V<H3Woo00<007ooOol0@Goo00D004EAAE55
D@000095D@050015DDEAAE400003AE401000AE55D@000dEA00@004EAAE4000=5D@040015DDEA0003
AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@050015DDEAAE400003AE401P00AE55DDEA0015
D@@00099TP040019TTVB0003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP00
00=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP030019TTVB
0099TP030019TTVB0099TP050019TTVBBI800003BI801@00BI99TTVB00000TVB0`0015:J00D005:J
DYYBVP0000=BVP@0009BF003001BF59H009BF003001BF59H009BF003001BF59H00@0009;W`D0009B
VP03001BVU:J009BVP03001BVU:J009BVP<000=C7P04001C7U<NDah40002D]`00`00D]aBg002D]`4
0002Dad00`00DaeC7@02Dad40003Cel01P00Cel00000Dad000AC7@@0008oWP<000AB^`03001B^e:k
009B^`03001B^e:k00L00004D_`005;lD_`30005D_`00`00D_`000020005D_d00`00Oomoo`09Ool0
0`00Oomoo`0<Ool0029oo`03001oogoo041oo`050015DDEAAE400002AE401@00AE55DDEA00000dEA
00@004EAAE4000=5D@040015DDEA0003AE401000AE55D@000dEA00D004EAAE55D@0000=5D@040015
DDEA0003AE401@00AE55DDEA00000dEA00<004EA00000`000TVB00D004VBBI99TP000099TP050019
TTVBBI800003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019
TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP030019TTVB0099TP050019
TTVBBI800003BI800`00BI8000040002DYX00`00DYYBVP02DYX01000DYYBVU:J10000U9H00<0059H
DUP00U9H00D0059HDUQBF00000ABF0<000=;W`<0009BVP03001BVU:J00=BVP06001BVU:JDYX005:J
0`0000=C7P00Dah00e<N10000U;L00<005;LD]`00U;L00H005;L000005<M0005Dad01000Dad00000
0TmO00@004mOCem?G`<000AC7@05001C7@00000oWP050002D[/00`00D[]B^`02D[/01000D[]B^e:k
1`0000ABo000D_aBo0@000=Bo003001Bo5;l00@000=Bo@03001BoE;m00<000]oo`03001oogoo00ao
o`008goo00<007ooOol0?goo00D004EAAE55D@000095D@050015DDEAAE400003AE401000AE55D@00
0dEA00@004EAAE4000=5D@040015DDEA0003AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@05
0015DDEAAE400002AE430002BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP030019TTVB0099
TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI80
0003BI801@00BI99TTVB000014VB00D004VBBI99TP0000A9TP050019TTVBBI800002BI830002DYX0
0`00DYYBVP03DYX01P00DYYBVU:J001BVP800003DUP0059H00ABF005001BF59HDUP00004DUP40002
Bil01P00Bil00000DYX000ABVP03001BVU:J009BVP03001BVU:J00<000EC7P06001C7P00001Bg000
1E;L00<005;LD]`00`0015<M00@005<MDaeC7@@0009?G`D000=C7@03001C7E<M00H0009B^`03001B
^e:k00=B^`04001B^e:kD[/7000015;l001Bo5;l1@000U;l00<005;lD_`010000e;m00<005;mD_d0
10000e;l00<007ooOol027oo00<007ooOol037oo000TOol2000oOol01@00AE55DDEA00000TEA00D0
04EAAE55D@0000=5D@040015DDEA0003AE401000AE55D@000dEA00@004EAAE4000=5D@050015DDEA
AE400003AE401000AE55D@000dEA00@004EAAE55D@<00003BI8004VB0099TP050019TTVBBI800003
BI801000BI99TP0014VB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB0000
0dVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI801@00BI99TTVB000014VB00D004VBBI99
TP0000=9TP<00003DYX005:J00=BVP03001BVU:J009BVP03001BVU:J00<000ABF003001BF59H009B
F005001BF59HDUP00002DUP40003Bil30004DYX00`00DYYBVP02DYX00`00DYYBVP040003Dah01000
DaiC7U<N0`0015;L00@005;LD]aBg0@000=C7@03001C7E<M00D000=?G`<000=C7@04001C7E<MDad7
00000e:k001B^`03D[/00`00D[]B^`02D[/00`00D[/00004000015;l001Bo5;l10000U;l00D005;l
D_`005;l00<0009Bo@03001BoE;m009Bo@<0009Bo003001Bo5;l009Bo08000Yoo`03001oogoo00]o
o`009Woo00<007ooOol0?7oo00D004EAAE55D@000095D@050015DDEAAE400003AE401000AE55D@00
0dEA00@004EAAE4000=5D@040015DDEA0003AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@03
0015D@00008000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9
TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI80
0003BI800`00BI99TP02BI801@00BI99TTVB000014VB00H004VBBI99TP00BI830004DYX00`00DYYB
VP02DYX00`00DYYBVP040002DUP00`00DUQBF002DUP00`00DUQBF002DUP00`00DUQBF0040002Bil5
0002DYX00`00DYYBVP02DYX01000DYYBVU:J10000e<N00<005<NDah01@000U;L00<005;LD]`00U;L
10000U<M00<005<MDad00U<M0`000dmO00<004mO00000P0000=C7@00Dad00e<M100000@oWP000000
00EB^`05001B^e:kD[/00003D[/60003D_`30002D_`00`00D_aBo002D_`01P00D_`00000D_d000AB
o@06001Bo@00001Bo00015;l00H005;l000005;m000:Ool00`00Oomoo`0;Ool002Moo`03001oogoo
03]oo`050015DDEAAE400002AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@040015DDEA0003
AE401000AE55D@000dEA00D004EAAE55D@0000=5D@050015DDEA0015D@040002BI801@00BI99TTVB
00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VB
BI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VB
BI99TP0000=9TP030019TTVB0099TP030019TP0000<0009BVP03001BVU:J009BVP03001BVU:J009B
VP<0009BF003001BF59H009BF003001BF59H009BF004001BF59HDUP30002Bil40002DYX00`00DYYB
VP03DYX01000DYYBVU:J10000e<N00<005<NDah010000U;L00<005;LD]`00e;L00H005;L000005<M
0005Dad01000Dad000000TmO00<004mOCel00`001E<M00D005<M000003nN00@0009B^`03001B^e:k
00=B^`03001B^e:k00P0009Bo0@00003D_`005;l00=Bo003001Bo5;l00<00005D_d005;mD_d00002
D_d30004D_`00`00D_aBo0030004D_d00`00Oomoo`07Ool00`00Oomoo`0;Ool002Qoo`03001oogoo
03Yoo`050015DDEAAE400002AE401@00AE55DDEA00000dEA00@004EAAE400095D@050015DDEAAE40
0003AE401000AE55D@000dEA00D004EAAE55D@0000=5D@030015D@0000800099TP050019TTVBBI80
0003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99
TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI800`00BI99TP02BI801@00BI99
TTVB00000dVB00D004VBBI99TP0000=9TP<0009BVP03001BVU:J009BVP06001BVU:JDYX005:J0`00
00=BF000DUP00e9H00D0059HDUQBF00000ABF004001BF0000002Bil30002DYX00`00DYYBVP02DYX0
0`00DYYBVP02DYX01P00DYX00000Dah000EC7P<0009Bg003001Bg5;L009Bg004001Bg5;LD]`30004
Dad01000DaeC7E<M10000TmO10000e<M00@005<MDaeC7@H0009B^`03001B^e:k009B^`04001B^e:k
D[/70003D_`00`00D_`000020005D_`00`00D_`000040002D_d00`00D_eBo@050002D_`00`00D_aB
o0050002D_d00`00D_eBo@030009Ool00`00Oomoo`0;Ool002Uoo`8003Yoo`050015DDEAAE400002
AE401@00AE55DDEA00000dEA00<004EA00000dEA00D004EAAE55D@0000=5D@040015DDEA0003AE40
1@00AE55DDEA00000TEA0`0000=9TP00BI800TVB00D004VBBI99TP0000=9TP050019TTVBBI800003
BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB
00000dVB00D004VBBI99TP0000A9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB100000=B
VP00DYX00e:J00D005:JDYYBVP00009BVP<000EBF005001BF59HDUP00003DUP01000DUQBF59H1000
00E;W`00001BVP0000ABVP03001BVU:J009BVP03001BVU:J00<000AC7P03001C7P0000800003D]`0
05;L00=Bg003001Bg5;L00D000=C7@03001C7E<M00D0009?G`@000=C7@03001C7E<M00L00003D[/0
05:k00AB^`04001B^e:kD[/500001CnN000005;l00000U;l10000e;l00<005;lD_`010000e;m00<0
05;mD_d0100000ABo000D_`0009Bo0@000=Bo@03001BoE;m00@000=Bo@03001oogoo00Ioo`03001o
ogoo00]oo`00:goo00<007ooOol0=goo00D004EAAE55D@000095D@050015DDEAAE400002AE401000
AE55D@000dEA00D004EAAE55D@0000=5D@040015DDEA0003AE401000AE55DDEA0`0000E9TP00BI99
TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019
TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800004BI80
1@00BI99TTVB00000dVB00H004VBBI99TP00BI830005DYX01@00DYYBVU:J00000U:J10000U9H00<0
059HDUP00e9H00D0059HDUQBF000009BF0D0009;W`<000ABVP05001BVU:JDYX00003DYX40003Dah0
0`00DaiC7P030005D]`01000D]aBg5;L0`0015<M00<005<MDad010000dmO10000U<M00<005<MDad0
0U<M0`000SnN0`0015:k00<005:kD[/00U:k00<005:k00000P000SnN0`000U;l10000e;l00<005;l
D_`010000e;m00<005;mD_d010000e;l00<005;lD_`010000e;m00<005;mD_d010000e;m00<005;m
D_d00`001goo00<007ooOol02goo000/Ool00`00Oomoo`0fOol01@00AE55DDEA00000TEA00@004EA
AE4000=5D@040015DDEA0003AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@030015D@000080
00=9TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI80
0003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI800`00BI99
TP02BI801@00BI99TTVB00000dVB00H004VBBI99TP00BI840002DYX00`00DYYBVP03DYX00`00DYYB
VP040002DUP00`00DUQBF002DUP00`00DUQBF002DUP01000DUQBF59H0`000T^O1@000U:J00<005:J
DYX00U:J00@005:JDYYBVP@000=C7P03001C7U<N00@0009Bg003001Bg5;L00=Bg006001Bg000001C
7@001E<M0`000dmO00H004mO000005<M0005Dad01@00Dad00000?ih010000U:k00<005:kD[/00U:k
00@005:kD[]B^`P00003D_`000000080009Bo003001Bo5;l009Bo0<0009Bo@03001BoE;m009Bo@<0
009Bo003001Bo5;l009Bo0@00003D_d005;m00=Bo@<000=Bo@03001BoE;m00@000=Bo@03001oogoo
00Aoo`03001oogoo00]oo`00;Goo00<007ooOol0=Goo00D004EAAE55D@000095D@040015DDEA0003
AE401000AE55D@000dEA00D004EAAE55D@0000=5D@050015DDEA0015D@040002BI801@00BI99TTVB
00000TVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VB
BI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VB
BI99TP0000=9TP060019TTVBBI8004VB10000U:J00<005:JDYX00U:J00<005:JDYX00U:J0`000U9H
00<0059HDUP00U9H00<0059HDUP00U9H00<0059HDUP00U9H0`000T^O0`000U:J00<005:JDYX00e:J
00H005:JDYYBVP00DYX20002Dah00`00DaiC7P02Dah30002D]`00`00D]aBg002D]`01000D]aBg5;L
0`0015<M00<005<M00000P0000=?G`00Cel00TmO0`0015<M00@005<MDaeC7@H0009B^`03001B^e:k
009B^`03001B^e:k00P000=Bo0<0009Bo003001Bo5;l009Bo006001Bo000001Bo@0015;m00H005;m
000005;l0004D_`01P00D_`00000D_d0009Bo@04001Bo@00D_d200000e;m001Bo@03D_d30002D_d0
0`00D_eBo@02D_d20006Ool00`00Oomoo`0:Ool002ioo`03001oogoo03Aoo`050015DDEAAE400002
AE401000AE55D@000dEA00@004EAAE4000=5D@050015DDEAAE400003AE400`00AE4000020002BI80
1@00BI99TTVB00000dVB00@004VBBI8000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB
00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00<004VBBI800TVB
00D004VBBI99TP0000=9TP050019TTVBBI800002BI830002DYX00`00DYYBVP02DYX00`00DYYBVP02
DYX01P00DYX00000DUP000ABF005001BF59HDUP00004DUP00`00DUQBF00400001D^O000005:J0000
15:J00<005:JDYX00U:J00<005:JDYX00`001E<N00H005<N000005;L0004D]`00`00D]aBg0050003
Dad00`00DaeC7@040002Cel50003Dad00`00DaeC7@060002D[/00`00D[]B^`03D[/01000D[]B^e:k
1`000e;l00H005;l000005;l0004D_`00`00D_aBo0030004D_d00`00D_eBo@030004D_`00`00D_aB
o0030004D_d00`00D_eBo@030004D_d400000e;m001Bo@03D_d400000e;m001oo`05Ool00`00Oomo
o`0:Ool002moo`8003Aoo`040015DDEA0002AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@06
0015DDEAAE4004EA100000=9TP00BI800TVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00
BI99TTVB00000dVB00D004VBBI99TP0000=9TP030019TTVB0099TP040019TTVB0003BI801@00BI99
TTVB00000dVB00<004VBBI800TVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI8300000e:J
001BVP03DYX00`00DYYBVP02DYX00`00DYYBVP030004DUP01@00DUQBF59H00000e9H00@0059HDUQB
F0@0009;W`<000ABVP03001BVU:J009BVP03001BVU:J00@000=C7P04001C7U<NDah30004D]`01000
D]aBg5;L0`0015<M00<005<MDad010000dmO0`000e<M00@005<MDaeC7@@00005?ih00000D[/00004
D[/00`00D[]B^`02D[/00`00D[/000040003D_`00`00D_aBo0030004D_`00`00D_aBo0040003D_d0
0`00D_eBo@040003D_`00`00D_aBo0040002D_d01000D_eBoE;m100000=Bo@0000000U;m0`001E;m
00<005;m00000P001E;m00<007ooOol00goo00<007ooOol02Woo000aOol00`00Oomoo`0aOol01000
AE55D@000TEA00D004EAAE55D@0000=5D@040015DDEA0003AE400`00AE55D@030002BI801000BI99
TP000dVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VBBI99
TP0000A9TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000A9TP050019
TTVBBI800003BI801P00BI99TTVB0019TP<000ABVP05001BVU:JDYX00003DYX40002DUP00`00DUQB
F002DUP01@00DUQBF59H00000U9H1@000T^O10000U:J00<005:JDYX00U:J00@005:JDYYBVP@000=C
7P03001C7U<N00D0009Bg003001Bg5;L009Bg006001Bg000001C7@001E<M0`000dmO00H004mO0000
05<M0004Dad40002?ih30004D[/01@00D[]B^e:k00000e:k1P0000ABo000D_aBo0@000=Bo003001B
o5;l00@000=Bo@03001BoE;m00@0009Bo004001Bo5;lD_`40002D_d00`00D_eBo@050002D_d00`00
D_eBo@040003D_d00`00D_eBo@040003D_d00`00D_eBo@030005Ool00`00Oomoo`0:Ool0039oo`03
001oogoo031oo`040015DDEA0002AE401@00AE55DDEA00000dEA00@004EAAE4000=5D@<00003BI80
04VB0099TP040019TTVB0003BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP050019TTVBBI80
0003BI800`00BI99TP02BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP050019TTVBBI800004
BI801@00BI99TTVB00000dVB00H004VBBI99TP00BI840002DYX00`00DYYBVP02DYX00`00DYYBVP05
0002DUP00`00DUQBF002DUP01@00DUQBF59H00000e9H0`000d^O10000U:J00<005:JDYX00U:J00@0
05:JDYYBVP@000=C7P03001C7U<N00@0009Bg003001Bg5;L00=Bg003001Bg5;L00<000AC7@03001C
7@000080009?G`03001?GdmO00<000AC7@05001C7@00000oWP050002D[/00`00D[]B^`02D[/00`00
D[]B^`090002D_`40003D_`00`00D_aBo0040003D_d00`00D_eBo@040002D_`00`00D_aBo0050002
D_d00`00D_eBo@040003D_d00`00D_eBo@04000015;m001Bo@000U;m10000e;m00<005;mD_d01000
0e;m00<007ooOol00Woo00<007ooOol02Woo000cOol00`00Oomoo`0^Ool01@00AE55DDEA00000TEA
00D004EAAE55D@0000=5D@050015DDEA0015D@030003BI801@00BI99TTVB00000TVB00D004VBBI99
TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00<004VBBI800TVB00D004VBBI99
TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB000014VB00D004VBBI99TP0000=9TP060019
TTVBBI8004VB10000U:J00<005:JDYX00U:J00@005:JDYYBVP<0009BF003001BF59H00=BF005001B
F59HDUP00004DUP30002Bil40002DYX00`00DYYBVP02DYX01P00DYYBVU:J001BVP80009C7P03001C
7U<N009C7P<0009Bg003001Bg5;L009Bg004001Bg5;LD]`40003Dad00`00DaeC7@040003Cel40003
Dad00`00DaeC7@060002D[/00`00D[]B^`03D[/00`00D[]B^`090002D_`40003D_`00`00D_aBo004
0002D_d01000D_eBoE;m10000U;l00<005;lD_`010000e;m00<005;mD_d010000e;m00<005;mD_d0
10000e;m00<005;mD_d010000e;m00<005;mD_d010000U;m00@005;mD_eBo@<000=oo`03001oogoo
00Yoo`00=7oo0P00;Woo00D004EAAE55D@000095D@050015DDEAAE400003AE400`00AE4000020002
BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP050019TTVBBI800003BI801000BI99TP000dVB
00D004VBBI99TP0000A9TP050019TTVBBI800003BI801@00BI99TTVB00000TVB00<004VBBI800TVB
00D004VBBI99TP0000=9TP050019TTVBBI800002BI830002DYX00`00DYYBVP02DYX01P00DYYBVU:J
001BVP800003DUP0059H00=BF003001BF59H009BF005001BF59HDUP00002DUP400001D^O000005:J
00001E:J00D005:JDYYBVP00009BVP<000EC7P06001C7P00001Bg00015;L00<005;LD]`01@000e<M
00<005<MDad010000TmO1@000e<M00<005<MDad0100000DoWP00001B^`0000AB^`03001B^e:k009B
^`P0009Bo0@0009Bo003001Bo5;l009Bo0<0009Bo@04001BoE;mD_d40002D_`01000D_aBo5;l0`00
0U;m00<005;mD_d00U;m0`000U;m00<005;mD_d00U;m0`000e;m00<005;mD_d0100000=Bo@000000
0e;m10000U;m00<005;mD_d01@000U;m00<007ooOol00Woo00<007ooOol02Goo000fOol00`00Oomo
o`0[Ool01@00AE55DDEA00000TEA00H004EAAE55D@00AE4400000dVB0019TP02BI801@00BI99TTVB
00000dVB00@004VBBI8000=9TP050019TTVBBI800003BI801000BI99TP000dVB00<004VBBI800TVB
00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP00
00=9TP040019TTVBBI8300000e:J001BVP03DYX01@00DYYBVU:J00000U:J0`00159H00<0059HDUP0
0U9H00D0059HDUQBF000009BF0@0009;W`<000ABVP03001BVU:J009BVP03001BVU:J00@000=C7P04
001C7U<NDah30004D]`01000D]aBg5;L0`0015<M00<005<MDad010000dmO0`000U<M00<005<MDad0
0e<M0`000SnN0`0015:k00H005:kD[]B^`00D[/300000cnN00000004D_`30002D_`00`00D_aBo002
D_`01P00D_`00000D_d000ABo@<00003D_`005;l00ABo0<00003D_d005;m00=Bo@06001Bo@00001B
o@0015;m00H005;m000005;m0004D_d30002D_d00`00D_eBo@050002D_d00`00D_eBo@040003D_d0
0`00D_eBo@030003Ool00`00Oomoo`09Ool003Moo`03001oogoo02Yoo`050015DDEAAE400002AE40
0`00AE4000030002BI801000BI99TP000dVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00
BI99TTVB00000dVB00@004VBBI8000A9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D0
04VBBI99TP0000=9TP050019TTVBBI800003BI801P00BI99TTVB0019TP<000ABVP05001BVU:JDYX0
0002DYX40002DUP00`00DUQBF002DUP00`00DUQBF002DUP00`00DUQBF0040002Bil40002DYX00`00
DYYBVP03DYX01000DYYBVU:J0`000e<N00<005<NDah01@000U;L00<005;LD]`00U;L00H005;L0000
05<M0005Dad30003Cel01P00Cel00000Dad000AC7@03001C7@0000800003?ih000000080009B^`03
001B^e:k009B^`03001B^e:k00<00004?ih000000002D_`01P00D_`00000D_`000ABo003001Bo5;l
00<000ABo@03001Bo@00008000ABo003001Bo5;l00<000ABo@03001BoE;m00<000ABo@03001BoE;m
00<000ABo@06001Bo@00001Bo@0015;m1@0015;m0`000e;m00<005;mD_d010000e<M00@007ooOol0
00]oo`00>7oo00<007ooOol0:Goo00H004EAAE55D@00AE430002BI801@00BI99TTVB00000TVB00D0
04VBBI99TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9
TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI80
0003BI801P00BI99TTVB0019TP@0009BVP03001BVU:J009BVP03001BVU:J00@0009BF003001BF59H
009BF003001BF59H009BF004001BF59HDUP30002Bil40002DYX00`00DYYBVP02DYX00`00DYYBVP02
DYX01000DYX000000U<N00<005<NDah010000e;L00<005;LD]`00U;L00<005;LD]`00`0015<M00<0
05<M00000P000TmO00<004mOCel00`0015<M00<005<MDad01`000U:k00<005:kD[/00U:k00<005:k
D[/0200000ABo000D_aBo0<000ABo003001Bo5;l00@0009Bo@03001BoE;m00@000=Bo003001Bo5;l
00@000=Bo@03001BoE;m00@000=Bo@03001BoE;m00@0009Bo@04001BoE;mD_d30004D_d00`00D_d0
00020003D_d200001E;m000005;m000015;m0`000U<M00@005<MDaeC7@<00003Ool007oo00Yoo`00
>Goo0P00:Goo00@004EAAE55D@800003BI8004VB0099TP050019TTVBBI800002BI801@00BI99TTVB
00000dVB00D004VBBI99TP000099TP050019TTVBBI800003BI800`00BI99TP02BI801000BI99TP00
0dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000dVB00H004VBBI99
TP00BI840002DYX00`00DYYBVP02DYX01000DYYBVU:J0`000U9H00<0059HDUP00U9H00<0059HDUP0
0U9H00H0059HDUQBF000DUP20002Bil30002DYX00`00DYYBVP02DYX00`00DYYBVP02DYX00`00DYYB
VP030004Dah30002D]`00`00D]aBg003D]`00`00D]aBg0040003Dad00`00DaeC7@040003Cel40003
Dad00`00DaeC7@060002D[/00`00D[]B^`03D[/00`00D[]B^`08000015;l001Bo5;l10000e;l00<0
05;lD_`010000U;m00<005;mD_d010000e;l00<005;lD_`010000e;m00<005;mD_d010000e;m00<0
05;mD_d010000U;m00<005;mD_d01@000U;m00<005;mD_d010000e;m00<005;mD_d00`0015;m00H0
05;m000005<M0003Dad40002D_d00`00Ool0000;Ool003]oo`03001oogoo02Ioo`030015D@000080
0099TP050019TTVBBI800003BI801000BI99TP000dVB00D004VBBI99TP0000=9TP040019TTVB0003
BI801@00BI99TTVB000014VB00@004VBBI8000=9TP050019TTVBBI800003BI801@00BI99TTVB0000
0dVB00D004VBBI99TP0000=9TP030019TTVB00<0009BVP03001BVU:J009BVP06001BVU:JDYX005:J
0P0000=BF000DUP00e9H00D0059HDUQBF00000ABF003001BF59H00@00005Bil00000DYX00004DYX0
1@00DYYBVU:J00000e:J10000e<N00H005<N000005;L0004D]`01000D]aBg5;L10000e<M00<005<M
Dad010000TmO1@000e<M00<005<MDad0100000DoWP00001B^`0000AB^`03001B^e:k009B^`L00004
D_`005;lD_`40003D_`00`00D_aBo0040002D_d00`00D_eBo@040003D_`00`00D_aBo0040003D_d0
0`00D_eBo@040003D_d00`00D_eBo@040002D_d00`00D_eBo@040003D_d00`00D_eBo@040003D_d0
0`00D_eBo@04000015;m001Bo@000U;m0`0015<M0`0000=Bo@00D_d015;m0P002goo000lOol00`00
Oomoo`0UOol20002BI801000BI99TP000dVB00D004VBBI99TP000099TP050019TTVBBI800003BI80
1@00BI99TTVB00000TVB00D004VBBI99TP0000A9TP050019TTVBBI800002BI801@00BI99TTVB0000
0dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801000BI99TTVB0`0000=BVP00DYX00e:J
00D005:JDYYBVP00009BVP<000ABF005001BF59HDUP00003DUP01000DUQBF59H10000T^O0`0015:J
00D005:JDYYBVP00009BVPD000=C7P03001C7U<N00<000ABg004001Bg5;LD]`40003Dad00`00DaeC
7@040003Cel30002Dad00`00DaeC7@03Dad30002?ih30004D[/01P00D[]B^e:k001B^`<00005?ih0
0000D_`00002D_`40003D_`00`00D_aBo0040002D_d00`00D_eBo@040003D_`00`00D_aBo0040003
D_d00`00D_eBo@040003D_d00`00D_eBo@040002D_d00`00D_eBo@040003D_d00`00D_eBo@040003
D_d00`00D_eBo@040002D_d01000D_eBoE;m10000U<M00<005<MDad00`0015;m00<005;mD_d01000
2goo000mOol00`00Oomoo`0TOol01@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP040019TTVB
0003BI801@00BI99TTVB00000dVB00@004VBBI8000A9TP050019TTVBBI800003BI801000BI99TP00
0dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801P00BI99TTVB0019TP<000ABVP05001B
VU:JDYX00002DYX40002DUP00`00DUQBF002DUP01@00DUQBF59H00000U9H1@000T^O10000U:J00<0
05:JDYX00U:J00<005:JDYX0100015<N00<005<NDah010000U;L00<005;LD]`00U;L00@005;L0000
009C7@03001C7E<M009C7@<000=?G`06001?G`00001C7@0015<M00<005<M00000P0000<oWP000000
0P000U:k00<005:kD[/00U:k00<005:kD[/00`0000@oWP000000009Bo0@0009Bo003001Bo5;l009B
o0<0009Bo@04001BoE;mD_d30002D_`00`00D_aBo002D_`30002D_d00`00D_eBo@02D_d30003D_d0
0`00D_eBo@040002D_d00`00D_eBo@040003D_d00`00D_eBo@040003D_d00`00D_eBo@040002D_d0
0`00D_eBo@0500000e<M00000002Dad40003D_d00`00D_eBo@040003Dad2000:Ool003ioo`8002Ao
o`050019TTVBBI800002BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP050019TTVBBI800003
BI801@00BI99TTVB00000dVB00D004VBBI99TP0000=9TP040019TTVB0003BI801@00BI99TTVB0000
0dVB00D004VBBI99TP0000=9TP030019TP0000<0009BVP03001BVU:J009BVP03001BVU:J00@0009B
F003001BF59H009BF005001BF59HDUP00003DUP40002Bil40002DYX00`00DYYBVP02DYX01000DYYB
VU:J0`0015<N00<005<NDah010000U;L00<005;LD]`00U;L00<005;LD]`00`001E<M00@005<M0000
009?G`03001?GdmO00<000AC7@03001C7E<M00L0009B^`03001B^e:k009B^`03001B^e:k00P0009B
o0<0009Bo003001Bo5;l009Bo006001Bo000001Bo@0015;m00D005;m001Bo00000ABo006001Bo000
001Bo@0015;m00H005;m000005;m0004D_d30002D_d01000D_eBoE;m0`000e;m00<005;mD_d01000
0e;m00<005;mD_d010000U;m00<005;mD_d010000e<M00<005<MDad010000e;m00<005;mD_d01000
0U<M00@005<MDaeC7@<000Yoo`00@7oo00<007ooOol08Goo00D004VBBI99TP000099TP050019TTVB
BI800003BI801000BI99TP000dVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99
TTVB00000dVB00@004VBBI8000=9TP050019TTVBBI800003BI801P00BI99TTVB0019TP@0009BVP03
001BVU:J009BVP04001BVU:JDYX30002DUP00`00DUQBF002DUP01@00DUQBF59H0000159H0`000d^O
0`000U:J00<005:JDYX00U:J00H005:JDYYBVP00DYX200000e<N001C7P04Dah30002D]`00`00D]aB
g002D]`00`00D]aBg0040003Dad01000DaeC7E<M10000TmO10000e<M00<005<MDad01P000U:k00<0
05:kD[/00e:k00<005:kD[/020000U;l00H005;l000005;l0004D_`00`00D_aBo0030004D_d00`00
D_eBo@030003D_`00`00D_aBo0030004D_d00`00D_eBo@030004D_d01P00D_d00000D_d000ABo@<0
0003D_d005;m00=Bo@<000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=C7@03001C7E<M00@0
0004D_d005;m0002D_d40002Dad00`00DaeC7@050002Ool00`00Oomoo`08Ool0045oo`03001oogoo
021oo`050019TTVBBI800002BI801@00BI99TTVB00000dVB00@004VBBI8000=9TP030019TTVB0099
TP040019TTVB0003BI801@00BI99TTVB00000dVB00D004VBBI99TP000099TP050019TTVBBI800003
BI801P00BI99TTVB0019TP@0009BVP03001BVU:J009BVP06001BVU:JDYX005:J0P0000=BF000DUP0
0e9H00D0059HDUQBF00000=BF003001BF59H00D00005Bil00000DYX00004DYX01@00DYYBVU:J0000
0U:J0`0015<N00<005<N00000P0000=Bg000D]`00e;L00<005;LD]`010000e<M00<005<MDad01@00
0TmO10000e<M00<005<MDad01P000U:k00<005:kD[/00U:k00<005:kD[/00U:k1`000e;l00<005;l
00000P0015;l00<005;lD_`010000e;m00<005;mD_d010000U;l00<005;lD_`010000e;m00<005;m
D_d010000e;m00<005;mD_d00`0015;m00<005;m00000P0015;m00H005;m000005;m0004D_d30002
D_d01000D_eBoE;m0`000e<M00<005<MDad010000e;m00<005;mD_d010000U<M00<005<MDad01000
1goo00<007ooOol027oo0012Ool00`00Oomoo`0OOol01@00BI99TTVB00000TVB00D004VBBI99TP00
00=9TP040019TTVB0003BI800`00BI99TP02BI801000BI99TP000dVB00D004VBBI99TP0000=9TP05
0019TTVBBI800002BI801@00BI99TTVB00000dVB00<004VBBI800`000U:J00<005:JDYX00U:J00D0
05:JDYYBVP00009BVP<000ABF005001BF59HDUP00003DUP00`00DUQBF0050002Bil30004DYX01@00
DYYBVU:J00000U:J10000e<N00<005<NDah00`001E;L00<005;LD]`010000e<M00<005<MDad01000
14mO0`000e<M00<005<MDad0100000DoWP00001B^`0000AB^`03001B^e:k009B^`03001B^`0000@0
00=Bo003001Bo5;l00<000=Bo003001Bo5;l00@000=Bo@03001BoE;m00@0009Bo003001Bo5;l00@0
00=Bo@03001BoE;m00@000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=Bo@03001BoE;m00<0
00ABo@06001Bo@00001Bo@0015;m0`000U<M00<005<MDad010000e;m00<005;mD_d0100000=C7@00
00000U<M10002goo00<007ooOol027oo0013Ool2000OOol01@00BI99TTVB00000TVB00D004VBBI99
TP0000=9TP040019TTVB0004BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP050019TTVB
BI800003BI801000BI99TP000dVB00@004VBBI99TP<00003DYX005:J00=BVP05001BVU:JDYX00002
DYX40002DUP00`00DUQBF002DUP01@00DUQBF59H00000U9H1@000T^O10000U:J00<005:JDYX00U:J
00<005:JDYX010000e<N00<005<NDah010000e;L00<005;LD]`00U;L0`000U<M00<005<MDad00U<M
0`000dmO00<004mO00000P0000=C7@00Dad00e<M0`000SnN0`0015:k00D005:kD[]B^`0000=B^`@0
00=Bo003001Bo5;l00@0009Bo003001Bo5;l00@000=Bo@03001BoE;m00@0009Bo003001Bo5;l00@0
00=Bo@03001BoE;m00@000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=Bo@03001BoE;m00@0
00=Bo@03001BoE;m00<000ABo@03001Bo@00008000AC7@<0009Bo@04001BoE;mD_d40002Dad00`00
DaeC7@04000?Ool00`00Oomoo`08Ool004Eoo`03001oogoo01aoo`050019TTVBBI800002BI801@00
BI99TTVB00000dVB00D004VBBI99TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB00000dVB
00D004VBBI99TP0000=9TP040019TTVB0003BI800`00BI8000020004DYX01@00DYYBVU:J00000U:J
10000U9H00<0059HDUP00U9H00D0059HDUQBF00000=BF0@0009;W`@0009BVP03001BVU:J009BVP04
001BVU:JDYX30003Dah00`00DaiC7P040003D]`00`00D]aBg002D]`01P00D]`00000Dad000AC7@04
001C7@000002Cel00`00Cem?G`040004Dad01@00Dad00000?ih010000U:k00<005:kD[/00U:k00<0
05:kD[/01`0000ABo000D_aBo0@0009Bo003001Bo5;l00@000=Bo@03001BoE;m00@000=Bo003001B
o5;l00<000=Bo@03001BoE;m00@000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=Bo@03001B
oE;m00@000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=C7@06001C7@00001Bo@000e;m1000
0U<M00<005<MDad0100000=oo`00Ool047oo00<007ooOol027oo0016Ool00`00Oomoo`0KOol01@00
BI99TTVB00000TVB00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TTVB00000TVB
00D004VBBI99TP0000=9TP050019TTVBBI800003BI801@00BI99TP00BI8010000U:J00<005:JDYX0
0U:J00<005:JDYX010000U9H00<0059HDUP00U9H00D0059HDUQBF00000ABF0<0009;W`@0009BVP03
001BVU:J009BVP06001BVU:JDYX005:J0P0000=C7P00Dah00e<N0`000e;L00<005;LD]`00U;L00<0
05;LD]`00`0015<M00<005<MDad010000TmO100015<M00<005<MDad01P000U:k00<005:kD[/00U:k
00<005:kD[/02@000U;l10000e;l00<005;lD_`00`000e;m00<005;mD_d010000e;l00<005;lD_`0
10000U;m00<005;mD_d010000e;m00<005;mD_d010000U;m00<005;mD_d010000e;m00<005;mD_d0
10000e;m00<005;mD_d010000U;m00<005;mD_d010000e<M00<005<MDad00`0015;m0`0000=C7@00
Dad00e<M0`001Woo00<007ooOol03goo00<007ooOol01goo0017Ool00`00Oomoo`0JOol01@00BI99
TTVB00000TVB00<004VBBI800TVB00@004VBBI8000=9TP050019TTVBBI800003BI801000BI99TP00
0dVB00D004VBBI99TP0000=9TP060019TTVBBI8004VB0`000U:J00<005:JDYX00U:J00@005:JDYYB
VP<0009BF003001BF59H009BF005001BF59HDUP00003DUP00`00DUQBF0070002DYX00`00DYYBVP02
DYX01@00DYYBVU:J00000U:J0`0015<N00@005<N0000009Bg003001Bg5;L009Bg003001Bg5;L00@0
00=C7@03001C7E<M00@0009?G`@000AC7@03001C7E<M00H0009B^`03001B^e:k009B^`03001B^e:k
00T0009Bo0@000=Bo003001Bo5;l00@0009Bo@03001BoE;m00@000=Bo003001Bo5;l00@0009Bo@03
001BoE;m00@000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=Bo@03001BoE;m00@000=Bo@03
001BoE;m00@0009Bo@03001BoE;m00@000=C7@03001C7E<M00@0009Bo@03001BoE;m00<000AC7@04
001C7@000009Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool004Qoo`8001Yoo`050019TTVBBI800003
BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB
00000dVB00H004VBBI99TP00BI8400000e:J001BVP03DYX00`00DYYBVP02DYX01@00DYX0059H0000
159H00<0059HDUP00U9H00@0059HDUP0009BF0D00005Bil00000DYX00004DYX01@00DYYBVU:J0000
0U:J10000e<N00<005<NDah00`001E;L00<005;LD]`010000e<M00<005<MDad010000TmO10000e<M
00@005<MDaeC7@@00005?ih00000D[/00004D[/01000D[]B^e:k20000U;l10000U;l00<005;lD_`0
0U;l0`000U;m00@005;mD_eBo@<0009Bo003001Bo5;l009Bo0<0009Bo@04001BoE;mD_d30002D_d0
0`00D_eBo@02D_d30003D_d00`00D_eBo@030003D_d00`00D_eBo@040003D_d00`00D_eBo@040002
D_d00`00D_eBo@040003Dad00`00DaeC7@040002D_d00`00D_eBo@040003Dad00`00DaeC7@03000<
Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool004Yoo`03001oogoo01Moo`050019TTVBBI800003BI80
1@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB0000
0dVB00<004VBBI800`000U:J00D005:JDYYBVP0000ABVP03001BVU:J00<000=BF003001BF59H009B
F005001BF59HDUP00002DUP40002Bil30004DYX01@00DYYBVU:J00000U:J10000e<N00<005<NDah0
10000e;L00<005;LD]`00U;L0`000e<M00<005<MDad010000dmO0`000e<M00<005<MDad01@000SnN
0`0015:k00H005:kD[]B^`00D[/5000015;l001Bo5;l0`000U;l00<005;lD_`00U;l00H005;l0000
05;m0004D_d300000e;l001Bo003D_`01P00D_`00000D_d000ABo@<00003D_d005;m00=Bo@06001B
o@00001Bo@0015;m0`000U;m00<005;mD_d010000e;m00<005;mD_d010000U;m00<005;mD_d01000
0e<M00<005<MDad010000U;m00<005;mD_d010000e<M00<005<MDad0100047oo00<007ooOol03Goo
00<007ooOol01goo001;Ool00`00Oomoo`0FOol01@00BI99TTVB00000dVB00D004VBBI99TP000099
TP050019TTVBBI800003BI801@00BI99TTVB00000TVB00D004VBBI99TP0000=9TP<00003DYX005:J
00=BVP05001BVU:JDYX00002DYX40002DUP01@00DUQBF59H0000159H00<0059HDUP010000T^O1000
0U:J00<005:JDYX00U:J00<005:JDYX010000e<N00<005<NDah010000e;L00<005;LD]`00U;L00H0
05;L000005<M0004Dad30003Cel01P00Cel00000Dad000AC7@@0008oWP@0009B^`03001B^e:k009B
^`03001B^e:k00D000ABo0<00003D_`005;l00=Bo003001Bo5;l00<000ABo@03001BoE;m008000AB
o003001Bo5;l00<000ABo@03001BoE;m008000ABo@03001BoE;m00<000ABo@06001Bo@00001Bo@00
0e;m0`000e;m00<005;mD_d010000U;m00<005;mD_d010000e<M00<005<MDad010000U;m00<005;m
D_d010000e<M00<005<MDad010005Goo00<007ooOol037oo00<007ooOol01goo001<Ool00`00Oomo
o`0EOol01@00BI99TTVB00000dVB00D004VBBI99TP000099TP050019TTVBBI800003BI801@00BI99
TTVB00000TVB00H004VBBI99TP00BI830004DYX01@00DYYBVU:J00000U:J10000U9H00<0059HDUP0
0U9H00D0059HDUQBF00000=BF0<0009;W`@0009BVP03001BVU:J009BVP04001BVU:JDYX30003Dah0
0`00DaiC7P040003D]`00`00D]aBg002D]`00`00D]aBg0030004Dad01000Dad000000TmO00<004mO
Cel00`0015<M00@005<M0000008oWP@0009B^`03001B^e:k009B^`03001B^e:k00L0009Bo006001B
o000001Bo0000e;l00<005;lD_`010000e;m00<005;mD_d010000U;l00<005;lD_`010000e;m00<0
05;mD_d010000U;m00<005;mD_d010000e;m00<005;mD_d00`0015;m0`0000=Bo@00D_d00e;m0`00
0U;m00<005;mD_d010000e<M00<005<MDad010000U;m00<005;mD_d010000e<M00<005<MDad01000
6Goo00<007ooOol037oo00<007ooOol01goo001=Ool2000EOol01@00BI99TTVB00000dVB00D004VB
BI99TP000099TP050019TTVBBI800003BI801@00BI99TTVB00000TVB00<004VB00000`000U:J00<0
05:JDYX00U:J00<005:JDYX010000U9H00<0059HDUP00U9H00D0059HDUQBF00000=BF005001BF000
001;W`040002DYX00`00DYYBVP02DYX01P00DYYBVU:J001BVP80009C7P03001C7U<N00@000=Bg003
001Bg5;L009Bg003001Bg5;L00@000=C7@03001C7E<M00@0009?G`@000=C7@03001C7E<M00L0009B
^`03001B^e:k009B^`03001B^e:k00P00004D_`005;lD_`30004D_`00`00D_`000030003D_d00`00
D_eBo@040002D_`00`00D_aBo0040003D_d00`00D_eBo@040002D_d00`00D_eBo@040003D_d00`00
D_eBo@040002D_d00`00D_eBo@030004D_d01P00D_d00000D_d000=Bo@<000=C7@03001C7E<M00@0
00=Bo@03001BoE;m00<000=C7@03001C7E<M00@001ioo`03001oogoo00]oo`03001oogoo00Moo`00
Cgoo00<007ooOol04Woo00D004VBBI99TP0000=9TP050019TTVBBI800002BI801@00BI99TTVB0000
0dVB00H004VBBI99TP00BI830002DYX00`00DYYBVP02DYX01000DYYBVU:J0`000U9H00<0059HDUP0
0U9H00D0059HDUQBF00000=BF003001BF59H00H0009BVP03001BVU:J009BVP05001BVU:JDYX00002
DYX30004Dah30003D]`00`00D]aBg002D]`00`00D]aBg0040003Dad00`00DaeC7@040002Cel40003
Dad00`00DaeC7@060002D[/00`00D[]B^`03D[/00`00D[]B^`08000015;l001Bo5;l10000e;l00<0
05;lD_`00`000e;m00<005;mD_d010000e;l00<005;lD_`00`000e;m00<005;mD_d010000e;m00<0
05;mD_d00`000e;m00<005;mD_d010000e;m00<005;mD_d00`000e;m00<005;mD_d00`0015;m00<0
05;m00000U<M00<005<MDad010000e;m00<005;mD_d010000U<M00<005<MDad010008goo00<007oo
Ool02goo00<007ooOol01Woo001@Ool00`00Oomoo`0AOol01@00BI99TTVB00000dVB00D004VBBI99
TP000099TP050019TTVBBI800003BI800`00BI80000300000e:J001BVP03DYX01P00DYYBVU:J001B
VP800003DUP0059H00=BF005001BF59HDUP00003DUP00`00DUQBF00400001D^O000005:J000015:J
00D005:JDYYBVP00009BVP@000=C7P04001C7P000002D]`00`00D]aBg002D]`00`00D]aBg0040003
Dad00`00DaeC7@040002Cel40003Dad00`00DaeC7@060002D[/00`00D[]B^`02D[/00`00D[]B^`02
D[/7000015;l001Bo5;l10000e;l00<005;lD_`010000U;m00<005;mD_d010000e;l00<005;lD_`0
10000U;m00<005;mD_d010000e;m00<005;mD_d010000U;m00<005;mD_d010000e;m00<005;mD_d0
10000U;m00<005;mD_d010000e;m00<005;mD_d00`000e<M0`000e;m00<005;mD_d010000U<M00<0
05<MDad01000:7oo00<007ooOol02Woo00<007ooOol01Woo001AOol00`00Oomoo`0@Ool01@00BI99
TTVB00000dVB00D004VBBI99TP000099TP060019TTVBBI8004VB10000U:J00D005:JDYYBVP0000=B
VP03001BVU:J00<000ABF005001BF59HDUP00003DUP00`00DUQBF0040002Bil30004DYX01@00DYYB
VU:J00000U:J100015<N00<005<NDah00P001E;L00<005;LD]`010000e<M00<005<MDad010000TmO
10000e<M00<005<MDad0100000DoWP00001B^`0000AB^`03001B^e:k009B^`03001B^`0000@0009B
o003001Bo5;l00<000=Bo003001Bo5;l00@000=Bo@03001BoE;m00<000=Bo003001Bo5;l00@0009B
o@03001BoE;m00@000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=Bo@03001BoE;m00@0009B
o@03001BoE;m00@000=Bo@03001BoE;m00@0009C7@06001C7@00001Bo@0015;m0`000U<M00<005<M
Dad01000;7oo00<007ooOol02Woo00<007ooOol01Woo001BOol2000@Ool01@00BI99TTVB00000dVB
00D004VBBI99TP000099TP030019TTVB00<0009BVP03001BVU:J009BVP05001BVU:JDYX00002DYX3
0002DUP00`00DUQBF002DUP01@00DUQBF59H00000U9H1@000T^O0`000e:J00D005:JDYYBVP00009B
VP@000AC7P03001C7U<N00@0009Bg003001Bg5;L009Bg0<000=C7@03001C7E<M00@000=?G`<0009C
7@03001C7E<M009C7@@0008oWP8000AB^`03001B^e:k009B^`03001B^e:k00@0009Bo003001Bo5;l
00@0009Bo003001Bo5;l00@000=Bo@03001BoE;m00@0009Bo003001Bo5;l00@000=Bo@03001BoE;m
00<000=Bo@03001BoE;m00@000=Bo@03001BoE;m00<000=Bo@03001BoE;m00@0009Bo@03001BoE;m
00@000=Bo@03001BoE;m00@0009C7@03001C7E<M00<000ABo@06001Bo@00001C7@000U<M1000<Goo
00<007ooOol02Goo00<007ooOol01Woo001DOol00`00Oomoo`0=Ool01@00BI99TTVB00000dVB00D0
04VBBI99TP000099TP<00003DYX005:J00=BVP05001BVU:JDYX00002DYX400000e9H001BF003DUP0
1@00DUQBF59H00000U9H1@000T^O100000=BVP00DYX015:J00<005:JDYX00`0015<N00<005<NDah0
10000U;L00<005;LD]`00U;L00H005;L000005<M0004Dad30003Cel01P00Cel00000Dad000AC7@04
001C7@000002?ih40002D[/00`00D[]B^`02D[/00`00D[]B^`05000015;l001Bo5;l10000e;l00<0
05;lD_`00`000e;m00<005;mD_d010000e;l00<005;lD_`00`000e;m00<005;mD_d010000U;m00<0
05;mD_d010000e;m00<005;mD_d010000U;m00<005;mD_d010000e;m00<005;mD_d00`000e;m00<0
05;mD_d010000U<M00<005<MDad010000e;m00<005;mD_d00`000e<M0`00=Woo00<007ooOol027oo
00<007ooOol01Woo001EOol00`00Oomoo`0<Ool01@00BI99TTVB00000dVB00H004VBBI99TP00BI82
0004DYX01@00DYYBVU:J00000U:J10000U9H00D0059HDUQBF00000ABF003001BF59H00@0009;W`@0
009BVP05001BVU:JDYX00004DYX30003Dah00`00DaiC7P040002D]`00`00D]aBg002D]`00`00D]aB
g0030004Dad01000Dad000000TmO00<004mOCel00`0015<M00<005<MDad01`000U:k00<005:kD[/0
0U:k00<005:kD[/020000U;l0`000e;l00<005;lD_`010000U;m00<005;mD_d010000e;l00<005;l
D_`010000U;m00<005;mD_d010000e;m00<005;mD_d00`000e;m00<005;mD_d010000U;m00<005;m
D_d010000e;m00<005;mD_d010000U;m00<005;mD_d010000e<M00<005<MDad00`000e;m00<005;m
D_d010000U<M00@005<M000003Uoo`03001oogoo00Qoo`03001oogoo00Ioo`00EWoo00<007ooOol0
2goo00D004VBBI99TP0000=9TP030019TP0000<00003DYX005:J00=BVP03001BVU:J00@0009BF003
001BF59H009BF005001BF59HDUP00003DUP00`00DUP00002Bil40002DYX00`00DYYBVP02DYX01P00
DYYBVU:J001BVP800003Dah005<N00=C7P<0009Bg003001Bg5;L009Bg003001Bg5;L00@000=C7@03
001C7E<M00@0009?G`@000=C7@03001C7E<M00L0009B^`03001B^e:k009B^`03001B^e:k00P0009B
o0@0009Bo003001Bo5;l00@000=Bo@03001BoE;m00<000=Bo003001Bo5;l00@0009Bo@03001BoE;m
00@000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=Bo@03001BoE;m00<000=Bo@03001BoE;m
00@0009Bo@03001BoE;m00@000=C7@03001C7E<M00@0009Bo@03001BoE;m00@000=C7@03001C7E<M
008003aoo`03001oogoo00Moo`03001oogoo00Ioo`00Egoo00<007ooOol02Woo00H004VBBI99TP00
BI840002DYX01@00DYYBVU:J00000e:J0`000U9H00<0059HDUP00U9H00D0059HDUQBF00000=BF003
001BF59H00H0009BVP03001BVU:J009BVP05001BVU:JDYX00002DYX30004Dah01P00Dah00000D]`0
00ABg003001Bg5;L00@000=C7@03001C7E<M00@0009?G`@000=C7@03001C7E<M00L0009B^`03001B
^e:k009B^`03001B^e:k00P0009Bo0@0009Bo004001Bo5;lD_`30002D_d00`00D_eBo@02D_d30000
0e;l001Bo003D_`30002D_d01000D_eBoE;m0`000e;m00<005;mD_d010000U;m00<005;mD_d01000
0e;m00<005;mD_d010000U;m00<005;mD_d010000U;m00<005;mD_d010000e<M00<005<MDad01000
0U;m00<005;mD_d010000e<M00<005<MDad01000?goo00<007ooOol01goo00<007ooOol01Goo001H
Ool2000:Ool00`00BI8000030002DYX00`00DYYBVP02DYX02@00DYYBVU:J001BVP00DUP00004DUP0
1@00DUQBF59H00000e9H00<0059HDUP0100000E;W`00001BVP0000ABVP05001BVU:JDYX00002DYX4
0003Dah00`00DaiC7P030004D]`00`00D]aBg0040003Dad00`00DaeC7@050002Cel30004Dad00`00
DaeC7@060002D[/00`00D[]B^`02D[/01000D[]B^e:k20000U;l0`000U;l00<005;lD_`00U;l00D0
05;l001Bo@0000ABo@06001Bo@00001Bo0000e;l00H005;l000005;m0004D_d01@00D_d005;m0000
15;m0`000e;m00<005;mD_d00`000e;m00<005;mD_d010000U;m00<005;mD_d010000e;m00<005;m
D_d00`000e<M00<005<MDad010000U;m00<005;mD_d010000e<M00<005<MDad01000A7oo00<007oo
Ool01Woo00<007ooOol01Goo001JOol00`00Oomoo`07Ool20002DYX00`00DYYBVP02DYX01@00DYYB
VU:J00000U:J0`000e9H00D0059HDUQBF00000=BF003001BF59H00D0009;W`8000ABVP05001BVU:J
DYX00002DYX40003Dah00`00DaiC7P040003D]`00`00D]aBg0040003Dad00`00DaeC7@050002Cel4
0003Dad00`00DaeC7@0400001CnN000005:k000015:k00H005:kD[]B^`00D[/60002D_`400000e;l
001Bo003D_`00`00D_aBo0030003D_d00`00D_eBo@030004D_`00`00D_aBo0020004D_d00`00D_eB
o@030003D_d01P00D_d00000D_d000ABo@<0009Bo@03001BoE;m00@000=Bo@03001BoE;m00<000=B
o@03001BoE;m00@0009C7@03001C7E<M00@000=Bo@03001BoE;m00<000=C7@03001C7E<M00@004Qo
o`03001oogoo00Ioo`03001oogoo00Eoo`00Fgoo00<007ooOol01Woo00<005:JDYX00U:J00D005:J
DYYBVP00009BVP@0009BF003001BF59H009BF004001BF59H0002DUP50002Bil40002DYX01@00DYYB
VU:J00000U:J10000e<N00<005<NDah010000U;L00<005;LD]`00U;L0`0015<M00<005<MDad00`00
14mO0`000U<M00<005<MDad00U<M0`000SnN0`0015:k00D005:kD[]B^`00009B^`@000ABo0<0009B
o005001Bo5;lD_`00002D_`40003D_d00`00D_eBo@030003D_`00`00D_aBo0040002D_d00`00D_eB
o@040003D_d00`00D_eBo@020004D_d01P00D_d00000D_d000=Bo@<000=Bo@03001BoE;m00@0009B
o@03001BoE;m00@0009C7@03001C7E<M00@000=Bo@03001BoE;m00@0009C7@03001C7E<M00@004eo
o`03001oogoo00Eoo`03001oogoo00Eoo`00G7oo00<007ooOol01Woo00<005:JDYX00U:J00<005:J
DYX00`000U9H00<0059HDUP00U9H00D0059HDUQBF000009BF0@0009;W`@0009BVP03001BVU:J009B
VP03001BVU:J00<000AC7P03001C7U<N00<000=Bg006001Bg5;LD]`005;L0P000U<M00<005<MDad0
0U<M0`000dmO00H004mO000005<M0004Dad01@00Dad00000?ih010000U:k00<005:kD[/00U:k00<0
05:kD[/01@000e;l00H005;l000005;l0004D_`00`00D_aBo0030003D_d00`00D_eBo@040002D_`0
0`00D_aBo0040003D_d00`00D_eBo@030003D_d00`00D_eBo@040002D_d00`00D_eBo@030004D_d3
0002D_d00`00D_eBo@040002D_d00`00D_eBo@040003Dad00`00DaeC7@030003D_d00`00D_eBo@04
0002Dad00`00DaeC7@04001BOol00`00Oomoo`04Ool00`00Oomoo`05Ool005eoo`8000Moo`03001B
VU:J00@00003DUP0059H00=BF005001BF59HDUP00002DUP40002Bil40002DYX00`00DYYBVP02DYX0
1000DYYBVU:J0`000e<N00<005<NDah010000U;L00<005;LD]`00U;L00<005;LD]`00`0015<M00@0
05<M0000009?G`03001?GdmO00<000AC7@03001C7E<M00H0009B^`03001B^e:k009B^`03001B^e:k
00@00003?ih00000009Bo003001Bo5;l008000ABo003001Bo5;l00@0009Bo@03001BoE;m00@000=B
o003001Bo5;l00<000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=B
o@03001BoE;m008000ABo@<000=Bo@03001BoE;m00<000=C7@03001C7E<M00@0009Bo@03001BoE;m
00@0009C7@03001C7E<M00@005Moo`03001oogoo00=oo`03001oogoo00Eoo`00Ggoo00<007ooOol0
1Goo0P000U9H00D0059HDUQBF00000=BF004001BF59HDUP40002Bil30002DYX00`00DYYBVP02DYX0
1P00DYYBVU:J001BVP80009C7P03001C7U<N00@0009Bg003001Bg5;L009Bg003001Bg5;L00@000=C
7@03001C7E<M00@0009?G`@000=C7@03001C7E<M00H0009B^`03001B^e:k009B^`03001B^e:k00@0
0003?ih0000000<0009Bo0@0009Bo003001Bo5;l00@000=Bo@03001BoE;m00<000=Bo003001Bo5;l
00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=Bo@03001BoE;m00<000=Bo@03001BoE;m
00@0009Bo@04001Bo@000002D_d00`00D_eBo@040002Dad00`00DaeC7@040002D_d00`00D_eBo@04
0003Dad00`00DaeC7@03001KOol00`00Oomoo`03Ool00`00Oomoo`05Ool0061oo`03001oogoo00Ao
o`03001BF59H009BF005001BF59HDUP00002DUP01000DUP000000T^O100000=BVP00DYX00e:J00D0
05:JDYYBVP00009BVP<000AC7P<0009Bg003001Bg5;L009Bg003001Bg5;L00@000=C7@03001C7E<M
00@0009?G`@000=C7@03001C7E<M00H0009B^`03001B^e:k009B^`03001B^e:k00@00003?ih00000
00800004D_`005;lD_`30003D_`00`00D_aBo0030003D_d00`00D_eBo@040002D_`00`00D_aBo004
0002D_d00`00D_eBo@040003D_d00`00D_eBo@030003D_d00`00D_eBo@040002D_d00`00D_eBo@04
0003D_d00`00D_eBo@020004D_d30002Dad00`00DaeC7@040003D_d00`00D_eBo@030003Dad00`00
DaeC7@04001OOol00`00Oomoo`03Ool00`00Oomoo`04Ool0065oo`03001oogoo00Aoo`05001BF59H
DUP00003DUP00`00DUQBF0060002DYX01@00DYYBVU:J00000e:J00<005:JDYX010000e<N00H005<N
000005;L0004D]`00`00D]aBg0040003Dad00`00DaeC7@040002Cel40003Dad00`00DaeC7@070000
0e:k001B^`03D[/00`00D[]B^`09000015;l001Bo5;l10000U;l00<005;lD_`010000U;m00<005;m
D_d010000e;l00<005;lD_`00`000e;m00<005;mD_d00`000e;m00<005;mD_d010000U;m00<005;m
D_d010000e;m00<005;mD_d00`000e;m00<005;mD_d010000U;m00@005;m0000009C7@03001C7E<M
00<000=Bo@03001BoE;m00@0009C7@03001C7E<M00@006Aoo`03001oogoo009oo`03001oogoo00Ao
o`00HWoo0P0017oo00D0059HDUQBF000009BF0H0009BVP03001BVU:J009BVP05001BVU:JDYX00002
DYX30004Dah00`00DaiC7P030003D]`00`00D]aBg0040003Dad00`00DaeC7@050002Cel30004Dad0
0`00DaeC7@060002D[/01@00D[]B^e:k00000e:k200000ABo000D_aBo0@000=Bo003001Bo5;l00<0
00=Bo@03001BoE;m00<000=Bo003001Bo5;l00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@0
00=Bo@03001BoE;m00<000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00<0
00AC7@<0009Bo@03001BoE;m00@0009C7@03001C7E<M00@006Uoo`05001oogooOol00006Ool006Ao
o`05001oogooOol00002DUP400001D^O000005:J000015:J00D005:JDYYBVP00009BVP@000=C7P03
001C7U<N00@000=Bg003001Bg5;L00<000AC7@03001C7E<M00@0009?G`@000=C7@03001C7E<M00@0
0005?ih00000D[/00004D[/01P00D[]B^e:k001B^`D0009Bo003001Bo5;l00<000=Bo003001Bo5;l
00@0009Bo@03001BoE;m00@0009Bo003001Bo5;l00@000=Bo@03001BoE;m00<000=Bo@03001BoE;m
00<000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=Bo@03001BoE;m
00<000=C7@06001C7@00001Bo@000U;m10000e<M00<005<MDad00`00KGoo00D007ooOomoo`0000Io
o`00IGoo00@007ooOomoo`<0009;W`8000ABVP05001BVU:JDYX00002DYX40003Dah00`00DaiC7P04
0002D]`00`00D]aBg002D]`30003Dad00`00DaeC7@040003Cel30003Dad00`00DaeC7@040002?ih3
0004D[/01@00D[]B^e:k00000U:k10000U;l00<005;lD_`010000U;l00<005;lD_`010000e;m00<0
05;mD_d00`000e;l00<005;lD_`00`000e;m00<005;mD_d010000U;m00<005;mD_d010000U;m00<0
05;mD_d010000e;m00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<005;mD_d010000U<M00<0
05<MDad010000U;m0`000e<M00<005<MDad01000LGoo00@007ooOol000Ioo`00IWoo00<007ooOol0
0goo0P000U:J00<005:JDYX00U:J00<005:JDYX00`000e<N00<005<NDah010000U;L00<005;LD]`0
0U;L00@005;L0000009C7@03001C7E<M00@000=?G`06001?G`00001C7@0015<M0`000SnN10000U:k
00<005:kD[/00U:k00<005:kD[/01@000U;l00<005;lD_`00`000e;l00<005;lD_`00`000e;m00<0
05;mD_d010000U;l00<005;lD_`010000U;m00<005;mD_d010000e;m00<005;mD_d00`000e;m00<0
05;mD_d00`000e;m00<005;mD_d010000U;m00<005;mD_d010000U;m00<005;mD_d010000U<M00<0
05<MDad010000U;m10000U<M00<005<MDad01000MWoo00<007oo00001Woo001WOol20003Ool00`00
DYYBVP02DYX00`00DYYBVP040003Dah00`00DaiC7P030003D]`01@00D]aBg5;L00000U;L0`0015<M
0`000dmO00<004mOCel00`0015<M00@005<M0000008oWP<0009B^`03001B^e:k009B^`03001B^e:k
00D0009Bo003001Bo5;l00@0009Bo003001Bo5;l00@0009Bo@03001BoE;m00@000=Bo003001Bo5;l
00<000=Bo@03001BoE;m00<000=Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m
00@0009Bo@03001BoE;m00@000=Bo@03001BoE;m00<000=C7@03001C7E<M00<000=Bo@<0009C7@03
001C7E<M00@007Yoo`03001oo`0000Ioo`00JGoo00D007ooOomoo`0000=BVP<000=C7P03001C7U<N
00@0009Bg003001Bg5;L009Bg003001Bg5;L00<000=C7@04001C7@000003Cel00`00Cem?G`030003
Dad00`00DaeC7@070002D[/01@00D[]B^e:k00000U:k1P000U;l00<005;lD_`00`000e;l00<005;l
D_`00`000e;m00<005;mD_d00`000e;l00<005;lD_`010000U;m00<005;mD_d010000U;m00<005;m
D_d010000U;m00<005;mD_d010000e;m00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<005;m
D_d010000U<M00<005<MDad010000U;m00@005;m0000009C7@03001C7E<M00<007moo`03001oo`00
00Eoo`00JWoo00D007ooOol005:J0080009C7P03001C7U<N00@0009Bg003001Bg5;L009Bg003001B
g5;L00@000=C7@03001C7E<M00@0009?G`@000=C7@03001C7E<M00H0009B^`03001B^e:k009B^`03
001B^e:k00<00003?ih000000080009Bo0@0009Bo003001Bo5;l00@0009Bo@03001BoE;m00@0009B
o003001Bo5;l00@000=Bo@03001BoE;m00<000=Bo@03001BoE;m00<000=Bo@03001BoE;m00<000=B
o@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009C7@03001C7E<M00@000=B
o@03001BoE;m00<0009C7@@008=oo`8000Eoo`00Jgoo00<007ooOol00`000U<N0`000U;L00<005;L
D]`00U;L00<005;LD]`010000e<M00<005<MDad010000TmO10000e<M00<005<MDad01P000U:k00<0
05:kD[/00U:k00<005:kD[/0100000<oWP0000000P000U;l0`000e;l00<005;lD_`00`000e;m00<0
05;mD_d00`000e;l00<005;lD_`00`000e;m00<005;mD_d010000U;m00<005;mD_d010000U;m00<0
05;mD_d010000U;m00<005;mD_d010000e;m00<005;mD_d00`000e;m00<005;mD_d00`000e<M00<0
05<MDad00`000e;m00<005;mD_d0100000=C7@0000000P00QWoo0`001Goo001/Ool20003Ool20002
D]`01@00D]aBg5;L00000U;L10000e<M00<005<MDad010000TmO10000e<M00<005<MDad01P000U:k
00<005:kD[/00U:k00<005:kD[/0100000<oWP0000000P000U;l10000U;l00<005;lD_`010000U;m
00<005;mD_d010000U;l00<005;lD_`010000U;m00<005;mD_d010000e;m00<005;mD_d00`000e;m
00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<005;mD_d010000U;m00<005;mD_d010000U<M
00<005<MDad010000U;m00<005;mD_d010000U<M0`00QWoo100027oo001^Ool01000Oomoo`0015;L
00<005;LD]`00`0015<M00<005<MDad010000TmO0`0015<M00<005<MDad01P0000=B^`00D[/00e:k
00<005:kD[/02P000U;l0`000e;l00<005;lD_`00`000e;m00<005;mD_d00`000e;l00<005;lD_`0
0`000e;m00<005;mD_d00`000e;m00<005;mD_d010000U;m00<005;mD_d010000U;m00<005;mD_d0
10000U;m00<005;mD_d010000U;m00<005;mD_d010000e<M00<005<MDad00`000e;m00<005;mD_d0
0`000U<M1000QGoo100037oo001_Ool01000Oomoo`000U;L10000e<M00<005<MDad010000TmO1000
0e<M00<005<MDad01P000U:k00D005:kD[]B^`0000=B^`T0009Bo0@0009Bo003001Bo5;l00@0009B
o@03001BoE;m00@0009Bo003001Bo5;l00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@000=B
o@03001BoE;m00<000=Bo@03001BoE;m00<000=Bo@03001BoE;m00<000=Bo@03001BoE;m00<000=C
7@03001C7E<M00@0009Bo@03001BoE;m00@00003Dad00000008008Ioo`<0011oo`00L7oo00<007oo
Ool00P000e<M00<005<MDad010000TmO10000e<M00<005<MDad01P000U:k00<005:kD[/00U:k00H0
05:kD[]B^`00D[/70002D_`30003D_`00`00D_aBo0030003D_d00`00D_eBo@030003D_`00`00D_aB
o0030003D_d00`00D_eBo@030003D_d00`00D_eBo@030003D_d00`00D_eBo@040002D_d00`00D_eB
o@040002D_d00`00D_eBo@040002D_d00`00D_eBo@040002Dad00`00DaeC7@040002D_d00`00D_eB
o@040002Dad30026Ool4000COol0075oo`80009oo`03001C7E<M00@0009?G`<000=C7@03001C7E<M
00D00004?ih005:k0004D[/01@00D[]B^e:k00000U:k1P000U;l10000U;l00<005;lD_`010000U;m
00<005;mD_d010000U;l00<005;lD_`010000U;m00<005;mD_d010000U;m00<005;mD_d010000U;m
00<005;mD_d010000e;m00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<005;mD_d00`000e<M
00<005<MDad00`000e;m00<005;mD_d00`000e<M0`00QGoo10005goo001cOol00`00Oomoo`020003
Cel30003Dad00`00DaeC7@040002?ih30003D[/01@00D[]B^e:k00000U:k1@001Goo0P000e;l00<0
05;lD_`00`000e;m00<005;mD_d00`000e;l00<005;lD_`00`000e;m00<005;mD_d00`000e;m00<0
05;mD_d00`000e;m00<005;mD_d00`000e;m00<005;mD_d010000U;m00<005;mD_d010000U;m00<0
05;mD_d010000U<M00<005<MDad010000U;m00<005;mD_d010000U<M00@005<M000008Aoo`@001]o
o`00M7oo00D007ooOol004mO00800003Dad005<M00=C7@<0008oWP@0009B^`03001B^e:k009B^`03
001B^e:k00D000Uoo`03001Bo5;l00@0009Bo@03001BoE;m00@0009Bo003001Bo5;l00@0009Bo@03
001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03
001BoE;m00@000=Bo@03001BoE;m00<000=C7@03001C7E<M00<000=Bo@03001BoE;m00<000=C7@03
001C7E<M0080089oo`@001moo`00MGoo00<007ooOol00P000e<M00@005<M0000008oWP<0009B^`03
001B^e:k009B^`03001B^e:k00D000ioo`8000=Bo@03001BoE;m00<000=Bo003001Bo5;l00<000=B
o@03001BoE;m00<000=Bo@03001BoE;m00<000=Bo@03001BoE;m00<000=Bo@03001BoE;m00<000=B
o@03001BoE;m00<000=Bo@03001BoE;m00@0009C7@03001C7E<M00@0009Bo@03001BoE;m00@00003
Dad0000000H0081oo`@002=oo`00MWoo0P000Woo00<005<MDad01P000U:k00D005:kD[]B^`00009B
^`D001Aoo`03001BoE;m00<000=Bo003001Bo5;l00<000=Bo@03001BoE;m00<0009Bo@03001BoE;m
00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m
00@0009C7@03001C7E<M00@0009Bo@03001BoE;m00@0009C7@<008Eoo`<002Moo`00N7oo00<007oo
Ool010000U:k00<005:kD[/00U:k00<005:kD[/01@0067oo0P000U;l00<005;lD_`010000U;m00<0
05;mD_d010000U;m00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<0
05;mD_d00`000e;m00<005;mD_d00`000e<M00<005<MDad00`000e;m00<005;mD_d00`000U<M1000
Q7oo1000:Woo001iOol01@00Oomoogoo000015:k00<005:kD[/01@007Goo00<005;lD_`00`000e;m
00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<005;mD_d00`000U;m00<005;mD_d010000U;m
00<005;mD_d010000U;m00<005;mD_d010000U<M00<005<MDad010000U;m00<005;mD_d010000U<M
0`00Q7oo1000;Woo001jOol01@00Oomoogoo00000U:k1P008Goo0P000U;m00<005;mD_d010000U;m
00<005;mD_d010000U;m00<005;mD_d010000U;m00<005;mD_d00`000e;m00<005;mD_d00`000e;m
00<005;mD_d00`000e<M00<005<MDad00`000e;m00<005;mD_d00`000U<M1000Pgoo1000<Woo001k
Ool20002Ool2000XOol00`00D_eBo@030003D_d00`00D_eBo@030003D_d00`00D_eBo@030003D_d0
0`00D_eBo@030002D_d00`00D_eBo@040002D_d00`00D_eBo@040002Dad00`00DaeC7@040002D_d0
0`00D_eBo@040002Dad30023Ool4000fOol007eoo`03001oogoo02Yoo`80009Bo@03001BoE;m00@0
009Bo@03001BoE;m00@0009Bo@03001BoE;m00@0009Bo@03001BoE;m00<000=Bo@03001BoE;m00<0
00=C7@03001C7E<M00<000=Bo@03001BoE;m00<0009C7@@008=oo`<003Yoo`00OWoo00<007ooOol0
:Woo00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<005;mD_d00`000e;m00<005;mD_d00`00
0U;m00<005;mD_d010000U<M00<005<MDad010000U;m00<005;mD_d010000U<M0`00Pgoo1000?Goo
001oOol00`00Oomoo`0ZOol20002D_d00`00D_eBo@040002D_d00`00D_eBo@040002D_d00`00D_eB
o@040002D_d00`00D_eBo@030003Dad00`00DaeC7@030002D_d70002Dad40022Ool40011Ool0081o
o`03001oogoo02Yoo`03001BoE;m00<000=Bo@03001BoE;m00<000=Bo@03001BoE;m00<000=Bo@03
001BoE;m00<0009C7@03001C7E<M00@0009Bo@<000=C7@03001C7E<M00<0089oo`@004Eoo`00PGoo
0P00:goo0P000U;m00<005;mD_d010000U;m00<005;mD_d010000U;m00<005;mD_d010000U<M00<0
05<MDad00`000U;m10000U<M00<005<MDad01000PGoo1000BGoo0023Ool00`00Oomoo`0YOol00`00
D_eBo@030003D_d00`00D_eBo@030003D_d00`00D_eBo@030003Dad00`00DaeC7@030002D_d30003
Dad00`00DaeC7@030021Ool4001=Ool008Aoo`03001oogoo02Uoo`80009Bo@03001BoE;m00@0009B
o@03001BoE;m00@0009C7@L0009Bo@<0009C7@03001C7E<M00@0085oo`<0055oo`00QGoo00<007oo
Ool0:Goo00<005;mD_d010000U;m00<005;mD_d00`000U<M10000U;m00<005;mD_d010000U<M00<0
05<MDad00`00PGoo1000E7oo0026Ool2000ZOol20002D_d70002Dad30003D_d00`00D_eBo@030002
Dad00`00DaeC7@040020Ool4001HOol008Qoo`03001oogoo02Uoo`8000=C7@03001C7E<M00<0009B
o@03001BoE;m00@0009C7@03001C7E<M00<0081oo`@005aoo`00RGoo00<007ooOol0:Goo00<005<M
Dad010000U;m00<005;mD_d00`000e<M00<005<MDad00`00Ogoo1000H7oo002:Ool00`00Oomoo`0Y
Ool20003D_d00`00D_eBo@030002Dad00`00DaeC7@04001nOol4001TOol008]oo`8002Yoo`03001B
oE;m00@0009C7@03001C7E<M00<007moo`<006Qoo`00SGoo00<007ooOol0:7oo0P000e<M00<005<M
Dad00`00OWoo1000Jgoo002>Ool00`00Oomoo`0XOol00`00DaeC7@04001mOol4001_Ool008moo`03
001oogoo02Qoo`8007eoo`@007=oo`00T7oo0P00:7oo00<007ooOol0N7oo1000Mgoo002BOol00`00
Oomoo`0UOol00`00Oomoo`1dOol4001kOol009=oo`03001oogoo02Aoo`03001oogoo075oo`<007mo
o`00U7oo00<007ooOol08goo00<007ooOol0KGoo1000PWoo002EOol2000SOol00`00Oomoo`1YOol4
0026Ool009Moo`03001oogoo021oo`03001oogoo06Eoo`@008Yoo`00V7oo00<007ooOol07goo00<0
07ooOol0HGoo1000SWoo002IOol00`00Oomoo`0NOol00`00Oomoo`1NOol3002BOol009Yoo`8001io
o`03001oogoo05Yoo`@009Eoo`00W7oo00<007ooOol06goo00<007ooOol0EWoo1000VGoo002MOol0
0`00Oomoo`0JOol00`00Oomoo`1BOol4002MOol009ioo`03001oogoo01Uoo`03001oogoo04ioo`@0
0:5oo`00Wgoo0P006Goo00<007ooOol0BWoo1000YGoo002QOol00`00Oomoo`0FOol00`00Oomoo`17
Ool3002YOol00:9oo`03001oogoo01Eoo`03001oogoo04=oo`@00:aoo`00Xgoo00<007ooOol057oo
00<007ooOol0?goo1000/7oo002TOol2000DOol00`00Oomoo`0kOol4002dOol00:Ioo`03001oogoo
015oo`03001oogoo03Moo`@00;Qoo`00Ygoo00<007ooOol047oo00<007ooOol0<goo1000_7oo002X
Ool00`00Oomoo`0?Ool00`00Oomoo`0`Ool30030Ool00:Uoo`03001oogoo00eoo`03001oogoo02eo
o`@00<=oo`00ZWoo0P003Goo00<007ooOol0:Goo1000agoo002/Ool00`00Oomoo`0:Ool00`00Oomo
o`0UOol4003;Ool00:eoo`03001oogoo00Uoo`03001oogoo025oo`@00<moo`00[Woo00<007ooOol0
27oo00<007ooOol07Woo0`00dgoo002_Ool20008Ool00`00Oomoo`0JOol4003FOol00;5oo`03001o
ogoo00Eoo`03001oogoo01Ioo`@00=Yoo`00/Woo00<007ooOol017oo00<007ooOol04Woo1000gWoo
002cOol00`00Oomoo`03Ool00`00Oomoo`0>Ool4003ROol00;Aoo`8000=oo`03001oogoo00Yoo`@0
0>Ioo`00]Woo00@007ooOol000Uoo`<00>Yoo`00]goo00<007oo00001Goo1000kGoo002hOol20000
0goo00000002003aOol00;Uoo`800?Eoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003o
OonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
   ImageRangeCache->{{{0, 431}, {349.312, 0}} -> {-0.0632353, 0.0220283,
   0.00357649, 0.00357649}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Back Projection of Filtered", "Section"],

Cell[BoxData[
     \(\(BFlimited[x_, y_, n_] :=
         If[x^2 + y^2 > 32^2, 0,
           1/\((2\ Pi)\)\ Sum[\(\(Transpose[
                     Re[Filtdata]]\)[\([m*64 + 1]\)]\)[\([Floor[
                       x\ Cos[m*Pi] + y\ Sin[m\ Pi]] + 33]\)], {m, 0, 1 - 1/n,
                 1/n}]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
     \(Plot3D[
       BFlimited[x, y, 4], {x, \(-32\), 32}, {y, \(-32\),
         32}, {PlotRange \[Rule] All, PlotPoints \[Rule] {64, 
64}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.21264e-16 1.04977 -0.0679587 1.04977 [
[.13842 .20256 -17.9329 -9 ]
[.13842 .20256 .06713 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.54622 .04218 -10.3916 -9 ]
[.54622 .04218 1.60844 0 ]
[.76347 .09094 0 -6.1678 ]
[.76347 .09094 18 2.8322 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93784 .35795 0 -5.9154 ]
[.93784 .35795 12 3.0846 ]
[.01674 .31133 -18 -2.78139 ]
[.01674 .31133 0 6.21861 ]
[.0067 .37427 -6 -2.83478 ]
[.0067 .37427 0 6.16522 ]
[-0.00376 .43979 -12 -2.89059 ]
[-0.00376 .43979 0 6.10941 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14766 .21187 m
.15228 .21653 L
s
[(-20)] .13842 .20256 .99254 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.55397 .05277 m
.55784 .05807 L
s
[(20)] .54622 .04218 .73193 1 Mshowa
.125 Mabswid
.19515 .19327 m
.19788 .19611 L
s
.24353 .17433 m
.24621 .17721 L
s
.29283 .15503 m
.29545 .15796 L
s
.39427 .1153 m
.39678 .11833 L
s
.44647 .09487 m
.44892 .09794 L
s
.49969 .07402 m
.50208 .07715 L
s
.10103 .23013 m
.10385 .23288 L
s
.05524 .24806 m
.0581 .25076 L
s
.60933 .03109 m
.61159 .03432 L
s
.66582 .00897 m
.668 .01225 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75117 .0955 m
.74502 .09778 L
s
[(-20)] .76347 .09094 -1 .37062 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92532 .36189 m
.91906 .36386 L
s
[(20)] .93784 .35795 -1 .31453 Mshowa
.125 Mabswid
.77562 .13291 m
.77192 .13425 L
s
.79923 .16902 m
.79552 .17034 L
s
.82203 .2039 m
.81832 .20519 L
s
.86539 .27022 m
.86165 .27146 L
s
.88601 .30176 m
.88227 .30299 L
s
.90598 .33231 m
.90223 .33351 L
s
.72582 .05673 m
.72214 .05812 L
s
.69953 .01651 m
.69586 .01793 L
s
.94406 .39056 m
.9403 .39172 L
s
.96223 .41835 m
.95847 .4195 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.029 .30665 m
.03513 .30431 L
s
[(-20)] .01674 .31133 1 -0.38191 Mshowa
.019 .36971 m
.02516 .36744 L
s
[(0)] .0067 .37427 1 -0.37005 Mshowa
.0086 .43537 m
.01478 .43316 L
s
[(20)] -0.00376 .43979 1 -0.35765 Mshowa
.125 Mabswid
.02654 .32218 m
.03022 .32079 L
s
.02405 .33787 m
.02773 .33648 L
s
.02154 .35371 m
.02523 .35233 L
s
.01644 .38588 m
.02014 .38452 L
s
.01385 .40221 m
.01755 .40086 L
s
.01124 .41871 m
.01494 .41737 L
s
.03143 .29127 m
.03511 .28986 L
s
.03385 .27604 m
.03752 .27462 L
s
.03624 .26096 m
.0399 .25953 L
s
.00593 .45221 m
.00964 .4509 L
s
.00323 .46922 m
.00695 .46792 L
s
.00051 .48642 m
.00423 .48512 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.656 .752 .92 r
.39665 .69898 .40164 .70333 .41 .70098 .40502 .69661 Metetra
.656 .752 .92 r
.40502 .69661 .41 .70098 .41838 .69861 .41342 .69424 Metetra
.656 .752 .92 r
.41342 .69424 .41838 .69861 .42679 .69625 .42185 .69185 Metetra
.656 .752 .92 r
.42185 .69185 .42679 .69625 .43523 .69387 .4303 .68946 Metetra
.656 .752 .92 r
.4303 .68946 .43523 .69387 .44369 .69149 .43878 .68706 Metetra
.656 .752 .92 r
.43878 .68706 .44369 .69149 .45218 .68909 .44729 .68466 Metetra
.656 .752 .92 r
.44729 .68466 .45218 .68909 .4607 .6867 .45582 .68225 Metetra
.656 .752 .92 r
.45582 .68225 .4607 .6867 .46924 .68429 .46438 .67983 Metetra
.656 .752 .92 r
.46438 .67983 .46924 .68429 .47781 .68188 .47297 .6774 Metetra
.656 .752 .92 r
.47297 .6774 .47781 .68188 .48641 .67945 .48159 .67496 Metetra
.656 .752 .92 r
.48159 .67496 .48641 .67945 .49503 .67702 .49023 .67252 Metetra
.656 .752 .92 r
.49023 .67252 .49503 .67702 .50368 .67459 .4989 .67007 Metetra
.656 .752 .92 r
.4989 .67007 .50368 .67459 .51236 .67214 .50759 .66761 Metetra
.656 .752 .92 r
.50759 .66761 .51236 .67214 .52107 .66969 .51632 .66514 Metetra
.656 .752 .92 r
.51632 .66514 .52107 .66969 .5298 .66723 .52507 .66267 Metetra
.656 .752 .92 r
.52507 .66267 .5298 .66723 .53856 .66476 .53385 .66019 Metetra
.656 .752 .92 r
.53385 .66019 .53856 .66476 .54735 .66229 .54266 .6577 Metetra
.656 .752 .92 r
.54266 .6577 .54735 .66229 .55617 .6598 .55149 .6552 Metetra
.656 .752 .92 r
.55149 .6552 .55617 .6598 .56502 .65731 .56036 .65269 Metetra
.656 .752 .92 r
.56036 .65269 .56502 .65731 .57389 .65481 .56925 .65018 Metetra
.656 .752 .92 r
.56925 .65018 .57389 .65481 .5828 .6523 .57817 .64765 Metetra
.656 .752 .92 r
.57817 .64765 .5828 .6523 .59173 .64979 .58712 .64512 Metetra
.656 .752 .92 r
.58712 .64512 .59173 .64979 .60069 .64727 .5961 .64258 Metetra
.948 .725 .568 r
.5961 .64258 .60069 .64727 .60968 .64473 .60375 .58142 Metetra
.228 .146 .55 r
.60375 .58142 .60968 .64473 .61869 .64219 .61392 .62875 Metetra
0 .083 .627 r
.61392 .62875 .61869 .64219 .62774 .63965 .62349 .64464 Metetra
.398 0 .035 r
.62349 .64464 .62774 .63965 .63682 .63709 .63267 .64395 Metetra
.477 .063 .175 r
.63267 .64395 .63682 .63709 .64592 .63452 .64192 .64386 Metetra
.381 .014 .212 r
.64192 .64386 .64592 .63452 .65506 .63195 .65108 .64035 Metetra
.456 .071 .219 r
.65108 .64035 .65506 .63195 .66423 .62937 .66035 .63912 Metetra
.429 .066 .245 r
.66035 .63912 .66423 .62937 .67342 .62678 .66961 .63657 Metetra
.451 .088 .256 r
.66961 .63657 .67342 .62678 .68265 .62418 .67892 .63462 Metetra
.433 .08 .264 r
.67892 .63462 .68265 .62418 .6919 .62157 .68823 .63186 Metetra
.417 .063 .254 r
.68823 .63186 .6919 .62157 .70119 .61896 .69756 .6287 Metetra
.425 .062 .244 r
.69756 .6287 .70119 .61896 .7105 .61633 .70693 .62601 Metetra
.363 .005 .216 r
.70693 .62601 .7105 .61633 .71985 .6137 .71625 .62177 Metetra
.42 .03 .19 r
.71625 .62177 .71985 .6137 .72923 .61106 .72573 .61977 Metetra
.305 0 .163 r
.72573 .61977 .72923 .61106 .73864 .60841 .73506 .61485 Metetra
.233 0 .033 r
.73506 .61485 .73864 .60841 .74808 .60575 .74444 .61044 Metetra
.615 .838 .453 r
.74444 .61044 .74808 .60575 .75755 .60308 .75332 .59813 Metetra
.656 .752 .92 r
.75332 .59813 .75755 .60308 .76705 .60041 .76284 .59544 Metetra
.656 .752 .92 r
.76284 .59544 .76705 .60041 .77658 .59772 .7724 .59274 Metetra
.656 .752 .92 r
.7724 .59274 .77658 .59772 .78615 .59503 .78199 .59003 Metetra
.656 .752 .92 r
.78199 .59003 .78615 .59503 .79575 .59232 .79161 .58731 Metetra
.656 .752 .92 r
.79161 .58731 .79575 .59232 .80538 .58961 .80126 .58458 Metetra
.656 .752 .92 r
.80126 .58458 .80538 .58961 .81504 .58689 .81094 .58184 Metetra
.656 .752 .92 r
.81094 .58184 .81504 .58689 .82473 .58416 .82066 .57909 Metetra
.656 .752 .92 r
.82066 .57909 .82473 .58416 .83446 .58142 .83041 .57634 Metetra
.656 .752 .92 r
.83041 .57634 .83446 .58142 .84422 .57867 .84019 .57357 Metetra
.656 .752 .92 r
.84019 .57357 .84422 .57867 .85401 .57591 .85001 .5708 Metetra
.656 .752 .92 r
.85001 .5708 .85401 .57591 .86384 .57315 .85986 .56801 Metetra
.656 .752 .92 r
.85986 .56801 .86384 .57315 .8737 .57037 .86974 .56522 Metetra
.656 .752 .92 r
.86974 .56522 .8737 .57037 .88359 .56758 .87966 .56241 Metetra
.656 .752 .92 r
.87966 .56241 .88359 .56758 .89351 .56479 .88961 .5596 Metetra
.656 .752 .92 r
.88961 .5596 .89351 .56479 .90347 .56198 .89959 .55678 Metetra
.656 .752 .92 r
.89959 .55678 .90347 .56198 .91346 .55917 .90961 .55395 Metetra
.656 .752 .92 r
.90961 .55395 .91346 .55917 .92349 .55634 .91966 .5511 Metetra
.656 .752 .92 r
.91966 .5511 .92349 .55634 .93355 .55351 .92975 .54825 Metetra
.656 .752 .92 r
.92975 .54825 .93355 .55351 .94365 .55067 .93987 .54539 Metetra
.656 .752 .92 r
.93987 .54539 .94365 .55067 .95378 .54781 .95002 .54252 Metetra
.656 .752 .92 r
.95002 .54252 .95378 .54781 .96394 .54495 .96021 .53964 Metetra
.656 .752 .92 r
.96021 .53964 .96394 .54495 .97414 .54208 .97044 .53675 Metetra
.656 .752 .92 r
.97044 .53675 .97414 .54208 .98438 .53919 .9807 .53385 Metetra
.656 .752 .92 r
.39163 .6946 .39665 .69898 .40502 .69661 .40002 .69222 Metetra
.656 .752 .92 r
.40002 .69222 .40502 .69661 .41342 .69424 .40844 .68983 Metetra
.656 .752 .92 r
.40844 .68983 .41342 .69424 .42185 .69185 .41688 .68743 Metetra
.656 .752 .92 r
.41688 .68743 .42185 .69185 .4303 .68946 .42535 .68503 Metetra
.656 .752 .92 r
.42535 .68503 .4303 .68946 .43878 .68706 .43385 .68262 Metetra
.656 .752 .92 r
.43385 .68262 .43878 .68706 .44729 .68466 .44237 .6802 Metetra
.656 .752 .92 r
.44237 .6802 .44729 .68466 .45582 .68225 .45092 .67777 Metetra
.656 .752 .92 r
.45092 .67777 .45582 .68225 .46438 .67983 .4595 .67534 Metetra
.656 .752 .92 r
.4595 .67534 .46438 .67983 .47297 .6774 .4681 .6729 Metetra
.656 .752 .92 r
.4681 .6729 .47297 .6774 .48159 .67496 .47673 .67045 Metetra
.656 .752 .92 r
.47673 .67045 .48159 .67496 .49023 .67252 .48539 .66799 Metetra
.656 .752 .92 r
.48539 .66799 .49023 .67252 .4989 .67007 .49408 .66552 Metetra
.656 .752 .92 r
.49408 .66552 .4989 .67007 .50759 .66761 .5028 .66305 Metetra
.656 .752 .92 r
.5028 .66305 .50759 .66761 .51632 .66514 .51154 .66057 Metetra
.656 .752 .92 r
.51154 .66057 .51632 .66514 .52507 .66267 .52031 .65808 Metetra
.656 .752 .92 r
.52031 .65808 .52507 .66267 .53385 .66019 .52911 .65558 Metetra
.656 .752 .92 r
.52911 .65558 .53385 .66019 .54266 .6577 .53793 .65308 Metetra
.656 .752 .92 r
.53793 .65308 .54266 .6577 .55149 .6552 .54679 .65056 Metetra
.656 .752 .92 r
.54679 .65056 .55149 .6552 .56036 .65269 .55567 .64804 Metetra
.656 .752 .92 r
.55567 .64804 .56036 .65269 .56925 .65018 .56458 .64551 Metetra
.918 .753 .663 r
.56458 .64551 .56925 .65018 .57817 .64765 .5732 .61988 Metetra
.631 .477 .655 r
.5732 .61988 .57817 .64765 .58712 .64512 .58207 .61488 Metetra
.628 .47 .649 r
.58207 .61488 .58712 .64512 .5961 .64258 .59095 .60969 Metetra
.769 .562 .618 r
.59095 .60969 .5961 .64258 .60375 .58142 .59922 .57581 Metetra
.955 .612 .306 r
.59922 .57581 .60375 .58142 .61392 .62875 .60935 .62354 Metetra
.788 .329 0 r
.60935 .62354 .61392 .62875 .62349 .64464 .61893 .63987 Metetra
.586 .727 .941 r
.61893 .63987 .62349 .64464 .63267 .64395 .62811 .63865 Metetra
.52 .677 .936 r
.62811 .63865 .63267 .64395 .64192 .64386 .63737 .63871 Metetra
.693 .749 .895 r
.63737 .63871 .64192 .64386 .65108 .64035 .64655 .63515 Metetra
.572 .705 .932 r
.64655 .63515 .65108 .64035 .66035 .63912 .65586 .63429 Metetra
.667 .756 .917 r
.65586 .63429 .66035 .63912 .66961 .63657 .66513 .6314 Metetra
.627 .728 .92 r
.66513 .6314 .66961 .63657 .67892 .63462 .67446 .62943 Metetra
.648 .736 .913 r
.67446 .62943 .67892 .63462 .68823 .63186 .68381 .62699 Metetra
.692 .764 .906 r
.68381 .62699 .68823 .63186 .69756 .6287 .69313 .62343 Metetra
.657 .737 .909 r
.69313 .62343 .69756 .6287 .70693 .62601 .70253 .62076 Metetra
.719 .758 .883 r
.70253 .62076 .70693 .62601 .71625 .62177 .71186 .61633 Metetra
.605 .712 .92 r
.71186 .61633 .71625 .62177 .72573 .61977 .72138 .61483 Metetra
.749 .779 .877 r
.72138 .61483 .72573 .61977 .73506 .61485 .73071 .60946 Metetra
.729 .757 .876 r
.73071 .60946 .73506 .61485 .74444 .61044 .7401 .60466 Metetra
.913 .763 .681 r
.7401 .60466 .74444 .61044 .75332 .59813 .74841 .58321 Metetra
.908 .677 .578 r
.74841 .58321 .75332 .59813 .76284 .59544 .75444 .52961 Metetra
.429 .295 .596 r
.75444 .52961 .76284 .59544 .7724 .59274 .766 .55708 Metetra
.253 .205 .608 r
.766 .55708 .7724 .59274 .78199 .59003 .77779 .585 Metetra
.656 .752 .92 r
.77779 .585 .78199 .59003 .79161 .58731 .78744 .58226 Metetra
.656 .752 .92 r
.78744 .58226 .79161 .58731 .80126 .58458 .79711 .57952 Metetra
.656 .752 .92 r
.79711 .57952 .80126 .58458 .81094 .58184 .80682 .57676 Metetra
.656 .752 .92 r
.80682 .57676 .81094 .58184 .82066 .57909 .81656 .574 Metetra
.656 .752 .92 r
.81656 .574 .82066 .57909 .83041 .57634 .82633 .57122 Metetra
.656 .752 .92 r
.82633 .57122 .83041 .57634 .84019 .57357 .83614 .56844 Metetra
.656 .752 .92 r
.83614 .56844 .84019 .57357 .85001 .5708 .84598 .56565 Metetra
.656 .752 .92 r
.84598 .56565 .85001 .5708 .85986 .56801 .85585 .56285 Metetra
.656 .752 .92 r
.85585 .56285 .85986 .56801 .86974 .56522 .86576 .56003 Metetra
.656 .752 .92 r
.86576 .56003 .86974 .56522 .87966 .56241 .8757 .55721 Metetra
.656 .752 .92 r
.8757 .55721 .87966 .56241 .88961 .5596 .88568 .55438 Metetra
.656 .752 .92 r
.88568 .55438 .88961 .5596 .89959 .55678 .89568 .55154 Metetra
.656 .752 .92 r
.89568 .55154 .89959 .55678 .90961 .55395 .90573 .54869 Metetra
.656 .752 .92 r
.90573 .54869 .90961 .55395 .91966 .5511 .9158 .54583 Metetra
.656 .752 .92 r
.9158 .54583 .91966 .5511 .92975 .54825 .92591 .54296 Metetra
.656 .752 .92 r
.92591 .54296 .92975 .54825 .93987 .54539 .93606 .54008 Metetra
.656 .752 .92 r
.93606 .54008 .93987 .54539 .95002 .54252 .94624 .53719 Metetra
.656 .752 .92 r
.94624 .53719 .95002 .54252 .96021 .53964 .95646 .53429 Metetra
.656 .752 .92 r
.95646 .53429 .96021 .53964 .97044 .53675 .96671 .53138 Metetra
.656 .752 .92 r
.96671 .53138 .97044 .53675 .9807 .53385 .977 .52846 Metetra
.656 .752 .92 r
.38658 .6902 .39163 .6946 .40002 .69222 .39499 .6878 Metetra
.656 .752 .92 r
.39499 .6878 .40002 .69222 .40844 .68983 .40342 .6854 Metetra
.656 .752 .92 r
.40342 .6854 .40844 .68983 .41688 .68743 .41188 .68299 Metetra
.656 .752 .92 r
.41188 .68299 .41688 .68743 .42535 .68503 .42037 .68057 Metetra
.656 .752 .92 r
.42037 .68057 .42535 .68503 .43385 .68262 .42888 .67815 Metetra
.656 .752 .92 r
.42888 .67815 .43385 .68262 .44237 .6802 .43742 .67571 Metetra
.656 .752 .92 r
.43742 .67571 .44237 .6802 .45092 .67777 .44599 .67327 Metetra
.656 .752 .92 r
.44599 .67327 .45092 .67777 .4595 .67534 .45458 .67082 Metetra
.656 .752 .92 r
.45458 .67082 .4595 .67534 .4681 .6729 .46321 .66837 Metetra
.656 .752 .92 r
.46321 .66837 .4681 .6729 .47673 .67045 .47185 .6659 Metetra
.656 .752 .92 r
.47185 .6659 .47673 .67045 .48539 .66799 .48053 .66343 Metetra
.656 .752 .92 r
.48053 .66343 .48539 .66799 .49408 .66552 .48924 .66095 Metetra
.656 .752 .92 r
.48924 .66095 .49408 .66552 .5028 .66305 .49797 .65846 Metetra
.656 .752 .92 r
.49797 .65846 .5028 .66305 .51154 .66057 .50673 .65597 Metetra
.656 .752 .92 r
.50673 .65597 .51154 .66057 .52031 .65808 .51552 .65346 Metetra
.656 .752 .92 r
.51552 .65346 .52031 .65808 .52911 .65558 .52433 .65095 Metetra
.656 .752 .92 r
.52433 .65095 .52911 .65558 .53793 .65308 .53318 .64843 Metetra
.656 .752 .92 r
.53318 .64843 .53793 .65308 .54679 .65056 .54205 .6459 Metetra
.92 .748 .652 r
.54205 .6459 .54679 .65056 .55567 .64804 .55076 .61784 Metetra
.581 .437 .65 r
.55076 .61784 .55567 .64804 .56458 .64551 .55965 .61768 Metetra
.619 .468 .656 r
.55965 .61768 .56458 .64551 .5732 .61988 .56854 .61396 Metetra
.741 .729 .84 r
.56854 .61396 .5732 .61988 .58207 .61488 .57742 .60858 Metetra
.711 .71 .847 r
.57742 .60858 .58207 .61488 .59095 .60969 .58634 .60426 Metetra
.926 .738 .628 r
.58634 .60426 .59095 .60969 .59922 .57581 .59467 .57086 Metetra
.953 .61 .313 r
.59467 .57086 .59922 .57581 .60935 .62354 .60475 .61799 Metetra
.782 .329 0 r
.60475 .61799 .60935 .62354 .61893 .63987 .61433 .63466 Metetra
.577 .706 .93 r
.61433 .63466 .61893 .63987 .62811 .63865 .62353 .63372 Metetra
.536 .701 .946 r
.62353 .63372 .62811 .63865 .63737 .63871 .6328 .63335 Metetra
.681 .738 .894 r
.6328 .63335 .63737 .63871 .64655 .63515 .64201 .6301 Metetra
.583 .717 .935 r
.64201 .6301 .64655 .63515 .65586 .63429 .65133 .62897 Metetra
.654 .732 .907 r
.65133 .62897 .65586 .63429 .66513 .6314 .66062 .62639 Metetra
.626 .736 .926 r
.66062 .62639 .66513 .6314 .67446 .62943 .66998 .6244 Metetra
.661 .748 .915 r
.66998 .6244 .67446 .62943 .68381 .62699 .67933 .62162 Metetra
.682 .742 .896 r
.67933 .62162 .68381 .62699 .69313 .62343 .68869 .61829 Metetra
.67 .748 .909 r
.68869 .61829 .69313 .62343 .70253 .62076 .69809 .61528 Metetra
.705 .746 .884 r
.69809 .61528 .70253 .62076 .71186 .61633 .70747 .61125 Metetra
.615 .732 .929 r
.70747 .61125 .71186 .61633 .72138 .61483 .71699 .60944 Metetra
.754 .765 .862 r
.71699 .60944 .72138 .61483 .73071 .60946 .72633 .60371 Metetra
.706 .739 .877 r
.72633 .60371 .73071 .60946 .7401 .60466 .73577 .59956 Metetra
.925 .775 .677 r
.73577 .59956 .7401 .60466 .74841 .58321 .74409 .57752 Metetra
.961 .734 .551 r
.74409 .57752 .74841 .58321 .75444 .52961 .75014 .52297 Metetra
.845 .439 0 r
.75014 .52297 .75444 .52961 .766 .55708 .76171 .5508 Metetra
.52 .641 .909 r
.76171 .5508 .766 .55708 .77779 .585 .77148 .55121 Metetra
.602 .447 .643 r
.77148 .55121 .77779 .585 .78744 .58226 .78106 .54846 Metetra
.263 .216 .616 r
.78106 .54846 .78744 .58226 .79711 .57952 .79294 .57442 Metetra
.656 .752 .92 r
.79294 .57442 .79711 .57952 .80682 .57676 .80267 .57165 Metetra
.656 .752 .92 r
.80267 .57165 .80682 .57676 .81656 .574 .81244 .56887 Metetra
.656 .752 .92 r
.81244 .56887 .81656 .574 .82633 .57122 .82223 .56608 Metetra
.656 .752 .92 r
.82223 .56608 .82633 .57122 .83614 .56844 .83206 .56328 Metetra
.656 .752 .92 r
.83206 .56328 .83614 .56844 .84598 .56565 .84193 .56047 Metetra
.656 .752 .92 r
.84193 .56047 .84598 .56565 .85585 .56285 .85182 .55765 Metetra
.656 .752 .92 r
.85182 .55765 .85585 .56285 .86576 .56003 .86176 .55482 Metetra
.656 .752 .92 r
.86176 .55482 .86576 .56003 .8757 .55721 .87172 .55198 Metetra
.656 .752 .92 r
.87172 .55198 .8757 .55721 .88568 .55438 .88172 .54913 Metetra
.656 .752 .92 r
.88172 .54913 .88568 .55438 .89568 .55154 .89175 .54627 Metetra
.656 .752 .92 r
.89175 .54627 .89568 .55154 .90573 .54869 .90182 .5434 Metetra
.656 .752 .92 r
.90182 .5434 .90573 .54869 .9158 .54583 .91192 .54053 Metetra
.656 .752 .92 r
.91192 .54053 .9158 .54583 .92591 .54296 .92206 .53764 Metetra
.656 .752 .92 r
.92206 .53764 .92591 .54296 .93606 .54008 .93223 .53474 Metetra
.656 .752 .92 r
.93223 .53474 .93606 .54008 .94624 .53719 .94244 .53183 Metetra
.656 .752 .92 r
.94244 .53183 .94624 .53719 .95646 .53429 .95268 .52891 Metetra
.656 .752 .92 r
.95268 .52891 .95646 .53429 .96671 .53138 .96296 .52598 Metetra
.656 .752 .92 r
.96296 .52598 .96671 .53138 .977 .52846 .97327 .52305 Metetra
.656 .752 .92 r
.3815 .68577 .38658 .6902 .39499 .6878 .38992 .68336 Metetra
.656 .752 .92 r
.38992 .68336 .39499 .6878 .40342 .6854 .39837 .68094 Metetra
.656 .752 .92 r
.39837 .68094 .40342 .6854 .41188 .68299 .40685 .67852 Metetra
.656 .752 .92 r
.40685 .67852 .41188 .68299 .42037 .68057 .41535 .67609 Metetra
.656 .752 .92 r
.41535 .67609 .42037 .68057 .42888 .67815 .42389 .67365 Metetra
.656 .752 .92 r
.42389 .67365 .42888 .67815 .43742 .67571 .43244 .6712 Metetra
.656 .752 .92 r
.43244 .6712 .43742 .67571 .44599 .67327 .44103 .66875 Metetra
.656 .752 .92 r
.44103 .66875 .44599 .67327 .45458 .67082 .44964 .66628 Metetra
.656 .752 .92 r
.44964 .66628 .45458 .67082 .46321 .66837 .45828 .66381 Metetra
.656 .752 .92 r
.45828 .66381 .46321 .66837 .47185 .6659 .46695 .66133 Metetra
.656 .752 .92 r
.46695 .66133 .47185 .6659 .48053 .66343 .47564 .65885 Metetra
.656 .752 .92 r
.47564 .65885 .48053 .66343 .48924 .66095 .48436 .65635 Metetra
.656 .752 .92 r
.48436 .65635 .48924 .66095 .49797 .65846 .49311 .65385 Metetra
.656 .752 .92 r
.49311 .65385 .49797 .65846 .50673 .65597 .50189 .65134 Metetra
.656 .752 .92 r
.50189 .65134 .50673 .65597 .51552 .65346 .5107 .64882 Metetra
.656 .752 .92 r
.5107 .64882 .51552 .65346 .52433 .65095 .51954 .64629 Metetra
.94 .721 .578 r
.51954 .64629 .52433 .65095 .53318 .64843 .52834 .58522 Metetra
.392 .261 .582 r
.52834 .58522 .53318 .64843 .54205 .6459 .53719 .61306 Metetra
.607 .45 .643 r
.53719 .61306 .54205 .6459 .55076 .61784 .54604 .60988 Metetra
.597 .619 .844 r
.54604 .60988 .55076 .61784 .55965 .61768 .55493 .60898 Metetra
.563 .585 .834 r
.55493 .60898 .55965 .61768 .56854 .61396 .56386 .60908 Metetra
.779 .771 .846 r
.56386 .60908 .56854 .61396 .57742 .60858 .57275 .60254 Metetra
.723 .722 .849 r
.57275 .60254 .57742 .60858 .58634 .60426 .58168 .59786 Metetra
.917 .728 .633 r
.58168 .59786 .58634 .60426 .59467 .57086 .59009 .56536 Metetra
.954 .612 .308 r
.59009 .56536 .59467 .57086 .60475 .61799 .60013 .61305 Metetra
.789 .325 0 r
.60013 .61305 .60475 .61799 .61433 .63466 .60968 .62893 Metetra
.561 .679 .918 r
.60968 .62893 .61433 .63466 .62353 .63372 .61892 .62841 Metetra
.517 .678 .938 r
.61892 .62841 .62353 .63372 .6328 .63335 .62822 .62847 Metetra
.705 .765 .899 r
.62822 .62847 .6328 .63335 .64201 .6301 .63743 .62457 Metetra
.576 .695 .923 r
.63743 .62457 .64201 .6301 .65133 .62897 .64677 .62369 Metetra
.651 .734 .911 r
.64677 .62369 .65133 .62897 .66062 .62639 .65609 .62118 Metetra
.627 .729 .921 r
.65609 .62118 .66062 .62639 .66998 .6244 .66546 .61917 Metetra
.665 .742 .908 r
.66546 .61917 .66998 .6244 .67933 .62162 .67483 .6163 Metetra
.692 .748 .895 r
.67483 .6163 .67933 .62162 .68869 .61829 .6842 .61268 Metetra
.645 .722 .904 r
.6842 .61268 .68869 .61829 .69809 .61528 .69365 .61029 Metetra
.722 .771 .891 r
.69365 .61029 .69809 .61528 .70747 .61125 .70303 .60579 Metetra
.638 .726 .912 r
.70303 .60579 .70747 .61125 .71699 .60944 .71255 .60353 Metetra
.728 .74 .862 r
.71255 .60353 .71699 .60944 .72633 .60371 .72195 .59859 Metetra
.727 .77 .887 r
.72195 .59859 .72633 .60371 .73577 .59956 .73139 .5939 Metetra
.921 .765 .67 r
.73139 .5939 .73577 .59956 .74409 .57752 .73969 .57084 Metetra
.955 .728 .555 r
.73969 .57084 .74409 .57752 .75014 .52297 .74583 .51657 Metetra
.863 .458 0 r
.74583 .51657 .75014 .52297 .76171 .5508 .75746 .54556 Metetra
.686 .754 .903 r
.75746 .54556 .76171 .5508 .77148 .55121 .76697 .54206 Metetra
.63 .616 .818 r
.76697 .54206 .77148 .55121 .78106 .54846 .77662 .54003 Metetra
.618 .627 .837 r
.77662 .54003 .78106 .54846 .79294 .57442 .78634 .53842 Metetra
.761 .549 .61 r
.78634 .53842 .79294 .57442 .80267 .57165 .79355 .5052 Metetra
.203 .137 .555 r
.79355 .5052 .80267 .57165 .81244 .56887 .80829 .56371 Metetra
.656 .752 .92 r
.80829 .56371 .81244 .56887 .82223 .56608 .81811 .5609 Metetra
.656 .752 .92 r
.81811 .5609 .82223 .56608 .83206 .56328 .82796 .55808 Metetra
.656 .752 .92 r
.82796 .55808 .83206 .56328 .84193 .56047 .83785 .55525 Metetra
.656 .752 .92 r
.83785 .55525 .84193 .56047 .85182 .55765 .84777 .55242 Metetra
.656 .752 .92 r
.84777 .55242 .85182 .55765 .86176 .55482 .85773 .54957 Metetra
.656 .752 .92 r
.85773 .54957 .86176 .55482 .87172 .55198 .86772 .54671 Metetra
.656 .752 .92 r
.86772 .54671 .87172 .55198 .88172 .54913 .87774 .54385 Metetra
.656 .752 .92 r
.87774 .54385 .88172 .54913 .89175 .54627 .8878 .54097 Metetra
.656 .752 .92 r
.8878 .54097 .89175 .54627 .90182 .5434 .89789 .53808 Metetra
.656 .752 .92 r
.89789 .53808 .90182 .5434 .91192 .54053 .90802 .53519 Metetra
.656 .752 .92 r
.90802 .53519 .91192 .54053 .92206 .53764 .91818 .53228 Metetra
.656 .752 .92 r
.91818 .53228 .92206 .53764 .93223 .53474 .92838 .52936 Metetra
.656 .752 .92 r
.92838 .52936 .93223 .53474 .94244 .53183 .93861 .52644 Metetra
.656 .752 .92 r
.93861 .52644 .94244 .53183 .95268 .52891 .94888 .5235 Metetra
.656 .752 .92 r
.94888 .5235 .95268 .52891 .96296 .52598 .95918 .52055 Metetra
.656 .752 .92 r
.95918 .52055 .96296 .52598 .97327 .52305 .96952 .51759 Metetra
.656 .752 .92 r
.37639 .68132 .3815 .68577 .38992 .68336 .38483 .67889 Metetra
.656 .752 .92 r
.38483 .67889 .38992 .68336 .39837 .68094 .3933 .67646 Metetra
.656 .752 .92 r
.3933 .67646 .39837 .68094 .40685 .67852 .40179 .67402 Metetra
.656 .752 .92 r
.40179 .67402 .40685 .67852 .41535 .67609 .41031 .67158 Metetra
.656 .752 .92 r
.41031 .67158 .41535 .67609 .42389 .67365 .41886 .66912 Metetra
.656 .752 .92 r
.41886 .66912 .42389 .67365 .43244 .6712 .42744 .66666 Metetra
.656 .752 .92 r
.42744 .66666 .43244 .6712 .44103 .66875 .43604 .66419 Metetra
.656 .752 .92 r
.43604 .66419 .44103 .66875 .44964 .66628 .44467 .66171 Metetra
.656 .752 .92 r
.44467 .66171 .44964 .66628 .45828 .66381 .45332 .65923 Metetra
.656 .752 .92 r
.45332 .65923 .45828 .66381 .46695 .66133 .46201 .65674 Metetra
.656 .752 .92 r
.46201 .65674 .46695 .66133 .47564 .65885 .47072 .65423 Metetra
.656 .752 .92 r
.47072 .65423 .47564 .65885 .48436 .65635 .47946 .65172 Metetra
.656 .752 .92 r
.47946 .65172 .48436 .65635 .49311 .65385 .48823 .64921 Metetra
.656 .752 .92 r
.48823 .64921 .49311 .65385 .50189 .65134 .49703 .64668 Metetra
0 .085 .579 r
.49703 .64668 .50189 .65134 .5107 .64882 .5058 .65436 Metetra
.238 0 0 r
.5058 .65436 .5107 .64882 .51954 .64629 .51468 .65139 Metetra
.971 .926 .618 r
.51468 .65139 .51954 .64629 .52834 .58522 .52359 .62996 Metetra
0 0 .23 r
.52359 .62996 .52834 .58522 .53719 .61306 .53237 .57699 Metetra
.172 .134 .57 r
.53237 .57699 .53719 .61306 .54604 .60988 .5413 .60506 Metetra
.716 .762 .889 r
.5413 .60506 .54604 .60988 .55493 .60898 .55019 .60096 Metetra
.588 .614 .846 r
.55019 .60096 .55493 .60898 .56386 .60908 .55912 .60029 Metetra
.652 .627 .812 r
.55912 .60029 .56386 .60908 .57275 .60254 .56807 .59759 Metetra
.761 .768 .859 r
.56807 .59759 .57275 .60254 .58168 .59786 .57701 .59182 Metetra
.921 .732 .631 r
.57701 .59182 .58168 .59786 .59009 .56536 .58547 .55892 Metetra
.957 .615 .297 r
.58547 .55892 .59009 .56536 .60013 .61305 .59547 .60745 Metetra
.778 .323 0 r
.59547 .60745 .60013 .61305 .60968 .62893 .60503 .62395 Metetra
.584 .721 .938 r
.60503 .62395 .60968 .62893 .61892 .62841 .61427 .62276 Metetra
.51 .662 .93 r
.61427 .62276 .61892 .62841 .62822 .62847 .62359 .62304 Metetra
.69 .741 .89 r
.62359 .62304 .62822 .62847 .63743 .62457 .63283 .61951 Metetra
.584 .719 .936 r
.63283 .61951 .63743 .62457 .64677 .62369 .64218 .61832 Metetra
.653 .732 .908 r
.64218 .61832 .64677 .62369 .65609 .62118 .65152 .61573 Metetra
.628 .721 .914 r
.65152 .61573 .65609 .62118 .66546 .61917 .66091 .61371 Metetra
.662 .733 .903 r
.66091 .61371 .66546 .61917 .67483 .6163 .6703 .61087 Metetra
.681 .742 .897 r
.6703 .61087 .67483 .6163 .6842 .61268 .67971 .60754 Metetra
.66 .747 .914 r
.67971 .60754 .6842 .61268 .69365 .61029 .68916 .60474 Metetra
.725 .752 .874 r
.68916 .60474 .69365 .61029 .70303 .60579 .69855 .59999 Metetra
.611 .704 .91 r
.69855 .59999 .70303 .60579 .71255 .60353 .70812 .59838 Metetra
.752 .775 .872 r
.70812 .59838 .71255 .60353 .72195 .59859 .71752 .5928 Metetra
.745 .751 .857 r
.71752 .5928 .72195 .59859 .73139 .5939 .72693 .58724 Metetra
.908 .749 .672 r
.72693 .58724 .73139 .5939 .73969 .57084 .73529 .56452 Metetra
.957 .731 .556 r
.73529 .56452 .73969 .57084 .74583 .51657 .74158 .51125 Metetra
.852 .429 0 r
.74158 .51125 .74583 .51657 .75746 .54556 .75293 .53636 Metetra
.649 .625 .812 r
.75293 .53636 .75746 .54556 .76697 .54206 .76251 .5336 Metetra
.515 .574 .853 r
.76251 .5336 .76697 .54206 .77662 .54003 .77241 .53479 Metetra
.954 .761 .605 r
.77241 .53479 .77662 .54003 .78634 .53842 .7797 .50124 Metetra
0 0 .502 r
.7797 .50124 .78634 .53842 .79355 .5052 .79345 .55065 Metetra
.649 .382 .502 r
.79345 .55065 .79355 .5052 .80829 .56371 .80485 .56745 Metetra
.227 0 0 r
.80485 .56745 .80829 .56371 .81811 .5609 .81479 .5654 Metetra
.585 .815 .424 r
.81479 .5654 .81811 .5609 .82796 .55808 .82383 .55285 Metetra
.656 .752 .92 r
.82383 .55285 .82796 .55808 .83785 .55525 .83374 .55001 Metetra
.656 .752 .92 r
.83374 .55001 .83785 .55525 .84777 .55242 .84369 .54715 Metetra
.656 .752 .92 r
.84369 .54715 .84777 .55242 .85773 .54957 .85367 .54429 Metetra
.656 .752 .92 r
.85367 .54429 .85773 .54957 .86772 .54671 .86368 .54141 Metetra
.656 .752 .92 r
.86368 .54141 .86772 .54671 .87774 .54385 .87373 .53853 Metetra
.656 .752 .92 r
.87373 .53853 .87774 .54385 .8878 .54097 .88382 .53563 Metetra
.656 .752 .92 r
.88382 .53563 .8878 .54097 .89789 .53808 .89393 .53273 Metetra
.656 .752 .92 r
.89393 .53273 .89789 .53808 .90802 .53519 .90409 .52981 Metetra
.656 .752 .92 r
.90409 .52981 .90802 .53519 .91818 .53228 .91428 .52689 Metetra
.656 .752 .92 r
.91428 .52689 .91818 .53228 .92838 .52936 .9245 .52395 Metetra
.656 .752 .92 r
.9245 .52395 .92838 .52936 .93861 .52644 .93476 .52101 Metetra
.656 .752 .92 r
.93476 .52101 .93861 .52644 .94888 .5235 .94505 .51805 Metetra
.656 .752 .92 r
.94505 .51805 .94888 .5235 .95918 .52055 .95538 .51508 Metetra
.656 .752 .92 r
.95538 .51508 .95918 .52055 .96952 .51759 .96575 .51211 Metetra
.656 .752 .92 r
.37125 .67684 .37639 .68132 .38483 .67889 .37971 .6744 Metetra
.656 .752 .92 r
.37971 .6744 .38483 .67889 .3933 .67646 .38819 .67195 Metetra
.656 .752 .92 r
.38819 .67195 .3933 .67646 .40179 .67402 .3967 .6695 Metetra
.656 .752 .92 r
.3967 .6695 .40179 .67402 .41031 .67158 .40524 .66704 Metetra
.656 .752 .92 r
.40524 .66704 .41031 .67158 .41886 .66912 .41381 .66457 Metetra
.656 .752 .92 r
.41381 .66457 .41886 .66912 .42744 .66666 .4224 .6621 Metetra
.656 .752 .92 r
.4224 .6621 .42744 .66666 .43604 .66419 .43102 .65961 Metetra
.656 .752 .92 r
.43102 .65961 .43604 .66419 .44467 .66171 .43967 .65712 Metetra
.656 .752 .92 r
.43967 .65712 .44467 .66171 .45332 .65923 .44834 .65462 Metetra
.656 .752 .92 r
.44834 .65462 .45332 .65923 .46201 .65674 .45704 .65211 Metetra
.656 .752 .92 r
.45704 .65211 .46201 .65674 .47072 .65423 .46577 .6496 Metetra
.656 .752 .92 r
.46577 .6496 .47072 .65423 .47946 .65172 .47453 .64707 Metetra
.656 .752 .92 r
.47453 .64707 .47946 .65172 .48823 .64921 .48332 .64454 Metetra
.718 .222 0 r
.48332 .64454 .48823 .64921 .49703 .64668 .492 .6561 Metetra
.275 0 .141 r
.492 .6561 .49703 .64668 .5058 .65436 .5009 .65102 Metetra
.733 .828 .924 r
.5009 .65102 .5058 .65436 .51468 .65139 .50981 .64657 Metetra
.671 .752 .911 r
.50981 .64657 .51468 .65139 .52359 .62996 .51873 .64365 Metetra
.51873 .64365 .52359 .62996 .53237 .57699 .52767 .62178 Metetra
0 0 .231 r
.52767 .62178 .53237 .57699 .5413 .60506 .53643 .56882 Metetra
.192 .148 .576 r
.53643 .56882 .5413 .60506 .55019 .60096 .54544 .596 Metetra
.706 .756 .891 r
.54544 .596 .55019 .60096 .55912 .60029 .55437 .59214 Metetra
.673 .65 .819 r
.55437 .59214 .55912 .60029 .56807 .59759 .56333 .58875 Metetra
.63 .617 .818 r
.56333 .58875 .56807 .59759 .57701 .59182 .57233 .5868 Metetra
.931 .742 .625 r
.57233 .5868 .57701 .59182 .58547 .55892 .58082 .55265 Metetra
.956 .614 .299 r
.58082 .55265 .58547 .55892 .59547 .60745 .59077 .60092 Metetra
.762 .323 0 r
.59077 .60092 .59547 .60745 .60503 .62395 .60035 .61842 Metetra
.57 .694 .924 r
.60035 .61842 .60503 .62395 .61427 .62276 .60961 .61762 Metetra
.542 .699 .941 r
.60961 .61762 .61427 .62276 .62359 .62304 .61892 .61716 Metetra
.669 .719 .887 r
.61892 .61716 .62359 .62304 .63283 .61951 .6282 .61417 Metetra
.584 .709 .929 r
.6282 .61417 .63283 .61951 .64218 .61832 .63757 .61303 Metetra
.668 .742 .906 r
.63757 .61303 .64218 .61832 .65152 .61573 .64692 .61004 Metetra
.63 .714 .907 r
.64692 .61004 .65152 .61573 .66091 .61371 .65633 .60801 Metetra
.647 .721 .902 r
.65633 .60801 .66091 .61371 .6703 .61087 .66575 .60553 Metetra
.683 .747 .9 r
.66575 .60553 .6703 .61087 .67971 .60754 .67517 .60212 Metetra
.682 .744 .899 r
.67517 .60212 .67971 .60754 .68916 .60474 .68462 .59874 Metetra
.701 .73 .873 r
.68462 .59874 .68916 .60474 .69855 .59999 .69407 .5947 Metetra
.625 .731 .923 r
.69407 .5947 .69855 .59999 .70812 .59838 .70364 .59266 Metetra
.77 .76 .844 r
.70364 .59266 .70812 .59838 .71752 .5928 .713 .58605 Metetra
.729 .718 .84 r
.713 .58605 .71752 .5928 .72693 .58724 .72245 .58075 Metetra
.906 .753 .681 r
.72245 .58075 .72693 .58724 .73529 .56452 .73093 .55924 Metetra
.964 .736 .544 r
.73093 .55924 .73529 .56452 .74158 .51125 .73705 .50207 Metetra
.717 .339 0 r
.73705 .50207 .74158 .51125 .75293 .53636 .74843 .52782 Metetra
.545 .588 .848 r
.74843 .52782 .75293 .53636 .76251 .5336 .75824 .52826 Metetra
.948 .763 .62 r
.75824 .52826 .76251 .5336 .77241 .53479 .76584 .49753 Metetra
0 0 .498 r
.76584 .49753 .77241 .53479 .7797 .50124 .77934 .54665 Metetra
.652 .384 .501 r
.77934 .54665 .7797 .50124 .79345 .55065 .79072 .56432 Metetra
.479 .149 .329 r
.79072 .56432 .79345 .55065 .80485 .56745 .80063 .56212 Metetra
.546 .701 .942 r
.80063 .56212 .80485 .56745 .81479 .5654 .81071 .56155 Metetra
.462 .733 .986 r
.81071 .56155 .81479 .5654 .82383 .55285 .82089 .56145 Metetra
.82089 .56145 .82383 .55285 .83374 .55001 .82961 .54473 Metetra
.656 .752 .92 r
.82961 .54473 .83374 .55001 .84369 .54715 .83958 .54186 Metetra
.656 .752 .92 r
.83958 .54186 .84369 .54715 .85367 .54429 .84959 .53897 Metetra
.656 .752 .92 r
.84959 .53897 .85367 .54429 .86368 .54141 .85963 .53608 Metetra
.656 .752 .92 r
.85963 .53608 .86368 .54141 .87373 .53853 .8697 .53317 Metetra
.656 .752 .92 r
.8697 .53317 .87373 .53853 .88382 .53563 .87981 .53026 Metetra
.656 .752 .92 r
.87981 .53026 .88382 .53563 .89393 .53273 .88995 .52734 Metetra
.656 .752 .92 r
.88995 .52734 .89393 .53273 .90409 .52981 .90013 .5244 Metetra
.656 .752 .92 r
.90013 .5244 .90409 .52981 .91428 .52689 .91035 .52146 Metetra
.656 .752 .92 r
.91035 .52146 .91428 .52689 .9245 .52395 .9206 .51851 Metetra
.656 .752 .92 r
.9206 .51851 .9245 .52395 .93476 .52101 .93088 .51554 Metetra
.656 .752 .92 r
.93088 .51554 .93476 .52101 .94505 .51805 .9412 .51257 Metetra
.656 .752 .92 r
.9412 .51257 .94505 .51805 .95538 .51508 .95156 .50958 Metetra
.656 .752 .92 r
.95156 .50958 .95538 .51508 .96575 .51211 .96195 .50659 Metetra
.656 .752 .92 r
.36609 .67233 .37125 .67684 .37971 .6744 .37456 .66988 Metetra
.656 .752 .92 r
.37456 .66988 .37971 .6744 .38819 .67195 .38306 .66742 Metetra
.656 .752 .92 r
.38306 .66742 .38819 .67195 .3967 .6695 .39159 .66495 Metetra
.656 .752 .92 r
.39159 .66495 .3967 .6695 .40524 .66704 .40014 .66248 Metetra
.656 .752 .92 r
.40014 .66248 .40524 .66704 .41381 .66457 .40872 .65999 Metetra
.656 .752 .92 r
.40872 .65999 .41381 .66457 .4224 .6621 .41733 .6575 Metetra
.656 .752 .92 r
.41733 .6575 .4224 .6621 .43102 .65961 .42597 .655 Metetra
.656 .752 .92 r
.42597 .655 .43102 .65961 .43967 .65712 .43463 .6525 Metetra
.656 .752 .92 r
.43463 .6525 .43967 .65712 .44834 .65462 .44333 .64998 Metetra
.656 .752 .92 r
.44333 .64998 .44834 .65462 .45704 .65211 .45205 .64746 Metetra
.656 .752 .92 r
.45205 .64746 .45704 .65211 .46577 .6496 .46079 .64493 Metetra
.761 .273 0 r
.46079 .64493 .46577 .6496 .47453 .64707 .46933 .65722 Metetra
.344 0 .195 r
.46933 .65722 .47453 .64707 .48332 .64454 .4782 .65308 Metetra
.422 .032 .192 r
.4782 .65308 .48332 .64454 .492 .6561 .48706 .65134 Metetra
.666 .753 .916 r
.48706 .65134 .492 .6561 .5009 .65102 .49596 .64854 Metetra
.767 .872 .925 r
.49596 .64854 .5009 .65102 .50981 .64657 .5049 .64318 Metetra
.728 .827 .926 r
.5049 .64318 .50981 .64657 .51873 .64365 .51385 .63884 Metetra
.689 .759 .905 r
.51385 .63884 .51873 .64365 .52767 .62178 .52283 .63545 Metetra
.52283 .63545 .52767 .62178 .53643 .56882 .53179 .61363 Metetra
0 0 .222 r
.53179 .61363 .53643 .56882 .54544 .596 .54053 .55966 Metetra
.185 .143 .574 r
.54053 .55966 .54544 .596 .55437 .59214 .54962 .58721 Metetra
.78 .772 .846 r
.54962 .58721 .55437 .59214 .56333 .58875 .55857 .58059 Metetra
.656 .644 .826 r
.55857 .58059 .56333 .58875 .57233 .5868 .56757 .5778 Metetra
.891 .703 .641 r
.56757 .5778 .57233 .5868 .58082 .55265 .57617 .54752 Metetra
.953 .61 .312 r
.57617 .54752 .58082 .55265 .59077 .60092 .58605 .59479 Metetra
.769 .322 0 r
.58605 .59479 .59077 .60092 .60035 .61842 .59561 .61178 Metetra
.536 .639 .899 r
.59561 .61178 .60035 .61842 .60961 .61762 .60491 .61191 Metetra
.509 .662 .93 r
.60491 .61191 .60961 .61762 .61892 .61716 .61425 .61218 Metetra
.708 .765 .897 r
.61425 .61218 .61892 .61716 .6282 .61417 .62353 .60813 Metetra
.569 .676 .912 r
.62353 .60813 .6282 .61417 .63757 .61303 .63293 .60745 Metetra
.664 .731 .899 r
.63293 .60745 .63757 .61303 .64692 .61004 .64229 .60456 Metetra
.628 .723 .915 r
.64229 .60456 .64692 .61004 .65633 .60801 .65172 .60251 Metetra
.652 .731 .907 r
.65172 .60251 .65633 .60801 .66575 .60553 .66117 .5999 Metetra
.699 .742 .885 r
.66117 .5999 .66575 .60553 .67517 .60212 .67059 .59599 Metetra
.642 .705 .893 r
.67059 .59599 .67517 .60212 .68462 .59874 .6801 .59364 Metetra
.73 .772 .887 r
.6801 .59364 .68462 .59874 .69407 .5947 .68954 .58883 Metetra
.666 .725 .893 r
.68954 .58883 .69407 .5947 .70364 .59266 .69908 .58583 Metetra
.747 .722 .829 r
.69908 .58583 .70364 .59266 .713 .58605 .70849 .5797 Metetra
.703 .723 .865 r
.70849 .5797 .713 .58605 .72245 .58075 .71802 .57547 Metetra
.933 .769 .654 r
.71802 .57547 .72245 .58075 .73093 .55924 .7263 .54989 Metetra
.942 .711 .56 r
.7263 .54989 .73093 .55924 .73705 .50207 .73255 .49356 Metetra
.805 .418 0 r
.73255 .49356 .73705 .50207 .74843 .52782 .74412 .52252 Metetra
.948 .762 .617 r
.74412 .52252 .74843 .52782 .75824 .52826 .75176 .49102 Metetra
0 0 .47 r
.75176 .49102 .75824 .52826 .76584 .49753 .76523 .54289 Metetra
.651 .383 .5 r
.76523 .54289 .76584 .49753 .77934 .54665 .77648 .56028 Metetra
.498 .164 .331 r
.77648 .56028 .77934 .54665 .79072 .56432 .78645 .55902 Metetra
.556 .708 .942 r
.78645 .55902 .79072 .56432 .80063 .56212 .7965 .55824 Metetra
.425 .714 .984 r
.7965 .55824 .80063 .56212 .81071 .56155 .80669 .55859 Metetra
.594 .841 .991 r
.80669 .55859 .81071 .56155 .82089 .56145 .81669 .55611 Metetra
.681 .76 .911 r
.81669 .55611 .82089 .56145 .82961 .54473 .82663 .55258 Metetra
.44 .034 .172 r
.82663 .55258 .82961 .54473 .83958 .54186 .83683 .55143 Metetra
.83683 .55143 .83958 .54186 .84959 .53897 .84548 .53362 Metetra
.656 .752 .92 r
.84548 .53362 .84959 .53897 .85963 .53608 .85554 .53071 Metetra
.656 .752 .92 r
.85554 .53071 .85963 .53608 .8697 .53317 .86564 .52779 Metetra
.656 .752 .92 r
.86564 .52779 .8697 .53317 .87981 .53026 .87578 .52486 Metetra
.656 .752 .92 r
.87578 .52486 .87981 .53026 .88995 .52734 .88595 .52191 Metetra
.656 .752 .92 r
.88595 .52191 .88995 .52734 .90013 .5244 .89615 .51896 Metetra
.656 .752 .92 r
.89615 .51896 .90013 .5244 .91035 .52146 .90639 .516 Metetra
.656 .752 .92 r
.90639 .516 .91035 .52146 .9206 .51851 .91667 .51302 Metetra
.656 .752 .92 r
.91667 .51302 .9206 .51851 .93088 .51554 .92698 .51004 Metetra
.656 .752 .92 r
.92698 .51004 .93088 .51554 .9412 .51257 .93733 .50705 Metetra
.656 .752 .92 r
.93733 .50705 .9412 .51257 .95156 .50958 .94771 .50404 Metetra
.656 .752 .92 r
.94771 .50404 .95156 .50958 .96195 .50659 .95813 .50103 Metetra
.656 .752 .92 r
.36089 .6678 .36609 .67233 .37456 .66988 .36938 .66533 Metetra
.656 .752 .92 r
.36938 .66533 .37456 .66988 .38306 .66742 .3779 .66286 Metetra
.656 .752 .92 r
.3779 .66286 .38306 .66742 .39159 .66495 .38644 .66038 Metetra
.656 .752 .92 r
.38644 .66038 .39159 .66495 .40014 .66248 .39501 .65789 Metetra
.656 .752 .92 r
.39501 .65789 .40014 .66248 .40872 .65999 .40361 .65539 Metetra
.656 .752 .92 r
.40361 .65539 .40872 .65999 .41733 .6575 .41224 .65288 Metetra
.656 .752 .92 r
.41224 .65288 .41733 .6575 .42597 .655 .42089 .65037 Metetra
.656 .752 .92 r
.42089 .65037 .42597 .655 .43463 .6525 .42957 .64785 Metetra
.656 .752 .92 r
.42957 .64785 .43463 .6525 .44333 .64998 .43828 .64532 Metetra
.656 .752 .92 r
.43828 .64532 .44333 .64998 .45205 .64746 .44702 .64278 Metetra
.765 .277 0 r
.44702 .64278 .45205 .64746 .46079 .64493 .45549 .65504 Metetra
.405 .037 .223 r
.45549 .65504 .46079 .64493 .46933 .65722 .46433 .6523 Metetra
.657 .744 .914 r
.46433 .6523 .46933 .65722 .4782 .65308 .47319 .6497 Metetra
.728 .826 .926 r
.47319 .6497 .4782 .65308 .48706 .65134 .4821 .64538 Metetra
.622 .694 .896 r
.4821 .64538 .48706 .65134 .49596 .64854 .491 .64365 Metetra
.674 .752 .909 r
.491 .64365 .49596 .64854 .5049 .64318 .49995 .64063 Metetra
.764 .871 .926 r
.49995 .64063 .5049 .64318 .51385 .63884 .50894 .63531 Metetra
.745 .825 .914 r
.50894 .63531 .51385 .63884 .52283 .63545 .51794 .63048 Metetra
.683 .753 .904 r
.51794 .63048 .52283 .63545 .53179 .61363 .52696 .6272 Metetra
.52696 .6272 .53179 .61363 .54053 .55966 .53594 .60448 Metetra
0 0 .225 r
.53594 .60448 .54053 .55966 .54962 .58721 .54466 .55073 Metetra
.243 .184 .589 r
.54466 .55073 .54962 .58721 .55857 .58059 .55381 .57542 Metetra
.762 .763 .854 r
.55381 .57542 .55857 .58059 .56757 .5778 .5628 .5695 Metetra
.899 .71 .639 r
.5628 .5695 .56757 .5778 .57617 .54752 .57145 .53856 Metetra
.96 .621 .27 r
.57145 .53856 .57617 .54752 .58605 .59479 .58133 .58954 Metetra
.78 .317 0 r
.58133 .58954 .58605 .59479 .59561 .61178 .59085 .60541 Metetra
.54 .651 .907 r
.59085 .60541 .59561 .61178 .60491 .61191 .60016 .60535 Metetra
.491 .622 .907 r
.60016 .60535 .60491 .61191 .61425 .61218 .60954 .60623 Metetra
.682 .723 .881 r
.60954 .60623 .61425 .61218 .62353 .60813 .61884 .60282 Metetra
.61 .722 .925 r
.61884 .60282 .62353 .60813 .63293 .60745 .62823 .60113 Metetra
.631 .693 .89 r
.62823 .60113 .63293 .60745 .64229 .60456 .63765 .59909 Metetra
.628 .724 .916 r
.63765 .59909 .64229 .60456 .65172 .60251 .6471 .59702 Metetra
.685 .744 .896 r
.6471 .59702 .65172 .60251 .66117 .5999 .65653 .59353 Metetra
.663 .706 .879 r
.65653 .59353 .66117 .5999 .67059 .59599 .66601 .59059 Metetra
.667 .743 .907 r
.66601 .59059 .67059 .59599 .6801 .59364 .67551 .58756 Metetra
.739 .742 .854 r
.67551 .58756 .6801 .59364 .68954 .58883 .68494 .58211 Metetra
.659 .695 .872 r
.68494 .58211 .68954 .58883 .69908 .58583 .69451 .57925 Metetra
.723 .723 .85 r
.69451 .57925 .69908 .58583 .70849 .5797 .704 .57425 Metetra
.804 .779 .83 r
.704 .57425 .70849 .5797 .71802 .57547 .71334 .56616 Metetra
.887 .712 .658 r
.71334 .56616 .71802 .57547 .7263 .54989 .7217 .54125 Metetra
.944 .717 .564 r
.7217 .54125 .7263 .54989 .73255 .49356 .72822 .48801 Metetra
.657 .733 .906 r
.72822 .48801 .73255 .49356 .74412 .52252 .73773 .48526 Metetra
0 0 .47 r
.73773 .48526 .74412 .52252 .75176 .49102 .75089 .53625 Metetra
.663 .392 .5 r
.75089 .53625 .75176 .49102 .76523 .54289 .76223 .55642 Metetra
.489 .154 .325 r
.76223 .55642 .76523 .54289 .77648 .56028 .77216 .55486 Metetra
.502 .678 .944 r
.77216 .55486 .77648 .56028 .78645 .55902 .78226 .55504 Metetra
.442 .718 .983 r
.78226 .55504 .78645 .55902 .7965 .55824 .79241 .55523 Metetra
.569 .829 .994 r
.79241 .55523 .7965 .55824 .80669 .55859 .80243 .55314 Metetra
.683 .757 .907 r
.80243 .55314 .80669 .55859 .81669 .55611 .81236 .54952 Metetra
.578 .671 .903 r
.81236 .54952 .81669 .55611 .82663 .55258 .82256 .54862 Metetra
.635 .808 .966 r
.82256 .54862 .82663 .55258 .83683 .55143 .83264 .54585 Metetra
.643 .739 .918 r
.83264 .54585 .83683 .55143 .84548 .53362 .84276 .54325 Metetra
.84276 .54325 .84548 .53362 .85554 .53071 .85144 .52531 Metetra
.656 .752 .92 r
.85144 .52531 .85554 .53071 .86564 .52779 .86156 .52237 Metetra
.656 .752 .92 r
.86156 .52237 .86564 .52779 .87578 .52486 .87172 .51942 Metetra
.656 .752 .92 r
.87172 .51942 .87578 .52486 .88595 .52191 .88191 .51645 Metetra
.656 .752 .92 r
.88191 .51645 .88595 .52191 .89615 .51896 .89214 .51348 Metetra
.656 .752 .92 r
.89214 .51348 .89615 .51896 .90639 .516 .90241 .5105 Metetra
.656 .752 .92 r
.90241 .5105 .90639 .516 .91667 .51302 .91271 .50751 Metetra
.656 .752 .92 r
.91271 .50751 .91667 .51302 .92698 .51004 .92305 .50451 Metetra
.656 .752 .92 r
.92305 .50451 .92698 .51004 .93733 .50705 .93343 .50149 Metetra
.656 .752 .92 r
.93343 .50149 .93733 .50705 .94771 .50404 .94384 .49847 Metetra
.656 .752 .92 r
.94384 .49847 .94771 .50404 .95813 .50103 .95429 .49543 Metetra
.656 .752 .92 r
.35566 .66324 .36089 .6678 .36938 .66533 .36417 .66076 Metetra
.656 .752 .92 r
.36417 .66076 .36938 .66533 .3779 .66286 .3727 .65827 Metetra
.656 .752 .92 r
.3727 .65827 .3779 .66286 .38644 .66038 .38126 .65577 Metetra
.656 .752 .92 r
.38126 .65577 .38644 .66038 .39501 .65789 .38985 .65327 Metetra
.656 .752 .92 r
.38985 .65327 .39501 .65789 .40361 .65539 .39847 .65076 Metetra
.656 .752 .92 r
.39847 .65076 .40361 .65539 .41224 .65288 .40711 .64824 Metetra
.656 .752 .92 r
.40711 .64824 .41224 .65288 .42089 .65037 .41578 .64571 Metetra
.656 .752 .92 r
.41578 .64571 .42089 .65037 .42957 .64785 .42448 .64317 Metetra
.656 .752 .92 r
.42448 .64317 .42957 .64785 .43828 .64532 .43321 .64063 Metetra
.792 .312 0 r
.43321 .64063 .43828 .64532 .44702 .64278 .44159 .65353 Metetra
.417 .056 .242 r
.44159 .65353 .44702 .64278 .45549 .65504 .45042 .65087 Metetra
.69 .784 .923 r
.45042 .65087 .45549 .65504 .46433 .6523 .45929 .64749 Metetra
.663 .751 .916 r
.45929 .64749 .46433 .6523 .47319 .6497 .46817 .64474 Metetra
.665 .747 .911 r
.46817 .64474 .47319 .6497 .4821 .64538 .47708 .64195 Metetra
.724 .826 .928 r
.47708 .64195 .4821 .64538 .491 .64365 .48603 .6377 Metetra
.632 .7 .894 r
.48603 .6377 .491 .64365 .49995 .64063 .49499 .63569 Metetra
.672 .751 .91 r
.49499 .63569 .49995 .64063 .50894 .63531 .50398 .6327 Metetra
.78 .87 .915 r
.50398 .6327 .50894 .63531 .51794 .63048 .51301 .62691 Metetra
.737 .824 .918 r
.51301 .62691 .51794 .63048 .52696 .6272 .52206 .62227 Metetra
.715 .764 .891 r
.52206 .62227 .52696 .6272 .53594 .60448 .53112 .61808 Metetra
.53112 .61808 .53594 .60448 .54466 .55073 .54012 .59548 Metetra
0 0 .196 r
.54012 .59548 .54466 .55073 .55381 .57542 .54881 .53889 Metetra
.226 .172 .585 r
.54881 .53889 .55381 .57542 .5628 .5695 .55804 .56443 Metetra
.931 .743 .625 r
.55804 .56443 .5628 .5695 .57145 .53856 .56671 .53017 Metetra
.959 .62 .276 r
.56671 .53017 .57145 .53856 .58133 .58954 .57651 .58037 Metetra
.698 .309 0 r
.57651 .58037 .58133 .58954 .59085 .60541 .5861 .60035 Metetra
.6 .729 .935 r
.5861 .60035 .59085 .60541 .60016 .60535 .59539 .59881 Metetra
.504 .63 .908 r
.59539 .59881 .60016 .60535 .60954 .60623 .60477 .59943 Metetra
.657 .688 .868 r
.60477 .59943 .60954 .60623 .61884 .60282 .61411 .59668 Metetra
.566 .674 .911 r
.61411 .59668 .61884 .60282 .62823 .60113 .62355 .59602 Metetra
.673 .754 .912 r
.62355 .59602 .62823 .60113 .63765 .59909 .63295 .59285 Metetra
.631 .698 .894 r
.63295 .59285 .63765 .59909 .6471 .59702 .64241 .59077 Metetra
.643 .703 .89 r
.64241 .59077 .6471 .59702 .65653 .59353 .6519 .58837 Metetra
.703 .764 .899 r
.6519 .58837 .65653 .59353 .66601 .59059 .66137 .58437 Metetra
.689 .722 .874 r
.66137 .58437 .66601 .59059 .67551 .58756 .67086 .58064 Metetra
.725 .713 .839 r
.67086 .58064 .67551 .58756 .68494 .58211 .68032 .57542 Metetra
.603 .673 .89 r
.68032 .57542 .68494 .58211 .69451 .57925 .68998 .57402 Metetra
.825 .788 .817 r
.68998 .57402 .69451 .57925 .704 .57425 .69928 .5648 Metetra
.742 .665 .775 r
.69928 .5648 .704 .57425 .71334 .56616 .70868 .55742 Metetra
.88 .718 .677 r
.70868 .55742 .71334 .56616 .7217 .54125 .71727 .53591 Metetra
.969 .722 .507 r
.71727 .53591 .7217 .54125 .72822 .48801 .72199 .45128 Metetra
0 0 .205 r
.72199 .45128 .72822 .48801 .73773 .48526 .73659 .53031 Metetra
.66 .389 .499 r
.73659 .53031 .73773 .48526 .75089 .53625 .74777 .54977 Metetra
.549 .206 .34 r
.74777 .54977 .75089 .53625 .76223 .55642 .75787 .55105 Metetra
.522 .691 .945 r
.75787 .55105 .76223 .55642 .77216 .55486 .76791 .55086 Metetra
.36 .674 .976 r
.76791 .55086 .77216 .55486 .78226 .55504 .77811 .55199 Metetra
.579 .831 .993 r
.77811 .55199 .78226 .55504 .79241 .55523 .7881 .54976 Metetra
.666 .751 .913 r
.7881 .54976 .79241 .55523 .80243 .55314 .79806 .54659 Metetra
.583 .676 .904 r
.79806 .54659 .80243 .55314 .81236 .54952 .80823 .54554 Metetra
.621 .802 .969 r
.80823 .54554 .81236 .54952 .82256 .54862 .81831 .54303 Metetra
.645 .74 .918 r
.81831 .54303 .82256 .54862 .83264 .54585 .82843 .54037 Metetra
.613 .732 .93 r
.82843 .54037 .83264 .54585 .84276 .54325 .83864 .5384 Metetra
.644 .772 .941 r
.83864 .5384 .84276 .54325 .85144 .52531 .84882 .53563 Metetra
.84882 .53563 .85144 .52531 .86156 .52237 .85745 .51691 Metetra
.656 .752 .92 r
.85745 .51691 .86156 .52237 .87172 .51942 .86764 .51394 Metetra
.656 .752 .92 r
.86764 .51394 .87172 .51942 .88191 .51645 .87786 .51096 Metetra
.656 .752 .92 r
.87786 .51096 .88191 .51645 .89214 .51348 .88811 .50797 Metetra
.656 .752 .92 r
.88811 .50797 .89214 .51348 .90241 .5105 .8984 .50497 Metetra
.656 .752 .92 r
.8984 .50497 .90241 .5105 .91271 .50751 .90873 .50196 Metetra
.656 .752 .92 r
.90873 .50196 .91271 .50751 .92305 .50451 .9191 .49893 Metetra
.656 .752 .92 r
.9191 .49893 .92305 .50451 .93343 .50149 .9295 .4959 Metetra
.656 .752 .92 r
.9295 .4959 .93343 .50149 .94384 .49847 .93994 .49286 Metetra
.656 .752 .92 r
.93994 .49286 .94384 .49847 .95429 .49543 .95041 .4898 Metetra
.656 .752 .92 r
.3504 .65865 .35566 .66324 .36417 .66076 .35892 .65616 Metetra
.656 .752 .92 r
.35892 .65616 .36417 .66076 .3727 .65827 .36747 .65366 Metetra
.656 .752 .92 r
.36747 .65366 .3727 .65827 .38126 .65577 .37605 .65114 Metetra
.656 .752 .92 r
.37605 .65114 .38126 .65577 .38985 .65327 .38466 .64863 Metetra
.656 .752 .92 r
.38466 .64863 .38985 .65327 .39847 .65076 .39329 .6461 Metetra
.656 .752 .92 r
.39329 .6461 .39847 .65076 .40711 .64824 .40195 .64356 Metetra
.656 .752 .92 r
.40195 .64356 .40711 .64824 .41578 .64571 .41064 .64102 Metetra
.656 .752 .92 r
.41064 .64102 .41578 .64571 .42448 .64317 .41936 .63847 Metetra
.773 .286 0 r
.41936 .63847 .42448 .64317 .43321 .64063 .42769 .65068 Metetra
.4 .029 .214 r
.42769 .65068 .43321 .64063 .44159 .65353 .43651 .64798 Metetra
.633 .713 .905 r
.43651 .64798 .44159 .65353 .45042 .65087 .44533 .64596 Metetra
.665 .748 .912 r
.44533 .64596 .45042 .65087 .45929 .64749 .45421 .64317 Metetra
.689 .779 .92 r
.45421 .64317 .45929 .64749 .46817 .64474 .46312 .63977 Metetra
.667 .748 .91 r
.46312 .63977 .46817 .64474 .47708 .64195 .47205 .6369 Metetra
.663 .744 .91 r
.47205 .6369 .47708 .64195 .48603 .6377 .481 .63412 Metetra
.734 .821 .919 r
.481 .63412 .48603 .6377 .49499 .63569 .49001 .62956 Metetra
.63 .695 .891 r
.49001 .62956 .49499 .63569 .50398 .6327 .49901 .6276 Metetra
.686 .75 .9 r
.49901 .6276 .50398 .6327 .51301 .62691 .50805 .62422 Metetra
.773 .868 .918 r
.50805 .62422 .51301 .62691 .52206 .62227 .51713 .61858 Metetra
.77 .824 .895 r
.51713 .61858 .52206 .62227 .53112 .61808 .52621 .61288 Metetra
.704 .753 .89 r
.52621 .61288 .53112 .61808 .54012 .59548 .53532 .60894 Metetra
.669 .739 .239 r
.53532 .60894 .54012 .59548 .54881 .53889 .54433 .58362 Metetra
0 0 .203 r
.54433 .58362 .54881 .53889 .55804 .56443 .55299 .52767 Metetra
.598 .435 .633 r
.55299 .52767 .55804 .56443 .56671 .53017 .56198 .52478 Metetra
.953 .61 .309 r
.56198 .52478 .56671 .53017 .57651 .58037 .57169 .57199 Metetra
.712 .306 0 r
.57169 .57199 .57651 .58037 .5861 .60035 .58124 .59088 Metetra
.459 .522 .836 r
.58124 .59088 .5861 .60035 .59539 .59881 .59062 .59341 Metetra
.563 .701 .934 r
.59062 .59341 .59539 .59881 .60477 .59943 .59998 .59259 Metetra
.652 .686 .869 r
.59998 .59259 .60477 .59943 .61411 .59668 .60934 .58996 Metetra
.545 .645 .899 r
.60934 .58996 .61411 .59668 .62355 .59602 .61881 .58984 Metetra
.666 .714 .884 r
.61881 .58984 .62355 .59602 .63295 .59285 .62823 .58684 Metetra
.63 .707 .901 r
.62823 .58684 .63295 .59285 .64241 .59077 .63772 .58474 Metetra
.65 .714 .895 r
.63772 .58474 .64241 .59077 .6519 .58837 .64722 .58214 Metetra
.714 .73 .863 r
.64722 .58214 .6519 .58837 .66137 .58437 .65668 .57755 Metetra
.69 .705 .859 r
.65668 .57755 .66137 .58437 .67086 .58064 .66619 .57367 Metetra
.687 .7 .856 r
.66619 .57367 .67086 .58064 .68032 .57542 .67573 .56985 Metetra
.746 .763 .867 r
.67573 .56985 .68032 .57542 .68998 .57402 .68521 .56431 Metetra
.751 .665 .766 r
.68521 .56431 .68998 .57402 .69928 .5648 .69458 .55615 Metetra
.688 .659 .816 r
.69458 .55615 .69928 .5648 .70868 .55742 .70416 .55187 Metetra
.961 .737 .554 r
.70416 .55187 .70868 .55742 .71727 .53591 .71099 .49808 Metetra
.595 .433 .633 r
.71099 .49808 .71727 .53591 .72199 .45128 .72057 .49537 Metetra
.757 .471 .499 r
.72057 .49537 .72199 .45128 .73659 .53031 .73334 .54365 Metetra
.531 .188 .331 r
.73334 .54365 .73659 .53031 .74777 .54977 .74335 .54416 Metetra
.32 .574 .932 r
.74335 .54416 .74777 .54977 .75787 .55105 .75356 .54696 Metetra
.394 .689 .979 r
.75356 .54696 .75787 .55105 .76791 .55086 .7637 .54775 Metetra
.516 .802 .998 r
.7637 .54775 .76791 .55086 .77811 .55199 .77374 .54638 Metetra
.672 .748 .908 r
.77374 .54638 .77811 .55199 .7881 .54976 .78367 .54307 Metetra
.563 .662 .904 r
.78367 .54307 .7881 .54976 .79806 .54659 .79386 .54248 Metetra
.628 .799 .964 r
.79386 .54248 .79806 .54659 .80823 .54554 .80393 .53988 Metetra
.637 .734 .919 r
.80393 .53988 .80823 .54554 .81831 .54303 .81404 .53741 Metetra
.616 .728 .926 r
.81404 .53741 .81831 .54303 .82843 .54037 .82424 .5354 Metetra
.638 .765 .94 r
.82424 .5354 .82843 .54037 .83864 .5384 .83442 .53278 Metetra
.649 .743 .918 r
.83442 .53278 .83864 .5384 .84882 .53563 .84462 .52997 Metetra
.673 .752 .91 r
.84462 .52997 .84882 .53563 .85745 .51691 .8548 .52655 Metetra
.8548 .52655 .85745 .51691 .86764 .51394 .86353 .50843 Metetra
.656 .752 .92 r
.86353 .50843 .86764 .51394 .87786 .51096 .87377 .50543 Metetra
.656 .752 .92 r
.87377 .50543 .87786 .51096 .88811 .50797 .88405 .50242 Metetra
.656 .752 .92 r
.88405 .50242 .88811 .50797 .8984 .50497 .89437 .4994 Metetra
.656 .752 .92 r
.89437 .4994 .8984 .50497 .90873 .50196 .90473 .49637 Metetra
.656 .752 .92 r
.90473 .49637 .90873 .50196 .9191 .49893 .91512 .49333 Metetra
.656 .752 .92 r
.91512 .49333 .9191 .49893 .9295 .4959 .92555 .49027 Metetra
.656 .752 .92 r
.92555 .49027 .9295 .4959 .93994 .49286 .93601 .48721 Metetra
.656 .752 .92 r
.93601 .48721 .93994 .49286 .95041 .4898 .94652 .48413 Metetra
.656 .752 .92 r
.34511 .65404 .3504 .65865 .35892 .65616 .35365 .65153 Metetra
.656 .752 .92 r
.35365 .65153 .35892 .65616 .36747 .65366 .36222 .64901 Metetra
.656 .752 .92 r
.36222 .64901 .36747 .65366 .37605 .65114 .37081 .64649 Metetra
.656 .752 .92 r
.37081 .64649 .37605 .65114 .38466 .64863 .37943 .64395 Metetra
.656 .752 .92 r
.37943 .64395 .38466 .64863 .39329 .6461 .38809 .64141 Metetra
.656 .752 .92 r
.38809 .64141 .39329 .6461 .40195 .64356 .39676 .63886 Metetra
.656 .752 .92 r
.39676 .63886 .40195 .64356 .41064 .64102 .40547 .6363 Metetra
.717 .215 0 r
.40547 .6363 .41064 .64102 .41936 .63847 .41378 .64708 Metetra
.439 .046 .194 r
.41378 .64708 .41936 .63847 .42769 .65068 .42253 .64589 Metetra
.665 .753 .916 r
.42253 .64589 .42769 .65068 .43651 .64798 .43137 .64309 Metetra
.661 .749 .915 r
.43137 .64309 .43651 .64798 .44533 .64596 .44023 .64038 Metetra
.638 .716 .904 r
.44023 .64038 .44533 .64596 .45421 .64317 .44911 .63822 Metetra
.661 .748 .914 r
.44911 .63822 .45421 .64317 .46312 .63977 .45803 .63548 Metetra
.696 .784 .919 r
.45803 .63548 .46312 .63977 .47205 .6369 .46699 .63189 Metetra
.666 .748 .911 r
.46699 .63189 .47205 .6369 .481 .63412 .47596 .62901 Metetra
.674 .747 .906 r
.47596 .62901 .481 .63412 .49001 .62956 .48497 .62595 Metetra
.729 .821 .922 r
.48497 .62595 .49001 .62956 .49901 .6276 .49402 .62151 Metetra
.646 .703 .889 r
.49402 .62151 .49901 .6276 .50805 .62422 .50307 .61913 Metetra
.685 .752 .903 r
.50307 .61913 .50805 .62422 .51713 .61858 .51216 .61576 Metetra
.801 .863 .895 r
.51216 .61576 .51713 .61858 .52621 .61288 .52128 .60916 Metetra
.757 .823 .904 r
.52128 .60916 .52621 .61288 .53532 .60894 .5304 .60386 Metetra
.783 .773 .845 r
.5304 .60386 .53532 .60894 .54433 .58362 .53954 .59699 Metetra
.53954 .59699 .54433 .58362 .55299 .52767 .54857 .57226 Metetra
.54857 .57226 .55299 .52767 .56198 .52478 .55693 .48866 Metetra
.776 .547 0 r
.55693 .48866 .56198 .52478 .57169 .57199 .56689 .56652 Metetra
.771 .308 0 r
.56689 .56652 .57169 .57199 .58124 .59088 .57638 .58226 Metetra
.492 .562 .855 r
.57638 .58226 .58124 .59088 .59062 .59341 .58574 .58376 Metetra
.406 .489 .833 r
.58574 .58376 .59062 .59341 .59998 .59259 .5952 .5874 Metetra
.71 .762 .893 r
.5952 .5874 .59998 .59259 .60934 .58996 .60455 .58321 Metetra
.58 .661 .893 r
.60455 .58321 .60934 .58996 .61881 .58984 .61401 .58235 Metetra
.604 .649 .868 r
.61401 .58235 .61881 .58984 .62823 .58684 .6235 .581 Metetra
.629 .714 .908 r
.6235 .581 .62823 .58684 .63772 .58474 .633 .57888 Metetra
.708 .741 .877 r
.633 .57888 .63772 .58474 .64722 .58214 .64246 .57459 Metetra
.685 .683 .842 r
.64246 .57459 .64722 .58214 .65668 .57755 .65196 .57072 Metetra
.64 .686 .877 r
.65196 .57072 .65668 .57755 .66619 .57367 .66156 .56836 Metetra
.809 .784 .829 r
.66156 .56836 .66619 .57367 .67573 .56985 .67092 .56001 Metetra
.686 .635 .793 r
.67092 .56001 .67573 .56985 .68521 .56431 .68047 .55547 Metetra
.703 .661 .806 r
.68047 .55547 .68521 .56431 .69458 .55615 .69002 .55048 Metetra
.948 .751 .604 r
.69002 .55048 .69458 .55615 .70416 .55187 .69794 .5139 Metetra
.211 .167 .588 r
.69794 .5139 .70416 .55187 .71099 .49808 .70934 .54368 Metetra
.215 .037 .411 r
.70934 .54368 .71099 .49808 .72057 .49537 .71721 .50826 Metetra
.823 .479 .403 r
.71721 .50826 .72057 .49537 .73334 .54365 .72888 .5382 Metetra
.382 .617 .944 r
.72888 .5382 .73334 .54365 .74335 .54416 .73899 .54005 Metetra
.104 .512 .907 r
.73899 .54005 .74335 .54416 .75356 .54696 .74928 .54374 Metetra
.536 .806 .995 r
.74928 .54374 .75356 .54696 .7637 .54775 .75929 .54218 Metetra
.635 .736 .921 r
.75929 .54218 .7637 .54775 .77374 .54638 .76927 .53976 Metetra
.572 .67 .905 r
.76927 .53976 .77374 .54638 .78367 .54307 .77942 .53895 Metetra
.603 .789 .97 r
.77942 .53895 .78367 .54307 .79386 .54248 .78951 .53679 Metetra
.639 .735 .918 r
.78951 .53679 .79386 .54248 .80393 .53988 .79961 .53426 Metetra
.604 .724 .929 r
.79961 .53426 .80393 .53988 .81404 .53741 .80981 .5325 Metetra
.642 .77 .941 r
.80981 .5325 .81404 .53741 .82424 .5354 .81997 .52977 Metetra
.642 .741 .921 r
.81997 .52977 .82424 .5354 .83442 .53278 .83018 .52713 Metetra
.674 .753 .911 r
.83018 .52713 .83442 .53278 .84462 .52997 .84034 .52367 Metetra
.645 .718 .901 r
.84034 .52367 .84462 .52997 .8548 .52655 .85062 .52098 Metetra
.706 .77 .902 r
.85062 .52098 .8548 .52655 .86353 .50843 .86077 .51659 Metetra
.86077 .51659 .86353 .50843 .87377 .50543 .86966 .49986 Metetra
.656 .752 .92 r
.86966 .49986 .87377 .50543 .88405 .50242 .87997 .49683 Metetra
.656 .752 .92 r
.87997 .49683 .88405 .50242 .89437 .4994 .89031 .49379 Metetra
.656 .752 .92 r
.89031 .49379 .89437 .4994 .90473 .49637 .9007 .49074 Metetra
.656 .752 .92 r
.9007 .49074 .90473 .49637 .91512 .49333 .91111 .48768 Metetra
.656 .752 .92 r
.91111 .48768 .91512 .49333 .92555 .49027 .92157 .48461 Metetra
.656 .752 .92 r
.92157 .48461 .92555 .49027 .93601 .48721 .93206 .48152 Metetra
.656 .752 .92 r
.93206 .48152 .93601 .48721 .94652 .48413 .94259 .47843 Metetra
.656 .752 .92 r
.33979 .6494 .34511 .65404 .35365 .65153 .34834 .64688 Metetra
.656 .752 .92 r
.34834 .64688 .35365 .65153 .36222 .64901 .35693 .64434 Metetra
.656 .752 .92 r
.35693 .64434 .36222 .64901 .37081 .64649 .36554 .6418 Metetra
.656 .752 .92 r
.36554 .6418 .37081 .64649 .37943 .64395 .37418 .63925 Metetra
.656 .752 .92 r
.37418 .63925 .37943 .64395 .38809 .64141 .38285 .63669 Metetra
.656 .752 .92 r
.38285 .63669 .38809 .64141 .39676 .63886 .39154 .63413 Metetra
.763 .271 0 r
.39154 .63413 .39676 .63886 .40547 .6363 .39975 .6458 Metetra
.327 0 .152 r
.39975 .6458 .40547 .6363 .41378 .64708 .40858 .64205 Metetra
.658 .742 .912 r
.40858 .64205 .41378 .64708 .42253 .64589 .4174 .6394 Metetra
.602 .671 .889 r
.4174 .6394 .42253 .64589 .43137 .64309 .4262 .6381 Metetra
.665 .747 .911 r
.4262 .6381 .43137 .64309 .44023 .64038 .43509 .63529 Metetra
.663 .743 .909 r
.43509 .63529 .44023 .64038 .44911 .63822 .44399 .63249 Metetra
.637 .712 .901 r
.44399 .63249 .44911 .63822 .45803 .63548 .45292 .63032 Metetra
.669 .743 .906 r
.45292 .63032 .45803 .63548 .46699 .63189 .46189 .62737 Metetra
.694 .776 .914 r
.46189 .62737 .46699 .63189 .47596 .62901 .47089 .62379 Metetra
.674 .743 .903 r
.47089 .62379 .47596 .62901 .48497 .62595 .47992 .6207 Metetra
.669 .742 .905 r
.47992 .6207 .48497 .62595 .49402 .62151 .48897 .61773 Metetra
.747 .818 .908 r
.48897 .61773 .49402 .62151 .50307 .61913 .49807 .61273 Metetra
.641 .692 .883 r
.49807 .61273 .50307 .61913 .51216 .61576 .50716 .61046 Metetra
.711 .753 .885 r
.50716 .61046 .51216 .61576 .52128 .60916 .5163 .60628 Metetra
.795 .863 .9 r
.5163 .60628 .52128 .60916 .5304 .60386 .52546 .59987 Metetra
.824 .814 .841 r
.52546 .59987 .5304 .60386 .53954 .59699 .53462 .59157 Metetra
.758 .76 .854 r
.53462 .59157 .53954 .59699 .54857 .57226 .5438 .58563 Metetra
.991 .827 .451 r
.5438 .58563 .54857 .57226 .55693 .48866 .5526 .53208 Metetra
.531 .281 .48 r
.5526 .53208 .55693 .48866 .56689 .56652 .56171 .52909 Metetra
0 0 .406 r
.56171 .52909 .56689 .56652 .57638 .58226 .57153 .57648 Metetra
.593 .7 .917 r
.57153 .57648 .57638 .58226 .58574 .58376 .58086 .57516 Metetra
.44 .536 .859 r
.58086 .57516 .58574 .58376 .5952 .5874 .59031 .57765 Metetra
.582 .584 .82 r
.59031 .57765 .5952 .5874 .60455 .58321 .59974 .57707 Metetra
.595 .689 .908 r
.59974 .57707 .60455 .58321 .61401 .58235 .60921 .57576 Metetra
.637 .692 .884 r
.60921 .57576 .61401 .58235 .6235 .581 .61869 .57348 Metetra
.632 .662 .861 r
.61869 .57348 .6235 .581 .633 .57888 .6282 .57134 Metetra
.672 .678 .848 r
.6282 .57134 .633 .57888 .64246 .57459 .63771 .56794 Metetra
.678 .707 .87 r
.63771 .56794 .64246 .57459 .65196 .57072 .64725 .56448 Metetra
.75 .743 .845 r
.64725 .56448 .65196 .57072 .66156 .56836 .65672 .55846 Metetra
.735 .656 .771 r
.65672 .55846 .66156 .56836 .67092 .56001 .66615 .55123 Metetra
.617 .625 .836 r
.66615 .55123 .67092 .56001 .68047 .55547 .67584 .54949 Metetra
.945 .746 .603 r
.67584 .54949 .68047 .55547 .69002 .55048 .68386 .51211 Metetra
0 0 .476 r
.68386 .51211 .69002 .55048 .69794 .5139 .69603 .55983 Metetra
.536 .286 .483 r
.69603 .55983 .69794 .5139 .70934 .54368 .70583 .55726 Metetra
.948 .795 .341 r
.70583 .55726 .70934 .54368 .71721 .50826 .71272 .50246 Metetra
.892 .49 .063 r
.71272 .50246 .71721 .50826 .72888 .5382 .72445 .53384 Metetra
.201 .564 .937 r
.72445 .53384 .72888 .5382 .73899 .54005 .73466 .5368 Metetra
.282 .672 .971 r
.73466 .5368 .73899 .54005 .74928 .54374 .74481 .53799 Metetra
.648 .734 .912 r
.74481 .53799 .74928 .54374 .75929 .54218 .75476 .53527 Metetra
.525 .638 .904 r
.75476 .53527 .75929 .54218 .76927 .53976 .76495 .5355 Metetra
.616 .788 .964 r
.76495 .5355 .76927 .53976 .77942 .53895 .77501 .53315 Metetra
.623 .725 .92 r
.77501 .53315 .77942 .53895 .78951 .53679 .78512 .53099 Metetra
.609 .719 .923 r
.78512 .53099 .78951 .53679 .79961 .53426 .7953 .52914 Metetra
.63 .757 .939 r
.7953 .52914 .79961 .53426 .80981 .5325 .80547 .52669 Metetra
.644 .735 .915 r
.80547 .52669 .80981 .5325 .81997 .52977 .81566 .524 Metetra
.67 .747 .909 r
.81566 .524 .81997 .52977 .83018 .52713 .82583 .52064 Metetra
.646 .712 .896 r
.82583 .52064 .83018 .52713 .84034 .52367 .83609 .51792 Metetra
.702 .762 .899 r
.83609 .51792 .84034 .52367 .85062 .52098 .84624 .51364 Metetra
.651 .689 .872 r
.84624 .51364 .85062 .52098 .86077 .51659 .85656 .51072 Metetra
.602 .718 .926 r
.85656 .51072 .86077 .51659 .86966 .49986 .86703 .50897 Metetra
.86703 .50897 .86966 .49986 .87997 .49683 .87586 .49121 Metetra
.656 .752 .92 r
.87586 .49121 .87997 .49683 .89031 .49379 .88623 .48815 Metetra
.656 .752 .92 r
.88623 .48815 .89031 .49379 .9007 .49074 .89664 .48508 Metetra
.656 .752 .92 r
.89664 .48508 .9007 .49074 .91111 .48768 .90708 .482 Metetra
.656 .752 .92 r
.90708 .482 .91111 .48768 .92157 .48461 .91757 .4789 Metetra
.656 .752 .92 r
.91757 .4789 .92157 .48461 .93206 .48152 .92809 .4758 Metetra
.656 .752 .92 r
.92809 .4758 .93206 .48152 .94259 .47843 .93864 .47268 Metetra
.656 .752 .92 r
.33443 .64473 .33979 .6494 .34834 .64688 .34301 .64219 Metetra
.656 .752 .92 r
.34301 .64219 .34834 .64688 .35693 .64434 .35161 .63965 Metetra
.656 .752 .92 r
.35161 .63965 .35693 .64434 .36554 .6418 .36024 .63709 Metetra
.656 .752 .92 r
.36024 .63709 .36554 .6418 .37418 .63925 .36889 .63452 Metetra
.656 .752 .92 r
.36889 .63452 .37418 .63925 .38285 .63669 .37758 .63195 Metetra
.656 .752 .92 r
.37758 .63195 .38285 .63669 .39154 .63413 .38629 .62937 Metetra
.617 .102 0 r
.38629 .62937 .39154 .63413 .39975 .6458 .3946 .63849 Metetra
.563 .629 .876 r
.3946 .63849 .39975 .6458 .40858 .64205 .40332 .63815 Metetra
.705 .8 .924 r
.40332 .63815 .40858 .64205 .4174 .6394 .41219 .63437 Metetra
.662 .745 .911 r
.41219 .63437 .4174 .6394 .4262 .6381 .42105 .6316 Metetra
.6 .671 .89 r
.42105 .6316 .4262 .6381 .43509 .63529 .42991 .63035 Metetra
.67 .752 .912 r
.42991 .63035 .43509 .63529 .44399 .63249 .43884 .62739 Metetra
.663 .744 .91 r
.43884 .62739 .44399 .63249 .45292 .63032 .44779 .62457 Metetra
.645 .715 .899 r
.44779 .62457 .45292 .63032 .46189 .62737 .45677 .6222 Metetra
.665 .744 .909 r
.45677 .6222 .46189 .62737 .47089 .62379 .46578 .61934 Metetra
.703 .782 .913 r
.46578 .61934 .47089 .62379 .47992 .6207 .47484 .61552 Metetra
.675 .747 .905 r
.47484 .61552 .47992 .6207 .48897 .61773 .48391 .61238 Metetra
.686 .744 .896 r
.48391 .61238 .48897 .61773 .49807 .61273 .49301 .60894 Metetra
.737 .819 .915 r
.49301 .60894 .49807 .61273 .50716 .61046 .50215 .60419 Metetra
.677 .711 .874 r
.50215 .60419 .50716 .61046 .5163 .60628 .5113 .6009 Metetra
.705 .75 .887 r
.5113 .6009 .5163 .60628 .52546 .59987 .52048 .59686 Metetra
.85 .851 .843 r
.52048 .59686 .52546 .59987 .53462 .59157 .52968 .58778 Metetra
.815 .825 .857 r
.52968 .58778 .53462 .59157 .5438 .58563 .53887 .58009 Metetra
.929 .739 .625 r
.53887 .58009 .5438 .58563 .5526 .53208 .54789 .54489 Metetra
.818 .49 .435 r
.54789 .54489 .5526 .53208 .56171 .52909 .55737 .574 Metetra
.155 0 .371 r
.55737 .574 .56171 .52909 .57153 .57648 .56627 .53888 Metetra
.137 .108 .559 r
.56627 .53888 .57153 .57648 .58086 .57516 .57601 .56949 Metetra
.584 .703 .924 r
.57601 .56949 .58086 .57516 .59031 .57765 .5854 .56831 Metetra
.582 .593 .829 r
.5854 .56831 .59031 .57765 .59974 .57707 .59485 .56767 Metetra
.472 .535 .841 r
.59485 .56767 .59974 .57707 .60921 .57576 .6044 .5698 Metetra
.711 .739 .873 r
.6044 .5698 .60921 .57576 .61869 .57348 .61384 .56539 Metetra
.631 .648 .848 r
.61384 .56539 .61869 .57348 .6282 .57134 .62337 .56323 Metetra
.602 .634 .855 r
.62337 .56323 .6282 .57134 .63771 .56794 .63296 .56193 Metetra
.773 .755 .837 r
.63296 .56193 .63771 .56794 .64725 .56448 .6424 .55498 Metetra
.718 .656 .787 r
.6424 .55498 .64725 .56448 .65672 .55846 .65188 .54896 Metetra
.665 .633 .808 r
.65188 .54896 .65672 .55846 .66615 .55123 .66148 .5454 Metetra
.941 .75 .617 r
.66148 .5454 .66615 .55123 .67584 .54949 .66978 .51133 Metetra
0 0 .476 r
.66978 .51133 .67584 .54949 .68386 .51211 .68167 .55799 Metetra
.64 .371 .495 r
.68167 .55799 .68386 .51211 .69603 .55983 .69236 .5735 Metetra
.69236 .5735 .69603 .55983 .70583 .55726 .70122 .55144 Metetra
.961 .738 .555 r
.70122 .55144 .70583 .55726 .71272 .50246 .70829 .49827 Metetra
.91 .508 .128 r
.70829 .49827 .71272 .50246 .72445 .53384 .72006 .53048 Metetra
.358 .711 .986 r
.72006 .53048 .72445 .53384 .73466 .5368 .73013 .531 Metetra
.499 .667 .938 r
.73013 .531 .73466 .5368 .74481 .53799 .74025 .53126 Metetra
.544 .654 .907 r
.74025 .53126 .74481 .53799 .75476 .53527 .75039 .53103 Metetra
.559 .766 .975 r
.75039 .53103 .75476 .53527 .76495 .5355 .76049 .52962 Metetra
.625 .723 .917 r
.76049 .52962 .76495 .5355 .77501 .53315 .77058 .52741 Metetra
.589 .714 .93 r
.77058 .52741 .77501 .53315 .78512 .53099 .78077 .52596 Metetra
.636 .764 .94 r
.78077 .52596 .78512 .53099 .7953 .52914 .79092 .52335 Metetra
.633 .732 .919 r
.79092 .52335 .7953 .52914 .80547 .52669 .80112 .52091 Metetra
.67 .748 .909 r
.80112 .52091 .80547 .52669 .81566 .524 .81127 .51753 Metetra
.639 .711 .899 r
.81127 .51753 .81566 .524 .82583 .52064 .82154 .51497 Metetra
.705 .766 .9 r
.82154 .51497 .82583 .52064 .83609 .51792 .83167 .5106 Metetra
.647 .688 .874 r
.83167 .5106 .83609 .51792 .84624 .51364 .84199 .5078 Metetra
.602 .72 .928 r
.84199 .5078 .84624 .51364 .85656 .51072 .85244 .50603 Metetra
.74 .82 .914 r
.85244 .50603 .85656 .51072 .86703 .50897 .86258 .50068 Metetra
.86 .741 .731 r
.86258 .50068 .86703 .50897 .87586 .49121 .87172 .48555 Metetra
.656 .752 .92 r
.87172 .48555 .87586 .49121 .88623 .48815 .88212 .48247 Metetra
.656 .752 .92 r
.88212 .48247 .88623 .48815 .89664 .48508 .89255 .47938 Metetra
.656 .752 .92 r
.89255 .47938 .89664 .48508 .90708 .482 .90303 .47628 Metetra
.656 .752 .92 r
.90303 .47628 .90708 .482 .91757 .4789 .91354 .47316 Metetra
.656 .752 .92 r
.91354 .47316 .91757 .4789 .92809 .4758 .92408 .47004 Metetra
.656 .752 .92 r
.92408 .47004 .92809 .4758 .93864 .47268 .93467 .4669 Metetra
.656 .752 .92 r
.32905 .64004 .33443 .64473 .34301 .64219 .33764 .63748 Metetra
.656 .752 .92 r
.33764 .63748 .34301 .64219 .35161 .63965 .34626 .63492 Metetra
.656 .752 .92 r
.34626 .63492 .35161 .63965 .36024 .63709 .3549 .63235 Metetra
.656 .752 .92 r
.3549 .63235 .36024 .63709 .36889 .63452 .36358 .62977 Metetra
.656 .752 .92 r
.36358 .62977 .36889 .63452 .37758 .63195 .37228 .62718 Metetra
0 .063 .546 r
.37228 .62718 .37758 .63195 .38629 .62937 .3806 .63447 Metetra
.198 0 0 r
.3806 .63447 .38629 .62937 .3946 .63849 .38939 .63183 Metetra
.602 .667 .885 r
.38939 .63183 .3946 .63849 .40332 .63815 .39815 .63054 Metetra
.565 .623 .869 r
.39815 .63054 .40332 .63815 .41219 .63437 .40692 .63017 Metetra
.706 .79 .916 r
.40692 .63017 .41219 .63437 .42105 .6316 .41584 .62633 Metetra
.662 .737 .906 r
.41584 .62633 .42105 .6316 .42991 .63035 .42475 .62354 Metetra
.607 .666 .881 r
.42475 .62354 .42991 .63035 .43884 .62739 .43365 .62213 Metetra
.669 .741 .904 r
.43365 .62213 .43884 .62739 .44779 .62457 .44263 .61915 Metetra
.667 .736 .901 r
.44263 .61915 .44779 .62457 .45677 .6222 .45163 .61622 Metetra
.641 .707 .895 r
.45163 .61622 .45677 .6222 .46578 .61934 .46065 .61391 Metetra
.678 .739 .897 r
.46065 .61391 .46578 .61934 .47484 .61552 .46972 .61066 Metetra
.699 .767 .904 r
.46972 .61066 .47484 .61552 .48391 .61238 .47882 .60688 Metetra
.685 .74 .893 r
.47882 .60688 .48391 .61238 .49301 .60894 .48794 .60343 Metetra
.683 .74 .894 r
.48794 .60343 .49301 .60894 .50215 .60419 .49709 .60004 Metetra
.768 .808 .885 r
.49709 .60004 .50215 .60419 .5113 .6009 .50628 .59421 Metetra
.658 .693 .871 r
.50628 .59421 .5113 .6009 .52048 .59686 .51547 .5914 Metetra
.781 .764 .838 r
.51547 .5914 .52048 .59686 .52968 .58778 .52469 .58435 Metetra
.836 .839 .848 r
.52469 .58435 .52968 .58778 .53887 .58009 .53392 .57579 Metetra
.941 .75 .617 r
.53392 .57579 .53887 .58009 .54789 .54489 .543 .53888 Metetra
.955 .612 .306 r
.543 .53888 .54789 .54489 .55737 .574 .55261 .58742 Metetra
.432 .093 .288 r
.55261 .58742 .55737 .574 .56627 .53888 .56198 .5843 Metetra
0 0 .237 r
.56198 .5843 .56627 .53888 .57601 .56949 .57068 .53079 Metetra
.128 .1 .554 r
.57068 .53079 .57601 .56949 .5854 .56831 .58054 .5627 Metetra
.716 .752 .88 r
.58054 .5627 .5854 .56831 .59485 .56767 .58993 .55821 Metetra
.544 .573 .834 r
.58993 .55821 .59485 .56767 .6044 .5698 .59944 .55861 Metetra
.567 .553 .798 r
.59944 .55861 .6044 .5698 .61384 .56539 .609 .55855 Metetra
.632 .684 .881 r
.609 .55855 .61384 .56539 .62337 .56323 .61855 .55637 Metetra
.737 .721 .837 r
.61855 .55637 .62337 .56323 .63296 .56193 .62802 .55067 Metetra
.69 .615 .768 r
.62802 .55067 .63296 .56193 .6424 .55498 .63752 .5454 Metetra
.628 .614 .817 r
.63752 .5454 .6424 .55498 .65188 .54896 .64716 .54323 Metetra
.944 .748 .607 r
.64716 .54323 .65188 .54896 .66148 .5454 .65547 .50625 Metetra
0 0 .44 r
.65547 .50625 .66148 .5454 .66978 .51133 .66732 .55715 Metetra
.635 .366 .494 r
.66732 .55715 .66978 .51133 .68167 .55799 .67787 .57165 Metetra
.403 .069 .281 r
.67787 .57165 .68167 .55799 .69236 .5735 .68766 .56728 Metetra
.907 .766 .694 r
.68766 .56728 .69236 .5735 .70122 .55144 .69665 .5469 Metetra
.968 .747 .552 r
.69665 .5469 .70122 .55144 .70829 .49827 .70385 .49444 Metetra
.904 .496 .119 r
.70385 .49444 .70829 .49827 .72006 .53048 .71549 .52463 Metetra
.556 .693 .931 r
.71549 .52463 .72006 .53048 .73013 .531 .72551 .52387 Metetra
.382 .556 .9 r
.72551 .52387 .73013 .531 .74025 .53126 .7358 .52667 Metetra
.581 .76 .964 r
.7358 .52667 .74025 .53126 .75039 .53103 .74587 .52503 Metetra
.59 .705 .922 r
.74587 .52503 .75039 .53103 .76049 .52962 .75599 .5236 Metetra
.598 .708 .921 r
.75599 .5236 .76049 .52962 .77058 .52741 .76615 .522 Metetra
.614 .74 .935 r
.76615 .522 .77058 .52741 .78077 .52596 .77632 .51994 Metetra
.639 .726 .911 r
.77632 .51994 .78077 .52596 .79092 .52335 .7865 .51737 Metetra
.663 .739 .906 r
.7865 .51737 .79092 .52335 .80112 .52091 .79665 .51416 Metetra
.641 .703 .891 r
.79665 .51416 .80112 .52091 .81127 .51753 .8069 .51156 Metetra
.697 .753 .895 r
.8069 .51156 .81127 .51753 .82154 .51497 .81705 .50737 Metetra
.647 .681 .867 r
.81705 .50737 .82154 .51497 .83167 .5106 .82735 .50454 Metetra
.601 .712 .922 r
.82735 .50454 .83167 .5106 .84199 .5078 .83779 .50282 Metetra
.739 .808 .906 r
.83779 .50282 .84199 .5078 .85244 .50603 .84793 .49746 Metetra
.687 .675 .833 r
.84793 .49746 .85244 .50603 .86258 .50068 .85818 .49307 Metetra
.652 .685 .868 r
.85818 .49307 .86258 .50068 .87172 .48555 .86861 .49006 Metetra
.86861 .49006 .87172 .48555 .88212 .48247 .87798 .47676 Metetra
.656 .752 .92 r
.87798 .47676 .88212 .48247 .89255 .47938 .88844 .47364 Metetra
.656 .752 .92 r
.88844 .47364 .89255 .47938 .90303 .47628 .89894 .47052 Metetra
.656 .752 .92 r
.89894 .47052 .90303 .47628 .91354 .47316 .90948 .46739 Metetra
.656 .752 .92 r
.90948 .46739 .91354 .47316 .92408 .47004 .92005 .46424 Metetra
.656 .752 .92 r
.92005 .46424 .92408 .47004 .93467 .4669 .93067 .46108 Metetra
.656 .752 .92 r
.32363 .63531 .32905 .64004 .33764 .63748 .33224 .63274 Metetra
.656 .752 .92 r
.33224 .63274 .33764 .63748 .34626 .63492 .34087 .63016 Metetra
.656 .752 .92 r
.34087 .63016 .34626 .63492 .3549 .63235 .34954 .62758 Metetra
.656 .752 .92 r
.34954 .62758 .3549 .63235 .36358 .62977 .35823 .62498 Metetra
.928 .714 .594 r
.35823 .62498 .36358 .62977 .37228 .62718 .36965 .56347 Metetra
.103 .036 .488 r
.36965 .56347 .37228 .62718 .3806 .63447 .37609 .61068 Metetra
.175 .174 .617 r
.37609 .61068 .3806 .63447 .38939 .63183 .38409 .62663 Metetra
.661 .739 .908 r
.38409 .62663 .38939 .63183 .39815 .63054 .39292 .6239 Metetra
.599 .668 .888 r
.39292 .6239 .39815 .63054 .40692 .63017 .40173 .62264 Metetra
.568 .628 .871 r
.40173 .62264 .40692 .63017 .41584 .62633 .41055 .62216 Metetra
.706 .793 .918 r
.41055 .62216 .41584 .62633 .42475 .62354 .41952 .61828 Metetra
.667 .741 .905 r
.41952 .61828 .42475 .62354 .43365 .62213 .42848 .61534 Metetra
.603 .667 .884 r
.42848 .61534 .43365 .62213 .44263 .61915 .43743 .61399 Metetra
.674 .748 .907 r
.43743 .61399 .44263 .61915 .45163 .61622 .44645 .61088 Metetra
.67 .741 .903 r
.44645 .61088 .45163 .61622 .46065 .61391 .4555 .60785 Metetra
.652 .71 .89 r
.4555 .60785 .46065 .61391 .46972 .61066 .46458 .60526 Metetra
.67 .74 .903 r
.46458 .60526 .46972 .61066 .47882 .60688 .47369 .60221 Metetra
.718 .78 .901 r
.47369 .60221 .47882 .60688 .48794 .60343 .48284 .5979 Metetra
.684 .74 .893 r
.48284 .5979 .48794 .60343 .49709 .60004 .49201 .59444 Metetra
.707 .744 .881 r
.49201 .59444 .49709 .60004 .50628 .59421 .50121 .5903 Metetra
.765 .82 .896 r
.50121 .5903 .50628 .59421 .51547 .5914 .51044 .58462 Metetra
.742 .718 .829 r
.51044 .58462 .51547 .5914 .52469 .58435 .51968 .57871 Metetra
.767 .758 .845 r
.51968 .57871 .52469 .58435 .53392 .57579 .52894 .57225 Metetra
.947 .757 .614 r
.52894 .57225 .53392 .57579 .543 .53888 .53809 .53478 Metetra
.948 .604 .325 r
.53809 .53478 .543 .53888 .55261 .58742 .54764 .58161 Metetra
.756 .293 0 r
.54764 .58161 .55261 .58742 .56198 .5843 .5572 .59727 Metetra
.5572 .59727 .56198 .5843 .57068 .53079 .56645 .57673 Metetra
0 0 .252 r
.56645 .57673 .57068 .53079 .58054 .5627 .57516 .52411 Metetra
.218 .164 .58 r
.57516 .52411 .58054 .5627 .58993 .55821 .58504 .55115 Metetra
.646 .683 .87 r
.58504 .55115 .58993 .55821 .59944 .55861 .5945 .54859 Metetra
.549 .565 .823 r
.5945 .54859 .59944 .55861 .609 .55855 .60407 .54891 Metetra
.629 .613 .816 r
.60407 .54891 .609 .55855 .61855 .55637 .61363 .54671 Metetra
.718 .654 .784 r
.61363 .54671 .61855 .55637 .62802 .55067 .6231 .54058 Metetra
.631 .606 .807 r
.6231 .54058 .62802 .55067 .63752 .5454 .63271 .53825 Metetra
.928 .735 .622 r
.63271 .53825 .63752 .5454 .64716 .54323 .64125 .50431 Metetra
0 0 .454 r
.64125 .50431 .64716 .54323 .65547 .50625 .65276 .55247 Metetra
.649 .377 .495 r
.65276 .55247 .65547 .50625 .66732 .55715 .66335 .57015 Metetra
.385 .045 .26 r
.66335 .57015 .66732 .55715 .67787 .57165 .67313 .56562 Metetra
.64 .723 .908 r
.67313 .56562 .67787 .57165 .68766 .56728 .68303 .56309 Metetra
.931 .807 .701 r
.68303 .56309 .68766 .56728 .69665 .5469 .69209 .54312 Metetra
.972 .75 .544 r
.69209 .54312 .69665 .5469 .70385 .49444 .69926 .48841 Metetra
.875 .465 .023 r
.69926 .48841 .70385 .49444 .71549 .52463 .71082 .51743 Metetra
.423 .577 .902 r
.71082 .51743 .71549 .52463 .72551 .52387 .72102 .51955 Metetra
.372 .673 .975 r
.72102 .51955 .72551 .52387 .7358 .52667 .73123 .52061 Metetra
.599 .706 .919 r
.73123 .52061 .7358 .52667 .74587 .52503 .74132 .519 Metetra
.547 .685 .93 r
.74132 .519 .74587 .52503 .75599 .5236 .75153 .51841 Metetra
.626 .754 .939 r
.75153 .51841 .75599 .5236 .76615 .522 .76166 .51603 Metetra
.619 .721 .919 r
.76166 .51603 .76615 .522 .77632 .51994 .77185 .51391 Metetra
.662 .737 .905 r
.77185 .51391 .77632 .51994 .7865 .51737 .782 .51072 Metetra
.632 .703 .897 r
.782 .51072 .7865 .51737 .79665 .51416 .79224 .50833 Metetra
.702 .76 .897 r
.79224 .50833 .79665 .51416 .8069 .51156 .80237 .50401 Metetra
.642 .68 .871 r
.80237 .50401 .8069 .51156 .81705 .50737 .81267 .50135 Metetra
.6 .714 .924 r
.81267 .50135 .81705 .50737 .82735 .50454 .8231 .49962 Metetra
.735 .809 .91 r
.8231 .49962 .82735 .50454 .83779 .50282 .83324 .49438 Metetra
.69 .68 .835 r
.83324 .49438 .83779 .50282 .84793 .49746 .84349 .4899 Metetra
.649 .686 .871 r
.84349 .4899 .84793 .49746 .85818 .49307 .85391 .48698 Metetra
.937 .789 .671 r
.85391 .48698 .85818 .49307 .86861 .49006 .86237 .4645 Metetra
.877 .634 .567 r
.86237 .4645 .86861 .49006 .87798 .47676 .86728 .40934 Metetra
.208 .141 .558 r
.86728 .40934 .87798 .47676 .88844 .47364 .8843 .46787 Metetra
.656 .752 .92 r
.8843 .46787 .88844 .47364 .89894 .47052 .89483 .46473 Metetra
.656 .752 .92 r
.89483 .46473 .89894 .47052 .90948 .46739 .90539 .46157 Metetra
.656 .752 .92 r
.90539 .46157 .90948 .46739 .92005 .46424 .916 .4584 Metetra
.656 .752 .92 r
.916 .4584 .92005 .46424 .93067 .46108 .92664 .45523 Metetra
.656 .752 .92 r
.31818 .63056 .32363 .63531 .33224 .63274 .3268 .62798 Metetra
.656 .752 .92 r
.3268 .62798 .33224 .63274 .34087 .63016 .33546 .62538 Metetra
.656 .752 .92 r
.33546 .62538 .34087 .63016 .34954 .62758 .34414 .62278 Metetra
.656 .752 .92 r
.34414 .62278 .34954 .62758 .35823 .62498 .35285 .62017 Metetra
.928 .714 .593 r
.35285 .62017 .35823 .62498 .36965 .56347 .36442 .55783 Metetra
.664 .719 .89 r
.36442 .55783 .36965 .56347 .37609 .61068 .37304 .55506 Metetra
0 0 .456 r
.37304 .55506 .37609 .61068 .38409 .62663 .37957 .60232 Metetra
.186 .179 .617 r
.37957 .60232 .38409 .62663 .39292 .6239 .38763 .61828 Metetra
.661 .725 .897 r
.38763 .61828 .39292 .6239 .40173 .62264 .39651 .61551 Metetra
.606 .657 .874 r
.39651 .61551 .40173 .62264 .41055 .62216 .40537 .61411 Metetra
.571 .617 .859 r
.40537 .61411 .41055 .62216 .41952 .61828 .41423 .61361 Metetra
.707 .775 .905 r
.41423 .61361 .41952 .61828 .42848 .61534 .42325 .60966 Metetra
.664 .726 .895 r
.42325 .60966 .42848 .61534 .43743 .61399 .43225 .60676 Metetra
.615 .659 .87 r
.43225 .60676 .43743 .61399 .44645 .61088 .44125 .60512 Metetra
.672 .727 .891 r
.44125 .60512 .44645 .61088 .4555 .60785 .45032 .60201 Metetra
.673 .725 .889 r
.45032 .60201 .4555 .60785 .46458 .60526 .45942 .59885 Metetra
.651 .7 .882 r
.45942 .59885 .46458 .60526 .47369 .60221 .46854 .59625 Metetra
.689 .727 .879 r
.46854 .59625 .47369 .60221 .48284 .5979 .47771 .59261 Metetra
.703 .755 .893 r
.47771 .59261 .48284 .5979 .49201 .59444 .4869 .58863 Metetra
.717 .741 .87 r
.4869 .58863 .49201 .59444 .50121 .5903 .49612 .58409 Metetra
.7 .724 .868 r
.49612 .58409 .50121 .5903 .51044 .58462 .50536 .58002 Metetra
.822 .796 .828 r
.50536 .58002 .51044 .58462 .51968 .57871 .51464 .57129 Metetra
.714 .695 .83 r
.51464 .57129 .51968 .57871 .52894 .57225 .52392 .56636 Metetra
.928 .737 .624 r
.52392 .56636 .52894 .57225 .53809 .53478 .53314 .5308 Metetra
.947 .601 .322 r
.53314 .5308 .53809 .53478 .54764 .58161 .54264 .57639 Metetra
.763 .289 0 r
.54264 .57639 .54764 .58161 .5572 .59727 .55219 .59137 Metetra
.617 .712 .913 r
.55219 .59137 .5572 .59727 .56645 .57673 .56169 .58945 Metetra
.56169 .58945 .56645 .57673 .57516 .52411 .57096 .56823 Metetra
0 0 .192 r
.57096 .56823 .57516 .52411 .58504 .55115 .57958 .5115 Metetra
.157 .119 .561 r
.57958 .5115 .58504 .55115 .5945 .54859 .58962 .54256 Metetra
.774 .755 .836 r
.58962 .54256 .5945 .54859 .60407 .54891 .59904 .53556 Metetra
.619 .552 .757 r
.59904 .53556 .60407 .54891 .61363 .54671 .6086 .53334 Metetra
.537 .505 .769 r
.6086 .53334 .61363 .54671 .6231 .54058 .61828 .5345 Metetra
.939 .744 .613 r
.61828 .5345 .6231 .54058 .63271 .53825 .62687 .49834 Metetra
0 0 .436 r
.62687 .49834 .63271 .53825 .64125 .50431 .63821 .54861 Metetra
.646 .373 .491 r
.63821 .54861 .64125 .50431 .65276 .55247 .64866 .56518 Metetra
.479 .126 .288 r
.64866 .56518 .65276 .55247 .66335 .57015 .65856 .56404 Metetra
.688 .738 .889 r
.65856 .56404 .66335 .57015 .67313 .56562 .66839 .5602 Metetra
.569 .719 .943 r
.66839 .5602 .67313 .56562 .68303 .56309 .67837 .55903 Metetra
.94 .804 .683 r
.67837 .55903 .68303 .56309 .69209 .54312 .68739 .53693 Metetra
.961 .734 .55 r
.68739 .53693 .69209 .54312 .69926 .48841 .69456 .48061 Metetra
.865 .471 0 r
.69456 .48061 .69926 .48841 .71082 .51743 .70625 .51245 Metetra
.453 .684 .964 r
.70625 .51245 .71082 .51743 .72102 .51955 .71638 .5129 Metetra
.447 .611 .919 r
.71638 .5129 .72102 .51955 .73123 .52061 .72662 .51432 Metetra
.576 .69 .919 r
.72662 .51432 .73123 .52061 .74132 .519 .73677 .51321 Metetra
.58 .711 .933 r
.73677 .51321 .74132 .519 .75153 .51841 .74695 .5119 Metetra
.625 .704 .902 r
.74695 .5119 .75153 .51841 .76166 .51603 .75711 .50969 Metetra
.652 .722 .9 r
.75711 .50969 .76166 .51603 .77185 .51391 .76727 .50679 Metetra
.636 .69 .884 r
.76727 .50679 .77185 .51391 .782 .51072 .77749 .50431 Metetra
.688 .735 .887 r
.77749 .50431 .782 .51072 .79224 .50833 .78764 .50035 Metetra
.644 .67 .86 r
.78764 .50035 .79224 .50833 .80237 .50401 .79792 .49759 Metetra
.599 .699 .914 r
.79792 .49759 .80237 .50401 .81267 .50135 .80833 .49595 Metetra
.734 .79 .898 r
.80833 .49595 .81267 .50135 .8231 .49962 .81847 .49068 Metetra
.683 .665 .826 r
.81847 .49068 .8231 .49962 .83324 .49438 .82872 .48634 Metetra
.648 .672 .859 r
.82872 .48634 .83324 .49438 .84349 .4899 .83913 .4834 Metetra
.931 .78 .672 r
.83913 .4834 .84349 .4899 .85391 .48698 .84766 .46094 Metetra
.875 .632 .568 r
.84766 .46094 .85391 .48698 .86237 .4645 .85278 .40578 Metetra
.582 .403 .604 r
.85278 .40578 .86237 .4645 .86728 .40934 .86306 .4027 Metetra
.911 .541 .099 r
.86306 .4027 .86728 .40934 .8843 .46787 .88013 .46206 Metetra
.656 .752 .92 r
.88013 .46206 .8843 .46787 .89483 .46473 .89069 .45889 Metetra
.656 .752 .92 r
.89069 .45889 .89483 .46473 .90539 .46157 .90128 .45572 Metetra
.656 .752 .92 r
.90128 .45572 .90539 .46157 .916 .4584 .91191 .45253 Metetra
.656 .752 .92 r
.91191 .45253 .916 .4584 .92664 .45523 .92258 .44933 Metetra
.656 .752 .92 r
.3127 .62578 .31818 .63056 .3268 .62798 .32134 .62318 Metetra
.656 .752 .92 r
.32134 .62318 .3268 .62798 .33546 .62538 .33001 .62057 Metetra
.656 .752 .92 r
.33001 .62057 .33546 .62538 .34414 .62278 .33871 .61795 Metetra
.906 .737 .662 r
.33871 .61795 .34414 .62278 .35285 .62017 .34876 .58961 Metetra
.629 .467 .645 r
.34876 .58961 .35285 .62017 .36442 .55783 .35761 .58374 Metetra
.35761 .58374 .36442 .55783 .37304 .55506 .36779 .5495 Metetra
.662 .723 .894 r
.36779 .5495 .37304 .55506 .37957 .60232 .37646 .54675 Metetra
0 0 .455 r
.37646 .54675 .37957 .60232 .38763 .61828 .38307 .59402 Metetra
.184 .178 .617 r
.38307 .59402 .38763 .61828 .39651 .61551 .39119 .60996 Metetra
.665 .731 .899 r
.39119 .60996 .39651 .61551 .40537 .61411 .40012 .60707 Metetra
.602 .659 .878 r
.40012 .60707 .40537 .61411 .41423 .61361 .40903 .60573 Metetra
.573 .623 .864 r
.40903 .60573 .41423 .61361 .42325 .60966 .41795 .60513 Metetra
.711 .783 .908 r
.41795 .60513 .42325 .60966 .43225 .60676 .427 .60106 Metetra
.671 .73 .894 r
.427 .60106 .43225 .60676 .44125 .60512 .43606 .59797 Metetra
.607 .66 .876 r
.43606 .59797 .44125 .60512 .45032 .60201 .44511 .5965 Metetra
.684 .741 .894 r
.44511 .5965 .45032 .60201 .45942 .59885 .45423 .59304 Metetra
.675 .729 .89 r
.45423 .59304 .45942 .59885 .46854 .59625 .46338 .58981 Metetra
.659 .704 .88 r
.46338 .58981 .46854 .59625 .47771 .59261 .47255 .58696 Metetra
.689 .74 .89 r
.47255 .58696 .47771 .59261 .4869 .58863 .48176 .58332 Metetra
.738 .764 .874 r
.48176 .58332 .4869 .58863 .49612 .58409 .49101 .57818 Metetra
.712 .738 .872 r
.49101 .57818 .49612 .58409 .50536 .58002 .50027 .57376 Metetra
.765 .74 .83 r
.50027 .57376 .50536 .58002 .51464 .57129 .50957 .56702 Metetra
.812 .811 .849 r
.50957 .56702 .51464 .57129 .52392 .56636 .51887 .55916 Metetra
.917 .725 .628 r
.51887 .55916 .52392 .56636 .53314 .5308 .52816 .52424 Metetra
.956 .613 .3 r
.52816 .52424 .53314 .5308 .54264 .57639 .53761 .573 Metetra
.785 .291 0 r
.53761 .573 .54264 .57639 .55219 .59137 .54715 .58647 Metetra
.713 .781 .905 r
.54715 .58647 .55219 .59137 .56169 .58945 .55665 .58212 Metetra
.609 .663 .877 r
.55665 .58212 .56169 .58945 .57096 .56823 .56621 .58049 Metetra
.56621 .58049 .57096 .56823 .57958 .5115 .57548 .55723 Metetra
0 0 .212 r
.57548 .55723 .57958 .5115 .58962 .54256 .58406 .50015 Metetra
.27 .194 .584 r
.58406 .50015 .58962 .54256 .59904 .53556 .5941 .52639 Metetra
.63 .625 .826 r
.5941 .52639 .59904 .53556 .6086 .53334 .60366 .52414 Metetra
.906 .713 .632 r
.60366 .52414 .6086 .53334 .61828 .5345 .61246 .49193 Metetra
0 0 .432 r
.61246 .49193 .61828 .5345 .62687 .49834 .62361 .54424 Metetra
.644 .372 .492 r
.62361 .54424 .62687 .49834 .63821 .54861 .63396 .56086 Metetra
.412 .058 .251 r
.63396 .56086 .63821 .54861 .64866 .56518 .64377 .55768 Metetra
.473 .597 .896 r
.64377 .55768 .64866 .56518 .65856 .56404 .65377 .55895 Metetra
.623 .755 .941 r
.65377 .55895 .65856 .56404 .66839 .5602 .66369 .55665 Metetra
.709 .851 .95 r
.66369 .55665 .66839 .5602 .67837 .55903 .67356 .55222 Metetra
.91 .755 .677 r
.67356 .55222 .67837 .55903 .68739 .53693 .68259 .5294 Metetra
.952 .727 .561 r
.68259 .5294 .68739 .53693 .69456 .48061 .69 .47593 Metetra
.897 .487 .088 r
.69 .47593 .69456 .48061 .70625 .51245 .70156 .50578 Metetra
.484 .631 .918 r
.70156 .50578 .70625 .51245 .71638 .5129 .71172 .50654 Metetra
.396 .597 .926 r
.71172 .50654 .71638 .5129 .72662 .51432 .72202 .50855 Metetra
.588 .716 .932 r
.72202 .50855 .72662 .51432 .73677 .51321 .73216 .50705 Metetra
.591 .703 .921 r
.73216 .50705 .73677 .51321 .74695 .5119 .74235 .50556 Metetra
.652 .723 .901 r
.74235 .50556 .74695 .5119 .75711 .50969 .75249 .50263 Metetra
.616 .684 .891 r
.75249 .50263 .75711 .50969 .76727 .50679 .76273 .50066 Metetra
.697 .749 .892 r
.76273 .50066 .76727 .50679 .77749 .50431 .77285 .49645 Metetra
.635 .67 .866 r
.77285 .49645 .77749 .50431 .78764 .50035 .78314 .49395 Metetra
.595 .699 .915 r
.78314 .49395 .78764 .50035 .79792 .49759 .79353 .49237 Metetra
.731 .796 .904 r
.79353 .49237 .79792 .49759 .80833 .49595 .80368 .48721 Metetra
.687 .672 .83 r
.80368 .48721 .80833 .49595 .81847 .49068 .81391 .48276 Metetra
.645 .675 .864 r
.81391 .48276 .81847 .49068 .82872 .48634 .82432 .47994 Metetra
.931 .782 .673 r
.82432 .47994 .82872 .48634 .83913 .4834 .83292 .45748 Metetra
.875 .632 .569 r
.83292 .45748 .83913 .4834 .84766 .46094 .83827 .40239 Metetra
.582 .402 .604 r
.83827 .40239 .84766 .46094 .85278 .40578 .84853 .39925 Metetra
.785 .373 0 r
.84853 .39925 .85278 .40578 .86306 .4027 .86224 .429 Metetra
.54 .249 .422 r
.86224 .429 .86306 .4027 .88013 .46206 .87305 .42918 Metetra
.276 .232 .627 r
.87305 .42918 .88013 .46206 .89069 .45889 .88652 .45302 Metetra
.656 .752 .92 r
.88652 .45302 .89069 .45889 .90128 .45572 .89714 .44982 Metetra
.656 .752 .92 r
.89714 .44982 .90128 .45572 .91191 .45253 .9078 .44661 Metetra
.656 .752 .92 r
.9078 .44661 .91191 .45253 .92258 .44933 .9185 .44339 Metetra
.656 .752 .92 r
.30718 .62097 .3127 .62578 .32134 .62318 .31584 .61835 Metetra
.656 .752 .92 r
.31584 .61835 .32134 .62318 .33001 .62057 .32452 .61573 Metetra
.656 .752 .92 r
.32452 .61573 .33001 .62057 .33871 .61795 .33324 .61309 Metetra
.902 .74 .671 r
.33324 .61309 .33871 .61795 .34876 .58961 .34323 .58713 Metetra
.806 .862 .891 r
.34323 .58713 .34876 .58961 .35761 .58374 .35215 .58047 Metetra
.779 .832 .893 r
.35215 .58047 .35761 .58374 .36779 .5495 .36103 .57457 Metetra
.36103 .57457 .36779 .5495 .37646 .54675 .37124 .54024 Metetra
.663 .694 .868 r
.37124 .54024 .37646 .54675 .38307 .59402 .37994 .53738 Metetra
.006 0 .46 r
.37994 .53738 .38307 .59402 .39119 .60996 .38665 .58469 Metetra
.205 .188 .617 r
.38665 .58469 .39119 .60996 .40012 .60707 .39483 .60061 Metetra
.661 .7 .876 r
.39483 .60061 .40012 .60707 .40903 .60573 .4038 .59774 Metetra
.612 .639 .853 r
.4038 .59774 .40903 .60573 .41795 .60513 .41276 .59616 Metetra
.577 .599 .838 r
.41276 .59616 .41795 .60513 .427 .60106 .42172 .59555 Metetra
.706 .746 .883 r
.42172 .59555 .427 .60106 .43606 .59797 .43082 .59145 Metetra
.67 .703 .872 r
.43082 .59145 .43606 .59797 .44511 .5965 .43992 .5883 Metetra
.622 .639 .846 r
.43992 .5883 .44511 .5965 .45423 .59304 .44902 .58643 Metetra
.67 .702 .871 r
.44902 .58643 .45423 .59304 .46338 .58981 .45819 .58323 Metetra
.69 .71 .863 r
.45819 .58323 .46338 .58981 .47255 .58696 .46739 .57942 Metetra
.658 .672 .852 r
.46739 .57942 .47255 .58696 .48176 .58332 .4766 .57648 Metetra
.714 .711 .846 r
.4766 .57648 .48176 .58332 .49101 .57818 .48587 .57174 Metetra
.714 .723 .857 r
.48587 .57174 .49101 .57818 .50027 .57376 .49515 .5671 Metetra
.769 .731 .818 r
.49515 .5671 .50027 .57376 .50957 .56702 .50447 .5599 Metetra
.755 .716 .816 r
.50447 .5599 .50957 .56702 .51887 .55916 .5138 .55316 Metetra
.929 .736 .621 r
.5138 .55316 .51887 .55916 .52816 .52424 .52315 .51642 Metetra
.957 .616 .285 r
.52315 .51642 .52816 .52424 .53761 .573 .53254 .56567 Metetra
.643 .205 0 r
.53254 .56567 .53761 .573 .54715 .58647 .54208 .58061 Metetra
.727 .751 .872 r
.54208 .58061 .54715 .58647 .55665 .58212 .5516 .57563 Metetra
.617 .695 .899 r
.5516 .57563 .55665 .58212 .56621 .58049 .56117 .57372 Metetra
.784 .738 .811 r
.56117 .57372 .56621 .58049 .57548 .55723 .57069 .56561 Metetra
.879 .889 .463 r
.57069 .56561 .57548 .55723 .58406 .50015 .57996 .54165 Metetra
0 0 .177 r
.57996 .54165 .58406 .50015 .5941 .52639 .58855 .48707 Metetra
.586 .422 .627 r
.58855 .48707 .5941 .52639 .60366 .52414 .59803 .48477 Metetra
0 0 .427 r
.59803 .48477 .60366 .52414 .61246 .49193 .60883 .53351 Metetra
.663 .384 .488 r
.60883 .53351 .61246 .49193 .62361 .54424 .61913 .55261 Metetra
.517 .105 .199 r
.61913 .55261 .62361 .54424 .63396 .56086 .62905 .55395 Metetra
.654 .7 .88 r
.62905 .55395 .63396 .56086 .64377 .55768 .63888 .55101 Metetra
.41 .595 .92 r
.63888 .55101 .64377 .55768 .65377 .55895 .64892 .55289 Metetra
.686 .741 .893 r
.64892 .55289 .65377 .55895 .66369 .55665 .65881 .54907 Metetra
.71 .704 .842 r
.65881 .54907 .66369 .55665 .67356 .55222 .66867 .5441 Metetra
.888 .735 .687 r
.66867 .5441 .67356 .55222 .68259 .5294 .67782 .5231 Metetra
.96 .735 .554 r
.67782 .5231 .68259 .5294 .69 .47593 .68526 .46841 Metetra
.86 .46 0 r
.68526 .46841 .69 .47593 .70156 .50578 .69682 .4987 Metetra
.481 .616 .908 r
.69682 .4987 .70156 .50578 .71172 .50654 .70701 .49965 Metetra
.441 .603 .914 r
.70701 .49965 .71172 .50654 .72202 .50855 .71729 .50121 Metetra
.603 .668 .886 r
.71729 .50121 .72202 .50855 .73216 .50705 .72745 .49962 Metetra
.613 .671 .882 r
.72745 .49962 .73216 .50705 .74235 .50556 .73763 .49774 Metetra
.63 .668 .868 r
.73763 .49774 .74235 .50556 .75249 .50263 .74783 .4954 Metetra
.674 .704 .87 r
.74783 .4954 .75249 .50263 .76273 .50066 .75798 .49176 Metetra
.634 .643 .842 r
.75798 .49176 .76273 .50066 .77285 .49645 .76824 .48923 Metetra
.596 .672 .893 r
.76824 .48923 .77285 .49645 .78314 .49395 .77862 .48774 Metetra
.726 .758 .879 r
.77862 .48774 .78314 .49395 .79353 .49237 .78876 .48254 Metetra
.674 .643 .812 r
.78876 .48254 .79353 .49237 .80368 .48721 .799 .47836 Metetra
.644 .651 .842 r
.799 .47836 .80368 .48721 .81391 .48276 .80938 .47546 Metetra
.919 .765 .674 r
.80938 .47546 .81391 .48276 .82432 .47994 .81806 .45304 Metetra
.87 .628 .57 r
.81806 .45304 .82432 .47994 .83292 .45748 .82362 .39796 Metetra
.58 .4 .602 r
.82362 .39796 .83292 .45748 .83827 .40239 .83388 .39492 Metetra
.762 .36 0 r
.83388 .39492 .83827 .40239 .84853 .39925 .84743 .42465 Metetra
.537 .244 .416 r
.84743 .42465 .84853 .39925 .86224 .429 .8582 .42483 Metetra
.366 .682 .978 r
.8582 .42483 .86224 .429 .87305 .42918 .86912 .4258 Metetra
.771 .301 0 r
.86912 .4258 .87305 .42918 .88652 .45302 .88233 .44711 Metetra
.656 .752 .92 r
.88233 .44711 .88652 .45302 .89714 .44982 .89298 .44389 Metetra
.656 .752 .92 r
.89298 .44389 .89714 .44982 .9078 .44661 .90366 .44066 Metetra
.656 .752 .92 r
.90366 .44066 .9078 .44661 .9185 .44339 .91439 .43741 Metetra
.656 .752 .92 r
.30163 .61613 .30718 .62097 .31584 .61835 .3103 .6135 Metetra
.656 .752 .92 r
.3103 .6135 .31584 .61835 .32452 .61573 .31901 .61086 Metetra
.901 .74 .672 r
.31901 .61086 .32452 .61573 .33324 .61309 .32908 .5849 Metetra
.613 .461 .652 r
.32908 .5849 .33324 .61309 .34323 .58713 .33785 .581 Metetra
.658 .706 .882 r
.33785 .581 .34323 .58713 .35215 .58047 .34658 .57829 Metetra
.809 .876 .895 r
.34658 .57829 .35215 .58047 .36103 .57457 .35555 .57154 Metetra
.783 .844 .898 r
.35555 .57154 .36103 .57457 .37124 .54024 .36448 .56558 Metetra
.36448 .56558 .37124 .54024 .37994 .53738 .3747 .5311 Metetra
.662 .702 .876 r
.3747 .5311 .37994 .53738 .38665 .58469 .38345 .52827 Metetra
.002 0 .458 r
.38345 .52827 .38665 .58469 .39483 .60061 .39024 .57559 Metetra
.202 .187 .618 r
.39024 .57559 .39483 .60061 .4038 .59774 .39848 .59142 Metetra
.666 .708 .879 r
.39848 .59142 .4038 .59774 .41276 .59616 .4075 .5884 Metetra
.605 .643 .862 r
.4075 .5884 .41276 .59616 .42172 .59555 .4165 .58696 Metetra
.585 .613 .847 r
.4165 .58696 .42172 .59555 .43082 .59145 .42552 .5861 Metetra
.71 .755 .887 r
.42552 .5861 .43082 .59145 .43992 .5883 .43467 .58189 Metetra
.671 .709 .876 r
.43467 .58189 .43992 .5883 .44902 .58643 .44382 .57868 Metetra
.623 .653 .858 r
.44382 .57868 .44902 .58643 .45819 .58323 .45296 .57674 Metetra
.692 .714 .866 r
.45296 .57674 .45819 .58323 .46739 .57942 .46218 .57288 Metetra
.69 .713 .866 r
.46218 .57288 .46739 .57942 .4766 .57648 .47143 .56904 Metetra
.68 .684 .847 r
.47143 .56904 .4766 .57648 .48587 .57174 .48069 .56538 Metetra
.707 .724 .864 r
.48069 .56538 .48587 .57174 .49515 .5671 .49 .56102 Metetra
.795 .752 .814 r
.49 .56102 .49515 .5671 .50447 .5599 .49935 .55273 Metetra
.742 .713 .824 r
.49935 .55273 .50447 .5599 .5138 .55316 .5087 .54664 Metetra
.924 .732 .625 r
.5087 .54664 .5138 .55316 .52315 .51642 .51811 .5108 Metetra
.952 .605 .301 r
.51811 .5108 .52315 .51642 .53254 .56567 .52744 .55659 Metetra
0 0 .378 r
.52744 .55659 .53254 .56567 .54208 .58061 .53697 .57294 Metetra
.598 .651 .873 r
.53697 .57294 .54208 .58061 .5516 .57563 .54653 .57158 Metetra
.795 .829 .878 r
.54653 .57158 .5516 .57563 .56117 .57372 .55607 .56458 Metetra
.767 .684 .771 r
.55607 .56458 .56117 .57372 .57069 .56561 .56561 .55578 Metetra
.602 .6 .823 r
.56561 .55578 .57069 .56561 .57996 .54165 .57525 .55439 Metetra
.988 .822 .437 r
.57525 .55439 .57996 .54165 .58855 .48707 .58398 .49924 Metetra
.435 .077 .257 r
.58398 .49924 .58855 .48707 .59803 .48477 .59354 .49694 Metetra
.876 .548 .425 r
.59354 .49694 .59803 .48477 .60883 .53351 .60435 .54624 Metetra
.4 .049 .25 r
.60435 .54624 .60883 .53351 .61913 .55261 .61409 .54265 Metetra
.476 .534 .837 r
.61409 .54265 .61913 .55261 .62905 .55395 .62404 .54465 Metetra
.459 .541 .853 r
.62404 .54465 .62905 .55395 .63888 .55101 .63405 .54681 Metetra
.579 .78 .975 r
.63405 .54681 .63888 .55101 .64892 .55289 .64398 .54499 Metetra
.716 .698 .832 r
.64398 .54499 .64892 .55289 .65881 .54907 .65382 .53969 Metetra
.6 .614 .837 r
.65382 .53969 .65881 .54907 .66867 .5441 .66385 .5383 Metetra
.92 .775 .684 r
.66385 .5383 .66867 .5441 .67782 .5231 .673 .51626 Metetra
.958 .731 .554 r
.673 .51626 .67782 .5231 .68526 .46841 .6805 .46085 Metetra
.868 .472 .005 r
.6805 .46085 .68526 .46841 .69682 .4987 .69209 .49221 Metetra
.484 .64 .925 r
.69209 .49221 .69682 .4987 .70701 .49965 .70228 .49284 Metetra
.465 .62 .917 r
.70228 .49284 .70701 .49965 .71729 .50121 .71255 .49392 Metetra
.619 .679 .884 r
.71255 .49392 .71729 .50121 .72745 .49962 .7227 .49187 Metetra
.588 .651 .88 r
.7227 .49187 .72745 .49962 .73763 .49774 .73294 .49067 Metetra
.675 .71 .875 r
.73294 .49067 .73763 .49774 .74783 .4954 .74307 .48699 Metetra
.628 .653 .856 r
.74307 .48699 .74783 .4954 .75798 .49176 .75333 .48469 Metetra
.593 .677 .898 r
.75333 .48469 .75798 .49176 .76824 .48923 .76369 .48323 Metetra
.717 .763 .889 r
.76369 .48323 .76824 .48923 .77862 .48774 .77384 .47835 Metetra
.681 .656 .819 r
.77384 .47835 .77862 .48774 .78876 .48254 .78406 .47396 Metetra
.64 .656 .85 r
.78406 .47396 .78876 .48254 .799 .47836 .79444 .47122 Metetra
.92 .767 .675 r
.79444 .47122 .799 .47836 .80938 .47546 .8032 .44889 Metetra
.871 .629 .571 r
.8032 .44889 .80938 .47546 .81806 .45304 .80898 .39387 Metetra
.58 .4 .602 r
.80898 .39387 .81806 .45304 .82362 .39796 .81921 .39075 Metetra
.78 .375 0 r
.81921 .39075 .82362 .39796 .83388 .39492 .83261 .42056 Metetra
.537 .243 .415 r
.83261 .42056 .83388 .39492 .84743 .42465 .84336 .42075 Metetra
.34 .681 .979 r
.84336 .42075 .84743 .42465 .8582 .42483 .85425 .42178 Metetra
.614 .864 .99 r
.85425 .42178 .8582 .42483 .86912 .4258 .86476 .41859 Metetra
.611 .684 .894 r
.86476 .41859 .86912 .4258 .88233 .44711 .87545 .41664 Metetra
.285 .245 .637 r
.87545 .41664 .88233 .44711 .89298 .44389 .88878 .43791 Metetra
.656 .752 .92 r
.88878 .43791 .89298 .44389 .90366 .44066 .8995 .43466 Metetra
.656 .752 .92 r
.8995 .43466 .90366 .44066 .91439 .43741 .91025 .4314 Metetra
.656 .752 .92 r
.29605 .61126 .30163 .61613 .3103 .6135 .30474 .60861 Metetra
.656 .752 .92 r
.30474 .60861 .3103 .6135 .31901 .61086 .31346 .60596 Metetra
.905 .736 .662 r
.31346 .60596 .31901 .61086 .32908 .5849 .32374 .57745 Metetra
.697 .68 .83 r
.32374 .57745 .32908 .5849 .33785 .581 .33254 .57325 Metetra
.689 .671 .827 r
.33254 .57325 .33785 .581 .34658 .57829 .34135 .5693 Metetra
.651 .629 .815 r
.34135 .5693 .34658 .57829 .35555 .57154 .35012 .56648 Metetra
.78 .767 .841 r
.35012 .56648 .35555 .57154 .36448 .56558 .35911 .55969 Metetra
.754 .739 .839 r
.35911 .55969 .36448 .56558 .3747 .5311 .36808 .5537 Metetra
.36808 .5537 .3747 .5311 .38345 .52827 .37831 .51923 Metetra
.656 .629 .811 r
.37831 .51923 .38345 .52827 .39024 .57559 .3871 .5162 Metetra
.043 0 .471 r
.3871 .5162 .39024 .57559 .39848 .59142 .39397 .56347 Metetra
.254 .211 .616 r
.39397 .56347 .39848 .59142 .4075 .5884 .40227 .57931 Metetra
.656 .634 .816 r
.40227 .57931 .4075 .5884 .4165 .58696 .41133 .57622 Metetra
.613 .583 .796 r
.41133 .57622 .4165 .58696 .42552 .5861 .42038 .57447 Metetra
.581 .552 .788 r
.42038 .57447 .42552 .5861 .43467 .58189 .42943 .57383 Metetra
.701 .675 .822 r
.42943 .57383 .43467 .58189 .44382 .57868 .43863 .56922 Metetra
.661 .63 .808 r
.43863 .56922 .44382 .57868 .45296 .57674 .44781 .56586 Metetra
.634 .592 .79 r
.44781 .56586 .45296 .57674 .46218 .57288 .45701 .56331 Metetra
.663 .63 .806 r
.45701 .56331 .46218 .57288 .47143 .56904 .46626 .5598 Metetra
.693 .649 .802 r
.46626 .5598 .47143 .56904 .48069 .56538 .47555 .55513 Metetra
.674 .623 .79 r
.47555 .55513 .48069 .56538 .49 .56102 .48486 .55098 Metetra
.728 .65 .771 r
.48486 .55098 .49 .56102 .49935 .55273 .49422 .54409 Metetra
.75 .683 .787 r
.49422 .54409 .49935 .55273 .5087 .54664 .50359 .53673 Metetra
.901 .702 .624 r
.50359 .53673 .5087 .54664 .51811 .5108 .51307 .49993 Metetra
.953 .612 .227 r
.51307 .49993 .51811 .5108 .52744 .55659 .52233 .5475 Metetra
0 0 .45 r
.52233 .5475 .52744 .55659 .53697 .57294 .53183 .56242 Metetra
.677 .623 .788 r
.53183 .56242 .53697 .57294 .54653 .57158 .54138 .55802 Metetra
.649 .569 .751 r
.54138 .55802 .54653 .57158 .55607 .56458 .55095 .55422 Metetra
.717 .645 .776 r
.55095 .55422 .55607 .56458 .56561 .55578 .56053 .54779 Metetra
.92 .724 .621 r
.56053 .54779 .56561 .55578 .57525 .55439 .56972 .51173 Metetra
0 0 .431 r
.56972 .51173 .57525 .55439 .58398 .49924 .58016 .56147 Metetra
.536 .291 .49 r
.58016 .56147 .58398 .49924 .59354 .49694 .58993 .55924 Metetra
.065 0 .359 r
.58993 .55924 .59354 .49694 .60435 .54624 .59856 .50342 Metetra
.193 .14 .565 r
.59856 .50342 .60435 .54624 .61409 .54265 .60909 .53456 Metetra
.559 .625 .874 r
.60909 .53456 .61409 .54265 .62404 .54465 .61897 .53413 Metetra
.592 .586 .814 r
.61897 .53413 .62404 .54465 .63405 .54681 .62888 .53301 Metetra
.532 .503 .769 r
.62888 .53301 .63405 .54681 .64398 .54499 .63891 .53421 Metetra
.663 .617 .793 r
.63891 .53421 .64398 .54499 .65382 .53969 .64882 .5303 Metetra
.657 .641 .823 r
.64882 .5303 .65382 .53969 .66385 .5383 .65878 .52694 Metetra
.853 .689 .678 r
.65878 .52694 .66385 .5383 .673 .51626 .66801 .50594 Metetra
.939 .71 .567 r
.66801 .50594 .673 .51626 .6805 .46085 .67565 .45181 Metetra
.82 .432 0 r
.67565 .45181 .6805 .46085 .69209 .49221 .68713 .4817 Metetra
.521 .549 .825 r
.68713 .4817 .69209 .49221 .70228 .49284 .69735 .48272 Metetra
.528 .561 .833 r
.69735 .48272 .70228 .49284 .71255 .49392 .70761 .48346 Metetra
.609 .598 .814 r
.70761 .48346 .71255 .49392 .7227 .49187 .71778 .4817 Metetra
.633 .615 .815 r
.71778 .4817 .7227 .49187 .73294 .49067 .72795 .4791 Metetra
.62 .585 .793 r
.72795 .4791 .73294 .49067 .74307 .48699 .73818 .47684 Metetra
.583 .592 .827 r
.73818 .47684 .74307 .48699 .75333 .48469 .74855 .47593 Metetra
.705 .68 .823 r
.74855 .47593 .75333 .48469 .76369 .48323 .75866 .47074 Metetra
.655 .591 .771 r
.75866 .47074 .76369 .48323 .77384 .47835 .76888 .46672 Metetra
.631 .591 .791 r
.76888 .46672 .77384 .47835 .78406 .47396 .77924 .464 Metetra
.885 .72 .672 r
.77924 .464 .78406 .47396 .79444 .47122 .78806 .4417 Metetra
.857 .616 .573 r
.78806 .4417 .79444 .47122 .8032 .44889 .79405 .38677 Metetra
.577 .396 .599 r
.79405 .38677 .8032 .44889 .80898 .39387 .80428 .38385 Metetra
.677 .311 0 r
.80428 .38385 .80898 .39387 .81921 .39075 .81749 .41353 Metetra
.532 .228 .397 r
.81749 .41353 .81921 .39075 .83261 .42056 .8282 .41372 Metetra
.469 .624 .919 r
.8282 .41372 .83261 .42056 .84336 .42075 .83905 .41473 Metetra
.653 .745 .917 r
.83905 .41473 .84336 .42075 .85425 .42178 .84955 .41162 Metetra
.613 .61 .824 r
.84955 .41162 .85425 .42178 .86476 .41859 .86021 .40967 Metetra
.604 .634 .853 r
.86021 .40967 .86476 .41859 .87545 .41664 .87094 .40799 Metetra
0 0 .393 r
.87094 .40799 .87545 .41664 .88878 .43791 .88456 .4319 Metetra
.656 .752 .92 r
.88456 .4319 .88878 .43791 .8995 .43466 .8953 .42862 Metetra
.656 .752 .92 r
.8953 .42862 .8995 .43466 .91025 .4314 .90609 .42534 Metetra
.656 .752 .92 r
.29043 .60637 .29605 .61126 .30474 .60861 .29914 .6037 Metetra
.908 .733 .654 r
.29914 .6037 .30474 .60861 .31346 .60596 .30968 .57259 Metetra
.599 .439 .637 r
.30968 .57259 .31346 .60596 .32374 .57745 .31841 .56929 Metetra
.654 .648 .832 r
.31841 .56929 .32374 .57745 .33254 .57325 .32714 .56649 Metetra
.704 .702 .845 r
.32714 .56649 .33254 .57325 .34135 .5693 .33598 .56222 Metetra
.695 .691 .842 r
.33598 .56222 .34135 .5693 .35012 .56648 .34483 .55818 Metetra
.652 .646 .831 r
.34483 .55818 .35012 .56648 .35911 .55969 .35364 .55539 Metetra
.79 .795 .856 r
.35364 .55539 .35911 .55969 .36808 .5537 .36267 .54855 Metetra
.765 .765 .853 r
.36267 .54855 .36808 .5537 .37831 .51923 .37168 .54242 Metetra
.37168 .54242 .37831 .51923 .3871 .5162 .38192 .50782 Metetra
.655 .645 .828 r
.38192 .50782 .3871 .5162 .39397 .56347 .39074 .50491 Metetra
.034 0 .468 r
.39074 .50491 .39397 .56347 .40227 .57931 .39771 .552 Metetra
.245 .208 .617 r
.39771 .552 .40227 .57931 .41133 .57622 .40607 .56771 Metetra
.658 .648 .829 r
.40607 .56771 .41133 .57622 .42038 .57447 .41517 .56464 Metetra
.617 .603 .814 r
.41517 .56464 .42038 .57447 .42943 .57383 .42426 .56279 Metetra
.594 .57 .796 r
.42426 .56279 .42943 .57383 .43863 .56922 .43336 .56167 Metetra
.707 .691 .832 r
.43336 .56167 .43863 .56922 .44781 .56586 .4426 .55697 Metetra
.669 .646 .818 r
.4426 .55697 .44781 .56586 .45701 .56331 .45183 .55338 Metetra
.63 .608 .81 r
.45183 .55338 .45701 .56331 .46626 .5598 .46106 .55107 Metetra
.708 .666 .806 r
.46106 .55107 .46626 .5598 .47555 .55513 .47038 .54586 Metetra
.678 .643 .808 r
.47038 .54586 .47555 .55513 .48486 .55098 .47969 .54181 Metetra
.736 .668 .784 r
.47969 .54181 .48486 .55098 .49422 .54409 .48907 .53495 Metetra
.749 .674 .778 r
.48907 .53495 .49422 .54409 .50359 .53673 .49845 .52732 Metetra
.905 .706 .623 r
.49845 .52732 .50359 .53673 .51307 .49993 .508 .49019 Metetra
.957 .616 .255 r
.508 .49019 .51307 .49993 .52233 .5475 .51718 .5388 Metetra
0 0 .567 r
.51718 .5388 .52233 .5475 .53183 .56242 .52668 .55115 Metetra
.706 .626 .765 r
.52668 .55115 .53183 .56242 .54138 .55802 .53622 .54492 Metetra
.545 .517 .775 r
.53622 .54492 .54138 .55802 .55095 .55422 .54583 .54554 Metetra
.916 .717 .619 r
.54583 .54554 .55095 .55422 .56053 .54779 .55514 .50832 Metetra
0 0 .4 r
.55514 .50832 .56053 .54779 .56972 .51173 .56532 .55724 Metetra
.636 .363 .487 r
.56532 .55724 .56972 .51173 .58016 .56147 .57534 .57246 Metetra
.416 .039 .212 r
.57534 .57246 .58016 .56147 .58993 .55924 .58518 .57022 Metetra
.58518 .57022 .58993 .55924 .59856 .50342 .59467 .54903 Metetra
0 0 .236 r
.59467 .54903 .59856 .50342 .60909 .53456 .60331 .49483 Metetra
.164 .125 .565 r
.60331 .49483 .60909 .53456 .61897 .53413 .61393 .5253 Metetra
.715 .676 .811 r
.61393 .5253 .61897 .53413 .62888 .53301 .62372 .51967 Metetra
.474 .475 .779 r
.62372 .51967 .62888 .53301 .63891 .53421 .63381 .52267 Metetra
.598 .573 .797 r
.63381 .52267 .63891 .53421 .64882 .5303 .64381 .5213 Metetra
.688 .664 .821 r
.64381 .5213 .64882 .5303 .65878 .52694 .65374 .51678 Metetra
.864 .706 .683 r
.65374 .51678 .65878 .52694 .66801 .50594 .66303 .49612 Metetra
.941 .714 .566 r
.66303 .49612 .66801 .50594 .67565 .45181 .67076 .44228 Metetra
.814 .431 0 r
.67076 .44228 .67565 .45181 .68713 .4817 .68223 .47272 Metetra
.563 .606 .854 r
.68223 .47272 .68713 .4817 .69735 .48272 .69238 .47228 Metetra
.485 .532 .83 r
.69238 .47228 .69735 .48272 .70761 .48346 .70271 .47418 Metetra
.647 .641 .83 r
.70271 .47418 .70761 .48346 .71778 .4817 .71283 .47114 Metetra
.603 .594 .815 r
.71283 .47114 .71778 .4817 .72795 .4791 .72307 .46957 Metetra
.582 .605 .841 r
.72307 .46957 .72795 .4791 .73818 .47684 .7334 .46864 Metetra
.693 .689 .841 r
.7334 .46864 .73818 .47684 .74855 .47593 .74354 .46409 Metetra
.658 .602 .781 r
.74354 .46409 .74855 .47593 .75866 .47074 .75374 .4601 Metetra
.633 .609 .809 r
.75374 .4601 .75866 .47074 .76888 .46672 .76407 .4574 Metetra
.892 .729 .674 r
.76407 .4574 .76888 .46672 .77924 .464 .77296 .43521 Metetra
.859 .619 .574 r
.77296 .43521 .77924 .464 .78806 .4417 .77919 .38057 Metetra
.578 .396 .599 r
.77919 .38057 .78806 .4417 .79405 .38677 .78938 .37747 Metetra
.722 .342 0 r
.78938 .37747 .79405 .38677 .80428 .38385 .80243 .40721 Metetra
.533 .23 .399 r
.80243 .40721 .80428 .38385 .81749 .41353 .81311 .40748 Metetra
.443 .641 .941 r
.81311 .40748 .81749 .41353 .8282 .41372 .82392 .40852 Metetra
.652 .778 .94 r
.82392 .40852 .8282 .41372 .83905 .41473 .83439 .40532 Metetra
.611 .625 .841 r
.83439 .40532 .83905 .41473 .84955 .41162 .84503 .40344 Metetra
.602 .652 .872 r
.84503 .40344 .84955 .41162 .86021 .40967 .85574 .40178 Metetra
.652 .685 .868 r
.85574 .40178 .86021 .40967 .87094 .40799 .86634 .3986 Metetra
.633 .639 .838 r
.86634 .3986 .87094 .40799 .88456 .4319 .87703 .39592 Metetra
.261 .214 .615 r
.87703 .39592 .88456 .4319 .8953 .42862 .89108 .42255 Metetra
.656 .752 .92 r
.89108 .42255 .8953 .42862 .90609 .42534 .90189 .41924 Metetra
.656 .752 .92 r
.28478 .60144 .29043 .60637 .29914 .6037 .2935 .59876 Metetra
.925 .713 .598 r
.2935 .59876 .29914 .6037 .30968 .57259 .30613 .53668 Metetra
.597 .433 .63 r
.30613 .53668 .30968 .57259 .31841 .56929 .31482 .53313 Metetra
.596 .432 .63 r
.31482 .53313 .31841 .56929 .32714 .56649 .32352 .52972 Metetra
.591 .427 .628 r
.32352 .52972 .32714 .56649 .33598 .56222 .33222 .52684 Metetra
.604 .439 .631 r
.33222 .52684 .33598 .56222 .34483 .55818 .34102 .52257 Metetra
.602 .437 .631 r
.34102 .52257 .34483 .55818 .35364 .55539 .34983 .51853 Metetra
.591 .428 .628 r
.34983 .51853 .35364 .55539 .36267 .54855 .35862 .51552 Metetra
.63 .462 .637 r
.35862 .51552 .36267 .54855 .37168 .54242 .36761 .50868 Metetra
.622 .455 .635 r
.36761 .50868 .37168 .54242 .38192 .50782 .37657 .50262 Metetra
.918 .734 .637 r
.37657 .50262 .38192 .50782 .39074 .50491 .38672 .46844 Metetra
.593 .429 .629 r
.38672 .46844 .39074 .50491 .39771 .552 .39552 .46526 Metetra
.267 .145 .521 r
.39552 .46526 .39771 .552 .40607 .56771 .40253 .51168 Metetra
.442 .295 .586 r
.40253 .51168 .40607 .56771 .41517 .56464 .41089 .52676 Metetra
.593 .428 .627 r
.41089 .52676 .41517 .56464 .42426 .56279 .41996 .52348 Metetra
.583 .419 .625 r
.41996 .52348 .42426 .56279 .43336 .56167 .42902 .52117 Metetra
.57 .408 .622 r
.42902 .52117 .43336 .56167 .4426 .55697 .43808 .52029 Metetra
.608 .441 .63 r
.43808 .52029 .4426 .55697 .45183 .55338 .44728 .51525 Metetra
.6 .433 .627 r
.44728 .51525 .45183 .55338 .46106 .55107 .45648 .51104 Metetra
.588 .421 .624 r
.45648 .51104 .46106 .55107 .47038 .54586 .46568 .50811 Metetra
.605 .437 .628 r
.46568 .50811 .47038 .54586 .47969 .54181 .47495 .50336 Metetra
.631 .455 .626 r
.47495 .50336 .47969 .54181 .48907 .53495 .48427 .495 Metetra
.616 .442 .623 r
.48427 .495 .48907 .53495 .49845 .52732 .49358 .48835 Metetra
.757 .544 .608 r
.49358 .48835 .49845 .52732 .508 .49019 .50309 .45358 Metetra
0 0 .402 r
.50309 .45358 .508 .49019 .51718 .5388 .51215 .4966 Metetra
.434 .308 .61 r
.51215 .4966 .51718 .5388 .52668 .55115 .52153 .50928 Metetra
.574 .41 .621 r
.52153 .50928 .52668 .55115 .53622 .54492 .53101 .50788 Metetra
.763 .55 .609 r
.53101 .50788 .53622 .54492 .54583 .54554 .54038 .47327 Metetra
.204 .114 .525 r
.54038 .47327 .54583 .54554 .55514 .50832 .55023 .52208 Metetra
.752 .406 .398 r
.55023 .52208 .55514 .50832 .56532 .55724 .56008 .54001 Metetra
.659 .543 .712 r
.56008 .54001 .56532 .55724 .57534 .57246 .56978 .53453 Metetra
.583 .423 .63 r
.56978 .53453 .57534 .57246 .58518 .57022 .57955 .53224 Metetra
.568 .413 .631 r
.57955 .53224 .58518 .57022 .59467 .54903 .58939 .5317 Metetra
.811 .628 .654 r
.58939 .5317 .59467 .54903 .60331 .49483 .59879 .50858 Metetra
.976 .816 .404 r
.59879 .50858 .60331 .49483 .61393 .5253 .60726 .45248 Metetra
.383 .247 .569 r
.60726 .45248 .61393 .5253 .62372 .51967 .61787 .4822 Metetra
.581 .422 .631 r
.61787 .4822 .62372 .51967 .63381 .52267 .62772 .48016 Metetra
.579 .414 .621 r
.62772 .48016 .63381 .52267 .64381 .5213 .63761 .47801 Metetra
.561 .4 .62 r
.63761 .47801 .64381 .5213 .65374 .51678 .64763 .47823 Metetra
.71 .509 .616 r
.64763 .47823 .65374 .51678 .66303 .49612 .6568 .45599 Metetra
.808 .575 .585 r
.6568 .45599 .66303 .49612 .67076 .44228 .66454 .40276 Metetra
.188 .145 .575 r
.66454 .40276 .67076 .44228 .68223 .47272 .67588 .43277 Metetra
.556 .401 .626 r
.67588 .43277 .68223 .47272 .69238 .47228 .68601 .43356 Metetra
.568 .411 .629 r
.68601 .43356 .69238 .47228 .70271 .47418 .69612 .43299 Metetra
.572 .411 .624 r
.69612 .43299 .70271 .47418 .71283 .47114 .70625 .4318 Metetra
.565 .408 .628 r
.70625 .4318 .71283 .47114 .72307 .46957 .71649 .43159 Metetra
.604 .438 .63 r
.71649 .43159 .72307 .46957 .7334 .46864 .72649 .42665 Metetra
.589 .421 .622 r
.72649 .42665 .7334 .46864 .74354 .46409 .73662 .42322 Metetra
.583 .419 .625 r
.73662 .42322 .74354 .46409 .75374 .4601 .74684 .42059 Metetra
.703 .502 .614 r
.74684 .42059 .75374 .4601 .76407 .4574 .75574 .39911 Metetra
.765 .528 .576 r
.75574 .39911 .76407 .4574 .77296 .43521 .76214 .3452 Metetra
.569 .377 .581 r
.76214 .3452 .77296 .43521 .77919 .38057 .77223 .34233 Metetra
.221 .176 .592 r
.77223 .34233 .77919 .38057 .78938 .37747 .78496 .37144 Metetra
.497 .669 .94 r
.78496 .37144 .78938 .37747 .80243 .40721 .79549 .37157 Metetra
.555 .409 .637 r
.79549 .37157 .80243 .40721 .81311 .40748 .80615 .37249 Metetra
.591 .434 .638 r
.80615 .37249 .81311 .40748 .82392 .40852 .81651 .36944 Metetra
.579 .419 .629 r
.81651 .36944 .82392 .40852 .83439 .40532 .82701 .36746 Metetra
.578 .42 .632 r
.82701 .36746 .83439 .40532 .84503 .40344 .83759 .36572 Metetra
.59 .429 .631 r
.83759 .36572 .84503 .40344 .85574 .40178 .84807 .36252 Metetra
.584 .423 .629 r
.84807 .36252 .85574 .40178 .86634 .3986 .85864 .35988 Metetra
.583 .423 .63 r
.85864 .35988 .86634 .3986 .87703 .39592 .86927 .35737 Metetra
0 0 .474 r
.86927 .35737 .87703 .39592 .89108 .42255 .88683 .41643 Metetra
.656 .752 .92 r
.88683 .41643 .89108 .42255 .90189 .41924 .89767 .4131 Metetra
.656 .752 .92 r
.27909 .59648 .28478 .60144 .2935 .59876 .28783 .59378 Metetra
.842 .764 .776 r
.28783 .59378 .2935 .59876 .30613 .53668 .2972 .58226 Metetra
.516 .259 .464 r
.2972 .58226 .30613 .53668 .31482 .53313 .306 .57914 Metetra
.512 .256 .463 r
.306 .57914 .31482 .53313 .32352 .52972 .31487 .57553 Metetra
.514 .257 .464 r
.31487 .57553 .32352 .52972 .33222 .52684 .32374 .57217 Metetra
.518 .26 .464 r
.32374 .57217 .33222 .52684 .34102 .52257 .33261 .56929 Metetra
.506 .251 .462 r
.33261 .56929 .34102 .52257 .34983 .51853 .3416 .56487 Metetra
.508 .253 .463 r
.3416 .56487 .34983 .51853 .35862 .51552 .35059 .56073 Metetra
.518 .261 .464 r
.35059 .56073 .35862 .51552 .36761 .50868 .35954 .55787 Metetra
.485 .236 .46 r
.35954 .55787 .36761 .50868 .37657 .50262 .36872 .55077 Metetra
.492 .24 .461 r
.36872 .55077 .37657 .50262 .38672 .46844 .37786 .5445 Metetra
.316 .111 .435 r
.37786 .5445 .38672 .46844 .39552 .46526 .3882 .50941 Metetra
.514 .256 .462 r
.3882 .50941 .39552 .46526 .40253 .51168 .39718 .50614 Metetra
.951 .623 .363 r
.39718 .50614 .40253 .51168 .41089 .52676 .40437 .55383 Metetra
.679 .383 .465 r
.40437 .55383 .41089 .52676 .41996 .52348 .41292 .56941 Metetra
.516 .258 .463 r
.41292 .56941 .41996 .52348 .42902 .52117 .42217 .56613 Metetra
.525 .266 .464 r
.42217 .56613 .42902 .52117 .43808 .52029 .43141 .56407 Metetra
.525 .264 .462 r
.43141 .56407 .43808 .52029 .44728 .51525 .44069 .56207 Metetra
.506 .251 .462 r
.44069 .56207 .44728 .51525 .45648 .51104 .45007 .55749 Metetra
.502 .247 .461 r
.45007 .55749 .45648 .51104 .46568 .50811 .45947 .5525 Metetra
.507 .25 .459 r
.45947 .5525 .46568 .50811 .47495 .50336 .46888 .54837 Metetra
.47 .218 .45 r
.46888 .54837 .47495 .50336 .48427 .495 .47838 .54009 Metetra
.49 .236 .456 r
.47838 .54009 .48427 .495 .49358 .48835 .48785 .53389 Metetra
.033 0 .303 r
.48785 .53389 .49358 .48835 .50309 .45358 .49761 .49475 Metetra
.758 .472 .499 r
.49761 .49475 .50309 .45358 .51215 .4966 .50673 .54065 Metetra
.642 .366 .486 r
.50673 .54065 .51215 .4966 .52153 .50928 .51625 .55654 Metetra
.143 0 .352 r
.51625 .55654 .52153 .50928 .53101 .50788 .52588 .52153 Metetra
.873 .552 .441 r
.52588 .52153 .53101 .50788 .54038 .47327 .53565 .57461 Metetra
.592 .348 .515 r
.53565 .57461 .54038 .47327 .55023 .52208 .54554 .58901 Metetra
.545 .297 .491 r
.54554 .58901 .55023 .52208 .56008 .54001 .55544 .58883 Metetra
.532 .274 .469 r
.55544 .58883 .56008 .54001 .56978 .53453 .56537 .58735 Metetra
.529 .275 .474 r
.56537 .58735 .56978 .53453 .57955 .53224 .57533 .58512 Metetra
.513 .262 .471 r
.57533 .58512 .57955 .53224 .58939 .5317 .5853 .58063 Metetra
.508 .254 .464 r
.5853 .58063 .58939 .5317 .59879 .50858 .59528 .57581 Metetra
.419 .196 .466 r
.59528 .57581 .59879 .50858 .60726 .45248 .6049 .55436 Metetra
.287 .107 .454 r
.6049 .55436 .60726 .45248 .61787 .4822 .61345 .49583 Metetra
.825 .481 .405 r
.61345 .49583 .61787 .4822 .62772 .48016 .62439 .52784 Metetra
.507 .252 .463 r
.62439 .52784 .62772 .48016 .63761 .47801 .63438 .52302 Metetra
.533 .271 .464 r
.63438 .52302 .63761 .47801 .64763 .47823 .64452 .52187 Metetra
.366 .135 .425 r
.64452 .52187 .64763 .47823 .6568 .45599 .65403 .50323 Metetra
0 0 .263 r
.65403 .50323 .6568 .45599 .66454 .40276 .66189 .44648 Metetra
.707 .417 .483 r
.66189 .44648 .66454 .40276 .67588 .43277 .67342 .47803 Metetra
.543 .28 .466 r
.67342 .47803 .67588 .43277 .68601 .43356 .6837 .4783 Metetra
.553 .287 .467 r
.6837 .4783 .68601 .43356 .69612 .43299 .69411 .47997 Metetra
.536 .276 .468 r
.69411 .47997 .69612 .43299 .70625 .4318 .70446 .47921 Metetra
.519 .262 .466 r
.70446 .47921 .70625 .4318 .71649 .43159 .71471 .47597 Metetra
.513 .254 .46 r
.71471 .47597 .71649 .43159 .72649 .42665 .72498 .47229 Metetra
.524 .265 .463 r
.72498 .47229 .72649 .42665 .73662 .42322 .73537 .46992 Metetra
.356 .135 .434 r
.73537 .46992 .73662 .42322 .74684 .42059 .74448 .44793 Metetra
0 0 .035 r
.74448 .44793 .74684 .42059 .75574 .39911 .75117 .39284 Metetra
.64 .728 .912 r
.75117 .39284 .75574 .39911 .76214 .3452 .76143 .39009 Metetra
.698 .405 .476 r
.76143 .39009 .76214 .3452 .77223 .34233 .77425 .42024 Metetra
.548 .304 .498 r
.77425 .42024 .77223 .34233 .78496 .37144 .78494 .42062 Metetra
.55 .289 .472 r
.78494 .42062 .78496 .37144 .79549 .37157 .79577 .4219 Metetra
.522 .268 .471 r
.79577 .4219 .79549 .37157 .80615 .37249 .80629 .41873 Metetra
.529 .269 .465 r
.80629 .41873 .80615 .37249 .81651 .36944 .81696 .41691 Metetra
.532 .272 .467 r
.81696 .41691 .81651 .36944 .82701 .36746 .82772 .41538 Metetra
.521 .265 .467 r
.82772 .41538 .82701 .36746 .83759 .36572 .83837 .41224 Metetra
.524 .265 .465 r
.83837 .41224 .83759 .36572 .84807 .36252 .8491 .40959 Metetra
.526 .267 .466 r
.8491 .40959 .84807 .36252 .85864 .35988 .85992 .4072 Metetra
.523 .265 .466 r
.85992 .4072 .85864 .35988 .86927 .35737 .87072 .4043 Metetra
.578 .306 .469 r
.87072 .4043 .86927 .35737 .88683 .41643 .88255 .41027 Metetra
.656 .752 .92 r
.88255 .41027 .88683 .41643 .89767 .4131 .89342 .40691 Metetra
.543 .02 0 r
.27337 .59149 .27909 .59648 .28783 .59378 .28138 .59925 Metetra
.12 0 0 r
.28138 .59925 .28783 .59378 .2972 .58226 .29024 .59603 Metetra
.415 .065 .26 r
.29024 .59603 .2972 .58226 .306 .57914 .29909 .59321 Metetra
.408 .061 .261 r
.29909 .59321 .306 .57914 .31487 .57553 .30799 .59009 Metetra
.397 .054 .263 r
.30799 .59009 .31487 .57553 .32374 .57217 .31694 .58649 Metetra
.397 .052 .259 r
.31694 .58649 .32374 .57217 .33261 .56929 .32592 .58295 Metetra
.412 .061 .257 r
.32592 .58295 .33261 .56929 .3416 .56487 .33489 .58004 Metetra
.38 .043 .263 r
.33489 .58004 .3416 .56487 .35059 .56073 .34397 .57567 Metetra
.382 .043 .261 r
.34397 .57567 .35059 .56073 .35954 .55787 .35306 .57143 Metetra
.406 .054 .252 r
.35306 .57143 .35954 .55787 .36872 .55077 .36211 .56836 Metetra
.327 .012 .269 r
.36211 .56836 .36872 .55077 .37786 .5445 .37138 .5614 Metetra
.331 .012 .264 r
.37138 .5614 .37786 .5445 .3882 .50941 .38063 .55485 Metetra
.042 0 .29 r
.38063 .55485 .3882 .50941 .39718 .50614 .39106 .51915 Metetra
.382 .028 .234 r
.39106 .51915 .39718 .50614 .40437 .55383 .40015 .51556 Metetra
0 0 .273 r
.40015 .51556 .40437 .55383 .41292 .56941 .40745 .56419 Metetra
.832 .371 0 r
.40745 .56419 .41292 .56941 .42217 .56613 .41611 .57988 Metetra
.379 .03 .241 r
.41611 .57988 .42217 .56613 .43141 .56407 .42548 .5759 Metetra
.421 .05 .227 r
.42548 .5759 .43141 .56407 .44069 .56207 .43483 .57376 Metetra
.437 .064 .232 r
.43483 .57376 .44069 .56207 .45007 .55749 .44421 .57211 Metetra
.276 0 .208 r
.44421 .57211 .45007 .55749 .45947 .5525 .45373 .56502 Metetra
.305 0 .184 r
.45373 .56502 .45947 .5525 .46888 .54837 .46324 .55969 Metetra
.264 0 .137 r
.46324 .55969 .46888 .54837 .47838 .54009 .47276 .55416 Metetra
.107 0 .123 r
.47276 .55416 .47838 .54009 .48785 .53389 .48237 .54369 Metetra
.99 .863 .51 r
.48237 .54369 .48785 .53389 .49761 .49475 .49225 .50429 Metetra
.887 .563 .43 r
.49225 .50429 .49761 .49475 .50673 .54065 .50133 .55475 Metetra
.50133 .55475 .50673 .54065 .51625 .55654 .51103 .53757 Metetra
.898 .586 .089 r
.51103 .53757 .51625 .55654 .52588 .52153 .52059 .58958 Metetra
.629 .368 .504 r
.52059 .58958 .52588 .52153 .53565 .57461 .53045 .60947 Metetra
.494 .222 .43 r
.53045 .60947 .53565 .57461 .54554 .58901 .54037 .60549 Metetra
.481 .145 .319 r
.54037 .60549 .54554 .58901 .55544 .58883 .55034 .60415 Metetra
.522 .175 .32 r
.55034 .60415 .55544 .58883 .56537 .58735 .56038 .60486 Metetra
.467 .139 .325 r
.56038 .60486 .56537 .58735 .57533 .58512 .57043 .60264 Metetra
.356 .04 .284 r
.57043 .60264 .57533 .58512 .5853 .58063 .58046 .59596 Metetra
.417 .077 .28 r
.58046 .59596 .5853 .58063 .59528 .57581 .59055 .59232 Metetra
.445 .111 .306 r
.59055 .59232 .59528 .57581 .6049 .55436 .6007 .58936 Metetra
.185 0 .34 r
.6007 .58936 .6049 .55436 .61345 .49583 .61032 .56435 Metetra
.123 0 .382 r
.61032 .56435 .61345 .49583 .62439 .52784 .61898 .5085 Metetra
0 0 .43 r
.61898 .5085 .62439 .52784 .63438 .52302 .63001 .53738 Metetra
.381 .039 .255 r
.63001 .53738 .63438 .52302 .64452 .52187 .64012 .53279 Metetra
.64012 .53279 .64452 .52187 .65403 .50323 .64966 .51247 Metetra
.99 .819 .438 r
.64966 .51247 .65403 .50323 .66189 .44648 .65784 .46001 Metetra
.815 .462 .389 r
.65784 .46001 .66189 .44648 .67342 .47803 .66931 .48915 Metetra
.525 .139 .252 r
.66931 .48915 .67342 .47803 .6837 .4783 .67972 .49067 Metetra
.579 .203 .294 r
.67972 .49067 .6837 .4783 .69411 .47997 .69031 .4945 Metetra
.411 .069 .272 r
.69031 .4945 .69411 .47997 .70446 .47921 .70059 .49076 Metetra
.393 .021 .209 r
.70059 .49076 .70446 .47921 .71471 .47597 .71093 .48767 Metetra
.439 .064 .229 r
.71093 .48767 .71471 .47597 .72498 .47229 .7214 .48594 Metetra
.7214 .48594 .72498 .47229 .73537 .46992 .73065 .46405 Metetra
.973 .744 .532 r
.73065 .46405 .73537 .46992 .74448 .44793 .73757 .40802 Metetra
.58 .418 .626 r
.73757 .40802 .74448 .44793 .75117 .39284 .7479 .40567 Metetra
.827 .462 .362 r
.7479 .40567 .75117 .39284 .76143 .39009 .76066 .43639 Metetra
.545 .281 .466 r
.76066 .43639 .76143 .39009 .77425 .42024 .77142 .43711 Metetra
.531 .191 .337 r
.77142 .43711 .77425 .42024 .78494 .42062 .78226 .4382 Metetra
.459 .134 .328 r
.78226 .4382 .78494 .42062 .79577 .4219 .79285 .43529 Metetra
.456 .098 .269 r
.79285 .43529 .79577 .4219 .80629 .41873 .80358 .43356 Metetra
.47 .123 .295 r
.80358 .43356 .80629 .41873 .81696 .41691 .81438 .43198 Metetra
.437 .097 .29 r
.81438 .43198 .81696 .41691 .82772 .41538 .82508 .42886 Metetra
.439 .084 .265 r
.82508 .42886 .82772 .41538 .83837 .41224 .83589 .42641 Metetra
.447 .097 .279 r
.83589 .42641 .83837 .41224 .8491 .40959 .84676 .42401 Metetra
.437 .092 .28 r
.84676 .42401 .8491 .40959 .85992 .4072 .85762 .4211 Metetra
.425 .077 .269 r
.85762 .4211 .85992 .4072 .87072 .4043 .86849 .41788 Metetra
.432 .08 .265 r
.86849 .41788 .87072 .4043 .88255 .41027 .87944 .41508 Metetra
.87944 .41508 .88255 .41027 .89342 .40691 .88914 .40069 Metetra
.677 .162 0 r
.26761 .58647 .27337 .59149 .28138 .59925 .2755 .59586 Metetra
.661 .823 .961 r
.2755 .59586 .28138 .59925 .29024 .59603 .28437 .59281 Metetra
.667 .832 .963 r
.28437 .59281 .29024 .59603 .29909 .59321 .29327 .58961 Metetra
.65 .813 .961 r
.29327 .58961 .29909 .59321 .30799 .59009 .30217 .58676 Metetra
.67 .829 .96 r
.30217 .58676 .30799 .59009 .31694 .58649 .31113 .58349 Metetra
.689 .848 .959 r
.31113 .58349 .31694 .58649 .32592 .58295 .32014 .57979 Metetra
.675 .84 .962 r
.32014 .57979 .32592 .58295 .33489 .58004 .32916 .57637 Metetra
.661 .815 .958 r
.32916 .57637 .33489 .58004 .34397 .57567 .33819 .5733 Metetra
.722 .882 .955 r
.33819 .5733 .34397 .57567 .35306 .57143 .34732 .56877 Metetra
.705 .869 .959 r
.34732 .56877 .35306 .57143 .36211 .56836 .35646 .56463 Metetra
.667 .816 .955 r
.35646 .56463 .36211 .56836 .37138 .5614 .36557 .56142 Metetra
.807 .971 .904 r
.36557 .56142 .37138 .5614 .38063 .55485 .3749 .55411 Metetra
.796 .95 .921 r
.3749 .55411 .38063 .55485 .39106 .51915 .38421 .5474 Metetra
.38421 .5474 .39106 .51915 .40015 .51556 .39466 .51167 Metetra
.68 .812 .946 r
.39466 .51167 .40015 .51556 .40745 .56419 .40379 .50821 Metetra
0 0 .453 r
.40379 .50821 .40745 .56419 .41611 .57988 .41122 .55596 Metetra
.154 .165 .617 r
.41122 .55596 .41611 .57988 .42548 .5759 .41994 .57213 Metetra
.71 .829 .938 r
.41994 .57213 .42548 .5759 .43483 .57376 .42938 .56787 Metetra
.68 .74 .896 r
.42938 .56787 .43483 .57376 .44421 .57211 .43881 .56432 Metetra
.662 .677 .854 r
.43881 .56432 .44421 .57211 .45373 .56502 .44827 .56109 Metetra
.746 .83 .916 r
.44827 .56109 .45373 .56502 .46324 .55969 .45781 .55584 Metetra
.864 .825 .807 r
.45781 .55584 .46324 .55969 .47276 .55416 .46746 .54463 Metetra
.752 .673 .774 r
.46746 .54463 .47276 .55416 .48237 .54369 .47705 .53654 Metetra
.921 .729 .625 r
.47705 .53654 .48237 .54369 .49225 .50429 .48697 .50027 Metetra
.835 .368 0 r
.48697 .50027 .49225 .50429 .50133 .55475 .49629 .51652 Metetra
.723 .513 0 r
.49629 .51652 .50133 .55475 .51103 .53757 .50543 .5878 Metetra
.645 .372 .49 r
.50543 .5878 .51103 .53757 .52059 .58958 .51518 .60674 Metetra
.489 .156 .328 r
.51518 .60674 .52059 .58958 .53045 .60947 .52509 .60568 Metetra
.608 .815 .98 r
.52509 .60568 .53045 .60947 .54037 .60549 .53505 .60314 Metetra
.115 .62 .899 r
.53505 .60314 .54037 .60549 .55034 .60415 .54506 .60446 Metetra
.55 .93 .896 r
.54506 .60446 .55034 .60415 .56038 .60486 .55509 .59984 Metetra
.609 .764 .954 r
.55509 .59984 .56038 .60486 .57043 .60264 .56517 .59759 Metetra
.558 .745 .964 r
.56517 .59759 .57043 .60264 .58046 .59596 .5753 .59623 Metetra
.685 .977 .898 r
.5753 .59623 .58046 .59596 .59055 .59232 .58539 .58989 Metetra
.683 .901 .974 r
.58539 .58989 .59055 .59232 .6007 .58936 .59554 .58544 Metetra
.677 .836 .96 r
.59554 .58544 .6007 .58936 .61032 .56435 .60573 .58155 Metetra
0 0 .035 r
.60573 .58155 .61032 .56435 .61898 .5085 .61546 .55921 Metetra
0 0 .245 r
.61546 .55921 .61898 .5085 .63001 .53738 .62397 .4988 Metetra
.167 .132 .571 r
.62397 .4988 .63001 .53738 .64012 .53279 .63512 .52799 Metetra
.936 .796 .68 r
.63512 .52799 .64012 .53279 .64966 .51247 .64462 .50496 Metetra
.955 .73 .558 r
.64462 .50496 .64966 .51247 .65784 .46001 .65279 .45007 Metetra
.854 .477 0 r
.65279 .45007 .65784 .46001 .66931 .48915 .66446 .48489 Metetra
.305 .653 .97 r
.66446 .48489 .66931 .48915 .67972 .49067 .67489 .4863 Metetra
.448 .726 .985 r
.67489 .4863 .67972 .49067 .69031 .4945 .68532 .48616 Metetra
.607 .653 .869 r
.68532 .48616 .69031 .4945 .70059 .49076 .69571 .48431 Metetra
.557 .691 .929 r
.69571 .48431 .70059 .49076 .71093 .48767 .7062 .48336 Metetra
.948 .816 .68 r
.7062 .48336 .71093 .48767 .7214 .48594 .71549 .46091 Metetra
.875 .636 .575 r
.71549 .46091 .7214 .48594 .73065 .46405 .72271 .40603 Metetra
.573 .393 .6 r
.72271 .40603 .73065 .46405 .73757 .40802 .73301 .40347 Metetra
.879 .46 .04 r
.73301 .40347 .73757 .40802 .7479 .40567 .74561 .43423 Metetra
.538 .245 .417 r
.74561 .43423 .7479 .40567 .76066 .43639 .75635 .43504 Metetra
.002 .562 .807 r
.75635 .43504 .76066 .43639 .77142 .43711 .7672 .4365 Metetra
.4 .85 .906 r
.7672 .4365 .77142 .43711 .78226 .4382 .77778 .43368 Metetra
.566 .779 .979 r
.77778 .43368 .78226 .4382 .79285 .43529 .78849 .43184 Metetra
.5 .8 .999 r
.78849 .43184 .79285 .43529 .80358 .43356 .79928 .43038 Metetra
.594 .855 .993 r
.79928 .43038 .80358 .43356 .81438 .43198 .80999 .42741 Metetra
.609 .797 .972 r
.80999 .42741 .81438 .43198 .82508 .42886 .82078 .42479 Metetra
.58 .809 .986 r
.82078 .42479 .82508 .42886 .83589 .42641 .83164 .42246 Metetra
.603 .826 .985 r
.83164 .42246 .83589 .42641 .84676 .42401 .8425 .41967 Metetra
.634 .821 .972 r
.8425 .41967 .84676 .42401 .85762 .4211 .85336 .41645 Metetra
.619 .802 .969 r
.85336 .41645 .85762 .4211 .86849 .41788 .86431 .41358 Metetra
.62 .819 .977 r
.86431 .41358 .86849 .41788 .87944 .41508 .87528 .41056 Metetra
.932 .861 .747 r
.87528 .41056 .87944 .41508 .88914 .40069 .88483 .39442 Metetra
.788 .301 0 r
.26182 .58142 .26761 .58647 .2755 .59586 .26954 .59309 Metetra
.63 .846 .983 r
.26954 .59309 .2755 .59586 .28437 .59281 .2784 .59034 Metetra
.643 .862 .982 r
.2784 .59034 .28437 .59281 .29327 .58961 .28731 .58728 Metetra
.66 .873 .979 r
.28731 .58728 .29327 .58961 .30217 .58676 .29628 .5839 Metetra
.639 .846 .979 r
.29628 .5839 .30217 .58676 .31113 .58349 .30524 .58099 Metetra
.649 .865 .981 r
.30524 .58099 .31113 .58349 .32014 .57979 .31424 .5778 Metetra
.676 .892 .976 r
.31424 .5778 .32014 .57979 .32916 .57637 .32331 .574 Metetra
.673 .876 .975 r
.32331 .574 .32916 .57637 .33819 .5733 .3324 .57036 Metetra
.636 .844 .98 r
.3324 .57036 .33819 .5733 .34732 .56877 .34147 .56747 Metetra
.714 .927 .962 r
.34147 .56747 .34732 .56877 .35646 .56463 .35067 .56271 Metetra
.704 .902 .967 r
.35067 .56271 .35646 .56463 .36557 .56142 .35987 .55835 Metetra
.673 .848 .967 r
.35987 .55835 .36557 .56142 .3749 .55411 .36905 .55486 Metetra
.773 .988 .895 r
.36905 .55486 .3749 .55411 .38421 .5474 .37841 .54777 Metetra
.77 .982 .908 r
.37841 .54777 .38421 .5474 .39466 .51167 .38777 .54099 Metetra
.38777 .54099 .39466 .51167 .40379 .50821 .39828 .50442 Metetra
.673 .817 .952 r
.39828 .50442 .40379 .50821 .41122 .55596 .40746 .50105 Metetra
0 0 .445 r
.40746 .50105 .41122 .55596 .41994 .57213 .41499 .54921 Metetra
.2 .203 .637 r
.41499 .54921 .41994 .57213 .42938 .56787 .42384 .56343 Metetra
.726 .806 .914 r
.42384 .56343 .42938 .56787 .43881 .56432 .43334 .5587 Metetra
.656 .745 .915 r
.43334 .5587 .43881 .56432 .44827 .56109 .44281 .55574 Metetra
.753 .777 .873 r
.44281 .55574 .44827 .56109 .45781 .55584 .45238 .54986 Metetra
.839 .765 .781 r
.45238 .54986 .45781 .55584 .46746 .54463 .46207 .5383 Metetra
.754 .748 .847 r
.46207 .5383 .46746 .54463 .47705 .53654 .47166 .53201 Metetra
.952 .728 .562 r
.47166 .53201 .47705 .53654 .48697 .50027 .48207 .46455 Metetra
.936 .665 .192 r
.48207 .46455 .48697 .50027 .49629 .51652 .49041 .56708 Metetra
.712 .432 .499 r
.49041 .56708 .49629 .51652 .50543 .5878 .49986 .60456 Metetra
.495 .157 .323 r
.49986 .60456 .50543 .5878 .51518 .60674 .50975 .60391 Metetra
.181 .646 .936 r
.50975 .60391 .51518 .60674 .52509 .60568 .51969 .60512 Metetra
.382 .836 .918 r
.51969 .60512 .52509 .60568 .53505 .60314 .52968 .60285 Metetra
.226 .744 .846 r
.52968 .60285 .53505 .60314 .54506 .60446 .53972 .6015 Metetra
.68 .875 .972 r
.53972 .6015 .54506 .60446 .55509 .59984 .54978 .59736 Metetra
.532 .85 .998 r
.54978 .59736 .55509 .59984 .56517 .59759 .55989 .5951 Metetra
.498 .835 .998 r
.55989 .5951 .56517 .59759 .5753 .59623 .57005 .59322 Metetra
.652 .869 .98 r
.57005 .59322 .5753 .59623 .58539 .58989 .58022 .58953 Metetra
.604 .944 .934 r
.58022 .58953 .58539 .58989 .59554 .58544 .5904 .58477 Metetra
.72 .97 .933 r
.5904 .58477 .59554 .58544 .60573 .58155 .60058 .57857 Metetra
.515 .824 1 r
.60058 .57857 .60573 .58155 .61546 .55921 .61089 .57675 Metetra
.61089 .57675 .61546 .55921 .62397 .4988 .62054 .54985 Metetra
0 0 .255 r
.62054 .54985 .62397 .4988 .63512 .52799 .62905 .49033 Metetra
.454 .334 .627 r
.62905 .49033 .63512 .52799 .64462 .50496 .63964 .50016 Metetra
.969 .746 .545 r
.63964 .50016 .64462 .50496 .65279 .45007 .64784 .44331 Metetra
.904 .511 .089 r
.64784 .44331 .65279 .45007 .66446 .48489 .6595 .47848 Metetra
.373 .598 .934 r
.6595 .47848 .66446 .48489 .67489 .4863 .66997 .48048 Metetra
.517 .697 .951 r
.66997 .48048 .67489 .4863 .68532 .48616 .6804 .48003 Metetra
.535 .694 .941 r
.6804 .48003 .68532 .48616 .69571 .48431 .69088 .47936 Metetra
.93 .81 .704 r
.69088 .47936 .69571 .48431 .7062 .48336 .70038 .45942 Metetra
.88 .642 .574 r
.70038 .45942 .7062 .48336 .71549 .46091 .70781 .40412 Metetra
.572 .393 .601 r
.70781 .40412 .71549 .46091 .72271 .40603 .7181 .40162 Metetra
.887 .471 .062 r
.7181 .40162 .72271 .40603 .73301 .40347 .73058 .43309 Metetra
.539 .247 .419 r
.73058 .43309 .73301 .40347 .74561 .43423 .7413 .43404 Metetra
.109 0 0 r
.7413 .43404 .74561 .43423 .75635 .43504 .7521 .4352 Metetra
.273 .778 .81 r
.7521 .4352 .75635 .43504 .7672 .4365 .7627 .43269 Metetra
.531 .797 .994 r
.7627 .43269 .7672 .4365 .77778 .43368 .77341 .43102 Metetra
.429 .802 .994 r
.77341 .43102 .77778 .43368 .78849 .43184 .78421 .4298 Metetra
.554 .889 .986 r
.78421 .4298 .78849 .43184 .79928 .43038 .79489 .42659 Metetra
.576 .821 .991 r
.79489 .42659 .79928 .43038 .80999 .42741 .80569 .42418 Metetra
.543 .834 .999 r
.80569 .42418 .80999 .42741 .82078 .42479 .81655 .42192 Metetra
.57 .863 .996 r
.81655 .42192 .82078 .42479 .83164 .42246 .82739 .41902 Metetra
.61 .855 .99 r
.82739 .41902 .83164 .42246 .8425 .41967 .83826 .41582 Metetra
.591 .828 .989 r
.83826 .41582 .8425 .41967 .85336 .41645 .84921 .41311 Metetra
.595 .855 .993 r
.84921 .41311 .85336 .41645 .86431 .41358 .86018 .41006 Metetra
.618 .857 .988 r
.86018 .41006 .86431 .41358 .87528 .41056 .87115 .4067 Metetra
.956 .869 .712 r
.87115 .4067 .87528 .41056 .88483 .39442 .88049 .38811 Metetra
.756 .258 0 r
.25599 .57634 .26182 .58142 .26954 .59309 .26376 .5872 Metetra
.67 .727 .893 r
.26376 .5872 .26954 .59309 .2784 .59034 .27266 .58407 Metetra
.66 .712 .887 r
.27266 .58407 .2784 .59034 .28731 .58728 .28158 .58115 Metetra
.669 .72 .887 r
.28158 .58115 .28731 .58728 .29628 .5839 .29054 .57801 Metetra
.674 .73 .892 r
.29054 .57801 .29628 .5839 .30524 .58099 .29954 .57474 Metetra
.664 .716 .887 r
.29954 .57474 .30524 .58099 .31424 .5778 .30856 .57169 Metetra
.676 .724 .886 r
.30856 .57169 .31424 .5778 .32331 .574 .31762 .56833 Metetra
.689 .743 .893 r
.31762 .56833 .32331 .574 .3324 .57036 .32672 .56465 Metetra
.692 .743 .891 r
.32672 .56465 .3324 .57036 .34147 .56747 .33586 .56085 Metetra
.667 .707 .878 r
.33586 .56085 .34147 .56747 .35067 .56271 .34499 .55766 Metetra
.732 .776 .888 r
.34499 .55766 .35067 .56271 .35987 .55835 .35424 .55273 Metetra
.707 .752 .887 r
.35424 .55273 .35987 .55835 .36905 .55486 .36348 .54847 Metetra
.674 .718 .882 r
.36348 .54847 .36905 .55486 .37841 .54777 .3727 .54509 Metetra
.83 .868 .874 r
.3727 .54509 .37841 .54777 .38777 .54099 .38215 .53706 Metetra
.781 .825 .887 r
.38215 .53706 .38777 .54099 .39828 .50442 .39153 .53065 Metetra
.39153 .53065 .39828 .50442 .40746 .50105 .40205 .49396 Metetra
.712 .709 .845 r
.40205 .49396 .40746 .50105 .41499 .54921 .41133 .48918 Metetra
.045 0 .472 r
.41133 .48918 .41499 .54921 .42384 .56343 .41898 .53628 Metetra
.226 .199 .618 r
.41898 .53628 .42384 .56343 .43334 .5587 .42785 .55219 Metetra
.795 .748 .81 r
.42785 .55219 .43334 .5587 .44281 .55574 .43748 .54355 Metetra
.696 .611 .758 r
.43748 .54355 .44281 .55574 .45238 .54986 .44706 .53753 Metetra
.67 .597 .765 r
.44706 .53753 .45238 .54986 .46207 .5383 .45663 .53285 Metetra
.937 .74 .612 r
.45663 .53285 .46207 .5383 .47166 .53201 .46685 .49211 Metetra
.36 .258 .601 r
.46685 .49211 .47166 .53201 .48207 .46455 .47606 .50837 Metetra
.804 .515 .5 r
.47606 .50837 .48207 .46455 .49041 .56708 .48475 .58068 Metetra
.747 .397 .39 r
.48475 .58068 .49041 .56708 .49986 .60456 .49439 .59798 Metetra
.494 .656 .932 r
.49439 .59798 .49986 .60456 .50975 .60391 .50429 .59818 Metetra
.24 .555 .933 r
.50429 .59818 .50975 .60391 .51969 .60512 .51424 .60107 Metetra
.693 .83 .949 r
.51424 .60107 .51969 .60512 .52968 .60285 .52426 .59692 Metetra
.66 .748 .915 r
.52426 .59692 .52968 .60285 .53972 .6015 .53431 .59366 Metetra
.592 .66 .885 r
.53431 .59366 .53972 .6015 .54978 .59736 .54441 .59218 Metetra
.61 .761 .952 r
.54441 .59218 .54978 .59736 .55989 .5951 .55454 .58991 Metetra
.709 .792 .916 r
.55454 .58991 .55989 .5951 .57005 .59322 .56469 .58531 Metetra
.604 .665 .882 r
.56469 .58531 .57005 .59322 .58022 .58953 .57491 .5835 Metetra
.644 .743 .921 r
.57491 .5835 .58022 .58953 .5904 .58477 .58515 .58059 Metetra
.792 .847 .892 r
.58515 .58059 .5904 .58477 .60058 .57857 .59535 .57337 Metetra
.691 .79 .926 r
.59535 .57337 .60058 .57857 .61089 .57675 .60563 .56923 Metetra
.721 .724 .852 r
.60563 .56923 .61089 .57675 .62054 .54985 .6159 .5637 Metetra
.6159 .5637 .62054 .54985 .62905 .49033 .62556 .53686 Metetra
0 0 .07 r
.62556 .53686 .62905 .49033 .63964 .50016 .63342 .45903 Metetra
.699 .498 .612 r
.63342 .45903 .63964 .50016 .64784 .44331 .64289 .43742 Metetra
.875 .459 .028 r
.64289 .43742 .64784 .44331 .6595 .47848 .65424 .46562 Metetra
.491 .499 .793 r
.65424 .46562 .6595 .47848 .66997 .48048 .66472 .46771 Metetra
.372 .43 .792 r
.66472 .46771 .66997 .48048 .6804 .48003 .67542 .47299 Metetra
.912 .766 .686 r
.67542 .47299 .6804 .48003 .69088 .47936 .68488 .45117 Metetra
.858 .621 .579 r
.68488 .45117 .69088 .47936 .70038 .45942 .6926 .39751 Metetra
.562 .382 .595 r
.6926 .39751 .70038 .45942 .70781 .40412 .70294 .39635 Metetra
.843 .443 0 r
.70294 .39635 .70781 .40412 .7181 .40162 .71526 .42805 Metetra
.53 .23 .402 r
.71526 .42805 .7181 .40162 .73058 .43309 .72591 .42851 Metetra
.256 .61 .955 r
.72591 .42851 .73058 .43309 .7413 .43404 .73673 .43069 Metetra
.585 .842 .994 r
.73673 .43069 .7413 .43404 .7521 .4352 .7473 .42799 Metetra
.596 .687 .905 r
.7473 .42799 .7521 .4352 .7627 .43269 .75798 .42623 Metetra
.56 .697 .932 r
.75798 .42623 .7627 .43269 .77341 .43102 .76876 .42511 Metetra
.636 .752 .932 r
.76876 .42511 .77341 .43102 .78421 .4298 .77945 .42221 Metetra
.618 .687 .893 r
.77945 .42221 .78421 .4298 .79489 .42659 .79024 .41991 Metetra
.618 .718 .917 r
.79024 .41991 .79489 .42659 .80569 .42418 .80106 .4175 Metetra
.632 .725 .914 r
.80106 .4175 .80569 .42418 .81655 .42192 .8119 .41473 Metetra
.645 .714 .898 r
.8119 .41473 .81655 .42192 .82739 .41902 .82276 .41165 Metetra
.636 .705 .896 r
.82276 .41165 .82739 .41902 .83826 .41582 .83368 .40879 Metetra
.641 .719 .905 r
.83368 .40879 .83826 .41582 .84921 .41311 .84463 .40579 Metetra
.649 .714 .895 r
.84463 .40579 .84921 .41311 .86018 .41006 .85561 .40254 Metetra
.641 .704 .893 r
.85561 .40254 .86018 .41006 .87115 .4067 .86665 .39953 Metetra
.908 .792 .721 r
.86665 .39953 .87115 .4067 .88049 .38811 .87612 .38175 Metetra
.812 .334 0 r
.25012 .57122 .25599 .57634 .26376 .5872 .25776 .58365 Metetra
.66 .819 .96 r
.25776 .58365 .26376 .5872 .27266 .58407 .26668 .58058 Metetra
.666 .823 .959 r
.26668 .58058 .27266 .58407 .28158 .58115 .27564 .57739 Metetra
.648 .809 .961 r
.27564 .57739 .28158 .58115 .29054 .57801 .28461 .57456 Metetra
.667 .827 .96 r
.28461 .57456 .29054 .57801 .29954 .57474 .29363 .5713 Metetra
.678 .83 .956 r
.29363 .5713 .29954 .57474 .30856 .57169 .30269 .56782 Metetra
.649 .807 .959 r
.30269 .56782 .30856 .57169 .31762 .56833 .31174 .56495 Metetra
.681 .835 .957 r
.31174 .56495 .31762 .56833 .32672 .56465 .32086 .56138 Metetra
.697 .843 .953 r
.32086 .56138 .32672 .56465 .33586 .56085 .33003 .55746 Metetra
.703 .839 .948 r
.33003 .55746 .33586 .56085 .34499 .55766 .33924 .55341 Metetra
.655 .795 .949 r
.33924 .55341 .34499 .55766 .35424 .55273 .34841 .55044 Metetra
.736 .892 .95 r
.34841 .55044 .35424 .55273 .36348 .54847 .35771 .54549 Metetra
.742 .863 .937 r
.35771 .54549 .36348 .54847 .3727 .54509 .36703 .54047 Metetra
.666 .783 .936 r
.36703 .54047 .3727 .54509 .38215 .53706 .3763 .53727 Metetra
.817 .977 .893 r
.3763 .53727 .38215 .53706 .39153 .53065 .38578 .52944 Metetra
.841 .928 .888 r
.38578 .52944 .39153 .53065 .40205 .49396 .39529 .52124 Metetra
.39529 .52124 .40205 .49396 .41133 .48918 .40584 .48397 Metetra
.69 .766 .91 r
.40584 .48397 .41133 .48918 .41898 .53628 .41512 .48023 Metetra
.036 0 .475 r
.41512 .48023 .41898 .53628 .42785 .55219 .42296 .52467 Metetra
.344 .28 .641 r
.42296 .52467 .42785 .55219 .43748 .54355 .43201 .53627 Metetra
.692 .705 .857 r
.43201 .53627 .43748 .54355 .44706 .53753 .44156 .53209 Metetra
.934 .741 .618 r
.44156 .53209 .44706 .53753 .45663 .53285 .45191 .49305 Metetra
0 0 .325 r
.45191 .49305 .45663 .53285 .46685 .49211 .4604 .54225 Metetra
.369 .134 .421 r
.4604 .54225 .46685 .49211 .47606 .50837 .47032 .52379 Metetra
.861 .543 .448 r
.47032 .52379 .47606 .50837 .48475 .58068 .47924 .57523 Metetra
.865 .426 .025 r
.47924 .57523 .48475 .58068 .49439 .59798 .48884 .59581 Metetra
.116 .629 .893 r
.48884 .59581 .49439 .59798 .50429 .59818 .49877 .59689 Metetra
.216 .721 .901 r
.49877 .59689 .50429 .59818 .51424 .60107 .50876 .5965 Metetra
.714 .815 .928 r
.50876 .5965 .51424 .60107 .52426 .59692 .5188 .59185 Metetra
.443 .696 .973 r
.5188 .59185 .52426 .59692 .53431 .59366 .52888 .59207 Metetra
.618 .915 .98 r
.52888 .59207 .53431 .59366 .54441 .59218 .539 .58816 Metetra
.589 .805 .982 r
.539 .58816 .54441 .59218 .55454 .58991 .54917 .58587 Metetra
.582 .803 .984 r
.54917 .58587 .55454 .58991 .56469 .58531 .55937 .58368 Metetra
.708 .938 .961 r
.55937 .58368 .56469 .58531 .57491 .5835 .56958 .57833 Metetra
.576 .753 .961 r
.56958 .57833 .57491 .5835 .58515 .58059 .57987 .5766 Metetra
.736 .85 .934 r
.57987 .5766 .58515 .58059 .59535 .57337 .59014 .57123 Metetra
.66 .911 .979 r
.59014 .57123 .59535 .57337 .60563 .56923 .60045 .56689 Metetra
.841 .921 .886 r
.60045 .56689 .60563 .56923 .6159 .5637 .61068 .55803 Metetra
.708 .78 .908 r
.61068 .55803 .6159 .5637 .62556 .53686 .62103 .55335 Metetra
.833 .777 .272 r
.62103 .55335 .62556 .53686 .63342 .45903 .6302 .51035 Metetra
.745 .635 .072 r
.6302 .51035 .63342 .45903 .64289 .43742 .63673 .3974 Metetra
0 0 .319 r
.63673 .3974 .64289 .43742 .65424 .46562 .64925 .45973 Metetra
.475 .676 .953 r
.64925 .45973 .65424 .46562 .66472 .46771 .65966 .45992 Metetra
.864 .752 .737 r
.65966 .45992 .66472 .46771 .67542 .47299 .66945 .44452 Metetra
.851 .616 .583 r
.66945 .44452 .67542 .47299 .68488 .45117 .67751 .39349 Metetra
.566 .387 .598 r
.67751 .39349 .68488 .45117 .6926 .39751 .68779 .39172 Metetra
.883 .474 .043 r
.68779 .39172 .6926 .39751 .70294 .39635 .69995 .42383 Metetra
.552 .25 .409 r
.69995 .42383 .70294 .39635 .71526 .42805 .71068 .42627 Metetra
0 .546 .821 r
.71068 .42627 .71526 .42805 .72591 .42851 .72146 .42817 Metetra
.374 .839 .883 r
.72146 .42817 .72591 .42851 .73673 .43069 .732 .42534 Metetra
.535 .73 .964 r
.732 .42534 .73673 .43069 .7473 .42799 .74271 .4243 Metetra
.478 .78 .997 r
.74271 .4243 .7473 .42799 .75798 .42623 .75347 .42321 Metetra
.6 .866 .993 r
.75347 .42321 .75798 .42623 .76876 .42511 .76414 .42003 Metetra
.585 .767 .966 r
.76414 .42003 .76876 .42511 .77945 .42221 .77493 .41798 Metetra
.574 .802 .985 r
.77493 .41798 .77945 .42221 .79024 .41991 .78575 .41576 Metetra
.592 .814 .984 r
.78575 .41576 .79024 .41991 .80106 .4175 .7966 .4132 Metetra
.636 .825 .973 r
.7966 .4132 .80106 .4175 .8119 .41473 .80743 .40989 Metetra
.61 .792 .968 r
.80743 .40989 .8119 .41473 .82276 .41165 .81836 .40721 Metetra
.615 .813 .976 r
.81836 .40721 .82276 .41165 .83368 .40879 .82931 .40429 Metetra
.638 .82 .97 r
.82931 .40429 .83368 .40879 .84463 .40579 .84027 .40093 Metetra
.624 .799 .966 r
.84027 .40093 .84463 .40579 .85561 .40254 .8513 .39793 Metetra
.626 .812 .972 r
.8513 .39793 .85561 .40254 .86665 .39953 .86237 .39482 Metetra
.951 .848 .704 r
.86237 .39482 .86665 .39953 .87612 .38175 .87172 .37535 Metetra
.811 .333 0 r
.24422 .56608 .25012 .57122 .25776 .58365 .25185 .57848 Metetra
.668 .755 .916 r
.25185 .57848 .25776 .58365 .26668 .58058 .26079 .57538 Metetra
.662 .753 .918 r
.26079 .57538 .26668 .58058 .27564 .57739 .26975 .57241 Metetra
.677 .766 .918 r
.26975 .57241 .27564 .57739 .28461 .57456 .27877 .56907 Metetra
.663 .744 .911 r
.27877 .56907 .28461 .57456 .29363 .5713 .28779 .56607 Metetra
.667 .755 .916 r
.28779 .56607 .29363 .5713 .30269 .56782 .29684 .56295 Metetra
.688 .774 .917 r
.29684 .56295 .30269 .56782 .31174 .56495 .30596 .55932 Metetra
.668 .742 .906 r
.30596 .55932 .31174 .56495 .32086 .56138 .31508 .55615 Metetra
.691 .763 .907 r
.31508 .55615 .32086 .56138 .33003 .55746 .32426 .5524 Metetra
.692 .77 .911 r
.32426 .5524 .33003 .55746 .33924 .55341 .33347 .54862 Metetra
.699 .782 .916 r
.33347 .54862 .33924 .55341 .34841 .55044 .34271 .54467 Metetra
.692 .746 .892 r
.34271 .54467 .34841 .55044 .35771 .54549 .35198 .5408 Metetra
.722 .792 .907 r
.35198 .5408 .35771 .54549 .36703 .54047 .36131 .53621 Metetra
.738 .812 .91 r
.36131 .53621 .36703 .54047 .3763 .53727 .37068 .53118 Metetra
.716 .743 .873 r
.37068 .53118 .3763 .53727 .38578 .52944 .38005 .5265 Metetra
.839 .86 .859 r
.38005 .5265 .38578 .52944 .39529 .52124 .38961 .51779 Metetra
.79 .849 .895 r
.38961 .51779 .39529 .52124 .40584 .48397 .39909 .51119 Metetra
.39909 .51119 .40584 .48397 .41512 .48023 .40977 .4706 Metetra
.731 .662 .782 r
.40977 .4706 .41512 .48023 .42296 .52467 .41919 .46378 Metetra
.047 0 .472 r
.41919 .46378 .42296 .52467 .43201 .53627 .42703 .51126 Metetra
.738 .556 .647 r
.42703 .51126 .43201 .53627 .44156 .53209 .43692 .49302 Metetra
0 0 .346 r
.43692 .49302 .44156 .53209 .45191 .49305 .44524 .53905 Metetra
.631 .354 .48 r
.44524 .53905 .45191 .49305 .4604 .54225 .45452 .55405 Metetra
.952 .878 .474 r
.45452 .55405 .4604 .54225 .47032 .52379 .46483 .51927 Metetra
.95 .61 .335 r
.46483 .51927 .47032 .52379 .47924 .57523 .47368 .5712 Metetra
.872 .43 .074 r
.47368 .5712 .47924 .57523 .48884 .59581 .48328 .59122 Metetra
.421 .707 .982 r
.48328 .59122 .48884 .59581 .49877 .59689 .49323 .59142 Metetra
.583 .74 .951 r
.49323 .59142 .49877 .59689 .50876 .5965 .50324 .58971 Metetra
.633 .711 .903 r
.50324 .58971 .50876 .5965 .5188 .59185 .51331 .58712 Metetra
.505 .741 .979 r
.51331 .58712 .5188 .59185 .52888 .59207 .52341 .58634 Metetra
.651 .756 .926 r
.52341 .58634 .52888 .59207 .539 .58816 .53356 .58322 Metetra
.606 .773 .96 r
.53356 .58322 .539 .58816 .54917 .58587 .54374 .58091 Metetra
.642 .785 .95 r
.54374 .58091 .54917 .58587 .55937 .58368 .55397 .57788 Metetra
.672 .763 .919 r
.55397 .57788 .55937 .58368 .56958 .57833 .56422 .57423 Metetra
.733 .845 .933 r
.56422 .57423 .56958 .57833 .57987 .5766 .57449 .56895 Metetra
.658 .699 .876 r
.57449 .56895 .57987 .5766 .59014 .57123 .58481 .56557 Metetra
.663 .768 .927 r
.58481 .56557 .59014 .57123 .60045 .56689 .59517 .56209 Metetra
.81 .83 .866 r
.59517 .56209 .60045 .56689 .61068 .55803 .60546 .5538 Metetra
.724 .842 .937 r
.60546 .5538 .61068 .55803 .62103 .55335 .61583 .54871 Metetra
.947 .795 .66 r
.61583 .54871 .62103 .55335 .6302 .51035 .62559 .52232 Metetra
.995 .784 .421 r
.62559 .52232 .6302 .51035 .63673 .3974 .63347 .44262 Metetra
.311 .087 .404 r
.63347 .44262 .63673 .3974 .64925 .45973 .64298 .41978 Metetra
.402 .293 .615 r
.64298 .41978 .64925 .45973 .65966 .45992 .65387 .43411 Metetra
.864 .629 .582 r
.65387 .43411 .65966 .45992 .66945 .44452 .66207 .38206 Metetra
.547 .37 .593 r
.66207 .38206 .66945 .44452 .67751 .39349 .67244 .38323 Metetra
.839 .464 0 r
.67244 .38323 .67751 .39349 .68779 .39172 .68459 .4191 Metetra
.531 .231 .403 r
.68459 .4191 .68779 .39172 .69995 .42383 .69518 .41979 Metetra
.125 .553 .921 r
.69518 .41979 .69995 .42383 .71068 .42627 .70597 .42272 Metetra
.496 .795 .998 r
.70597 .42272 .71068 .42627 .72146 .42817 .71658 .42134 Metetra
.556 .683 .924 r
.71658 .42134 .72146 .42817 .732 .42534 .72726 .42035 Metetra
.553 .757 .972 r
.72726 .42035 .732 .42534 .74271 .4243 .73797 .41882 Metetra
.601 .757 .953 r
.73797 .41882 .74271 .4243 .75347 .42321 .74868 .41658 Metetra
.609 .717 .921 r
.74868 .41658 .75347 .42321 .76414 .42003 .75944 .41437 Metetra
.608 .754 .948 r
.75944 .41437 .76414 .42003 .77493 .41798 .77024 .412 Metetra
.613 .744 .939 r
.77024 .412 .77493 .41798 .78575 .41576 .78108 .40956 Metetra
.64 .748 .927 r
.78108 .40956 .78575 .41576 .7966 .4132 .79192 .40654 Metetra
.622 .724 .92 r
.79192 .40654 .7966 .4132 .80743 .40989 .80284 .40398 Metetra
.64 .761 .936 r
.80284 .40398 .80743 .40989 .81836 .40721 .81376 .40089 Metetra
.646 .749 .924 r
.81376 .40089 .81836 .40721 .82931 .40429 .82472 .39766 Metetra
.633 .733 .92 r
.82472 .39766 .82931 .40429 .84027 .40093 .83575 .39478 Metetra
.646 .757 .93 r
.83575 .39478 .84027 .40093 .8513 .39793 .84679 .39151 Metetra
.641 .745 .925 r
.84679 .39151 .8513 .39793 .86237 .39482 .85789 .38838 Metetra
.93 .81 .705 r
.85789 .38838 .86237 .39482 .87172 .37535 .86728 .36891 Metetra
.826 .355 0 r
.23828 .5609 .24422 .56608 .25185 .57848 .24585 .57386 Metetra
.653 .775 .938 r
.24585 .57386 .25185 .57848 .26079 .57538 .25479 .57104 Metetra
.671 .79 .938 r
.25479 .57104 .26079 .57538 .26975 .57241 .26379 .56781 Metetra
.668 .78 .933 r
.26379 .56781 .26975 .57241 .27877 .56907 .27281 .56465 Metetra
.667 .788 .939 r
.27281 .56465 .27877 .56907 .28779 .56607 .28186 .56149 Metetra
.669 .782 .934 r
.28186 .56149 .28779 .56607 .29684 .56295 .29095 .55828 Metetra
.676 .781 .929 r
.29095 .55828 .29684 .56295 .30596 .55932 .30007 .55493 Metetra
.697 .797 .927 r
.30007 .55493 .30596 .55932 .31508 .55615 .30925 .55105 Metetra
.657 .761 .927 r
.30925 .55105 .31508 .55615 .32426 .5524 .3184 .54809 Metetra
.69 .801 .934 r
.3184 .54809 .32426 .5524 .33347 .54862 .32763 .54436 Metetra
.722 .809 .918 r
.32763 .54436 .33347 .54862 .34271 .54467 .33693 .5398 Metetra
.689 .78 .92 r
.33693 .5398 .34271 .54467 .35198 .5408 .34621 .53608 Metetra
.687 .786 .926 r
.34621 .53608 .35198 .5408 .36131 .53621 .35552 .53239 Metetra
.778 .832 .894 r
.35552 .53239 .36131 .53621 .37068 .53118 .36497 .5261 Metetra
.749 .784 .881 r
.36497 .5261 .37068 .53118 .38005 .5265 .37441 .5205 Metetra
.674 .737 .898 r
.37441 .5205 .38005 .5265 .38961 .51779 .38378 .51708 Metetra
.9 .918 .824 r
.38378 .51708 .38961 .51779 .39909 .51119 .39349 .50555 Metetra
.829 .773 .798 r
.39349 .50555 .39909 .51119 .40977 .4706 .40315 .4952 Metetra
.40315 .4952 .40977 .4706 .41919 .46378 .41368 .45882 Metetra
.934 .745 .625 r
.41368 .45882 .41919 .46378 .42703 .51126 .42406 .42216 Metetra
0 0 .3 r
.42406 .42216 .42703 .51126 .43692 .49302 .43044 .5217 Metetra
.755 .452 .471 r
.43044 .5217 .43692 .49302 .44524 .53905 .43914 .55412 Metetra
.296 0 .207 r
.43914 .55412 .44524 .53905 .45452 .55405 .44895 .54769 Metetra
.926 .741 .634 r
.44895 .54769 .45452 .55405 .46483 .51927 .45933 .51342 Metetra
.955 .621 .336 r
.45933 .51342 .46483 .51927 .47368 .5712 .46803 .57009 Metetra
.842 .384 .114 r
.46803 .57009 .47368 .5712 .48328 .59122 .47767 .58642 Metetra
.622 .782 .958 r
.47767 .58642 .48328 .59122 .49323 .59142 .48767 .58382 Metetra
.34 .545 .907 r
.48767 .58382 .49323 .59142 .50324 .58971 .49767 .5866 Metetra
.693 .874 .966 r
.49767 .5866 .50324 .58971 .51331 .58712 .50777 .58218 Metetra
.552 .753 .971 r
.50777 .58218 .51331 .58712 .52341 .58634 .5179 .58077 Metetra
.58 .739 .951 r
.5179 .58077 .52341 .58634 .53356 .58322 .52807 .57906 Metetra
.591 .802 .98 r
.52807 .57906 .53356 .58322 .54374 .58091 .53829 .57674 Metetra
.67 .827 .959 r
.53829 .57674 .54374 .58091 .55397 .57788 .54854 .57297 Metetra
.703 .806 .929 r
.54854 .57297 .55397 .57788 .56422 .57423 .55881 .56847 Metetra
.633 .754 .935 r
.55881 .56847 .56422 .57423 .57449 .56895 .56914 .56571 Metetra
.815 .888 .896 r
.56914 .56571 .57449 .56895 .58481 .56557 .57942 .55777 Metetra
.552 .651 .9 r
.57942 .55777 .58481 .56557 .59517 .56209 .58986 .55708 Metetra
.701 .806 .93 r
.58986 .55708 .59517 .56209 .60546 .5538 .60026 .55258 Metetra
.862 .958 .868 r
.60026 .55258 .60546 .5538 .61583 .54871 .61055 .54265 Metetra
.934 .773 .658 r
.61055 .54265 .61583 .54871 .62559 .52232 .62036 .51562 Metetra
.962 .735 .55 r
.62036 .51562 .62559 .52232 .63347 .44262 .62905 .45711 Metetra
.23 0 .186 r
.62905 .45711 .63347 .44262 .64298 .41978 .63917 .44847 Metetra
.943 .751 .283 r
.63917 .44847 .64298 .41978 .65387 .43411 .64561 .34326 Metetra
.391 .243 .557 r
.64561 .34326 .65387 .43411 .66207 .38206 .65717 .37659 Metetra
.89 .48 .063 r
.65717 .37659 .66207 .38206 .67244 .38323 .66891 .40789 Metetra
.58 .264 .398 r
.66891 .40789 .67244 .38323 .68459 .4191 .67965 .41286 Metetra
.051 .406 .859 r
.67965 .41286 .68459 .4191 .69518 .41979 .69052 .41856 Metetra
.438 .858 .952 r
.69052 .41856 .69518 .41979 .70597 .42272 .70104 .41603 Metetra
.528 .675 .931 r
.70104 .41603 .70597 .42272 .71658 .42134 .71173 .41554 Metetra
.461 .678 .958 r
.71173 .41554 .71658 .42134 .72726 .42035 .72252 .41582 Metetra
.599 .797 .976 r
.72252 .41582 .72726 .42035 .73797 .41882 .73319 .41332 Metetra
.61 .761 .951 r
.73319 .41332 .73797 .41882 .74868 .41658 .74392 .41087 Metetra
.569 .736 .954 r
.74392 .41087 .74868 .41658 .75944 .41437 .75475 .40926 Metetra
.604 .777 .963 r
.75475 .40926 .75944 .41437 .77024 .412 .76558 .4068 Metetra
.645 .791 .952 r
.76558 .4068 .77024 .412 .78108 .40956 .77638 .4035 Metetra
.607 .741 .94 r
.77638 .4035 .78108 .40956 .79192 .40654 .78731 .40117 Metetra
.626 .778 .954 r
.78731 .40117 .79192 .40654 .80284 .40398 .79823 .39828 Metetra
.635 .769 .944 r
.79823 .39828 .80284 .40398 .81376 .40089 .80919 .39523 Metetra
.637 .772 .945 r
.80919 .39523 .81376 .40089 .82472 .39766 .8202 .39213 Metetra
.635 .777 .949 r
.8202 .39213 .82472 .39766 .83575 .39478 .83124 .38903 Metetra
.633 .769 .945 r
.83124 .38903 .83575 .39478 .84679 .39151 .84234 .38599 Metetra
.649 .786 .947 r
.84234 .38599 .84679 .39151 .85789 .38838 .85344 .38253 Metetra
.941 .822 .699 r
.85344 .38253 .85789 .38838 .86728 .36891 .86282 .36241 Metetra
.829 .359 0 r
.23231 .55569 .23828 .5609 .24585 .57386 .23985 .56876 Metetra
.668 .76 .919 r
.23985 .56876 .24585 .57386 .25479 .57104 .24884 .56562 Metetra
.662 .748 .914 r
.24884 .56562 .25479 .57104 .26379 .56781 .25783 .56262 Metetra
.664 .757 .919 r
.25783 .56262 .26379 .56781 .27281 .56465 .26687 .55954 Metetra
.675 .763 .918 r
.26687 .55954 .27281 .56465 .28186 .56149 .27595 .55621 Metetra
.679 .759 .912 r
.27595 .55621 .28186 .56149 .29095 .55828 .28507 .55276 Metetra
.676 .75 .907 r
.28507 .55276 .29095 .55828 .30007 .55493 .29421 .54938 Metetra
.668 .748 .91 r
.29421 .54938 .30007 .55493 .30925 .55105 .30337 .54617 Metetra
.692 .779 .918 r
.30337 .54617 .30925 .55105 .3184 .54809 .31259 .54239 Metetra
.69 .749 .896 r
.31259 .54239 .3184 .54809 .32763 .54436 .32184 .53856 Metetra
.673 .742 .902 r
.32184 .53856 .32763 .54436 .33693 .5398 .3311 .53518 Metetra
.719 .796 .912 r
.3311 .53518 .33693 .5398 .34621 .53608 .34044 .53066 Metetra
.736 .77 .88 r
.34044 .53066 .34621 .53608 .35552 .53239 .34985 .52543 Metetra
.702 .715 .858 r
.34985 .52543 .35552 .53239 .36497 .5261 .35923 .52096 Metetra
.722 .779 .898 r
.35923 .52096 .36497 .5261 .37441 .5205 .36866 .51623 Metetra
.824 .815 .841 r
.36866 .51623 .37441 .5205 .38378 .51708 .37828 .50747 Metetra
.728 .664 .787 r
.37828 .50747 .38378 .51708 .39349 .50555 .38782 .50081 Metetra
.804 .803 .85 r
.38782 .50081 .39349 .50555 .40315 .4952 .39742 .49293 Metetra
.952 .766 .614 r
.39742 .49293 .40315 .4952 .41368 .45882 .40815 .45319 Metetra
.781 .308 0 r
.40815 .45319 .41368 .45882 .42406 .42216 .41694 .4676 Metetra
.631 .353 .478 r
.41694 .4676 .42406 .42216 .43044 .5217 .42584 .48247 Metetra
0 0 .337 r
.42584 .48247 .43044 .5217 .43914 .55412 .43403 .52864 Metetra
.216 .203 .628 r
.43403 .52864 .43914 .55412 .44895 .54769 .44329 .54367 Metetra
.944 .764 .629 r
.44329 .54367 .44895 .54769 .45933 .51342 .45376 .50873 Metetra
.951 .612 .337 r
.45376 .50873 .45933 .51342 .46803 .57009 .46245 .562 Metetra
.773 .341 0 r
.46245 .562 .46803 .57009 .47767 .58642 .47204 .58089 Metetra
.541 .723 .958 r
.47204 .58089 .47767 .58642 .48767 .58382 .48204 .57987 Metetra
.45 .753 .994 r
.48204 .57987 .48767 .58382 .49767 .5866 .49209 .57932 Metetra
.633 .699 .893 r
.49209 .57932 .49767 .5866 .50777 .58218 .5022 .5767 Metetra
.525 .72 .962 r
.5022 .5767 .50777 .58218 .5179 .58077 .51235 .57588 Metetra
.647 .79 .951 r
.51235 .57588 .5179 .58077 .52807 .57906 .52254 .57272 Metetra
.584 .713 .932 r
.52254 .57272 .52807 .57906 .53829 .57674 .53278 .57109 Metetra
.676 .772 .923 r
.53278 .57109 .53829 .57674 .54854 .57297 .54306 .5673 Metetra
.698 .778 .913 r
.54306 .5673 .54854 .57297 .55881 .56847 .55336 .56289 Metetra
.705 .784 .913 r
.55336 .56289 .55881 .56847 .56914 .56571 .56369 .55827 Metetra
.696 .722 .869 r
.56369 .55827 .56914 .56571 .57942 .55777 .57406 .55365 Metetra
.583 .806 .984 r
.57406 .55365 .57942 .55777 .58986 .55708 .58449 .55133 Metetra
.775 .796 .87 r
.58449 .55133 .58986 .55708 .60026 .55258 .59486 .54419 Metetra
.731 .711 .831 r
.59486 .54419 .60026 .55258 .61055 .54265 .60527 .53784 Metetra
.946 .793 .66 r
.60527 .53784 .61055 .54265 .62036 .51562 .61516 .51132 Metetra
.974 .734 .511 r
.61516 .51132 .62036 .51562 .62905 .45711 .62331 .43129 Metetra
.765 .57 .634 r
.62331 .43129 .62905 .45711 .63917 .44847 .63293 .40834 Metetra
.69 .492 .614 r
.63293 .40834 .63917 .44847 .64561 .34326 .64259 .38896 Metetra
.361 .125 .416 r
.64259 .38896 .64561 .34326 .65717 .37659 .65221 .37043 Metetra
.9 .501 .081 r
.65221 .37043 .65717 .37659 .66891 .40789 .66407 .40512 Metetra
.039 .548 .875 r
.66407 .40512 .66891 .40789 .67965 .41286 .67472 .40753 Metetra
.415 .673 .968 r
.67472 .40753 .67965 .41286 .69052 .41856 .68536 .40819 Metetra
.422 .511 .845 r
.68536 .40819 .69052 .41856 .70104 .41603 .69618 .4111 Metetra
.543 .756 .975 r
.69618 .4111 .70104 .41603 .71173 .41554 .70684 .40968 Metetra
.574 .731 .949 r
.70684 .40968 .71173 .41554 .72252 .41582 .71754 .40802 Metetra
.56 .657 .901 r
.71754 .40802 .72252 .41582 .73319 .41332 .72834 .40708 Metetra
.578 .72 .94 r
.72834 .40708 .73319 .41332 .74392 .41087 .73915 .40542 Metetra
.628 .773 .95 r
.73915 .40542 .74392 .41087 .75475 .40926 .74992 .40254 Metetra
.615 .72 .921 r
.74992 .40254 .75475 .40926 .76558 .4068 .76077 .40013 Metetra
.617 .724 .922 r
.76077 .40013 .76558 .4068 .77638 .4035 .77167 .39765 Metetra
.637 .764 .939 r
.77167 .39765 .77638 .4035 .78731 .40117 .78257 .39458 Metetra
.633 .735 .922 r
.78257 .39458 .78731 .40117 .79823 .39828 .79352 .39168 Metetra
.63 .734 .923 r
.79352 .39168 .79823 .39828 .80919 .39523 .80453 .38884 Metetra
.634 .744 .928 r
.80453 .38884 .80919 .39523 .8202 .39213 .81558 .38587 Metetra
.643 .754 .929 r
.81558 .38587 .8202 .39213 .83124 .38903 .82664 .38264 Metetra
.647 .752 .926 r
.82664 .38264 .83124 .38903 .84234 .38599 .83775 .37932 Metetra
.641 .74 .921 r
.83775 .37932 .84234 .38599 .85344 .38253 .84891 .37615 Metetra
.936 .812 .698 r
.84891 .37615 .85344 .38253 .86282 .36241 .85833 .35588 Metetra
.809 .33 0 r
.22629 .55045 .23231 .55569 .23985 .56876 .23389 .5628 Metetra
.666 .73 .897 r
.23389 .5628 .23985 .56876 .24884 .56562 .24288 .55966 Metetra
.66 .729 .901 r
.24288 .55966 .24884 .56562 .25783 .56262 .2519 .55669 Metetra
.668 .733 .898 r
.2519 .55669 .25783 .56262 .26687 .55954 .26095 .55349 Metetra
.672 .73 .894 r
.26095 .55349 .26687 .55954 .27595 .55621 .27005 .55016 Metetra
.68 .733 .89 r
.27005 .55016 .27595 .55621 .28507 .55276 .27919 .54661 Metetra
.668 .727 .894 r
.27919 .54661 .28507 .55276 .29421 .54938 .28834 .54337 Metetra
.672 .734 .896 r
.28834 .54337 .29421 .54938 .30337 .54617 .29753 .54001 Metetra
.694 .735 .882 r
.29753 .54001 .30337 .54617 .31259 .54239 .30678 .53601 Metetra
.677 .724 .885 r
.30678 .53601 .31259 .54239 .32184 .53856 .31603 .53249 Metetra
.682 .736 .892 r
.31603 .53249 .32184 .53856 .3311 .53518 .32532 .52883 Metetra
.723 .738 .863 r
.32532 .52883 .3311 .53518 .34044 .53066 .33471 .52379 Metetra
.72 .723 .852 r
.33471 .52379 .34044 .53066 .34985 .52543 .34413 .51868 Metetra
.686 .718 .873 r
.34413 .51868 .34985 .52543 .35923 .52096 .35351 .5148 Metetra
.777 .755 .834 r
.35351 .5148 .35923 .52096 .36866 .51623 .36308 .50747 Metetra
.763 .692 .783 r
.36308 .50747 .36866 .51623 .37828 .50747 .3727 .49917 Metetra
.695 .68 .831 r
.3727 .49917 .37828 .50747 .38782 .50081 .38217 .49458 Metetra
.923 .734 .628 r
.38217 .49458 .38782 .50081 .39742 .49293 .39295 .45779 Metetra
0 0 .27 r
.39295 .45779 .39742 .49293 .40815 .45319 .40054 .50244 Metetra
.608 .334 .477 r
.40054 .50244 .40815 .45319 .41694 .4676 .40956 .51406 Metetra
.003 0 .267 r
.40956 .51406 .41694 .4676 .42584 .48247 .42028 .47615 Metetra
.74 .749 .86 r
.42028 .47615 .42584 .48247 .43403 .52864 .4299 .47044 Metetra
0 0 .45 r
.4299 .47044 .43403 .52864 .44329 .54367 .43811 .51989 Metetra
.74 .562 .653 r
.43811 .51989 .44329 .54367 .45376 .50873 .44819 .50239 Metetra
.954 .612 .312 r
.44819 .50239 .45376 .50873 .46245 .562 .45686 .55297 Metetra
.784 .368 0 r
.45686 .55297 .46245 .562 .47204 .58089 .46639 .57363 Metetra
.446 .616 .922 r
.46639 .57363 .47204 .58089 .48204 .57987 .47638 .57466 Metetra
.571 .751 .962 r
.47638 .57466 .48204 .57987 .49209 .57932 .48646 .57301 Metetra
.667 .743 .907 r
.48646 .57301 .49209 .57932 .5022 .5767 .4966 .56946 Metetra
.499 .644 .921 r
.4966 .56946 .5022 .5767 .51235 .57588 .50676 .56963 Metetra
.656 .743 .914 r
.50676 .56963 .51235 .57588 .52254 .57272 .51698 .56634 Metetra
.648 .737 .914 r
.51698 .56634 .52254 .57272 .53278 .57109 .52724 .56326 Metetra
.617 .68 .887 r
.52724 .56326 .53278 .57109 .54306 .5673 .53754 .56099 Metetra
.727 .765 .883 r
.53754 .56099 .54306 .5673 .55336 .56289 .54786 .55554 Metetra
.669 .715 .883 r
.54786 .55554 .55336 .56289 .56369 .55827 .55823 .5518 Metetra
.664 .742 .909 r
.55823 .5518 .56369 .55827 .57406 .55365 .56863 .54826 Metetra
.697 .792 .923 r
.56863 .54826 .57406 .55365 .58449 .55133 .57905 .54382 Metetra
.791 .749 .815 r
.57905 .54382 .58449 .55133 .59486 .54419 .58942 .53483 Metetra
.655 .659 .842 r
.58942 .53483 .59486 .54419 .60527 .53784 .59991 .53127 Metetra
.954 .747 .585 r
.59991 .53127 .60527 .53784 .61516 .51132 .6094 .48671 Metetra
.929 .668 .522 r
.6094 .48671 .61516 .51132 .62331 .43129 .61667 .373 Metetra
.318 .207 .567 r
.61667 .373 .62331 .43129 .63293 .40834 .62782 .40156 Metetra
.898 .5 .075 r
.62782 .40156 .63293 .40834 .64259 .38896 .63941 .43575 Metetra
.394 .151 .423 r
.63941 .43575 .64259 .38896 .65221 .37043 .64937 .42019 Metetra
0 0 .295 r
.64937 .42019 .65221 .37043 .66407 .40512 .6578 .36879 Metetra
.075 .074 .552 r
.6578 .36879 .66407 .40512 .67472 .40753 .66969 .40067 Metetra
.579 .695 .921 r
.66969 .40067 .67472 .40753 .68536 .40819 .68024 .39916 Metetra
.418 .544 .876 r
.68024 .39916 .68536 .40819 .69618 .4111 .69105 .40154 Metetra
.483 .567 .864 r
.69105 .40154 .69618 .4111 .70684 .40968 .70187 .40276 Metetra
.612 .71 .915 r
.70187 .40276 .70684 .40968 .71754 .40802 .71255 .40046 Metetra
.565 .668 .907 r
.71255 .40046 .71754 .40802 .72834 .40708 .72336 .39934 Metetra
.568 .664 .903 r
.72336 .39934 .72834 .40708 .73915 .40542 .73422 .39818 Metetra
.626 .708 .905 r
.73422 .39818 .73915 .40542 .74992 .40254 .74504 .39553 Metetra
.629 .718 .911 r
.74504 .39553 .74992 .40254 .76077 .40013 .75589 .39277 Metetra
.612 .699 .906 r
.75589 .39277 .76077 .40013 .77167 .39765 .76683 .39046 Metetra
.636 .717 .905 r
.76683 .39046 .77167 .39765 .78257 .39458 .77776 .3875 Metetra
.641 .723 .908 r
.77776 .3875 .78257 .39458 .79352 .39168 .78873 .3844 Metetra
.628 .712 .906 r
.78873 .3844 .79352 .39168 .80453 .38884 .79977 .38163 Metetra
.637 .719 .907 r
.79977 .38163 .80453 .38884 .81558 .38587 .81084 .37862 Metetra
.642 .72 .905 r
.81084 .37862 .81558 .38587 .82664 .38264 .82194 .37546 Metetra
.65 .727 .905 r
.82194 .37546 .82664 .38264 .83775 .37932 .83307 .37207 Metetra
.643 .722 .906 r
.83307 .37207 .83775 .37932 .84891 .37615 .84426 .36885 Metetra
.92 .794 .705 r
.84426 .36885 .84891 .37615 .85833 .35588 .8538 .3493 Metetra
.808 .328 0 r
.22024 .54517 .22629 .55045 .23389 .5628 .22783 .55748 Metetra
.655 .751 .921 r
.22783 .55748 .23389 .5628 .24288 .55966 .23682 .5546 Metetra
.673 .766 .92 r
.23682 .5546 .24288 .55966 .2519 .55669 .24588 .55129 Metetra
.67 .753 .913 r
.24588 .55129 .2519 .55669 .26095 .55349 .25496 .54804 Metetra
.675 .753 .91 r
.25496 .54804 .26095 .55349 .27005 .55016 .26407 .54465 Metetra
.666 .75 .913 r
.26407 .54465 .27005 .55016 .27919 .54661 .27321 .54149 Metetra
.678 .768 .918 r
.27321 .54149 .27919 .54661 .28834 .54337 .28239 .53802 Metetra
.701 .765 .901 r
.28239 .53802 .28834 .54337 .29753 .54001 .29164 .53392 Metetra
.658 .729 .902 r
.29164 .53392 .29753 .54001 .30678 .53601 .30085 .53091 Metetra
.695 .774 .913 r
.30085 .53091 .30678 .53601 .31603 .53249 .31015 .52699 Metetra
.73 .767 .882 r
.31015 .52699 .31603 .53249 .32532 .52883 .31954 .52193 Metetra
.7 .717 .862 r
.31954 .52193 .32532 .52883 .33471 .52379 .32892 .51754 Metetra
.674 .731 .892 r
.32892 .51754 .33471 .52379 .34413 .51868 .33826 .51405 Metetra
.81 .804 .845 r
.33826 .51405 .34413 .51868 .35351 .5148 .34789 .50585 Metetra
.743 .682 .792 r
.34789 .50585 .35351 .5148 .36308 .50747 .35747 .49869 Metetra
.662 .657 .835 r
.35747 .49869 .36308 .50747 .3727 .49917 .36689 .49521 Metetra
.938 .752 .624 r
.36689 .49521 .3727 .49917 .38217 .49458 .37788 .45723 Metetra
0 0 .248 r
.37788 .45723 .38217 .49458 .39295 .45779 .38511 .50473 Metetra
.634 .355 .478 r
.38511 .50473 .39295 .45779 .40054 .50244 .3939 .52073 Metetra
.254 0 .222 r
.3939 .52073 .40054 .50244 .40956 .51406 .40373 .51191 Metetra
.772 .912 .935 r
.40373 .51191 .40956 .51406 .42028 .47615 .41348 .50574 Metetra
.41348 .50574 .42028 .47615 .4299 .47044 .42423 .46722 Metetra
.782 .869 .912 r
.42423 .46722 .4299 .47044 .43811 .51989 .43392 .46079 Metetra
.43 .282 .578 r
.43392 .46079 .43811 .51989 .44819 .50239 .44309 .47602 Metetra
.932 .643 .172 r
.44309 .47602 .44819 .50239 .45686 .55297 .45113 .54902 Metetra
.844 .381 .015 r
.45113 .54902 .45686 .55297 .46639 .57363 .46072 .56644 Metetra
.499 .645 .922 r
.46072 .56644 .46639 .57363 .47638 .57466 .47073 .56655 Metetra
.346 .536 .898 r
.47073 .56655 .47638 .57466 .48646 .57301 .48077 .56939 Metetra
.74 .863 .938 r
.48077 .56939 .48646 .57301 .4966 .56946 .49096 .5639 Metetra
.563 .736 .957 r
.49096 .5639 .4966 .56946 .50676 .56963 .50115 .56243 Metetra
.617 .699 .903 r
.50115 .56243 .50676 .56963 .51698 .56634 .51138 .56013 Metetra
.616 .733 .929 r
.51138 .56013 .51698 .56634 .52724 .56326 .52167 .55774 Metetra
.709 .788 .913 r
.52167 .55774 .52724 .56326 .53754 .56099 .53198 .553 Metetra
.647 .689 .876 r
.53198 .553 .53754 .56099 .54786 .55554 .54234 .54987 Metetra
.581 .742 .953 r
.54234 .54987 .54786 .55554 .55823 .5518 .55275 .54805 Metetra
.814 .871 .888 r
.55275 .54805 .55823 .5518 .56863 .54826 .56313 .53994 Metetra
.659 .687 .865 r
.56313 .53994 .56863 .54826 .57905 .54382 .57359 .53638 Metetra
.724 .734 .86 r
.57359 .53638 .57905 .54382 .58942 .53483 .58405 .53069 Metetra
.952 .801 .656 r
.58405 .53069 .58942 .53483 .59991 .53127 .59408 .50345 Metetra
.893 .645 .556 r
.59408 .50345 .59991 .53127 .6094 .48671 .60279 .42583 Metetra
.766 .528 .575 r
.60279 .42583 .6094 .48671 .61667 .373 .61164 .3693 Metetra
.95 .599 .281 r
.61164 .3693 .61667 .373 .62782 .40156 .62379 .43115 Metetra
.542 .241 .407 r
.62379 .43115 .62782 .40156 .63941 .43575 .63438 .43317 Metetra
0 .276 .652 r
.63438 .43317 .63941 .43575 .64937 .42019 .64516 .43841 Metetra
0 0 .081 r
.64516 .43841 .64937 .42019 .6578 .36879 .65494 .41626 Metetra
0 0 .259 r
.65494 .41626 .6578 .36879 .66969 .40067 .66324 .36197 Metetra
.099 .085 .553 r
.66324 .36197 .66969 .40067 .68024 .39916 .67531 .39458 Metetra
.604 .799 .974 r
.67531 .39458 .68024 .39916 .69105 .40154 .68589 .39197 Metetra
.492 .573 .865 r
.68589 .39197 .69105 .40154 .70187 .40276 .69671 .39296 Metetra
.445 .542 .861 r
.69671 .39296 .70187 .40276 .71255 .40046 .70766 .39506 Metetra
.624 .775 .953 r
.70766 .39506 .71255 .40046 .72336 .39934 .71839 .39223 Metetra
.593 .698 .916 r
.71839 .39223 .72336 .39934 .73422 .39818 .72923 .39034 Metetra
.57 .664 .902 r
.72923 .39034 .73422 .39818 .74504 .39553 .74017 .38911 Metetra
.61 .732 .932 r
.74017 .38911 .74504 .39553 .75589 .39277 .75108 .38671 Metetra
.65 .763 .932 r
.75108 .38671 .75589 .39277 .76683 .39046 .76196 .38334 Metetra
.606 .707 .916 r
.76196 .38334 .76683 .39046 .77776 .3875 .77298 .3811 Metetra
.63 .744 .93 r
.77298 .3811 .77776 .3875 .78873 .3844 .784 .3782 Metetra
.642 .757 .932 r
.784 .3782 .78873 .3844 .79977 .38163 .79503 .37498 Metetra
.634 .738 .923 r
.79503 .37498 .79977 .38163 .81084 .37862 .80613 .37198 Metetra
.639 .742 .923 r
.80613 .37198 .81084 .37862 .82194 .37546 .81727 .36884 Metetra
.636 .742 .925 r
.81727 .36884 .82194 .37546 .83307 .37207 .82846 .36575 Metetra
.653 .761 .929 r
.82846 .36575 .83307 .37207 .84426 .36885 .83965 .36222 Metetra
.929 .809 .706 r
.83965 .36222 .84426 .36885 .8538 .3493 .84924 .34267 Metetra
.756 .258 0 r
.21415 .53986 .22024 .54517 .22783 .55748 .22185 .55075 Metetra
.667 .708 .878 r
.22185 .55075 .22783 .55748 .23682 .5546 .23089 .54749 Metetra
.661 .695 .871 r
.23089 .54749 .23682 .5546 .24588 .55129 .23994 .54436 Metetra
.675 .705 .87 r
.23994 .54436 .24588 .55129 .25496 .54804 .24906 .54083 Metetra
.657 .692 .871 r
.24906 .54083 .25496 .54804 .26407 .54465 .25817 .53777 Metetra
.668 .706 .876 r
.25817 .53777 .26407 .54465 .27321 .54149 .26732 .53443 Metetra
.687 .707 .863 r
.26732 .53443 .27321 .54149 .28239 .53802 .27656 .53047 Metetra
.66 .685 .863 r
.27656 .53047 .28239 .53802 .29164 .53392 .28576 .52728 Metetra
.688 .721 .874 r
.28576 .52728 .29164 .53392 .30085 .53091 .29505 .52334 Metetra
.703 .699 .844 r
.29505 .52334 .30085 .53091 .31015 .52699 .30441 .5187 Metetra
.694 .679 .831 r
.30441 .5187 .31015 .52699 .31954 .52193 .31378 .51417 Metetra
.673 .686 .854 r
.31378 .51417 .31954 .52193 .32892 .51754 .32313 .51052 Metetra
.766 .73 .82 r
.32313 .51052 .32892 .51754 .33826 .51405 .33271 .50323 Metetra
.723 .643 .769 r
.33271 .50323 .33826 .51405 .34789 .50585 .34229 .49624 Metetra
.672 .644 .814 r
.34229 .49624 .34789 .50585 .35747 .49869 .35172 .49221 Metetra
.92 .73 .629 r
.35172 .49221 .35747 .49869 .36689 .49521 .36282 .45501 Metetra
0 0 .255 r
.36282 .45501 .36689 .49521 .37788 .45723 .36973 .50421 Metetra
.624 .346 .475 r
.36973 .50421 .37788 .45723 .38511 .50473 .3785 .51849 Metetra
.314 0 .181 r
.3785 .51849 .38511 .50473 .3939 .52073 .38818 .51357 Metetra
.655 .703 .883 r
.38818 .51357 .3939 .52073 .40373 .51191 .39782 .51046 Metetra
.759 .938 .943 r
.39782 .51046 .40373 .51191 .41348 .50574 .4076 .50439 Metetra
.883 .917 .844 r
.4076 .50439 .41348 .50574 .42423 .46722 .41755 .4937 Metetra
.41755 .4937 .42423 .46722 .43392 .46079 .42839 .4524 Metetra
.912 .721 .631 r
.42839 .4524 .43392 .46079 .44309 .47602 .43886 .4177 Metetra
.742 .559 0 r
.43886 .4177 .44309 .47602 .45113 .54902 .44592 .52133 Metetra
0 0 .298 r
.44592 .52133 .45113 .54902 .46072 .56644 .455 .55918 Metetra
.548 .667 .915 r
.455 .55918 .46072 .56644 .47073 .56655 .46505 .5584 Metetra
.458 .596 .902 r
.46505 .5584 .47073 .56655 .48077 .56939 .47512 .55949 Metetra
.598 .619 .844 r
.47512 .55949 .48077 .56939 .49096 .5639 .48528 .55779 Metetra
.66 .751 .918 r
.48528 .55779 .49096 .5639 .50115 .56243 .4955 .55437 Metetra
.647 .686 .873 r
.4955 .55437 .50115 .56243 .51138 .56013 .50576 .55125 Metetra
.621 .655 .862 r
.50576 .55125 .51138 .56013 .52167 .55774 .51606 .54884 Metetra
.648 .666 .854 r
.51606 .54884 .52167 .55774 .53198 .553 .5264 .54559 Metetra
.63 .701 .897 r
.5264 .54559 .53198 .553 .54234 .54987 .53678 .54293 Metetra
.708 .743 .879 r
.53678 .54293 .54234 .54987 .55275 .54805 .54718 .53798 Metetra
.717 .671 .804 r
.54718 .53798 .55275 .54805 .56313 .53994 .5576 .53157 Metetra
.63 .675 .874 r
.5576 .53157 .56313 .53994 .57359 .53638 .56809 .52887 Metetra
.918 .754 .662 r
.56809 .52887 .57359 .53638 .58405 .53069 .57824 .50219 Metetra
.867 .629 .576 r
.57824 .50219 .58405 .53069 .59408 .50345 .58763 .4418 Metetra
.669 .458 .589 r
.58763 .4418 .59408 .50345 .60279 .42583 .59749 .41704 Metetra
.892 .737 .683 r
.59749 .41704 .60279 .42583 .61164 .3693 .60733 .39508 Metetra
.774 .446 .433 r
.60733 .39508 .61164 .3693 .62379 .43115 .6187 .42939 Metetra
0 .533 .803 r
.6187 .42939 .62379 .43115 .63438 .43317 .62932 .43128 Metetra
.287 .753 .945 r
.62932 .43128 .63438 .43317 .64516 .43841 .63993 .43068 Metetra
.551 .657 .906 r
.63993 .43068 .64516 .43841 .65494 .41626 .65059 .42986 Metetra
.65059 .42986 .65494 .41626 .66324 .36197 .66048 .40954 Metetra
0 0 .245 r
.66048 .40954 .66324 .36197 .67531 .39458 .66866 .35286 Metetra
.151 .116 .56 r
.66866 .35286 .67531 .39458 .68589 .39197 .68082 .38475 Metetra
.611 .701 .908 r
.68082 .38475 .68589 .39197 .69671 .39296 .69149 .38247 Metetra
.507 .561 .845 r
.69149 .38247 .69671 .39296 .70766 .39506 .70238 .38328 Metetra
.508 .536 .82 r
.70238 .38328 .70766 .39506 .71839 .39223 .71335 .38431 Metetra
.627 .689 .889 r
.71335 .38431 .71839 .39223 .72923 .39034 .72416 .38162 Metetra
.596 .653 .876 r
.72416 .38162 .72923 .39034 .74017 .38911 .73507 .37978 Metetra
.592 .636 .863 r
.73507 .37978 .74017 .38911 .75108 .38671 .74605 .37809 Metetra
.618 .667 .875 r
.74605 .37809 .75108 .38671 .76196 .38334 .75703 .37563 Metetra
.644 .706 .892 r
.75703 .37563 .76196 .38334 .77298 .3811 .76799 .3724 Metetra
.616 .666 .875 r
.76799 .3724 .77298 .3811 .784 .3782 .77907 .36996 Metetra
.638 .69 .882 r
.77907 .36996 .784 .3782 .79503 .37498 .79014 .36688 Metetra
.648 .699 .883 r
.79014 .36688 .79503 .37498 .80613 .37198 .80123 .36348 Metetra
.63 .68 .879 r
.80123 .36348 .80613 .37198 .81727 .36884 .81242 .36059 Metetra
.645 .695 .882 r
.81242 .36059 .81727 .36884 .82846 .36575 .82361 .35727 Metetra
.639 .686 .878 r
.82361 .35727 .82846 .36575 .83965 .36222 .83486 .35409 Metetra
.9 .779 .718 r
.83486 .35409 .83965 .36222 .84924 .34267 .84465 .33599 Metetra
.791 .305 0 r
.20802 .53452 .21415 .53986 .22185 .55075 .21563 .54633 Metetra
.667 .791 .941 r
.21563 .54633 .22185 .55075 .23089 .54749 .22468 .5431 Metetra
.677 .795 .937 r
.22468 .5431 .23089 .54749 .23994 .54436 .23378 .53964 Metetra
.654 .778 .94 r
.23378 .53964 .23994 .54436 .24906 .54083 .24287 .53668 Metetra
.675 .806 .945 r
.24287 .53668 .24906 .54083 .25817 .53777 .25203 .53323 Metetra
.695 .794 .927 r
.25203 .53323 .25817 .53777 .26732 .53443 .26125 .52934 Metetra
.656 .766 .93 r
.26125 .52934 .26732 .53443 .27656 .53047 .27044 .52633 Metetra
.692 .812 .939 r
.27044 .52633 .27656 .53047 .28576 .52728 .27971 .52246 Metetra
.724 .791 .905 r
.27971 .52246 .28576 .52728 .29505 .52334 .28908 .51772 Metetra
.716 .762 .889 r
.28908 .51772 .29505 .52334 .30441 .5187 .29846 .51308 Metetra
.66 .75 .917 r
.29846 .51308 .30441 .5187 .31378 .51417 .30776 .50997 Metetra
.803 .819 .864 r
.30776 .50997 .31378 .51417 .32313 .51052 .31737 .5024 Metetra
.748 .702 .808 r
.31737 .5024 .32313 .51052 .33271 .50323 .32696 .49544 Metetra
.662 .683 .86 r
.32696 .49544 .33271 .50323 .34229 .49624 .33634 .4921 Metetra
.934 .751 .63 r
.33634 .4921 .34229 .49624 .35172 .49221 .34757 .4553 Metetra
0 0 .197 r
.34757 .4553 .35172 .49221 .36282 .45501 .35427 .50373 Metetra
.629 .351 .478 r
.35427 .50373 .36282 .45501 .36973 .50421 .36289 .51943 Metetra
.374 .02 .231 r
.36289 .51943 .36973 .50421 .3785 .51849 .37253 .51557 Metetra
.664 .868 .976 r
.37253 .51557 .3785 .51849 .38818 .51357 .3822 .51182 Metetra
.605 .899 .987 r
.3822 .51182 .38818 .51357 .39782 .51046 .39188 .50839 Metetra
.678 .907 .975 r
.39188 .50839 .39782 .51046 .4076 .50439 .40164 .50405 Metetra
.913 .93 .809 r
.40164 .50405 .4076 .50439 .41755 .4937 .4117 .49135 Metetra
.834 .901 .886 r
.4117 .49135 .41755 .4937 .42839 .4524 .42161 .48297 Metetra
.91 .794 .315 r
.42161 .48297 .42839 .4524 .43886 .4177 .43327 .41281 Metetra
.95 .607 .327 r
.43327 .41281 .43886 .4177 .44592 .52133 .44154 .46231 Metetra
0 0 .279 r
.44154 .46231 .44592 .52133 .455 .55918 .44964 .53474 Metetra
.042 .093 .589 r
.44964 .53474 .455 .55918 .46505 .5584 .45926 .55389 Metetra
.463 .739 .988 r
.45926 .55389 .46505 .5584 .47512 .55949 .46938 .55337 Metetra
.661 .752 .918 r
.46938 .55337 .47512 .55949 .48528 .55779 .47958 .54993 Metetra
.443 .6 .912 r
.47958 .54993 .48528 .55779 .4955 .55437 .48978 .55113 Metetra
.758 .884 .936 r
.48978 .55113 .4955 .55437 .50576 .55125 .50009 .54505 Metetra
.616 .736 .932 r
.50009 .54505 .50576 .55125 .51606 .54884 .51041 .54262 Metetra
.5 .688 .951 r
.51041 .54262 .51606 .54884 .5264 .54559 .52077 .54229 Metetra
.774 .887 .926 r
.52077 .54229 .5264 .54559 .53678 .54293 .53118 .53568 Metetra
.698 .732 .877 r
.53118 .53568 .53678 .54293 .54718 .53798 .54161 .53098 Metetra
.68 .735 .892 r
.54161 .53098 .54718 .53798 .5576 .53157 .55207 .52687 Metetra
.935 .803 .69 r
.55207 .52687 .5576 .53157 .56809 .52887 .56236 .50395 Metetra
.883 .645 .573 r
.56236 .50395 .56809 .52887 .57824 .50219 .572 .4416 Metetra
.576 .39 .592 r
.572 .4416 .57824 .50219 .58763 .4418 .58231 .43676 Metetra
.567 .06 0 r
.58231 .43676 .58763 .4418 .59749 .41704 .59299 .44824 Metetra
.59299 .44824 .59749 .41704 .60733 .39508 .60219 .39224 Metetra
.921 .527 .196 r
.60219 .39224 .60733 .39508 .6187 .42939 .6136 .42866 Metetra
.072 .63 .798 r
.6136 .42866 .6187 .42939 .62932 .43128 .6242 .42876 Metetra
.31 .746 .968 r
.6242 .42876 .62932 .43128 .63993 .43068 .63486 .42846 Metetra
.463 .84 .988 r
.63486 .42846 .63993 .43068 .65059 .42986 .6455 .42641 Metetra
.509 .812 1 r
.6455 .42641 .65059 .42986 .66048 .40954 .65621 .42463 Metetra
.65621 .42463 .66048 .40954 .66866 .35286 .66607 .40226 Metetra
0 0 .266 r
.66607 .40226 .66866 .35286 .68082 .38475 .67426 .3463 Metetra
.117 .099 .56 r
.67426 .3463 .68082 .38475 .69149 .38247 .68654 .37761 Metetra
.625 .799 .966 r
.68654 .37761 .69149 .38247 .70238 .38328 .69725 .37461 Metetra
.491 .601 .89 r
.69725 .37461 .70238 .38328 .71335 .38431 .70821 .37526 Metetra
.466 .577 .882 r
.70821 .37526 .71335 .38431 .72416 .38162 .71929 .37657 Metetra
.641 .801 .96 r
.71929 .37657 .72416 .38162 .73507 .37978 .73013 .37323 Metetra
.578 .716 .937 r
.73013 .37323 .73507 .37978 .74605 .37809 .74114 .37148 Metetra
.574 .713 .937 r
.74114 .37148 .74605 .37809 .75703 .37563 .7522 .36981 Metetra
.608 .76 .951 r
.7522 .36981 .75703 .37563 .76799 .3724 .76325 .36725 Metetra
.645 .802 .958 r
.76325 .36725 .76799 .3724 .77907 .36996 .77428 .36377 Metetra
.61 .747 .942 r
.77428 .36377 .77907 .36996 .79014 .36688 .78543 .36122 Metetra
.626 .776 .952 r
.78543 .36122 .79014 .36688 .80123 .36348 .79659 .35819 Metetra
.646 .8 .957 r
.79659 .35819 .80123 .36348 .81242 .36059 .80775 .35466 Metetra
.627 .767 .947 r
.80775 .35466 .81242 .36059 .82361 .35727 .819 .35164 Metetra
.634 .783 .953 r
.819 .35164 .82361 .35727 .83486 .35409 .83028 .34838 Metetra
.939 .833 .714 r
.83028 .34838 .83486 .35409 .84465 .33599 .84003 .32927 Metetra
.665 .149 0 r
.20185 .52914 .20802 .53452 .21563 .54633 .20969 .53837 Metetra
.667 .675 .849 r
.20969 .53837 .21563 .54633 .22468 .5431 .21877 .53493 Metetra
.653 .666 .85 r
.21877 .53493 .22468 .5431 .23378 .53964 .22785 .53189 Metetra
.666 .682 .855 r
.22785 .53189 .23378 .53964 .24287 .53668 .23699 .52848 Metetra
.674 .674 .841 r
.23699 .52848 .24287 .53668 .25203 .53323 .24618 .52471 Metetra
.654 .659 .843 r
.24618 .52471 .25203 .53323 .26125 .52934 .25536 .52155 Metetra
.676 .686 .852 r
.25536 .52155 .26125 .52934 .27044 .52633 .26461 .51781 Metetra
.694 .675 .827 r
.26461 .51781 .27044 .52633 .27971 .52246 .27395 .51319 Metetra
.686 .656 .815 r
.27395 .51319 .27971 .52246 .28908 .51772 .28331 .5087 Metetra
.655 .65 .833 r
.28331 .5087 .28908 .51772 .29846 .51308 .29261 .5054 Metetra
.763 .715 .807 r
.29261 .5054 .29846 .51308 .30776 .50997 .30222 .49785 Metetra
.705 .618 .757 r
.30222 .49785 .30776 .50997 .31737 .5024 .31178 .49129 Metetra
.648 .607 .794 r
.31178 .49129 .31737 .5024 .32696 .49544 .32115 .48786 Metetra
.911 .72 .632 r
.32115 .48786 .32696 .49544 .33634 .4921 .33253 .45089 Metetra
0 0 .24 r
.33253 .45089 .33634 .4921 .34757 .4553 .33892 .50031 Metetra
.635 .353 .473 r
.33892 .50031 .34757 .4553 .35427 .50373 .34742 .51616 Metetra
.309 0 .145 r
.34742 .51616 .35427 .50373 .36289 .51943 .35707 .51193 Metetra
.648 .692 .878 r
.35707 .51193 .36289 .51943 .37253 .51557 .36669 .50894 Metetra
.568 .691 .924 r
.36669 .50894 .37253 .51557 .3822 .51182 .37626 .50771 Metetra
.77 .835 .902 r
.37626 .50771 .3822 .51182 .39188 .50839 .38609 .50145 Metetra
.756 .741 .839 r
.38609 .50145 .39188 .50839 .40164 .50405 .39596 .49469 Metetra
.713 .673 .809 r
.39596 .49469 .40164 .50405 .4117 .49135 .40581 .48886 Metetra
.876 .882 .835 r
.40581 .48886 .4117 .49135 .42161 .48297 .41584 .478 Metetra
.942 .749 .613 r
.41584 .478 .42161 .48297 .43327 .41281 .42675 .43764 Metetra
.69 .372 .432 r
.42675 .43764 .43327 .41281 .44154 .46231 .43592 .45467 Metetra
.738 .293 0 r
.43592 .45467 .44154 .46231 .44964 .53474 .44525 .47122 Metetra
0 0 .446 r
.44525 .47122 .44964 .53474 .45926 .55389 .45395 .52484 Metetra
.141 .138 .593 r
.45395 .52484 .45926 .55389 .46938 .55337 .46365 .54429 Metetra
.676 .673 .84 r
.46365 .54429 .46938 .55337 .47958 .54993 .47389 .54004 Metetra
.59 .618 .848 r
.47389 .54004 .47958 .54993 .48978 .55113 .48412 .53848 Metetra
.564 .553 .8 r
.48412 .53848 .48978 .55113 .50009 .54505 .49439 .53782 Metetra
.62 .704 .905 r
.49439 .53782 .50009 .54505 .51041 .54262 .50473 .53536 Metetra
.728 .741 .862 r
.50473 .53536 .51041 .54262 .52077 .54229 .51512 .52956 Metetra
.647 .596 .783 r
.51512 .52956 .52077 .54229 .53118 .53568 .52554 .52566 Metetra
.641 .641 .835 r
.52554 .52566 .53118 .53568 .54161 .53098 .53599 .52244 Metetra
.904 .74 .668 r
.53599 .52244 .54161 .53098 .55207 .52687 .54634 .4967 Metetra
.854 .619 .581 r
.54634 .4967 .55207 .52687 .56236 .50395 .55628 .43949 Metetra
.579 .389 .588 r
.55628 .43949 .56236 .50395 .572 .4416 .56658 .43367 Metetra
.871 .467 .012 r
.56658 .43367 .572 .4416 .58231 .43676 .57746 .46319 Metetra
.104 0 .245 r
.57746 .46319 .58231 .43676 .59299 .44824 .58764 .44295 Metetra
.967 .749 .555 r
.58764 .44295 .59299 .44824 .60219 .39224 .597 .38925 Metetra
.901 .485 .139 r
.597 .38925 .60219 .39224 .6136 .42866 .60821 .41877 Metetra
.417 .527 .862 r
.60821 .41877 .6136 .42866 .6242 .42876 .61889 .42128 Metetra
.349 .562 .916 r
.61889 .42128 .6242 .42876 .63486 .42846 .62965 .42382 Metetra
.7 .832 .946 r
.62965 .42382 .63486 .42846 .6455 .42641 .64024 .41916 Metetra
.627 .711 .907 r
.64024 .41916 .6455 .42641 .65621 .42463 .65093 .41644 Metetra
.599 .671 .89 r
.65093 .41644 .65621 .42463 .66607 .40226 .6617 .41447 Metetra
.6617 .41447 .66607 .40226 .67426 .3463 .67159 .39194 Metetra
0 0 .223 r
.67159 .39194 .67426 .3463 .68654 .37761 .67968 .33463 Metetra
.169 .126 .563 r
.67968 .33463 .68654 .37761 .69725 .37461 .6921 .36615 Metetra
.638 .68 .874 r
.6921 .36615 .69725 .37461 .70821 .37526 .70288 .36311 Metetra
.535 .547 .814 r
.70288 .36311 .70821 .37526 .71929 .37657 .71389 .36332 Metetra
.508 .514 .797 r
.71389 .36332 .71929 .37657 .73013 .37323 .72503 .36452 Metetra
.64 .678 .869 r
.72503 .36452 .73013 .37323 .74114 .37148 .73595 .36133 Metetra
.6 .623 .847 r
.73595 .36133 .74114 .37148 .7522 .36981 .74701 .35935 Metetra
.595 .615 .841 r
.74701 .35935 .7522 .36981 .76325 .36725 .75813 .35752 Metetra
.624 .646 .852 r
.75813 .35752 .76325 .36725 .77428 .36377 .76923 .35475 Metetra
.644 .674 .864 r
.76923 .35475 .77428 .36377 .78543 .36122 .78034 .35139 Metetra
.623 .645 .851 r
.78034 .35139 .78543 .36122 .79659 .35819 .79154 .34865 Metetra
.634 .658 .855 r
.79154 .34865 .79659 .35819 .80775 .35466 .80277 .34553 Metetra
.647 .675 .862 r
.80277 .34553 .80775 .35466 .819 .35164 .814 .34202 Metetra
.632 .656 .856 r
.814 .34202 .819 .35164 .83028 .34838 .82532 .33894 Metetra
.87 .751 .729 r
.82532 .33894 .83028 .34838 .84003 .32927 .83537 .32249 Metetra
.497 0 0 r
.19564 .52373 .20185 .52914 .20969 .53837 .20366 .53102 Metetra
.653 .688 .871 r
.20366 .53102 .20969 .53837 .21877 .53493 .21271 .52806 Metetra
.669 .708 .877 r
.21271 .52806 .21877 .53493 .22785 .53189 .22183 .52469 Metetra
.683 .703 .862 r
.22183 .52469 .22785 .53189 .23699 .52848 .23102 .52082 Metetra
.655 .682 .864 r
.23102 .52082 .23699 .52848 .24618 .52471 .24017 .51774 Metetra
.677 .709 .872 r
.24017 .51774 .24618 .52471 .25536 .52155 .2494 .51408 Metetra
.705 .704 .846 r
.2494 .51408 .25536 .52155 .26461 .51781 .25874 .50936 Metetra
.69 .676 .831 r
.25874 .50936 .26461 .51781 .27395 .51319 .26808 .50493 Metetra
.652 .667 .852 r
.26808 .50493 .27395 .51319 .28331 .5087 .27735 .50183 Metetra
.771 .736 .821 r
.27735 .50183 .28331 .5087 .29261 .5054 .28697 .49434 Metetra
.714 .637 .77 r
.28697 .49434 .29261 .5054 .30222 .49785 .29653 .48771 Metetra
.656 .628 .811 r
.29653 .48771 .30222 .49785 .31178 .49129 .3059 .48416 Metetra
.912 .724 .634 r
.3059 .48416 .31178 .49129 .32115 .48786 .31738 .44777 Metetra
0 0 .212 r
.31738 .44777 .32115 .48786 .33253 .45089 .32353 .4969 Metetra
.634 .352 .473 r
.32353 .4969 .33253 .45089 .33892 .50031 .33191 .51288 Metetra
.339 0 .16 r
.33191 .51288 .33892 .50031 .34742 .51616 .34152 .50933 Metetra
.62 .704 .905 r
.34152 .50933 .34742 .51616 .35707 .51193 .35108 .50704 Metetra
.603 .771 .96 r
.35108 .50704 .35707 .51193 .36669 .50894 .36069 .50481 Metetra
.704 .828 .941 r
.36069 .50481 .36669 .50894 .37626 .50771 .37043 .50045 Metetra
.733 .728 .847 r
.37043 .50045 .37626 .50771 .38609 .50145 .38026 .4946 Metetra
.697 .731 .876 r
.38026 .4946 .38609 .50145 .39596 .49469 .39006 .49017 Metetra
.821 .823 .85 r
.39006 .49017 .39596 .49469 .40581 .48886 .40005 .48144 Metetra
.747 .729 .835 r
.40005 .48144 .40581 .48886 .41584 .478 .40996 .47486 Metetra
.954 .765 .609 r
.40996 .47486 .41584 .478 .42675 .43764 .42098 .43423 Metetra
.943 .597 .333 r
.42098 .43423 .42675 .43764 .43592 .45467 .42926 .48154 Metetra
.128 0 .237 r
.42926 .48154 .43592 .45467 .44525 .47122 .43957 .4638 Metetra
.621 .691 .894 r
.43957 .4638 .44525 .47122 .45395 .52484 .44947 .46142 Metetra
0 0 .438 r
.44947 .46142 .45395 .52484 .46365 .54429 .45828 .51622 Metetra
.253 .221 .628 r
.45828 .51622 .46365 .54429 .47389 .54004 .46815 .53099 Metetra
.588 .638 .868 r
.46815 .53099 .47389 .54004 .48412 .53848 .47839 .52943 Metetra
.544 .618 .877 r
.47839 .52943 .48412 .53848 .49439 .53782 .48868 .52894 Metetra
.621 .659 .866 r
.48868 .52894 .49439 .53782 .50473 .53536 .49903 .52646 Metetra
.719 .697 .828 r
.49903 .52646 .50473 .53536 .51512 .52956 .50944 .52043 Metetra
.665 .672 .847 r
.50944 .52043 .51512 .52956 .52554 .52566 .51988 .51648 Metetra
.885 .731 .686 r
.51988 .51648 .52554 .52566 .53599 .52244 .53031 .49407 Metetra
.867 .629 .578 r
.53031 .49407 .53599 .52244 .54634 .4967 .54049 .43329 Metetra
.558 .374 .588 r
.54049 .43329 .54634 .4967 .55628 .43949 .5508 .43112 Metetra
.873 .473 .016 r
.5508 .43112 .55628 .43949 .56658 .43367 .56152 .46109 Metetra
.492 .186 .375 r
.56152 .46109 .56658 .43367 .57746 .46319 .57204 .45971 Metetra
.943 .839 .712 r
.57204 .45971 .57746 .46319 .58764 .44295 .58228 .43954 Metetra
.977 .756 .539 r
.58228 .43954 .58764 .44295 .597 .38925 .59167 .38136 Metetra
.882 .484 .034 r
.59167 .38136 .597 .38925 .60821 .41877 .60291 .41379 Metetra
.426 .705 .981 r
.60291 .41379 .60821 .41877 .61889 .42128 .61355 .41389 Metetra
.374 .581 .922 r
.61355 .41389 .61889 .42128 .62965 .42382 .62431 .41597 Metetra
.578 .672 .903 r
.62431 .41597 .62965 .42382 .64024 .41916 .63503 .41446 Metetra
.648 .816 .964 r
.63503 .41446 .64024 .41916 .65093 .41644 .64573 .41092 Metetra
.673 .793 .938 r
.64573 .41092 .65093 .41644 .6617 .41447 .65645 .40692 Metetra
.622 .703 .903 r
.65645 .40692 .6617 .41447 .67159 .39194 .66726 .40428 Metetra
.66726 .40428 .67159 .39194 .67968 .33463 .67716 .38133 Metetra
0 0 .235 r
.67716 .38133 .67968 .33463 .6921 .36615 .68522 .32422 Metetra
.167 .127 .565 r
.68522 .32422 .6921 .36615 .70288 .36311 .69775 .35506 Metetra
.633 .692 .887 r
.69775 .35506 .70288 .36311 .71389 .36332 .7086 .35211 Metetra
.529 .563 .834 r
.7086 .35211 .71389 .36332 .72503 .36452 .71968 .3523 Metetra
.504 .53 .817 r
.71968 .3523 .72503 .36452 .73595 .36133 .7309 .35341 Metetra
.651 .706 .888 r
.7309 .35341 .73595 .36133 .74701 .35935 .74187 .34994 Metetra
.602 .644 .864 r
.74187 .34994 .74701 .35935 .75813 .35752 .753 .34785 Metetra
.592 .633 .861 r
.753 .34785 .75813 .35752 .76923 .35475 .76419 .34606 Metetra
.628 .677 .877 r
.76419 .34606 .76923 .35475 .78034 .35139 .77536 .34317 Metetra
.649 .7 .884 r
.77536 .34317 .78034 .35139 .79154 .34865 .78653 .33965 Metetra
.62 .666 .873 r
.78653 .33965 .79154 .34865 .80277 .34553 .79781 .33698 Metetra
.638 .687 .88 r
.79781 .33698 .80277 .34553 .814 .34202 .8091 .33376 Metetra
.652 .703 .884 r
.8091 .33376 .814 .34202 .82532 .33894 .82039 .33012 Metetra
.859 .763 .755 r
.82039 .33012 .82532 .33894 .83537 .32249 .83068 .31567 Metetra
.841 .764 .777 r
.1894 .51828 .19564 .52373 .20366 .53102 .19928 .50637 Metetra
.602 .465 .668 r
.19928 .50637 .20366 .53102 .21271 .52806 .20834 .50296 Metetra
.606 .467 .665 r
.20834 .50296 .21271 .52806 .22183 .52469 .21747 .49919 Metetra
.596 .458 .664 r
.21747 .49919 .22183 .52469 .23102 .52082 .22655 .4961 Metetra
.606 .468 .668 r
.22655 .4961 .23102 .52082 .24017 .51774 .23573 .49236 Metetra
.617 .473 .664 r
.23573 .49236 .24017 .51774 .2494 .51408 .24501 .48769 Metetra
.61 .465 .66 r
.24501 .48769 .2494 .51408 .25874 .50936 .25428 .48339 Metetra
.597 .458 .662 r
.25428 .48339 .25874 .50936 .26808 .50493 .2635 .48012 Metetra
.649 .498 .664 r
.2635 .48012 .26808 .50493 .27735 .50183 .27305 .4728 Metetra
.628 .469 .648 r
.27305 .4728 .27735 .50183 .28697 .49434 .28256 .4663 Metetra
.595 .449 .653 r
.28256 .4663 .28697 .49434 .29653 .48771 .29185 .46292 Metetra
.814 .606 .621 r
.29185 .46292 .29653 .48771 .3059 .48416 .30342 .42666 Metetra
0 0 .391 r
.30342 .42666 .3059 .48416 .31738 .44777 .30928 .4753 Metetra
.676 .368 .445 r
.30928 .4753 .31738 .44777 .32353 .4969 .3175 .49143 Metetra
.674 .766 .92 r
.3175 .49143 .32353 .4969 .33191 .51288 .32704 .48787 Metetra
.588 .457 .67 r
.32704 .48787 .33191 .51288 .34152 .50933 .33655 .48534 Metetra
.566 .447 .677 r
.33655 .48534 .34152 .50933 .35108 .50704 .34602 .48431 Metetra
.618 .488 .681 r
.34602 .48431 .35108 .50704 .36069 .50481 .3557 .48002 Metetra
.63 .487 .669 r
.3557 .48002 .36069 .50481 .37043 .50045 .36547 .47431 Metetra
.603 .464 .664 r
.36547 .47431 .37043 .50045 .38026 .4946 .37518 .4705 Metetra
.617 .481 .674 r
.37518 .4705 .38026 .4946 .39006 .49017 .38495 .46599 Metetra
.668 .514 .667 r
.38495 .46599 .39006 .49017 .40005 .48144 .39492 .45704 Metetra
.647 .5 .669 r
.39492 .45704 .40005 .48144 .40996 .47486 .40483 .4499 Metetra
.821 .609 .616 r
.40483 .4499 .40996 .47486 .42098 .43423 .41575 .41304 Metetra
.86 .563 .035 r
.41575 .41304 .42098 .43423 .42926 .48154 .42396 .4591 Metetra
.213 .221 .652 r
.42396 .4591 .42926 .48154 .43957 .4638 .43342 .47174 Metetra
.992 .875 .549 r
.43342 .47174 .43957 .4638 .44947 .46142 .44422 .43574 Metetra
.583 .453 .669 r
.44422 .43574 .44947 .46142 .45828 .51622 .45413 .4334 Metetra
.18 .081 .497 r
.45413 .4334 .45828 .51622 .46815 .53099 .4631 .4838 Metetra
.321 .217 .577 r
.4631 .4838 .46815 .53099 .47839 .52943 .4729 .5039 Metetra
.629 .487 .669 r
.4729 .5039 .47839 .52943 .48868 .52894 .48321 .49799 Metetra
.579 .435 .649 r
.48321 .49799 .48868 .52894 .49903 .52646 .49351 .49545 Metetra
.556 .419 .65 r
.49351 .49545 .49903 .52646 .50944 .52043 .50384 .49477 Metetra
.78 .583 .633 r
.50384 .49477 .50944 .52043 .51988 .51648 .51431 .46895 Metetra
.801 .564 .579 r
.51431 .46895 .51988 .51648 .53031 .49407 .52467 .41061 Metetra
.557 .362 .572 r
.52467 .41061 .53031 .49407 .54049 .43329 .5349 .40725 Metetra
0 0 .423 r
.5349 .40725 .54049 .43329 .5508 .43112 .54539 .43968 Metetra
.317 0 .039 r
.54539 .43968 .5508 .43112 .56152 .46109 .55582 .43728 Metetra
.547 .441 .686 r
.55582 .43728 .56152 .46109 .57204 .45971 .56633 .43739 Metetra
.79 .599 .642 r
.56633 .43739 .57204 .45971 .58228 .43954 .57652 .41371 Metetra
.875 .637 .575 r
.57652 .41371 .58228 .43954 .59167 .38136 .58598 .35662 Metetra
0 0 .436 r
.58598 .35662 .59167 .38136 .60291 .41379 .59713 .38888 Metetra
.547 .436 .678 r
.59713 .38888 .60291 .41379 .61355 .41389 .60773 .38897 Metetra
.55 .438 .679 r
.60773 .38897 .61355 .41389 .62431 .41597 .61838 .38886 Metetra
.552 .43 .667 r
.61838 .38886 .62431 .41597 .63503 .41446 .6291 .38863 Metetra
.57 .448 .673 r
.6291 .38863 .63503 .41446 .64573 .41092 .63983 .38712 Metetra
.626 .492 .68 r
.63983 .38712 .64573 .41092 .65645 .40692 .65046 .38175 Metetra
.601 .471 .675 r
.65046 .38175 .65645 .40692 .66726 .40428 .6612 .37799 Metetra
.588 .458 .67 r
.6612 .37799 .66726 .40428 .67716 .38133 .67201 .37508 Metetra
.936 .794 .678 r
.67201 .37508 .67716 .38133 .68522 .32422 .68186 .3519 Metetra
.68186 .3519 .68522 .32422 .69775 .35506 .68984 .29509 Metetra
.302 .196 .564 r
.68984 .29509 .69775 .35506 .7086 .35211 .70243 .32576 Metetra
.592 .459 .669 r
.70243 .32576 .7086 .35211 .71968 .3523 .71327 .32251 Metetra
.548 .419 .656 r
.71327 .32251 .71968 .3523 .7309 .35341 .72435 .3225 Metetra
.538 .408 .652 r
.72435 .3225 .7309 .35341 .74187 .34994 .73556 .32332 Metetra
.593 .46 .669 r
.73556 .32332 .74187 .34994 .753 .34785 .74655 .31996 Metetra
.578 .445 .664 r
.74655 .31996 .753 .34785 .76419 .34606 .75766 .31763 Metetra
.572 .44 .662 r
.75766 .31763 .76419 .34606 .77536 .34317 .76886 .31572 Metetra
.586 .452 .666 r
.76886 .31572 .77536 .34317 .78653 .33965 .78003 .31281 Metetra
.595 .461 .668 r
.78003 .31281 .78653 .33965 .79781 .33698 .7912 .30923 Metetra
.585 .451 .665 r
.7912 .30923 .79781 .33698 .8091 .33376 .80247 .30636 Metetra
.59 .456 .666 r
.80247 .30636 .8091 .33376 .82039 .33012 .81376 .30311 Metetra
.465 .378 .672 r
.81376 .30311 .82039 .33012 .83068 .31567 .82596 .3088 Metetra
.924 .712 .599 r
.18311 .5128 .1894 .51828 .19928 .50637 .19822 .44894 Metetra
.57 .383 .589 r
.19822 .44894 .19928 .50637 .20834 .50296 .2072 .44511 Metetra
.565 .379 .588 r
.2072 .44511 .20834 .50296 .21747 .49919 .21614 .44198 Metetra
.569 .383 .59 r
.21614 .44198 .21747 .49919 .22655 .4961 .22516 .4383 Metetra
.575 .387 .59 r
.22516 .4383 .22655 .4961 .23573 .49236 .23429 .43367 Metetra
.573 .385 .589 r
.23429 .43367 .23573 .49236 .24501 .48769 .24343 .42927 Metetra
.565 .379 .588 r
.24343 .42927 .24501 .48769 .25428 .48339 .25249 .42605 Metetra
.591 .4 .591 r
.25249 .42605 .25428 .48339 .2635 .48012 .2619 .41889 Metetra
.584 .392 .587 r
.2619 .41889 .2635 .48012 .27305 .4728 .27126 .41238 Metetra
.565 .378 .586 r
.27126 .41238 .27305 .4728 .28256 .4663 .2804 .40901 Metetra
.714 .496 .592 r
.2804 .40901 .28256 .4663 .29185 .46292 .29189 .37394 Metetra
.194 .076 .481 r
.29189 .37394 .29185 .46292 .30342 .42666 .29746 .42101 Metetra
.841 .384 0 r
.29746 .42101 .30342 .42666 .30928 .4753 .30548 .4365 Metetra
.583 .415 .62 r
.30548 .4365 .30928 .4753 .3175 .49143 .31487 .43277 Metetra
.556 .373 .588 r
.31487 .43277 .3175 .49143 .32704 .48787 .32417 .43084 Metetra
.553 .372 .59 r
.32417 .43084 .32704 .48787 .33655 .48534 .3335 .42937 Metetra
.571 .386 .592 r
.3335 .42937 .33655 .48534 .34602 .48431 .343 .42538 Metetra
.576 .388 .59 r
.343 .42538 .34602 .48431 .3557 .48002 .35259 .4203 Metetra
.56 .375 .588 r
.35259 .4203 .3557 .48002 .36547 .47431 .36208 .41762 Metetra
.581 .393 .592 r
.36208 .41762 .36547 .47431 .37518 .4705 .37175 .41201 Metetra
.576 .388 .59 r
.37175 .41201 .37518 .4705 .38495 .46599 .38142 .40698 Metetra
.586 .395 .59 r
.38142 .40698 .38495 .46599 .39492 .45704 .39117 .40031 Metetra
.596 .405 .593 r
.39117 .40031 .39492 .45704 .40483 .4499 .40099 .39226 Metetra
.72 .498 .588 r
.40099 .39226 .40483 .4499 .41575 .41304 .41185 .35517 Metetra
0 0 .439 r
.41185 .35517 .41575 .41304 .42396 .4591 .41977 .40309 Metetra
.441 .29 .58 r
.41977 .40309 .42396 .4591 .43342 .47174 .4291 .41517 Metetra
.587 .399 .593 r
.4291 .41517 .43342 .47174 .44422 .43574 .43905 .40851 Metetra
.805 .593 .615 r
.43905 .40851 .44422 .43574 .45413 .4334 .44966 .37425 Metetra
.564 .379 .589 r
.44966 .37425 .45413 .4334 .4631 .4838 .45949 .37091 Metetra
.306 .162 .515 r
.45949 .37091 .4631 .4838 .4729 .5039 .46845 .41981 Metetra
.46 .288 .56 r
.46845 .41981 .4729 .5039 .48321 .49799 .47825 .43477 Metetra
.558 .373 .586 r
.47825 .43477 .48321 .49799 .49351 .49545 .48839 .43213 Metetra
.654 .444 .587 r
.48839 .43213 .49351 .49545 .50384 .49477 .49874 .41038 Metetra
.721 .486 .569 r
.49874 .41038 .50384 .49477 .51431 .46895 .50917 .35542 Metetra
.554 .35 .559 r
.50917 .35542 .51431 .46895 .52467 .41061 .51922 .35099 Metetra
.289 .179 .551 r
.51922 .35099 .52467 .41061 .5349 .40725 .52935 .37965 Metetra
.507 .396 .662 r
.52935 .37965 .5349 .40725 .54539 .43968 .5396 .38227 Metetra
.555 .375 .592 r
.5396 .38227 .54539 .43968 .55582 .43728 .54989 .3805 Metetra
.575 .39 .593 r
.54989 .3805 .55582 .43728 .56633 .43739 .5602 .37555 Metetra
.653 .443 .587 r
.5602 .37555 .56633 .43739 .57652 .41371 .57031 .35436 Metetra
.766 .527 .573 r
.57031 .35436 .57652 .41371 .58598 .35662 .57975 .29982 Metetra
.281 .179 .556 r
.57975 .29982 .58598 .35662 .59713 .38888 .59063 .32874 Metetra
.54 .361 .588 r
.59063 .32874 .59713 .38888 .60773 .38897 .60108 .32916 Metetra
.533 .357 .588 r
.60108 .32916 .60773 .38897 .61838 .38886 .61163 .33066 Metetra
.565 .381 .591 r
.61163 .33066 .61838 .38886 .6291 .38863 .62209 .3272 Metetra
.548 .367 .588 r
.62209 .3272 .6291 .38863 .63983 .38712 .63268 .32633 Metetra
.558 .374 .589 r
.63268 .32633 .63983 .38712 .65046 .38175 .64327 .32385 Metetra
.574 .388 .592 r
.64327 .32385 .65046 .38175 .6612 .37799 .65381 .31885 Metetra
.572 .386 .591 r
.65381 .31885 .6612 .37799 .67201 .37508 .66439 .31413 Metetra
.56 .376 .589 r
.66439 .31413 .67201 .37508 .68186 .3519 .67509 .31129 Metetra
.706 .499 .606 r
.67509 .31129 .68186 .3519 .68984 .29509 .68481 .28856 Metetra
.975 .746 .527 r
.68481 .28856 .68984 .29509 .70243 .32576 .69266 .2333 Metetra
.402 .247 .553 r
.69266 .2333 .70243 .32576 .71327 .32251 .70512 .26254 Metetra
.563 .379 .589 r
.70512 .26254 .71327 .32251 .72435 .3225 .71584 .25915 Metetra
.543 .362 .586 r
.71584 .25915 .72435 .3225 .73556 .32332 .7268 .25899 Metetra
.539 .359 .585 r
.7268 .25899 .73556 .32332 .74655 .31996 .73789 .25952 Metetra
.564 .379 .589 r
.73789 .25952 .74655 .31996 .75766 .31763 .74874 .25595 Metetra
.556 .373 .588 r
.74874 .25595 .75766 .31763 .76886 .31572 .75974 .25361 Metetra
.555 .372 .588 r
.75974 .25361 .76886 .31572 .78003 .31281 .7708 .25149 Metetra
.561 .376 .589 r
.7708 .25149 .78003 .31281 .7912 .30923 .78184 .2484 Metetra
.564 .379 .589 r
.78184 .2484 .7912 .30923 .80247 .30636 .79288 .24472 Metetra
.56 .375 .588 r
.79288 .24472 .80247 .30636 .81376 .30311 .80402 .24178 Metetra
.056 .032 .51 r
.80402 .24178 .81376 .30311 .82596 .3088 .8212 .30188 Metetra
.656 .752 .92 r
.17678 .50728 .18311 .5128 .19822 .44894 .18583 .50427 Metetra
.109 0 .29 r
.18583 .50427 .19822 .44894 .2072 .44511 .19781 .472 Metetra
.442 .138 .353 r
.19781 .472 .2072 .44511 .21614 .44198 .20691 .46831 Metetra
.42 .116 .341 r
.20691 .46831 .21614 .44198 .22516 .4383 .21613 .46365 Metetra
.423 .116 .337 r
.21613 .46365 .22516 .4383 .23429 .43367 .22533 .45935 Metetra
.448 .14 .35 r
.22533 .45935 .23429 .43367 .24343 .42927 .23446 .45617 Metetra
.366 .069 .321 r
.23446 .45617 .24343 .42927 .25249 .42605 .24398 .44889 Metetra
.352 .04 .289 r
.24398 .44889 .25249 .42605 .2619 .41889 .25343 .44236 Metetra
.44 .125 .333 r
.25343 .44236 .2619 .41889 .27126 .41238 .26264 .43917 Metetra
.26264 .43917 .27126 .41238 .2804 .40901 .27441 .40329 Metetra
.949 .624 .378 r
.27441 .40329 .2804 .40901 .29189 .37394 .27973 .45161 Metetra
.598 .336 .49 r
.27973 .45161 .29189 .37394 .29746 .42101 .2877 .46762 Metetra
.487 .216 .428 r
.2877 .46762 .29746 .42101 .30548 .4365 .29715 .46414 Metetra
.475 .17 .369 r
.29715 .46414 .30548 .4365 .31487 .43277 .30655 .46204 Metetra
.491 .19 .383 r
.30655 .46204 .31487 .43277 .32417 .43084 .31593 .46079 Metetra
.456 .159 .372 r
.31593 .46079 .32417 .43084 .3335 .42937 .3255 .45716 Metetra
.427 .126 .351 r
.3255 .45716 .3335 .42937 .343 .42538 .33518 .45226 Metetra
.459 .153 .359 r
.33518 .45226 .343 .42538 .35259 .4203 .34477 .44933 Metetra
.449 .151 .366 r
.34477 .44933 .35259 .4203 .36208 .41762 .35444 .44541 Metetra
.423 .124 .35 r
.35444 .44541 .36208 .41762 .37175 .41201 .36421 .44028 Metetra
.436 .136 .357 r
.36421 .44028 .37175 .41201 .38142 .40698 .37398 .43571 Metetra
.374 .083 .337 r
.37398 .43571 .38142 .40698 .39117 .40031 .38392 .42769 Metetra
.394 .097 .338 r
.38392 .42769 .39117 .40031 .40099 .39226 .39381 .42108 Metetra
.39381 .42108 .40099 .39226 .41185 .35517 .40492 .38224 Metetra
.81 .499 .464 r
.40492 .38224 .41185 .35517 .41977 .40309 .41285 .43086 Metetra
.664 .347 .428 r
.41285 .43086 .41977 .40309 .4291 .41517 .42217 .4459 Metetra
.423 .132 .364 r
.42217 .4459 .4291 .41517 .43905 .40851 .43225 .43989 Metetra
.47 .175 .382 r
.43225 .43989 .43905 .40851 .44966 .37425 .44226 .43681 Metetra
.134 0 .339 r
.44226 .43681 .44966 .37425 .45949 .37091 .45317 .39574 Metetra
.447 .136 .344 r
.45317 .39574 .45949 .37091 .46845 .41981 .46315 .39241 Metetra
.743 .494 0 r
.46315 .39241 .46845 .41981 .47825 .43477 .47229 .4433 Metetra
.294 0 .018 r
.47229 .4433 .47825 .43477 .48839 .43213 .48251 .44067 Metetra
1 .814 .5 r
.48251 .44067 .48839 .43213 .49874 .41038 .49331 .38286 Metetra
.582 .445 .66 r
.49331 .38286 .49874 .41038 .50917 .35542 .50344 .38028 Metetra
.774 .446 .433 r
.50344 .38028 .50917 .35542 .51922 .35099 .51348 .41379 Metetra
.507 .246 .454 r
.51348 .41379 .51922 .35099 .52935 .37965 .52381 .41113 Metetra
.534 .231 .399 r
.52381 .41113 .52935 .37965 .5396 .38227 .53419 .41319 Metetra
.452 .158 .374 r
.53419 .41319 .5396 .38227 .54989 .3805 .54461 .40882 Metetra
.453 .151 .363 r
.54461 .40882 .54989 .3805 .5602 .37555 .55507 .40501 Metetra
.099 0 .251 r
.55507 .40501 .5602 .37555 .57031 .35436 .56534 .38304 Metetra
.709 .674 .128 r
.56534 .38304 .57031 .35436 .57975 .29982 .57498 .32643 Metetra
.756 .426 .425 r
.57498 .32643 .57975 .29982 .59063 .32874 .58598 .35739 Metetra
.508 .2 .38 r
.58598 .35739 .59063 .32874 .60108 .32916 .59656 .3574 Metetra
.521 .21 .381 r
.59656 .3574 .60108 .32916 .61163 .33066 .60723 .35849 Metetra
.477 .171 .368 r
.60723 .35849 .61163 .33066 .62209 .3272 .61787 .35631 Metetra
.468 .167 .371 r
.61787 .35631 .62209 .3272 .63268 .32633 .62854 .35327 Metetra
.484 .174 .365 r
.62854 .35327 .63268 .32633 .64327 .32385 .6393 .35174 Metetra
.469 .164 .366 r
.6393 .35174 .64327 .32385 .65381 .31885 .65008 .34897 Metetra
.438 .145 .369 r
.65008 .34897 .65381 .31885 .66439 .31413 .66078 .34356 Metetra
.449 .152 .368 r
.66078 .34356 .66439 .31413 .67509 .31129 .67156 .33906 Metetra
.463 .159 .364 r
.67156 .33906 .67509 .31129 .68481 .28856 .68244 .33588 Metetra
.298 .069 .389 r
.68244 .33588 .68481 .28856 .69266 .2333 .69229 .31259 Metetra
.173 .004 .397 r
.69229 .31259 .69266 .2333 .70512 .26254 .70014 .25583 Metetra
.832 .414 0 r
.70014 .25583 .70512 .26254 .71584 .25915 .71291 .28603 Metetra
.456 .151 .359 r
.71291 .28603 .71584 .25915 .7268 .25899 .7238 .28243 Metetra
.498 .173 .346 r
.7238 .28243 .7268 .25899 .73789 .25952 .73498 .28231 Metetra
.508 .178 .343 r
.73498 .28231 .73789 .25952 .74874 .25595 .74627 .28295 Metetra
.456 .152 .359 r
.74627 .28295 .74874 .25595 .75974 .25361 .75732 .27936 Metetra
.469 .158 .355 r
.75732 .27936 .75974 .25361 .7708 .25149 .76851 .2769 Metetra
.474 .16 .353 r
.76851 .2769 .7708 .25149 .78184 .2484 .77978 .27484 Metetra
.462 .154 .357 r
.77978 .27484 .78184 .2484 .79288 .24472 .79103 .27174 Metetra
.732 .383 .39 r
.79103 .27174 .79288 .24472 .80402 .24178 .80501 .29869 Metetra
.498 .234 .445 r
.80501 .29869 .80402 .24178 .8212 .30188 .81641 .29491 Metetra
.656 .752 .92 r
.17041 .50172 .17678 .50728 .18583 .50427 .17948 .4987 Metetra
.904 .736 .663 r
.17948 .4987 .18583 .50427 .19781 .472 .19127 .46906 Metetra
.722 .864 .948 r
.19127 .46906 .19781 .472 .20691 .46831 .20049 .46443 Metetra
.712 .826 .936 r
.20049 .46443 .20691 .46831 .21613 .46365 .20969 .4601 Metetra
.651 .831 .969 r
.20969 .4601 .21613 .46365 .22533 .45935 .21882 .45692 Metetra
.809 .881 .898 r
.21882 .45692 .22533 .45935 .23446 .45617 .22834 .4497 Metetra
.756 .744 .842 r
.22834 .4497 .23446 .45617 .24398 .44889 .23781 .44323 Metetra
.666 .753 .915 r
.23781 .44323 .24398 .44889 .25343 .44236 .24702 .43992 Metetra
.939 .763 .637 r
.24702 .43992 .25343 .44236 .26264 .43917 .25894 .40406 Metetra
.709 .518 0 r
.25894 .40406 .26264 .43917 .27441 .40329 .26399 .45259 Metetra
.627 .347 .473 r
.26399 .45259 .27441 .40329 .27973 .45161 .27186 .46861 Metetra
.388 .039 .246 r
.27186 .46861 .27973 .45161 .2877 .46762 .28131 .46517 Metetra
.494 .834 .998 r
.28131 .46517 .2877 .46762 .29715 .46414 .29068 .46336 Metetra
.278 .771 .9 r
.29068 .46336 .29715 .46414 .30655 .46204 .30005 .46214 Metetra
.5 .903 .92 r
.30005 .46214 .30655 .46204 .31593 .46079 .30961 .45859 Metetra
.723 .907 .959 r
.30961 .45859 .31593 .46079 .3255 .45716 .3193 .4535 Metetra
.561 .812 .992 r
.3193 .4535 .3255 .45716 .33518 .45226 .32884 .45146 Metetra
.629 .935 .964 r
.32884 .45146 .33518 .45226 .34477 .44933 .33854 .44714 Metetra
.677 .903 .976 r
.33854 .44714 .34477 .44933 .35444 .44541 .34827 .44283 Metetra
.673 .888 .977 r
.34827 .44283 .35444 .44541 .36421 .44028 .35802 .43871 Metetra
.69 .929 .968 r
.35802 .43871 .36421 .44028 .37398 .43571 .36784 .43387 Metetra
.83 .922 .896 r
.36784 .43387 .37398 .43571 .38392 .42769 .37783 .42564 Metetra
.822 .918 .901 r
.37783 .42564 .38392 .42769 .39381 .42108 .38782 .41771 Metetra
.951 .77 .622 r
.38782 .41771 .39381 .42108 .40492 .38224 .39894 .38101 Metetra
.934 .588 .351 r
.39894 .38101 .40492 .38224 .41285 .43086 .40687 .42789 Metetra
.826 .349 .012 r
.40687 .42789 .41285 .43086 .42217 .4459 .41618 .44327 Metetra
.352 .765 .98 r
.41618 .44327 .42217 .4459 .43225 .43989 .42613 .44267 Metetra
.605 .94 .752 r
.42613 .44267 .43225 .43989 .44226 .43681 .43632 .43508 Metetra
.855 .931 .876 r
.43632 .43508 .44226 .43681 .45317 .39574 .44656 .42562 Metetra
0 0 .031 r
.44656 .42562 .45317 .39574 .46315 .39241 .45737 .38955 Metetra
.948 .823 .688 r
.45737 .38955 .46315 .39241 .47229 .4433 .46777 .36656 Metetra
.553 .359 .573 r
.46777 .36656 .47229 .4433 .48251 .44067 .47779 .36381 Metetra
.441 .276 .56 r
.47779 .36381 .48251 .44067 .49331 .38286 .48763 .37994 Metetra
.913 .513 .201 r
.48763 .37994 .49331 .38286 .50344 .38028 .49752 .41023 Metetra
.528 .221 .39 r
.49752 .41023 .50344 .38028 .51348 .41379 .5078 .41192 Metetra
0 .528 .797 r
.5078 .41192 .51348 .41379 .52381 .41113 .51816 .41377 Metetra
.51816 .41377 .52381 .41113 .53419 .41319 .52858 .41035 Metetra
.683 .899 .974 r
.52858 .41035 .53419 .41319 .54461 .40882 .53904 .40566 Metetra
.494 .82 1 r
.53904 .40566 .54461 .40882 .55507 .40501 .54955 .40384 Metetra
.973 .865 .672 r
.54955 .40384 .55507 .40501 .56534 .38304 .55988 .38006 Metetra
.978 .76 .54 r
.55988 .38006 .56534 .38304 .57498 .32643 .56964 .32319 Metetra
.909 .501 .157 r
.56964 .32319 .57498 .32643 .58598 .35739 .58064 .35511 Metetra
.213 .696 .931 r
.58064 .35511 .58598 .35739 .59656 .3574 .59125 .35536 Metetra
.215 .705 .924 r
.59125 .35536 .59656 .3574 .60723 .35849 .60193 .35539 Metetra
.485 .821 .999 r
.60193 .35539 .60723 .35849 .61787 .35631 .61262 .35356 Metetra
.447 .817 .993 r
.61262 .35356 .61787 .35631 .62854 .35327 .62337 .35192 Metetra
.601 .93 .961 r
.62337 .35192 .62854 .35327 .6393 .35174 .63408 .34742 Metetra
.496 .776 .994 r
.63408 .34742 .6393 .35174 .65008 .34897 .64494 .3461 Metetra
.566 .869 .995 r
.64494 .3461 .65008 .34897 .66078 .34356 .65579 .34302 Metetra
.611 .95 .92 r
.65579 .34302 .66078 .34356 .67156 .33906 .66658 .33758 Metetra
.629 .939 .959 r
.66658 .33758 .67156 .33906 .68244 .33588 .67742 .33263 Metetra
.588 .864 .994 r
.67742 .33263 .68244 .33588 .69229 .31259 .68838 .32939 Metetra
0 0 .019 r
.68838 .32939 .69229 .31259 .70014 .25583 .69827 .30596 Metetra
0 0 .267 r
.69827 .30596 .70014 .25583 .71291 .28603 .70608 .24888 Metetra
.113 .101 .564 r
.70608 .24888 .71291 .28603 .7238 .28243 .719 .27902 Metetra
.608 .867 .991 r
.719 .27902 .7238 .28243 .73498 .28231 .72999 .27551 Metetra
.493 .674 .945 r
.72999 .27551 .73498 .28231 .74627 .28295 .74125 .27528 Metetra
.467 .629 .924 r
.74125 .27528 .74627 .28295 .75732 .27936 .75264 .27583 Metetra
.616 .869 .99 r
.75264 .27583 .75732 .27936 .76851 .2769 .76377 .27217 Metetra
.573 .8 .985 r
.76377 .27217 .76851 .2769 .77978 .27484 .77505 .26972 Metetra
.564 .78 .98 r
.77505 .26972 .77978 .27484 .79103 .27174 .78641 .26756 Metetra
.78 .317 0 r
.78641 .26756 .79103 .27174 .80501 .29869 .80016 .2917 Metetra
.656 .752 .92 r
.80016 .2917 .80501 .29869 .81641 .29491 .81158 .28789 Metetra
.656 .752 .92 r
.164 .49613 .17041 .50172 .17948 .4987 .17308 .49309 Metetra
.9 .739 .673 r
.17308 .49309 .17948 .4987 .19127 .46906 .18469 .46594 Metetra
.707 .857 .954 r
.18469 .46594 .19127 .46906 .20049 .46443 .1939 .46164 Metetra
.636 .86 .984 r
.1939 .46164 .20049 .46443 .20969 .4601 .20302 .45848 Metetra
.812 .911 .907 r
.20302 .45848 .20969 .4601 .21882 .45692 .21256 .45124 Metetra
.765 .769 .856 r
.21256 .45124 .21882 .45692 .22834 .4497 .22204 .44473 Metetra
.659 .778 .937 r
.22204 .44473 .22834 .4497 .23781 .44323 .23124 .44155 Metetra
.943 .77 .638 r
.23124 .44155 .23781 .44323 .24702 .43992 .24333 .40558 Metetra
.746 .543 0 r
.24333 .40558 .24702 .43992 .25894 .40406 .24812 .45425 Metetra
.626 .346 .473 r
.24812 .45425 .25894 .40406 .26399 .45259 .25588 .47036 Metetra
.398 .051 .257 r
.25588 .47036 .26399 .45259 .27186 .46861 .26532 .4671 Metetra
.451 .847 .977 r
.26532 .4671 .27186 .46861 .28131 .46517 .27469 .46511 Metetra
.161 .7 .805 r
.27469 .46511 .28131 .46517 .29068 .46336 .28403 .46413 Metetra
.429 .871 .864 r
.28403 .46413 .29068 .46336 .30005 .46214 .29359 .46066 Metetra
.69 .927 .968 r
.29359 .46066 .30005 .46214 .30961 .45859 .30327 .4559 Metetra
.546 .847 .998 r
.30327 .4559 .30961 .45859 .3193 .4535 .31281 .4536 Metetra
.539 .92 .925 r
.31281 .4536 .3193 .4535 .32884 .45146 .3225 .44963 Metetra
.647 .909 .981 r
.3225 .44963 .32884 .45146 .33854 .44714 .33222 .4456 Metetra
.585 .902 .983 r
.33222 .4456 .33854 .44714 .34827 .44283 .34194 .44219 Metetra
.687 .954 .951 r
.34194 .44219 .34827 .44283 .35802 .43871 .35179 .4369 Metetra
.674 .919 .974 r
.35179 .4369 .35802 .43871 .36784 .43387 .36162 .4324 Metetra
.836 .934 .893 r
.36162 .4324 .36784 .43387 .37783 .42564 .37168 .42388 Metetra
.804 .931 .917 r
.37168 .42388 .37783 .42564 .38782 .41771 .38168 .41651 Metetra
.966 .786 .61 r
.38168 .41651 .38782 .41771 .39894 .38101 .393 .37746 Metetra
.945 .603 .34 r
.393 .37746 .39894 .38101 .40687 .42789 .40074 .42759 Metetra
.836 .383 .138 r
.40074 .42759 .40687 .42789 .41618 .44327 .41002 .44388 Metetra
.613 .955 .894 r
.41002 .44388 .41618 .44327 .42613 .44267 .42017 .43833 Metetra
.586 .802 .982 r
.42017 .43833 .42613 .44267 .43632 .43508 .43024 .43596 Metetra
.795 .996 .862 r
.43024 .43596 .43632 .43508 .44656 .42562 .44053 .42716 Metetra
.981 .881 .657 r
.44053 .42716 .44656 .42562 .45737 .38955 .45119 .4019 Metetra
.997 .779 .476 r
.45119 .4019 .45737 .38955 .46777 .36656 .46303 .31206 Metetra
.56 .378 .592 r
.46303 .31206 .46777 .36656 .47779 .36381 .47292 .30924 Metetra
0 0 .161 r
.47292 .30924 .47779 .36381 .48763 .37994 .4817 .39228 Metetra
.766 .392 .348 r
.4817 .39228 .48763 .37994 .49752 .41023 .49172 .41169 Metetra
.244 0 0 r
.49172 .41169 .49752 .41023 .5078 .41192 .50205 .41269 Metetra
.349 .825 .812 r
.50205 .41269 .5078 .41192 .51816 .41377 .51247 .40924 Metetra
.25 .633 .961 r
.51247 .40924 .51816 .41377 .52858 .41035 .52292 .41078 Metetra
.585 .946 .883 r
.52292 .41078 .52858 .41035 .53904 .40566 .53343 .40523 Metetra
.602 .944 .93 r
.53343 .40523 .53904 .40566 .54955 .40384 .54396 .4002 Metetra
.947 .833 .7 r
.54396 .4002 .54955 .40384 .55988 .38006 .55438 .37863 Metetra
.984 .77 .534 r
.55438 .37863 .55988 .38006 .56964 .32319 .56427 .32156 Metetra
.905 .495 .183 r
.56427 .32156 .56964 .32319 .58064 .35511 .57524 .3525 Metetra
.204 .68 .935 r
.57524 .3525 .58064 .35511 .59125 .35536 .58589 .35307 Metetra
.1 .619 .884 r
.58589 .35307 .59125 .35536 .60193 .35539 .59663 .35425 Metetra
.435 .86 .944 r
.59663 .35425 .60193 .35539 .61262 .35356 .60734 .35149 Metetra
.431 .833 .978 r
.60734 .35149 .61262 .35356 .62337 .35192 .61812 .3495 Metetra
.504 .858 .991 r
.61812 .3495 .62337 .35192 .63408 .34742 .62894 .34694 Metetra
.509 .908 .916 r
.62894 .34694 .63408 .34742 .64494 .3461 .63974 .34273 Metetra
.495 .818 1 r
.63974 .34273 .64494 .3461 .65579 .34302 .65068 .34084 Metetra
.533 .881 .985 r
.65068 .34084 .65579 .34302 .66658 .33758 .66161 .33768 Metetra
.586 .946 .878 r
.66161 .33768 .66658 .33758 .67742 .33263 .67247 .33185 Metetra
.568 .931 .93 r
.67247 .33185 .67742 .33263 .68838 .32939 .6834 .32707 Metetra
.564 .891 .986 r
.6834 .32707 .68838 .32939 .69827 .30596 .69444 .32354 Metetra
0 0 .043 r
.69444 .32354 .69827 .30596 .70608 .24888 .70437 .29995 Metetra
0 0 .273 r
.70437 .29995 .70608 .24888 .719 .27902 .71214 .24256 Metetra
.1 .094 .563 r
.71214 .24256 .719 .27902 .72999 .27551 .72524 .27284 Metetra
.589 .891 .989 r
.72524 .27284 .72999 .27551 .74125 .27528 .7363 .26914 Metetra
.473 .692 .963 r
.7363 .26914 .74125 .27528 .75264 .27583 .74766 .26892 Metetra
.448 .649 .944 r
.74766 .26892 .75264 .27583 .76377 .27217 .75915 .26944 Metetra
.585 .891 .989 r
.75915 .26944 .76377 .27217 .77505 .26972 .77037 .26572 Metetra
.554 .826 .996 r
.77037 .26572 .77505 .26972 .78641 .26756 .78174 .26318 Metetra
.74 .267 0 r
.78174 .26318 .78641 .26756 .80016 .2917 .79526 .28466 Metetra
.656 .752 .92 r
.79526 .28466 .80016 .2917 .81158 .28789 .80671 .28082 Metetra
.656 .752 .92 r
.15755 .49051 .164 .49613 .17308 .49309 .16665 .48744 Metetra
.656 .752 .92 r
.16665 .48744 .17308 .49309 .18469 .46594 .17578 .48437 Metetra
.784 .849 .395 r
.17578 .48437 .18469 .46594 .1939 .46164 .18744 .45712 Metetra
.791 .806 .864 r
.18744 .45712 .1939 .46164 .20302 .45848 .19698 .44989 Metetra
.734 .689 .807 r
.19698 .44989 .20302 .45848 .21256 .45124 .20647 .44342 Metetra
.656 .684 .864 r
.20647 .44342 .21256 .45124 .22204 .44473 .21566 .44019 Metetra
.923 .743 .64 r
.21566 .44019 .22204 .44473 .23124 .44155 .2279 .40419 Metetra
0 0 .077 r
.2279 .40419 .23124 .44155 .24333 .40558 .23241 .453 Metetra
.63 .347 .47 r
.23241 .453 .24333 .40558 .24812 .45425 .24007 .46922 Metetra
.36 0 .198 r
.24007 .46922 .24812 .45425 .25588 .47036 .2495 .46584 Metetra
.569 .777 .977 r
.2495 .46584 .25588 .47036 .26532 .4671 .25885 .464 Metetra
.433 .783 .997 r
.25885 .464 .26532 .4671 .27469 .46511 .26816 .46307 Metetra
.621 .893 .988 r
.26816 .46307 .27469 .46511 .28403 .46413 .27771 .45959 Metetra
.718 .815 .925 r
.27771 .45959 .28403 .46413 .29359 .46066 .28739 .45485 Metetra
.59 .736 .944 r
.28739 .45485 .29359 .46066 .30327 .4559 .29689 .45293 Metetra
.673 .872 .974 r
.29689 .45293 .30327 .4559 .31281 .4536 .30657 .44895 Metetra
.675 .806 .945 r
.30657 .44895 .31281 .4536 .3225 .44963 .31627 .44519 Metetra
.669 .814 .953 r
.31627 .44519 .3225 .44963 .33222 .4456 .326 .44153 Metetra
.677 .831 .957 r
.326 .44153 .33222 .4456 .34194 .44219 .33577 .43764 Metetra
.727 .822 .924 r
.33577 .43764 .34194 .44219 .35179 .4369 .34563 .43257 Metetra
.748 .833 .917 r
.34563 .43257 .35179 .4369 .36162 .4324 .35556 .4269 Metetra
.784 .796 .862 r
.35556 .4269 .36162 .4324 .37168 .42388 .36559 .41948 Metetra
.82 .834 .86 r
.36559 .41948 .37168 .42388 .38168 .41651 .37568 .41089 Metetra
.937 .748 .622 r
.37568 .41089 .38168 .41651 .393 .37746 .38704 .37307 Metetra
.948 .606 .335 r
.38704 .37307 .393 .37746 .40074 .42759 .39468 .42385 Metetra
.797 .305 0 r
.39468 .42385 .40074 .42759 .41002 .44388 .40403 .4381 Metetra
.714 .783 .906 r
.40403 .4381 .41002 .44388 .42017 .43833 .41418 .43316 Metetra
.583 .768 .967 r
.41418 .43316 .42017 .43833 .43024 .43596 .42427 .43105 Metetra
.93 .786 .68 r
.42427 .43105 .43024 .43596 .44053 .42716 .43504 .40641 Metetra
.891 .659 .58 r
.43504 .40641 .44053 .42716 .45119 .4019 .44657 .34667 Metetra
.586 .397 .592 r
.44657 .34667 .45119 .4019 .46303 .31206 .45665 .33981 Metetra
.46 .153 .358 r
.45665 .33981 .46303 .31206 .47292 .30924 .46667 .337 Metetra
.5 .189 .371 r
.46667 .337 .47292 .30924 .4817 .39228 .4767 .33684 Metetra
0 0 .406 r
.4767 .33684 .4817 .39228 .49172 .41169 .48612 .39075 Metetra
.012 .102 .612 r
.48612 .39075 .49172 .41169 .50205 .41269 .49628 .40762 Metetra
.662 .805 .951 r
.49628 .40762 .50205 .41269 .51247 .40924 .50673 .40386 Metetra
.361 .662 .971 r
.50673 .40386 .51247 .40924 .52292 .41078 .51721 .40475 Metetra
.652 .767 .934 r
.51721 .40475 .52292 .41078 .53343 .40523 .52775 .40128 Metetra
.733 .869 .944 r
.52775 .40128 .53343 .40523 .54396 .4002 .53832 .39568 Metetra
.942 .813 .688 r
.53832 .39568 .54396 .4002 .55438 .37863 .54878 .37265 Metetra
.966 .744 .552 r
.54878 .37265 .55438 .37863 .56427 .32156 .55881 .31665 Metetra
.899 .487 .102 r
.55881 .31665 .56427 .32156 .57524 .3525 .56974 .34719 Metetra
.406 .688 .977 r
.56974 .34719 .57524 .3525 .58589 .35307 .58042 .34752 Metetra
.309 .625 .96 r
.58042 .34752 .58589 .35307 .59663 .35425 .59119 .34914 Metetra
.583 .781 .974 r
.59119 .34914 .59663 .35425 .60734 .35149 .60195 .34681 Metetra
.577 .798 .983 r
.60195 .34681 .60734 .35149 .61812 .3495 .61275 .34441 Metetra
.608 .794 .97 r
.61275 .34441 .61812 .3495 .62894 .34694 .62359 .34158 Metetra
.594 .779 .968 r
.62359 .34158 .62894 .34694 .63974 .34273 .63448 .33906 Metetra
.69 .881 .969 r
.63448 .33906 .63974 .34273 .65068 .34084 .64534 .33421 Metetra
.576 .723 .943 r
.64534 .33421 .65068 .34084 .66161 .33768 .65636 .33231 Metetra
.632 .795 .961 r
.65636 .33231 .66161 .33768 .67247 .33185 .66737 .329 Metetra
.723 .925 .959 r
.66737 .329 .67247 .33185 .6834 .32707 .67829 .32308 Metetra
.698 .875 .964 r
.67829 .32308 .6834 .32707 .69444 .32354 .6893 .31805 Metetra
.637 .795 .959 r
.6893 .31805 .69444 .32354 .70437 .29995 .70042 .31462 Metetra
.70042 .31462 .70437 .29995 .71214 .24256 .71038 .29081 Metetra
0 0 .25 r
.71038 .29081 .71214 .24256 .72524 .27284 .7181 .23316 Metetra
.142 .116 .566 r
.7181 .23316 .72524 .27284 .7363 .26914 .73135 .26344 Metetra
.65 .793 .951 r
.73135 .26344 .7363 .26914 .74766 .26892 .74249 .25975 Metetra
.525 .619 .888 r
.74249 .25975 .74766 .26892 .75915 .26944 .75394 .25943 Metetra
.499 .583 .87 r
.75394 .25943 .75915 .26944 .77037 .26572 .76551 .2599 Metetra
.7 .244 0 r
.76551 .2599 .77037 .26572 .78174 .26318 .77889 .28141 Metetra
.403 .06 .265 r
.77889 .28141 .78174 .26318 .79526 .28466 .79033 .27756 Metetra
.656 .752 .92 r
.79033 .27756 .79526 .28466 .80671 .28082 .80182 .27369 Metetra
.656 .752 .92 r
.15105 .48484 .15755 .49051 .16665 .48744 .16017 .48176 Metetra
.656 .752 .92 r
.16017 .48176 .16665 .48744 .17578 .48437 .16932 .47867 Metetra
.905 .737 .662 r
.16932 .47867 .17578 .48437 .18744 .45712 .18132 .44881 Metetra
.737 .696 .812 r
.18132 .44881 .18744 .45712 .19698 .44989 .19081 .44234 Metetra
.655 .691 .872 r
.19081 .44234 .19698 .44989 .20647 .44342 .19998 .43916 Metetra
.924 .745 .641 r
.19998 .43916 .20647 .44342 .21566 .44019 .21237 .40311 Metetra
.713 .531 0 r
.21237 .40311 .21566 .44019 .2279 .40419 .21662 .45201 Metetra
.629 .346 .469 r
.21662 .45201 .2279 .40419 .23241 .453 .22417 .46823 Metetra
.366 0 .201 r
.22417 .46823 .23241 .453 .24007 .46922 .23358 .46499 Metetra
.563 .788 .983 r
.23358 .46499 .24007 .46922 .2495 .46584 .24291 .46314 Metetra
.405 .787 .991 r
.24291 .46314 .2495 .46584 .25885 .464 .2522 .46221 Metetra
.61 .899 .987 r
.2522 .46221 .25885 .464 .26816 .46307 .26175 .45874 Metetra
.709 .822 .935 r
.26175 .45874 .26816 .46307 .27771 .45959 .2714 .45423 Metetra
.596 .756 .954 r
.2714 .45423 .27771 .45959 .28739 .45485 .28091 .45211 Metetra
.649 .876 .983 r
.28091 .45211 .28739 .45485 .29689 .45293 .29056 .44844 Metetra
.672 .812 .95 r
.29056 .44844 .29689 .45293 .30657 .44895 .30025 .44473 Metetra
.64 .816 .968 r
.30025 .44473 .30657 .44895 .31627 .44519 .30994 .44159 Metetra
.69 .852 .961 r
.30994 .44159 .31627 .44519 .326 .44153 .31972 .43737 Metetra
.692 .832 .95 r
.31972 .43737 .326 .44153 .33577 .43764 .32954 .43316 Metetra
.743 .828 .917 r
.32954 .43316 .33577 .43764 .34563 .43257 .33946 .42761 Metetra
.711 .806 .924 r
.33946 .42761 .34563 .43257 .35556 .4269 .34936 .42293 Metetra
.84 .845 .849 r
.34936 .42293 .35556 .4269 .36559 .41948 .35954 .41339 Metetra
.763 .777 .865 r
.35954 .41339 .36559 .41948 .37568 .41089 .36958 .40665 Metetra
.945 .764 .626 r
.36958 .40665 .37568 .41089 .38704 .37307 .38097 .37026 Metetra
.94 .593 .337 r
.38097 .37026 .38704 .37307 .39468 .42385 .38868 .4174 Metetra
.737 .261 0 r
.38868 .4174 .39468 .42385 .40403 .4381 .39801 .43198 Metetra
.578 .73 .947 r
.39801 .43198 .40403 .4381 .41418 .43316 .40807 .43016 Metetra
.942 .822 .696 r
.40807 .43016 .41418 .43316 .42427 .43105 .41887 .40754 Metetra
.88 .647 .582 r
.41887 .40754 .42427 .43105 .43504 .40641 .43068 .3479 Metetra
.55 .367 .586 r
.43068 .3479 .43504 .40641 .44657 .34667 .44065 .34594 Metetra
.895 .488 .227 r
.44065 .34594 .44657 .34667 .45665 .33981 .45 .37207 Metetra
.468 .171 .376 r
.45 .37207 .45665 .33981 .46667 .337 .46017 .36929 Metetra
0 0 .119 r
.46017 .36929 .46667 .337 .4767 .33684 .47089 .33605 Metetra
.575 .926 .951 r
.47089 .33605 .4767 .33684 .48612 .39075 .48107 .33188 Metetra
0 0 .436 r
.48107 .33188 .48612 .39075 .49628 .40762 .49067 .38383 Metetra
.094 .137 .616 r
.49067 .38383 .49628 .40762 .50673 .40386 .50094 .40069 Metetra
.53 .837 .999 r
.50094 .40069 .50673 .40386 .51721 .40475 .51145 .39838 Metetra
.666 .761 .921 r
.51145 .39838 .51721 .40475 .52775 .40128 .52202 .39454 Metetra
.571 .713 .938 r
.52202 .39454 .52775 .40128 .53832 .39568 .53263 .39283 Metetra
.962 .835 .672 r
.53263 .39283 .53832 .39568 .54878 .37265 .54316 .36809 Metetra
.973 .751 .544 r
.54316 .36809 .54878 .37265 .55881 .31665 .55329 .31005 Metetra
.899 .496 .083 r
.55329 .31005 .55881 .31665 .56974 .34719 .56422 .34273 Metetra
.392 .72 .988 r
.56422 .34273 .56974 .34719 .58042 .34752 .57492 .34271 Metetra
.348 .681 .979 r
.57492 .34271 .58042 .34752 .59119 .34914 .5857 .3434 Metetra
.534 .737 .968 r
.5857 .3434 .59119 .34914 .60195 .34681 .5965 .34204 Metetra
.543 .782 .986 r
.5965 .34204 .60195 .34681 .61275 .34441 .60735 .34017 Metetra
.63 .838 .98 r
.60735 .34017 .61275 .34441 .62359 .34158 .61821 .33666 Metetra
.603 .802 .976 r
.61821 .33666 .62359 .34158 .63448 .33906 .62913 .33382 Metetra
.62 .796 .966 r
.62913 .33382 .63448 .33906 .64534 .33421 .64009 .33072 Metetra
.674 .886 .976 r
.64009 .33072 .64534 .33421 .65636 .33231 .65103 .32608 Metetra
.589 .746 .952 r
.65103 .32608 .65636 .33231 .66737 .329 .66212 .32379 Metetra
.629 .803 .966 r
.66212 .32379 .66737 .329 .67829 .32308 .67321 .32045 Metetra
.721 .934 .959 r
.67321 .32045 .67829 .32308 .6893 .31805 .68421 .31443 Metetra
.691 .891 .97 r
.68421 .31443 .6893 .31805 .70042 .31462 .69529 .30937 Metetra
.643 .81 .963 r
.69529 .30937 .70042 .31462 .71038 .29081 .70648 .30571 Metetra
.70648 .30571 .71038 .29081 .7181 .23316 .71648 .28183 Metetra
0 0 .252 r
.71648 .28183 .7181 .23316 .73135 .26344 .72415 .22394 Metetra
.138 .114 .565 r
.72415 .22394 .73135 .26344 .74249 .25975 .73756 .25429 Metetra
.651 .806 .957 r
.73756 .25429 .74249 .25975 .75394 .25943 .74878 .25048 Metetra
.523 .626 .895 r
.74878 .25048 .75394 .25943 .76551 .2599 .76031 .25011 Metetra
0 0 .369 r
.76031 .25011 .76551 .2599 .77889 .28141 .77389 .27429 Metetra
.656 .752 .92 r
.77389 .27429 .77889 .28141 .79033 .27756 .78536 .27041 Metetra
.656 .752 .92 r
.78536 .27041 .79033 .27756 .80182 .27369 .79688 .26652 Metetra
.656 .752 .92 r
.14451 .47914 .15105 .48484 .16017 .48176 .15365 .47604 Metetra
.656 .752 .92 r
.15365 .47604 .16017 .48176 .16932 .47867 .16282 .47292 Metetra
.656 .752 .92 r
.16282 .47292 .16932 .47867 .18132 .44881 .17203 .4698 Metetra
.834 .856 .402 r
.17203 .4698 .18132 .44881 .19081 .44234 .18435 .43712 Metetra
.917 .736 .641 r
.18435 .43712 .19081 .44234 .19998 .43916 .19689 .40108 Metetra
.706 .53 0 r
.19689 .40108 .19998 .43916 .21237 .40311 .20086 .45005 Metetra
.631 .346 .467 r
.20086 .45005 .21237 .40311 .21662 .45201 .20829 .46635 Metetra
.348 0 .174 r
.20829 .46635 .21662 .45201 .22417 .46823 .2177 .46305 Metetra
.577 .755 .962 r
.2177 .46305 .22417 .46823 .23358 .46499 .22701 .46124 Metetra
.457 .769 .997 r
.22701 .46124 .23358 .46499 .24291 .46314 .23627 .46037 Metetra
.633 .869 .986 r
.23627 .46037 .24291 .46314 .2522 .46221 .24579 .45701 Metetra
.712 .791 .913 r
.24579 .45701 .2522 .46221 .26175 .45874 .25545 .45236 Metetra
.594 .718 .93 r
.25545 .45236 .26175 .45874 .2714 .45423 .26492 .45043 Metetra
.664 .837 .966 r
.26492 .45043 .2714 .45423 .28091 .45211 .27457 .44679 Metetra
.67 .78 .932 r
.27457 .44679 .28091 .45211 .29056 .44844 .28424 .44317 Metetra
.648 .777 .942 r
.28424 .44317 .29056 .44844 .30025 .44473 .29391 .44001 Metetra
.668 .804 .948 r
.29391 .44001 .30025 .44473 .30994 .44159 .30366 .43637 Metetra
.696 .792 .925 r
.30366 .43637 .30994 .44159 .31972 .43737 .31347 .43208 Metetra
.713 .794 .915 r
.31347 .43208 .31972 .43737 .32954 .43316 .32335 .42731 Metetra
.721 .777 .897 r
.32335 .42731 .32954 .43316 .33946 .42761 .33327 .42222 Metetra
.754 .798 .889 r
.33327 .42222 .33946 .42761 .34936 .42293 .34328 .4161 Metetra
.778 .759 .836 r
.34328 .4161 .34936 .42293 .35954 .41339 .35339 .4083 Metetra
.755 .811 .897 r
.35339 .4083 .35954 .41339 .36958 .40665 .36343 .40222 Metetra
.946 .758 .615 r
.36343 .40222 .36958 .40665 .38097 .37026 .37507 .36254 Metetra
.955 .61 .296 r
.37507 .36254 .38097 .37026 .38868 .4174 .38264 .41108 Metetra
.782 .314 0 r
.38264 .41108 .38868 .4174 .39801 .43198 .3919 .42703 Metetra
.923 .789 .695 r
.3919 .42703 .39801 .43198 .40807 .43016 .40277 .40438 Metetra
.863 .633 .588 r
.40277 .40438 .40807 .43016 .41887 .40754 .41469 .34946 Metetra
.577 .387 .587 r
.41469 .34946 .41887 .40754 .43068 .3479 .42478 .34333 Metetra
.921 .528 .199 r
.42478 .34333 .43068 .3479 .44065 .34594 .43384 .37409 Metetra
.497 .183 .365 r
.43384 .37409 .44065 .34594 .45 .37207 .44394 .37393 Metetra
.44394 .37393 .45 .37207 .46017 .36929 .45415 .37113 Metetra
.607 .95 .806 r
.45415 .37113 .46017 .36929 .47089 .33605 .46448 .36422 Metetra
.46448 .36422 .47089 .33605 .48107 .33188 .47531 .32719 Metetra
.555 .781 .983 r
.47531 .32719 .48107 .33188 .49067 .38383 .48552 .32529 Metetra
0 0 .451 r
.48552 .32529 .49067 .38383 .50094 .40069 .4953 .37453 Metetra
.088 .119 .598 r
.4953 .37453 .50094 .40069 .51145 .39838 .50565 .39319 Metetra
.72 .82 .928 r
.50565 .39319 .51145 .39838 .52202 .39454 .51625 .38793 Metetra
.637 .746 .927 r
.51625 .38793 .52202 .39454 .53263 .39283 .52688 .38477 Metetra
.9 .758 .696 r
.52688 .38477 .53263 .39283 .54316 .36809 .53749 .36332 Metetra
.972 .749 .543 r
.53749 .36332 .54316 .36809 .55329 .31005 .54774 .30444 Metetra
.897 .487 .09 r
.54774 .30444 .55329 .31005 .56422 .34273 .55862 .33538 Metetra
.396 .606 .933 r
.55862 .33538 .56422 .34273 .57492 .34271 .56936 .33676 Metetra
.384 .654 .964 r
.56936 .33676 .57492 .34271 .5857 .3434 .58016 .33763 Metetra
.583 .759 .962 r
.58016 .33763 .5857 .3434 .5965 .34204 .59098 .33541 Metetra
.535 .706 .949 r
.59098 .33541 .5965 .34204 .60735 .34017 .60187 .33426 Metetra
.624 .771 .951 r
.60187 .33426 .60735 .34017 .61821 .33666 .61277 .33123 Metetra
.64 .796 .958 r
.61277 .33123 .61821 .33666 .62913 .33382 .6237 .32777 Metetra
.631 .77 .947 r
.6237 .32777 .62913 .33382 .64009 .33072 .63469 .32458 Metetra
.628 .767 .946 r
.63469 .32458 .64009 .33072 .65103 .32608 .64573 .32144 Metetra
.701 .851 .954 r
.64573 .32144 .65103 .32608 .66212 .32379 .65673 .31644 Metetra
.59 .71 .926 r
.65673 .31644 .66212 .32379 .67321 .32045 .66791 .31428 Metetra
.644 .775 .943 r
.66791 .31428 .67321 .32045 .68421 .31443 .67906 .31073 Metetra
.737 .9 .952 r
.67906 .31073 .68421 .31443 .69529 .30937 .69013 .30461 Metetra
.706 .852 .952 r
.69013 .30461 .69529 .30937 .70648 .30571 .70129 .29942 Metetra
.646 .774 .941 r
.70129 .29942 .70648 .30571 .71648 .28183 .71257 .29579 Metetra
.71257 .29579 .71648 .28183 .72415 .22394 .72259 .27172 Metetra
0 0 .244 r
.72259 .27172 .72415 .22394 .73756 .25429 .7302 .21364 Metetra
.15 .12 .566 r
.7302 .21364 .73756 .25429 .74878 .25048 .74377 .24396 Metetra
.77 .336 0 r
.74377 .24396 .74878 .25048 .76031 .25011 .75739 .27101 Metetra
.414 .081 .289 r
.75739 .27101 .76031 .25011 .77389 .27429 .76885 .26712 Metetra
.656 .752 .92 r
.76885 .26712 .77389 .27429 .78536 .27041 .78036 .26321 Metetra
.656 .752 .92 r
.78036 .26321 .78536 .27041 .79688 .26652 .79191 .25929 Metetra
.656 .752 .92 r
.13793 .4734 .14451 .47914 .15365 .47604 .14709 .47028 Metetra
.656 .752 .92 r
.14709 .47028 .15365 .47604 .16282 .47292 .15628 .46715 Metetra
.656 .752 .92 r
.15628 .46715 .16282 .47292 .17203 .4698 .1655 .464 Metetra
.927 .714 .595 r
.1655 .464 .17203 .4698 .18435 .43712 .18133 .39918 Metetra
.726 .545 0 r
.18133 .39918 .18435 .43712 .19689 .40108 .18503 .44822 Metetra
.63 .345 .466 r
.18503 .44822 .19689 .40108 .20086 .45005 .19235 .46454 Metetra
.349 0 .174 r
.19235 .46454 .20086 .45005 .20829 .46635 .20174 .46131 Metetra
.574 .76 .966 r
.20174 .46131 .20829 .46635 .2177 .46305 .21103 .4595 Metetra
.443 .772 .997 r
.21103 .4595 .2177 .46305 .22701 .46124 .22027 .45865 Metetra
.632 .875 .987 r
.22027 .45865 .22701 .46124 .23627 .46037 .22978 .45524 Metetra
.706 .792 .918 r
.22978 .45524 .23627 .46037 .24579 .45701 .23942 .45076 Metetra
.593 .723 .934 r
.23942 .45076 .24579 .45701 .25545 .45236 .24887 .44881 Metetra
.658 .846 .972 r
.24887 .44881 .25545 .45236 .26492 .45043 .2585 .44521 Metetra
.67 .785 .935 r
.2585 .44521 .26492 .45043 .27457 .44679 .26817 .44157 Metetra
.63 .775 .95 r
.26817 .44157 .27457 .44679 .28424 .44317 .27781 .43875 Metetra
.678 .819 .951 r
.27781 .43875 .28424 .44317 .29391 .44001 .28756 .43485 Metetra
.674 .791 .936 r
.28756 .43485 .29391 .44001 .30366 .43637 .29733 .43108 Metetra
.714 .795 .915 r
.29733 .43108 .30366 .43637 .31347 .43208 .30721 .42629 Metetra
.685 .772 .917 r
.30721 .42629 .31347 .43208 .32335 .42731 .31706 .42223 Metetra
.769 .811 .886 r
.31706 .42223 .32335 .42731 .33327 .42222 .32711 .41562 Metetra
.71 .752 .886 r
.32711 .41562 .33327 .42222 .34328 .4161 .33707 .41072 Metetra
.762 .802 .885 r
.33707 .41072 .34328 .4161 .35339 .4083 .34714 .40426 Metetra
.838 .847 .851 r
.34714 .40426 .35339 .4083 .36343 .40222 .35739 .39477 Metetra
.928 .733 .619 r
.35739 .39477 .36343 .40222 .37507 .36254 .36909 .35552 Metetra
.954 .612 .311 r
.36909 .35552 .37507 .36254 .38264 .41108 .37649 .40599 Metetra
.668 .8 .945 r
.37649 .40599 .38264 .41108 .3919 .42703 .38659 .40221 Metetra
.87 .639 .587 r
.38659 .40221 .3919 .42703 .40277 .40438 .39882 .3455 Metetra
.546 .362 .584 r
.39882 .3455 .40277 .40438 .41469 .34946 .40874 .34383 Metetra
.918 .521 .17 r
.40874 .34383 .41469 .34946 .42478 .34333 .41767 .37324 Metetra
.498 .188 .371 r
.41767 .37324 .42478 .34333 .43384 .37409 .42774 .37314 Metetra
.178 .705 .86 r
.42774 .37314 .43384 .37409 .44394 .37393 .43788 .37255 Metetra
.483 .874 .967 r
.43788 .37255 .44394 .37393 .45415 .37113 .44814 .36974 Metetra
.749 .955 .941 r
.44814 .36974 .45415 .37113 .46448 .36422 .45851 .36322 Metetra
.712 .961 .944 r
.45851 .36322 .46448 .36422 .47531 .32719 .46889 .35716 Metetra
0 0 .014 r
.46889 .35716 .47531 .32719 .48552 .32529 .47975 .3195 Metetra
.694 .787 .922 r
.47975 .3195 .48552 .32529 .4953 .37453 .49006 .31501 Metetra
0 0 .433 r
.49006 .31501 .4953 .37453 .50565 .39319 .49996 .36788 Metetra
.193 .197 .634 r
.49996 .36788 .50565 .39319 .51625 .38793 .51044 .38258 Metetra
.714 .816 .929 r
.51044 .38258 .51625 .38793 .52688 .38477 .5211 .37744 Metetra
.911 .771 .694 r
.5211 .37744 .52688 .38477 .53749 .36332 .53176 .35545 Metetra
.958 .734 .558 r
.53176 .35545 .53749 .36332 .54774 .30444 .54215 .29987 Metetra
.896 .479 .102 r
.54215 .29987 .54774 .30444 .55862 .33538 .55299 .32948 Metetra
.437 .685 .969 r
.55299 .32948 .55862 .33538 .56936 .33676 .56374 .32959 Metetra
.316 .569 .93 r
.56374 .32959 .56936 .33676 .58016 .33763 .57459 .33196 Metetra
.584 .764 .965 r
.57459 .33196 .58016 .33763 .59098 .33541 .58543 .32966 Metetra
.572 .757 .966 r
.58543 .32966 .59098 .33541 .60187 .33426 .59633 .32759 Metetra
.591 .731 .941 r
.59633 .32759 .60187 .33426 .61277 .33123 .60727 .32533 Metetra
.608 .768 .957 r
.60727 .32533 .61277 .33123 .6237 .32777 .61826 .32258 Metetra
.663 .817 .957 r
.61826 .32258 .6237 .32777 .63469 .32458 .62926 .31852 Metetra
.628 .772 .949 r
.62926 .31852 .63469 .32458 .64573 .32144 .64032 .31534 Metetra
.634 .773 .947 r
.64032 .31534 .64573 .32144 .65673 .31644 .65143 .31202 Metetra
.697 .861 .96 r
.65143 .31202 .65673 .31644 .66791 .31428 .66252 .30702 Metetra
.6 .719 .928 r
.66252 .30702 .66791 .31428 .67906 .31073 .67376 .30457 Metetra
.641 .777 .946 r
.67376 .30457 .67906 .31073 .69013 .30461 .685 .30104 Metetra
.738 .908 .952 r
.685 .30104 .69013 .30461 .70129 .29942 .69614 .2948 Metetra
.704 .86 .956 r
.69614 .2948 .70129 .29942 .71257 .29579 .70737 .28958 Metetra
.65 .781 .944 r
.70737 .28958 .71257 .29579 .72259 .27172 .71872 .2858 Metetra
.71872 .2858 .72259 .27172 .7302 .21364 .72878 .26164 Metetra
0 0 .245 r
.72878 .26164 .7302 .21364 .74377 .24396 .73634 .20334 Metetra
0 0 .391 r
.73634 .20334 .74377 .24396 .75739 .27101 .75228 .26381 Metetra
.656 .752 .92 r
.75228 .26381 .75739 .27101 .76885 .26712 .76378 .25989 Metetra
.656 .752 .92 r
.76378 .25989 .76885 .26712 .78036 .26321 .77531 .25595 Metetra
.656 .752 .92 r
.77531 .25595 .78036 .26321 .79191 .25929 .7869 .252 Metetra
.656 .752 .92 r
.13131 .46763 .13793 .4734 .14709 .47028 .14048 .46448 Metetra
.656 .752 .92 r
.14048 .46448 .14709 .47028 .15628 .46715 .14969 .46133 Metetra
.656 .752 .92 r
.14969 .46133 .15628 .46715 .1655 .464 .15893 .45816 Metetra
.656 .752 .92 r
.15893 .45816 .1655 .464 .18133 .39918 .16821 .45498 Metetra
.565 .288 .455 r
.16821 .45498 .18133 .39918 .18503 .44822 .1764 .46229 Metetra
.338 0 .158 r
.1764 .46229 .18503 .44822 .19235 .46454 .18578 .45903 Metetra
.576 .743 .956 r
.18578 .45903 .19235 .46454 .20174 .46131 .19504 .45727 Metetra
.464 .762 .995 r
.19504 .45727 .20174 .46131 .21103 .4595 .20425 .45643 Metetra
.637 .858 .983 r
.20425 .45643 .21103 .4595 .22027 .45865 .21374 .4531 Metetra
.707 .778 .908 r
.21374 .4531 .22027 .45865 .22978 .45524 .22338 .44855 Metetra
.591 .708 .924 r
.22338 .44855 .22978 .45524 .23942 .45076 .23281 .44667 Metetra
.661 .826 .962 r
.23281 .44667 .23942 .45076 .24887 .44881 .24243 .44311 Metetra
.663 .766 .926 r
.24243 .44311 .24887 .44881 .2585 .44521 .25207 .43963 Metetra
.64 .765 .939 r
.25207 .43963 .2585 .44521 .26817 .44157 .2617 .43664 Metetra
.666 .797 .945 r
.2617 .43664 .26817 .44157 .27781 .43875 .27142 .43303 Metetra
.674 .771 .923 r
.27142 .43303 .27781 .43875 .28756 .43485 .28118 .42925 Metetra
.702 .782 .913 r
.28118 .42925 .28756 .43485 .29733 .43108 .29103 .42474 Metetra
.686 .754 .903 r
.29103 .42474 .29733 .43108 .30721 .42629 .30089 .4206 Metetra
.734 .787 .895 r
.30089 .4206 .30721 .42629 .31706 .42223 .31086 .41508 Metetra
.713 .737 .87 r
.31086 .41508 .31706 .42223 .32711 .41562 .32084 .40993 Metetra
.665 .774 .93 r
.32084 .40993 .32711 .41562 .33707 .41072 .33075 .4063 Metetra
.847 .832 .831 r
.33075 .4063 .33707 .41072 .34714 .40426 .34108 .39589 Metetra
.77 .722 .808 r
.34108 .39589 .34714 .40426 .35739 .39477 .35129 .38756 Metetra
.927 .736 .624 r
.35129 .38756 .35739 .39477 .36909 .35552 .363 .34997 Metetra
.925 .537 .206 r
.363 .34997 .36909 .35552 .37649 .40599 .3713 .38007 Metetra
.823 .608 .612 r
.3713 .38007 .37649 .40599 .38659 .40221 .38287 .34257 Metetra
.549 .364 .582 r
.38287 .34257 .38659 .40221 .39882 .3455 .39279 .34021 Metetra
.927 .542 .212 r
.39279 .34021 .39882 .3455 .40874 .34383 .40143 .37244 Metetra
.468 .156 .353 r
.40143 .37244 .40874 .34383 .41767 .37324 .41153 .37059 Metetra
0 .508 .818 r
.41153 .37059 .41767 .37324 .42774 .37314 .42155 .37291 Metetra
.623 .952 .931 r
.42155 .37291 .42774 .37314 .43788 .37255 .43187 .36771 Metetra
.613 .799 .971 r
.43187 .36771 .43788 .37255 .44814 .36974 .44215 .36487 Metetra
.557 .778 .981 r
.44215 .36487 .44814 .36974 .45851 .36322 .45245 .36293 Metetra
.804 .984 .892 r
.45245 .36293 .45851 .36322 .46889 .35716 .46294 .35441 Metetra
.755 .915 .945 r
.46294 .35441 .46889 .35716 .47975 .3195 .47339 .34813 Metetra
.47339 .34813 .47975 .3195 .49006 .31501 .48428 .30951 Metetra
.579 .762 .965 r
.48428 .30951 .49006 .31501 .49996 .36788 .49463 .30738 Metetra
.003 0 .46 r
.49463 .30738 .49996 .36788 .51044 .38258 .50471 .3559 Metetra
.183 .183 .623 r
.50471 .3559 .51044 .38258 .5211 .37744 .51528 .37168 Metetra
.933 .794 .683 r
.51528 .37168 .5211 .37744 .53176 .35545 .526 .34783 Metetra
.96 .735 .555 r
.526 .34783 .53176 .35545 .54215 .29987 .5365 .291 Metetra
.884 .491 .038 r
.5365 .291 .54215 .29987 .55299 .32948 .54733 .32456 Metetra
.5 .758 .988 r
.54733 .32456 .55299 .32948 .56374 .32959 .55809 .32334 Metetra
.392 .65 .961 r
.55809 .32334 .56374 .32959 .57459 .33196 .56894 .32417 Metetra
.532 .666 .923 r
.56894 .32417 .57459 .33196 .58543 .32966 .57983 .32332 Metetra
.579 .739 .952 r
.57983 .32332 .58543 .32966 .59633 .32759 .59075 .32122 Metetra
.62 .756 .943 r
.59075 .32122 .59633 .32759 .60727 .32533 .60171 .31828 Metetra
.59 .72 .934 r
.60171 .31828 .60727 .32533 .61826 .32258 .61274 .31606 Metetra
.635 .758 .937 r
.61274 .31606 .61826 .32258 .62926 .31852 .62379 .31275 Metetra
.657 .795 .948 r
.62379 .31275 .62926 .31852 .64032 .31534 .63487 .30886 Metetra
.642 .764 .937 r
.63487 .30886 .64032 .31534 .65143 .31202 .646 .30536 Metetra
.637 .757 .935 r
.646 .30536 .65143 .31202 .66252 .30702 .65719 .30197 Metetra
.706 .842 .948 r
.65719 .30197 .66252 .30702 .67376 .30457 .66834 .29679 Metetra
.599 .704 .918 r
.66834 .29679 .67376 .30457 .685 .30104 .67967 .29439 Metetra
.648 .764 .934 r
.67967 .29439 .685 .30104 .69614 .2948 .69098 .29068 Metetra
.742 .891 .947 r
.69098 .29068 .69614 .2948 .70737 .28958 .70219 .2844 Metetra
.71 .843 .946 r
.70219 .2844 .70737 .28958 .71872 .2858 .71349 .27904 Metetra
.65 .764 .933 r
.71349 .27904 .71872 .2858 .72878 .26164 .72493 .27525 Metetra
0 0 .026 r
.72493 .27525 .72878 .26164 .73634 .20334 .73566 .26049 Metetra
.484 .214 .429 r
.73566 .26049 .73634 .20334 .75228 .26381 .74714 .25656 Metetra
.656 .752 .92 r
.74714 .25656 .75228 .26381 .76378 .25989 .75866 .25261 Metetra
.656 .752 .92 r
.75866 .25261 .76378 .25989 .77531 .25595 .77023 .24864 Metetra
.656 .752 .92 r
.77023 .24864 .77531 .25595 .7869 .252 .78185 .24466 Metetra
.656 .752 .92 r
.12464 .46181 .13131 .46763 .14048 .46448 .13383 .45865 Metetra
.656 .752 .92 r
.13383 .45865 .14048 .46448 .14969 .46133 .14306 .45547 Metetra
.656 .752 .92 r
.14306 .45547 .14969 .46133 .15893 .45816 .15232 .45228 Metetra
.656 .752 .92 r
.15232 .45228 .15893 .45816 .16821 .45498 .16161 .44908 Metetra
.517 0 0 r
.16161 .44908 .16821 .45498 .1764 .46229 .16975 .45685 Metetra
.574 .746 .958 r
.16975 .45685 .1764 .46229 .18578 .45903 .17899 .45509 Metetra
.455 .763 .996 r
.17899 .45509 .18578 .45903 .19504 .45727 .18817 .45427 Metetra
.635 .861 .984 r
.18817 .45427 .19504 .45727 .20425 .45643 .19765 .45093 Metetra
.704 .78 .911 r
.19765 .45093 .20425 .45643 .21374 .4531 .20728 .44647 Metetra
.591 .711 .927 r
.20728 .44647 .21374 .4531 .22338 .44855 .21669 .44457 Metetra
.657 .83 .966 r
.21669 .44457 .22338 .44855 .23281 .44667 .22628 .44107 Metetra
.666 .771 .928 r
.22628 .44107 .23281 .44667 .24243 .44311 .23592 .43753 Metetra
.628 .762 .943 r
.23592 .43753 .24243 .44311 .25207 .43963 .24552 .43476 Metetra
.668 .8 .946 r
.24552 .43476 .25207 .43963 .2617 .43664 .25523 .4311 Metetra
.668 .776 .931 r
.25523 .4311 .2617 .43664 .27142 .43303 .26497 .42746 Metetra
.704 .784 .914 r
.26497 .42746 .27142 .43303 .28118 .42925 .27482 .4229 Metetra
.665 .749 .912 r
.27482 .4229 .28118 .42925 .29103 .42474 .28463 .41928 Metetra
.745 .796 .894 r
.28463 .41928 .29103 .42474 .30089 .4206 .29462 .41344 Metetra
.68 .729 .887 r
.29462 .41344 .30089 .4206 .31086 .41508 .30453 .40933 Metetra
.673 .774 .926 r
.30453 .40933 .31086 .41508 .32084 .40993 .31444 .40552 Metetra
.791 .838 .887 r
.31444 .40552 .32084 .40993 .33075 .4063 .32461 .39818 Metetra
.788 .732 .8 r
.32461 .39818 .33075 .4063 .34108 .39589 .3349 .38884 Metetra
.762 .754 .846 r
.3349 .38884 .34108 .39589 .35129 .38756 .34508 .38169 Metetra
.947 .732 .58 r
.34508 .38169 .35129 .38756 .363 .34997 .3579 .32491 Metetra
.596 .463 .669 r
.3579 .32491 .363 .34997 .3713 .38007 .36778 .32118 Metetra
.391 .245 .56 r
.36778 .32118 .3713 .38007 .38287 .34257 .3768 .33657 Metetra
.929 .544 .205 r
.3768 .33657 .38287 .34257 .39279 .34021 .38524 .36864 Metetra
.523 .204 .369 r
.38524 .36864 .39279 .34021 .40143 .37244 .39516 .37069 Metetra
.333 .787 .95 r
.39516 .37069 .40143 .37244 .41153 .37059 .40528 .36949 Metetra
.439 .859 .951 r
.40528 .36949 .41153 .37059 .42155 .37291 .4155 .36689 Metetra
.599 .75 .949 r
.4155 .36689 .42155 .37291 .43187 .36771 .42575 .36452 Metetra
.574 .853 .996 r
.42575 .36452 .43187 .36771 .44215 .36487 .43607 .36166 Metetra
.695 .888 .969 r
.43607 .36166 .44215 .36487 .45245 .36293 .44648 .35684 Metetra
.657 .769 .932 r
.44648 .35684 .45245 .36293 .46294 .35441 .45689 .35321 Metetra
.758 .964 .932 r
.45689 .35321 .46294 .35441 .47339 .34813 .4674 .34624 Metetra
.815 .946 .909 r
.4674 .34624 .47339 .34813 .48428 .30951 .47795 .33799 Metetra
.47795 .33799 .48428 .30951 .49463 .30738 .48884 .30112 Metetra
.729 .785 .897 r
.48884 .30112 .49463 .30738 .50471 .3559 .4993 .29548 Metetra
0 0 .453 r
.4993 .29548 .50471 .3559 .51528 .37168 .50951 .34523 Metetra
.591 .458 .669 r
.50951 .34523 .51528 .37168 .526 .34783 .5202 .34158 Metetra
.966 .743 .549 r
.5202 .34158 .526 .34783 .5365 .291 .53082 .28342 Metetra
.891 .49 .059 r
.53082 .28342 .5365 .291 .54733 .32456 .5416 .31588 Metetra
.354 .543 .901 r
.5416 .31588 .54733 .32456 .55809 .32334 .55241 .31837 Metetra
.448 .734 .988 r
.55241 .31837 .55809 .32334 .56894 .32417 .56327 .3178 Metetra
.591 .744 .95 r
.56327 .3178 .56894 .32417 .57983 .32332 .57416 .31546 Metetra
.507 .654 .925 r
.57416 .31546 .57983 .32332 .59075 .32122 .58514 .31505 Metetra
.63 .769 .947 r
.58514 .31505 .59075 .32122 .60171 .31828 .59612 .31184 Metetra
.615 .754 .945 r
.59612 .31184 .60171 .31828 .61274 .31606 .60716 .30897 Metetra
.606 .728 .932 r
.60716 .30897 .61274 .31606 .62379 .31275 .61826 .30636 Metetra
.631 .764 .943 r
.61826 .30636 .62379 .31275 .63487 .30886 .62939 .3031 Metetra
.671 .803 .946 r
.62939 .3031 .63487 .30886 .646 .30536 .64054 .29882 Metetra
.638 .763 .939 r
.64054 .29882 .646 .30536 .65719 .30197 .65175 .29536 Metetra
.642 .763 .937 r
.65175 .29536 .65719 .30197 .66834 .29679 .66301 .29181 Metetra
.704 .847 .951 r
.66301 .29181 .66834 .29679 .67967 .29439 .67424 .2866 Metetra
.604 .709 .919 r
.67424 .2866 .67967 .29439 .69098 .29068 .68564 .28403 Metetra
.647 .767 .936 r
.68564 .28403 .69098 .29068 .70219 .2844 .69704 .2803 Metetra
.744 .894 .947 r
.69704 .2803 .70219 .2844 .71349 .27904 .70832 .27391 Metetra
.709 .847 .948 r
.70832 .27391 .71349 .27904 .72493 .27525 .7197 .26851 Metetra
.896 .823 .768 r
.7197 .26851 .72493 .27525 .73566 .26049 .73045 .25322 Metetra
.656 .752 .92 r
.73045 .25322 .73566 .26049 .74714 .25656 .74196 .24926 Metetra
.656 .752 .92 r
.74196 .24926 .74714 .25656 .75866 .25261 .75351 .24528 Metetra
.656 .752 .92 r
.75351 .24528 .75866 .25261 .77023 .24864 .76512 .24128 Metetra
.656 .752 .92 r
.76512 .24128 .77023 .24864 .78185 .24466 .77677 .23727 Metetra
.656 .752 .92 r
.11792 .45596 .12464 .46181 .13383 .45865 .12714 .45277 Metetra
.656 .752 .92 r
.12714 .45277 .13383 .45865 .14306 .45547 .13638 .44957 Metetra
.656 .752 .92 r
.13638 .44957 .14306 .45547 .15232 .45228 .14566 .44636 Metetra
.656 .752 .92 r
.14566 .44636 .15232 .45228 .16161 .44908 .15498 .44314 Metetra
.656 .752 .92 r
.15498 .44314 .16161 .44908 .16975 .45685 .16432 .43991 Metetra
0 .07 .611 r
.16432 .43991 .16975 .45685 .17899 .45509 .17207 .45183 Metetra
.637 .851 .982 r
.17207 .45183 .17899 .45509 .18817 .45427 .18153 .44854 Metetra
.704 .772 .905 r
.18153 .44854 .18817 .45427 .19765 .45093 .19115 .44403 Metetra
.588 .701 .921 r
.19115 .44403 .19765 .45093 .20728 .44647 .20053 .44221 Metetra
.659 .82 .96 r
.20053 .44221 .20728 .44647 .21669 .44457 .21012 .43869 Metetra
.66 .76 .924 r
.21012 .43869 .21669 .44457 .22628 .44107 .21973 .43526 Metetra
.633 .756 .937 r
.21973 .43526 .22628 .44107 .23592 .43753 .22932 .43241 Metetra
.662 .79 .943 r
.22932 .43241 .23592 .43753 .24552 .43476 .239 .42888 Metetra
.667 .764 .923 r
.239 .42888 .24552 .43476 .25523 .4311 .24873 .42525 Metetra
.693 .772 .912 r
.24873 .42525 .25523 .4311 .26497 .42746 .25855 .42094 Metetra
.673 .746 .906 r
.25855 .42094 .26497 .42746 .27482 .4229 .26836 .41712 Metetra
.728 .783 .897 r
.26836 .41712 .27482 .4229 .28463 .41928 .27832 .41176 Metetra
.681 .719 .878 r
.27832 .41176 .28463 .41928 .29462 .41344 .28822 .40757 Metetra
.636 .76 .937 r
.28822 .40757 .29462 .41344 .30453 .40933 .29807 .40457 Metetra
.794 .826 .877 r
.29807 .40457 .30453 .40933 .31444 .40552 .30826 .39697 Metetra
.727 .708 .832 r
.30826 .39697 .31444 .40552 .32461 .39818 .31838 .39077 Metetra
.773 .747 .83 r
.31838 .39077 .32461 .39818 .3349 .38884 .32862 .38288 Metetra
.92 .762 .669 r
.32862 .38288 .3349 .38884 .34508 .38169 .33997 .35607 Metetra
.899 .655 .56 r
.33997 .35607 .34508 .38169 .3579 .32491 .35465 .26692 Metetra
0 0 .397 r
.35465 .26692 .3579 .32491 .36778 .32118 .36169 .31513 Metetra
.951 .607 .313 r
.36169 .31513 .36778 .32118 .3768 .33657 .36901 .36486 Metetra
.506 .187 .361 r
.36901 .36486 .3768 .33657 .38524 .36864 .37894 .36583 Metetra
0 .412 .748 r
.37894 .36583 .38524 .36864 .39516 .37069 .38883 .36908 Metetra
.677 .935 .967 r
.38883 .36908 .39516 .37069 .40528 .36949 .39913 .36402 Metetra
.541 .749 .973 r
.39913 .36402 .40528 .36949 .4155 .36689 .40934 .36249 Metetra
.594 .812 .983 r
.40934 .36249 .4155 .36689 .42575 .36452 .41963 .3598 Metetra
.609 .806 .975 r
.41963 .3598 .42575 .36452 .43607 .36166 .42998 .35692 Metetra
.693 .83 .949 r
.42998 .35692 .43607 .36166 .44648 .35684 .44041 .35237 Metetra
.699 .843 .951 r
.44041 .35237 .44648 .35684 .45689 .35321 .45088 .34762 Metetra
.63 .782 .954 r
.45088 .34762 .45689 .35321 .4674 .34624 .46135 .34448 Metetra
.847 .946 .884 r
.46135 .34448 .4674 .34624 .47795 .33799 .47198 .33499 Metetra
.717 .905 .962 r
.47198 .33499 .47795 .33799 .48884 .30112 .48254 .32952 Metetra
.48254 .32952 .48884 .30112 .4993 .29548 .49349 .28914 Metetra
.714 .781 .904 r
.49349 .28914 .4993 .29548 .50951 .34523 .504 .28393 Metetra
.237 .136 .531 r
.504 .28393 .50951 .34523 .5202 .34158 .51442 .31506 Metetra
.831 .61 .602 r
.51442 .31506 .5202 .34158 .53082 .28342 .52511 .27693 Metetra
.893 .483 .07 r
.52511 .27693 .53082 .28342 .5416 .31588 .53584 .30791 Metetra
.408 .598 .923 r
.53584 .30791 .5416 .31588 .55241 .31837 .54666 .3092 Metetra
.318 .509 .887 r
.54666 .3092 .55241 .31837 .56327 .3178 .55756 .31243 Metetra
.639 .802 .961 r
.55756 .31243 .56327 .3178 .57416 .31546 .56847 .30891 Metetra
.58 .736 .949 r
.56847 .30891 .57416 .31546 .58514 .31505 .57945 .30677 Metetra
.562 .67 .91 r
.57945 .30677 .58514 .31505 .59612 .31184 .59049 .30528 Metetra
.619 .753 .942 r
.59049 .30528 .59612 .31184 .60716 .30897 .60156 .30231 Metetra
.637 .757 .935 r
.60156 .30231 .60716 .30897 .61826 .30636 .61267 .29892 Metetra
.606 .719 .925 r
.61267 .29892 .61826 .30636 .62939 .3031 .62385 .29629 Metetra
.642 .756 .932 r
.62385 .29629 .62939 .3031 .64054 .29882 .63505 .29275 Metetra
.668 .793 .942 r
.63505 .29275 .64054 .29882 .65175 .29536 .64627 .28853 Metetra
.646 .759 .931 r
.64627 .28853 .65175 .29536 .66301 .29181 .65755 .28485 Metetra
.642 .754 .93 r
.65755 .28485 .66301 .29181 .67424 .2866 .66889 .28128 Metetra
.71 .838 .943 r
.66889 .28128 .67424 .2866 .68564 .28403 .68019 .2759 Metetra
.603 .7 .912 r
.68019 .2759 .68564 .28403 .69704 .2803 .69168 .27333 Metetra
.651 .76 .929 r
.69168 .27333 .69704 .2803 .70832 .27391 .70315 .26947 Metetra
.951 .865 .718 r
.70315 .26947 .70832 .27391 .7197 .26851 .71369 .24987 Metetra
.613 .525 .73 r
.71369 .24987 .7197 .26851 .73045 .25322 .72519 .24589 Metetra
.656 .752 .92 r
.72519 .24589 .73045 .25322 .74196 .24926 .73673 .2419 Metetra
.656 .752 .92 r
.73673 .2419 .74196 .24926 .75351 .24528 .74832 .23789 Metetra
.656 .752 .92 r
.74832 .23789 .75351 .24528 .76512 .24128 .75996 .23386 Metetra
.656 .752 .92 r
.75996 .23386 .76512 .24128 .77677 .23727 .77165 .22982 Metetra
.656 .752 .92 r
.11116 .45007 .11792 .45596 .12714 .45277 .1204 .44686 Metetra
.656 .752 .92 r
.1204 .44686 .12714 .45277 .13638 .44957 .12966 .44364 Metetra
.656 .752 .92 r
.12966 .44364 .13638 .44957 .14566 .44636 .13896 .44041 Metetra
.656 .752 .92 r
.13896 .44041 .14566 .44636 .15498 .44314 .14829 .43716 Metetra
.656 .752 .92 r
.14829 .43716 .15498 .44314 .16432 .43991 .15766 .43391 Metetra
.656 .752 .92 r
.15766 .43391 .16432 .43991 .17207 .45183 .16706 .43064 Metetra
.134 .172 .636 r
.16706 .43064 .17207 .45183 .18153 .44854 .17496 .44166 Metetra
.587 .703 .923 r
.17496 .44166 .18153 .44854 .19115 .44403 .18432 .43983 Metetra
.656 .822 .963 r
.18432 .43983 .19115 .44403 .20053 .44221 .19389 .43636 Metetra
.661 .762 .925 r
.19389 .43636 .20053 .44221 .21012 .43869 .20349 .4329 Metetra
.627 .756 .94 r
.20349 .4329 .21012 .43869 .21973 .43526 .21305 .43017 Metetra
.663 .792 .943 r
.21305 .43017 .21973 .43526 .22932 .43241 .22273 .42661 Metetra
.662 .767 .927 r
.22273 .42661 .22932 .43241 .239 .42888 .23243 .42308 Metetra
.697 .776 .912 r
.23243 .42308 .239 .42888 .24873 .42525 .24225 .41868 Metetra
.66 .742 .91 r
.24225 .41868 .24873 .42525 .25855 .42094 .25202 .41518 Metetra
.731 .785 .896 r
.25202 .41518 .25855 .42094 .26836 .41712 .26199 .40973 Metetra
.67 .72 .887 r
.26199 .40973 .26836 .41712 .27832 .41176 .27185 .40588 Metetra
.642 .762 .936 r
.27185 .40588 .27832 .41176 .28822 .40757 .28169 .40275 Metetra
.767 .824 .896 r
.28169 .40275 .28822 .40757 .29807 .40457 .29182 .39621 Metetra
.739 .716 .83 r
.29182 .39621 .29807 .40457 .30826 .39697 .30198 .38952 Metetra
.699 .73 .874 r
.30198 .38952 .30826 .39697 .31838 .39077 .31202 .38471 Metetra
.92 .759 .666 r
.31202 .38471 .31838 .39077 .32862 .38288 .32354 .35715 Metetra
.869 .637 .585 r
.32354 .35715 .32862 .38288 .33997 .35607 .3369 .29718 Metetra
.715 .49 .582 r
.3369 .29718 .33997 .35607 .35465 .26692 .34859 .2609 Metetra
.959 .644 .385 r
.34859 .2609 .35465 .26692 .36169 .31513 .35374 .34259 Metetra
.693 .366 .418 r
.35374 .34259 .36169 .31513 .36901 .36486 .36261 .36233 Metetra
0 .522 .819 r
.36261 .36233 .36901 .36486 .37894 .36583 .37251 .36437 Metetra
.343 .8 .942 r
.37251 .36437 .37894 .36583 .38883 .36908 .38264 .36286 Metetra
.651 .761 .93 r
.38264 .36286 .38883 .36908 .39913 .36402 .3929 .3594 Metetra
.456 .748 .992 r
.3929 .3594 .39913 .36402 .40934 .36249 .4031 .35863 Metetra
.685 .861 .966 r
.4031 .35863 .40934 .36249 .41963 .3598 .41349 .35413 Metetra
.62 .774 .955 r
.41349 .35413 .41963 .3598 .42998 .35692 .42386 .35123 Metetra
.613 .772 .956 r
.42386 .35123 .42998 .35692 .44041 .35237 .43428 .34844 Metetra
.729 .87 .947 r
.43428 .34844 .44041 .35237 .45088 .34762 .4448 .34289 Metetra
.701 .835 .947 r
.4448 .34289 .45088 .34762 .46135 .34448 .45534 .33808 Metetra
.697 .775 .912 r
.45534 .33808 .46135 .34448 .47198 .33499 .46591 .33334 Metetra
.744 .953 .944 r
.46591 .33334 .47198 .33499 .48254 .32952 .47655 .32676 Metetra
.85 .918 .878 r
.47655 .32676 .48254 .32952 .49349 .28914 .48724 .31709 Metetra
.48724 .31709 .49349 .28914 .504 .28393 .49819 .27765 Metetra
.927 .786 .684 r
.49819 .27765 .504 .28393 .51442 .31506 .50885 .25442 Metetra
.553 .365 .58 r
.50885 .25442 .51442 .31506 .52511 .27693 .51938 .25085 Metetra
.716 .459 0 r
.51938 .25085 .52511 .27693 .53584 .30791 .53005 .30131 Metetra
.466 .68 .958 r
.53005 .30131 .53584 .30791 .54666 .3092 .54087 .30114 Metetra
.343 .561 .917 r
.54087 .30114 .54666 .3092 .55756 .31243 .55179 .30339 Metetra
.495 .615 .9 r
.55179 .30339 .55756 .31243 .56847 .30891 .56276 .30343 Metetra
.625 .796 .964 r
.56276 .30343 .56847 .30891 .57945 .30677 .57374 .30015 Metetra
.623 .753 .94 r
.57374 .30015 .57945 .30677 .59049 .30528 .58479 .29708 Metetra
.553 .671 .916 r
.58479 .29708 .59049 .30528 .60156 .30231 .59591 .29572 Metetra
.643 .764 .937 r
.59591 .29572 .60156 .30231 .61267 .29892 .60705 .29216 Metetra
.631 .754 .936 r
.60705 .29216 .61267 .29892 .62385 .29629 .61824 .28885 Metetra
.615 .726 .925 r
.61824 .28885 .62385 .29629 .63505 .29275 .62949 .28596 Metetra
.64 .759 .935 r
.62949 .28596 .63505 .29275 .64627 .28853 .64077 .28242 Metetra
.675 .797 .94 r
.64077 .28242 .64627 .28853 .65755 .28485 .65206 .27798 Metetra
.645 .76 .932 r
.65206 .27798 .65755 .28485 .66889 .28128 .66343 .27428 Metetra
.645 .757 .93 r
.66343 .27428 .66889 .28128 .68019 .2759 .67484 .27058 Metetra
.709 .841 .945 r
.67484 .27058 .68019 .2759 .69168 .27333 .68622 .26517 Metetra
.904 .787 .722 r
.68622 .26517 .69168 .27333 .70315 .26947 .69689 .2465 Metetra
.6 .485 .694 r
.69689 .2465 .70315 .26947 .71369 .24987 .70837 .24251 Metetra
.656 .752 .92 r
.70837 .24251 .71369 .24987 .72519 .24589 .7199 .2385 Metetra
.656 .752 .92 r
.7199 .2385 .72519 .24589 .73673 .2419 .73147 .23448 Metetra
.656 .752 .92 r
.73147 .23448 .73673 .2419 .74832 .23789 .7431 .23044 Metetra
.656 .752 .92 r
.7431 .23044 .74832 .23789 .75996 .23386 .75477 .22639 Metetra
.656 .752 .92 r
.75477 .22639 .75996 .23386 .77165 .22982 .76649 .22231 Metetra
.656 .752 .92 r
.10436 .44414 .11116 .45007 .1204 .44686 .11361 .44091 Metetra
.656 .752 .92 r
.11361 .44091 .1204 .44686 .12966 .44364 .12289 .43766 Metetra
.656 .752 .92 r
.12289 .43766 .12966 .44364 .13896 .44041 .13221 .43441 Metetra
.656 .752 .92 r
.13221 .43441 .13896 .44041 .14829 .43716 .14156 .43114 Metetra
.656 .752 .92 r
.14156 .43114 .14829 .43716 .15766 .43391 .15095 .42787 Metetra
.656 .752 .92 r
.15095 .42787 .15766 .43391 .16706 .43064 .16037 .42458 Metetra
.792 .31 0 r
.16037 .42458 .16706 .43064 .17496 .44166 .16807 .4373 Metetra
.658 .816 .959 r
.16807 .4373 .17496 .44166 .18432 .43983 .17763 .4338 Metetra
.658 .756 .922 r
.17763 .4338 .18432 .43983 .19389 .43636 .1872 .43042 Metetra
.629 .752 .936 r
.1872 .43042 .19389 .43636 .20349 .4329 .19675 .42763 Metetra
.659 .784 .941 r
.19675 .42763 .20349 .4329 .21305 .43017 .20641 .42417 Metetra
.663 .761 .923 r
.20641 .42417 .21305 .43017 .22273 .42661 .2161 .42062 Metetra
.69 .768 .912 r
.2161 .42062 .22273 .42661 .23243 .42308 .2259 .41638 Metetra
.663 .739 .906 r
.2259 .41638 .23243 .42308 .24225 .41868 .23566 .41277 Metetra
.723 .779 .897 r
.23566 .41277 .24225 .41868 .25202 .41518 .24561 .40754 Metetra
.669 .713 .881 r
.24561 .40754 .25202 .41518 .26199 .40973 .25546 .40366 Metetra
.62 .749 .939 r
.25546 .40366 .26199 .40973 .27185 .40588 .26525 .40099 Metetra
.774 .822 .89 r
.26525 .40099 .27185 .40588 .28169 .40275 .2754 .39416 Metetra
.714 .704 .839 r
.2754 .39416 .28169 .40275 .29182 .39621 .28549 .38848 Metetra
.704 .724 .865 r
.28549 .38848 .29182 .39621 .30198 .38952 .29555 .38343 Metetra
.912 .763 .682 r
.29555 .38343 .30198 .38952 .31202 .38471 .30699 .35866 Metetra
.869 .637 .585 r
.30699 .35866 .31202 .38471 .32354 .35715 .3207 .29778 Metetra
.575 .381 .581 r
.3207 .29778 .32354 .35715 .3369 .29718 .33072 .29095 Metetra
.669 .758 .917 r
.33072 .29095 .3369 .29718 .34859 .2609 .34057 .28718 Metetra
.823 .506 .453 r
.34057 .28718 .34859 .2609 .35374 .34259 .34729 .33988 Metetra
.875 .438 .137 r
.34729 .33988 .35374 .34259 .36261 .36233 .35612 .36022 Metetra
.448 .838 .983 r
.35612 .36022 .36261 .36233 .37251 .36437 .36624 .35821 Metetra
.446 .682 .965 r
.36624 .35821 .37251 .36437 .38264 .36286 .37633 .35818 Metetra
.649 .82 .965 r
.37633 .35818 .38264 .36286 .3929 .3594 .38663 .35456 Metetra
.556 .783 .984 r
.38663 .35456 .3929 .3594 .4031 .35863 .3969 .35254 Metetra
.647 .768 .937 r
.3969 .35254 .4031 .35863 .41349 .35413 .40728 .3491 Metetra
.613 .798 .97 r
.40728 .3491 .41349 .35413 .42386 .35123 .41768 .34617 Metetra
.662 .813 .956 r
.41768 .34617 .42386 .35123 .43428 .34844 .42816 .34227 Metetra
.683 .779 .924 r
.42816 .34227 .43428 .34844 .4448 .34289 .43868 .33793 Metetra
.695 .827 .946 r
.43868 .33793 .4448 .34289 .45534 .33808 .44925 .33324 Metetra
.753 .844 .919 r
.44925 .33324 .45534 .33808 .46591 .33334 .45989 .32695 Metetra
.601 .746 .946 r
.45989 .32695 .46591 .33334 .47655 .32676 .47048 .32443 Metetra
.862 .93 .869 r
.47048 .32443 .47655 .32676 .48724 .31709 .48123 .31418 Metetra
.823 .919 .901 r
.48123 .31418 .48724 .31709 .49819 .27765 .49197 .30559 Metetra
.797 .741 .217 r
.49197 .30559 .49819 .27765 .50885 .25442 .50306 .2478 Metetra
.964 .741 .552 r
.50306 .2478 .50885 .25442 .51938 .25085 .51381 .1915 Metetra
0 0 .233 r
.51381 .1915 .51938 .25085 .53005 .30131 .52422 .27449 Metetra
.053 .093 .585 r
.52422 .27449 .53005 .30131 .54087 .30114 .53506 .29445 Metetra
.416 .654 .957 r
.53506 .29445 .54087 .30114 .55179 .30339 .54598 .29499 Metetra
.533 .654 .913 r
.54598 .29499 .55179 .30339 .56276 .30343 .55695 .2941 Metetra
.476 .599 .895 r
.55695 .2941 .56276 .30343 .57374 .30015 .56801 .29455 Metetra
.672 .81 .949 r
.56801 .29455 .57374 .30015 .58479 .29708 .57907 .29022 Metetra
.62 .746 .937 r
.57907 .29022 .58479 .29708 .59591 .29572 .59019 .28719 Metetra
.575 .673 .906 r
.59019 .28719 .59591 .29572 .60705 .29216 .60139 .28535 Metetra
.637 .757 .935 r
.60139 .28535 .60705 .29216 .61824 .28885 .6126 .28189 Metetra
.643 .755 .93 r
.6126 .28189 .61824 .28885 .62949 .28596 .62386 .27827 Metetra
.614 .72 .921 r
.62386 .27827 .62949 .28596 .64077 .28242 .63519 .27537 Metetra
.647 .756 .928 r
.63519 .27537 .64077 .28242 .65206 .27798 .64655 .27162 Metetra
.673 .79 .937 r
.64655 .27162 .65206 .27798 .66343 .27428 .65792 .26718 Metetra
.65 .757 .928 r
.65792 .26718 .66343 .27428 .67484 .27058 .66936 .26333 Metetra
.645 .751 .926 r
.66936 .26333 .67484 .27058 .68622 .26517 .68086 .2596 Metetra
.944 .838 .71 r
.68086 .2596 .68622 .26517 .69689 .2465 .69149 .23912 Metetra
.656 .752 .92 r
.69149 .23912 .69689 .2465 .70837 .24251 .703 .2351 Metetra
.656 .752 .92 r
.703 .2351 .70837 .24251 .7199 .2385 .71457 .23106 Metetra
.656 .752 .92 r
.71457 .23106 .7199 .2385 .73147 .23448 .72617 .22701 Metetra
.656 .752 .92 r
.72617 .22701 .73147 .23448 .7431 .23044 .73783 .22294 Metetra
.656 .752 .92 r
.73783 .22294 .7431 .23044 .75477 .22639 .74953 .21885 Metetra
.656 .752 .92 r
.74953 .21885 .75477 .22639 .76649 .22231 .76129 .21475 Metetra
.656 .752 .92 r
.09751 .43816 .10436 .44414 .11361 .44091 .10678 .43491 Metetra
.656 .752 .92 r
.10678 .43491 .11361 .44091 .12289 .43766 .11608 .43165 Metetra
.656 .752 .92 r
.11608 .43165 .12289 .43766 .13221 .43441 .12542 .42837 Metetra
.656 .752 .92 r
.12542 .42837 .13221 .43441 .14156 .43114 .13479 .42508 Metetra
.656 .752 .92 r
.13479 .42508 .14156 .43114 .15095 .42787 .1442 .42179 Metetra
.656 .752 .92 r
.1442 .42179 .15095 .42787 .16037 .42458 .15364 .41847 Metetra
.656 .752 .92 r
.15364 .41847 .16037 .42458 .16807 .4373 .16311 .41515 Metetra
.062 .114 .605 r
.16311 .41515 .16807 .4373 .17763 .4338 .17087 .42788 Metetra
.625 .752 .938 r
.17087 .42788 .17763 .4338 .1872 .43042 .1804 .42516 Metetra
.659 .786 .942 r
.1804 .42516 .1872 .43042 .19675 .42763 .19004 .42167 Metetra
.659 .762 .926 r
.19004 .42167 .19675 .42763 .20641 .42417 .19971 .41819 Metetra
.691 .769 .912 r
.19971 .41819 .20641 .42417 .2161 .42062 .2095 .41392 Metetra
.656 .737 .909 r
.2095 .41392 .2161 .42062 .2259 .41638 .21924 .41047 Metetra
.724 .78 .896 r
.21924 .41047 .2259 .41638 .23566 .41277 .22918 .40519 Metetra
.662 .713 .886 r
.22918 .40519 .23566 .41277 .24561 .40754 .239 .40151 Metetra
.625 .753 .939 r
.239 .40151 .24561 .40754 .25546 .40366 .24879 .39871 Metetra
.759 .819 .899 r
.24879 .39871 .25546 .40366 .26525 .40099 .2589 .3924 Metetra
.718 .706 .838 r
.2589 .3924 .26525 .40099 .2754 .39416 .26899 .38655 Metetra
.678 .721 .881 r
.26899 .38655 .2754 .39416 .28549 .38848 .27899 .38236 Metetra
.912 .761 .681 r
.27899 .38236 .28549 .38848 .29555 .38343 .29055 .35727 Metetra
.864 .634 .588 r
.29055 .35727 .29555 .38343 .30699 .35866 .30434 .29927 Metetra
.581 .385 .581 r
.30434 .29927 .30699 .35866 .3207 .29778 .31444 .2915 Metetra
.916 .517 .164 r
.31444 .2915 .3207 .29778 .33072 .29095 .32235 .31789 Metetra
.32235 .31789 .33072 .29095 .34057 .28718 .33417 .28421 Metetra
.943 .605 .354 r
.33417 .28421 .34057 .28718 .34729 .33988 .34075 .33788 Metetra
.837 .37 .077 r
.34075 .33788 .34729 .33988 .35612 .36022 .34978 .35416 Metetra
.518 .719 .964 r
.34978 .35416 .35612 .36022 .36624 .35821 .35988 .35308 Metetra
.354 .679 .978 r
.35988 .35308 .36624 .35821 .37633 .35818 .36996 .35361 Metetra
.711 .84 .944 r
.36996 .35361 .37633 .35818 .38663 .35456 .38035 .3486 Metetra
.565 .745 .961 r
.38035 .3486 .38663 .35456 .3969 .35254 .39064 .34671 Metetra
.619 .771 .953 r
.39064 .34671 .3969 .35254 .40728 .3491 .40103 .3438 Metetra
.615 .79 .965 r
.40103 .3438 .40728 .3491 .41768 .34617 .41145 .34085 Metetra
.687 .811 .941 r
.41145 .34085 .41768 .34617 .42816 .34227 .42198 .33637 Metetra
.689 .792 .929 r
.42198 .33637 .42816 .34227 .43868 .33793 .43254 .33184 Metetra
.639 .771 .943 r
.43254 .33184 .43868 .33793 .44925 .33324 .4431 .32849 Metetra
.771 .851 .911 r
.4431 .32849 .44925 .33324 .45989 .32695 .45379 .3216 Metetra
.641 .801 .959 r
.45379 .3216 .45989 .32695 .47048 .32443 .46443 .31809 Metetra
.738 .793 .896 r
.46443 .31809 .47048 .32443 .48123 .31418 .47516 .31198 Metetra
.842 .94 .888 r
.47516 .31198 .48123 .31418 .49197 .30559 .48596 .30255 Metetra
.965 .826 .655 r
.48596 .30255 .49197 .30559 .50306 .2478 .49691 .27517 Metetra
.957 .784 .336 r
.49691 .27517 .50306 .2478 .51381 .1915 .50811 .18467 Metetra
.884 .473 .048 r
.50811 .18467 .51381 .1915 .52422 .27449 .51848 .214 Metetra
0 0 .432 r
.51848 .214 .52422 .27449 .53506 .29445 .52917 .26741 Metetra
.03 .077 .577 r
.52917 .26741 .53506 .29445 .54598 .29499 .54014 .28822 Metetra
.594 .738 .944 r
.54014 .28822 .54598 .29499 .55695 .2941 .55113 .28576 Metetra
.515 .65 .918 r
.55113 .28576 .55695 .2941 .56801 .29455 .56219 .28515 Metetra
.527 .626 .892 r
.56219 .28515 .56801 .29455 .57907 .29022 .57332 .28449 Metetra
.664 .805 .95 r
.57332 .28449 .57907 .29022 .59019 .28719 .58446 .28031 Metetra
.638 .755 .933 r
.58446 .28031 .59019 .28719 .60139 .28535 .59565 .27682 Metetra
.571 .674 .909 r
.59565 .27682 .60139 .28535 .6126 .28189 .60693 .27503 Metetra
.649 .762 .932 r
.60693 .27503 .6126 .28189 .62386 .27827 .61822 .27124 Metetra
.641 .755 .931 r
.61822 .27124 .62386 .27827 .63519 .27537 .62955 .26762 Metetra
.62 .723 .92 r
.62955 .26762 .63519 .27537 .64655 .27162 .64096 .26455 Metetra
.646 .757 .93 r
.64096 .26455 .64655 .27162 .65792 .26718 .6524 .26078 Metetra
.677 .793 .936 r
.6524 .26078 .65792 .26718 .66936 .26333 .66384 .25619 Metetra
.926 .806 .708 r
.66384 .25619 .66936 .26333 .68086 .2596 .67455 .23572 Metetra
.597 .478 .689 r
.67455 .23572 .68086 .2596 .69149 .23912 .68605 .23169 Metetra
.656 .752 .92 r
.68605 .23169 .69149 .23912 .703 .2351 .6976 .22764 Metetra
.656 .752 .92 r
.6976 .22764 .703 .2351 .71457 .23106 .70919 .22357 Metetra
.656 .752 .92 r
.70919 .22357 .71457 .23106 .72617 .22701 .72083 .21948 Metetra
.656 .752 .92 r
.72083 .21948 .72617 .22701 .73783 .22294 .73252 .21538 Metetra
.656 .752 .92 r
.73252 .21538 .73783 .22294 .74953 .21885 .74426 .21127 Metetra
.656 .752 .92 r
.74426 .21127 .74953 .21885 .76129 .21475 .75605 .20713 Metetra
.656 .752 .92 r
.09061 .43215 .09751 .43816 .10678 .43491 .0999 .42888 Metetra
.656 .752 .92 r
.0999 .42888 .10678 .43491 .11608 .43165 .10922 .42559 Metetra
.656 .752 .92 r
.10922 .42559 .11608 .43165 .12542 .42837 .11858 .42229 Metetra
.656 .752 .92 r
.11858 .42229 .12542 .42837 .13479 .42508 .12797 .41898 Metetra
.656 .752 .92 r
.12797 .41898 .13479 .42508 .1442 .42179 .1374 .41566 Metetra
.656 .752 .92 r
.1374 .41566 .1442 .42179 .15364 .41847 .14686 .41233 Metetra
.656 .752 .92 r
.14686 .41233 .15364 .41847 .16311 .41515 .15635 .40898 Metetra
.656 .752 .92 r
.15635 .40898 .16311 .41515 .17087 .42788 .16588 .40562 Metetra
.023 .087 .591 r
.16588 .40562 .17087 .42788 .1804 .42516 .17362 .41907 Metetra
.66 .758 .923 r
.17362 .41907 .1804 .42516 .19004 .42167 .18329 .41556 Metetra
.686 .765 .911 r
.18329 .41556 .19004 .42167 .19971 .41819 .19305 .41139 Metetra
.658 .735 .907 r
.19305 .41139 .19971 .41819 .2095 .41392 .20278 .40788 Metetra
.719 .775 .897 r
.20278 .40788 .2095 .41392 .21924 .41047 .2127 .40274 Metetra
.663 .71 .883 r
.2127 .40274 .21924 .41047 .22918 .40519 .22252 .39902 Metetra
.612 .745 .94 r
.22252 .39902 .22918 .40519 .239 .40151 .23226 .39647 Metetra
.763 .816 .895 r
.23226 .39647 .239 .40151 .24879 .39871 .24239 .39001 Metetra
.707 .701 .842 r
.24239 .39001 .24879 .39871 .2589 .3924 .25244 .38458 Metetra
.68 .716 .876 r
.25244 .38458 .2589 .3924 .26899 .38655 .26243 .3803 Metetra
.908 .761 .687 r
.26243 .3803 .26899 .38655 .27899 .38236 .27402 .35614 Metetra
.864 .634 .588 r
.27402 .35614 .27899 .38236 .29055 .35727 .28813 .29763 Metetra
.56 .368 .578 r
.28813 .29763 .29055 .35727 .30434 .29927 .29803 .29278 Metetra
.915 .514 .158 r
.29803 .29278 .30434 .29927 .31444 .2915 .30582 .31856 Metetra
.415 .095 .312 r
.30582 .31856 .31444 .2915 .32235 .31789 .31579 .31484 Metetra
.952 .785 .638 r
.31579 .31484 .32235 .31789 .33417 .28421 .32767 .28173 Metetra
.939 .596 .347 r
.32767 .28173 .33417 .28421 .34075 .33788 .33439 .33156 Metetra
.824 .365 0 r
.33439 .33156 .34075 .33788 .34978 .35416 .34334 .34907 Metetra
.454 .731 .986 r
.34334 .34907 .34978 .35416 .35988 .35308 .35344 .34845 Metetra
.502 .772 .992 r
.35344 .34845 .35988 .35308 .36996 .35361 .36363 .34706 Metetra
.676 .763 .916 r
.36363 .34706 .36996 .35361 .38035 .3486 .37401 .34289 Metetra
.534 .743 .972 r
.37401 .34289 .38035 .3486 .39064 .34671 .38431 .3414 Metetra
.661 .804 .952 r
.38431 .3414 .39064 .34671 .40103 .3438 .39476 .33754 Metetra
.623 .758 .944 r
.39476 .33754 .40103 .3438 .41145 .34085 .40521 .33457 Metetra
.65 .768 .935 r
.40521 .33457 .41145 .34085 .42198 .33637 .41573 .33099 Metetra
.706 .816 .934 r
.41573 .33099 .42198 .33637 .43254 .33184 .42634 .32601 Metetra
.676 .793 .937 r
.42634 .32601 .43254 .33184 .4431 .32849 .43696 .32176 Metetra
.702 .771 .905 r
.43696 .32176 .4431 .32849 .45379 .3216 .44763 .31676 Metetra
.66 .827 .964 r
.44763 .31676 .45379 .3216 .46443 .31809 .45832 .31273 Metetra
.779 .835 .894 r
.45832 .31273 .46443 .31809 .47516 .31198 .4691 .30536 Metetra
.712 .78 .905 r
.4691 .30536 .47516 .31198 .48596 .30255 .47988 .30002 Metetra
.97 .831 .649 r
.47988 .30002 .48596 .30255 .49691 .27517 .49093 .27179 Metetra
.978 .757 .535 r
.49093 .27179 .49691 .27517 .50811 .18467 .50211 .21083 Metetra
.415 .093 .309 r
.50211 .21083 .50811 .18467 .51848 .214 .5127 .20695 Metetra
.493 .676 .946 r
.5127 .20695 .51848 .214 .52917 .26741 .52333 .20646 Metetra
0 0 .428 r
.52333 .20646 .52917 .26741 .54014 .28822 .53419 .261 Metetra
.122 .14 .606 r
.53419 .261 .54014 .28822 .55113 .28576 .54527 .27879 Metetra
.583 .729 .943 r
.54527 .27879 .55113 .28576 .56219 .28515 .55634 .27653 Metetra
.563 .667 .908 r
.55634 .27653 .56219 .28515 .57332 .28449 .56748 .27492 Metetra
.518 .619 .891 r
.56748 .27492 .57332 .28449 .58446 .28031 .5787 .27443 Metetra
.685 .809 .942 r
.5787 .27443 .58446 .28031 .59565 .27682 .5899 .26973 Metetra
.635 .75 .931 r
.5899 .26973 .59565 .27682 .60693 .27503 .60117 .26627 Metetra
.583 .676 .904 r
.60117 .26627 .60693 .27503 .61822 .27124 .61253 .26417 Metetra
.646 .757 .93 r
.61253 .26417 .61822 .27124 .62955 .26762 .62389 .26042 Metetra
.648 .755 .927 r
.62389 .26042 .62955 .26762 .64096 .26455 .63531 .2566 Metetra
.619 .719 .918 r
.63531 .2566 .64096 .26455 .6524 .26078 .6468 .25351 Metetra
.927 .802 .702 r
.6468 .25351 .6524 .26078 .66384 .25619 .65756 .23231 Metetra
.596 .478 .689 r
.65756 .23231 .66384 .25619 .67455 .23572 .66904 .22826 Metetra
.656 .752 .92 r
.66904 .22826 .67455 .23572 .68605 .23169 .68057 .2242 Metetra
.656 .752 .92 r
.68057 .2242 .68605 .23169 .6976 .22764 .69215 .22011 Metetra
.656 .752 .92 r
.69215 .22011 .6976 .22764 .70919 .22357 .70378 .21602 Metetra
.656 .752 .92 r
.70378 .21602 .70919 .22357 .72083 .21948 .71545 .2119 Metetra
.656 .752 .92 r
.71545 .2119 .72083 .21948 .73252 .21538 .72718 .20777 Metetra
.656 .752 .92 r
.72718 .20777 .73252 .21538 .74426 .21127 .73895 .20362 Metetra
.656 .752 .92 r
.73895 .20362 .74426 .21127 .75605 .20713 .75077 .19945 Metetra
.656 .752 .92 r
.08367 .4261 .09061 .43215 .0999 .42888 .09298 .4228 Metetra
.656 .752 .92 r
.09298 .4228 .0999 .42888 .10922 .42559 .10232 .41949 Metetra
.656 .752 .92 r
.10232 .41949 .10922 .42559 .11858 .42229 .11169 .41617 Metetra
.656 .752 .92 r
.11169 .41617 .11858 .42229 .12797 .41898 .1211 .41284 Metetra
.656 .752 .92 r
.1211 .41284 .12797 .41898 .1374 .41566 .13055 .4095 Metetra
.656 .752 .92 r
.13055 .4095 .1374 .41566 .14686 .41233 .14003 .40614 Metetra
.656 .752 .92 r
.14003 .40614 .14686 .41233 .15635 .40898 .14954 .40277 Metetra
.656 .752 .92 r
.14954 .40277 .15635 .40898 .16588 .40562 .15909 .39939 Metetra
.656 .752 .92 r
.15909 .39939 .16588 .40562 .17362 .41907 .16868 .39599 Metetra
.081 .121 .604 r
.16868 .39599 .17362 .41907 .18329 .41556 .17656 .40876 Metetra
.654 .735 .909 r
.17656 .40876 .18329 .41556 .19305 .41139 .18626 .40534 Metetra
.72 .775 .897 r
.18626 .40534 .19305 .41139 .20278 .40788 .19618 .40016 Metetra
.658 .71 .886 r
.19618 .40016 .20278 .40788 .2127 .40274 .20597 .39656 Metetra
.614 .746 .94 r
.20597 .39656 .2127 .40274 .22252 .39902 .2157 .39396 Metetra
.755 .815 .9 r
.2157 .39396 .22252 .39902 .23226 .39647 .2258 .38776 Metetra
.709 .701 .841 r
.2258 .38776 .23226 .39647 .24239 .39001 .23586 .38224 Metetra
.667 .714 .883 r
.23586 .38224 .24239 .39001 .25244 .38458 .24581 .37835 Metetra
.908 .76 .686 r
.24581 .37835 .25244 .38458 .26243 .3803 .25751 .35397 Metetra
.862 .633 .59 r
.25751 .35397 .26243 .3803 .27402 .35614 .27181 .2964 Metetra
.561 .368 .578 r
.27181 .2964 .27402 .35614 .28813 .29763 .28174 .29124 Metetra
.926 .539 .205 r
.28174 .29124 .28813 .29763 .29803 .29278 .28914 .31991 Metetra
.397 .077 .302 r
.28914 .31991 .29803 .29278 .30582 .31856 .29917 .31543 Metetra
.572 .853 .996 r
.29917 .31543 .30582 .31856 .31579 .31484 .30911 .31264 Metetra
.96 .784 .621 r
.30911 .31264 .31579 .31484 .32767 .28173 .32137 .27525 Metetra
.953 .611 .32 r
.32137 .27525 .32767 .28173 .33439 .33156 .32793 .32628 Metetra
.845 .388 .001 r
.32793 .32628 .33439 .33156 .34334 .34907 .33682 .34435 Metetra
.568 .795 .985 r
.33682 .34435 .34334 .34907 .35344 .34845 .34703 .34206 Metetra
.489 .698 .962 r
.34703 .34206 .35344 .34845 .36363 .34706 .35721 .34143 Metetra
.682 .798 .937 r
.35721 .34143 .36363 .34706 .37401 .34289 .36762 .33711 Metetra
.548 .748 .97 r
.36762 .33711 .37401 .34289 .38431 .3414 .37795 .33539 Metetra
.668 .783 .935 r
.37795 .33539 .38431 .3414 .39476 .33754 .38844 .33137 Metetra
.622 .763 .947 r
.38844 .33137 .39476 .33754 .40521 .33457 .39892 .32838 Metetra
.643 .771 .94 r
.39892 .32838 .40521 .33457 .41573 .33099 .40946 .32491 Metetra
.697 .791 .923 r
.40946 .32491 .41573 .33099 .42634 .32601 .42009 .32011 Metetra
.671 .791 .938 r
.42009 .32011 .42634 .32601 .43696 .32176 .43074 .31595 Metetra
.732 .811 .913 r
.43074 .31595 .43696 .32176 .44763 .31676 .44146 .31013 Metetra
.591 .739 .947 r
.44146 .31013 .44763 .31676 .45832 .31273 .45214 .30775 Metetra
.796 .85 .891 r
.45214 .30775 .45832 .31273 .4691 .30536 .46298 .2998 Metetra
.754 .827 .908 r
.46298 .2998 .4691 .30536 .47988 .30002 .47381 .29326 Metetra
.926 .782 .682 r
.47381 .29326 .47988 .30002 .49093 .27179 .48488 .26928 Metetra
.981 .76 .531 r
.48488 .26928 .49093 .27179 .50211 .21083 .49623 .20712 Metetra
.886 .456 .095 r
.49623 .20712 .50211 .21083 .5127 .20695 .50667 .23386 Metetra
.50667 .23386 .5127 .20695 .52333 .20646 .51753 .19945 Metetra
.44 .653 .95 r
.51753 .19945 .52333 .20646 .53419 .261 .52824 .19972 Metetra
0 0 .444 r
.52824 .19972 .53419 .261 .54527 .27879 .53927 .25136 Metetra
.114 .134 .603 r
.53927 .25136 .54527 .27879 .55634 .27653 .55047 .26953 Metetra
.627 .748 .935 r
.55047 .26953 .55634 .27653 .56748 .27492 .56161 .26628 Metetra
.556 .666 .91 r
.56161 .26628 .56748 .27492 .5787 .27443 .57283 .26478 Metetra
.54 .63 .889 r
.57283 .26478 .5787 .27443 .5899 .26973 .58413 .26378 Metetra
.681 .808 .943 r
.58413 .26378 .5899 .26973 .60117 .26627 .59541 .25911 Metetra
.645 .754 .929 r
.59541 .25911 .60117 .26627 .61253 .26417 .60675 .25538 Metetra
.58 .676 .905 r
.60675 .25538 .61253 .26417 .62389 .26042 .6182 .25329 Metetra
.652 .76 .929 r
.6182 .25329 .62389 .26042 .63531 .2566 .62964 .24933 Metetra
.923 .803 .71 r
.62964 .24933 .63531 .2566 .6468 .25351 .6405 .22888 Metetra
.594 .472 .684 r
.6405 .22888 .6468 .25351 .65756 .23231 .65197 .22482 Metetra
.656 .752 .92 r
.65197 .22482 .65756 .23231 .66904 .22826 .66349 .22074 Metetra
.656 .752 .92 r
.66349 .22074 .66904 .22826 .68057 .2242 .67505 .21665 Metetra
.656 .752 .92 r
.67505 .21665 .68057 .2242 .69215 .22011 .68666 .21253 Metetra
.656 .752 .92 r
.68666 .21253 .69215 .22011 .70378 .21602 .69832 .20841 Metetra
.656 .752 .92 r
.69832 .20841 .70378 .21602 .71545 .2119 .71003 .20426 Metetra
.656 .752 .92 r
.71003 .20426 .71545 .2119 .72718 .20777 .72179 .20009 Metetra
.656 .752 .92 r
.72179 .20009 .72718 .20777 .73895 .20362 .73359 .19591 Metetra
.656 .752 .92 r
.73359 .19591 .73895 .20362 .75077 .19945 .74545 .19172 Metetra
.656 .752 .92 r
.07668 .42 .08367 .4261 .09298 .4228 .08601 .41668 Metetra
.656 .752 .92 r
.08601 .41668 .09298 .4228 .10232 .41949 .09537 .41335 Metetra
.656 .752 .92 r
.09537 .41335 .10232 .41949 .11169 .41617 .10476 .41001 Metetra
.656 .752 .92 r
.10476 .41001 .11169 .41617 .1211 .41284 .11419 .40666 Metetra
.656 .752 .92 r
.11419 .40666 .1211 .41284 .13055 .4095 .12365 .40329 Metetra
.656 .752 .92 r
.12365 .40329 .13055 .4095 .14003 .40614 .13315 .39991 Metetra
.656 .752 .92 r
.13315 .39991 .14003 .40614 .14954 .40277 .14269 .39651 Metetra
.656 .752 .92 r
.14269 .39651 .14954 .40277 .15909 .39939 .15226 .39311 Metetra
.656 .752 .92 r
.15226 .39311 .15909 .39939 .16868 .39599 .16187 .38969 Metetra
.656 .752 .92 r
.16187 .38969 .16868 .39599 .17656 .40876 .17151 .38626 Metetra
.136 .166 .628 r
.17151 .38626 .17656 .40876 .18626 .40534 .17961 .39753 Metetra
.659 .708 .884 r
.17961 .39753 .18626 .40534 .19618 .40016 .18939 .39389 Metetra
.606 .741 .94 r
.18939 .39389 .19618 .40016 .20597 .39656 .19908 .39144 Metetra
.757 .813 .897 r
.19908 .39144 .20597 .39656 .2157 .39396 .20919 .38514 Metetra
.701 .697 .843 r
.20919 .38514 .2157 .39396 .2258 .38776 .21922 .37987 Metetra
.669 .712 .88 r
.21922 .37987 .2258 .38776 .23586 .38224 .22916 .37589 Metetra
.905 .759 .689 r
.22916 .37589 .23586 .38224 .24581 .37835 .24092 .35195 Metetra
.862 .633 .59 r
.24092 .35195 .24581 .37835 .25751 .35397 .25552 .29409 Metetra
.553 .362 .576 r
.25552 .29409 .25751 .35397 .27181 .2964 .26536 .28983 Metetra
.927 .541 .206 r
.26536 .28983 .27181 .2964 .28174 .29124 .2726 .31831 Metetra
.452 .126 .322 r
.2726 .31831 .28174 .29124 .28914 .31991 .2824 .31681 Metetra
.636 .873 .986 r
.2824 .31681 .28914 .31991 .29917 .31543 .2924 .3131 Metetra
.787 .92 .927 r
.2924 .3131 .29917 .31543 .30911 .31264 .30268 .30602 Metetra
.931 .746 .629 r
.30268 .30602 .30911 .31264 .32137 .27525 .31495 .26989 Metetra
.949 .608 .331 r
.31495 .26989 .32137 .27525 .32793 .32628 .32138 .32133 Metetra
.824 .351 0 r
.32138 .32133 .32793 .32628 .33682 .34435 .33036 .33771 Metetra
.545 .715 .951 r
.33036 .33771 .33682 .34435 .34703 .34206 .34055 .33625 Metetra
.463 .711 .976 r
.34055 .33625 .34703 .34206 .35721 .34143 .35073 .33573 Metetra
.694 .8 .931 r
.35073 .33573 .35721 .34143 .36762 .33711 .3612 .33108 Metetra
.591 .757 .958 r
.3612 .33108 .36762 .33711 .37795 .33539 .37158 .32866 Metetra
.638 .75 .929 r
.37158 .32866 .37795 .33539 .38844 .33137 .38206 .32533 Metetra
.621 .769 .951 r
.38206 .32533 .38844 .33137 .39892 .32838 .39257 .32231 Metetra
.674 .786 .933 r
.39257 .32231 .39892 .32838 .40946 .32491 .40317 .31809 Metetra
.67 .76 .918 r
.40317 .31809 .40946 .32491 .42009 .32011 .4138 .31395 Metetra
.659 .78 .938 r
.4138 .31395 .42009 .32011 .43074 .31595 .42447 .31007 Metetra
.736 .81 .91 r
.42447 .31007 .43074 .31595 .44146 .31013 .43523 .30408 Metetra
.629 .776 .951 r
.43523 .30408 .44146 .31013 .45214 .30775 .44596 .30082 Metetra
.737 .779 .887 r
.44596 .30082 .45214 .30775 .46298 .2998 .45679 .29457 Metetra
.765 .841 .909 r
.45679 .29457 .46298 .2998 .47381 .29326 .46767 .28769 Metetra
.942 .798 .673 r
.46767 .28769 .47381 .29326 .48488 .26928 .47884 .26223 Metetra
.964 .74 .551 r
.47884 .26223 .48488 .26928 .49623 .20712 .49028 .20419 Metetra
.883 .45 .106 r
.49028 .20419 .49623 .20712 .50667 .23386 .50071 .23022 Metetra
.629 .87 .987 r
.50071 .23022 .50667 .23386 .51753 .19945 .51153 .22634 Metetra
0 0 .004 r
.51153 .22634 .51753 .19945 .52824 .19972 .52242 .19249 Metetra
.607 .726 .93 r
.52242 .19249 .52824 .19972 .53927 .25136 .53322 .18979 Metetra
0 0 .443 r
.53322 .18979 .53927 .25136 .55047 .26953 .54442 .24192 Metetra
.143 .154 .611 r
.54442 .24192 .55047 .26953 .56161 .26628 .55572 .2591 Metetra
.62 .743 .934 r
.55572 .2591 .56161 .26628 .57283 .26478 .56695 .25596 Metetra
.577 .673 .905 r
.56695 .25596 .57283 .26478 .58413 .26378 .57825 .25395 Metetra
.535 .625 .888 r
.57825 .25395 .58413 .26378 .59541 .25911 .58963 .25303 Metetra
.691 .81 .938 r
.58963 .25303 .59541 .25911 .60675 .25538 .60098 .24805 Metetra
.642 .751 .928 r
.60098 .24805 .60675 .25538 .6182 .25329 .6124 .24433 Metetra
.894 .771 .719 r
.6124 .24433 .6182 .25329 .62964 .24933 .62339 .22545 Metetra
.595 .478 .689 r
.62339 .22545 .62964 .24933 .6405 .22888 .63484 .22137 Metetra
.656 .752 .92 r
.63484 .22137 .6405 .22888 .65197 .22482 .64634 .21728 Metetra
.656 .752 .92 r
.64634 .21728 .65197 .22482 .66349 .22074 .65789 .21317 Metetra
.656 .752 .92 r
.65789 .21317 .66349 .22074 .67505 .21665 .66949 .20904 Metetra
.656 .752 .92 r
.66949 .20904 .67505 .21665 .68666 .21253 .68113 .2049 Metetra
.656 .752 .92 r
.68113 .2049 .68666 .21253 .69832 .20841 .69283 .20074 Metetra
.656 .752 .92 r
.69283 .20074 .69832 .20841 .71003 .20426 .70457 .19656 Metetra
.656 .752 .92 r
.70457 .19656 .71003 .20426 .72179 .20009 .71636 .19236 Metetra
.656 .752 .92 r
.71636 .19236 .72179 .20009 .73359 .19591 .7282 .18815 Metetra
.656 .752 .92 r
.7282 .18815 .73359 .19591 .74545 .19172 .74008 .18392 Metetra
.656 .752 .92 r
.06964 .41387 .07668 .42 .08601 .41668 .07899 .41053 Metetra
.656 .752 .92 r
.07899 .41053 .08601 .41668 .09537 .41335 .08837 .40717 Metetra
.656 .752 .92 r
.08837 .40717 .09537 .41335 .10476 .41001 .09778 .40381 Metetra
.656 .752 .92 r
.09778 .40381 .10476 .41001 .11419 .40666 .10723 .40043 Metetra
.656 .752 .92 r
.10723 .40043 .11419 .40666 .12365 .40329 .11671 .39704 Metetra
.656 .752 .92 r
.11671 .39704 .12365 .40329 .13315 .39991 .12623 .39363 Metetra
.656 .752 .92 r
.12623 .39363 .13315 .39991 .14269 .39651 .13579 .39022 Metetra
.656 .752 .92 r
.13579 .39022 .14269 .39651 .15226 .39311 .14538 .38679 Metetra
.656 .752 .92 r
.14538 .38679 .15226 .39311 .16187 .38969 .155 .38334 Metetra
.656 .752 .92 r
.155 .38334 .16187 .38969 .17151 .38626 .16467 .37989 Metetra
.656 .752 .92 r
.16467 .37989 .17151 .38626 .17961 .39753 .17437 .37642 Metetra
.039 .112 .612 r
.17437 .37642 .17961 .39753 .18939 .39389 .18242 .38875 Metetra
.753 .813 .9 r
.18242 .38875 .18939 .39389 .19908 .39144 .19251 .3826 Metetra
.703 .698 .842 r
.19251 .3826 .19908 .39144 .20919 .38514 .20255 .37726 Metetra
.661 .71 .884 r
.20255 .37726 .20919 .38514 .21922 .37987 .21245 .3735 Metetra
.904 .758 .689 r
.21245 .3735 .21922 .37987 .22916 .37589 .22431 .34944 Metetra
.861 .632 .591 r
.22431 .34944 .22916 .37589 .24092 .35195 .23915 .29198 Metetra
.553 .361 .575 r
.23915 .29198 .24092 .35195 .25552 .29409 .249 .28756 Metetra
.93 .549 .224 r
.249 .28756 .25552 .29409 .26536 .28983 .25598 .31698 Metetra
.444 .117 .316 r
.25598 .31698 .26536 .28983 .2726 .31831 .26577 .31513 Metetra
.365 .761 .986 r
.26577 .31513 .2726 .31831 .2824 .31681 .27552 .31447 Metetra
.811 .917 .909 r
.27552 .31447 .2824 .31681 .2924 .3131 .28588 .30657 Metetra
.735 .774 .884 r
.28588 .30657 .2924 .3131 .30268 .30602 .29611 .30068 Metetra
.94 .759 .63 r
.29611 .30068 .30268 .30602 .31495 .26989 .30846 .26471 Metetra
.948 .605 .328 r
.30846 .26471 .31495 .26989 .32138 .32133 .31489 .3148 Metetra
.812 .35 0 r
.31489 .3148 .32138 .32133 .33036 .33771 .32381 .33179 Metetra
.528 .736 .97 r
.32381 .33179 .33036 .33771 .34055 .33625 .33401 .33038 Metetra
.482 .719 .975 r
.33401 .33038 .34055 .33625 .35073 .33573 .34423 .3296 Metetra
.708 .79 .915 r
.34423 .3296 .35073 .33573 .3612 .33108 .35475 .3245 Metetra
.561 .727 .952 r
.35475 .3245 .3612 .33108 .37158 .32866 .36512 .32269 Metetra
.661 .785 .94 r
.36512 .32269 .37158 .32866 .38206 .32533 .37565 .31878 Metetra
.623 .754 .94 r
.37565 .31878 .38206 .32533 .39257 .32231 .38619 .31574 Metetra
.651 .763 .931 r
.38619 .31574 .39257 .32231 .40317 .31809 .39679 .31204 Metetra
.695 .795 .927 r
.39679 .31204 .40317 .31809 .4138 .31395 .40748 .30724 Metetra
.641 .757 .932 r
.40748 .30724 .4138 .31395 .42447 .31007 .41816 .30375 Metetra
.726 .796 .907 r
.41816 .30375 .42447 .31007 .43523 .30408 .42895 .29798 Metetra
.632 .777 .95 r
.42895 .29798 .43523 .30408 .44596 .30082 .43971 .29462 Metetra
.759 .808 .892 r
.43971 .29462 .44596 .30082 .45679 .29457 .45059 .28772 Metetra
.712 .778 .904 r
.45059 .28772 .45679 .29457 .46767 .28769 .46147 .28229 Metetra
.944 .801 .671 r
.46147 .28229 .46767 .28769 .47884 .26223 .47273 .2565 Metetra
.97 .747 .545 r
.47273 .2565 .47884 .26223 .49028 .20419 .48432 .1971 Metetra
.887 .477 .055 r
.48432 .1971 .49028 .20419 .50071 .23022 .49468 .22735 Metetra
.662 .908 .979 r
.49468 .22735 .50071 .23022 .51153 .22634 .50555 .22257 Metetra
.577 .848 .996 r
.50555 .22257 .51153 .22634 .52242 .19249 .51645 .21949 Metetra
.51645 .21949 .52242 .19249 .53322 .18979 .52737 .18253 Metetra
.592 .722 .934 r
.52737 .18253 .53322 .18979 .54442 .24192 .53825 .1801 Metetra
0 0 .448 r
.53825 .1801 .54442 .24192 .55572 .2591 .54962 .23135 Metetra
.139 .151 .61 r
.54962 .23135 .55572 .2591 .56695 .25596 .56104 .2487 Metetra
.639 .75 .929 r
.56104 .2487 .56695 .25596 .57825 .25395 .57234 .24507 Metetra
.573 .672 .906 r
.57234 .24507 .57825 .25395 .58963 .25303 .58372 .24311 Metetra
.546 .631 .887 r
.58372 .24311 .58963 .25303 .60098 .24805 .59518 .24189 Metetra
.93 .824 .719 r
.59518 .24189 .60098 .24805 .6124 .24433 .60621 .222 Metetra
.599 .49 .701 r
.60621 .222 .6124 .24433 .62339 .22545 .61765 .21791 Metetra
.656 .752 .92 r
.61765 .21791 .62339 .22545 .63484 .22137 .62914 .2138 Metetra
.656 .752 .92 r
.62914 .2138 .63484 .22137 .64634 .21728 .64067 .20968 Metetra
.656 .752 .92 r
.64067 .20968 .64634 .21728 .65789 .21317 .65226 .20554 Metetra
.656 .752 .92 r
.65226 .20554 .65789 .21317 .66949 .20904 .66388 .20138 Metetra
.656 .752 .92 r
.66388 .20138 .66949 .20904 .68113 .2049 .67556 .1972 Metetra
.656 .752 .92 r
.67556 .1972 .68113 .2049 .69283 .20074 .68729 .19301 Metetra
.656 .752 .92 r
.68729 .19301 .69283 .20074 .70457 .19656 .69906 .1888 Metetra
.656 .752 .92 r
.69906 .1888 .70457 .19656 .71636 .19236 .71089 .18457 Metetra
.656 .752 .92 r
.71089 .18457 .71636 .19236 .7282 .18815 .72276 .18033 Metetra
.656 .752 .92 r
.72276 .18033 .7282 .18815 .74008 .18392 .73468 .17606 Metetra
.656 .752 .92 r
.06256 .40769 .06964 .41387 .07899 .41053 .07192 .40432 Metetra
.656 .752 .92 r
.07192 .40432 .07899 .41053 .08837 .40717 .08132 .40095 Metetra
.656 .752 .92 r
.08132 .40095 .08837 .40717 .09778 .40381 .09075 .39756 Metetra
.656 .752 .92 r
.09075 .39756 .09778 .40381 .10723 .40043 .10022 .39416 Metetra
.656 .752 .92 r
.10022 .39416 .10723 .40043 .11671 .39704 .10972 .39074 Metetra
.656 .752 .92 r
.10972 .39074 .11671 .39704 .12623 .39363 .11926 .38731 Metetra
.656 .752 .92 r
.11926 .38731 .12623 .39363 .13579 .39022 .12884 .38387 Metetra
.656 .752 .92 r
.12884 .38387 .13579 .39022 .14538 .38679 .13845 .38042 Metetra
.656 .752 .92 r
.13845 .38042 .14538 .38679 .155 .38334 .1481 .37695 Metetra
.656 .752 .92 r
.1481 .37695 .155 .38334 .16467 .37989 .15778 .37348 Metetra
.656 .752 .92 r
.15778 .37348 .16467 .37989 .17437 .37642 .1675 .36998 Metetra
.656 .752 .92 r
.1675 .36998 .17437 .37642 .18242 .38875 .17726 .36648 Metetra
.594 .478 .69 r
.17726 .36648 .18242 .38875 .19251 .3826 .18705 .36296 Metetra
.236 .264 .687 r
.18705 .36296 .19251 .3826 .20255 .37726 .19571 .37081 Metetra
.902 .757 .69 r
.19571 .37081 .20255 .37726 .21245 .3735 .20764 .34698 Metetra
.86 .632 .592 r
.20764 .34698 .21245 .3735 .22431 .34944 .22277 .28934 Metetra
.549 .357 .574 r
.22277 .28934 .22431 .34944 .23915 .29198 .23257 .28535 Metetra
.931 .551 .228 r
.23257 .28535 .23915 .29198 .249 .28756 .23936 .31465 Metetra
.459 .13 .319 r
.23936 .31465 .249 .28756 .25598 .31698 .24905 .31376 Metetra
.406 .781 .993 r
.24905 .31376 .25598 .31698 .26577 .31513 .25881 .31274 Metetra
.694 .911 .97 r
.25881 .31274 .26577 .31513 .27552 .31447 .26894 .30779 Metetra
.753 .773 .869 r
.26894 .30779 .27552 .31447 .28588 .30657 .27923 .30115 Metetra
.731 .811 .914 r
.27923 .30115 .28588 .30657 .29611 .30068 .28946 .2956 Metetra
.943 .759 .624 r
.28946 .2956 .29611 .30068 .30846 .26471 .30203 .25797 Metetra
.953 .61 .318 r
.30203 .25797 .30846 .26471 .31489 .3148 .30832 .30867 Metetra
.825 .363 0 r
.30832 .30867 .31489 .3148 .32381 .33179 .31719 .32599 Metetra
.557 .754 .969 r
.31719 .32599 .32381 .33179 .33401 .33038 .32745 .32408 Metetra
.524 .723 .964 r
.32745 .32408 .33401 .33038 .34423 .3296 .33772 .32279 Metetra
.682 .763 .913 r
.33772 .32279 .34423 .3296 .35475 .3245 .34822 .31836 Metetra
.572 .749 .961 r
.34822 .31836 .35475 .3245 .36512 .32269 .35864 .31623 Metetra
.665 .771 .929 r
.35864 .31623 .36512 .32269 .37565 .31878 .3692 .31221 Metetra
.623 .754 .941 r
.3692 .31221 .37565 .31878 .38619 .31574 .37976 .30914 Metetra
.648 .763 .933 r
.37976 .30914 .38619 .31574 .39679 .31204 .39039 .30551 Metetra
.684 .777 .922 r
.39039 .30551 .39679 .31204 .40748 .30724 .40109 .30096 Metetra
.67 .783 .934 r
.40109 .30096 .40748 .30724 .41816 .30375 .41183 .29676 Metetra
.708 .771 .901 r
.41183 .29676 .41816 .30375 .42895 .29798 .42263 .29144 Metetra
.611 .755 .947 r
.42263 .29144 .42895 .29798 .43971 .29462 .4334 .28854 Metetra
.769 .815 .889 r
.4334 .28854 .43971 .29462 .45059 .28772 .44434 .28128 Metetra
.732 .798 .904 r
.44434 .28128 .45059 .28772 .46147 .28229 .45526 .27525 Metetra
.925 .78 .682 r
.45526 .27525 .46147 .28229 .47273 .2565 .46656 .25102 Metetra
.971 .748 .544 r
.46656 .25102 .47273 .2565 .48432 .1971 .47831 .1911 Metetra
.888 .47 .066 r
.47831 .1911 .48432 .1971 .49468 .22735 .48865 .22009 Metetra
.484 .675 .949 r
.48865 .22009 .49468 .22735 .50555 .22257 .49951 .21961 Metetra
.609 .89 .989 r
.49951 .21961 .50555 .22257 .51645 .21949 .51045 .21564 Metetra
.738 .895 .95 r
.51045 .21564 .51645 .21949 .52737 .18253 .52145 .20948 Metetra
.52145 .20948 .52737 .18253 .53825 .1801 .53239 .17268 Metetra
.635 .737 .922 r
.53239 .17268 .53825 .1801 .54962 .23135 .54334 .16925 Metetra
0 0 .447 r
.54334 .16925 .54962 .23135 .56104 .2487 .55489 .22077 Metetra
.152 .16 .613 r
.55489 .22077 .56104 .2487 .57234 .24507 .56642 .23767 Metetra
.88 .803 .77 r
.56642 .23767 .57234 .24507 .58372 .24311 .5776 .22263 Metetra
.604 .506 .716 r
.5776 .22263 .58372 .24311 .59518 .24189 .58898 .21854 Metetra
.596 .481 .693 r
.58898 .21854 .59518 .24189 .60621 .222 .60041 .21443 Metetra
.656 .752 .92 r
.60041 .21443 .60621 .222 .61765 .21791 .61188 .21031 Metetra
.656 .752 .92 r
.61188 .21031 .61765 .21791 .62914 .2138 .62339 .20617 Metetra
.656 .752 .92 r
.62339 .20617 .62914 .2138 .64067 .20968 .63496 .20202 Metetra
.656 .752 .92 r
.63496 .20202 .64067 .20968 .65226 .20554 .64657 .19785 Metetra
.656 .752 .92 r
.64657 .19785 .65226 .20554 .66388 .20138 .65824 .19366 Metetra
.656 .752 .92 r
.65824 .19366 .66388 .20138 .67556 .1972 .66995 .18945 Metetra
.656 .752 .92 r
.66995 .18945 .67556 .1972 .68729 .19301 .68171 .18522 Metetra
.656 .752 .92 r
.68171 .18522 .68729 .19301 .69906 .1888 .69351 .18098 Metetra
.656 .752 .92 r
.69351 .18098 .69906 .1888 .71089 .18457 .70537 .17672 Metetra
.656 .752 .92 r
.70537 .17672 .71089 .18457 .72276 .18033 .71728 .17244 Metetra
.656 .752 .92 r
.71728 .17244 .72276 .18033 .73468 .17606 .72924 .16814 Metetra
.656 .752 .92 r
.05542 .40147 .06256 .40769 .07192 .40432 .06481 .39808 Metetra
.656 .752 .92 r
.06481 .39808 .07192 .40432 .08132 .40095 .07422 .39468 Metetra
.656 .752 .92 r
.07422 .39468 .08132 .40095 .09075 .39756 .08367 .39127 Metetra
.656 .752 .92 r
.08367 .39127 .09075 .39756 .10022 .39416 .09316 .38784 Metetra
.656 .752 .92 r
.09316 .38784 .10022 .39416 .10972 .39074 .10269 .3844 Metetra
.656 .752 .92 r
.10269 .3844 .10972 .39074 .11926 .38731 .11224 .38095 Metetra
.656 .752 .92 r
.11224 .38095 .11926 .38731 .12884 .38387 .12184 .37749 Metetra
.656 .752 .92 r
.12184 .37749 .12884 .38387 .13845 .38042 .13147 .37401 Metetra
.656 .752 .92 r
.13147 .37401 .13845 .38042 .1481 .37695 .14114 .37052 Metetra
.656 .752 .92 r
.14114 .37052 .1481 .37695 .15778 .37348 .15084 .36702 Metetra
.656 .752 .92 r
.15084 .36702 .15778 .37348 .1675 .36998 .16058 .3635 Metetra
.656 .752 .92 r
.16058 .3635 .1675 .36998 .17726 .36648 .17036 .35997 Metetra
.656 .752 .92 r
.17036 .35997 .17726 .36648 .18705 .36296 .18018 .35643 Metetra
.656 .752 .92 r
.18018 .35643 .18705 .36296 .19571 .37081 .19003 .35287 Metetra
.898 .671 .586 r
.19003 .35287 .19571 .37081 .20764 .34698 .20633 .2868 Metetra
.548 .356 .573 r
.20633 .2868 .20764 .34698 .22277 .28934 .21612 .28271 Metetra
.933 .555 .239 r
.21612 .28271 .22277 .28934 .23257 .28535 .22268 .31246 Metetra
.454 .123 .315 r
.22268 .31246 .23257 .28535 .23936 .31465 .23235 .3114 Metetra
.29 .72 .969 r
.23235 .3114 .23936 .31465 .24905 .31376 .24199 .31135 Metetra
.711 .912 .965 r
.24199 .31135 .24905 .31376 .25881 .31274 .25214 .30609 Metetra
.659 .753 .919 r
.25214 .30609 .25881 .31274 .26894 .30779 .26219 .30238 Metetra
.756 .815 .899 r
.26219 .30238 .26894 .30779 .27923 .30115 .2725 .29598 Metetra
.777 .825 .89 r
.2725 .29598 .27923 .30115 .28946 .2956 .28287 .28888 Metetra
.932 .746 .627 r
.28287 .28888 .28946 .2956 .30203 .25797 .2955 .25183 Metetra
.951 .609 .323 r
.2955 .25183 .30203 .25797 .30832 .30867 .30168 .30276 Metetra
.82 .353 0 r
.30168 .30276 .30832 .30867 .31719 .32599 .31056 .31958 Metetra
.578 .741 .953 r
.31056 .31958 .31719 .32599 .32745 .32408 .32086 .3174 Metetra
.5 .7 .959 r
.32086 .3174 .32745 .32408 .33772 .32279 .33112 .31655 Metetra
.696 .786 .92 r
.33112 .31655 .33772 .32279 .34822 .31836 .34167 .31173 Metetra
.578 .736 .95 r
.34167 .31173 .34822 .31836 .35864 .31623 .35211 .30954 Metetra
.654 .762 .929 r
.35211 .30954 .35864 .31623 .3692 .31221 .36269 .30576 Metetra
.622 .76 .945 r
.36269 .30576 .3692 .31221 .37976 .30914 .37327 .30266 Metetra
.659 .772 .933 r
.37327 .30266 .37976 .30914 .39039 .30551 .38394 .29874 Metetra
.682 .77 .918 r
.38394 .29874 .39039 .30551 .40109 .30096 .39468 .2942 Metetra
.656 .763 .929 r
.39468 .2942 .40109 .30096 .41183 .29676 .40542 .29032 Metetra
.725 .795 .907 r
.40542 .29032 .41183 .29676 .42263 .29144 .41628 .28452 Metetra
.601 .74 .942 r
.41628 .28452 .42263 .29144 .4334 .28854 .42707 .28183 Metetra
.751 .794 .888 r
.42707 .28183 .4334 .28854 .44434 .28128 .43802 .27506 Metetra
.738 .808 .907 r
.43802 .27506 .44434 .28128 .45526 .27525 .44898 .26884 Metetra
.933 .789 .678 r
.44898 .26884 .45526 .27525 .46656 .25102 .46037 .24386 Metetra
.964 .74 .55 r
.46037 .24386 .46656 .25102 .47831 .1911 .47224 .18534 Metetra
.888 .468 .07 r
.47224 .18534 .47831 .1911 .48865 .22009 .48255 .2141 Metetra
.54 .75 .973 r
.48255 .2141 .48865 .22009 .49951 .21961 .49345 .21231 Metetra
.431 .649 .95 r
.49345 .21231 .49951 .21961 .51045 .21564 .50439 .21261 Metetra
.765 .928 .94 r
.50439 .21261 .51045 .21564 .52145 .20948 .51544 .20554 Metetra
.725 .892 .956 r
.51544 .20554 .52145 .20948 .53239 .17268 .5265 .19964 Metetra
.5265 .19964 .53239 .17268 .54334 .16925 .53747 .16177 Metetra
.629 .735 .924 r
.53747 .16177 .54334 .16925 .55489 .22077 .5485 .15845 Metetra
0 0 .401 r
.5485 .15845 .55489 .22077 .56642 .23767 .56033 .21917 Metetra
.611 .528 .736 r
.56033 .21917 .56642 .23767 .5776 .22263 .57169 .21507 Metetra
.656 .752 .92 r
.57169 .21507 .5776 .22263 .58898 .21854 .5831 .21095 Metetra
.656 .752 .92 r
.5831 .21095 .58898 .21854 .60041 .21443 .59455 .20681 Metetra
.656 .752 .92 r
.59455 .20681 .60041 .21443 .61188 .21031 .60606 .20266 Metetra
.656 .752 .92 r
.60606 .20266 .61188 .21031 .62339 .20617 .61761 .19849 Metetra
.656 .752 .92 r
.61761 .19849 .62339 .20617 .63496 .20202 .6292 .1943 Metetra
.656 .752 .92 r
.6292 .1943 .63496 .20202 .64657 .19785 .64085 .1901 Metetra
.656 .752 .92 r
.64085 .1901 .64657 .19785 .65824 .19366 .65255 .18587 Metetra
.656 .752 .92 r
.65255 .18587 .65824 .19366 .66995 .18945 .66429 .18163 Metetra
.656 .752 .92 r
.66429 .18163 .66995 .18945 .68171 .18522 .67608 .17738 Metetra
.656 .752 .92 r
.67608 .17738 .68171 .18522 .69351 .18098 .68792 .1731 Metetra
.656 .752 .92 r
.68792 .1731 .69351 .18098 .70537 .17672 .69982 .16881 Metetra
.656 .752 .92 r
.69982 .16881 .70537 .17672 .71728 .17244 .71176 .16449 Metetra
.656 .752 .92 r
.71176 .16449 .71728 .17244 .72924 .16814 .72375 .16016 Metetra
.656 .752 .92 r
.04824 .39521 .05542 .40147 .06481 .39808 .05764 .39179 Metetra
.656 .752 .92 r
.05764 .39179 .06481 .39808 .07422 .39468 .06708 .38837 Metetra
.656 .752 .92 r
.06708 .38837 .07422 .39468 .08367 .39127 .07655 .38493 Metetra
.656 .752 .92 r
.07655 .38493 .08367 .39127 .09316 .38784 .08606 .38149 Metetra
.656 .752 .92 r
.08606 .38149 .09316 .38784 .10269 .3844 .0956 .37802 Metetra
.656 .752 .92 r
.0956 .37802 .10269 .3844 .11224 .38095 .10518 .37455 Metetra
.656 .752 .92 r
.10518 .37455 .11224 .38095 .12184 .37749 .11479 .37106 Metetra
.656 .752 .92 r
.11479 .37106 .12184 .37749 .13147 .37401 .12444 .36756 Metetra
.656 .752 .92 r
.12444 .36756 .13147 .37401 .14114 .37052 .13413 .36404 Metetra
.656 .752 .92 r
.13413 .36404 .14114 .37052 .15084 .36702 .14386 .36051 Metetra
.656 .752 .92 r
.14386 .36051 .15084 .36702 .16058 .3635 .15362 .35697 Metetra
.656 .752 .92 r
.15362 .35697 .16058 .3635 .17036 .35997 .16342 .35342 Metetra
.656 .752 .92 r
.16342 .35342 .17036 .35997 .18018 .35643 .17326 .34985 Metetra
.656 .752 .92 r
.17326 .34985 .18018 .35643 .19003 .35287 .18313 .34626 Metetra
.656 .752 .92 r
.18313 .34626 .19003 .35287 .20633 .2868 .19304 .34267 Metetra
.456 .174 .395 r
.19304 .34267 .20633 .2868 .21612 .28271 .203 .33906 Metetra
.099 0 .255 r
.203 .33906 .21612 .28271 .22268 .31246 .21558 .30917 Metetra
.314 .733 .975 r
.21558 .30917 .22268 .31246 .23235 .3114 .2252 .30893 Metetra
.657 .901 .981 r
.2252 .30893 .23235 .3114 .24199 .31135 .23526 .30462 Metetra
.671 .754 .913 r
.23526 .30462 .24199 .31135 .25214 .30609 .24532 .30061 Metetra
.642 .79 .953 r
.24532 .30061 .25214 .30609 .26219 .30238 .25537 .2972 Metetra
.796 .825 .874 r
.25537 .2972 .26219 .30238 .2725 .29598 .26584 .28922 Metetra
.75 .774 .873 r
.26584 .28922 .2725 .29598 .28287 .28888 .2762 .28265 Metetra
.936 .751 .628 r
.2762 .28265 .28287 .28888 .2955 .25183 .28892 .24573 Metetra
.95 .608 .323 r
.28892 .24573 .2955 .25183 .30168 .30276 .29502 .29634 Metetra
.805 .337 0 r
.29502 .29634 .30168 .30276 .31056 .31958 .30391 .31278 Metetra
.558 .721 .95 r
.30391 .31278 .31056 .31958 .32086 .3174 .31419 .31099 Metetra
.501 .712 .966 r
.31419 .31099 .32086 .3174 .33112 .31655 .32448 .31001 Metetra
.705 .78 .91 r
.32448 .31001 .33112 .31655 .34167 .31173 .33508 .30489 Metetra
.569 .727 .948 r
.33508 .30489 .34167 .31173 .35211 .30954 .34553 .30288 Metetra
.652 .763 .931 r
.34553 .30288 .35211 .30954 .36269 .30576 .35613 .29912 Metetra
.623 .756 .941 r
.35613 .29912 .36269 .30576 .37327 .30266 .36674 .29599 Metetra
.661 .768 .929 r
.36674 .29599 .37327 .30266 .38394 .29874 .37744 .29199 Metetra
.689 .775 .917 r
.37744 .29199 .38394 .29874 .39468 .2942 .38822 .28722 Metetra
.644 .754 .929 r
.38822 .28722 .39468 .2942 .40542 .29032 .39898 .28359 Metetra
.721 .786 .903 r
.39898 .28359 .40542 .29032 .41628 .28452 .40986 .27786 Metetra
.62 .758 .945 r
.40986 .27786 .41628 .28452 .42707 .28183 .42069 .27473 Metetra
.737 .781 .888 r
.42069 .27473 .42707 .28183 .43802 .27506 .43167 .26833 Metetra
.723 .79 .904 r
.43167 .26833 .43802 .27506 .44898 .26884 .44266 .26248 Metetra
.935 .79 .676 r
.44266 .26248 .44898 .26884 .46037 .24386 .45412 .2372 Metetra
.967 .743 .548 r
.45412 .2372 .46037 .24386 .47224 .18534 .46615 .178 Metetra
.887 .477 .053 r
.46615 .178 .47224 .18534 .48255 .2141 .47639 .20834 Metetra
.555 .767 .977 r
.47639 .20834 .48255 .2141 .49345 .21231 .48732 .20619 Metetra
.489 .724 .976 r
.48732 .20619 .49345 .21231 .50439 .21261 .4983 .20517 Metetra
.604 .729 .933 r
.4983 .20517 .50439 .21261 .51544 .20554 .50936 .20239 Metetra
.752 .924 .947 r
.50936 .20239 .51544 .20554 .5265 .19964 .52048 .19561 Metetra
.851 .399 .007 r
.52048 .19561 .5265 .19964 .53747 .16177 .53169 .2198 Metetra
.458 .176 .397 r
.53169 .2198 .53747 .16177 .5485 .15845 .54299 .2157 Metetra
.457 .175 .396 r
.54299 .2157 .5485 .15845 .56033 .21917 .55434 .21158 Metetra
.656 .752 .92 r
.55434 .21158 .56033 .21917 .57169 .21507 .56573 .20745 Metetra
.656 .752 .92 r
.56573 .20745 .57169 .21507 .5831 .21095 .57717 .2033 Metetra
.656 .752 .92 r
.57717 .2033 .5831 .21095 .59455 .20681 .58866 .19913 Metetra
.656 .752 .92 r
.58866 .19913 .59455 .20681 .60606 .20266 .60019 .19495 Metetra
.656 .752 .92 r
.60019 .19495 .60606 .20266 .61761 .19849 .61177 .19074 Metetra
.656 .752 .92 r
.61177 .19074 .61761 .19849 .6292 .1943 .6234 .18652 Metetra
.656 .752 .92 r
.6234 .18652 .6292 .1943 .64085 .1901 .63508 .18229 Metetra
.656 .752 .92 r
.63508 .18229 .64085 .1901 .65255 .18587 .64681 .17803 Metetra
.656 .752 .92 r
.64681 .17803 .65255 .18587 .66429 .18163 .65859 .17376 Metetra
.656 .752 .92 r
.65859 .17376 .66429 .18163 .67608 .17738 .67041 .16947 Metetra
.656 .752 .92 r
.67041 .16947 .67608 .17738 .68792 .1731 .68229 .16516 Metetra
.656 .752 .92 r
.68229 .16516 .68792 .1731 .69982 .16881 .69422 .16083 Metetra
.656 .752 .92 r
.69422 .16083 .69982 .16881 .71176 .16449 .70619 .15649 Metetra
.656 .752 .92 r
.70619 .15649 .71176 .16449 .72375 .16016 .71822 .15212 Metetra
.656 .752 .92 r
.04101 .3889 .04824 .39521 .05764 .39179 .05043 .38546 Metetra
.656 .752 .92 r
.05043 .38546 .05764 .39179 .06708 .38837 .05988 .38202 Metetra
.656 .752 .92 r
.05988 .38202 .06708 .38837 .07655 .38493 .06937 .37856 Metetra
.656 .752 .92 r
.06937 .37856 .07655 .38493 .08606 .38149 .0789 .37508 Metetra
.656 .752 .92 r
.0789 .37508 .08606 .38149 .0956 .37802 .08846 .3716 Metetra
.656 .752 .92 r
.08846 .3716 .0956 .37802 .10518 .37455 .09806 .3681 Metetra
.656 .752 .92 r
.09806 .3681 .10518 .37455 .11479 .37106 .1077 .36458 Metetra
.656 .752 .92 r
.1077 .36458 .11479 .37106 .12444 .36756 .11737 .36106 Metetra
.656 .752 .92 r
.11737 .36106 .12444 .36756 .13413 .36404 .12708 .35752 Metetra
.656 .752 .92 r
.12708 .35752 .13413 .36404 .14386 .36051 .13682 .35396 Metetra
.656 .752 .92 r
.13682 .35396 .14386 .36051 .15362 .35697 .14661 .3504 Metetra
.656 .752 .92 r
.14661 .3504 .15362 .35697 .16342 .35342 .15643 .34682 Metetra
.656 .752 .92 r
.15643 .34682 .16342 .35342 .17326 .34985 .16629 .34322 Metetra
.656 .752 .92 r
.16629 .34322 .17326 .34985 .18313 .34626 .17618 .33961 Metetra
.656 .752 .92 r
.17618 .33961 .18313 .34626 .19304 .34267 .18612 .33599 Metetra
.656 .752 .92 r
.18612 .33599 .19304 .34267 .203 .33906 .19609 .33235 Metetra
.656 .752 .92 r
.19609 .33235 .203 .33906 .21558 .30917 .2061 .3287 Metetra
.348 0 .198 r
.2061 .3287 .21558 .30917 .2252 .30893 .21615 .32504 Metetra
.792 .87 .433 r
.21615 .32504 .2252 .30893 .23526 .30462 .22836 .2991 Metetra
.657 .794 .948 r
.22836 .2991 .23526 .30462 .24532 .30061 .23842 .29538 Metetra
.709 .816 .932 r
.23842 .29538 .24532 .30061 .25537 .2972 .24863 .2904 Metetra
.768 .776 .859 r
.24863 .2904 .25537 .2972 .26584 .28922 .25908 .28301 Metetra
.749 .792 .887 r
.25908 .28301 .26584 .28922 .2762 .28265 .26946 .27661 Metetra
.938 .752 .626 r
.26946 .27661 .2762 .28265 .28892 .24573 .28233 .23912 Metetra
.952 .609 .318 r
.28233 .23912 .28892 .24573 .29502 .29634 .28834 .28947 Metetra
.809 .347 0 r
.28834 .28947 .29502 .29634 .30391 .31278 .29717 .30644 Metetra
.568 .743 .959 r
.29717 .30644 .30391 .31278 .31419 .31099 .30749 .30436 Metetra
.525 .716 .96 r
.30749 .30436 .31419 .31099 .32448 .31001 .31782 .30304 Metetra
.688 .764 .91 r
.31782 .30304 .32448 .31001 .33508 .30489 .32842 .29835 Metetra
.576 .741 .955 r
.32842 .29835 .33508 .30489 .34553 .30288 .33891 .29613 Metetra
.655 .763 .929 r
.33891 .29613 .34553 .30288 .35613 .29912 .34954 .29228 Metetra
.623 .751 .938 r
.34954 .29228 .35613 .29912 .36674 .29599 .36017 .28912 Metetra
.658 .762 .927 r
.36017 .28912 .36674 .29599 .37744 .29199 .3709 .28515 Metetra
.683 .772 .919 r
.3709 .28515 .37744 .29199 .38822 .28722 .38169 .28054 Metetra
.663 .772 .93 r
.38169 .28054 .38822 .28722 .39898 .28359 .3925 .27642 Metetra
.709 .771 .901 r
.3925 .27642 .39898 .28359 .40986 .27786 .40341 .27097 Metetra
.608 .748 .944 r
.40341 .27097 .40986 .27786 .42069 .27473 .41425 .26809 Metetra
.756 .8 .889 r
.41425 .26809 .42069 .27473 .43167 .26833 .42528 .26112 Metetra
.711 .773 .901 r
.42528 .26112 .43167 .26833 .44266 .26248 .43629 .25557 Metetra
.929 .784 .679 r
.43629 .25557 .44266 .26248 .45412 .2372 .44782 .23074 Metetra
.968 .744 .547 r
.44782 .23074 .45412 .2372 .46615 .178 .46 .1712 Metetra
.887 .473 .059 r
.46 .1712 .46615 .178 .47639 .20834 .47021 .20094 Metetra
.486 .677 .949 r
.47021 .20094 .47639 .20834 .48732 .20619 .48115 .20033 Metetra
.503 .743 .981 r
.48115 .20033 .48732 .20619 .4983 .20517 .49216 .19897 Metetra
.806 .35 0 r
.49216 .19897 .4983 .20517 .50936 .20239 .50307 .22043 Metetra
.336 0 .178 r
.50307 .22043 .50936 .20239 .52048 .19561 .51431 .21633 Metetra
.359 .004 .218 r
.51431 .21633 .52048 .19561 .53169 .2198 .52559 .21222 Metetra
.656 .752 .92 r
.52559 .21222 .53169 .2198 .54299 .2157 .53692 .20809 Metetra
.656 .752 .92 r
.53692 .20809 .54299 .2157 .55434 .21158 .5483 .20394 Metetra
.656 .752 .92 r
.5483 .20394 .55434 .21158 .56573 .20745 .55972 .19977 Metetra
.656 .752 .92 r
.55972 .19977 .56573 .20745 .57717 .2033 .57119 .19559 Metetra
.656 .752 .92 r
.57119 .19559 .57717 .2033 .58866 .19913 .58271 .19139 Metetra
.656 .752 .92 r
.58271 .19139 .58866 .19913 .60019 .19495 .59428 .18717 Metetra
.656 .752 .92 r
.59428 .18717 .60019 .19495 .61177 .19074 .60589 .18294 Metetra
.656 .752 .92 r
.60589 .18294 .61177 .19074 .6234 .18652 .61756 .17869 Metetra
.656 .752 .92 r
.61756 .17869 .6234 .18652 .63508 .18229 .62927 .17442 Metetra
.656 .752 .92 r
.62927 .17442 .63508 .18229 .64681 .17803 .64103 .17013 Metetra
.656 .752 .92 r
.64103 .17013 .64681 .17803 .65859 .17376 .65284 .16582 Metetra
.656 .752 .92 r
.65284 .16582 .65859 .17376 .67041 .16947 .6647 .1615 Metetra
.656 .752 .92 r
.6647 .1615 .67041 .16947 .68229 .16516 .67661 .15716 Metetra
.656 .752 .92 r
.67661 .15716 .68229 .16516 .69422 .16083 .68857 .15279 Metetra
.656 .752 .92 r
.68857 .15279 .69422 .16083 .70619 .15649 .70059 .14842 Metetra
.656 .752 .92 r
.70059 .14842 .70619 .15649 .71822 .15212 .71265 .14402 Metetra
.656 .752 .92 r
.03372 .38255 .04101 .3889 .05043 .38546 .04316 .37909 Metetra
.656 .752 .92 r
.04316 .37909 .05043 .38546 .05988 .38202 .05264 .37562 Metetra
.656 .752 .92 r
.05264 .37562 .05988 .38202 .06937 .37856 .06215 .37213 Metetra
.656 .752 .92 r
.06215 .37213 .06937 .37856 .0789 .37508 .07169 .36864 Metetra
.656 .752 .92 r
.07169 .36864 .0789 .37508 .08846 .3716 .08128 .36512 Metetra
.656 .752 .92 r
.08128 .36512 .08846 .3716 .09806 .3681 .09089 .3616 Metetra
.656 .752 .92 r
.09089 .3616 .09806 .3681 .1077 .36458 .10055 .35806 Metetra
.656 .752 .92 r
.10055 .35806 .1077 .36458 .11737 .36106 .11024 .35451 Metetra
.656 .752 .92 r
.11024 .35451 .11737 .36106 .12708 .35752 .11997 .35095 Metetra
.656 .752 .92 r
.11997 .35095 .12708 .35752 .13682 .35396 .12974 .34737 Metetra
.656 .752 .92 r
.12974 .34737 .13682 .35396 .14661 .3504 .13954 .34378 Metetra
.656 .752 .92 r
.13954 .34378 .14661 .3504 .15643 .34682 .14939 .34017 Metetra
.656 .752 .92 r
.14939 .34017 .15643 .34682 .16629 .34322 .15927 .33655 Metetra
.656 .752 .92 r
.15927 .33655 .16629 .34322 .17618 .33961 .16918 .33292 Metetra
.656 .752 .92 r
.16918 .33292 .17618 .33961 .18612 .33599 .17914 .32927 Metetra
.656 .752 .92 r
.17914 .32927 .18612 .33599 .19609 .33235 .18914 .3256 Metetra
.656 .752 .92 r
.18914 .3256 .19609 .33235 .2061 .3287 .19917 .32193 Metetra
.656 .752 .92 r
.19917 .32193 .2061 .3287 .21615 .32504 .20924 .31824 Metetra
.656 .752 .92 r
.20924 .31824 .21615 .32504 .22836 .2991 .21936 .31453 Metetra
.297 0 .114 r
.21936 .31453 .22836 .2991 .23842 .29538 .22951 .31081 Metetra
.824 .884 .454 r
.22951 .31081 .23842 .29538 .24863 .2904 .24179 .28413 Metetra
.769 .793 .873 r
.24179 .28413 .24863 .2904 .25908 .28301 .25225 .27692 Metetra
.762 .798 .882 r
.25225 .27692 .25908 .28301 .26946 .27661 .26271 .27004 Metetra
.935 .748 .625 r
.26271 .27004 .26946 .27661 .28233 .23912 .27571 .23215 Metetra
.953 .61 .317 r
.27571 .23215 .28233 .23912 .28834 .28947 .28158 .28296 Metetra
.812 .346 0 r
.28158 .28296 .28834 .28947 .29717 .30644 .2904 .29974 Metetra
.582 .738 .95 r
.2904 .29974 .29717 .30644 .30749 .30436 .30076 .29744 Metetra
.51 .701 .956 r
.30076 .29744 .30749 .30436 .31782 .30304 .31109 .29639 Metetra
.697 .778 .914 r
.31109 .29639 .31782 .30304 .32842 .29835 .32173 .29144 Metetra
.568 .728 .949 r
.32173 .29144 .32842 .29835 .33891 .29613 .33223 .28938 Metetra
.664 .768 .927 r
.33223 .28938 .33891 .29613 .34954 .29228 .3429 .28526 Metetra
.624 .747 .935 r
.3429 .28526 .34954 .29228 .36017 .28912 .35356 .28208 Metetra
.649 .755 .927 r
.35356 .28208 .36017 .28912 .3709 .28515 .3643 .27832 Metetra
.69 .776 .917 r
.3643 .27832 .3709 .28515 .38169 .28054 .37513 .27349 Metetra
.654 .758 .927 r
.37513 .27349 .38169 .28054 .3925 .27642 .38596 .26957 Metetra
.72 .785 .904 r
.38596 .26957 .3925 .27642 .40341 .27097 .39691 .2638 Metetra
.599 .736 .94 r
.39691 .2638 .40341 .27097 .41425 .26809 .40777 .26108 Metetra
.748 .789 .886 r
.40777 .26108 .41425 .26809 .42528 .26112 .41883 .25428 Metetra
.726 .79 .903 r
.41883 .25428 .42528 .26112 .43629 .25557 .42989 .24827 Metetra
.925 .78 .681 r
.42989 .24827 .43629 .25557 .44782 .23074 .44148 .22372 Metetra
.965 .741 .549 r
.44148 .22372 .44782 .23074 .46 .1712 .4538 .16451 Metetra
.887 .472 .06 r
.4538 .16451 .46 .1712 .47021 .20094 .46397 .19406 Metetra
.864 .438 .006 r
.46397 .19406 .47021 .20094 .48115 .20033 .47447 .22106 Metetra
.355 0 .213 r
.47447 .22106 .48115 .20033 .49216 .19897 .48565 .21696 Metetra
.331 0 .172 r
.48565 .21696 .49216 .19897 .50307 .22043 .49687 .21285 Metetra
.656 .752 .92 r
.49687 .21285 .50307 .22043 .51431 .21633 .50814 .20872 Metetra
.656 .752 .92 r
.50814 .20872 .51431 .21633 .52559 .21222 .51945 .20458 Metetra
.656 .752 .92 r
.51945 .20458 .52559 .21222 .53692 .20809 .53081 .20042 Metetra
.656 .752 .92 r
.53081 .20042 .53692 .20809 .5483 .20394 .54222 .19624 Metetra
.656 .752 .92 r
.54222 .19624 .5483 .20394 .55972 .19977 .55367 .19204 Metetra
.656 .752 .92 r
.55367 .19204 .55972 .19977 .57119 .19559 .56517 .18782 Metetra
.656 .752 .92 r
.56517 .18782 .57119 .19559 .58271 .19139 .57672 .18359 Metetra
.656 .752 .92 r
.57672 .18359 .58271 .19139 .59428 .18717 .58832 .17934 Metetra
.656 .752 .92 r
.58832 .17934 .59428 .18717 .60589 .18294 .59997 .17508 Metetra
.656 .752 .92 r
.59997 .17508 .60589 .18294 .61756 .17869 .61167 .17079 Metetra
.656 .752 .92 r
.61167 .17079 .61756 .17869 .62927 .17442 .62341 .16649 Metetra
.656 .752 .92 r
.62341 .16649 .62927 .17442 .64103 .17013 .63521 .16216 Metetra
.656 .752 .92 r
.63521 .16216 .64103 .17013 .65284 .16582 .64705 .15783 Metetra
.656 .752 .92 r
.64705 .15783 .65284 .16582 .6647 .1615 .65894 .15347 Metetra
.656 .752 .92 r
.65894 .15347 .6647 .1615 .67661 .15716 .67089 .14909 Metetra
.656 .752 .92 r
.67089 .14909 .67661 .15716 .68857 .15279 .68289 .14469 Metetra
.656 .752 .92 r
.68289 .14469 .68857 .15279 .70059 .14842 .69493 .14028 Metetra
.656 .752 .92 r
.69493 .14028 .70059 .14842 .71265 .14402 .70703 .13585 Metetra
.656 .752 .92 r
.02639 .37615 .03372 .38255 .04316 .37909 .03585 .37267 Metetra
.656 .752 .92 r
.03585 .37267 .04316 .37909 .05264 .37562 .04534 .36917 Metetra
.656 .752 .92 r
.04534 .36917 .05264 .37562 .06215 .37213 .05487 .36567 Metetra
.656 .752 .92 r
.05487 .36567 .06215 .37213 .07169 .36864 .06444 .36214 Metetra
.656 .752 .92 r
.06444 .36214 .07169 .36864 .08128 .36512 .07404 .35861 Metetra
.656 .752 .92 r
.07404 .35861 .08128 .36512 .09089 .3616 .08368 .35506 Metetra
.656 .752 .92 r
.08368 .35506 .09089 .3616 .10055 .35806 .09335 .3515 Metetra
.656 .752 .92 r
.09335 .3515 .10055 .35806 .11024 .35451 .10307 .34792 Metetra
.656 .752 .92 r
.10307 .34792 .11024 .35451 .11997 .35095 .11282 .34433 Metetra
.656 .752 .92 r
.11282 .34433 .11997 .35095 .12974 .34737 .1226 .34072 Metetra
.656 .752 .92 r
.1226 .34072 .12974 .34737 .13954 .34378 .13243 .33711 Metetra
.656 .752 .92 r
.13243 .33711 .13954 .34378 .14939 .34017 .14229 .33348 Metetra
.656 .752 .92 r
.14229 .33348 .14939 .34017 .15927 .33655 .1522 .32983 Metetra
.656 .752 .92 r
.1522 .32983 .15927 .33655 .16918 .33292 .16214 .32617 Metetra
.656 .752 .92 r
.16214 .32617 .16918 .33292 .17914 .32927 .17211 .32249 Metetra
.656 .752 .92 r
.17211 .32249 .17914 .32927 .18914 .3256 .18213 .31881 Metetra
.656 .752 .92 r
.18213 .31881 .18914 .3256 .19917 .32193 .19219 .3151 Metetra
.656 .752 .92 r
.19219 .3151 .19917 .32193 .20924 .31824 .20228 .31139 Metetra
.656 .752 .92 r
.20228 .31139 .20924 .31824 .21936 .31453 .21242 .30765 Metetra
.656 .752 .92 r
.21242 .30765 .21936 .31453 .22951 .31081 .22259 .30391 Metetra
.656 .752 .92 r
.22259 .30391 .22951 .31081 .24179 .28413 .23281 .30015 Metetra
.301 0 .122 r
.23281 .30015 .24179 .28413 .25225 .27692 .24307 .29637 Metetra
.339 0 .186 r
.24307 .29637 .25225 .27692 .26271 .27004 .25336 .29258 Metetra
.99 .84 .468 r
.25336 .29258 .26271 .27004 .27571 .23215 .26901 .22555 Metetra
.951 .609 .32 r
.26901 .22555 .27571 .23215 .28158 .28296 .27478 .27621 Metetra
.803 .336 0 r
.27478 .27621 .28158 .28296 .2904 .29974 .2836 .29269 Metetra
.565 .721 .946 r
.2836 .29269 .2904 .29974 .30076 .29744 .29396 .29073 Metetra
.512 .712 .962 r
.29396 .29073 .30076 .29744 .31109 .29639 .30431 .28955 Metetra
.696 .773 .911 r
.30431 .28955 .31109 .29639 .32173 .29144 .31498 .2846 Metetra
.583 .737 .949 r
.31498 .2846 .32173 .29144 .33223 .28938 .32552 .28223 Metetra
.654 .753 .923 r
.32552 .28223 .33223 .28938 .3429 .28526 .3362 .27834 Metetra
.623 .751 .938 r
.3362 .27834 .3429 .28526 .35356 .28208 .34689 .27513 Metetra
.659 .763 .927 r
.34689 .27513 .35356 .28208 .3643 .27832 .35767 .27109 Metetra
.679 .761 .914 r
.35767 .27109 .3643 .27832 .37513 .27349 .36852 .2665 Metetra
.655 .763 .929 r
.36852 .2665 .37513 .27349 .38596 .26957 .37937 .26253 Metetra
.716 .78 .903 r
.37937 .26253 .38596 .26957 .39691 .2638 .39035 .25684 Metetra
.615 .751 .942 r
.39035 .25684 .39691 .2638 .40777 .26108 .40125 .25372 Metetra
.738 .778 .885 r
.40125 .25372 .40777 .26108 .41883 .25428 .41234 .24719 Metetra
.719 .782 .902 r
.41234 .24719 .41883 .25428 .42989 .24827 .42342 .24136 Metetra
.884 .803 .765 r
.42342 .24136 .42989 .24827 .44148 .22372 .43482 .22576 Metetra
.28 .771 .706 r
.43482 .22576 .44148 .22372 .4538 .16451 .44589 .22169 Metetra
.449 .164 .387 r
.44589 .22169 .4538 .16451 .46397 .19406 .457 .21759 Metetra
.37 .023 .241 r
.457 .21759 .46397 .19406 .47447 .22106 .46816 .21349 Metetra
.656 .752 .92 r
.46816 .21349 .47447 .22106 .48565 .21696 .47937 .20936 Metetra
.656 .752 .92 r
.47937 .20936 .48565 .21696 .49687 .21285 .49062 .20522 Metetra
.656 .752 .92 r
.49062 .20522 .49687 .21285 .50814 .20872 .50191 .20106 Metetra
.656 .752 .92 r
.50191 .20106 .50814 .20872 .51945 .20458 .51326 .19688 Metetra
.656 .752 .92 r
.51326 .19688 .51945 .20458 .53081 .20042 .52465 .19269 Metetra
.656 .752 .92 r
.52465 .19269 .53081 .20042 .54222 .19624 .53609 .18847 Metetra
.656 .752 .92 r
.53609 .18847 .54222 .19624 .55367 .19204 .54757 .18424 Metetra
.656 .752 .92 r
.54757 .18424 .55367 .19204 .56517 .18782 .55911 .18 Metetra
.656 .752 .92 r
.55911 .18 .56517 .18782 .57672 .18359 .57069 .17573 Metetra
.656 .752 .92 r
.57069 .17573 .57672 .18359 .58832 .17934 .58232 .17145 Metetra
.656 .752 .92 r
.58232 .17145 .58832 .17934 .59997 .17508 .594 .16715 Metetra
.656 .752 .92 r
.594 .16715 .59997 .17508 .61167 .17079 .60573 .16283 Metetra
.656 .752 .92 r
.60573 .16283 .61167 .17079 .62341 .16649 .61751 .15849 Metetra
.656 .752 .92 r
.61751 .15849 .62341 .16649 .63521 .16216 .62934 .15414 Metetra
.656 .752 .92 r
.62934 .15414 .63521 .16216 .64705 .15783 .64121 .14976 Metetra
.656 .752 .92 r
.64121 .14976 .64705 .15783 .65894 .15347 .65314 .14537 Metetra
.656 .752 .92 r
.65314 .14537 .65894 .15347 .67089 .14909 .66512 .14096 Metetra
.656 .752 .92 r
.66512 .14096 .67089 .14909 .68289 .14469 .67715 .13653 Metetra
.656 .752 .92 r
.67715 .13653 .68289 .14469 .69493 .14028 .68924 .13208 Metetra
.656 .752 .92 r
.68924 .13208 .69493 .14028 .70703 .13585 .70137 .12761 Metetra
.656 .752 .92 r
.019 .36971 .02639 .37615 .03585 .37267 .02848 .36621 Metetra
.656 .752 .92 r
.02848 .36621 .03585 .37267 .04534 .36917 .03799 .36269 Metetra
.656 .752 .92 r
.03799 .36269 .04534 .36917 .05487 .36567 .04754 .35915 Metetra
.656 .752 .92 r
.04754 .35915 .05487 .36567 .06444 .36214 .05713 .35561 Metetra
.656 .752 .92 r
.05713 .35561 .06444 .36214 .07404 .35861 .06675 .35204 Metetra
.656 .752 .92 r
.06675 .35204 .07404 .35861 .08368 .35506 .07641 .34847 Metetra
.656 .752 .92 r
.07641 .34847 .08368 .35506 .09335 .3515 .08611 .34488 Metetra
.656 .752 .92 r
.08611 .34488 .09335 .3515 .10307 .34792 .09584 .34128 Metetra
.656 .752 .92 r
.09584 .34128 .10307 .34792 .11282 .34433 .10561 .33766 Metetra
.656 .752 .92 r
.10561 .33766 .11282 .34433 .1226 .34072 .11542 .33403 Metetra
.656 .752 .92 r
.11542 .33403 .1226 .34072 .13243 .33711 .12527 .33039 Metetra
.656 .752 .92 r
.12527 .33039 .13243 .33711 .14229 .33348 .13515 .32673 Metetra
.656 .752 .92 r
.13515 .32673 .14229 .33348 .1522 .32983 .14507 .32306 Metetra
.656 .752 .92 r
.14507 .32306 .1522 .32983 .16214 .32617 .15504 .31937 Metetra
.656 .752 .92 r
.15504 .31937 .16214 .32617 .17211 .32249 .16504 .31567 Metetra
.656 .752 .92 r
.16504 .31567 .17211 .32249 .18213 .31881 .17508 .31196 Metetra
.656 .752 .92 r
.17508 .31196 .18213 .31881 .19219 .3151 .18516 .30823 Metetra
.656 .752 .92 r
.18516 .30823 .19219 .3151 .20228 .31139 .19527 .30448 Metetra
.656 .752 .92 r
.19527 .30448 .20228 .31139 .21242 .30765 .20543 .30073 Metetra
.656 .752 .92 r
.20543 .30073 .21242 .30765 .22259 .30391 .21563 .29695 Metetra
.656 .752 .92 r
.21563 .29695 .22259 .30391 .23281 .30015 .22587 .29316 Metetra
.656 .752 .92 r
.22587 .29316 .23281 .30015 .24307 .29637 .23615 .28936 Metetra
.656 .752 .92 r
.23615 .28936 .24307 .29637 .25336 .29258 .24647 .28554 Metetra
.656 .752 .92 r
.24647 .28554 .25336 .29258 .26901 .22555 .25683 .28171 Metetra
.446 .159 .382 r
.25683 .28171 .26901 .22555 .27478 .27621 .26723 .27786 Metetra
.348 .822 .781 r
.26723 .27786 .27478 .27621 .2836 .29269 .27768 .27399 Metetra
.606 .518 .729 r
.27768 .27399 .2836 .29269 .29396 .29073 .28816 .27011 Metetra
.599 .498 .711 r
.28816 .27011 .29396 .29073 .30431 .28955 .29869 .26622 Metetra
.591 .474 .689 r
.29869 .26622 .30431 .28955 .31498 .2846 .30926 .26231 Metetra
.594 .483 .697 r
.30926 .26231 .31498 .2846 .32552 .28223 .31987 .25838 Metetra
.589 .471 .686 r
.31987 .25838 .32552 .28223 .3362 .27834 .33052 .25444 Metetra
.589 .471 .686 r
.33052 .25444 .3362 .27834 .34689 .27513 .34122 .25048 Metetra
.587 .465 .681 r
.34122 .25048 .34689 .27513 .35767 .27109 .35196 .2465 Metetra
.588 .466 .682 r
.35196 .2465 .35767 .27109 .36852 .2665 .36275 .24251 Metetra
.589 .471 .686 r
.36275 .24251 .36852 .2665 .37937 .26253 .37357 .2385 Metetra
.589 .471 .686 r
.37357 .2385 .37937 .26253 .39035 .25684 .38444 .23448 Metetra
.595 .485 .699 r
.38444 .23448 .39035 .25684 .40125 .25372 .39536 .23044 Metetra
.592 .478 .692 r
.39536 .23044 .40125 .25372 .41234 .24719 .40632 .22639 Metetra
.6 .5 .713 r
.40632 .22639 .41234 .24719 .42342 .24136 .41733 .22231 Metetra
.607 .52 .73 r
.41733 .22231 .42342 .24136 .43482 .22576 .42838 .21822 Metetra
.656 .752 .92 r
.42838 .21822 .43482 .22576 .44589 .22169 .43947 .21412 Metetra
.656 .752 .92 r
.43947 .21412 .44589 .22169 .457 .21759 .45062 .21 Metetra
.656 .752 .92 r
.45062 .21 .457 .21759 .46816 .21349 .4618 .20586 Metetra
.656 .752 .92 r
.4618 .20586 .46816 .21349 .47937 .20936 .47304 .2017 Metetra
.656 .752 .92 r
.47304 .2017 .47937 .20936 .49062 .20522 .48432 .19752 Metetra
.656 .752 .92 r
.48432 .19752 .49062 .20522 .50191 .20106 .49565 .19333 Metetra
.656 .752 .92 r
.49565 .19333 .50191 .20106 .51326 .19688 .50702 .18912 Metetra
.656 .752 .92 r
.50702 .18912 .51326 .19688 .52465 .19269 .51844 .1849 Metetra
.656 .752 .92 r
.51844 .1849 .52465 .19269 .53609 .18847 .52991 .18065 Metetra
.656 .752 .92 r
.52991 .18065 .53609 .18847 .54757 .18424 .54143 .17639 Metetra
.656 .752 .92 r
.54143 .17639 .54757 .18424 .55911 .18 .55299 .17211 Metetra
.656 .752 .92 r
.55299 .17211 .55911 .18 .57069 .17573 .56461 .16781 Metetra
.656 .752 .92 r
.56461 .16781 .57069 .17573 .58232 .17145 .57627 .1635 Metetra
.656 .752 .92 r
.57627 .1635 .58232 .17145 .594 .16715 .58798 .15916 Metetra
.656 .752 .92 r
.58798 .15916 .594 .16715 .60573 .16283 .59975 .15481 Metetra
.656 .752 .92 r
.59975 .15481 .60573 .16283 .61751 .15849 .61156 .15044 Metetra
.656 .752 .92 r
.61156 .15044 .61751 .15849 .62934 .15414 .62342 .14605 Metetra
.656 .752 .92 r
.62342 .14605 .62934 .15414 .64121 .14976 .63533 .14164 Metetra
.656 .752 .92 r
.63533 .14164 .64121 .14976 .65314 .14537 .6473 .13721 Metetra
.656 .752 .92 r
.6473 .13721 .65314 .14537 .66512 .14096 .65931 .13277 Metetra
.656 .752 .92 r
.65931 .13277 .66512 .14096 .67715 .13653 .67138 .1283 Metetra
.656 .752 .92 r
.67138 .1283 .67715 .13653 .68924 .13208 .68349 .12382 Metetra
.656 .752 .92 r
.68349 .12382 .68924 .13208 .70137 .12761 .69566 .11932 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14766 .21187 m
.15228 .21653 L
s
[(-20)] .13842 .20256 .99254 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.55397 .05277 m
.55784 .05807 L
s
[(20)] .54622 .04218 .73193 1 Mshowa
.125 Mabswid
.19515 .19327 m
.19788 .19611 L
s
.24353 .17433 m
.24621 .17721 L
s
.29283 .15503 m
.29545 .15796 L
s
.39427 .1153 m
.39678 .11833 L
s
.44647 .09487 m
.44892 .09794 L
s
.49969 .07402 m
.50208 .07715 L
s
.10103 .23013 m
.10385 .23288 L
s
.05524 .24806 m
.0581 .25076 L
s
.60933 .03109 m
.61159 .03432 L
s
.66582 .00897 m
.668 .01225 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 233.562},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GPP10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0/@000?l0/@000?l0/@000?l0/@000?l0
/@000?l0/@000?l0/@000?l0/@000?l0;`02oh00003o02`00ol00`3o001o0000o`0Z00;o1002ogl0
003o02L00ol60003o`3o07h0003o02D00_l90003o`3o07h0003o02800ol20003o`0000H000Co003o
O@000?l07`03o`h000Go0000o`1l0000o`0M00;o4@001Ol0003o07`0003U00Ko100012IXo`DV00?o
4`001_l00?l0og/0003U0003UOmV008000IX0000I_<2iP03Z;h002800_lF0003o`0000<000?o0000
N0000>H000>EofH01@001RVn002nlb000olH0003o`0000<000?o0000N0000>L000>nJ6H010000ol0
00020003o`0001`00_lL0003o`0000<000?o0000M`000>P000=VJ6H00`000ol000020003o`0001T0
0olN0003o`0000<000?o0000M`000>T000>nl`000P000ol000020003o`0001L00_lQ0003o`0000@0
00?o0000MP000>X000Ko0000:Kh20003_RT001D00ol20003o`0001h000?o00001@000ol0001e0000
i@001_mEiP05l`<000IVlnKVlfHC00?o9P000ol000050003o`0007D0003U0006__?oofgV100012IX
J6HB00;o:@000ol000060003o`0007@0003o00<00ol[0003o`0000L000?o0000L`000?l00@02obh0
00?o00001`000ol0001c0000o@03oc0000?o000020000ol0001b0000n`02oc<000?o00002@000ol0
001a0000n003ocD000?o00002@000ol0001a0000mP02ocP000?o00002P000ol0001`0000l`03o`80
00?o0000=@000ol0000;0003o`0006l0003`00?o1P000ol0000d0003o`0000T00oma0000kP02od00
00?o000030000ol0001^0000j`03od8000?o00003@000ol0001]0000j@02odD000?o00003@000ol0
001]0000iP03odL000?o00003P000ol0001/0000i002odX000?o00003`000ol0001[0000h@03od`0
00?o00003`000ol0001[0000g`03odl000?o00003`000ol0001Z0000g003o`<000?o0000C0000ol0
000?0003o`0001401_l400049VSo1D/0003I00?oE@000ol0000@0003o`00010000>EofH00P001VP0
001Vl`;V00>X_P00B@000=L00_mH0003o`00014000?o000040000iGoIP050006:Kh00;kcBP000=@0
0omJ0003o`00014000?o00001P07o`@000>nJ6H010000ol000020003o`0004P0003B00;oG@000ol0
000B0003o`00014000=VJ6H00`000ol000020003o`0004P0003?00?oG`000ol0000C0003o`000140
00>nl`000P000ol000020003o`0004P0003=00;oHP000ol0000C0003o`00018000Ko0000:Kh20003
_RT004T0003:00?oI0000ol0000C00;o3P001_mEiP05l`<000IVlnKVlfI:0000b002o`8000?o0000
HP000ol0000B0004o`00o`d000JnloooKNH400049VQXIT/0003500?oJ@000ol0000E0003o`0006@0
002G00049VSo1BP00_m/0003o`0001H000?o0000H`0009H000IVlnKVZ;hT00?oKP000ol0000G0003
o`000680002F0006:Kh00;kc8@03og4000?o00005`000ol0001R0000UP000ol000020003o`0001d0
0_md0003o`0001P000?o0000H@0009H000?o00000P000ol0000J00?oMP000ol0000I0003o`000600
002F0003o`00008000?o00006002ogT000?o00006@000ol0001P0000UP001RVn002n:AL01?mj0003
o`0001X000?o0000G`0009H000IVlnKVlfHE00;o10000ol0001f00;o7@000ol0001N0000U`0012IX
J6HC00?oO003o`035_l001`000?o0000GP000:`00_mm00;o00J6cXK>Q_lM0003o`0005d0002Y00?o
O003o`07LQKo5W8FLP02oa`000?o0000G@000:H00omm00;o00[>Q/j6cXKoQ/j60olL0003o`0005`0
002T00;oOP02o`085W;oLQIb5W85o`03L_l001`000?o0000F`000:400omn00;o00O>Q/j6c_o>00?o
00S>olj6ohK>oa/00_mM0000W`03ogd00ol01aKo5W8FLQH00_l02W8FLQIbog;oLQH2oa`000?o0000
FP0009`00ol20003o`0007P00ol01hK>Q/j6ohH00ol02HKoQ/j6cXKoQP03o`03Q_l001`000?o0000
F@0009X00_l60003o`0007<01?l021Ibog8FLQIb0_l02QIb5W8FoaIb5W83o`05LQIb5_l070000ol0
001I0000U`03og/00ol02LkocXK>Q/kocP03o`09c_o>Q/j6c_o>00?o00O>oon6cXK>00;o70000ol0
001H0000U@02og`00_l02W8FLQIbog8FLQH2o`09LQIb5W;oLQIb00?o00Mb5W8FL_mb00?o00=bo`00
70000ol0001G0000TP03og/00ol02HKoQ/j6cXKoQP03o`07Q_n6cXK>QP04o`08cXK>olj6cXH2o`06
cXK>Q/ko70000ol0001G0000S`03og`00_l02QIb5W8FoaIb5W82o`075W8FLQKo5P03o`0:5_lFLQIb
5W;oLPCo00LFLQIb5W;o01`000?o0000EP0008d00_ml00?o00W>olj6cXK>olh00ol01lkocXK>Q/h0
0_l02hK>Q/j6ohK>Q/j600;o00[>Q_n6ohK>Q/j60_lL0003o`0005D0002:00?oO002o`09LQIb5W;o
LQIb00?o00Mb5W8FL_mb00?o00Ybog8FLQIb5_lF0ol02AKo5W;oLQKo5P03o`035_l001/000?o0000
E@0008P00_l30003o`0006@00_l@00?o00N6c_o>Q/j600Co00S>Q/kocXK>QP;o00_>Q/j6c_o>Q/j6
cP02o`09Q/j6cXKoQ_n600?o00J6cXK>Q_lL0003o`0005@0002500?oJ@03o`03;Ol000`00ol021Ib
5W8FL_mb0_l02QKo5W8FLQIbog82o`0:5W;oLQIb5W;oLP?o00Mbog8FLQIb00Co00PFL_mb5W8FLP;o
70000ol0001C0000P`02of/000KoKRe^;Ol900Co00V6cXKoQ/j6cXH00_l02/j6cXKoQ/j6cXH2o`09
cXK>Q/kocXK>00?o00O>Q/j6c_o>00?o00W>oon6cXK>olh00ol00lko000K0003o`0005<0002000?o
B`000ol0000O0005ogd]OBd00_l600;o00Ybog8FLQIb5_lF0ol02AKo5W8FLQKo5P03o`075_lFLQIb
5P04o`08LQKo5W8FLQH2o`0:LQIb5W;oLQIb5P;o00Ib5W8FL_lL0003o`000580001n00;oCP02ob00
00GoKRe^;@02o`@00_l02XK>Q/kocXK>Q/h2o`09Q/j6cXKoQ/j600?o00N6cXK>Q_n600?o00V6ohK>
Q/j6ohH00ol02HKoQ/j6cXKoQP03o`07Q_n6cXK>QP02oa`000?o0000D@0007/00om@00?o7P02o`04
OBem;@;o00d0ooooL_mb5W8FL_mb00?o00Mbog8FLQIb00Co00PFL_mb5W8FLP;o00XFLQIb5_lFLQIb
0_l02AIb5W8FoaIb5P03o`075W8FLQKo5P03o`035_l001T00omC0000N@02oe800ol00a7o000K00?o
00A^;Fh]0ol02Lj6cXK>olj6cP03o`07cXK>Q/kocP03o`09c_o>Q/j6c_o>00?o00W>olj6cXK>olh0
0ol01lkocXK>Q/h01?l028Koolj6cXK>0_l01XK>Q/j6oa`000?o0000D00007H00omD00?o00=Nool0
6`03o`03OBgo00;o00LFoaIb5W8F00Co00Qb5_lFLQIb5P;o00Yb5W8FL_mb5W8F0_l02G8FLQIbog8F
LP03o`07LQIb5W;oLP03o`06L_mb5W8F0_l037;ooomb5_lFLQIboa`000?o0000D00003`01_l40004
9VSo1BT00ol30003o`00054000Go;Fko@@02oaX01Ol01hK>Q/j6ohH00ol02HKoQ/j6cXKoQP03o`09
Q/kocXK>Q_n600?o00N6c_o>Q/j600Co00S>Q/kocXK>QP;o00W>Q/j6c_o>Q/h00ol02Lj6cXK>Q_n6
cP03oa`000?o0000C`0003`000>EofH00P001VP0001Vl`;V00>X_P009@02oeX000Go1Bgo4003oaL0
1?l021Ib5_lFLQIb0_l02QIb5W8FoaIb5W82o`095W8FLQIbog8F00?o00PFLQIb5W;oLP;o00XFoaIb
5W8FL_mb0_l02QIbog8FLQIbog82o`085W;oLQIb5W83o`04LQIboa`000?o0000CP0003d000>EofH0
1@001RVn002nlb<00omL0005obe^od400_l00a7o000C00;o00[>olj6cXK>Q_n60_l02/j6ohK>Q/j6
ohH2o`08cXKoQ/j6cXH3o`09Q/j6ohK>Q/j600;o00[>Q/j6ohK>Q/j60_l02Lj6cXK>olj6cP03o`07
c_o>Q/kocP03o`08c_o>Q/j6c_lK0003o`0004h0000c00Oo10000kiXIP040003o`00008000?o0000
7`02oeh00_l01@D]1OmN00;o00<@o`0030001?l00002o`0:5W8FL_mb5W8FLP;o00TFLQIb5_lFLQH0
0ol01aIb5W8FoaH00ol02AKo5W8FLQKo5P03o`095_lFLQIb5_lF00?o00LFoaIb5W8F00Co00Qb5_lF
oaIb5P;o00Yb5W8FL_mb5W8F0_lK0003o`0004d0000o0003IVQV00<000?o00000P000ol0000L00?o
H002o`05;Fh]oa400_l00d7o000<00Co00W>olj6cXK>olh00ol01lkocXK>Q/h01?l028K>olj6cXK>
0_l02XK>Q/j6ohK>Q/h2o`09Q/j6cXKoQ/j600?o00N6cXK>Q_n600?o00N6ohK>Q/j600Go00V6ohK>
Q/j6ohH00ol00hKo000K0003o`0004`000100003__<0008000?o00000P000ol0000J00;oH`02o`05
1Bd5oeh00_l00a2No`0;00;o00Ub5W8FL_mb5W800ol01g8FLQIbog800ol02G;oLQIb5W;oLP03o`09
L_mb5W8FL_mb00?o00Mbog8FLQIb00Co00PFL_mb5W8FLP;o00XFLQIb5_lFLQIb0_l02AIb5W8FoaIb
5P03o`065W8FLQKo6`000ol0001<0000@@001_l0000Y_P8000>n:@006003ofD00_l01Re^;Fko@@;o
00@Aoooo1P03o`07Q/kocXK>QP04o`08cXKoQ/j6cXH2o`0:cXK>Q/kocXK>QP;o00W>Q/j6c_o>Q/h0
0ol01lj6cXK>olh00ol02LkocXK>Q/kocP03o`09c_o>Q/j6c_o>00?o00O>olj6cXK>00Co00R6c_o>
Q/j6cP;o6`000ol0001;0000?0001_mEiP05l`<000IVlnKVlfHG00?oI`002?l]1Bd5;Ol@0_l01Iko
oa7o00800ol021Ib5W8FL_mb0_l02AKo5W8FLQKo5P03o`095W;oLQIb5_lF00?o00LFoaIb5W8F00Co
00Qb5_lFLQIb5P;o00Ub5W8FL_mb5W800ol02G8FLQIbog8FLP03o`04LQIb5P;o00ebooooL_mb5W8F
L_mb00?o00=bo`006`000ol0001:0000?0001[kcoom]iP@000@VJ6QV5@03o`<000?o0000H`02o`05
KRe^;Fh01?l00a51o`04o`09Q/j6ohK>Q/j600;o00W>Q/j6ohK>Q/h00_l02HK>Q/j6c_o>QP03o`07
Q/j6cXKoQP03o`09Q/kocXK>Q_n600?o00N6c_o>Q/j600Co00S>Q_n6cXK>QPCo00O>Q_n6cXK>00?o
00W>Q/j6c_o>Q/h00ol01/j6cXK>oa/000?o0000BP0005`00om/00;o00D]1Bd5;@08o`095_lFLQIb
5_lF00?o00TFoaIb5W8FoaH00_l0278FoaIb5W8F0ol021Ib5_lFLQIb0_l02AIb5W8FL_mb5P03o`08
5W8FLQIbog82o`095_lFLQIb5_lF00?o00TFoaIb5W8FoaH00ol01aKo5W8FLQH01?l0278FoaIb5W8F
0_lK0003o`0004T0001J00;oK`02o`08KRe^;Ol]oa42o`0:Q/j6cXKoQ/j6cP;o00V6cXK>Q_n6cXH0
0ol01hK>Q/j6ohH00ol02HKoQ/j6cXKoQP02o`08cXKoQ/j6cXH3o`09Q/j6ohK>Q/j600;o00W>Q/j6
ohK>Q/h00_l02HK>Q/j6ohK>QP03o`07Q/kocXKoQP03o`09Q_n6cXK>Q_n600?o00>6o`006`000ol0
00180000E`03og400_l012d5;@D4o`09LQKo5W8FL_mb00?o00Mbog8FLQIb00Co00PFL_mb5W8FLP;o
00TFLQIb5_lFLQH00ol01aIb5W8FoaH00ol02AKo5W8FLQKo5P03o`095_lFLQIb5_lF00;o00Mb5_lF
LQIb00Co00PFLQKo5_lFLP;o00XFLQIb5_lFLQIb0_l01QIb5W8Foa/000?o0000B00005D00_md00;o
00=^;Ol00_l02Lj6cXK>Q_n6cP03o`07cXK>Q/kocP03o`09cXKoQ/j6c_o>00?o00O>olj6cXK>00Co
00R6c_o>Q/j6cP;o00Z6cXK>Q_n6cXK>0_l02HK>Q/j6ohK>QP03o`07Q/j6cXKoQP02o`08c_o>Q/j6
cXH4o`09cXKoQ/j6c_o>00?o00O>olj6cXK>00;o6@000ol0o`190000DP03ogD000?o_Ol00_l02G8F
L_mb5W8FLP03o`08LQIbog8FLQH2o`09LQIb5W8FoaIb00?o00Mb5W8FL_mb00?o00Ubog8FLQIbog80
0ol02G;oLQIb5W;oLP03o`07L_mb5W8FLP04o`085W;oLQIb5W82o`0:5W8FL_mb5W8FLP;o00PFLQIb
5_lFLP?o00Mb5W8FL_mb00?o00=bo`006`000ol000160000D002ogL00ol02LkocXK>Q/kocP03o`09
c_o>Q/j6c_o>00;o00R6c_o>Q/j6cP?o00S>Q/kocXK>QP;o00[>Q/j6c_o>Q/j60_l02Lj6cXK>olj6
cP03o`07cXK>Q/kocP03o`09c_o>Q/j6c_o>00?o00W>olj6cXK>olh00ol01lkocXK>Q/h00ol02<j6
c_o>Q/j60_l01/j6cXK>oa/000?o0000AP0004d00ol00`3o001d00;o00Yb5W8FL_mb5W8F0_l02G8F
LQIbog8FLP03o`07LQIb5W;oLP05o`07LQIb5W;oLP02o`0:l?ooLQIb5W;oLP;o00LFL_mb5W8F00Co
00Qb5_lFLQIb5P;o00Ub5W8FL_mb5W800ol02G8FLQIbog8FLP03o`04LQIb5P;o00ebooooL_mb5W8F
L_mb00;o00LFL_mb5W8F00;o6`000ol000150000B`02o`D000?o0000L002o`09Q/kocXK>Q_n600Co
00Joolj6cXH4o`08L/koQ/j6cXH4o`08cOooolj6cXH3o`03lO3o00;o00?>Q/h00ol01lj6cXK>olh0
0_l02F6Eolj6cXKoQP03o`07Q_n6cXK>QP04o`08cXKoQ/j6cXH4o`07cXKoQ/j6cP03o`09cXK>Q/ko
cXK>00?o00O>Q/j6c_o>00;o00>6o`006`000ol000140000B003ogP00_l0278FLQIbog8F1?l01c:o
oklbog800_l01Koo9W8V00?o00DFoooo3`03o`05<OoooaH01?l00o3oo`02l003oo7o00;o00Q6AOlF
LQIb5P;o00S5ELEEaOmb5P?o00LFLQIb5_lF00?o00TFoaIb5W8FoaH00ol02AKo5W8FLQKo5P03o`07
5_lFLQIb5P04o`08LQKo5W8FLQH2o`05LQIb5_l06`000ol000140000A@03ogP00ol01f7oQ/j6cXH0
1?l02;oo_`>ookl30_l01;oo_`<3o`05c/g>og801_l01<goolh5o`0?lOool?7ol?mQYF6UHOn600?o
00QQof6EHIEQU@;o00QQUF7oQ/j6cP;o00Z6cXK>Q_n6cXK>0_l02HK>Q/j6ohK>QP03o`07Q/kocXKo
QP03o`09Q_n6cXK>Q_n600?o00R6ohK>Q/j6oa/000?o00002@0012IXo`Df0000@`02ogP00ol01dD[
AB]5oaH00ol06;lb_onooklb_onooklb_onookoo<G8aLPGo00LbooooL_o=00Go00?`ool00_007Ooa
odI5ATE6AOlZ5RXFolEEaEG5EOm5_TFnAOlF00;o00ZZIOlFLQIb5_lF0_l01g8FoaIb5W801?l021Ib
og8FL_mb0_l02AIb5W8FoaIb5P03o`095W8FLQKo5W8F00?o6P000ol000080006I_?ViZRn=@000400
0olo0003o`0003D00ol02F6EoiEQUF6EH@02o`0HI_oo0koo_ono0koo_ono0koo_ono0oo>0_l33`;o
00L3ooooc_o>00?o00Oaoo7`oo3a00;o01;aojEQYF6UoiEQUF6EoiEQUF42o`0@UF6EHIEQof6EHIEQ
ohK>QP?o00N6cXK>Q_n600;o00W>Q_n6cXK>olh00ol01lkocXK>Q/h01?l028K>olj6cXK>1?l00hK>
o`0K0003o`0000L000HY_P00__<e0000?P02od800_lc00?o015Eob[e:_Go:dD[AB_oU_l2<P02o`0A
<[oo_c;o<[oo_c;o<[oo_c800ol00lkoo`02o`03_c;o00;o00=bool00ol01O3ooo3o00;`0_l01_3o
ADI5AP;o01TZ5RXF:_mEaEG5okoo_TFnAKkoZVFZIJYU00?o00QUYOmb5W8FLP;o00PFLQIb5_lFLP?o
00Mbog8FL_mb00?o00Ubog8FLQIbog800ol027;oLQIb5W;o6`000ol000060003o`00008000?o0000
<`0003/00om40003oa3o03000_l0:F65HHGoUF6EHOmQUF6EofJooiJoU_l3_ono0ol3_ono0ol3_ono
0ol300Go00<3_`<00ol00lkoo`03o`08lOool?o`lO03o`0GYF6UofJoof6EHIGoUF6EohH2of6EHID0
0_l03V6EHIEQUOnEHIEQUOo>0ol01iGocXK>Q/h00ol02<j6ohKoQ/j60_l02/j6cXK>olj6cXH2o`09
cXK>Q/kocXK>00?o6P000ol000060003o`00008000?o0000<`0003T00_l30003o`0004000_l0138@
ool/00;o02gEolEEaEG5ooDZmB[oAB_oUP7o<P8b0_lboc:o<_lb_ono<_lb_ono<_nooc800ol00c:o
<P03o`07L_oooo3ol002o`03l?o`00;`027oOOm5A_nFYYKo5RXF:_mEaOnoI[oo_TFno`4bofFZIJX0
0_l03VFUIJEUYOnZIJYUZ_mb0ol01Z[oLQIb5PGo00TFoaIb5W8FoaH00ol01aKo5W8FLQH01?l00g8F
o`0K0003o`0000D000?o00000P000ol0000c0000=P03odP000Oo;On_ojoo02P00ol06V6EHOmQQF65
HOmQUF6EoiEQokmVoknF_ono0_l04`>o0ol3o`>o0ol3o`>o0ol3o`<00_l01;l3_`<7o`03lOoa00;o
00O`oooal?n`00?o03AV_fJoof6EHIGoUF7o0XH2of6EHOnoA_nEHIEQokooHIEQUF7oHIEQUF6EoiEQ
UF6Eolj60ol02HK>Q/j6ohK>QP03o`07Q/j6cXKoQP03o`08Q_n6cXK>Q_lK0003o`0000@000HY_P00
_RTe0000=002od/000Som?l@oa0bob<01?l07UFZomE5eDGoELEEaOoe:_DZodGo0IKo0S82<_lb0P;o
01:o<_lboc:o<_lboc:o<_nooc82o`05_c:o<[l01_l01O3ooo3o00;`0_l04?3oOK3oUZJFYYKo5RXF
:QH2o`0GI[mV_onnAOlb0C;oIJYUobH2ojEUYFD00_l03JYUZVFZIOmUZVFZIJX00_l021IboolFLQIb
1?l021Ibog8FLQIb0_l02AIb5W8FoaIb5P03oaT00_l60006I_?Vi_=V=@0003400om=0008obgo[on_
4?lQ00;o01F5ohEQQF7oHIEQUOn5HHEQof6EHID00_l03KmV_onF_iKoY[nVo`800_l04;l3o`>ookl3
o`>ookl3o`<2o`05_`>o0kl01_l02O7ooo3ol?7oO002o`0>/7b`ofJoI[mVoiEQUF42o`0NQP:60XKo
UOm6_dKoUF7o_fJoof6EHOnoI_nEHIEQ0_l03YEQUF6EHOn6cXKoQ_n60_l02Lj6ohK>Q/kocP03o`07
c_o>Q/j6cP04o`03Q/ko01P000Co003o1P0012IXJ6Hf0000;P03oe0000Oom?l@oa0b00;o7@03o`0E
EJYEoeFZEJYEodGEAOmEaEG5ooDZ00;o02P?oiH1oc82<P;o0S;o_`Jooklboc:ooklboc:oojoo0on_
oklb_c:o1?l00o3ol002o`0?l?o`l?n`oo3o/7f`oiJV00Wo00EV_fJoIP02o`0S0C81<_mUZ_l29P;o
YFFUo`:oofFZIOl[0_nZIJYUo`;o5W801?l021Ib5W8FoaIb0ol01g8FLQIbog800ol027;oLQIb5W;o
1`03oa4000?o0000?@0002`00_mB000;ofh]ojoo[a3o4?l06004o`0FHHGoQF65HOmQQF65oiEQUOn5
HHEQQ@;o02;>E/iFofKo_iJooknV_ono0[oo_`?o0koo_`?o0koo_ono0_l01P>o0kl3_`Co00c`oo7`
oo3ol?7oO;02o`03O;3o00?o00bmc_o>_Ljmc[go0XH3o`06A[m6_dJo0_l06VJoI[ooHIGoI[mVoiEQ
UOmV_omQUF6Eo`6o0ol0266Eolj6cXK>0ol02<j6ohK>Q/j60_l02Lj6cXK>olj6cP03o`030?oo00?o
00=^<_l04@000ol0000m0000:@03oe@000[o;OCo43;o<_lb0_lE00;o01VUojEUYFGoEJYEZ_nZEJYE
odGEAOmEaEG500;o00Da3c4?<@02o`0=0S82<_lb0S;o_`Ko0P02o`0=_c:ookoo_c:oojoo0`02o`06
<[lb_c:o1?l01_3ooo3ol0;o0_000oml/003o`03L/ko00C>00?oc/h00lh3o`09L/ibo`4b0C8100;o
01PV0RH29_mUokl2_omUZ_l2:`;oZVFZohH3o`07eOoEEMGoLP03o`08:omb5W8FoaH3o`075_lFLQIb
5P04o`0<LQKoobe^ofi0KT3o4P000ol0000l00009`02o`8000?o0000DP003Om^;On_4?l@oa3o[ol0
4P02o`0GHHEQof65HHEQof65HOmQQF65oiEQUF401?l09EK>oliFc_o>E_noU_nV_jKo0[l2ojJookl3
_onookl3_onookl00ol01;l3_`<3o`03l?o`00;o00C`oo3a0_l04O3o/7b`olj6cXKo_Ljmc_o>00?o
00[>olj6cXK>odJo0ol01[mV_fJoIP;o00joI[mVoiEQokmV_omQU@?o0181oomQUOnEHIGoYF6UHJGo
cXH3o`07Q/j6cXKoQP03o`0?Q_n6cXK>Q_m^;Om^<Vhb00;o4P000ol0000k00009003oeT000Wo;O@]
oc;o<Q000_l0110bool=00?o01RZojEUYFGoIJEUYOnZEJ[oZUFZEOm5eDD2o`0JY/jVcZK>oc7oEPmF
3ol2o`8b0_l6_olb0S82o`0<<_lb_ono<_no[ol30_l00e;o<P02o`06EOool?o`0_l01_3ol?3o/0;o
00Ul/7b`og;>L_l00lh3o`09A/i6cTKoL/ib00Co00PFLQKo9P8V0P;o00Jo0[l2_`82o`04:`8[0PCo
0182QP;omOmEeOoEEOm5:dD[AB/2o`085W8FoaIb5W82o`095W8FLQKo5W8F00?o00I^ofi0KT02oa80
00?o0000>`0002<00_mJ000Aobe^;Fko4?l@[on_ojoo[ol02@03o`0HQF65HOmQQF65ohEQQF7oHHEQ
of65HHEQ0ol028IboeK>E/iF0_l01LiFcUK>00;o00foY[oo_`:ooknVoiJo00;o00X3_ono0ol3o`>o
0_l01Q1Bof95HP;o00K`oooaoo02o`03lOml00;o00B`O;1l2?l02<jmo`o>3lh?1?l02/jmoiK>U/jF
okl2o`07cTKo_fJoIP02o`03_fKo00;o00eVoono0Koo_eKoUF6E00?o00jUHJEQYF7oQ/j6cXKoQP;o
00O>olj6cXK>00Co00V6c_l]ofhbKS800_lC0003o`0003X0000S0003o`3o05T001;om2gd;Olboc8@
oa3o<_lb4?l500?o01ZZEOmEZUFZEOmUYFGoIJEUYOnZEJYEoeFZE@;o1Lh00onVo`02o`04YPooEP?o
02<V3ol2<_no1_l2<P;o0S82oc:ooklbokoo<P?o[e:_oeERE@02o`05l?ool?l00_02o`03l?ml00Go
00?>olh00/h02?o=c/g>cOo>0ol00`KocP04cP04oaIb5P?o00O>L/ibc_no00;o00P6oooo0R/2:`;o
00Z60XKo0OGoEMEE0_l030;o:dD[AOl1oaIb5P?o00HFLQIbog83o`07L_mb5W8FLP02o`07KT1^@?n0
o`0C0003o`0003T0000S00;o00<0o`00E`003ol]KRe^oa3o4:oo[on_o`02[`04o`0000;o01VEohEQ
QOn5HHEQQOn5HHEQof65HOmQQF6500Co00O>E_mbQW:600;o00EFcUK>EP02o`0CcTK>A/i6okoo_`;o
Y[nVoiJoUP03o`0;0kl3o`?o0kooDQ000_l01V95HTGol0;o00Caoo3a0_l04o3o/7coJli[cV_o_Ljm
okg>_Lh00_l02YK>U/jFokg>_Lh4o`08U/kocTK>A/h5o`05cPoo_fH01?l02[l1oeJoE[ooHID2o`09
_omQYF7o0F/100Ko00C>Q/j60_l02Lj6cXK>olj6cP03o`07KS9^<_l^o`0C0003o`0003T0000S0005
o`000?l0E`004Ood;O@]oc;o<Q3o4?lb4?l@00Co01Y5aDGoEJYEZ_nZEJYEofFUIJGoYFFUIOmEZP;o
00PV3bH?9PoocP;o00O>9_nV3jKo00:V00Ko9PlV3bH2o`0I1[l6o`8boc82<_no9_lb_c;o_olb0on_
DP02o`04EF9EHP;o00C`oo3o0_003Om<ooml/?mbcW;>L_l01<h03Oo=ool[c_l6LPIbolh00ol02G;o
LPIb1W;oLP05o`051/h6cPH00ol04786LPKo0_oe0OD1omEEofH2o`0?:dGo0OD1mOl6L_n=c_mb00;o
00LFL_mb5W8F00Co00Yb5_m^@6i0oh3o50000ol0000h00008P000ol000030003o`0005@000go;Fh]
K_l@oa2_ojoo00:_1?l06HGoUF6EHOmQQF7oHHEQQOn5HHEQof65HHD00ol02<jVoliFcUK>0_l03/ib
cW;>oeKoI/iVc_o>0ol03lko0[oo_jJooknF_ono0P02o`06_ono0ol30_l025;o_omRAF950_l00o7o
l@02o`03lOlY00;o00N`O;3ocV_>00So00P?cPo>3onFcP?o00W>U/jFc_o>U/h01Ol01LjFc_o>00?o
00O>olj6cXK>00;o00ZoE[mF_omQokl10_l05V6Uof/1Joo>3lh?okg>olj6cXK>olh2o`0>Q_n6cXK>
Q_lbKS;o;_lD0003o`0003P0000R0003o`0000@000?o0000DP003Ol]m2gd;Olboc8@oa001?l06jYU
ZVGoALE5aOnZEJ[oZUFZEOmUYFFUojEUY@02o`075W8FLQKo9P03o`07A_o>9/hVcP02o`FV0_l054H?
APm6okoo<P;o0S82obJooklF0_l01:oo0c83o`070S;oEF9EHP02o`04l?o`l0;o00?`od@00_l00k3o
o`03o`0<_/kocLk=c/gocR_>1?l3cP05og86LPH01ol01@Ib1W8600;o00Mb1W86L_mb00?o00P?o`7e
0OD1m@;o00<2IP800ol00oD1m@02o`0=LPIb1_o>SOlFLQIb5P02o`08LQIb5_lFLQH3o`06KT3oP2go
50000ol0000g00008P000ol000050003o`00054000OoKRe^;Fh]00;o00<@[ol00_l06iEQof65HHEQ
of6EHOmQQF65ohEQQF7oHHEQQ@03o`07cXKoY/jVcP02o`07cUK>E/koLP03o`05L_o>I/h00_l01eK>
oliFcUH00ol03KnVoiJoU_l2_ono0[l00ol00kl3o`02o`07Y[ooHTERA@02o`04lOoal0;o00C`oc`Y
0_l03Lj6c_o>cLk=okg>_Lh01?l02XK>oljmc[g>olh2o`09U_oooeK>E_nF00?o00L?oiK>U/jF00;o
00X?<0l`3omF_eJo0_l0106o0Kl2o`03J`5[00co00Z6ooooL_n6cXK>1?l02HK>ofhbobkdo`0E0003
o`0003H0000R0003o`0000H000?o0000C`02o`08;O@]m2gdoa02o`0L:ooe:_DZofFZIJ[oaDG5ojYE
ZUGoEJYEZ_nUI@?o00M[LV]bJolF00;o00Mb5_m63dH?00?o00iFcUK>ojKoLZ]bZg;oAP;o018`QS3o
0_l2<_no9[oo_aJooc85o`0;<P8b0_mREF9Eoo000_l00o3oC002o`0>A4coL/ibcW;o_/jnolh3o`08
:ombcW;>L_l3cPKo00G>L_mbcP04o`061/h6c_l60ol02@KoAPm63dKom@03o`045W;o0P;o00@?c_oe
0_l0178?L_l3c@04oc7=<@Go00=boaH00_l03G;oLQIb5W;o@?n0;Ol05002ocP0000R00;o20000ol0
001=0008obgoKRe^;Fh3o`0JHIEQof6EHIGoQF65HOmQUF7oHHEQQOn5HHD4o`08U/kocXK>Q/h2o`07
U/jFcYKocP02o`06A/i6olib0ol01/iFcUK>EP;o00D?IPmV3`02o`0@_iJookl2o`:o0_nF_ol2_`;o
00^oY[nVodERAF;ol@02o`03l?m400;o00Ll:CcocXK>00So00P?cPo>olj6cPSo00FFcYK>UP03o`07
U/jFc_o>3`03o`09U/jFcYKo<0l`00?o00FFcYK>UP02o`043b/?:`;o00<lool02?l04/koo`o>olib
c_n6cXK>olj6cPCo00@^m2ko5@000ol0000e00008P000ol000080003o`0004X00_l011goobd7o`0G
:dD[AOlZmB[oIJYUZ_o5ALE5oeFZEJX00ol2cP07obIb9W;oLP03o`06e/ko5W8F0ol01BH?9PlV00?o
0lh01?mbZg82o`05Y_l`QS000_l07VKo<P;o9[lVoaJo5_l2o`:o0_l2<P8b0_mREF9Eo`;`0_l00o3o
A002o`03C?oo00?o00_ec_n=cXg>SOl?:`05o`031/ko00;o00DFLQKocP03o`07c_l6LPIb1P03o`08
cW;oLPIb1W84o`05cW;>oaH00ol018H?olh2o`095_ooI_mb<G;o00?=0ol00`mbo`05o`04LQIb5PCo
00Qb5_ooP2f0oaH000?o0000=000028000?o00002@000ol000180004oago7@Co00?>E/h00ol05F6E
HIGoUF6EHOmQQF7oHIEQUOn5H@04o`07LYIbU_nFcP04o`04LTIbAPCo02`?cPoocTK>oliFog:FLYKo
c_o>I/iVofKoI/iVc_nFo`:ookl2_onoU_no0P?o00VoY[nVodERAF800_l00o3ol002o`0A?4Coolib
c_o>cLk=okg>_Lh00ol00ljFcP04o`05cOnVcZH00ol01g;>L/iboiH00ol020ooU/jFc_o>0ol01`oo
cRK>9/h00_l01F/?J`m[00;o00o>Y_mbog8?olg>cOo=<Ld01?l01EGoEF9E00;o00?>ool00_l02XK>
Q/j6obkd;_lF0003o`0003@0000Q0003o`0000/000?o0000>@02o`/000Co7Ol]0ol01J/?Z`n[00Co
00m5:dGo:_DZmOnZIJYUodD01Ol01@Ib1W;o00;>1?l01W86LPKocP;o011bQ_o>eLkEc_lVodH?APoo
0/h3o`053jH?YPl00ol016H?IPl3o`0<9[oo_aJooc82o`:o1?l0208b0_mREF9E0_l00o3oO002o`0>
A4co5W8FLQKomLkeolh3o`049_mbcPCo00<6c_l01?l020IbodK>A/i60_l02<hFcQK>olib1?l01R/?
:`ooLP?o00Abc_n60ol014Ko5W8>o`0CP7j0O_mnP7ko:_lZH_mnoaIb5P03o`04;H0]oaH000?o0000
<`00024000?o000030000ol0000f00;o00=^ool01002o`<000?o7K800_l02/kooomFcUKoA/h2o`0<
UF6EoiEQUF7oHHEQ0ol02G;>L_nFcYK>UP03o`08Q/j6oiK>U/h2o`09Q/j6cXKo3lh?00?o00G>E/iF
cP03o`0=L/iboliVc_l?J`oocP02o`0?E/iFokoo_`;oU[oo0[l200Go00RoY_m5HTGo<P?o00[`??ll
A3cocW;>2?l00`o>3`03o`03U/ko00?o00ZFcYKoU/jFc_o>0ol01lkocPo>3lh00ol01ljFcYKo<0l0
0ol01LjVcZK>00;o02D`3c0?<?nVodERof95HTGoIF9UH_mREF9EoeEREOmnP7j0of9U00?o00N6cXKo
;_Co01L000?o0000<P00024000?o00003@000ol0000d0008ogd]OOm^o`02o`034?oo00801?l05W8F
oli6oj_oUV^FJom5:dGo:_DZmBX3o`09Y/oo9W8VL_l600?o00TVo`o=3ld?o`H00_l01g8VohIbQW80
1?l01@Ib1_m600?o00i6olh[cR_>o`ooUS6F<@;o00DF3aH?5P02o`095[lFo`8bokl200Co00XVoc82
of9EH_no0ol01Gc`oom<00Go00PacOo=c/g>c@So0/h02Oo>L/ibc_l6LP04o`06cW;>L_lF0ol01g;o
LPIb1W800ol03RK>9_mbcW;o3c3oAPm60ol0981nP7koOGimoh1nP7koP7j0O_mnP7ko:V8ZH_mnP?mb
5W8FLP;o00<]o`005P000ol0000b00008@02o`l00_ld0008ofh]oo;o4?l240Go00B6cXK>0ol02DIF
oom6cTK>AP02o`06HIEQof6E0ol024IbAW96olib0ol02JK>Y/jVohK>QP03o`07U/jFcYKoQP02o`07
AW;oU/jFcP02o`09cVK>I/koL/ib00?o00<?J`l00_l01FKoE/iF00;o00/?o`:ooknF_ol2_`02o`0>
E/iFoknVodERAOlboo02o`0???3oolibolg>cLk=okg>00Go00c>Q_nmc[g>_OnFcYH4o`07cUK>E_nF
cP03o`07cYK>U/kocP03o`0=3oo>L/ibc_o>o`m[3`04o`073oooHTERA@02o`0KHTGoIF9UH_mREF9E
oeEREOmnP7j0O_mUH_o>00?o00C>ooCo60000ol0000a00008@000ol0000@0003o`00034000WoOBgo
/_l@KQ000ol01aKo5W8FLQH00_l02dK>oc4?oiI[U_la00Oo00S=1_nVcjK?YP?o00Qb5W;o9W8VLPCo
0/h01_mb9W8VLP;o00O>a/k6c_l600;o00Mb5_m63dH?00Co01mbcW;oU_m6<4H`o`oo<5H`E_nooc82
o`:oo`;o9PlV00;o00T2of9EH_noog`00_l03?1ll?o>9/kocC7=<@Go00M6old?c@oo00C>1?l02<ib
og;>L/ib0ol020K>olibcW;>0_l02Lh?cPo>obK>9P04o`0><?oo3oo>A_mnoh1nP7h2o`0SOWenogj0
O_n0OX1nogj0O_lZHRYR:_n0OX3oLQIb5W;oP?l060000ol0000`00008@000ol0000A0003o`0002l0
00Ko;Fh]oo84o`07Q/j6cXKoQP03o`0I3omFof^6JhKoA_n63hKocW;>L_o>L/koLP03o`09LUKocW;>
L_nV00;o00W>Y_nFLYIbolh00ol01lkoAW96LTH00_l01jK>Y/jVolh00_l01dK>of]bJg800_l01@mV
3fH?00?o00@?UPnF0ol01knFokl2o`800_l02LiFoonVodERo`02<P03oo0l00oo00_>3lh?c_o>Q/ko
cP03o`09c_o>U/jFc_o>00?o00S>olh?cPooUP?o00JVc_l?9Pl5o`03cZK>00;o02lV3bH?olkoHVGo
AF95odGoAF;oHVERof9EHUERof9EH_n0OX1nofERIOn6cXK>QP03oaP000?o0000<000020000?o0000
4`000ol0000^0004obem;@?o00PFLQKo5W8FLP;o1<h2o`05<@la3c400_l0236V<JHaooEb1ol02JK?
Y/nVcolFLP03o`065W8FLQKo0/h3o`07LRIb9W;oaP03o`07L_mb5W8FLP02o`075PlF3aKoLP02o`0<
cTKoAS16og:[L_mF0_l02S1V<?l2o`;o_`83o`0D9_oo0_mREOlb_c;o/7coc/g>ojX3o`0:XQJR5_mb
AW96LPOo00S>L/ibog;>LP?o00QbcW;>L_l6cPCo00AbcW;>1?l01W;>oaIb5P;o00D?Joo>3`03o`0S
P7j0ogj0O_mmO_mnogj0OX3oOX1nP?n0OX3oHRYR:_n0OX000_l01AKoooo`00;o6@000ol0000_0000
80000ol0000D0003o`0002d000go;OooQ/kocXK>Q_n600Co00Q[oooocPooJ`?o00@?Jon60ol046Ko
og;>L_o>L/koLUIbEW83o`08L/ibojK>Y/h3o`08LYIboljVcZH2o`07cXK>Q/kocP03o`07c_m6cTK>
AP02o`0<3lh?cPoo3oo>E/iF0_l01@n63hH?00;o00/2_ono0_mFoeKo/002o`03AF;o00<b00Ko??0l
old3o`0:c/g>oldacC7o3`?o00ZFolg>cLk=ojK>1Ol02<iboiK>U/jF0ol01Po>3lkocP;o00k>obK>
9/hVojKoJ`m[3`?o00k>of9UHVGoAF95odERA@;o01iRIF9UoeEREF;oHUERoh1nP7koIF9UofGoIF9U
oo02oaT000?o0000;P00020000?o00005@000ol0000[00?o00Qb5W8FL_mb5PWo00Ab1W860_l01EH`
ES1F00?o00mFcUK>obIb9W;oc/g>ojH00ol02F_?ob]b:g;o5P02o`03LQKo00C>00_oL_ooc/GoLXIb
QP03o`06c^G>iOl?0ol01Pm6odK>AP?o00YbZg:[o`oo<6H`0_l031H?o`;o_ol?I_lV3`?o00IREOlb
_c89o`07cZ[>Z_nR5P04o`C>00Goc^G>i@03o`0:L/ibob_>:lkocP?o00Mbog8aLS5b00;o00RF3iH?
olibcPCo01D?oooo3oo>:omnP7j0ogj0OX3oOWd00_l087j0OX3oOX1nP?n0OX3oHRYR:_n0OX1noeER
EF;o/?3o6@02obl0000P00?o5P000ol0000W00?o00S>Q/kocXK>QP?o00>6cXH00_l01/j6cXKo3`;o
00c>Q_l?J`oocTK>o`l2o`04A_o>LPOo00EbAW96LP07o`08Y/jVcZKoUW84o`063lh?c_o>0_l01YK>
U_l?cP?o00EVcVK>IP04o`0A3lkoE/iFoiJVU_n6oeK>E/h01Ol01LiFooo>00;o00>oool00c84o`05
cLkoSLd02?l02YIbUW;oLYIbolh3o`0:L_o>U/jFc_o>LP?o00L?cPo>3ol?00?o00FFc_l?cP05o`03
3lh?00;o00L?9PlV3oo>00;o02MUHVGoAF95H_mRAF;oHVERIOmEHUERof9EH_n0OX1nP?mRIF;oHVD0
1?l00o3o000G0003o`3o02l0000P0003o`0001L000?o00009002o`09LQKo5W8FL_mb00;o00DFL_mb
5P03o`04EW9FLP;o00PVLRIb9_mFo`B60_l01<j[cZ/2o`0GQ/j6olg>cOm[cf_o1Poo1W86L_lFLQH0
1?l4cP03olk500Co00B6LXIb0ol05W;>L_l?APoocVKoA/i6c_n[o`mV3fH3o`075PlFojH1YP03o`06
I_oo3on`0ol05klboolb_oo=L/gocKgocDG=ALgocPo>00So1<h01?mbcW84o`075/hFog8VLP03o`05
cW;>L/h00ol03/hVc_m6cTKoJ`oo3c0?0ol03V7oP7j0ogj0OX3oOWen0_l0581nP?mnP7j0oh1nP?mR
:V8ZH_mn1Ol018i5ogd3oaX000?o0000;000020000?o000060000ol0000P00?o00R6cXK>Q_n6cPCo
00^6cXK>olko3lkoQP02o`073hKoQ/j6cP03o`0NA/i6omH?oli6c_mbcW;>L_o>L/koL_o>E/iFolib
1Ol01jK>Y_nFLYH01?l01/jVcZKoUP;o015VL_nFcYK>ofKoIPmV3ol?cP04o`0<YYJVo`n63oo>o`o6
0ol00g;oEP02o`03c_m400Go00@bo`>o1ol01/gocC7=<@Co00_>L_o=c/g>cOn6LP05o`07cW;o3lh?
cP04o`05Y/jVoiH00ol03AKoL/ibcW;o3omV3fH01Ol08eARE?mUHVGoAF95H_mRAF;oH_mRIOmEHUER
of9EHUGoOX1n00?o00enQOn5OXEnogj0OX3o01T000?o0000;00000X01_l400049VSo1@L000?o0000
6P000ol0000L00?o00PFLQKo5W8FLP?o00Mb5W8FoaIb00[o0`l05_lVoolV3bKoQ_nFZiJ[olko3on6
cXH8o`043`H?1P?o00Qb9W;o5W8FLPCo0/h01_mb5W8FLP;o00S>a/k6c_o>LPCo00AVcVK>0ol02b]b
:g;oI_oF<MHa00?o00P1oiJVog;oIP;o00<?ool00ol01[lb_olb_`;o0ld00onRo`02o`0?cOooU/ko
9W8VL_o>iLkU00?o0/h02?o>:lh[c_lF0_l01aIbolibcW800_l02Lh?cPo>olhVcP04o`0W3oooZ`oo
L_mQO67oP7j0ogj0OX3oOWenogkoOX3oOX1nP7koOX1n00Co012>oh1nP?n>AHi5S_l5O@Go6P000ol0
000[00002P000iGoIP020006J00006Kc0^H00jRn00050003o`0001/000?o00006003o`09Q_n6cXK>
Q_n600;o00O>Q_n6cXK>00Co00DZHR[o_`0;o`8?1Ol00mH?o`04o`0>3oooolibog;>L/iboeH2o`09
LUKocW;>L_nV00;o00W>3onFLYIbolh00ol01lkoIW9VLVH00ol01/h?cPoo3`;o00IV3fKocW83o`03
3hH?00;o00=VcVH01?l01B]booo>00?o00=4/?l013806Ol3_onoole5cOo=OLgocPo>3lkocW;>olh0
0ol02/koLXIbQ_mbcW83o`073lh?cPooYP02o`06cPoo5PlF1Ol00`o>3`02o`043lh?cP;o01iRE69D
ofERIOm5HTERof95HTGoIOmUH_mREF9EoeD3o`0DOYEnUOn5OXEnogj5OXGoP7j0O_lI0003o`0002/0
000;0003UOmV00D000HY_P00__<60003o`0001`000?o00005003o`095W8FLQKo5W8F00?o00LFLQIb
5_lF00;o011boom5HTERoc;oHTERAOlb1ol00ld>o`03o`04LPmb3`Co00QbmG;eold6c@?o00SFc]K>
e_lVLP?o00K>eLkEc_l2cP?o00Mb5W8FL_o600?o00Mbolh[cR_>00;o00EVcVK>IP03o`0=cPo>omKo
EPmF3eKoZ`03o`03L_oo00Co00b`OOlb_c;o_c;o<[l6o`07X/fRoljFcP07o`06cRK>9/ko0/h5o`07
cW;>og8FLP03o`04:lh[cPCo00K>1_o>A/h2o`8?00?o3ol00_l06c;oHGaQoh1nP7koP7j0ogimOWgo
P7koO_n0OP04o`0HSR[oAHi5S_n0OX1nodF>AHko1Gd5O@Go6@000ol0000Z000000<0ool01Ol40003
_VQV00@000?o00000P000ol000040003o`0001d000?o00004003o`08Q/j6ohK>Q/h4o`07Q/j6ohK>
QP03o`03Q/j600;o01=R:V;o<[ooAF95H_lbof95H_lb00?o00EREOoo3`03o`03H_lb00;o00?>L_l0
1?l027;>og9FLUIb0ol027;>L_l?cPo>0ol027:FL_o>Y/jV0_l01lj6cXK>olh00ol01<h?o`l3o`05
cTKo3lh00ol01liVcVK>oj/01ol01lkooom4/?l00c801_no0ol3_`;o00=mcGd02?l02libolg>cLko
cPo>00Co00QbcW;oU/jFcPCo00D?cPoo3`02o`0>3bKoL/ibc_o>o`nV3jH2o`03cPoo00;o01ADHUAR
of9UH_mRAF95odERAOmUHPGo01aZHOmnQGkoOYEnUGkoOXEnogj5OXEnogj0OX3o6P000ol0000Y0000
3@000fIXIP030003o`00008000?o00001002oal000?o00003@02o`095W;oLQIb5_lF00;o00Mb5_lF
LQIb00Co00HFL_mb5_l2<P04of95o`8b00GoHTERo`02<P0FodERAOlboeEREF;o<_mREF9Eoc;oJP;o
00X[LR]bolk=c_o>0ol02F_oU/jFcYKocP02o`03mG;o00C>00_oL_ooc_GoLUIbEP03o`04cPK>1P;o
00D63`H?1P03o`09Q/j6oeH?E_n[00?o00?>og800_l04`oooon`OOlb_c;o_c;o<[oo_ol01<d03?o>
L/koAW96L_o=ZPGo0/h02?o>1/h6c_o>0_l01eKocR_>:lh00_l02<h?cPo>olh61?l020ooooo>3oo>
0ol03f5lHGcoOX1noh1nP7koO@05o`0RIOooOVEnIOlZSRZ>ohi5STGoOX1nP?n>AHi5ogd5OOn6oaT0
00?o0000:@0000h000>nl`000P000ol000020003o`0000@000?o00007`02o`X00ol02<j6cXK>olj6
1?l01/j6cXKoQP;o03C>Q_n6cXK>olko<[oo:V;o<[lbof95oklbof95oklbof9EH_lb_omEHUERoc;o
HVERolib1ol02HK>Q/j6og;>LP03o`083lh?cPooUW84o`063lh?c_o>0_l01G9FL_l?00;o013>3oo>
A/ko3iKocPo>3oo>0ol2Z`07oeKoLR_ocP03o`03A;3o00<b00So_`?o0ol3_`;o00=mcOl03?l03<ib
c_mbUW:Fog;>LP?o00K>3lh?olh3o`06cPoo9PlV1?l00lh?cP02o`05:`l[3b/00_l01GgooeAR00go
02REO_mQQF65ofYQJV7oOXEnQOnEOYEnogj5OXGoQGj5O_mnP?m6_dKo6@000ol0000X00003`001_l0
000Y_P8000>n:@001@000ol0000Q0003o`0000@00ol0278FL_mb5W8F0ol01aIb5W;oLQH00ol021Ib
5W8FoaIb0ol3<P04of95o`<b00CoAF;o0S801?m5H_l2<P05oeEREOl00S801OmREF;o008b00CoJV9Z
0ol032]b:oo>L/koJg9[LPCo00Mb1W;oL_Eb00Co00O>L/ibolke00?o00GFc]K>eP02o`0?cPK>1/ko
1_m6ITIVolj600Ko00@?0Oo>0_l00lkoo`03o`0@/7f`oklboklboc;o<[oo_`;o0W804?o1c/7ocKk=
__l[LR]b:ol2cPGo00IbcW;oLUH4o`049/hVcPCo00EbAW;oEP02o`8?00?oc_l01?l00cemo`02o`0d
UHGoHHEQof5UHFGo:XhZofEZIFYUofEnIGkoSRZ>ohi5STGoOX1nP?n>AHi5ogd5oeJ6EP;o6@000ol0
000W00002P001_mEiP05l`<000IVlnKVlfH50003o`0002<000Co00000_l02Lj6ohK>Q/kocP02o`07
Q/kocXK>QP03o`08Q/j6ohK>Q/h3o`0hH_lb_c:oob[o_c:o<_mRAOno<_mRAOno<[ooEF;o<[lbof9E
oklbof9UH_lbog;>L/kocW;>ohH2o`06E/iFog;>1Ol01hK>Q_nFLYH01?l01Lh?c_mF00?o00M[olh?
cPo>00;o00D?UPnF3`04o`05c_l?aPl00ol015Koob/3o`0Hl?m4/4Co<_l3_ono0ol3_ono0oo>L/ko
0ld02Oo=c/g>olibcP04o`07L/ibof]bJ`04o`06cPo>3ol?0_l01`oocW;>L/h00_l019H?UPl3o`0g
3oooogfaof65HHGoOX1nogj0OX3oOYEnUOn5HHEQof5ZHF[oQGj5O_mnUGkoOXEnQOn5OXEnQ@02o`07
_dJookl[o`0H0003o`0002L0000:0006__?oofgV100012IXJ6H60003o`0002@00ol021Ib5W8FoaIb
1?l01QIb5W;oLP;o00TFL_mb5W8FoaH00_l01G8FodGo00@b00?oH_l013800om5o`03<P04odERo`<b
00CoHUGo0c801?mEH_l3<P09of;o<Zlbog8[00So00@?1Pl60ol027;>L_o>L/ib1?l2cP05olh[cR/0
0ol4cP03o`Ko00;o00C>:om61?l02<koA_l?Z`n[0ol01<koolh3o`0ClOn`OK3o_olb_ono<_lb_ono
<P0:o`03cKko00Co00O>L_o>5/hF00Co00Mb5W;o9/hV00?o10l00om6o`02o`04cYKo3`;o00?nool0
1?l06SemoiF5UHGoHHEQQOmUHFGo:XhZS_mZIFYU0_l05GiUO_n>:XhZodF>AOmnP7j0O_m5SP03o`08
EXIFokn6_olI0003o`0002H0000N0003o`0002400ol028K>Q_n6cXK>0ol01lj6cXKoQ/h00ol02<j6
cXK>olj60ol00hK>QP02o`0^H_lb_c:oob[o_c:o<_mRoc:o<_mRoc:o<[ooEF;o<[lbof9Eoklb_omU
oklb_`?o00[>L/ibog;>L_mF0_l02G9Vog9FLUKoQP02o`09cPooUW:FL_o>00;o00JVcZKo3f/4o`04
3lh?cP?o00BF3iH?1?l01@oooomb00;o00=bob/00ol07?3ook14oc;o0koo_`?o0koo_`?o0ombcG;o
X/d3o`0:LTIbog8VLRKoLP;o00MbU_l?cPo>00Co00JFLYKocPl3o`05cPo>3lh01Ol00`ooo`03o`0K
OK5mohEQQF7oP7j0oh1nP7koUGjEohEQQF6500;o011QJ_n5OXEnogjEOYGoQGj51?l032K>odJoA_l[
_onooaL00olW00007P02ob000_l02AIbog8FLQKo5P02o`07LQKo5W8FLP03o`08LQIbog8FLQH3o`06
5W8FoaIb0ol5<P03of;o00@b00?oAOl00c800om5o`04<P03of;o00@b00?oEOl013803?mRoc:_<_mR
og;>LPOo00R[cZ_>Zoo>LPCo00GUc^G>o`02cPCo00C>L/ib0ol01:_>Zlh4o`05J`m[olh00_l00c3V
<005o`06cOooa_o>0ol05O7oogf`okoo<[oo_ono<_lb_ono<P06o`06cKg=og;>2?l01g;>L/ibog80
0_l01g;ocPo>3lh00ol01@Ib1_o>00Go00=bQ_l01_l0:Cem?On5UHFEohEQQOmUHFEQohhZSR[oIFYU
J_mnogkoSRZ>:_m5STF>00Co017>og8aLS5bohKoQ[n6of/2o`0H0003o`0002D0000N0003o`0001`0
0ol02<j6cXK>olj61?l01/j6cXKoQP;o00W>Q_n6cXK>olh00_l02HK>olj6cXKoQP03o`05_c:o<[l0
0_l0:C:o<[lbof;o<[lbof;o<[lb_omEoklb_c;oH_lb_c:oofGo_c:oofER00?o00]bc_o>L/ibofIb
IP04o`07cW;>L_o>3`04o`06LYIbU_nV0_l01Lh?og9F00Co00G>3lh?cP02o`07AW96L_o6Z`03o`04
L_ooLP?o00?`oo000_l00k14/002o`0=0koo_ono0ol3_ono0`02o`03cEG=00Oo00abAW;oL/ibc_nF
LYH3o`06IW9VL_mb0ol01@o>og;>00Oo00D?oooo<P05o`0WOK5mohEQQF7oP7j0oh1nP7koUGjEO_mQ
QF65of[oJV7oOXEnQOnE00?o00[>1/h6c_o>9/hV0_l022^o:ol1_`7o6@000ol0000T00007P000ol0
000I00?o00Qb5W;oLQIb5P?o00LFLQIbog8F00?o00PFLQIb5_lFLPCo00LFLQIbog8F00?o00<[ool0
1C82o`Db0_l4<P03odGo00@b00?oH_l013800omEo`04<P0Bof;o<Zlbof;o<_o>5/hFog;=1Ol01g:V
L_mb5W801?l0178VL_l3cP?o00C>A/i61Ol0179[o`l3o`083ol`iS3o0@l2o`03o_o=00;o01k6oooo
l?oal?mm/7go_c:ookoo_c;o<[oo_ono<_l4c@0<oc7=<OmbcW;>olib1Ol01/Iba_mVLPCo00>V3jH0
1?l01G;ooomb00?o00@ZH_mE0_l09[7oocem?GgoUHFEohEQQF7oHFEQohhZSR[oIFYUJ_mnIOmUobZ>
1?l02/k=o`K>1/h6oc43o`0;aOnoQ[oo0V_o0Ol06@000ol0000S00007@000ol0000H00;o00W>Q_n6
cXK>olh00_l01hK>olj6cXH00ol028K>Q_n6cXK>0ol01lj6cXKoQ/h01?l013:o<[l2o`05_c:o<[l0
0_l01C:o<[lb00;o00Bo<[lb0_l04klb_c:ooeGo_c:o<_mRoc:o<[l00_l033:o<[ooIOno<_mbcPCo
00QbcW;ocZK>YPCo00Mbc_l?cPo>00Co00>6LXH01ol019K>U/h3o`0=3lh?c_mbolJ[omKo3`02o`03
c_mb00?o00K`ooo`ok04o`0?0ol3_ono0ol3_onookl3017o00O>L/kocPo>00Co00=bEW801?l00`mb
o`07o`06OX1nP?lb0_l08GcoogfaOK7oHHEQoh1nP7koOX1noiEnUGkoHHEQQF7oH@05o`0;9/koc[k>
__l6cPH00ol03lG>aLk5okoo_`6ookmFo`0H0003o`0002<0000M0003o`0001D00ol021Ib5W8FoaIb
1?l01QIb5W;oLP;o00TFL_mb5W8FoaH00_l01g8FoaIb5W800ol02G8Fob^_:jl[o`06<P;o1C82o`@b
0_l5<P;o1C82o`Db0_l01Jlb[c:_00;o00<b[c800_l02W8?LPoocLk=og82o`09IW9Volibc_mb00;o
00G>L_l?cP06o`05LTIbof/00_l01Pl`3on63`Wo00Cnool?1Ol01?3ooo02o`04UHFEQ@;o020b_ono
<_lb_onookoo[kn_olebcOo=L/gocW;>L_l?c@Go00E[LV_o<002o`035Pko00?o00c>3omnP7j0O_mR
:V84o`0M/Ooo?GdmOOnEQIGoQF65HOmQIF5UobZ>:XkoJVD01?l02oGoog8aLS5bolk=00Go01;ec_o>
aLk5c_n6of/2oc81<_lI0003o`0000P01_l400049VSo1@`0000M0003o`0001800ol028K>Q_n6cXK>
0ol01lj6cXKoQ/h00ol02<j6cXK>olj61?l01/j6cXKoQP;o01W>Q_n6c_no<[lb_olb_c:o<[oo_c:o
<[lb00;o00Bo<[lb0_l01Klb_c:o00;o00Db_c:o<P02o`05_c:o<[l00_l01C:o<[lb00;o00Bo<[lb
0_l00libo`07o`04Q/j6cPOo00AbQW:61?l01g:6olh?cPl00ol010mF3eH3o`063lkoojH?1_l00lko
o`03o`0Ml?ool?n5HHEQQF7o0koo_ono0ol3_onookl3o`<02Ol00libo`03o`07IW9VL_mbJ`07o`=b
00koL_ooHVYRJV;oP7j0OP;o00?bok000_l05;5m/OmQQF65ogj0O_mnP7j0ogjE1Ol01/jEonG>i@;o
00C>9/hV0ol03LG>olkUc^G>olk5c/D00_l02@6o0OmF_ol2o`0I0003o`0000L000>EofH00P001VP0
001Vl`;V00>X_P002P0001d000?o00004002o`095W;oLQIb5_lF00;o00Mb5_lFLQIb00?o00Qb5W;o
LQIb5P?o00LFLQIbog8F00?o00DFLQIb5P02o`07[b^_:jl[o`06<P03oc8b00@b00?o<S800c82o`Db
0_l5<P;o1C82o`05[c:_<Zl00_l013:_<Zl4o`04cG;=o`Ab00_oI_oo3oo>U/jFcP07o`06LV]bJomb
0_l01Libc_l?00;o00P?U_o>o`nV3`;o00IRool?o`l3o`0Ol?o`l?o`ohFEQIF5UOlboc:ooklboc:o
okoo[koo<P02o`06c/g>og:R0ol01g96L_mbcW801?l00g;oo`023`04og;>LP?o00anP?n0OX1nof8Z
HRX2o`03lOn`00;o00mm?GdmohFEQOmQQF65ofD01Ol03/k=olg>cLk=ooG>mOla0ol03J[oaLk5c_o>
mLkeolD00ol02fKo0V_o0C81okoo01T000?o000020000iGoIP050006:Kh00;kc2`0001d00_l>00?o
00S>Q/j6c_o>QPCo00K>Q/j6ohH2o`09cXKoQ/j6c_o>00;o00N6c_o>Q/j600?o00R6cXKoQ/j6cP;o
00Db_c:o<P02o`0J<[lb_c:ooklb_c:o<_lb_c:o<_lb_c:o<[l2o`05<[lb_c800_l01Klb_c:o00;o
014b_c:o<_lb_c:o<_no<_o>LP08o`07<0l`3oo>LP05o`07Y/jVc_mbQP03o`05QW:6LXH00_l010o>
3lh4o`0:3ol?oh1nog;ocP?o00k`oo3`oo3oQF65HHGo_`;o0143_ono0ol3o`>ookl3o`?oE@09o`03
AW;o01;o011RJV9ZofYRJV;oP7j0O_ml0_l01K3ook5m00go013>9_nUcZG>YOnEcYG>olkU0ol03JG>
YLjUolG>aLkoc^D00ol03@o>3lh?okoo_eKoIP800_lI0003o`0000P000>nJ6H010000ol000020003
o`0000T0000L00;o3003o`08LQIbog8FLQH3o`075W8FL_mb5P03o`085W8FLQKo5W84o`065W8FL_mb
0_l02AIbog8FLQKo5P02o`07L_n_:jl[[`02o`Db0_l6<P03oc8b00<b00?o<S8013800olb<P04<P03
oc8b00@b017o<Zlb[c:_ojlb[c:_oc:_<P02o`0;LS5b<Oo=L/go:`l01Ol020o=olibcW;>0ol01G;>
L_mb00?o00@?Q_nF0_l00bIb9P04o`05:V8Zo`l01Ol08o3ooo3ol?7oUHFEQOlb0_lb_ono<_lboc:o
ojnooc;oOjio00_o00G=L/goLP03o`0IOX1nP?mEHUERoh1nP?n0OX1nof8ZHR[o/@02o`03/;7o00;o
01W>L_o=mLgoUHjES_mb<G8aolg>cLkoc/g>00Co00cUc_o>Z/jZc_o>aLh4o`079/hVofK>IP03o`09
<P4bodKo_`;o01T000?o000020000fIXIP030003o`00008000?o00002@0001d000?o00002002o`09
cXKoQ/j6c_o>00;o00N6c_o>Q/j600?o00R6cXKoQ/j6cP?o00O>Q/j6ohK>00?o00S>Q/j6c_o>QP?o
0126cXKo<[lb_ol[_ono<[lb0_l01Klb_c:o00;o02`b_c:o<_lb_c:o<[oo_c:o<[lboc:o<[lb_ono
<[lb_c;o<[lb_c;o_c:o<P;o00=bc_l02?l02Lh?c_o>L/koYP03o`055PooLYH01?l010o>3lh3o`06
Y/jVo`4?0_l01Gj0O_mb00?o00?aoo000_l08_3ol?3oHHEQojJoY_l3_ono0ol3o`>ookl3o`?oEC9E
<UD>o`0KHVGoEF9EHUGoIF9UofYRJ_mZHVYRoh1nP?ob00?o01V`O?lFcQK>5_nR<J;ocDG=AOo>9/hV
ojG>00Go00c>Z_oUc^G>oljUcZD4o`06cPoo3lh?1Ol030K>oeJoo`9VofJoo`800olD0003o`0000T0
00>nl`000P000ol000020003o`0000T0000L0003o`0000H01?l01g8FLQKo5W801?l01QIb5W;oLP;o
00TFL_mb5W8FoaH00_l01g8FoaIb5W800ol0278FL_mb5W8F0ol03aIb5_lFLQKo:jl[oc82o`03<P04
o`8bo`@b0_l4<P;o1S800olb<P04<P03oc8b00@b01Co<Zlb[c:_ojlb[c:_oc:_<_no<P?o00?>3_l0
0_l01Lg>og:V00Wo00?>3ol00ol01V]bJg;oQP;o00N[3j_o9_l100Co00<ZHRX01Ol00o3ol002o`0=
l?oolOnEQIGo0S;o_`02o`1D<[lboc;o<_no[ol3<_mo[Wn^OomT?FCoOGimogenOOn0OX1noh1nP7ko
HUERoh1nP?n0OX1nof8ZH_obok3o/;6`og;>L/komLgecOnESYGo<G8a1?l03<G>oc7><LhaonG>i@Go
00I6og8VLRH4o`0A<G;ocPK>1/ko0OnoA_nookl00_l00h1Ro`0E0003o`0000T000Ko0000:Kh20003
_RT000X0000L0003o`0000<00ol01hK>Q/kocXH01?l01lj6cXKoQ/h01?l01hK>Q/kocXH01?l01/j6
cXKoQP;o00W>Q_n6cXK>olh00_l01XKoQ/j6cP;o02:6c_no<_no:koo_c:ookl[oc:o<_l[_ono<[oo
Jono<[lb0_l01Klb_c:o00;o00`b_c:o<[oo_c:o<[l2o`04<[lb_`;o00No<[oo_`>o00Ko00=bcOl0
0ol01JK>Y/ko009b1?l01g:6LXKoJg801?l00lh?cP07o`05_omnP7h01Ol01_7ooo7ol0;o00_`of65
oknV_om6_`02o`0B_ono0ol3o`>ookl3oeDbEC9E0_l09;1modERAOlZHRYRof9UH_mREF9EofERIOmZ
HV[oJV9ZH_n0OPCo00F`ooml/00;o`03ALgo00Co00o=<OlacC7=oj[>Z/koc^D00ol01`o>3lh?o`l0
0_l02lkocQK>5/kocPK>00?o00aV0_noI_mV0_l^1OlE00;o1@001_mEiP05l`<000IVlnKVlfH;0000
70001?l00002o`075W;oLQIb5P03o`085W8FoaIb5W83o`07LQIb5_lFLP04o`075W8FL_mb5P04o`07
LQIb5_lFLP03o`06LQIb5_lF0_l03:[ooaKo:joo0S82o`8b00Go<P8bo`03<P04oc82o`<b00?o_ol0
13800ol2o`04<P;o1C82o`05<Zlb[c800_l02jlb[c;o0on_<_no00?o00=V[ol01?l0297=oaIb5W8F
0ol01aIb5_l?LPl01?l00lh?o`04o`03c@oo008?0_l00joo:P07o`05l?ool?l00_03o`0;UHGo<P;o
0[l2o`800_l02Klboc;o_joo0`02o`05Ojio[Wl00_l093eTogenOOmmOWenogj0O_n0OX1nof9EH_n0
OX3oP7j0O_mR:PCo00>`ool00_l02/koSJZ=Z_mUSFD3o`0@iLko_/jnc[koaLk5olhacPCo00MbAW;o
A/i600?o00UbcW;>og8aLS401?l0278VodJoo`;o0kl00on0HP02oa800_l00`3o00040006__?oofgV
100012IXJ6H<00007005o`06Q/j6c_o>0_l02HK>olj6cXKoQP02o`07cXKoQ/j6cP03o`08cXK>olj6
cXH3o`07Q/j6c_o>QP04o`06cXK>olj60ol0166EHID3o`0o_ol[_b^ooklbob^o:olb_ono:koo_c;o
_f_o_c:oof^ooc:o<_noQ_no<[lbokoo<[lboknFoklb_onFoc:o00;o00D3_onoIP03o`03O?oo00?o
00BVoooo0Pl00ombcP05o`03L/ib00?o00V6LXIbog;o3j/00_l01P>ooomRA@?o00?`oo400_l01_7o
l?3oO0?o01^V_jKo_dKo:kl[okoo_`?o0koo_on5oc9E<UD00_l09;1modERAOlZHRYRof9UH_mREF9E
ofERIOmZHV[oJV9ZHV[oOPCo01f`O?oec_G>ofG>ILkocR[>ooG>mLko<LdacOo=<@05o`06cPo>olib
1Ol02BK>olkec_Go5P03o`0BJonFcYK>U_l2okoo0VKo0Ol50_lF0003o`0001`0000K00;o00Mb5W8F
oaIb00?o00Qb5W8FL_mb5PCo00Ib5W8FoaH2o`09LQKo5W8FL_mb00;o00LFL_mb5W8F00?o00LFL_mb
5W8F00?o00TFL_nZEJYEogd00ol01C82<P8b00;o00D2<P8bo`02<P05o`8b0_l00S801?l2_ol2<P05
o`:o0_l00c801?l2_ol3<P0@okl2ojlb[ola0olb[ola0`?o00Pb_c;o[fKo_`?o00>o<[l01Ol00`mV
o`08o`09E_oo3VH>of]b00Co00X?oooo_jooHRYR0ol01o3ol?3ol?l00_000ommo`02o`0:0S82o`:o
oc42<@?o00no<_no[ol3ogko[Wn^ojl00_l08FCoOGimogenOGkoOX1noh1nP7koHUERoh1nP?n0OX1n
P002o`0M_ollok2aolkec_G>ohfZSOn=IHeUonG>iOo>_/h01?l01libc_lVLRH01?l02c5boolaLS5b
olib00?o00W>L/ibc_lVLRH00ol00kl2o`02_`03o`9V00?o5P000ol0000L000070001On6cXK>00?o
00S>Q/kocXK>QP?o00N6cXK>olj600?o00R6cXK>Q_n6cPCo00J6cXK>olh2o`08Q_n6cXK>olh2o`0=
Q/kocXK>oiEQUOmmO002o`05:kl[_b/00_l01Kl[_b^o00;o02T[_b^ookooJkm[oklbokm[_olb_on6
_hKo_c:oohJooc:ooiJoU_no<P04o`0:<_l3_`?oI[oo_`?o0c801?mRAF86o`05AOnooh`00ol33`Co
00=b3ol00ol00`>o0`02o`03AF9500?o00K`ooo`oo42o`04l?ml/0;o03nV_om6_ono:koo_`;o_`?o
0koo_on5oc9E<_lb_ommodERAOlZHRYRof9UH_mREF9EofERIOmZHVYRof9ZHVX00_l00kool002o`0C
O;3oc_G>mOo>ILkocR[>:_o>m@05o`07L/koLV]bJ`04o`0;c[ko1/h6c_o>9/h01?l01f_>Jom[cV/0
1Ol02eK>ofKoIP;o_`6o00;o00=Ro`005@000ol0000K00003`0012IXo`D80004o`3o5P;o00Ub5_lF
LQIbog800_l01aIbog8FLQH00ol021Ib5_lFLQIb0ol01g8FLQKo5W800ol01g8FLQKo5W801?l04aIb
5W;oLQKoEJYEZ_lmOCgo0S801?l01@8b0S8200;o00Db0S82<P02o`04_`:o0P;o00Fo0[l2o`02<P05
okl2_ol00S802ol2_`;o[c;o0c4300Co00da0on_oc:o<_n_I_no00?o00no<[lbof;o<Zlbogj0O_l0
0S8>o`06HXGo_jno0_l00f8ZHP03o`08l?ool?o`oo02o`0QOK1m/?lbokl2o`8a0_l2mOnoojnooc83
ogko[Wn^ojlb00?o01imOWgoOGimO_mnP7koP7j0O_mREF9Eogj0O_mnP7h2o`040_o`?0;o00>aool0
2?l01:[oIHd4o`0:c^GoiG;UL^GocP;o00/aolg>cLk=oc5b<@04o`07L/kocW;>LP04o`089W;oLQIb
5W82o`:o00CoIP;o0[l2oaL000?o00006P0000h000IVlnKVZ;h70003o`0000;o00O>Q/j6ohK>00Co
00J6cXK>olh2o`09Q/kocXK>Q_n600;o00O>Q_n6cXK>00?o00O>Q/kocXK>00?o00O>Q/j6ohK>00?o
00[>oiEQUF7oO7el0ol01b_>:lko:kl01?l01B^o:kl[00;o00A[_f^o0_l01F^oJkm[00;o00joQ[n6
oklbokn6_olb_`Go00JooiJoU[l2o`0:0koo_fKoI[mVo`Db02KoAOno<[ooAF95oklbof9ZH_noof9E
H_no<_n5okl3_onoodERA@?o00O`ooo`oo7`00;o00G`ok1l/002o`0;_dJookl[o`:ookl00_l03[l3
o`>oohGo<UDboc:o0ol06TERAF;oHRYRof9UH_mREF9EofERIF;oHVYR1?l00f7oYP02o`0>l7goog:F
oc7=<LgocF44o`0;cPo>olibc_o>L/h00ol02lhVcRKo_/jnc_o>00;o00VFooo>I/iVof/00_l02/ko
cUK>E/kocUH3o`090VKo0Kl1ofH200;o5`000ol0000J00003P001RVn002nl`L000?o00000P000omb
5P04o`07LQIb5_lFLP04o`075W8FL_mb5P04o`06LQIb5_lF0_l04G8FoaIb5W;oL_mb5_lFLQIb00?o
00]b5_lFL_nZEJ[o?@02o`07cRKoLS5b<@03o`07:lh[c_l2<P03o`040[l2_`;o00H2_`:o0[l2o`05
0[l2_`800_l01Kl2_`:o00?o00@3<@<a0_l07`<a0c7o_c:oofJ_ojno[olb_c:o<_mRoc:_<_mnP?l0
0c806OmnP?lb[c;oH_lb0c;oH_n__jooI_mR:V801?l00o3ol002o`03l?mm00Go00k>o`:ooc42<Ooe
0_m60PCo00`boc9nojio[_n_<Zl2o`0HOGimO_mnOGkoOX1noh1nP7j0oeEREOmn0ol5Q@?o01@ll3co
3lh?obG=9LgoL/EboljFcPWo00_>cOlaLS5bolk=cP03o`04L/ibcP;o00=bc_l00_l022Ib9W;oLRIb
1?l02Libc_noo`9Vo`02_`03oaKo01P000?o00006@0000h000?o00000P000ol000050003o`0000<0
0_l028K>Q_n6cXK>0ol01lj6cXKoQ/h01?l01hK>Q/kocXH01?l01lj6cXKoQ/h00ol01/j6cXKoQP;o
00G>Q_n6cP02o`05Q_mQUF400_l01`K>1/h6olh00_l01lko:lh[cR/00ol01B_>:om[00;o00O>:om[
_f^o00;o00J6_hJoQ[l2o`03Q[oo00Co00FoU[nF_`02o`03U[nF00?o00X3_onoI_mV_fKo1C809_m5
oklb_om5H_lb_c;oHV[o<[lboeGo<[lbohGo_`>ookooAF951?l00o7ol002o`0Il?llOOm[3f/?Jom6
ob^ookl2_ono0Ol1_`03o`0:HXGo<UDboc:o<P?o01ARAF;oHRYR:_mUHVGoEF9EH_mRI@?o00UnUOn5
HHEQQF400_l00o1mo`05o`07cC7=<OmQc@05o`0?c/GoULjEokk>_/jnobK>00Go00K>JlkocYH5o`07
A/kocTK>AP04o`07cXKoJli[cP02o`0:_`6oo`9Vo`6ooaP000?o0000600000h000?o00000P000ol0
000500;o1@001omb5W8FoaH00_l01g8FoaIb5W800ol0278FL_mb5W8F0ol01aIb5W;oLQH01?l01W8F
L_mb5PCo00Mb5W8FoaIb00?o00ZZEOmFolhVcRK>0_l01aK>5/ko:lh00_l01/koA/i6cP;o00O>5/hF
c_l200;o00LFL_l2_`:o00Go00Vo0_oo0c43<@<00_l01c43<OnV<:H00_l01ZmVokn__`;o00lb_c:o
<_mRoc:_<_mnP?l00c806omnP?lb[c;oH_lb0c;oH_n__ol3I_mR:V;oP002o`04l?o`l0?o00Qml7go
cUK>EP;o01X2<@;o0_Go0TKoQP;oIP;o<Wko[Wn^ojlb[`?o015nOGkoOWenOOn0OX3oOX1nP003o`06
HOn>EHko1XD4o`05cW;oSW802?l0478aobK=9/dVolg>cOo=c/d4o`07L/ibog;>LP04o`0:mG;oo`Ib
1W;oLP;o00T6o`Ib1W86olh00_l01OGoIP;o00:o00Go0QH2o`0H0003o`0001P0000>0003o`000080
00?o00001002o`L000?ocXH01?l01/j6cXKoQP;o00W>Q_n6cXK>olh00_l01hK>olj6cXH00ol01hK>
olj6cXH00ol01hK>Q/kocXH00ol00hKoO003o`06cV_>olh60_l03lkocPK>1_o>o`K>1/ko:`02o`07
1/ko:lh[cP02o`07A/i6cTKoQP04o`035_no00;o00G>oiJoUP02o`9600ooU_l[AR]6:omV_onoI[l0
0_l5<P;o02Db_c:oodERoc:o<_mRJ_lb_c;oEOlb_c;oQOno0ol1_om5HTER00?o00Caoo3a0ol01Sam
?7goJ`;o01b6okl[_ono0_l1_ono0Ol2_omRQF;oEOno<[lb0ol03f95H_mR:V8ZofERIOmEHP03o`0Z
O/EnoiEnUGkoHHEQQOn`olhVcRK>ofG=oleEcEGocPK>1_o5c/G>oljE1Ol01jK>olhVcRH01?l01liF
ob_>:lh00_l00dK>o`02o`08cYK>U_n6cXH3o`0?3lh?c_l1ofH2okl1oeKo01P000?o00005`0000h0
00HY_P00_RT60003o`0000L00_l01aIb5W;oLQH01?l01g8FLQKo5W801?l01QIb5W;oLP;o00PFoaIb
5W;oLP;o00LFL_mb5W8F00?o01LFL_mboo0loeH?EPoo9_l?APm6olhFcP02o`05:lh[cR/00_l01`HV
1RH6olh00_l01dH6og8FLQH01?l00liFcP02o`0BI/iVc_laoeH`ES1FojH`YS2V0_l03JmVokn__ono
oklb_c800_l01jlb[c;oO_l013803_mnP?lb[c;oH_lb0c830_l02Zooo`=V0olZHRX3o`06l?ool?ml
0_l00o1ml002o`0NL/ibc_laooD2odH2o`:6o`9VoghbOS;oOolb[c:_4_l036YEof5ZHF[oEHiEo`B5
01Wo/;7oL/ibc_mbSW;oUHjES_mb<G;ocBK=00Co00[>A_mb5W8FL_mb0_l02PKo1W86LPKomG85o`06
L/ibog861Ol01RK>9_mbm@?o0[l01olF0QKo5_l06@000ol0000F00003P001VKci^KcIPH000?o0000
20001Oo>Q/j600?o00N6cXK>olj600Co00O>Q/j6ohK>00Co00J6cXKoQ/h4o`06Q/j6c_o>0_l01HK>
olj600?o00Il?7cocV/4o`06cV_>Jol60_l03Pm[o`K>1_m[o`K>1/h60_l01lhFcQK>odH00ol03<ko
cQK>obKocQK>5P;o1DH02Olaob]6:olaAP02o`07I[mVo`:oo`04<P;o00Db_c:o<P02o`0;_c:o<_mR
oklb_c800_l01Klb_c:o00;o00Zooooo_`7oHTER0ol01_7`oo7o/0Go024?Joo>Q/ko:ol2_ono0Ol1
_ono0_n5HXERoeGo_c:oo`<00_l07Wj0O_mUHFEQoh1nP?mQJV5Zogk5O/GoOYEnof65H@;o00>`ool0
1Ol026G=IOmEcEG=2?l02ljmog;>L/kocZK>00?o00S>A/i6oeK>EPCo00S>I_oocV_>J`?o00L?cPoo
3lh?00Co00_>Q/koI_l1_onoEP02oaL00olG00003`0012IXJ6H70003o`0000T000_oL_oo5W;oLQIb
5P03o`085W8FoaIb5W83o`07LQIb5_lFLP03o`07LQIb5_lFLP04o`075W8FL_mb5P02o`03l3c`00?o
00L[cR_>odH?00Co01EF<5H`ob_o<IHaobH69_l`odH6APH00ol03Li6cTK>olkoI/iVolh00_l07DHV
oeH`E_m6ITKoY_lFIQIVojno[olb_ono<[lb00;o00F_<Zlb[`02o`@b00OoO_n_<Zlb00;o00L3<P<b
0ono00;o00R`ofH3obYR:P?o0_03o`08O;7ooliVcVH8o`090_m60_l2ofH200;o00an<Whbogoo<Zlb
oc82o`0LOC5mobEU9FGoQF65ofYEJUEZofYQJ_mESUF>o`:50ol01W9[of5bH@Go00ZEooooL_o>L/ko
1Lh00oo>AP05o`07L/ko1W86LP04o`07cW;oL/ibcP05o`06:om6cTK>1?l01`Ibog;>L/h00_l02@8F
oaH1o`9Vo`0H0003o`0001D0000J0003o`0000X00_l01XK>Q/kocP;o00V6c_o>Q/j6ohH00_l01lj6
ohK>Q/h00ol01lj6ohK>Q/h00ol01lj6cXKoQ/h00ol00lkoo`03o`07cRKoL/ibcP03o`07cW;>L_l?
J`04o`0:3f/?Jol6of/?J`Go00M[o`K>1/h600;o12H2o`0IcQK>5/koA_laES5F<OlaAS56oiKo_fKo
0P02o`@b0_l01C:o<[lb00;o00Fo<[lb_`02o`04_c:o<P;o00Fo<[lb_`04o`0:e?no0OmRAF;om0;o
00?`ogd00_l01Cb`??m[00;o00NFog;>L/ib00;o00P1_ono0Ol2_`;o00f5HXERoeGo_c:oo`>o00;o
02Z0OX3oHFEQoh1nP7koJV5ZHOo5O/GoOYEnUOn5HOn`ofIbI_mncGkocED2o`0=UW:FLYKo5/hFokg>
_@04o`0:cTKo9/hVcRKoAP;o00[>oliVcVK>oliV1?l01<h?cPl4o`07c_o>U/jFcP04o`0;3lko0OmF
_ono0Ol06@000ol0000D00006P000ol0000<0003oaIb00Co00LFLQIbog8F00Co00Ib5W8FoaH2o`08
L_mb5W8FoaH2o`07LQKo5W8FLP03o`0>LQKo5_mmob_>:lh[olh2o`07LS7ocUK>EP03o`07A/i6c_nF
<@04o`03E_oo00;o00Q6oc6V<Om6cP;o00daoliVc_l?odHVARI600;o00E6ITIVAP02o`04IQIVo`>F
0_l03klboono<[lboc:_<Zlb[`02o`Db0_l01:lb[c82o`050c83<P<01?l02[3oIP?o:V8Zof83o`06
l?oook5l0ol01W8[LR_o5P?o00X?c_m6ohKo0VH20_l037hbOS;oOolb[c;o<P?o01haOC7oIBEU9OmQ
QF7oEFYEJ_mZHF[oEHiES_n5ok47o`0;HG9Qolj=c_mbcW802Ol02libog;>L/kocW;>00?o00PFcQK>
og;>LPCo00HVcRKo:lh3o`08L/ibcW;oLPH3o`05EW9FLUH00_l0204FofH2oaKo60000ol0000D0000
6@03o`h00_l01lj6cXKoQ/h01?l01hK>Q/kocXH01?l01/j6c_o>QPCo00K>Q/j6ohH2o`05cXKoQ/h0
0ol01camobK>9/h00_l01b_>:lh[og800_l01lh[og;>L/h00ol00g:Fo`02o`033f_o00;o01e[3f/?
olko3hH?Q_lVohI[Q_lFcQKoQYKo<EHao`02QP03odKo00BF0_l01Kl2o`;o008b0_l03Klb_c:o<_lb
_c:o<[l00_l01;lb_c82o`05_c:o<[l00_l00fERo`02o`0:0OmRAF;om3goO0;o00/looooLPooU/jF
cP03o`043fH?IP?o01>ookl2of;oQF:5H_mEoklb_ol300?o01^0OX3oHFEQIOmnP7koJV5ZHOo5O/En
oiEnUGh00ol01W;>oleQc@Go00=EcOl01?l03lg>oljmc_o>9/hVc_o>AP05o`06E/iFo`o>1Ol01/h?
o`o>3`Co00O>Q/kocVK>00Co00FFLYKo3`03o`0;9_noE_l1_ol2Y_l060000ol0000C00006P000ol0
000>0005oaIb5W800ol01g8FLQKo5W801?l01aIb5W;oLQH00ol01aIb5W;oLQH01?l01g8FLQKo5W80
0_l01Gg`OOl[00;o00L?<OlaLS5b00;o00L[cR_>:oo>00;o00?>A_l00_l2cP?o00HacC7o<JH4o`04
<JHaYP?o00ha3c4?odKo3c4?<Om6o`>60ol3UP03oeH`00;o00>o<_l00_l02BKo<Zlb[c:_o`06<P0=
oc:_<Zlboc83<P<b0`02o`0=P7koe?l3obYR:_mRP004o`03O?1l00Go00P[oomb9W;ocP;o00?nool0
0ol0;6KoO_mn<Whbogoo<Zlboc;o<_laOC5mobEU9OmQQF65ofYEJ_mZHFYQohiE1?l02g8aLS7oL[eb
og9E00?o00W>9_oec_G>mOl00lh01?mbcW84o`07cW;>olibcP04o`06:lh[olib1Ol01liboooeL_D0
1?l01W9[L_o>3`?o00daLS5b<OlFofKo0AH100;o60000ol0000B00006@000ol0000@000;ohKoolj6
ohK>Q/h00ol02<j6c_o>Q/j60ol01XK>Q_n6cPCo00N6cXK>olj600?o00F6ooooO@04o`06A/i6c_l[
0_l01dK>ob_>:lh00_l01b_oool[oiH00_l01/kocPo>3`?o00JVcZK>ohH2o`06U/jFof^60ol01HJF
QYJ600;o0hH02_o>I/koU_l?IPl3o`0b0_oocPoo_c:o<[lboc:o<[lb_olb_c:o<_lb_c:o<_noofER
ok3o0OmRAF;om3gdoc`4o`043lkoc@;o00FVcZK>YP05o`033g8?00?o02N5H_n5HXERQOlb_c;o_`?o
0on0OX1nofEQIOmnP7j0of5ZHF[oO/D01?l00lhVo`02o`0DL/ibof7=HLgocGkoL/ibc_o>cLh9o`06
cPo>oli61Ol01Po>3ombcPCo00QFc_o>Y/jVcPCo00K>3ol?cPl4o`08:lkocRK>9/h2o`05_ol2YP80
1?lG0003o`000180000I0003o`0001400_l01W8FLQKo5P;o00Ub5_lFLQIbog800_l01QKo5W8FLP?o
00Qb5W;oLQIb5P?o00HFL_mbog`2o`079W8VL_l?<@04o`063c4?<Ol[0_l01`ooodK>A/h00_l01TK>
A/ko<@;o00I6cTKocW84o`04cW;>LP?o00GUc^Go3`03o`09eLkoQ_l?YPnV00;o00AF<5Ko0hH2o`09
[olVL_n_<Zlb00;o1S803?lb[c:_<_lb0c83<P;o00inP7koe?l3obYR:_mRP0;o00Lll?lV3bH?00Go
00<Vool00ol23`Co01AEogj0O_mn<WhbO_n_<Zoo0c;o<P;o015m<Ggo9FDUof65HHGoJUEZE@03o`05
cPKoLS403Ol01UEbEOo>9PGo0/h02OmbmG;eolh[cP04o`07L/ibog86LP04o`0;L/kocW;>L_mbcW80
1?l00eIbo`04o`09LQKo<G8aL_mb00?o00H?o`;o5P43o`035_l001L000?o00004@0001T000?o0000
4`000oo>QP04o`07cXK>Q_n6cP04o`05Q/j6ohH00_l02Lj6ohK>Q/kocP02o`05Q/kocXH00ol01k0l
oliVcVH00ol01fK>I/koA/h01_l00eKocP03o`06E_o>:lh[0_l01Li6cTK>00?o00K>:lh[oiH2o`06
c_o>3lh?0ol010o>3lh3o`0HI/iVoeI6o`oocUK>E/koQ[ooc_lb_c:o0_l04S:o<[lb_olb_c:ookoo
_c:o<P;o011RIF;o/?l1of95H_od?Ono1?l00lkoo`0:o`0Kc_ooofERIF;oHXERohERQF:5oc:o<_no
okl300;o00mnP7j0of5UHOn0OX1nofX00ol02/h?cPo>olkoHUD3o`;=00CocGk=1ol02libokg>_Ljm
og;>00Go00K>L/koLVH5o`0:L/kocXK>Q_mFcPGo00=bJg800ol02lhVodK>A/i6ob_>00Co00?>3ol0
0_l02JH2Y_o>Q/j6o`0G0003o`000140000I0003o`0001@00_l01aIb5W;oLQH01?l01g8FLQKo5W80
0ol01g8FLQKo5W801?l01aIb5W;oLQH00_l01Gc`O?mb00;o00La3omb<G8a00Oo00<a3ol00ol01S4?
<@oocP;o00iV3oo>A/ko3c7o:lh[cP;o00HaLS5bonD2o`05cVK>olh00_l02hIbQ_nVoc1F<5Ko00F6
00?oQ_l00_l02G;o[c:_<_l2o`04<P;o018b[c:_oc;o0c83o`;oOX1nom@3o`0;:V8Zof:0o`>o0kl0
0_l00dE_A@06o`03AF;o00;o01U5HOmEHUGoOX1noghbOS9nojlb[ol3oklb00Wo00AUohEQ1?l01g:F
L_l6cPH01?l01H1nP?lb00;o00o>oj:mX[go:g8[og8FL_l00lh4o`07cW;>obIb9P04o`0;L/koA/i6
cTKoL/h01?l01G:6L_mb00?o00Ybog8aLS7o5W8F1?l00lh?o`03o`05LVIboaH00_l00aIbo`02oaP0
00?o0000400001T000?o00005@001Oo>Q/j600?o00R6cXKoQ/j6cP?o00K>Q/kocXH4o`07cXK>Q_n6
cP03o`05c_oooc`01?l01V_>JlkocPGo00?>I/h00ol01liVcVKocUH01?l03LiFcUKoc_mFcUK>ob/0
0_l01VKocTK>AP;o00DVcRK>9P02o`05cR_>:lh00_l02eI6ETKoU_o>E/ko00:61?l060oo_c;oE[oo
_c:o<_l1oklb_onooklb_`?o00IRIF;o/=@2o`0:HTERoo@mokl3_`;o02LbOS9nof9UHVGoHTERAOmm
O_mRIF;oHXERohERQF:5oc:o<_nookl00_l025Koog;=oh3=1?l01[g>_Oo>3`Go00W>oc:ooeERoc80
1?l00gk=OP0=o`06IW9Vof]b1Ol02/ibof]bJg;ocW85o`06cPo>olh?0ol01<h[cR/2o`03cRKo00Co
00?>3ol00ol01XIbo`o>3`Co00N`ooo>Q/ko01P000?o00003`0001P00olG000=og;ooaIbog8FLQKo
5P02o`06L_mb5W8F0ol021Ib5_lFLQIb0ol01W8FoaKo?0;o00Mb5W8Foc4?00Go00C?3ola0_l01ll?
oeIbEW800ol01g8aLS7oIPl01?l0134?<@l2o`063j/?Zomb0_l057;FofK>I_laU_mbQW;oY_mF<5Ko
0iH04_n6ohJFohH?Q_lVoc:_okl2o`<b00goIP;o[c;o0S82oc8300?o00InP7koe;02o`0::V8Zof:0
o`>o0`;o01i_AFm5of85HPGoAF95H_m5HOmEHUGoOX1noghbOS82o`0<[c:_o`?o_omF_omo1?l2c@03
olk>00?>0ol01W8aolk=o`<b00OoOX3o<_mn00Go00n@A_oecOG=olebcOmVLVH01?l02libog8aLS5b
og;>00Co00O>3lkocW;>00Co00Qbc_laLS5b<@?o00D?APoo3`02o`05LV_o3lh01_l02IG>oggoLQIb
5P02oaL00_l@000060000ol0000H00;o00N6cXK>olj600Co00G>Q/kocP02o`09Q/kocXK>Q_n600;o
00G>Q_n6cP03o`07??3oU/jFcP05o`04c_m6LPCo00I6LTIbofH2o`07AW;oJli[cP03o`06cVK>I_o>
0_l01/koI/iVcP?o01C>E/iFobKoIPmV3oo>oliVc_m6o`BF0ol01hKoiPoVomH00_l07koo_eJooklb
o`6o0Ono<_nV_jKo<_nooc;oIF;o/=@00_l05695H_odo`>o0on5oc9n<WkoHVER0_l01695HTD2o`0>
O_mRIF;oHXERohERQF82o`0?<[oo0koo_onooc9Uogk=00Go01W>oooo3oo>:lh[onGo_c:ooeGo_c;o
HVYR00Oo00?>cOl02?l02libog9VLVKoL/ib00Co00IbAW;oL/h5o`09A/i6oeK>E_l[00?o00Ebog8?
LP04o`033lko00?o00D?olh6cP02o`06YOn`OOo>0_l00hKo000E0003o`3o0100000H0003o`0001X0
00?o5W801?l01aIb5W;oLQH00ol01aIb5W;oLQH01?l01g8FLQKo5W800_l01Cal??lF00Co00Ab9W8V
0ol01bIb9W;oc`l01?l01^H`iS3o<@;o00O?og9[LV]b00;o00I6LTIboj/2o`06IW9Vog;F0ol01C6F
<IHa00;o1:H3o`>F00CoIVIV0ol018KoUZH2o`06<_l2_`;o0S803Ol2IP;o[olb0S82oc800_l2<P06
oh1nomB`0_l012YR:V82o`0>_`?o<WkoKdE_AOmR1F82o`0MAF95HTGoHOmEHUGoOX1noghbO_lb<Olb
oc83okl00ol02C9o<_mmcOnmc@02o`0<QPn63hKoLS5bolgo0c800omno`02<P08ogj0O_lbof85o`0?
3lko<LdacOl[LR]bolib00Go00H?c_o>L/h4o`07A/e6olibcP08o`03cPoo00Co00<?L_l01Ol050mF
3eKocBK=olkoOK1mog8FLQKo60000ol0000=000060000ol0000K00;o00O>Q/j6ohK>00Co00J6cXKo
Q/h4o`07Q/j6c_o>QP03o`05Q_oooo001?l01Lh?c_o>00;o00L?c_o>U/jF00?o00NVcZK>odIb00?o
00IbAW96olh3o`06E_o>Q/j60ol016K>I/h3o`05cXK>ofH00ol015K>olh2o`0<IW9VoiKoIUIVolH?
0ol00`ooQ@03o`04_eJoEP;o00bo0Kl1okoo_jJoY[l3o`8b00KoIF;o/=@3o`03AF9500;o00h3_omR
QOlbOS9nof9UHP;o00ERAF95HP03o`0<HVERIOn5HXGoHXGo0S806Onoo`?o0kooQOlbIC;ocGk=olf=
cOl?cPl01ol05C:o<[ooEOno<[ooJV;o<_n0OX3o_`05o`03cW;o00So0W89o`07cXKo1/h6cP04o`06
c@ooLPmb1?l00f]bo`04o`03HYGo00Wo00?>1_l00_l01k1m/?n6cXH00olG0003o`0000d0000H0003
o`0001`000Go5W8FLP03o`07LQKo5W8FLP03o`07LQIb5_lFLP04o`065W;oL_na0ol3cP03ooEb00?o
00I6cTK>og82o`07LPKoLRIb9P03o`06:g8[o`o?1?l01/kVc^KoLP;o00D`iS3oIP02o`063ombQW:6
0ol0134?<@l3o`04i/kVcP;o0fH01_l1U_o6YP;o00UZHV[o_`:o0[l00_l01FH2IP9V00;o00@b0S82
0ol3<P06oh1nomB`0ol00f8ZHP02o`0E_omn<WkoKdE_AOmR1F;o<_mRAF9500?o01aEHUERoh1nP?lb
oc4b<Olboc;o<_lbH_lbOc9o2ol01Ld>cOo=00;o13800omno`03<P03oh3o008b00WoHTERojlboh00
2?l00libcP04o`0>cLkocW;>L_mbcW;>odH2o`053g;o3lh01Ol00g9[LP03o`0=P?oo[c;oP7ko<_mn
P004o`049/goO@;o00>`OOl00ol011Ib5_lG0003o`0000`0000H0003o`0001d000coQ_ooc_o>Q/j6
ohH2o`07cXKoQ/j6cP03o`06cXK>olj61Ol017coUW84o`06Q/j6o`o>1?l01Po>3lkocP;o00H?c_o>
U/h3o`07cPo>3ombEP04o`04LUIbEP;o00K>I/iVolh2o`05cVK>olh00_l01HH?Q_mV00;o010?Q_mV
olH?o`o6of;oHXER0_l00kmFo`04o`030Koo00;o00>V_jH00_l00jKoo`03<P06ofERok3D0ol00dER
A@02o`0F0on5HXGo<WhbO_mRIF;o<_m5HTERA@;o00]RIF9UohERQOmRo`03<P0@okoo0ol3ogj5oc9U
<_no[`oo01fo<[lb_omEoklb_omZoklb_omnP?no<_n5HXGo_`02o`03cOoo00;o00[>3oo>1/h6oc5b
2Ol00`mbo`03o`053g8?og800ol04c:ooiERoc:ooiERoc:ooiERokl00_l00`Ko/004o`07c_o>Q/j6
cP02oaD00ol=00006003oah00_l01W8FL_mb5PCo00Ib5W8FoaH2o`06LQKo5W8F1_l00k4l/@03o`06
LQIbog;>1?l01c5b<G;oLPH01?l03W86LPKoL_lVL_o>_/jn0ol01_G>mLko<0;o00D6c_lF3`04o`04
5PlF3`?o00C>Jli[0_l01<j6cXH6o`0:Y_n0O_mZHV[oQ@;o00@FLQIb0ol037;>L_lbooh1ojKo<P?o
00F0O_oD/003o`03HRYR00?o01DbOS9n<_m5KdGoHPERoc;oHTERAF800ol01f9EH_n0OX000_l06C8a
<S7o<_lboc;o<V;o<Wlbojlb[c;omGh00ol01;goc/h3o`Db00?oO_l00c800on0o`03<P0>odGo<Zlb
oh1nP?lboh04o`073g8?L_o=cP04o`033g8?00So00<?c_l01ol01gko[c;oP7h00_l033;oP7ko<Zoo
P7ko<P;o00_=9_mmoaIb5W;oLP03o`03L_l001400ol20003o`0000/0000G00;o8P000oo>QP03o`07
Q/j6c_o>QP04o`06cXK>Q_n61?l00lj6o`03o`063oo>U/jF0ol01iK>U/kocPl01?l01ljFcYKo3lh0
0ol01/h?cPoo3`;o00K>3lkocPl3o`043lh?cP?o00IFLUIbolh2o`053lh?ohH00_l010m[ohH2o`05
3ooo3jH00_l03F9ZH_mRQF;oHYERolh00_l01LiFog9600[o00R5HOmUH_n`e0?o01=5HTGo_omRQF:5
H_mn<WkoHVGo008b00KoAF95HTD3o`07IF9UohERQ@02o`Db01;o_`?o0omnQOlbIC;o_jno[ol4<PCo
02Fmocgo_c:o<[ooEOno<[ooJ_no<[ooO_lb_c;oQF;o<[ooQF:500go00S>oombTOo>LPGo00lbof;o
<[lbof;o<[ooUF800_l03KooUF;o<[ooUF;o_c800_l01lkoOK3oQ/h00ol01/j6cXK>o`h00ol50003
o`0000/0000G0003o`0002800_l01QIb5_lFLPCo00LFLQIbog8F00?o00LFLQIbog8F00;o00G>3lko
LP02o`073lkoLRIb9P03o`079W8VL_mbcP04o`06<G8aobIb1?l011Ib5W83o`053eH?olh00_l01bIb
olkFc]H00ol018H?QPl2o`04cVK>IPKo01H?oomnogj0O_mZHV[oQF:5H_l?9PlV0ol01Libc_om00Co
00mZQF[oP7koe;3oIOmR:V800ol03C9n<WhbodE_AOmR1Ol00S801_mRAF95HP?o00=Rool01Ol03S4b
<C8a<_l3oklboc9R0_l037lbojlb[c;omGkeOPGo00=m5Ol01S800olb<P02<P03oh3o00<b01?oAOlb
[c;oP7ko[c:_ogko[c:_00?o00@bQC:53?l5<P;o00hb[c:_ogko[c:_ogko[`;o00^0O_lb[on0O_lb
[`04o`=m0_l01W8FL_mb5P?o2P04o`P000?o00002`0000030?oo00Co100012IXo`D80003o`0002<0
00CocXK>0ol01lj6cXKoQ/h01?l01XK>Q_n6cP?o00K>occo3lh3o`06cPo>3oo>0_l01lh?oljFcYH0
0ol01Po>3ol?cPCo00H?cPo>olh2o`053lko3lh01?l01/h?cPooLP;o00D?1Poo3`02o`04cPooJ`;o
00D?ool?cP02o`0JHXERof9ZH_mRQF;oHYERUOo>E/kooPonofH3o`0AQF:5of65HOmUH_n`e?lmodD0
0ol03eGoHXERQF;oOS9nof9Uo`02<P08odERAF95ofD2o`07H_ooHFEQo`06<P?o00jo0omnoc;oIC;o
_jno[`;o1384o`0WP3go_c:o<[lboc:o<[ooJ_no<[ooO_lb_c;oQF;o<[lbof;o_`>o00?o00PbOS9n
<_lbI@;o00/b_c:o<_lb_c:o<P02o`04_c:o<P;o01Fo<[lbof;o<[ooUF;o<[ooUF;o_c801?l027f`
OOo>Q/j60ol018K>Q_l600?o30000ol0000;000000@0UOmV0P001VP0001Vl`;V00>X_P001P000ol0
000T000:og;oLQKo5W8FLPCo00HFoaIb5W83o`07LQKo5_mm?002o`06c/g>o`o>1?l01Po>3lkoLP;o
00K>oljnc[h3o`07LR]b:olFcP03o`04cTK>AP?o00M6cTK>obIb00Go00?>3ol00ol00g:6o`06o`0E
3oooEOmnP7koOX1nofYRJ_n5HXER00;o00<Vool01Ol01NCoQF:500;o00=ZQFX00_l01Gkoe;3D00Co
0160OX3o<WhbOS;oAFm5Kol5o`02<P05of95HTD00_l0169EHUD2o`0QJPEZ1Olb<C8a<_l2okooHS;o
[omo<_n_<Zoo[omnmGke00;o00IUogdEOOl5<P03oc8b008b00?oP?l00c808Om5oc:_<ZooO_n_<Zoo
O_n_<ZlbogkoQC:5<_lbOonoo`04<P03oc8b00<b0_l013:_<Zl2o`09<Zlb[omnojlb00;o00Ynoc:_
oh1noc:_0_l00ggoO@03O@0:og;ooaKo5W8FLP;o0P03oa0000?o00002P00008000>EofH01@001RVn
002nl`L000?o00009@001oo>Q/j6ohH00ol01hKoQ/j6ohH00_l01Lj6ohK>00?o00HlOCcocRH4o`07
cRK>9_o>3`03o`063lh?c_l?0_l01`o>oiK>U/h00ol01Lh?c_o>00;o00H?cPoo3lh4o`04cPo>3`?o
00<?cPl01?l01G;oo`o>00;o01ARIF;oHXERof9ZH_mRQF:5oiERU@Co0S82o`0<HX1Rof:5H_l2ohEQ
0_l06V;o/=B`o`DmoeEREOmRQF:5H_mn<WhbofGo0S801Om5HTER00;o00EUHVERI@02o`04IF5Uo`@b
00?o_`400ol03XEnoc;oIC;o_jnookoo1382o`17<_n0?H3o<[lb_c;o<[lb_c;o<[lb_omnoc:o<[oo
H_lb_c;oH_no0kl3oj[oOS9n<_lbIOmFoklb_c;o<[lb_c:ooklb_c800_l01;lb_c82o`0?_c:o<_mR
oc:o<_mRoklb00;o00Emoon`O@03o`06cXK>Q_n60_l01<kooolC0003o`0000X000030003_VQV00@0
00?o00000P000ol000050003o`0002H000?oLQH01?l01g8FLQKo5W800ol01g8FLQKo5W800_l00gdl
O@03o`071Pl63oo=cP04o`061/h6o`o>1Ol01@o>3ol[00;o00D?c_o>m@04o`04c^G>i@?o00I6LTIb
ohH2o`04:g;o3`;o00?>3lh00ol07`ooogkoEF9Eogj0O_mnP7koJV9ZH_mRQF;o_iFoUKl00ol02ggT
ohERQOl3ohEZ00;o01YnomB`e?mRIOn0OX3o<WhbOS;oAFm5Kol5o`8b00GoHTERA@02o`05HUEREF80
0_l02PEZ1Olb<C8aohH2o`0LH_mR<_n_oglbojlb[on_ogkeO_GomFGoOAEmo`Db00?o<S800c800olb
<P02<P0QodGo<Zlb[omnojlb[omnojlb[c;oO_n5<XDboc;oE[oo00<b0_l6<P0;oc:_<Zlboc:_<Zl0
0_l013:_<Zl3o`08<Zlbogko<Zl3o`0:OOooog8FoaIb5P?o00DFLQIbo`0D0003o`0000X000040003
IVQV00<000?o00000P000ol0000500;o:003o`06cXK>olj61?l01/j6c_o>QP?o00>6ool00ol01lh?
odK>A/h00ol01W9FL_mbcPCo00@VcRK>2?l00lh?o`02o`063lh?c_l?0_l01Po>3oo>3`?o00@?cPo>
1?l010ooo`l3o`0GHVYRof9UH_mRQF;oHVYRof:5HXGoUF800_l4<P0?okoooh1Rof:5H_l2ohEQ00;o
01MRok3D/?l5?OmEHUERohERQF;oOS9n<P02o`<b00_oAF95H_lbof9UHP03o`05IF5UHOl00S800ol1
_`02o`0@QGj5O_lbofDbokn__onoo`<b0_l02f8boh0mP3go_c:o00;o044b_c:o<_lb_c:oogko<[lb
_omRoc:o<_mRokl3_`?oZ_mn<Whboc;o_eKo_c:oodKo_c:o<[oo_c:o<[oo_c:o<P02o`04_c:o<P?o
00Pb_c;oH_no<P?o00F`OOo>QP05o`06Q/kocXK>0olC0003o`0000X000050003__<0008000?o0000
0P000ol000040003o`0002D00ol01P3oLQIb5P?o00HFLQKo5W84o`035W8F00;o00Uloooo3g8?o`l0
0_l01W8?onH`iP?o00H?1Pl6olh2o`073aKocPK>1P03o`061/h6o`o>1Ol23`Co00E[3f_oLP02o`03
oPko00Go02:0O_mnP7koEF9Eogj0O_mnP7koJV9ZH_mRojGo_iFoUOno0_l02ggTohERokl3ohEZ00;o
01MnomB`e?mRIF;oOX1noghbOS;oAFm5K`02o`<b01OoHTERAOlboeEREOlbo`EZ1F[o<C;o0P03o`0G
HS9R<_n_oglbojlb[on_0_oeoikomFD00_l011Em5Ol2<P03ob_o00Db00?o<S800c806on_<Zlb[omn
ojlb[omnojlb[on0O_n5<XDbQ@02o`04E[mFo`8b00?o_ol01C804Olb[c:_<_lb[c:_<_lb[c:_00?o
00<b[c800_l01:lb[c82o`=m0_l01QIb5_lFLPGo00=b5_l04`000ol0000:00001P001_l0000Y_P80
00>n:@001@000ol0000R00?o1@002_o>oon6c_o>Q/h3o`07cXK>Q_n6cP03o`03??oo00Oo00d?cPoo
E_l?c_o>E/iF00?o00IFcUK>og82o`06E_o>L/ib0ol015IbEW83o`06cW;>o`o>1ol07@ooof;oHVYR
of9ZH_mRIF;oHXERof9ZHV[oQF:500;o00=n__l013804?nooon0H_mRQOl30_n5HHD3o`0E/=B`o`Dm
1OmREF;oQF:5H_mn<Whb00;o13805_mRAF;o<_mRIF;o<_mUHFEQoc;o_`42o`0A_omnQGko<_mU<_no
[koo_jl01?l00c9R<P02o`0J?H0moklbob^ooklb_c;o<[lb_c;o_c:o<[l2o`0R_c:o<_mRokl3_omR
ZV;o<WhbO_mF_eJooc;o_dKo_c:o<P;o012o<[lb_ono<[lb_ono<[lb0_l01;oo_c82o`04<[lb_`;o
00R`OK3oQ/j6cP?o00O>Q_n6cXK>00;o4P000ol0000:000000L0oeGV00Gc00<000IVlnKVlfH60003
o`0001l00ol900;o00hFLQIbog;oLQKo5W8FLP?o00]b5_ooAW96L_mbcP08o`05LPmbo`H00_l01XH?
Q_l?5P?o00HF3aH?o`H2o`?>00WoL_oocUKoLRH01Ol00lkoo`023`;o02N0OX3oOX1nP?n0O_mEHUGo
OX1nogj0OX3oHVYRojEnYGkoUKoo<[l00_l037gTohERokl3_omZQ@;o01J0ok3Dof9UH_mnP7koOS9n
<_m5KdE_0_l4<P04odERo`8b00KoEF9Eoc82o`04JPEZ1@;o01F60_oo<_lbHS;o[c;o<_n_<Zoo[`80
1?l00fGeI@02o`045GdEO@;o00B6:hKo0c82o`Db01Wo[c:_<Zlboc:_<Zlboc:_<_mnP7j0oc:500?o
00ZoE[mFoc;oA[oo1382o`04<Zlb[`;o010b[c:_<_lb[c:_<_n_<_lb0_l01:lb[c82o`Am00co5_oo
L_mb5W8FoaH2o`03L_l0014000?o00002P0000030;kc00;o00=]iP000`0012IXJ6H70003o`0001`0
0ol>0003ohK>00?o00K>Q/j6ohH2o`0:cXKoQ/ko_oo>LPCo00G>L/ibo`02LPSo00=b3ol00ol01/h?
c_o>EPGo00=[3ol00_l010m[3f/4o`03YPoo00?o021[oomRof9EHUGoJV9ZofYRof9UH_mRQF:5ofYR
J_n5HP;o00FnO[ino`02<P08o`;o0_n0HX02o`070P<20omQQ@02o`0FIOoD/?l5?@GoHUERohERQF;o
OS9n<P;o13803?mRAOno<_mRIF;o<P;o00=QIOl00_l05P6oohGo_omnQGko<[oo<_no[koo_jl3o`04
HS9R<POo00P[_b^ooklb_`;o01Hb_c:o<_no<[lb_c;o_c:o<[oo0kl30_l00f:Zo`03o`0G<LgoE[mF
_olbokm6_olb_onF_olb_c800_l06klb_c:ooklb_c:ooklb_onooc:o<[oo/?mm/003o`07Q/j6c_o>
QP03o`05Q/j6c_l04P000ol0000900005P000ol0000I00?o4P02o`06LQIbog8F1?l0178FLQH2o`03
[koo00;o00M[_omAodIb00Co00?>L/h02?l00g;>o`07o`03cPoo00?o00E63dKoEP02o`03L_ko00So
0320OX1nogj0O_n0OX3oP7koEF9EH_n0OX3oP7j0of;o__nUOZEnoiFooc;o<_mmi7d2o`030koo00;o
01YZQOooP?n`e?mRIF;oOX1noghbOS;oAFm5K`;o13801?m5H_l2<P06oeEREOlb1?l06F;o<_n6oh3o
<_lbHS;o[c;o<_n_<_l2[`800ol01?EUmFD2o`0:LS5b<Ol[QR^6o`8b00Co0[oo13804On_<Zlb[c;o
<Zlb[c;o<Zlb00Co018aoc4b<C8aoeJoE[oo_dJoA_l2<P0=okl2ojlb[ol2ojlb[`02o`0B<Zlb[c;o
[c:_ojoo[c:_<_mm0ol01QIbog8FLPCo00HFLQKo5W83oa4000?o00002@0001H000?o00005P03oaL0
00?ocXH00ol01hK>Q/kocXH00ol01b^ooomV_fH00_l00`ooo`04o`0:9_ooof[o:g8[LP?o00AbcW;o
0W85o`9b3Ol08S;oojYRZ_mEHUGoEF9EofYRJ_mZH_mRIF9UohERQOmZHVX2o`0>_WjnogjnO_lbokl2
o`82o`03HX3o00?o00G>1_mQQ@02o`0GIOoD/?l5?@GoHUERohERQF;oOS9n<_l01C804omRAOno<_mR
IOno<_mRJV9Zoc800_l056:5okooOXEnoc:ooc;o_joo[kn_0ol06F8bHS;o_oo=c/g>okl[_ono<_no
Q_no<[l00_l03klb_c:o<_no<[lb_ol3_`03o`@a00SocC7=<OnoEP?o01A6_dJooc:ooiJooc:oohJo
oc:o<P;o00Zo<[lb_ono<[lb0_l02S:o<[oo/4CoQ/h5o`06cXKoQ/j61?l01<j6c_l@0003o`0000T0
000E00;o5@03oa/00_l01QIb5_lFLPCo00TFLQKo_om[_f/00ol01S3oolh?cP?o00J0oh1nog82o`05
P?oocPl01Ol00`o>o`03o`04cOooOP;o00AUoooo1383o`0MP7koOX1nogj0O_n0OX3oP7j0of9EH_n0
OX3oP7h00_l03kin_WkoOZEnoiGo_c;o<P03o`03OOoo00;o00LaL_mZQOll00;o01F`e?mRIF;oOX1n
oghbOS;oAFm5Kol01C801?m5H_l2<P04oeERo`8b01goQF:5ojlboh1nojlboc9Roc:_<_lbojlbo`:_
0P03o`06mFGeoc:o2?l028Ko<S;o0[oo0c801onooc:_<Zl00_l01C:_<Zlb00;o00f_olko<Kda_Olb
<C8a00?o01f>_OnoA[m6oc;o0[l2ojlbokl2ojlboc:Vojlb[`02o`0>[c:_<Zoo[c:_<_mm?7d2o`07
LQKo5W8FLP04o`065W;oLQIb0ol?0003o`0000T0000E0003o`0001800_lN0005ohK>Q/h00ol01lj6
c_o>Q/h00ol00kmV_`02o`06I_oooeH?0ol01V9UofYRJP;o00ARJ_mZ0ol00fERI@03o`04QOmZHPCo
00JEof6EHOl4<P0Moo7oHZ[oEF9EoeEREOmZHV[oJV9ZofERIOn5HXD00ol02gkoO[in__mn_Wjn00;o
00Bookl20_l00ggoo`04o`061_mQQOna0_l05MB`o`Dm1OmREF;oQF:5H_mn<Whbo`05<P0Pof95oklb
of9Uoklbof9ZH_no<_n5H_lb_omnQOno<[l2o`08[kn_ojnookl2o`06HS9Ro`>o0_l02<dUcBGoOOl[
0_l058JoQ_no<_mV0_lb_c:oo`;o<[lb1?l01<kec_l3<@03olgo00;o00>5oc400c401OnoA[m600;o
01VoU[oo<_noQ[oo<[oo0[oo<[lbokoo<[lb00;o00lb_c:o<_m4/?o>Q/j6ohH00_l01/kocXK>QPCo
00?>Q_l03`000ol0000900005@000ol0000?00?o8@004olFoomb5_lFLQIbog;oL_noJkl00_l01FJo
okmV00;o01b0O_mnP7koOX1nogj0oh1nP?n0OX3oHXERof:50_l02:EnYOmUOVGo13806ooaoh1nogj0
O_mnP7koP7j0oh1nP?mREF;oP003o`0CJV5Zokin_WkoOZEnYOlb_ono<P02o`03/7go00?o00M1oooo
QOll00;o01F`e?mRIF;oOX1noghbOS;oAFm5Kol01C801?m5H_l2<P04oeERo`8b01CoQF:5ojlboh1n
ojlboc9Roc:_<P;o00Pb[c;o0Zoo_`?o00iUmOlb_onoobZ>:XkoH@?o00Bo0[oo0S806Ono_olb[c;o
EP;o[c:_olkocQK>5_nm<Kd00_l036[>J/iZohjmS_m6_`?o00Fo0[l2_`02o`0Q0[l2ojlboc:Vojlb
oc:Foc:_<_nooc:_<Zoo?7dlog8F00?o00HFLQIbog82o`065_lFLQIb0_l>0003o`0000T0000E0003
o`0000`00olU00;o00O>Q/j6ohK>00?o00K>Q_mV_fH2o`0]_onoI[ooHVYRof9UH_mRJV;oHV[oJV9Z
ofERIOn5HXGoJ_oEoiEnUOmQUF7o00@b0ol05F:ZoeEREOmEHUGoJV9ZofYRJ_mUHP03o`0?UGkoOZEn
YOnnO[koO[in00;o00D2_ono0P02o`07OCcoHX3o@@03o`03QOna00;o01?D/?l5?@GoHUERohERQF:5
oc9n00;o1C808?mRoc:o<_mRIOno<[ooJV;o_c;oQF;o<[lbohGo_c:o0_l02:no[on__ono0ol01c9R
o`?o0kl00_l03<dUcOo=OOnoQ[n6_`;o01L2IP9Voklbokl2oc:ooldacOo>mLko<@02o`081_laQC65
<Ol3<@?o00S>aOnF_iJoUP;o00BoQ[n60_l03kl2_olb_ol2_olb_ol2_`02o`06<[lbodB`1?l01XK>
Q_n6cP?o00K>Q/j6ohH2o`03c_l000d000?o00002@0001D000?o00002@03obX000?oLQH01?l03g8F
L_mbokm[_onoI_mV_`02o`0JOX1nogj0O_mnP7koOX3oP7j0oh1nP?mRQF82o`0<OZGoYGjUO_mnIGko
0c83o`0BP7koOX1nogj0O_n0OX3oP7j00ol058GoEF5EofYQJV7oO[in__nUolj60_l00c:o<P02o`05
/?ooE6401Ol00hGo?002o`0C/=CoHVERogj0O_mn<WhbO_m_A@02o`Db00?oAOl00c800omEo`04<P0C
of:5ojlboh1nojlb[omRoc:_<P02o`08<Zlbo`:_okl3o`07IOGo<_lb_`02o`0<SRZ>of6mHOno0[l2
0_l4_`0<ojlboeH2ojlbojG>1ol02c4V<BKocV[>J_n>00;o00TFolk5c/Go0[l00ol01Kl2_`:o00;o
01BV<ZKo[c;o<YKo<Zoo1[oo<_lb[`?o00Ib5_lFLQH4o`06LQIbog8F0ol01AIb5W;o00d000?o0000
2@0001D000?o00001P03obh00_l01XK>Q_n6cPCo02AV_oooI[oo_fKo:omZH_mRIF;oHVYRof9ZofYR
J_mUHVGoQF82o`0=eGkEoiEnUGkoUF6Eo`03<P;o019Foj[oEF9EoeEREOmZHV[oJV82o`0AaGk5ogjE
OYGoYGjUokin_Wh00_l012H[9R/2o`04_ooocP;o00BVoh1R0_l06/koQOna/?oD/?l5?@GoHUERohER
QF:5oc9n0_l5<P0Zof;o<[lbof;o<[lb_omZH_no<_n5H_lb_c;oQOno<[lbojno[on__ono0ol01c9R
o`?o0kl01Ol00bGoO@07o`0>IP9V0VKo_ol2_`;o<[l3o`8a00ko<Ldao`K>1/koQC65<@;o00O5c/G>
olk500Co00O>Z_n6_hJo00;o00D2_`:o0P02o`0:_`:ooc:oo`:o0P;o00Jo<_oocXH5o`06Q/kocXK>
1?l01XK>Q_n6cP?o3@000ol0000800005@000ol0000300?o<`000olFLP03o`0ULQIb5_m[ofJookmV
_on_oh1nogj0O_mnP7koOX3oP7j0oh1nP003o`0?AOnUOZEnogjUO_mnIGko00<b017oEZooO_mnP7ko
OX1noh1nP003o`0K<On5HHGoEF5EHOmQJV7oO[in__o>Q/j6oj]600;o00P2ooooI_mQE0;o01`aohGo
?2Co/=CoHVERogj0OX3o<WhbO_m_oc;o1S82o`@b0_l4<P0Mof:5ojlboh1nojlb[omRoc:_<Zoo<Zlb
o`:_okl00ol01fGo_c;o<[l01?l030Goooo=__o=<Ldao`Fo0_l0109F0UH2o`0@<On>_HjmojF>YOlV
<BKocP?o00JFoaH`5S03o`09ZS7oc/G>aOl200;o00O>oc:V<ZHb00;o00BF<YHb0_l01[l6_`Ko[`Ko
00LFL_mb5W8F00Co00Ib5_lFLQH4o`04LQIbo``000?o0000200001@000Co00000olg00;o00K>Q/ko
cXH4o`0M_fKoI[oo_b_oJV;oHVERof9ZH_mRJ_mZHV[oIF800_l04GjEO_oEO]EnogjEO_nEHIGo008b
0_l00kmF_`02o`09EF9EoeEREOmZ00?o01AnYGkoaGk5O_nEOYGoYGjUokin_P;o00L[9R_o0J/100;o
00RoooooY_n0HPKo01Ja/?oD/=Co?@DmoeEREOmRQF:5oc;o0S800olb<P03<P;o00@b_c:o0_l07c:o
<[ooJ_lb_c;oQOno<[lbohGo_c:o<_n__ono[kl01Ol02c;o_`?o0koo<_lb00Co00K>L/kocW88o`05
_`:o0[l00_l00c7=o`03<@03olda00Oo0196cTK>A_o>aOo>olkUc^GocZX3o`07iLkUc_no0P03o`05
0[l2_`800_l01kl2_`;o<[l00_l028KoQ/j6c_o>0_l01XKoQ/j6cPCo00J6c_o>Q/h3o`/000?o0000
200001@01?lj0005og8FLQH00ol07QIb5_mVofJoI_no[on0O_mnP7koOX1nogj0oh1nP0?o019UodEQ
AOnUOZEnogjUO_mnIGh3o`8a00?o[eH00_l01Gj0O_mn00Co01m5J_laP37oQF65HOmQEF7oHFYQJ_nn
ohI[ohKoZdJ[00?o00P2ob_oI_mQE0Ko01<l9?n`e;3oIF9Uoh1nP?lbOS9n00;o00Ce<_Go1C82o`@b
0_l4<P0Kof;o<Zlboh3o<Zlb[omRoc:_<Zoo<Zoo[`:_00Go00]Uokoo_c:ooc;o<P02o`03cOoo00Go
00_>cOoecOG=mOl2EP03o`07<S4bokf>_@03o`0FcZ[o1/d6cOnFLYIboc3ocYK>ojXaZP?o00O>5_o>
mLke00?o00KUc^GoUS83o`0?1[l6_`Ko[ombog8FoaIb00?o00Ib5W8FoaH2o`06L_mb5W8F1?l00g8F
o`0;0003o`0000P0000D00;o?@009?o>oon6c_o>Q_mV_onoI_l[_b_oJV;oHVERof9ZH_mRJ_mZHP;o
01=nYGkoOYEnUOmneGkoOYEnUOmQ00;o00OEc]G>eOno00;o00=Eool00_l068EQof5ZHOmnYGjUogk5
O_nEOYGoYGjUOP;o00>6JhH01?l01@7oZoo`00;o00HVojKoP686o`0C/K3ook3Docd5?OmEHUGoHXER
Q@02o`<b00?o<S800c801_no<[lb_`;o020b_c:oof[o<[lbohGo_c:o<_n5oklb_c;o[koo_joo0`Co
00Hbokoo_`<2o`05<_oo0kl01?l02lebolk5c/Go<G8a00Co00PacOo=<Lgo<@;o00T6olk5c/GoiLh0
2?l04<h[cR_oiLkoc_oUc^G>olh2o`06eOoUc^G>0ol02Lh6o`:o0[l2_`02o`03Q_n600Co00K>Q/ko
cXH3o`06Q/j6c_o>0_l01XKoQ/j6cP;o2P000ol0000800005P000ol0000k00;o01hFLQIbog;o_ono
I[oo[kn_oh1nogj0O_mnP7koOX03o`0CJ_mUHFEQof55HOmnYGkoOZEnY@02o`03aOla00@a1Ol00eIb
o`03Q@0DofY5JTGoP360of65HOmQEF5EofX4o`07Jooo5S4F<@04o`03/Ooo00Co00=QE?l01Ol04c`T
oooD/?mUHVGoP7j0oc9n<Wh00_l01?DbmOl5<P03oc8b00<b00?o<S800c801omRoc:_<Zl00_l04c:_
<ZooH_lb[c:_oc:_ojl2oc801?l01VGo_ono<P;o00LbUOlb_ono00Ko00?>cOl01?l01OGoAC9500Oo
00QFcUK>oljZcP?o01K><Oo>cLk=oiK>U/koZ_mF3eKocQK>0_l01QK>5/koi@;o00X6olh6cPKo_`Jo
0ol02RKooolFL_mb5W84o`065W8FoaIb0ol01W8FLQKo5P;o00=bo`002@000ol0000800005`000ol0
000l0003ohK>00?o01NoI_mV_fKo:kl[ofYRof9UH_mRJV;oHP02o`0DOZEnogjUOZGoUGjEogkEO_mn
UGh2o`0:<@HaolkEc_nZo`<a01OoU_mQQF65ofYQJ_nUOZGoO/EnoiEnU@03o`039/hV00;o00S>1/h6
cPKo0@;o00?`ool01?l00h1Ro`05o`0A/K3o/OoDocd5?OmEHUGoHXD00ol4<P03oc8b00<b01?o_c:o
<[oo_c:o<[ooJ_lb_c:o00;o00Bo<[lb0_l03C:o<[oo_onookn_o`<01_l01;oo_`<2o`0<<Wko0koo
_ono0ol30ol00c7=o`07o`0=mLkocZ[>o`K>1/koa@02o`091_o>YLjUonG>00So00K>I/iVolh2o`06
c_oEc]G>0_l02<kec_GocPK>1?l010Ko_bH2o`03Q_oo00Co00K>Q_n6cXH4o`06cXK>olj60ol01HK>
Q/ko00T000?o0000200001P000?o0000?002o`0FLQIbokoo_fKo_jno[on0O_mnP7koOPCo02UUofYQ
JV7oHFEQof55HOmnYGjUojGo<?laaC75oc7oaC75oljmc_mFo`03Q@0OodEZAOn0<H3oHHEQQOmEofKo
cTK>oc3o5S4F<AKo0@02o`03c_oo00Go00=QE?l01?l03F[o9?mmok3oIF9Uoh001Ol0282>oc;e<_Go
1C800olb<P03<P03oc8b00@b0_l013:_<Zl2o`0C<Zlb[c;o[c:_<_n_ojoo[`;o<P03o`07l_lb_ono
<P02o`0><YGo<[oo_ono<_lboc82o`?=013ocLgocEK=E/gocLk=oliF0ol024K>A/kocS7>0ol02ljn
olibcW;o3eH?00?o00KFL]Ibolh2o`08c_l6cPK>o`H2o`075_o>mLkoJ`05o`06LQIbog8F1Ol01QIb
og8FLPCo00HFL_mb5W83o`P000?o0000200001T00_ln0003olj600?o00eV_ono:kl[ofYRof9U00?o
01MnUOnEO_mnYGjUojEnYOnEOYGoO]Ene@02o`=600Co1S460_l01JXaZS7o008a0_l04/koQF65ofYQ
J_nUOZGoO/Ena@;o00HVcRKo9_l3:`0:o`K>1_l1oj_o9POo00>0H_l00ol01o3ook2aogd00_l00cd5
o`02o`08OUGo:WhZO_l4<P03oc8b008b0_l09klb_c:ooklb_c:o<_no<[lb_olb_c:o<[oo<[lb_ono
okoo_joo0`02o`0JOOoo0koo_`?oOS9no`?o0koo_ono0ol3o`<8o`03c_G>00So00Vnc_l6cPK>ojD0
0_l02BKoc^G>iOlVcP05o`06cRK>oeK>0ol020mV3fKomLke0_l02NG>iLkoc_lV_`02o`06c_o>olj6
0ol01XK>Q_n6cPGo00G>Q_n6cP05o`03cXKo00T000?o00001`0001/000?o0000?002o`0=5W8FofKo
_jno[on0OP03o`0IHOmQAF7oHFEQof5ZHOmQIF7oHDEQAOnUOP02o`0C<2H`9_o5<Om6oc75<LGoc_m6
1P02o`>500coAFY5oh0aP37oQF42o`04IQIV5P;o00h`US2F<?lFo`7oYXKocPOo00MQE?ool?o`00;o
00@T??mR1?l046[oOUEnoh2>P8ko<_DbmOl4<P;o1382o`Hb01_o[c:_<Zoo[c:_<Zlbojlb[c;o[on_
ojl2oc800_l2P00;oc;o<[lboiDbobH00_l04S:ookoo_c;o<_lbole5cOo=cPCo00k=c_lacC7oiLkU
c_o>AP?o00La3c4?oljn00Co00O>_/koL/ib00Co00W>9_o>I/iVolh00_l01S3o5/hFcP;o00U[9_lF
LQIbog800_l01QKo5W8FLP?o00Ib5W;oLQH4o`06LQIbog8F0ol80003o`0000L0000L0003o`0003/0
00GoQ/j6cP02o`07:kl[_b_oJP02o`0HUGjEoiEnUGkoOYGoYGjUojEnYGkoOYEn0ol00kkoAP03AP0:
o`KoAS56oc6Z<@;o00<`9S000_l038EQQOmZHFYQogjUOP?o00W>olhVc_l?Q_l012/8o`039_oo00?o
00C`oh1R0_l00o3ol002o`0D/;7oOK7oaGk5oeEnEGkoORYn:_l3<P0;oc8b<_m6_olb_c800_l06[lb
_c:o<_no<[lb_olb_c:o<[oo<[lb_ono0_l01Jno[ol300;o00=mHWd00_l020>o0omn<_l60_l02`>o
okoo_`?o0ol300;o01?=<LgocFGo_/jnc_o>iLkUokk>00Co00H6cPKocRH4o`07cRKoc^G>i@04o`0:
c_GoL/ibc_mV3`?o00H?IPmVolh2o`043ono9P;o00>6c_l00_l01/kocXKoQP;o00K>olj6cXH3o`07
Q/kocXK>QP03o`04Q/j6o`L000?o00001`0001d000?o0000>`002olFoombojno[kn_00;o01QQof5U
HOmQAF55ofEQof5ZHOmQIF5UodD3o`07c[k>__lV<003o`0=AQI65_o5<On6o`I61P02o`B500KoJTEZ
oc44o`0<3f/?oaKoES1F<?l`0_l01@ooZ`n[00Go00S`ooool?mQE0Co02;`oolT??mROOmZOV[oOUEn
EOn>P8j0ooDbmC;o<_m6_dKo0c800om[o`05<P0Kojlb[c:_ojlb[c:_<_n_<Zoo<Zlbo`:_0_lb00;o
18000olb_`02o`0CUOno9[oo<[oo_onooklboc;o<P08o`07c/g>cOo=<@04o`07LS7o:ld[c@03o`09
LS7oI/iVc_o>00;o00XaooG>mLkeolhV1?l01/hVc_n6<0?o00K>I/iVobH4o`03LQIb00;o00XFoooo
5W8FL_mb0_l021Ko5W8FL_mb0_l01QKo5W8FLP;o1P000ol0000700007P000ol0000k00;o00O>Q_l[
_b^o00;o01InUOnEOYEnogjEO_mnUOnUOZEnogjU0ol01oG>okk>_/h00ol02/k5oc56<DKo<Ol3J`04
obKoAP;o00=QQOl01_l00g9VLP08o`033hKo00?o00D?oj/?Z`06o`05l?oooo000_l00f:0o`02o`0G
l?oo/;7oOK7oaGk5O_mnEGkoORYn:_l013804Olbokm6_olb_omV_olb_c:o00;o00Bo<[lb0_l01C:o
<[lb00;o00db_c;o0[l2ojnookl300;o00AmHWeR0_l07Kooogko_`Joo`?o0koo_ono0ol3o`?o<Lda
odG=00So00TVc_o>E/iFo`H00_l02LkocPK>1_o>9P03o`07:lh[c_oecP05o`06c_GoL/ib1?l01/ib
c_m[3`?o00J6c_o>Q/h4o`06Q/kocXK>0ol01lj6cXKoQ/h00ol01/j6cXKoQP;o00?>o`001@000ol0
000700007`02ocd00_l06[n__joo_omEHEGoIF5UodEQAOmUHOmQJV5Z0ol022Ko1/h6c_nn0_l02BKo
c/G>aOlFAP05o`06QV_ooc0V1?l0237oL/ibc_mb0_l01lh6og8aLS400ol00`o>o`04o`03Zooo00Go
00G`ooool002o`03E67o00?o01[`ob@lof9mofYnJWkoEGiEohj0SX3omC;e<P;o00FoA[m6o`02<P04
okm[o`@b0_l02jlb[c;o0olb[c:_00;o00N_<Zoo<Zlb00;o00F_okoo[`02o`:000?o_`800ol01YGo
_bKo_`;o00/b_onookoo_c;o<P02o`?=013ocLgomLkec_o>cLk=og8a0ol01c5b<G;oLS401?l01W8a
L_l?<@Co00L?<Ooec_G>00Co00HFc_lVcRH4o`04c_lFLPGo00Ab5_lF1_l01G8FoaIb00Go00Ib5_lF
LQH3o`055W8FL_l01@000ol0000700008@000ol0000k000Jokl[_omFA_mnUGkoOYEnogjEO_mnUGko
OZD2o`08cPK>1_oec_D2o`08aLk5c_o>aLh3o`04cXK>QP?o00<6c_l00TH02?m6oomVolhV0ol01aK>
5/hFog800_l00`o>o`02o`049/hVcPWo00G`ooool002o`03H_oo00?o01Kaok2aogfaOOmnaGkoOUEn
EOlZOR[o1382o`0WA[m6_olb_omV_olb_c;oI[oo<[lbohKo_c:o<_nooklbo`:o0_l200;o00>oo`<0
0_l01V9moknV_`?o00D6_`Kom@02o`0=0koo_onookl3o`?o0`08o`03cW;o00So00HVcRKoE/h4o`07
I/kocRK>9P03o`099/ko:lh[c_oe00;o00I6ooG>mLh4o`04mLkoLPCo00K>Q/kocXH5o`05Q/kocXH0
1?l01/j6c_o>QPGo00F6c_o>QP03o`D000?o00001`00028000?o0000>`005_n_okn6_omEHEGoIF5U
odEQAF7oHFD3o`08cUKocRK>olh2o`085_lV<2H`olD2o`05UW:Fog800_l02<ko1/h6c_l`0_l015K>
of/4o`06E_l6cPK>0ol00`ooo`02o`03<G8a00;o00=6ool00_l01O3oooo`00Co00C`oono1?l06O3o
93coHWeRogiZO_mEOUEnoh2>P8ko<_D00_l034JoA[m6oc;oJkm[o`<b01co_`;o<Zoo<@?o<ZlbobJo
oc;o[c:_okl6_ono1?l2P004okl2_`?o01@V_ol6_`Ko<_lb_onooklboc;o<P;o00EbcOo=cP03o`0;
LS5bolkUc_laLS401?l02G;>oc5b<G;oLP02o`09E_laLS5bo`la00?o00HF3aH?olh2o`06<OlFcQK>
0ol01W;oLQIb5P?o00<FLQH00_l00g;oo`02o`065W8FoaIb1?l01QIb5_lFLPCo00@FLQKo1@000ol0
000600008`000ol0000k00;o0196ETKoOYEnogjEO_mnUGjEoiD2o`08cPK>1/kocPH2o`08c_G>mOo>
aLh3o`04A/i6cP;o00Sec_G>o`K>1P;o00C>E/iF0ol01lhFc_m6oaH00ol00f^6o`05o`059_ooo`l0
1?l01O3oooo`00Co00Caoolb0_l06?7olOn`/Omm/GgoO/EnogiEOUGo:WhZOP?o00S>okm6_dJoAP;o
02>oI[oo<[oo_fJooc:ookn6_olb_ol2_onookl2_ono0[oo_`04o`05H_nV_jH00ol05Kl6_onomKoo
0ol3_onookoo_`?o0`06o`06cFG=olib2Ol02Po>oli6cTKoI/h3o`07cVK>I_lVcP04o`06:lh[oli6
0ol01TK>A/kocP;o00M6olj6c_o>00;o00J6ohK>Q/h3o`06cXK>olj61?l01/j6c_o>QPCo00K>Q/ko
cXH3o`@000?o00001P0002@00_lm000?ohJoQ_mQEOmUHFEQof5500?o00O>1_mFcUK>00?o00o>mOl`
5S0FobKo3eH?oiH00_l02<kocQK>5_o>0_l01<h[olh2o`065_m6cTK>1?l00c4?o`02o`06LS5b<OnV
1?l01DKooom600;o00Baoo2a0ol01?3oO[l2o`03l?o`00;o018l9?mmH_mnJWkoEGiEO_n0SX02o`0:
iLkUc_noA[m6_`;o00A[_f_o0S807?l2_`;o<Zoo<@<aojlbobJooc;o[c:_okl6oc83o`0B/On0o`:o
0_l6oklV_ol6_ol20_l02c:ookoo_ono<_lb00?o00?=S_l01_l03liboc7=<LgocC7=<OmbcP04o`06
LPIbog9F1?l01g9Voc5b<G800ol01W8aL_l?<@?o00HF3ooo5W83o`06LQIb5_lF0_l01W;oL_mb5P?o
00HFL_mb5W84o`065W;oLQIb1?l011Ib5_l30003o`0000H0000V0003o`0003/000_oAUKoUGjEoiEn
U@03o`081_o>mLkeolh2o`09c_o>1/h6olke00?o00AFcUK>0_l020K>1/koc_G>0_l011K>5/h2o`06
5/hFc_o>0_l04@K>1_mFoeK>ofK>I_nFY_mn00;o00D?oooocP02o`0;l?o`l?oaoo7oiC800_l08O7o
lOn`ok3o/GgoO/EnogiEOUGo:Wko5_o>iLkUc_noAP03o`05I[mV_fH00_l07FJoI[oo<_n6_hJooc;o
_`:ookoo_`;o0[l2o`:o00;o01mlooooY[oomLkeo`KomKoeoknFo`?o0koo_onookl300;o00B_oldZ
1Ol01bK>9/kocW802Ol01V_>oliFcPCo00UVc_o>Jli[ob/00_l01/kocR_>:`?o00E6c_m6cP04o`06
cXKoQ/j60ol018K>Q/h4o`05Q_n6cXH01?l01/j6ohK>QPCo00K>Q_n6cXH3o`8000?o00001P0002L0
00?o0000>`002?n6of5EHOmQ0ol01bK>9/kocPH00ol02=G>eLkoc_G>0ol01DK>A_l?00;o00Q6olhV
cRKo5P;o00AbY_l[0_l01/iVoeHFEP;o00G>A/i6cP02o`07YPnV3olao`02YP;o00=5ool01?l00dKo
o`02o`09l;7olOo`ogjo00;o00C`oo3`0_l03RCoOF9mofYnJ_mnEGiE0_l022/V:oo>iLkU0ol02:G>
okm[_f^o0_l01Kl2_`:o00;o00/3<@<aojoo_bJo9P02o`09[c;o1[ooQS:600;o01naoono0[oocPK>
obKo_`Ko_`:ooc;o<[oo_onooklb00;o00S^oooo1/goc@;o00?>L_l00ol02/k=og;>L/koc/d5o`0:
cQKocW;>L_mbIP?o00IVLVIbog82o`0=JolVLRIbo`ooL_mb5P05o`055W;oLQH00ol01AKo5W8F00?o
00LFoaIb5W8F00?o00HFoaIb5W84o`035W;o008000?o00001P0002P000?o0000>`02o`03UOoo00;o
00LVc_l6cPK>00?o00WUc_o>aLk5o`H00_l01LjVo`o>00?o00LFcQK>olh600?o00A6cTK>0_l052K>
9/hVoaKoA/kocPK>o`n6oeK>1?l01JKooomn00_o0_001ooaoo7`oc800_l01_7olO3oO@;o00ZaOK7o
aGk5oeEn0ol01QK>5/koi@?o00TaojG>YLko_fH01?l01FJoI[mV00;o00F6_hJoQP02o`0F_`:o0_l2
_`;o0[oo_`;o0_ml/?noYP;o00?ec_l00_l02;oe_onF_ono0_l02P>ookoo_onookl2o`090olaLS5b
olf000;o00YbAW;ocRK>olhV1?l02libc_o>3lh?ofK>00Co00IVcVKoJlh3o`07cV_>Jom6cP03o`03
c_oo00;o00J6cXKoQ/h4o`05Q/j6ohH01?l01lj6cXKoQ/h00ol01/j6cXKoQP;o00K>olj6cXH2o`03
0?l000L0000Y00;o?002o`09cQK>olh[c_o>00;o00T6onG>iLkoc]D00ol012Ib9W83o`07c_GoA/i6
cP03o`05iS3VojH00_l01eIbofK>I/h00_l02ZK>Y/koc_o6<LH3o`03cXK>00Co00?`ool02ol01;7o
ool2l005okmnoo000_l01?3o/7d;o`;>00Go9R/V:`02o`09<Kda_C7oYLjU00?o00MFLUIbo`:o00?o
00Da0c43<@02o`049[lV_`;o00Tb[ono1_lbQS800ol01K5m/Ol200Co01O><Ol6_`Ko_`;oE[oo<_lb
_onookoo_`02o`03<_oo01;o00K>L/kocPH9o`06<G;o1W861?l01W;>of]bJ`So00Ib5W;oLQH4o`06
LQIbog8F1Ol01AIbog8F00Co00Ib5W;oLQH3o`065W8FL_mb0_l011Ko0?l80000:`000ol0000j0008
olkec_GocRH2o`08c_G>mOoUc^D3o`05LVIbojH00_l020K>o`K>1_o>0_l01/iFc_m6LP?o00IFcUK>
obH2o`05cVKoA/h00ol030n63ol?olhVc_l?aP;o00C`oon`1_l01_3ooggol0?o00?`oc800_l05o7o
oo3oOK3oYLjUc_o>_Lkoc/G>aOo>00;o00<Voc4013402oo>ooo>oeK>E/iF00?o00KUc_noQ[l2o`04
cRKo_`;o00_5o`:ookl2o`:o0P03o`03O;1l00?o01ZZolG>aLkomOnoU_m6_dKo0ol3_onookoo_`;o
01L3ojooL/ebolk=c_o=c/g>og;>L_o>EP04o`0:cUKoL/ibc_o>3`Go00D?c_o>J`05o`0:Jlkoc_o>
Q_n6cPCo00J6cXKoQ/h4o`03Q/j600;o00?>ool00_l01XK>Q_n6cPCo00J6cXKoQ/h3o`04cXK>QP;o
200002`000?o0000>P000olFcP04o`08eLkocPK>olh2o`06LR]bolk60_l022K>9/hVooG>0ol0178a
LS43o`06A/i6oeIb0ol010lV3bH3o`0BQW:6olKoJli[olko3`7o<Oo`0_l012Cooo43o`05/Oo`ocd0
1?l00o3o_`02o`;`0ol03K1m/?lacC7=olhZc_l00/h3o`099V/VJonm<Kda00;o00IFcUK>oeH3o`0M
__oec_G>o`?oIRIV9VKoc]G>eOn_okl6oc:6okl01_l04/iZcV[ocS7>okoo0[oo_eKoQP;o00Pboc:o
okoo_`;o00<bo`801?l02<go_/fnoljZ2?l02Po>og;>L/kocR/4o`06cRK>obK>1?l01QK>5_l6LP?o
00=b5W800ol01W8FL_mb5PCo00Ib5W;oLQH4o`06LQKo5W8F1?l01W8FoaIb5PCo00Ib5_lFLQH4o`L0
000]0003o`0003T00ol02/kUokk>_/koc_D4o`03cPoo00?o00O>9_o>1/h600?o00E6cTKocP02o`06
c_m6cTK>0ol01LiVc_mV00;o00EbE_o>UP04o`03IPoo00_o00>`olh01?l01?3ol?l2O@Go00Dboooa
l003o`07OK1moljUcP08o`099/ko9/hVcRKo008a00Oo3oo>9/hV00;o00P`5S0F<?oUcP?o00DVcRK>
9P02o`04aLk5cP;o00P2_ono0[oo_`?o00YES_nZ<JXaolk50ol04YJoU_m6_onoJol3o`>ookoo_`;o
00H3ojoo0kl9o`0>cVKo_Ljmc_mbQW;ocUH4o`06cVK>olib1?l01/iFc_o>3`Co00C>oon60_l01/ko
cXK>QP?o00J6c_o>Q/h4o`04Q/kocPKo00F6c_o>QP05o`05Q/kocXH01Ol018K>ool70000;P02ocX0
00Soc_G>mOoEcPCo00<[cR/00ol02BK>olh[cR_o9P02o`05LV_o<@l00ol01/iFcUKoAP;o00H?og9V
LVH2o`04Zlj[cP?o00=63dH00ol01/kUc_nVZ`Ko00<Tog801?l01[7ol?lmP0?o00>`ool00ol00o3o
/002o`03OK3o00?o01RZc_nUSZGocW;>L_m[9V/Voc7o3dH?olh2o`07Q_oe__Fnm@03o`0FcPK>ofHV
I_laI_oEc_l[<OnoohHbQP?o00TVof6mHOmZcVX00ol03<jnokl2oeJookn6_`?o00Xboc:ookoo_om6
0_l01C:oole500?o00W<og8FLQKocLh02?l01VIbI_oeLPCo00K>L/kocW84o`05cTK>ob/00ol011Ib
5W84o`055_lFLQH01?l01G8FoaIb00Go00Eb5_lFLP04o`065W8FoaIb1?l01QIb5_lFLP?o1`000300
00?o0000>0001?o>iLh3o`05cPo>olh00_l02Lkoc_G>mOo>9P03o`04Q/j6cP?o00O>E_o>9/hV00;o
00K>9/hVolh2o`043fKoEP;o00c>9/koc_l?YPoo3ol2YPOo00>`ool01?l01?3oool3O@;o00Amool2
0_l00o3o/004o`0>iOo=<LdacOnm<Kgo9/h9o`03aPoo00;o02?>9/hVoaH`5_nVolh6cPK>obKoEVIF
olko9/hVc_l2_`;o0P02o`07<OmESUGo<@02o`0Rc_o=<Ldaokoo_dKoJkoo_`7o0ol3_onookoo_b_o
0ol3o`?=1?l00liVo`03o`07cVKo_LjmcP07o`06cPo>oliV1?l01/i[c_o>LP?o00F6c_o>QP03o`05
Q/j6cXH00ol01XKoQ/j6cP?o00?>Q/h00_l00hKoo`02o`06cXK>olj61?l01/j6c_o>QPCo0P000ol0
00050000<@000ol0000g0009ooGoo`K>olhF00?o00O>A/i6obK>00Co00E6LTKoJ`02o`08LS7o<G8a
oeH2o`05a/ko<@l01?l00dK>AP03o`04<@la3`;o00C6c/K>0ol00j_oo`06o`039?oo00Co00Naoooo
?H0m00;o00>`OOl01Ol2/00>olkUc^GocZ[>Z_n>YHh3o`08L/iboldacC43o`0B<G;oQ/j6cXKomOnV
3jKocPK>0ol0135V<FH2o`0;:c4[<OnVohHboaH00ol00gko_@03o`08:aH[5_o>_/h2o`09_eJookn6
o`8b00?o00<boc800_l02KooA[oo<_lb_`09o`09LPooL/ibc_o>00;o00=bolh00lh00omFLP04o`07
QW;oL_Ebm@03o`041_lFLPCo00HFLQKo5W83o`06LQIb5_lF0_l01W;oLQIb5P?o00HFLQKo5W84o`06
5W8FoaIb1?l60003o`0000D0000b0003o`0003L00ol00`o>o`02o`07mLkeo`K>1P03o`07cV_>Jon6
cP03o`07cUK>E_mFcP03o`03EW9F00?o00aVLVIbo`ooLUIbolh2o`043fKo3`;o00?>A_l01?l01/ko
oo3o/0Ko0_03o`07OOmVogdlO@05o`0I/7coiLkUc^GocC7=okdaoj_ocVK>I/koLP02o`0:__lVcRK>
obK>9P?o00BVZjJ[1?l03EIbofIFI_o>olhVc_l00jH01ol2o`;ocED00ol02G96olhFcQKo<@02o`0A
c_m6_onoJol1_omV0_l3o`<00ol00b^o:`03o`060ol3_ono0_l00j;oo`09o`07Jli[c_o>_@04o`09
c[goUW:FL_o>00;o00<?ofH01?l01/j6c_o>QPCo00K>Q/kocXH3o`06Q/j6c_o>0_l01XKoQ_n6cP?o
00K>Q_n6cXH4o`X000?o00001@0003<000?o0000>@02o`0AcR_o:lh[c_o>og9Fof]bJg800ol01/i6
c_mb<@Co00abEW;oa_mb9W;oY/h3o`04c]K>eP?o00<?I_l00_l01R_>:ol13`?o00Laoonaob@m00Go
00>al?l00ol01c5Voommoc401Ol2/005onG>iLh01?l02/koodH?A_mbcW83o`07c]G>eOlaLP05o`05
:g8[ojH00_l0537oc]K>e/koI_m[YV_o<OnVZjJ[0_l03[lFooo=S/gocW;>oaH[0ol03B/6:`KoE_n6
_olb0_l00[l3o`0B<_oookm6ob^ooc;o<[oo_ono1?l02/g>cOl>cPkoLVH5o`03AW;o00;>2?l0179V
LVH2o`05LQKo5W801?l01QIb5_lFLPCo00HFLQKo5W83o`04LQIb5PCo00Ebog8FLP04o`h000?o0000
1@0003@00_li0008olhVcRKoc_D3o`06cXK>Q_m[0_l01/kocUK>EP?o00I[cV_oJlh3o`04cYK>UP?o
00EbAW;oLP02o`03cPoo00;o00S>:lkoA_l13`Co00O>ooo`ok1]00;o00?`ool00_001on`ofIFIUH0
0_l00c6Uo`04o`04O;3ocP?o00C>oleU0ol00`n[o`04o`07c/Go_/jncP03o`07cPK>1_mbcP03o`08
cV_>JombEW83o`04cVK>IP?o00JVooooUPl4o`03ELgo00Oo00O>E_o>1/h600;o01a[_f_o0Ol2I_m6
_ol3o`?o:koo_b_o0ol3o`>o0_l00`>oo`0;o`06c@o=ohK>1?l01f_>oljmc[d01_l00lj6o`03o`06
cXK>olj61?l01/j6c_o>QPCo00G>Q_n6cP03o`05c_o>Q/h00olB0003o`0000D0000f0003o`0003L0
00?ocR/01?l01W9FL_mbEP?o00IFcUK>olh2o`06Jom[LV]b0ol01LK>a_mb00;o00E[coo?UP04o`09
5_ooL_mbQW:600So00Saoooo/OlT?@;o00c`ooool?lmO?laIS42o`06c_n6Q_ml1_l01bIb9W;ocLh0
1?l02/h6c_o>aLk5omD2o`073oo>1/h6cP03o`07cTKo<G8aLP04o`053g8?of/00_l00mK>o`03o`03
cZKo00;o00QVoooo<G8ao`;=00OoLUIbE_l600;o00S>okn6o`8bo`:o00?o_`801?l01TJoA_l[_`?o
00@boc:o0_l013:ooc82o`03cOGo00_o00T?c_m[LV]bolh00ol0178FLQH3o`065W8FoaIb1?l01QIb
og8FLPCo00DFL_mb5P04o`05LQIbog801?lE0003o`0000@0000g0003o`0003L00_l01XK>Q_nFcPCo
00IVcVKoE/h3o`06cXK>Q_m[0_l01Lh?og9V00?o00A6LTIb0ol00lh?cP03o`05cTK>olh00_l010o>
o`48o`04l?ooK@;o00?`oo000ol01[1m/?mVEP?o00?>E/h00_l02Cc`olibc_n6cP04o`0;Q/j6o`K>
1/koc/D00ol01liFcUKocPH00_l024KocR_>:om[0_l00aK>5P06o`04LVIbo`>60ol00lko9P029P05
obK>9/h01Ol00liFo`03o`0=3b/?okoo_`7o0_noAP05o`07_b_o:koo_`02o`040ol3_`;o00H3_ono
oh02o`0BcLkoolg>cOo=L/goc@o=of_>0ol01Li[ooo>00;o00F6c_o>QP04o`05cXKoQ/h01Ol01Lj6
ohK>00Co00J6cXKoQ/h5oaL000?o0000100003P000?o0000>0000olFLP03o`07LS5b<OlaLP03o`06
LVIbog9[1?l00oG>m@03o`05LVIboll00_l030nV3ol?ob_>:ombaPCo00<Fo`l02Ol01;7oocd2o`03
l?o`00;o00Baog`m0ol01BIb9_n600co00_Ec_lVLRIb9_l6cP04o`0AcW;o3aH?5_l6og:VLZKocTH0
0ol01li6cTKoI_l01<h04_o>o`n63omVo`H?oliVcVKo<@;o00@`oj8F0ol3cPKo00<b0_l00[l08ol2
_ooUoc3oA[oo_b_o<@?o<_lboc;o<_l3<_mROOn5cOmQ00ko00Eb3g;oLP03o`04LQIb5P?o00DFL_mb
5P04o`06LQIbog8F1?l01W8FL_mb5PCo10000ol0000E0003o`0000@0000i00;o>@02o`07cUKoE/iF
cP03o`06cXK>olj60ol03@o>3lkoc_m6LTKocVH01?l00`o>o`02o`049/hVcP?o00<?I_l03Ol2l0Co
00G`ooooO@04o`05cVKocV/01?l04XKoc/g>oldacOlacC7=ohK>QPCo00[>9_mVcVK>oeK>1?l014K>
A/h3o`0>cUKo5/hFolH?a_o>_Lh2o`>600Ko3lH?olh2o`8V0ol4AP06oldacOmb0_l06lkoL/ibc_no
ofKoA[ooc_la9S7o:ol[_onoYP03o`0;0ol3o`?o<[ooP6800_l01/k=of:EHP?o00<`L_l02_l01<j6
ohH3o`05Q_n6cXH00ol01XK>Q_n6cPCo00J6cXKoQ/h4o`T000?o000050000ol000040000>`000ol0
000f0007og8aLS7o<@02o`06L_mb:g8[0ol01/kec_o>i@?o00C6c/K>0ol00g:6LP03o`05<@laob/0
0_l23`?o00AbE_n_2_l00k7`o`03o`0;l?7ook1mo`m63dH00ol00oG>m@04o`0;_/jnoj8FX_oEc]D0
1?l02W8Vog8aLS7ocW84o`06A/e6cOnV0_l03jKo1Pl63om6ofK6I/KocP02o`09LRKo3omV0FH100Ko
00O=c_l`IS1V00Ko00O>3lh?og;e00Co00Bookl20_l0133U<>D2o`0L:koo0c7o0[oo<_lboc;o0c83
ogeRolf5oiEQU@Go00Qn<_laLS7oLP;o00=b5_l00_l01AIb5W8F00?o00HFoaIb5W83o`06LQIbog8F
1?l>0003o`0001<000?o0000100003`000?o0000=P000oo>EP03o`06Q/j6c_o>0_l01@o>olh?00Co
00G>Q/koAP02o`043lko3`;o00K>olhVcRH3o`0:3ooo9Poo3ono:`Co00?eool00ol2l004oggoo`;`
0_l01GdlOOmV00;o00EFonG>i@02o`03<OoE00So00g=ool?J`oocW;>olhV00Co00S>I/koc_G>m@;o
00MFLUIboliF00Go00?63ol00_l01:K>Y/h3o`0?a_oooaKocZ[oULjEc_m600;o00G>oc0V<002o`03
9/ko00?o00?>E/h00_l00km6_`02o`049S4V<@;o01jo:onV_onoI_l3o`?o0olb_c;oHX3oc/goHYER
ok02o`<b2_l01XK>Q_n6cP?o00K>Q/j6ohH2o`06c_o>Q/j60olB0003o`0001<000?o0000100003d0
00?o0000=P02o`06AW96ob]b1?l00lkUo`03o`06AW96odIb1?l00hIbo`02o`063c4?<Ola0_l00`mb
o`03o`033lko00;o00>o[ol00ol00b_oo`04o`07l?mmolkol@03o`0:OOooog9VLVKom@;o00>mc[d0
0_l01/k=c_n=c@;o00D?cPo>3`07o`0:9W;oLQIb5W;oc@;o00K>ojK?Y/l3o`04L/ibcP?o00DFcQKo
9P02o`0?cPoooeHFE_o>Z/jZolg>00?o00K>A/i6ohH5o`05JfKoo`H00_l01HKo0[oo009[00ooiC3o
Jol[_ol3okl2of/00ol02Klbo`<b0ommHP02o`07QOnEHIGoO@02o`05<Whbogd01?l01W8FL_mb5PCo
00Ib5W;oLQH3o`065W8FL_mb0_lF0003o`00018000?o0000100003h00_lh0003ohK>00?o00?>3lh0
0ol01lj6cXKoJlh01?l00lh?o`02o`06cTK>obK>1Ol01LkoEPmF00Ko00>oool01_l01?3oogd2o`04
OK3ocP;o00Ulool?<0oocUH00ol00lkEo`03<@;o00TacC7oOLemof/00ol03V_o<Ldaof_>JlkocVK>
0ol01/h?cPooLP;o00AVL_nF0ol01Poo9/hVcP?o00P?oombE_lFcP;o00?>Z_l00ol01/kec_l6cP?o
00D6cPKoJ`02o`061_oocTK>0_l01dKoJf_o<Ol00fH02_l[ojKoI[oo_f/2o`09_`?o<[lbof:000;o
00O=of:EH_n`00;o00<bool00_l01XK>Q_n6cPCo00J6cXKoQ/h4o`06Q/j6ohK>0olI0003o`000180
00?o00000`00040000?o0000=P02o`0<cR_>o`KoLR]bog9V1?l00`o>3`03o`06LS7oA/i61?l00`n6
o`03o`063oooofK60_l00jnoo`07o`03l?na00;o00Baoo1m0ol01K1moaH?00Co00<aoc400S400oo>
_@0=o`0;LUIbE_o>cLko9W801Ol01^G>iOoecP?o00C>e/kF0ol01/jVcZKo5P;o00_>a_ooa/k6c/Ko
EP04o`07aLkoc^G>i@03o`06c_l6cPK>0_l01lhFcQKoQUH01?l3J`;o00A[IV]V0_l02343okoo_f^o
0_l02klbo`<b0ommH_nR00;o00JEHIGoOK02o`06LQIbog8F1?l01W8FL_mb5PCo00Ib5W;oLQH4oad0
00?o00004@000ol000030000@@000ol0000f0003o`o>00?o00C>Q/j60ol01@o>3oo>00;o00_>oli6
cTKoA_o>3`04o`03cPo>00;o00W>oj/?o`oo:kl02?l01O3ol?n`00;o00>`ool00ol00k3oo`02o`07
cPK>1_oEcP04o`031/h600;o00/acC7=og8VL_o>J`08o`07cPo>3ombcP04o`05cPo>og800_l01/j6
c_nF3`?o00X?UPoo3iKoEW9F0ol02LhFomG>eLkocP02o`07c_oec_Go1P02o`061_l6cPK>0ol01NG>
iOm[00;o00<Fc_l00VH3o`0D_onoI_m[_onookoo_c:o<_mRP683o`0:HYERUOmm/?n6cPCo00J6cXKo
Q/h4o`06Q/kocXK>1?lQ0003o`00014000?o00000`00048000?o0000=P02o`05LTIbog800_l01@o>
og:F00?o00MFcUK>og8a00Ko00FFLYKoEP06o`07a_o6<On__`08o`06l?naogf`0_l0137>odD3o`06
YHjUoc4F1?l01j[>odK>A/h00ol00g:Ro`07o`0;<G8aoc5b<Omb1W801?l01W9VL_l?cP?o00EFLUIb
EP03o`06L/ibolKo0hH4o`09cOooL/ibolG>00?o00M[cV_>olke00;o00K>9/hVoaH2o`055UKocLh0
0ol011IF5UH3o`0IE/ko<Ol2_onoJolaokoo<P<b0ommHWgoA002o`05HIEQok001?l01W8FL_mb5PCo
00Eb5_lFLP05obH000?o000040000ol000030000@`02ocP000?ocXH01?l00`o>o`02o`06A/i6oeK>
1?l02Lkoo`l63ol?cP04o`03cRK>00Ko00<[_ol00_l00o3oo`02o`0Bl?oook1moljZcZ[o_C7o<Kda
0ol02Lh[olG>aLko1P02o`03c_oU00;o00AbcW;o0W801OlVcRK>00So00IbcW;oIW84o`053lh?ohH0
0ol23`03og8[00Co00JFoonV3jH:o`06cR_>obK>1?l01AK>olh600?o00@FcQK>0ol03<keoaK>5_lV
oaK>5P;o00QV_onoJonF_`?o00Zo<[lbof:0H_n`0_l00iERo`02o`06Q/j6ohK>1?l01HK>olj600Co
;0000ol0000?0003o`0000<000150003o`0003H00_l00`o>o`03o`06<G;ocTK>1?l00g8?o`03o`03
cPoo00Co00UZYF[oc_l?QPl00_l01;n_ojl7o`0@l?7oogf`OOlacS7o<4GoY@;o00VFo`Ib1W;oZ/h0
0ol02B_>:lkoiOmb1P06o`0=<Ooo3lh?og8VL_l[LP04o`06cW;>ooEb1Ol00`m[o`03o`03mG;e00?o
00<?ool00ol2cP08olk=c/gocW84o`06<G;oI/iV0ol0;Li6oaIF5_lVob_>:lkoE_o>JlkoE_mV5_l2
of^oo`?omKoo<P<b0ommHWgoA004o`065_lFLQIb0ol01W8FL_mb5P?o<@000ol0000>0003o`0000<0
00160003o`0003L00_l03<iFob_>:lkoc_l?cPCo00<?cPl01?l026JoojEQYF6U0_l02JKoogko_b_o
:`07o`;`0ol01Gf`oj[>00Oo00H[cR_ocR/4o`071/kocPK>1P05o`05LYKoSLd00_l01BH?9PlV00Oo
00JFcYKoIW84o`04IW9VLP?o00G>eLkocP02o`8?0ol02`oookg>_LkocZ[>00?o00O>9_l[cR_>00?o
00m6oaK>5/koc_o>9/koc_D00ol012H[9R/2o`035/hF00;o01][_f_oU_l2_ono<[lb_on0H_n`OOo>
Q/j6ohH00_l01Lj6ohK>00Co=0000ol0000>0003o`0000<000170003o`0003H000SoLS5b<OlaLPKo
00FFLYKocP02o`0GUGkoI[mVojEZYFZUofKoOZEnokn_ojl01?l01O3ooooa00?o00>`ool00_l02/k=
oljUcZGoUW83o`09<LkocTK>A_o>00;o00k>o`lao`o>3oo=_LgocP?o00<aL_l00g800omb1P04o`05
3ld?og800ol01PoocC7=<@?o00?nool00Pl2o`03UW;o00?>00gocOooc_mb<G8aoc5b00;o00La3c4?
oli600?o00@VJbI[0ol09W8aof_>Jon6oaIVof_o_f_o<@?omOnoo`<b0c;oHWeRoj94og8F0ol011Ib
5W83ocT000?o00003@000ol000030000B0000ol0000f0003oliF00Co00T?ooo>3lkocPl00_l01fKo
HYGo_fH00_l04:EQYF7oI[ooOYEnokl[ob/8o`03l?n`00;o00/Vc_o>YLjUoldac@03o`09cPKocZG>
o`K>00?o00HVcRK>obH;o`04cR_>:`Oo0`l00omVLP04o`06cUK>E_o>0_l00lh?o`02o`063oooodK>
1ol01b_>:lkocRH01?l01LhVoli600Co00E[cV_ocP02o`09A_o>E/iFob_o00=60_l05b_>:onookoo
_`;oQ_lb_c:ooh1RP?mm00Co00F6cXKoQP02ocd000?o00003@000ol000020000B@02ocL00ol00g;V
o`03o`033lko00?o00V_JjooUOnoI[l00_l01ZEZYF[o_`;o00QnYGko_joo[`Ko013`oooo/7cocR_>
olk=c_nU0_l02LkoA/i6c_o><@03o`06A/i6obK>0ol03IIbolg>cLko:g8[og800_l01EK>olk=00So
00O>L/iboaH?00Co00Abool?2?l010K>1_l3cP03odK>00Co00HaL_mb<G83o`06cR_>og9F0ol01g:[
LZ_oLS400ol00hH`QP02o`04JdI[AP;o00h3<OnomOnoo`<b0c;oHPCo00Ib5W;oLQH3ocl000?o0000
3@000ol000020000B`000ol0000g00;o00?>3ol00ol05B^o:omV_fKoH_mV_fKoI_mQYF7oIP02o`08
OYEnokoo_b/6o`03l?n`00;o00Em/?o>9P06o`079/hVc_o>1P04o`05E/kocUH01?l01AK>5_l[00_o
00A[3f/?0ol02hK>olk5c/G>og9[00Co00=b3ol01Ol02TG=AOo>L/kocPH8o`0@cXK>olhFc_o>olko
cRK>9P?o00HVcRKocTH4o`0:I/iVodKocTKo:`;o00c>oiJookoo_hJookl4o`06Q/j6ohK>1?m30003
o`0000`000?o00000P0004`000?o0000>002o`03LQKo00;o00Jo[on_Jjl2o`0GI[mVofJoofZUofJo
okooYOn__ono[kl00_l00o7oo`02o`04/?ooO0Co00TaoljEcYGoQ/h01?l01/k=oeIbEP?o00LaL_o>
I/iV00;o00AbEW9F2?l03Lkoo`oo9W8VL_o=c/d01?l00libo`03o`04cW;ocP;o00?=S_l01ol02QK>
ooG>mLkoIW87o`05LVIbolh00_l01/ko<G8aLP?o00IVcVKoL/h3o`03JiI[00;o00BVLZIb0_l01_Fo
o`:o0P;o00Ib5W;oLQH4odP000?o00002`000ol000020000C@000ol0000i00;o00>6cXH00_l01;mV
_fH2o`0G_fJookmVof6Uokoo_fKoUOl[_ono:kl00_l00o3ol002o`0>/7goolhVojG>YOo=<Ld3o`0B
E/koc/G>aOmFodK>olhVc_lF0_l01LiFoliF00;o00K=c/g>old2o`073lh?c_n6cP05o`033lh?00?o
00EbJg;oLP03o`0B5/koolibolg>cOo>mLkeolk=1?l02LhFoeK>E_mFcP03o`069/hVc_lV0_l01/ko
5/hFcP?o00@Vc_m60_l01LhVodK>00?o00H2_onoQ[l2o`03Q/ko00?oC@000ol0000:0003o`000080
001>00;o>P000omb5P03o`04Jjm[[`;o01MV_onoI[ooJZGoI_m[_onUojnookn__`02o`03lOoa00;o
00b`O?o>5/hFoc7>oiD2o`095_laLS5bolk=00?o00MFcUK>og8a00;o00@?<@la0ol01EIbokg>00Ko
00>63ol02?l00hKoo`03o`03L/ko00?o00@FEQIF0_l02/hVc_o=ILgo5/h4o`0:cTKoLS5b<Oo>LP?o
00Ib9W;oJlh3o`06IW9VL_mV0_l01<kocW83o`04JbI[9P?o00=bIW800_l00kl2_`05oe4000?o0000
2P000ol000020000D0000ol0000h00;o00J6cXKoI[l3o`0G_fKoI[mVof7oI[oo_fKoUOl[_ono:kl0
0_l00o3ol003o`05OK3ocRH01ol01/iFc_mFcPCo00IFcUKoA/h4o`04I/koEP;o00AFc_o>1?l01<h6
cPH6o`04cPo>3`Co00C>A_la1Ol015I6olh2o`031_oo00Wo00[>A/kocW;>olhF1?l01LiFofK>00Co
00IVcVKoI/h3o`03:lh[00?o00g>E_o>9/koc_o>9/hV00;o00B6_oooEP000ol000090003o`000080
001A0003o`0003P000?oLQH01?l02W8FL_nookmV_fH2o`0>_onoJkooYOn_ojno[kl2o`03lOoo00?o
00=lool00_l02S7=oc7=<Lgo5Pl3o`06c/g>oliF1?l01W8aL_mbIP;o00AbEW9F0_l01/iVcVKoEP;o
00RFc_oo<6KoIP;o00D]O?mbUP06o`04<5H`EP;o014F:aH[ojG>YOo=ILgo9W8VLP07o`05<G;oL/h0
1?l01W8aL_mbIPCo01Ab9W;oQ_l?<Ol6LPKo9_mVQVKoLP;o00BFokooF@000ol000080003o`000080
001B0003o`0003P00_l01XK>Q_n6cP?o00FoI[mV_`02o`0>I_mV_fKoUOl[ob^o:kl2o`05l?ooog`0
0_l02/iVolG>aLko<Ld4o`05cUKoaLh01?l01VK>I_l[cPCo00C>A_o>0_l01EK>of/?00?o00C>:lko
0ZH01om[ooo>og`01?l0237=oldacOm60_l01BKo1/h600?o00W>cLkocC7=olh00_l02LkocLk=c_o>
IP03o`06:lh[odK>1?l01VK>I_n6cP?o00=6cTH01_l01<i6cTH2o`03cR_>00;oF`000ol000080003
o`000040001C00;o>P000olFLP03o`06LQIbokmV0ol03fJookm[_onUojoo[kn__`02o`03lOmm00;o
00R`OOmb<Olac@Co00HF3aKo<G83o`06LV]bog9V1?l01W9FL_l?m@?o00=VLVH00ol02@K>1_o>of/?
J`02o`03UW;o00;o00YQYOoEc]G>oliU0_l02TIFAUKo:onUogh9o`07YW:VL_o>1P04o`05IW;oL_D0
1?l01W8aL_mbEPCo00Ab5_la0_l028K>olibc_mV0_l01II[olko05d000?o000020000ol000010000
E@000ol0000h00;o00G>Q_n6cP04o`03Q/j600;o00foI[mV_ono:ol[_b^o00Co00Aloon`1ol01S7=
<Om6cPCo00K>oli[cV/3o`079/kocVK>IP03o`0<I/iVoeKo3olFcQK>0ol01jKoo`n6ob/00_l04F:E
HYGo<Ldaoc7oYOlVcRK>00;o00=nUOl00S802oo>_Lkoc/g>odK>00Co00G>L_mVcP04o`07A/kocVK>
IP03o`06cRK>oeK>0_l01<hVcRH6o`04cUK>EP;oG`000ol000070003o`000040001F0003o`0003P0
00?o5W800ol01W8FL_mb5P?o01=[_f^oJono[on__jnook3ol?n`00;o00Yb<Oo=c_lacC7=0ol026Ib
oldVcOmb0_l0237o<G8aL_mb0_l01C3Vog9[00?o00E[<6_o1P02o`08LVKooc6V<JH2o`07m?nUHJEQ
Y@05o`05JV5ZoeH00_l027koOZEnoc9n2_l01TK>A_o>i@?o00Ub9W;oL/ibog800_l01S7o<@la3`?o
00AbI_o>0_l029Ko9/hVc_m[0_mR0003o`0000H000?o00000@0005L000?o0000>002o`06cXK>olj6
0ol01XK>Q_mV_`?o00Vookl[_b^ooo000ol02k3ocUK>E_o5c_la00;o00UbI_o>I/koc[h00ol01VK>
I_lVcP?o00AFLUIb0ol01VK>I_l?J`;o00QVcVKo3jKoQP;o01_>ocgoHYERUF;oEGiEogjUOZGoOZEn
ogjEO_l00S803?mbcW;>og;>L_o>APCo00G>L_mVcP07o`06cV_>Joo>0_l01<kocV/3o`07cR_>:oo>
LP03of@000?o00001P000ol000010000F002ocT000?o5W801?l01AIbog8F00Co00=b5W800_l01kn_
_jnook000ol01K1mog8a00Ko00CVc^K>1ol01VIbI_laLP?o00EbEW;oiP02o`05IW;oLVH01?l0278a
ofKoQUJ60_l02ZIbooodH_mQYF42o`0CEF5EofYQJV7oOZEnogjUO_lbOP02o`03LS7o00Oo00Ha3c7o
c_D3o`0:LRKocW;>L_mb<@?o00=VLVH00ol01S5b<OmbUPCoJ0000ol000050003o`000040001J0003
o`0003L00_l01/j6c_o>QP?o00J6cXKoQ/h3o`07_b^o:kool003o`03/?oo00;o00Rnc_o>QLkoIP;o
00UVokk>_/kocVH01?l01Li6of_>00?o00C>I/iV0ol01Pm[3olVcP?o00NVool?Q_m600;o00HmP?nE
HYD2o`0AEGiEogjUOZGoOZEnYOnEO_l00S803_l3ooo>L/koc/g>obK>1?l02LkocVK>I_mFcP04o`0<
Q/j6oeKoL_mVcVK>0om]0003o`0000@000?o00000@0005/000?o0000=`000olFLP04o`065W8FoaIb
0ol01W8FL_n__`?o00>`ok000_l02W9FL_o=c/gocLh3o`06<G8aoc7=1?l01TIbA_laLP?o00GFc]Ko
LP02o`05Jg;ocVH01?l00g9Vo`02o`03I/ko00;o014booARof6UHOn6of5EHOmQJP02o`0@OZEnYOnU
OZGoO_lb_oo>m@So00Ta3olaLS7oLRH01?l01W;>L_mb9P?o00E[cf_o<@02og4000?o00001001o`40
0@0005`000?o0000=`02o`06cXK>olj61?l01Lj6ohK>00Co00^6cXKo/?ml/?o>IP07o`06cUK>ofK>
0ol01/j6c_o>J`Co00G>I_mbAP03o`04cVK>IP?o00PFcQKoI_l?YP?o02C>okl3ocf0oiERohJoogiE
O_nUO_n6ojEnYOnEOYGo<_l3_`<2o`0:cW;ocLk=c_m6cPOo00IVcVKoI/h4o`05I/koAW800omc0003
o`0000@00Ol10040001M0003o`0003P000?oLQH00ol01QIb5_lFLP?o00Ib5W;oLQH4o`03OOoo00;o
00TVoldacC7o3`H01?l01Lg>oeIb00Co00HFLQKoIW83o`05LUIbog800_l01FK>og8a00Co02UVoli[
of_o_c;om6;oHJGo[hKoHEEQof5Zo`?oYGjUojEnYOmnoc:o<P02o`06cC7=old61?l02EIbonG>iOmb
9P04o`06L/ibog8F0omg0003o`0000<00Ol10040001N00;o>@02o`05Q/kocXH01?l01/j6c_o>QP?o
00>6cXH00_l02Lkookk>__o=<@04o`06Jli[onG>0ol01/i[c_o>:`Co00IFLUKocV/3o`033f_o00?o
00=[cV/00_l00hH?QP02o`0M0kl3_on0oiERohJoogiEO_nUokn6ojEnYOnEOYD00_l01[l3_`?oE0Ko
00Ibc_mFcUH7o`06Q/j6oeK>1?mk0003o`0000800Ol10040001P0003o`0003L000?oLQH00ol01QIb
5_lFLPCo00DFL_mb5P04o`05L_oo9/d00ol01]K>e_mbAPCo00IbEW;oLTH3o`069W8VolkF1?l00dIb
o`02o`05LS5bog800_l099I6olkocolb_c:oof;oHOn6[hKoHEEQof7o<@?oYGjUojEnY@;o01^o<[lb
ok1moljnc_nmc[goE_la3oo5c/GoLTH01?n00005o`000?l00P00064000?o0000=`02o`06Q/j6ohK>
0ol01/j6c_o>QP?o00J6cXKoQ/h3o`06cS7>ofIb0ol01^G>iOm[cPCo00E6c_o>QP04o`0<cV_>olko
Q_o>9/hV0ol00`nVo`02o`0::g;o0kl3_on0?@;o00RoQ[ooOUEnE@;o01>oQ_nUOZEnogjEO_no0kl3
oeB`00[o00?>9/h01on40005o`000?l00P00068000?o0000=`000omb5P04o`05LQKo5W801?l01QIb
5_lFLP?o00Ibol4``C03o`069_o>cLk=0ol01W8VoaIb5P?o00K>ZlkoEW84o`04I/koLP;o00=[L_l0
0_l00liVcP02o`08_c:o<[ooH_@2o`0CQZn6[omEHEGo0c43<OmnYGkoOP03o`06_c:o<_n`1?l02<h6
c_o=mOl?0_n<0004o`00o`80001S00;o>002o`06Q/j6ohK>0ol01/j6c_o>QPCo00O>Q_n6c_o>00;o
00N6c_o>JooU00;o00k>Q_n6cXKoA_m[c_mFLPCo00?>Jlh01Ol02Li[c_nV3ol?QP03o`0@_`>o0koo
P3goQ[n6_hKoE@?o00J6_hJoogh4o`05Q/ko_`<01?l400SoS`000ol0o`020000I@000ol0000f0003
og8F00Co00Eb5_lFLP04o`065W8FoaIb0ol01W;oL_mb5PGo00A6LTIb1_l00eIbEP03o`05:g8[oeH0
0_l02lkoLS5bog;oAZI600?o00Yboono<[lb_omR0_l01:n6[hH3o`065W8Foc430ol01W8FL_mb5P?o
W`001?l00?l10000IP000ol0000f00;o00J6cXKoQ/h3o`06cXK>olj61?l01Lj6ohK>00Co00>6c_l0
0ol04HKoolkocR_>:om[og9Folj600?o00L?QPn6olhF00?o00`?oon63om[ohKo0kl4o`04Q/ko_`;o
00F6c_o>QP04o`05cXKoQ/h01?nS0003o`3o0040001W0003o`0003H000?oLQH01?l01W8FL_mb5P?o
00HFLQKo5W83o`03LQKo00?o00=b5W800_l00aKoo`02o`03LPKo00?o00?6c_l00_l01RIb9_mVcPCo
00=6L_l00_l00li[o`02o`035_oo00;o00Ib5W;oLQH3o`035W;o00?o00DFL_mb5P04ojP00_l10000
J002ocL00_l01XK>Q_n6cPCo00F6c_o>QP04o`03cXKo00;o00J6cXKoQ/h4o`04Q/kocPGo00S>oon6
c_o>J`Go00R6c_o>olj6cP;o00Z6ooooQ/j6ohK>1?l00hK>o`02o`06cXK>olj60on[00?o0@0006X0
00?o0000=P000olFLP03o`06LQIbog8F0ol031Ib5_lFoaIb5_lFLP?o00Ib5W;oLQH3o`065W8FoaIb
0ol01W;ooomb5PCo00EboolFLP04o`055W;oLQH01?l00g8Fo`03o`05LQKo5W801?nZ00Co100006/0
00?o0000=P02o`05cXKoQ/h01?l01HK>olj600Co00?>Q_l00ol01Lj6ohK>00Co00F6c_o>QP04o`05
cXKoQ/h01?l01XK>Q_n6cP?o00K>Q/kocXH3o`03Q/ko00?o00J6cXKoQ/h3ojX01?l80000K0000ol0
000f0003oaIb00?o00Ib5W;oLQH4o`03LQKo00;o00HFLQKo5W83o`06LQIbog8F0ol01QIb5_lFLP?o
00Ib5W;oLQH4o`05LQKo5W801?l00aIbo`02o`06LQIbog8F1?nY00Co300006d00_lg00;o00G>Q_n6
cP04o`03Q/ko00?o00F6c_o>QP04o`05cXKoQ/h01?l01HK>olj600Co00G>Q_n6cP04o`06Q/j6ohK>
0ol00lj6cP03o`05cXKoQ/h01?nZ00?o400006l000?o0000=@000olFLP04o`035W;o00;o00Ib5W;o
LQH3o`065W8FoaIb0ol01W8FL_mb5P?o00HFLQKo5W83o`06LQIbog8F1?l0178FoaH2o`05LQKo5W80
0onZ00Co4`00070000?o0000=@02o`03cXKo00?o00G>Q_n6cP04o`05Q/kocXH01?l01Lj6ohK>00Co
00F6c_o>QP04o`06cXK>olj60ol01XK>Q_n6cP?o00?>Q_l00onY00Co5`00074000?o0000=P02o`06
5W8FoaIb0ol01W8FL_mb5P?o00HFLQKo5W83o`06LQIbog8F0ol01QIb5_lFLPCo00DFL_mb5P04o`03
LQKo00;oZ@04oa/0001b0003o`0003H000?ocXH01?l01Lj6ohK>00Co00F6c_o>QP04o`05cXKoQ/h0
1?l01HK>olj600Co00G>Q_n6cP04o`03Q/ko00?oZ004oal0001c00;o=`02o`065W8FoaIb0ol01W8F
L_mb5P?o00HFLQKo5W83o`06LQIbog8F0ol01QIb5_lFLP?o00=b5_l00onX00Co8`0007D000?o0000
=@000oo>QP04o`05cXKoQ/h01?l01HK>olj600Co00G>Q_n6cP04o`05Q/kocXH01?l00lj6o`02ojP0
1?lW0000MP000ol0000e00;o00HFLQKo5W83o`06LQIbog8F0ol01QIb5_lFLP?o00Ib5W;oLQH3o`03
5W;o00?oZ003ob/0001g0003o`0003D000?ocXH01?l01Lj6ohK>00Co00F6c_o>QP04o`05cXKoQ/h0
1?l00hK>o`02ojP01?l^0000N002ocH00_l01QIb5_lFLP?o00Ib5W;oLQH3o`035W;o00Ko00=b5_l0
0onW00Co<P0007X000?o0000=0000oo>QP04o`05cXKoQ/h01?l00hK>o`02o`06cXK>olj60onW00Co
=P0007/000?o0000=002o`065W8FoaIb0ol00g8Fo`03o`05LQKo5W801?nV00Co>P0007`000?o0000
=@000on6cP03o`03cXKo00;o00J6cXKoQ/h3ojH01?ln0000O@02ocH00_l00g8Fo`02o`065W8FoaIb
0onU00Co@P0007l000?o0000=@02o`05Q/kocXH01?nU00?oAP00080000?o0000=@000omb5P03ojD0
1?m90000P@000ol0000e00;oY004odd0002200;o=0000ol0002P00CoD@0008@000?o0000<@000ol0
002L00CoE@0008D000?o0000<0000ol0002H00CoF@0008H000?o0000;`000ol0002D00CoG@0008L0
00?o0000;P000ol0002A00?oH@0008P00_l^0003o`0008d01?mT0000RP000ol0000[0003o`0008T0
1?mX0000R`000ol0000Z0003o`0008D01?m/0000S0000ol0000Y0003o`0008401?m`0000S@02obT0
00?o0000O@04og@0002?0003o`0002H000?o0000N@04ogP0002@0003o`0002D000?o0000MP03og`0
002A0003o`0002@000?o0000LP04ogl0002B00;o90000ol0001^00CoP`0009@000?o00008@000ol0
001Z00CoQ`0009D000?o000080000ol0001V00CoR`0009H000?o00007`000ol0001R00CoS`0009L0
0_lO0003o`0005h01?nC0000V@000ol0000L0003o`0005/00onG0000VP000ol0000K0003o`0005L0
1?nJ0000V`000ol0000J0003o`0005<01?nN0000W0000ol0000I0003o`0004l01?nR0000W@02oaT0
00?o0000B`04ojH0002O0003o`0001H000?o0000A`04ojX0002P0003o`0001D000?o0000@`04ojh0
002Q0003o`0001@000?o0000@003ok80002R00;o50000ol0000l00Co]@000:@000?o00004@000ol0
000h00Co^@000:D000?o000040000ol0000d00Co_@000:H000?o00003P000ol0000a00Co`@000:L0
0_l>0003o`0002d01?o50000Z@000ol0000;0003o`0002T01?o90000ZP000ol0000:0003o`0002H0
0oo=0000Z`000ol000090003o`0002801?o@0000[002o`T000?o00007P04om@0002^0003o`0000H0
00?o00006P04omP0002_0003o`0000D000?o00005P04om`0002`0003o`0000@000?o00004P04on00
002a0003o`0000<000?o00003P04on@0002b00;o0`000ol0000;00?oj0000;@000Co003o2@04on/0
002e0003o`3o00D01?o_0000]P02o`030?oo00;ol`000;L00_og0000o`2a0000o`2a0000o`2a0000
o`2a0000o`2a0000o`2a0000o`2a0000o`2a0000\
\>"],
   ImageRangeCache->{{{54.0625, 283.438}, {244.25, 58.4375}} -> {-0.282352, \
0.300897, 0.00348562, 0.00348562}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
     \(DensityPlot[
       BFlimited[x, y, 4], {x, \(-32\), 32}, {y, \(-32\),
         32}, {PlotRange \[Rule] All, PlotPoints \[Rule] {64, 64},
         Mesh \[Rule] False}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.015024 0.5 0.015024 [
[.04928 -0.0125 -9 -9 ]
[.04928 -0.0125 9 0 ]
[.19952 -0.0125 -9 -9 ]
[.19952 -0.0125 9 0 ]
[.34976 -0.0125 -9 -9 ]
[.34976 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65024 -0.0125 -6 -9 ]
[.65024 -0.0125 6 0 ]
[.80048 -0.0125 -6 -9 ]
[.80048 -0.0125 6 0 ]
[.95072 -0.0125 -6 -9 ]
[.95072 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04928 -18 -4.5 ]
[-0.0125 .04928 0 4.5 ]
[-0.0125 .19952 -18 -4.5 ]
[-0.0125 .19952 0 4.5 ]
[-0.0125 .34976 -18 -4.5 ]
[-0.0125 .34976 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .65024 -12 -4.5 ]
[-0.0125 .65024 0 4.5 ]
[-0.0125 .80048 -12 -4.5 ]
[-0.0125 .80048 0 4.5 ]
[-0.0125 .95072 -12 -4.5 ]
[-0.0125 .95072 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04928 0 m
.04928 .00625 L
s
[(-30)] .04928 -0.0125 0 1 Mshowa
.19952 0 m
.19952 .00625 L
s
[(-20)] .19952 -0.0125 0 1 Mshowa
.34976 0 m
.34976 .00625 L
s
[(-10)] .34976 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65024 0 m
.65024 .00625 L
s
[(10)] .65024 -0.0125 0 1 Mshowa
.80048 0 m
.80048 .00625 L
s
[(20)] .80048 -0.0125 0 1 Mshowa
.95072 0 m
.95072 .00625 L
s
[(30)] .95072 -0.0125 0 1 Mshowa
.125 Mabswid
.07933 0 m
.07933 .00375 L
s
.10938 0 m
.10938 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.77043 0 m
.77043 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04928 m
.00625 .04928 L
s
[(-30)] -0.0125 .04928 1 0 Mshowa
0 .19952 m
.00625 .19952 L
s
[(-20)] -0.0125 .19952 1 0 Mshowa
0 .34976 m
.00625 .34976 L
s
[(-10)] -0.0125 .34976 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .65024 m
.00625 .65024 L
s
[(10)] -0.0125 .65024 1 0 Mshowa
0 .80048 m
.00625 .80048 L
s
[(20)] -0.0125 .80048 1 0 Mshowa
0 .95072 m
.00625 .95072 L
s
[(30)] -0.0125 .95072 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .10938 m
.00375 .10938 L
s
0 .13942 m
.00375 .13942 L
s
0 .16947 m
.00375 .16947 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .46995 m
.00375 .46995 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .77043 m
.00375 .77043 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .92067 m
.00375 .92067 L
s
0 .01923 m
.00375 .01923 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.04928 .99375 m
.04928 1 L
s
.19952 .99375 m
.19952 1 L
s
.34976 .99375 m
.34976 1 L
s
.5 .99375 m
.5 1 L
s
.65024 .99375 m
.65024 1 L
s
.80048 .99375 m
.80048 1 L
s
.95072 .99375 m
.95072 1 L
s
.125 Mabswid
.07933 .99625 m
.07933 1 L
s
.10938 .99625 m
.10938 1 L
s
.13942 .99625 m
.13942 1 L
s
.16947 .99625 m
.16947 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.31971 .99625 m
.31971 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.46995 .99625 m
.46995 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.62019 .99625 m
.62019 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.77043 .99625 m
.77043 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.92067 .99625 m
.92067 1 L
s
.01923 .99625 m
.01923 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .04928 m
1 .04928 L
s
.99375 .19952 m
1 .19952 L
s
.99375 .34976 m
1 .34976 L
s
.99375 .5 m
1 .5 L
s
.99375 .65024 m
1 .65024 L
s
.99375 .80048 m
1 .80048 L
s
.99375 .95072 m
1 .95072 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .10938 m
1 .10938 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .77043 m
1 .77043 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
818181818181818181818181818181818181818181818181818181818181818181818181
81818181818181818181818181818181818181818181818181818181
81818181818181818181818181818181818181818181818139788E909392949495959494
9293908E818181818181818181818181818181818181818181818181
81818181818181818181818181818181818181818167636038778E909392949494959494
9293908E77385E818181818181818181818181818181818181818181
81818181818181818181818181818181818181686866625F38778E909392949394949393
91938F8E76375E626581818181818181818181818181818181818181
81818181818181818181818181818181816367666666615E38778D909391939394949393
91928F8D75365E606365628181818181818181818181818181818181
81818181818181818181818181818139385F62666565615D36768D8F9291939394939393
90928F8C74365C5E63605E3738818181818181818181818181818181
81818181818181818181818181818E7738385E6164635F5D36758D8F9191929293939292
90918E8B74345A5E5E5C3637768E8181818181818181818181818181
81818181818181818181818193908E8E7737375D5F635E5B35748C8E9190929293939292
90908D8B72325A595A3436758D8D9093818181818181818181818181
8181818181818181818181929293908E8D7636365B5E5E5A34748B8D9190919192929191
8F8F8D89713255553234748C8D8F9391928181818181818181818181
818181818181818181819494929293908D8D7536345A595A32728B8C8F8F919191929090
8E8F8A87712D512D32728B8C8F929191949481818181818181818181
818181818181818181959594949291928F8D8C74333255543270888C8E8E909091918F8F
8D8D89876B29292D71898B8D91909193939394818181818181818181
81818181818181819495949493939191918E8B8B72322D502D7087898E8D8E8F908F8E8F
8B8B89826701296B87898D9090909393939494948181818181818181
8181818181818194949494949493939090918D8A88702C28286B86888C8C8E8E8E8E8D8C
898B837E3F016782878A8F8F8F929293949493939481818181818181
81818181818181929493939494939292908F8F8C88876B28006681878A8A8D8C8D8E8B8A
89867F563F3F7E82898D8D8E91919293939393939281818181818181
81818181818193939193939393939392918F8E8E89868166003E7C8289888A8B8C8B898A
838157557D567D838B8B8D9091919293929393919393818181818181
81818181818E9093939193929293929291908D8D8C88817C3E3E547D848687898A888884
7F59569393557F86898B8F8F909292929292919292908E8181818181
81818181818E8E8F9292909292919291918F8E8C8A8A827C547B53557E8087858688827F
565894AA93568184898C8E8F90919191919092928F8D8D8181818181
8181818138768D8D8F9191909191909190908E8D8988847D53929153567C808384807E56
5596AAA994587F838A8B8D8F909090918F91918E8D8D763881818181
818181815E37758C8C8E90908E908F8F8F8F8E8C8A87817E5490A6905552797D7E7A5355
92ABA9A995567E84898A8D8E8E8F8F8E90908D8C8C75375E81818181
818181625E5E36748B8B8D8F8F8D8F8E8E8E8D8C8987807C5690A5A7914F517475525191
A8A9A9AB93557F83888A8C8C8D8E8D8E8F8C8B8B74365D5E62818181
81818165605C5C347289898A8D8D8B8C8C8B8B8A8885807A5291A5A3A48C4A46474B8EA5
A5A9A9A791557C818788898A8C8A8C8D8A898972345B5C6065818181
81816563635E5A5A32718787898B8B898A89888886847E794F8EA4A2A39D841D1E849EA3
A3A9A7A590537B7F85868889888A8B88878770325A5A5E6363658181
818162605E5E5955552D6C828283868583848382817F79744C879DA09B946E57586F969B
A1A1A0A28B4D767B7F81838284858381826B2D5555595E5E60628181
81815E5E5C5A5A55515129677E7E7F81807E7F7E7C7A757146849996966A6AA9A96B6C96
979D9C9C874971757B7C7D7F807E7D7D67295151555A5A5C5E5E8181
81383737363432322D2929013F5655575958555653514D471E5C6E6A4545839899844746
6C7375735E21484D535356575654553F0128292D3232343637373881
8177767575747271716B67673F7D949394969592919089845D96A98384C1DBD8D9DCC384
84ADAEB29B5D878B8F92959292937D3E67676B707172747575767781
818E8E8D8C8C8B898787827E7D5593AAA9AAABA9A6A59E9A6FA9999ADBEFF1F4F5F2F1DC
9B9DC2C4B1739CA0A6A8A8A8A993557D7D828787898B8C8C8D8D8E81
81908F8F8F8E8D8C8B8988837F7F5694AAA9A9ABA8A3A0976C849BDBF4F3F4F7F8F5F4F4
DC9F9CC1AE759BA1A8A7A7A993557E7E8388898A8C8D8D8E8F8F9081
81939392929190908F8D8B8B8581805895ABAAA9A9A89C964786DCF5F8F7FCF9F9FDF9F7
F6E19E9DAD719FA3A6A8A994578080858A8B8D8F9090919292929381
819291919090908F8E8D8B8988837F7E5593A7A5A5A1996C46C3F1F3F8F9F9F9FAFAFAF8
F5F5DC9B836D999FA2A591537D7E8388898B8D8E8E90909091919281
819493939392929190908E8C8A8A847F7E5490A7A09C736F84DCF3F6FDFAFCFDFDFCFCFD
F8F7F4DA8647949AA38E537D7E83898A8C8E8F8F9192929293939381
8194939393929191908F8E8E8B8988827C7A528B9C7370AD9DDAF4F9FAFAFDFDFDFEFBFB
FAF9F3F2C4446A96874F797B8187888B8D8E8F909191929393939481
819494949493929291908F8F8D8A88867F7B75495E74ADC29DDEF6F8FBFCFEFEFFFFFDFC
FAFBF6F3D9826B584673797E85888A8C8E8F90919292939494949481
81949494939393929191908E8D8C8885847A7149209BC4C09CE1F6F7FDFBFDFFFFFFFDFD
F8FBF9F2D7999319466F788384878B8C8D8F90919292939394949481
819493939292929191908E8D8C8A88857F7A4D488573ADC19DDCF5F9FAFBFDFDFEFEFDFB
FAFAF4F2D8816A7F454A797D8587898C8D8E8F909192929293939481
8194939393929191918F8E8E8B8988837C53528B9C9B70AD9BDAF4F9FCFAFDFCFDFEFCFD
FAF9F3F1C4449296884F517B8288888B8D8E8F909191929393939481
819291919190908F8E8D8D8A8888827E55528FA59E9B996C83DAF1F4FBF9F9FBFCFAFBFB
F7F5F3D8836D9298A28C51537D8187888A8C8D8E8F90909191919281
81939392929291908F8F8C8B8A8580575794A8A6A6A3999547C4F2F5F9FAFCFAFBFCFCFA
F6F8DD9DAC6D9AA0A3A69355567F84898A8C8E8F9091919292939381
8190908F8F8E8D8C8C8A8888837E565592A9A7A7A6A39A946C83D9F2F4F4F9F7F8FAF6F4
F3DE9CC1AB6E9BA0A3A5A79154557D8288888A8C8C8D8E8F8F909081
818E8D8D8D8C8B8B898787827D555493A9A7A8A9A5A29F966AA999D8F2F1F3F7F8F3F3F3
DA9DC2C0AD73999EA6A6A6A79253557D818687898B8B8C8D8D8D8E81
818177767574747270706B673F3E7D93929394928F8E87845893A983C4D8DBDDDEDCDAC5
84ADABAD9B5C85898F919191927C3E3E666B70707274747576778181
8181383736363432322D2901003F55555558555353514A461E576A6C45849D9A9B9D8646
6D6F70745D20484D5052565454543E0000282D323234363637388181
81815E5E5D5C5A5A55512929677D7D7E807E7D7E7B79756F45849692966DABC0C0AB6F96
939A9C9A864971747A7A7C7F7D7C7D66282850555A5A5B5D5E5E8181
81818162605E5E59552D2D6B8281838583828382807E79744A889D9B9A966EADAD6F979A
9CA1A0A08B4E757A7F808182848281816B2C2D55595E5E6061818181
8181816563635E5A3232708787888B898889888786847D79518CA3A5A0999B5C5D9B9AA0
A6A8A5A790527B7F84858887888A8886877032325A5E636365818181
8181818165605C34347289898A8D8B8A8C8B8A8A8785807B5291A6A3A49E85464786A0A5
A5AAA9A792547C818688898A8A8A8C8A88897233345B606481818181
81818181625E3636748B8B8C8F8D8D8E8D8D8D8C8987827C5593A7A5A68E4C70714D90A7
A6ABACAA93567E82888A8C8C8D8C8D8E8C8A8B7436365D6181818181
81818181813737758C8C8D908E8E8F8F8E8E8D8C8A88817E5691A6A791507974757A5292
A9ABAAAC95557F83898B8D8E8E8F8E8E908D8C8C7536378181818181
818181818138768D8D8F91908F91909090908E8D8B88847F5591A792567A7A7E7F7B7C56
94ACAAAA96587F858A8B8E8F9090908F8F918E8D8D76378181818181
8181818181818E8D8F92909092919191918F8E8E8A8A847D539292547E7C808484817E7F
5596ABA9945981838A8C8E8F909191919090928F8D8D818181818181
8181818181818190939191939292929291908F8D8C8A827C557C547D7F8187858688837F
7E5994AA93578185898C8E8F91919292929191929081818181818181
8181818181818193919193939293939191908E8E8C88817D3E3E7C7E848788898A898884
7F80579494557F868B8B8F9090929293929391919381818181818181
81818181818181819293939394939292918F8F8F8A87816600667D828A888A8C8D8B8A8A
83817F567D567E838B8D8D9091919393939393928181818181818181
818181818181818181949394949392929091908C88876B28286781888A8A8D8D8E8E8C8A
89867F7E3F3F7E82898D8F8F91929293949493818181818181818181
8181818181818181818194949393939191918D8B89702D50286B87888C8C8E8E8F8F8E8C
8A8B837E67016782878B8F9090929293949481818181818181818181
81818181818181818181819493939192928E8C8B723254502D70878A8E8D8F8F908F8F8F
8B8B89826729296C87898D9091909393938181818181818181818181
818181818181818181818181949293928F8D8C74345A55553270888C8F8E909091918F90
8D8D89876C29512D71898B8E91929193818181818181818181818181
818181818181818181818181818193908D8D75365B5A595A32728B8D908F919191929190
8E8F8B87712D515532728B8C8F928181818181818181818181818181
8181818181818181818181818181818E8D76365D5C5E5E5A34748B8D9190919292929191
8F908D89713255555A34748C8D818181818181818181818181818181
8181818181818181818181818181818181385E5D60635E5B36758C8E9190929293939292
90908E8B72325A595A5C368181818181818181818181818181818181
81818181818181818181818181818181818181616563605D36758D8F9291939393939292
90918E8C74345A5E5E81818181818181818181818181818181818181
81818181818181818181818181818181818181818165615E37768D8F9291939394949393
91928F8C75365C818181818181818181818181818181818181818181
81818181818181818181818181818181818181818181818138778D909392939394949393
91928F8D818181818181818181818181818181818181818181818181
818181818181818181818181818181818181818181818181818181818181818181818181
81818181818181818181818181818181818181818181818181818181
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 288},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0/@000?l0/@000?l0/@000?l0/@000?l0
/@000?l0/@000?l0/@000?l0/@000?l0/@000?l0/@000?l0/@00030000JnZ?ooKNH400049VSo1Bh0
1_l400049VSo1Bh01?l00fP0000200049VSo1Bl000@VJ?l5=004o`03J000008000@VJ?l5;P06o`@0
00@VJ?l5;P001[jXoom]iP@000@VJ?l53`00030000IX_P001O<30006I_?ViZRn;@000iGoIP020006
J00006Kc0^H00jRn000^0003o`0000<000IVlnKVZ;h]0006I_?ViZRn=@000ol000030006I_?ViZRn
;@000iGoIP020006J00006Kc0^H00jRn000/0006J;h000Gc0`001VKci^JX_Ph0000e0006o`0002Vn
0P000kkc000]0003UOmV00D000HY_P00__<_0003o`0000<000HY_P00__<]0006:Kh00;kc=@000ol0
00030006:Kh00;kc;P000iGoIP050006:Kh00;kc<P001_l0000Y_P8000>nl`003@0002L01ol60003
1JP0008000?o00000P000ol0000R00Oo10000kiXIP040003o`00008000?o00008@07o`D000?o0000
0`000ol000020003o`0002/000?o00000P000ol0000c0003o`0000<000?o00000P000ol0000]0003
_VQV00@000?o00000P000ol0000_00031JP0008000?o00000P000ol0000<0000<P001:SoobH30003
o`00008000?o0000;P000fIXIP030003o`00008000?o0000;@000ol000030003o`00008000?o0000
:`000ol000020003o`0003<000?o00000`000ol000020003o`0002h000=VJ6H00`000ol000020003
o`0002d000BXoolV0`000ol000020003o`0000`0000c0003iPGc00<000?o00000P000ol0000_0003
__<0008000?o00000P000ol0000]0003o`0000<000?o00000P000ol0000[0003o`00008000?o0000
<`000ol000030003o`00008000?o0000;`000kkc00020003o`00008000?o0000;P000nH5l`030003
o`00008000?o0000300003D000Ko0000:Kh20003_RT0034000Ko0000:Kh20003_RT002h000?o0000
0`001RVn002n:Bd000HY_P00_RTe0003o`0000<000HY_P00_RTb0006o`0002Vn0P000khY000a0006
o`0002Vn0P000khY000=0000<0001ZQE0021l`<000IVlnKVlfH]0006oeGV00Gc0`001VKci^KcIRd0
00?o:Ol01@001VKci^KcIRd000IVlnKVlfHc0003obWo00D000IVlnKVlfH]0006oeGV00Gc0`001VKc
i^KcIRd000JXE@00PO<30006I_?Vi_=V3P00030000HV:Ooo:NH400049VQXIRh000JnloooKNH40004
9VQXIRh000=VKOl01P0012IXJ6H_00049VQXIS@000=VKOl01P0012IXJ6H^0006__?oofgV100012IX
J6H^00069RWoobWV100012IXJ6H?0000o`2a0000o`2a0000o`2a0000o`2a0000o`2a0000o`2a0000
7`3ooi7o0@0001l000?o00001@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00001001o`40000O0003o`000140
00?o0000>@000ol0000i0003o`0003T000?o0000>@000ol0000i0003o`0003T000?o00004001o`40
000O0003o`000?l0S@01o`40000O0003o`000?l0S@01o`40000O0003o`000?l0S@01o`40000O0003
o`000?l0S@01o`40000O00?oo`2<00;o0@0001l000?o00001@3o:X8Z1P01o`40000O0003o`0000D0
obZ2:PH00Ol100007`000ol000050?lZPRX6007o0@0001l000?o00001@3o:X8Z1P01o`40000O0003
o`0000D0obZ2:PH00Ol100007`000ol000050?lZPRX6007o0@0001l000?o00001@2@:PHD1QD6IA9Z
98DBJPIUTBX6007o0@0001l000?o00001@2@:PHD1QD6IA9Z98DBJPIUTBX6007o0@0001l000?o0000
1@2@:PHD1QD6IA9Z98DBJPIUTBX6007o0@0000X000JnZ?ooKNH400049VSo1@L000?o00001@2@:PHD
1QD6IA9Z98DBJPIUTBX6007o0@0000X000IX_P001O<30006I_?ViZRn1P000ol00005090Z1Q@65@IU
4VXTQA9Z1VFA:PH00Ol100003`001_l0000Y_P8000>nl`001@04o`@0T2X650HE1VDBJRB54VX6II4Z
1003o`4000000`3oo`05o`H000<5Z0000P000ol000020003o`0000@000?o00001@1n:PJ13;@610H5
1VDBJRB54VX6I@H51P@6Y7lZ1P01o`40000<0004Z?oo9P<000?o00000P000ol000040003o`0000D0
ORX6P@bd1P@61@IU4VXTQA9Z1VD61@H41ZAo:PH00Ol100003@000nH5l`030003o`00008000?o0000
10000ol0000507hZ1X4<]0H41PD6IA9Z98DBJPIU1PD610JTObX6007o0@0000l000Ko0000:Kh20003
_RT000D000?o00001@1n:PJ13;@610H51VDBJRB54VX6I@H51P@6Y7lZ1P01o`40000:0006Z5D0087c
0`001VKci^KcIPH000?o00001@1n:PJ13;@610H51VDBJRB54VX6I@H51P@6Y7lZ1P01o`40000:0006
9RWoobWV100012IXJ6H70003o`0000D0ORX6P@bd1P@61@IU4VXTQA9Z1VD61@H41ZAo:PH00Ol10000
7`000ol00005078Z3=@6P@Jd1Z@610H51VDBJPJ51VX<QAQZ36D61@H41Z@6]0J1LbX6007o0@0001l0
00?o00001@1b:PcD1X46]0JT1P@61@IU4VX6Q@IZ38DHJPaU1PD610JT1[@6PG<Z1P01o`40000O0003
o`0000D0LRX<e0J11[@6Y0H41PD6IA9Z1XD6JPb566X<I@H51P@6Y0Jd1X5c:PH00Ol100007`000ol0
0005078Z3=@6P@Jd1Z@610H51VDBJPJ51VX<QAQZ36D61@H41Z@6]0J1LbX6007o0@0001l000?o0000
1@1b:PcD1X46]0JT1P@61@IU4VX6Q@IZ38DHJPaU1PD610JT1[@6PG<Z1P01o`40000O00?o1@1b:PcD
1X46]0JT1P@61@IU4VX6Q@IZ38DHJPaU1PD610JT1[@6PG<Z1@02o`40000O0003o`0000D0IRX6]1R1
1[@6Y0H41PD6IAiZ38DHJPaU1PD610JT3;@6P@JdIbX6007o0@0001l000?o00001@1V:PJd6846]0JT
1P@61@IU7VX<QAQZ36D61@H41Z@<]0J11[AW:PH00Ol100007`000ol0000506HZ1[@HP@Jd1Z@610H5
1VDNJPb566X<I@H51P@6Y0bd1X46]6LZ1P01o`40000O0003o`0000D0IRX6]1R11[@6Y0H41PD6IAiZ
38DHJPaU1PD610JT3;@6P@JdIbX6007o0@0001l000?o00001@1V:PJd6846]0JT1P@61@IU7VX<QAQZ
36D61@H41Z@<]0J11[AW:PH00Ol100007`000ol0000506HZ1[@HP@Jd1Z@610H51VDNJPb566X<I@H5
1P@6Y0bd1X46]6LZ1P01o`40000O0003o`0000D0FRX650H41Z@6]1:11[@6Y0H41PD<IAQZ1XDNJPaU
1PD610JD1Z@<]0JT3@AJ:PH00Ol100007`000ol0000505XZ1Q@610JT1[@BP@Jd1Z@610H536DHJPJ5
7VX<I@H51P@6U0JT3;@6Y0d4FRX6007o0@0001l000?o00001@1J:PHD1P@6Y0Jd4X46]0JT1P@61@aU
66X6QAiZ36D61@H41Y@6Y0bd1Z@=15XZ1P01o`40000O0003o`0000D0FRX650H41Z@6]1:11[@6Y0H4
1PD<IAQZ1XDNJPaU1PD610JD1Z@<]0JT3@AJ:PH00Ol100007`000ol0000505XZ1Q@610JT1[@BP@Jd
1Z@610H536DHJPJ57VX<I@H51P@6U0JT3;@6Y0d4FRX6007o0@0001l00ol505XZ1Q@610JT1[@BP@Jd
1Z@610H536DHJPJ57VX<I@H51P@6U0JT3;@6Y0d4FRX500;o0@0001l000?o00001@1D:PIU1PD<10JT
4[@<Y0H41PD<ICaZ1VD6E@H51_<6U0bT1Y@=10H51VED:PH00Ol100007`000ol0000505@Z1VD61@`4
1Z@B]0bT1P@61@aU?6X6I@IE1PD6l`JD3:@6U0d41PD6IE@Z1P01o`40000O0003o`0000D0E2X6I@H5
30@6Y1:d3:@610H536DlJPIU1UD61@Kc1Y@<Y0JD3@@61@IUE2X6007o0@0001l000?o00001@1D:PIU
1PD<10JT4[@<Y0H41PD<ICaZ1VD6E@H51_<6U0bT1Y@=10H51VED:PH00Ol100007`000ol0000505@Z
1VD61@`41Z@B]0bT1P@61@aU?6X6I@IE1PD6l`JD3:@6U0d41PD6IE@Z1P01o`40000O0003o`0000D0
E2X6I@H530@6Y1:d3:@610H536DlJPIU1UD61@Kc1Y@<Y0JD3@@61@IUE2X6007o0@0001l000?o0000
1@18:PaZ36D61@`43:@6]0JT1Y@610H536DlJPIU1UD6m0Kc4Y@6l`H41`D<I@aZB2X6007o0@0001l0
00?o00001@18:PaZ36D61@`43:@6]0JT1Y@610H536DlJPIU1UD6m0Kc4Y@6l`H41`D<I@aZB2X6007o
0@0001l000?o00001@18:PaZ36D61@`43:@6]0JT1Y@610H536DlJPIU1UD6m0Kc4Y@6l`H41`D<I@aZ
B2X6007o0@0001l000?o00001@18:PaZ36D61@`43:@6]0JT1Y@610H536DlJPIU1UD6m0Kc4Y@6l`H4
1`D<I@aZB2X6007o0@0001l000?o00001@18:PaZ36D61@`43:@6]0JT1Y@610H536DlJPIU1UD6m0Kc
4Y@6l`H41`D<I@aZB2X6007o0@0001l00ol504PZ36X<I@H530@<Y0Jd1Z@6U0H41PD<ICaZ1VD6E@Kd
1_<BU0Kc1P@71@aU36Y8:PD00_l100007`000ol00005048Z66X<I@H530@6U0bT1Y@6l`H51UD6IC1Z
4VD6E@Kd1_<<K@cc1PDCIA9Z@RX6007o0@0001l000?o00001@12:QQZ36D61@`41Y@<Y0JD1_<61@IE
1VD`JQ9U1UD6m0Kc36d<l`H54fDBJT8Z1P01o`40000O0003o`0000D0@RXHJPaU1PD<10JD3:@6U0Kc
1PD6E@IU<6XBI@IE1_@6l`a]3?<61A=U4VY2:PH00Ol100007`000ol00005048Z66X<I@H530@6U0bT
1Y@6l`H51UD6IC1Z4VD6E@Kd1_<<K@cc1PDCIA9Z@RX6007o0@0001l000?o00001@12:QQZ36D61@`4
1Y@<Y0JD1_<61@IE1VD`JQ9U1UD6m0Kc36d<l`H54fDBJT8Z1P01o`40000O0003o`0000D0@RXHJPaU
1PD<10JD3:@6U0Kc1PD6E@IU<6XBI@IE1_@6l`a]3?<61A=U4VY2:PH00Ol100007`000ol0000503`Z
38DHJPaU1PD610Kc4Y@6l`Kd1UDBIBAZ36D6E@I51_@6d`IY1]<6l`Kd1UD=IA9Z38Dl:PH00Ol10000
7`000ol0000503`Z38DHJPaU1PD610Kc4Y@6l`Kd1UDBIBAZ36D6E@I51_@6d`IY1]<6l`Kd1UD=IA9Z
38Dl:PH00Ol100007`000ol0000503`Z38DHJPaU1PD610Kc4Y@6l`Kd1UDBIBAZ36D6E@I51_@6d`IY
1]<6l`Kd1UD=IA9Z38Dl:PH00Ol100007`000ol0000503`Z38DHJPaU1PD610Kc4Y@6l`Kd1UDBIBAZ
36D6E@I51_@6d`IY1]<6l`Kd1UD=IA9Z38Dl:PH00Ol100007`000ol0000503`Z38DHJPaU1PD610Kc
4Y@6l`Kd1UDBIBAZ36D6E@I51_@6d`IY1]<6l`Kd1UD=IA9Z38Dl:PH00Ol100007`03o`D0?2X<QAQZ
36D61@H41_<BU0Kc1_@6EA9U96X<I@IE1TD6m0KC1VT6d`Kc1_@6E@eU4VX<QC`Z1@02o`40000O0003
o`0000D0=RXHQA9Z4VD61@cc36d6l`Kd1UDBIAQZ66D6E@I51]@<``KC1_@<E@MU96X6QCHZ1P01o`40
000O0003o`0000D0=RXHQA9Z4VD61@cc36d6l`Kd1UDBIAQZ66D6E@I51]@<``KC1_@<E@MU96X6QCHZ
1P01o`40000O0003o`0000D0=RXHQA9Z4VD61@cc36d6l`Kd1UDBIAQZ66D6E@I51]@<``KC1_@<E@MU
96X6QCHZ1P01o`40000O0003o`0000D0=RXHQA9Z4VD61@cc36d6l`Kd1UDBIAQZ66D6E@I51]@<``KC
1_@<E@MU96X6QCHZ1P01o`40000O0003o`0000D0=RXHQA9Z4VD61@cc36d6l`Kd1UDBIAQZ66D6E@I5
1]@<``KC1_@<E@MU96X6QCHZ1P01o`40000O0003o`0000D0=RXHQA9Z4VD61@cc36d6l`Kd1UDBIAQZ
66D6E@I51]@<``KC1_@<E@MU96X6QCHZ1P01o`40000O0003o`0000D0<2XHQAiZ1VD<E@Kd1_<6d`IY
1]<6m0I51UDHI@IZ4VDBE@HZ1X46o`K31]@6A@IE1VDUJQ:5<2X6007o0@0001l000?o00001@0`:QR5
7VX6I@aE1_@6l`KC1VT6d`Kd1TD6EAQU1VXBIA9E1RX6P@Ko1/<6e0I51UD6IBEZ4XD`:PH00Ol10000
7`000ol00005030Z68DNJPIU35D6m0Kc1]<6J@KC1_@6A@IE66D6JQ9U4UD6:PJ11_l6``KD1TD6E@IU
9FXBQC0Z1P01o`40000:00Ko100012IXo`D70003o`0000D0<2XHQAiZ1VD<E@Kd1_<6d`IY1]<6m0I5
1UDHI@IZ4VDBE@HZ1X46o`K31]@6A@IE1VDUJQ:5<2X6007o0@0000X000>EofH00P001VP0001Vl`;V
00>X_P001@000ol00005030Z68DNJPIU35D6m0Kc1]<6J@KC1_@6A@IE66D6JQ9U4UD6:PJ11_l6``KD
1TD6E@IU9FXBQC0Z1P01o`40000;0003UOmV00D000HY_P00__<600Co100`:QR57VX6I@aE1_@6l`KC
1VT6d`Kd1TD6EAQU1VXBIA9E1RX6P@Ko1/<6e0I51UD6IBEZ4XD`:P@00ol1000000<0ool01Ol40003
_VQV00@000?o00000P000ol000040003o`0000D0:RXTQAiZ1VD<E@Kd1]<<``KD1TD6EC1U35D6:PHU
1R@6o`J11RX6A@IE4fDBJPb536X6QBXZ1P01o`40000=0003IVQV00<000?o00000P000ol000040003
o`0000D0:RXTQAiZ1VD<E@Kd1]<<``KD1TD6EC1U35D6:PHU1R@6o`J11RX6A@IE4fDBJPb536X6QBXZ
1P01o`40000>0003__<0008000?o00000P000ol000040003o`0000D0:RXTQAiZ1VD<E@Kd1]<<``KD
1TD6EC1U35D6:PHU1R@6o`J11RX6A@IE4fDBJPb536X6QBXZ1P01o`40000?0006o`0002Vn0P000khY
00050003o`0000D0:RXTQAiZ1VD<E@Kd1]<<``KD1TD6EC1U35D6:PHU1R@6o`J11RX6A@IE4fDBJPb5
36X6QBXZ1P01o`40000:0006oeGV00Gc0`001VKci^KcIPH000?o00001@0Z:RB57VX6I@aE1_@6d`c3
1]@6A@IE<6D<E@HZ1RD690Ko1X46:PI51UDCIA9Z38D<JPJ5:RX6007o0@0000X000JnloooKNH40004
9VQXIPL000?o00001@0Z:RB57VX6I@aE1_@6d`c31]@6A@IE<6D<E@HZ1RD690Ko1X46:PI51UDCIA9Z
38D<JPJ5:RX6007o0@0001l000?o00001@0Z:PIZ1XD<JPb566XBI@IE1TD6e0K31_l6P@HZ1TD<EAQU
4UD6A@HU1X@<90HU1RX6EA=U=VXZ:PH00Ol100007`000ol0000502XZ1VX6Q@aZ38DHJQ9U1UD6A@KD
1/<6o`J11RX6A@aE66DBE@I51RD6Q0`T1RD6:PIE4fDfJRXZ1P01o`40000O0003o`0000D0:RX6JPJ5
36X<QAQZ4VD6E@I51]@6``Ko1X46:PI535DHIA9E1TD69@J432@69@HZ1UDCICIZ:RX6007o0@0001l0
00?o00001@0Z:PIZ1XD<JPb566XBI@IE1TD6e0K31_l6P@HZ1TD<EAQU4UD6A@HU1X@<90HU1RX6EA=U
=VXZ:PH00Ol100007`000ol0000502XZ1VX6Q@aZ38DHJQ9U1UD6A@KD1/<6o`J11RX6A@aE66DBE@I5
1RD6Q0`T1RD6:PIE4fDfJRXZ1P01o`40000O00?o1@0Z:PIZ1XD<JPb566XBI@IE1TD6e0K31_l6P@HZ
1TD<EAQU4UD6A@HU1X@<90HU1RX6EA=U=VXZ:PD00_l100007`000ol0000502@Z@VXBI@IE1TD6:PJ1
1_l690HU1RXHE@IU4UD<:PJ41Vd69@J41RD6:PaE1VE3JR@Z1P01o`40000O0003o`0000D092Y2JQ9U
1UD6A@HZ1X46o`HT1RD6:QQE1VDBE@`Z1X@6K@HU1X@69@HZ35D6ID=Z92X6007o0@0001l000?o0000
1@0T:T9Z4VD6E@I51RX6P@Ko1R@69@HZ65D6IA9E32X6Q0I]1RD6Q0HU1RX<E@IU@fXT:PH00Ol10000
7`000ol0000502@Z@VXBI@IE1TD6:PJ11_l690HU1RXHE@IU4UD<:PJ41Vd69@J41RD6:PaE1VE3JR@Z
1P01o`40000O0003o`0000D092Y2JQ9U1UD6A@HZ1X46o`HT1RD6:QQE1VDBE@`Z1X@6K@HU1X@69@HZ
35D6ID=Z92X6007o0@0001l000?o00001@0T:T9Z4VD6E@I51RX6P@Ko1R@69@HZ65D6IA9E32X6Q0I]
1RD6Q0HU1RX<E@IU@fXT:PH00Ol100007`000ol0000501hZ1VE8JQ9U1UD6:PHU32@6K@HU4TDHE@I5
1RD6U0J436X6K@HU1TD<E@eU?6X6IAhZ1P01o`40000O0003o`0000D07RX6IDQZ4VD6E@HZ1RD<90I]
1RDBAAQE1TD69@JD1X@<JPI]1RD6A@aE3FDlJPIU7RX6007o0@0001l000?o00001@0N:PIUB6XBI@IE
1RX69@`T1Vd69A9565D6A@HU1Y@6Q0aZ1Vd69@I535D=ICaZ1VDN:PH00Ol100007`000ol0000501hZ
1VE8JQ9U1UD6:PHU32@6K@HU4TDHE@I51RD6U0J436X6K@HU1TD<E@eU?6X6IAhZ1P01o`40000O0003
o`0000D07RX6IDQZ4VD6E@HZ1RD<90I]1RDBAAQE1TD69@JD1X@<JPI]1RD6A@aE3FDlJPIU7RX6007o
0@0001l00ol501hZ1VE8JQ9U1UD6:PHU32@6K@HU4TDHE@I51RD6U0J436X6K@HU1TD<E@eU?6X6IAhZ
1@02o`40000O0003o`0000D07RXBICIZ4VD<E@HZ1RD6K@HE1VT6K@HU1RXBA@IE1RX69@b41XD6_PIZ
1X@6:PI51UDCIC1Z4VDN:PH00Ol100007`000ol0000501hZ4VDfJQ9U35D6:PHU1Vd65@IY1Vd69@HZ
4TD6E@HZ1RD<Q0J51[h6JPJ41RX6A@IE4fD`JQ9U7RX6007o0@0001l000?o00001@0N:Q9U=VXBI@aE
1RX69@I]1QD6J@I]1RD6:Q951UD6:PHU38@6Q@Jn1VX6Q0HZ1TD6EA=U<6XBIAhZ1P01o`40000O0003
o`0000D07RXBICIZ4VD<E@HZ1RD6K@HE1VT6K@HU1RXBA@IE1RX69@b41XD6_PIZ1X@6:PI51UDCIC1Z
4VDN:PH00Ol100007`000ol0000501hZ4VDfJQ9U35D6:PHU1Vd65@IY1Vd69@HZ4TD6E@HZ1RD<Q0J5
1[h6JPJ41RX6A@IE4fD`JQ9U7RX6007o0@0001l000?o00001@0N:Q9U=VXBI@aE1RX69@I]1QD6J@I]
1RD6:Q951UD6:PHU38@6Q@Jn1VX6Q0HZ1TD6EA=U<6XBIAhZ1P01o`40000O0003o`0000D062X610H5
4VDfJPaU35D6A@HU1VT<JPIY1X@69@`Z1TD6:PHU1X@6K@J51[h6e@J51X@69@HZ35D=IAQZ1VD<JQ9U
1PD611PZ1P01o`40000O0003o`0000D062X610H54VDfJPaU35D6A@HU1VT<JPIY1X@69@`Z1TD6:PHU
1X@6K@J51[h6e@J51X@69@HZ35D=IAQZ1VD<JQ9U1PD611PZ1P01o`40000O0003o`0000D062X610H5
4VDfJPaU35D6A@HU1VT<JPIY1X@69@`Z1TD6:PHU1X@6K@J51[h6e@J51X@69@HZ35D=IAQZ1VD<JQ9U
1PD611PZ1P01o`40000O0003o`0000D062X610H54VDfJPaU35D6A@HU1VT<JPIY1X@69@`Z1TD6:PHU
1X@6K@J51[h6e@J51X@69@HZ35D=IAQZ1VD<JQ9U1PD611PZ1P01o`40000O0003o`0000D062X610H5
4VDfJPaU35D6A@HU1VT<JPIY1X@69@`Z1TD6:PHU1X@6K@J51[h6e@J51X@69@HZ35D=IAQZ1VD<JQ9U
1PD611PZ1P01o`40000O00?o1@0H:PH41PDBICIZ36D<E@I51RD6J@aZ1VT6Q0HU32X6A@HZ1RD6Q0I]
1XD6_PKE1XD6Q0HU1RX<E@eU66X6I@aZ4VD61@H462X500;o0@0001l000?o00001@0H:PJT1P@61A9U
36X6I@IZ96D6E@I51RX69@I]1VX6a@IZ1Vd6J@HE32D65@IY1Vd6JPJn3=D6Q@J41RD6A@aE9FD<JQ9U
1PD610JT62X6007o0@0001l000?o00001@0H:PJT1P@61A9U36X6I@IZ96D6E@I51RX69@I]1VX6a@IZ
1Vd6J@HE32D65@IY1Vd6JPJn3=D6Q@J41RD6A@aE9FD<JQ9U1PD610JT62X6007o0@0001l000?o0000
1@0H:PJT1P@61A9U36X6I@IZ96D6E@I51RX69@I]1VX6a@IZ1Vd6J@HE32D65@IY1Vd6JPJn3=D6Q@J4
1RD6A@aE9FD<JQ9U1PD610JT62X6007o0@0001l000?o00001@0H:PJT1P@61A9U36X6I@IZ96D6E@I5
1RX69@I]1VX6a@IZ1Vd6J@HE32D65@IY1Vd6JPJn3=D6Q@J41RD6A@aE9FD<JQ9U1PD610JT62X6007o
0@0001l000?o00001@0H:PJT1P@61A9U36X6I@IZ96D6E@I51RX69@I]1VX6a@IZ1Vd6J@HE32D65@IY
1Vd6JPJn3=D6Q@J41RD6A@aE9FD<JQ9U1PD610JT62X6007o0@0001l000?o00001@0H:PJT1P@61A9U
36X6I@IZ96D6E@I51RX69@I]1VX6a@IZ1Vd6J@HE32D65@IY1Vd6JPJn3=D6Q@J41RD6A@aE9FD<JQ9U
1PD610JT62X6007o0@0001l000?o00001@0B:PJd3:@610H535DlI@IE1TD6:PHU1X@6JPK51]D6JPIT
1VT<1@aY1VXBe@Jn1VX6K@HU1RX<EC5U35D61@H43:@6]18Z1P01o`40000O0003o`0000D04RX6]0bT
1P@61@aE?6D6E@I51RX69@J41VX6a@KE1VX6I0IY30D<J@IZ4]D6_PIZ1Vd69@HZ35DaI@aE1PD610bT
1[@B:PH00Ol100007`000ol00005018Z1[@<Y0H41PD<ECaU1UD6A@HZ1RD6Q0IZ1/D6e@IZ1V@6J@`5
36T6JQ;E1[h6JPI]1RD6:PaE<FD<E@H51P@<Y0Jd4RX6007o0@0001l000?o00001@0B:PJd3:@610H5
35DlI@IE1TD6:PHU1X@6JPK51]D6JPIT1VT<1@aY1VXBe@Jn1VX6K@HU1RX<EC5U35D61@H43:@6]18Z
1P01o`40000O0003o`0000D04RX6]0bT1P@61@aE?6D6E@I51RX69@J41VX6a@KE1VX6I0IY30D<J@IZ
4]D6_PIZ1Vd69@HZ35DaI@aE1PD610bT1[@B:PH00Ol100007`03o`D04RX6]0bT1P@61@aE?6D6E@I5
1RX69@J41VX6a@KE1VX6I0IY30D<J@IZ4]D6_PIZ1Vd69@HZ35DaI@aE1PD610bT1[@B:PD00_l10000
7`000ol00005018Z1X46]0bD1_<6m19E36D6E@aU65D6A@HZ1QD6J@IZ4/D6I@ID34@6E0IU3<DBe@IZ
1Vd69@HZ1TDCE@IU1UD<IA9E1_@6l`bD1[@6PA8Z1P01o`40000O0003o`0000D04RX6P@Jd39@6l`Kd
4UD<I@IE36DHE@I51RX65@IY1VXBa@IU1U@<A0ID1VD<aA;E1VX6K@HU1RX6AA=E1VD6E@aU4UD6m0Kc
39@6]0J14RX6007o0@0001l000?o00001@0B:PJ11[@<U0Kc1_@BE@aU1UD<IAQE1TD6:PHE1VT6JQ;5
1VD6E0a41U@6I@c54]D6JPI]1RD6:PI54eD6I@IE36DBE@Kd1_<<U0Jd1X4B:PH00Ol100007`000ol0
0005018Z1X46]0bD1_<6m19E36D6E@aU65D6A@HZ1QD6J@IZ4/D6I@ID34@6E0IU3<DBe@IZ1Vd69@HZ
1TDCE@IU1UD<IA9E1_@6l`bD1[@6PA8Z1P01o`40000O0003o`0000D04RX6P@Jd39@6l`Kd4UD<I@IE
36DHE@I51RX65@IY1VXBa@IU1U@<A0ID1VD<aA;E1VX6K@HU1RX6AA=E1VD6E@aU4UD6m0Kc39@6]0J1
4RX6007o0@0001l000?o00001@0B:PJ11[@<U0Kc1_@BE@aU1UD<IAQE1TD6:PHE1VT6JQ;51VD6E0a4
1U@6I@c54]D6JPI]1RD6:PI54eD6I@IE36DBE@Kd1_<<U0Jd1X4B:PH00Ol100007`000ol0000500`Z
1X4<]0JT39@6l`Kd34D`E@a51RD65@IT1VD6a@JZ1/D6Y@I51Y<6X`I51ZD<a@cE1/D6JPIY1QD69@a5
9ED<A@Kd1_<<U0JT3;@6P@`Z1P01o`40000O0003o`0000D032X6P@bd1Z@<U0Kc1_@<AC1E34D69@HE
1V@6I@K51ZX6a@JU1TD6T`JS1TD6Y@c53=D6a@IZ1VT65@HU34DUE@a51_@6l`bD1Z@<]0J132X6007o
0@0001l000?o00001@0<:PJ13;@6Y0bD1_<6m0a5<5D<A@HU1QD6I0IU1/D6ZPK51ZD6A@JC1Z<6A@JU
3<D<e@K51VX6J@HE1RD<ABEE34D6m0Kc39@6Y0bd1X4<:PH00Ol100002`04o`03J000008000@VJ?l5
1`000ol0000500`Z1X4<]0JT39@6l`Kd34D`E@a51RD65@IT1VD6a@JZ1/D6Y@I51Y<6X`I51ZD<a@cE
1/D6JPIY1QD69@a59ED<A@Kd1_<<U0JT3;@6P@`Z1P01o`40000=0003o`0000<000IVlnKVZ;h60003
o`0000D032X6P@bd1Z@<U0Kc1_@<AC1E34D69@HE1V@6I@K51ZX6a@JU1TD6T`JS1TD6Y@c53=D6a@IZ
1VT65@HU34DUE@a51_@6l`bD1Z@<]0J132X6007o0@0000d000?o00000`001RVn002nl`H01?l400`Z
1X4<]0JT39@6l`Kd34D`E@a51RD65@IT1VD6a@JZ1/D6Y@I51Y<6X`I51ZD<a@cE1/D6JPIY1QD69@a5
9ED<A@Kd1_<<U0JT3;@6P@`Z1003o`4000000`3oo`05o`D000?o00000`000ol000020003o`0000@0
00?o00001@0<:Pbd3:@6U0a]1]<6i18Z34D6:PI54RX69@HE1PD6E0I51ZD6ZPJU1XD6i0b41^@6Q@JU
6:X6E@IT1PD65@HU4bX<AA8Z1]@6d`a]1Y@<Y0bd32X6007o0@0000d000?o00000`000ol000020003
o`0000@000?o00001@0<:Pbd3:@6U0a]1]<6i18Z34D6:PI54RX69@HE1PD6E0I51ZD6ZPJU1XD6i0b4
1^@6Q@JU6:X6E@IT1PD65@HU4bX<AA8Z1]@6d`a]1Y@<Y0bd32X6007o0@0000d000?o00000`000ol0
00020003o`0000@000?o00001@0<:Pbd3:@6U0a]1]<6i18Z34D6:PI54RX69@HE1PD6E0I51ZD6ZPJU
1XD6i0b41^@6Q@JU6:X6E@IT1PD65@HU4bX<AA8Z1]@6d`a]1Y@<Y0bd32X6007o0@0000d000?o0000
0`001RVn002n:@H000?o00001@0<:Pbd3:@6U0a]1]<6i18Z34D6:PI54RX69@HE1PD6E0I51ZD6ZPJU
1XD6i0b41^@6Q@JU6:X6E@IT1PD65@HU4bX<AA8Z1]@6d`a]1Y@<Y0bd32X6007o0@0000/000?o:Ol0
1@001VKci^KcIPH000?o00001@0<:Pbd3:@6U0a]1]<6i18Z34D6:PI54RX69@HE1PD6E0I51ZD6ZPJU
1XD6i0b41^@6Q@JU6:X6E@IT1PD65@HU4bX<AA8Z1]@6d`a]1Y@<Y0bd32X6007o0@0000/000=VKOl0
1P0012IXJ6H70003o`0000D032X<]0bT1Y@<K@KC1^@B:Pa51RX6AA8Z1RD65@H51U@6A@JU1ZX6Y@J5
1^@<Q0KT1XD6YARZ1UD6I0H51QD69A<Z34DB:PKD1]<<K@JD3:@<]0`Z1P01o`40000O0003o`0000D0
32X<Y1:D1Vd<J@K31X4B9@`Z62D65@H51_@6A0I51YD<Q@cD3=D6e0KT38DBY@I51U@6m0H51QDC9@HZ
4RD6P@K336T6KA:D3:@<:PH00Ol100007`000ol0000500`Z3:@BU0I]36T6``J14RD<:QPU1QD61@Kd
1T@6A@JE38D<e0cE1]@6i0b54ZD6A@ID1_@61@HE4bD6:Q8U1X46``aY1VdBU0bT32X6007o0@0001l0
00?o00001@0<:PbT4Y@6K@aY1/<6PA8U32XH9@HE1PD6m0I41TD6U@b53=@<e@KD1^@<QA:U1TD6E0Kd
1PD65A<U1RXB9@J11/<<J@I]4Y@<Y0`Z1P01o`40000O0003o`0000D032X<Y1:D1Vd<J@K31X4B9@`Z
62D65@H51_@6A0I51YD<Q@cD3=D6e0KT38DBY@I51U@6m0H51QDC9@HZ4RD6P@K336T6KA:D3:@<:PH0
0Ol100007`000ol0000500`Z3:@BU0I]36T6``J14RD<:QPU1QD61@Kd1T@6A@JE38D<e0cE1]@6i0b5
4ZD6A@ID1_@61@HE4bD6:Q8U1X46``aY1VdBU0bT32X6007o0@0001l00ol500`Z3:@BU0I]36T6``J1
4RD<:QPU1QD61@Kd1T@6A@JE38D<e0cE1]@6i0b54ZD6A@ID1_@61@HE4bD6:Q8U1X46``aY1VdBU0bT
32X500;o0@0001l000?o00001@06:QP44_<6d`c31_l690J41Vd6Q0JD1X@6K@J436T6I0I41Z<6U0KT
1]@<A0HZ39D6A@a41^@6m0H51_@6Y0JX1T@6I0aY4h@<K@HT1_l<``KC4_<H10HZ1P01o`40000O0003
o`0000D01RXH11;c1]<<``Ko1R@6Q0I]1X@6U0J41Vd6Q0aY1V@6A0JS1Y@6i0KD34@6:PbE1TD<A0KT
1_@61@Kd1Z@6Z0I41V@<JA>436d690Ko3<<6da;c60@6:PH00Ol100007`000ol0000500HZ60@Bl`KC
3<<6o`HT1X@6K@J41Y@6Q0I]1X@<J@IT1T@6X`JD1^@6e0a41RX<U@I534@6i0Kd1PD6m0JT1ZP6A0IT
36TCQ0a]1R@6o`c31]<BlaP41RX6007o0@0001l000?o00001@06:QP44_<6d`c31_l690J41Vd6Q0JD
1X@6K@J436T6I0I41Z<6U0KT1]@<A0HZ39D6A@a41^@6m0H51_@6Y0JX1T@6I0aY4h@<K@HT1_l<``KC
4_<H10HZ1P01o`40000O0003o`0000D01RXH11;c1]<<``Ko1R@6Q0I]1X@6U0J41Vd6Q0aY1V@6A0JS
1Y@6i0KD34@6:PbE1TD<A0KT1_@61@Kd1Z@6Z0I41V@<JA>436d690Ko3<<6da;c60@6:PH00Ol10000
7`000ol0000500HZ60@Bl`KC3<<6o`HT1X@6K@J41Y@6Q0I]1X@<J@IT1T@6X`JD1^@6e0a41RX<U@I5
34@6i0Kd1PD6m0JT1ZP6A0IT36TCQ0a]1R@6o`c31]<BlaP41RX6007o0@0001l000?o00001@06:Qh5
4_@6e0b11R@69@J51VXBQA9Z1UD6A@JT1XD6e@HZ1TD6:`JV39H6YPI634D<i@Ke1ZD6Y0I51UD6I@IZ
1XDCJPHU1R@<P@KD4_@N1@HZ1P01o`40000O0003o`0000D01RXN1A;d1]@<P@HT1RD6Q@IZ4XDBJPIE
1TD6Y0J51]D6:PI51R/6YPbF1ZH6APa53>D6m@JU1Z@6A@IE1VD6JPJ54fX69@HT3846e1;d7PD6:PH0
0Ol100007`000ol0000500HZ7PDBm0KD384690HU1XD6JQ:54VX6E@I51Z@6Q@KE1RX6A@H[1ZH<UPJV
1TH<A@cU1_D6Y@JT1TD6E@IU1VX6QA=Z1RD690b11]@Bm1h51RX6007o0@0001l000?o00001@06:Qh5
4_@6e0b11R@69@J51VXBQA9Z1UD6A@JT1XD6e@HZ1TD6:`JV39H6YPI634D<i@Ke1ZD6Y0I51UD6I@IZ
1XDCJPHU1R@<P@KD4_@N1@HZ1P01o`40000O0003o`0000D01RXN1A;d1]@<P@HT1RD6Q@IZ4XDBJPIE
1TD6Y0J51]D6:PI51R/6YPbF1ZH6APa53>D6m@JU1Z@6A@IE1VD6JPJ54fX69@HT3846e1;d7PD6:PH0
0Ol100007`03o`D01RXN1A;d1]@<P@HT1RD6Q@IZ4XDBJPIE1TD6Y0J51]D6:PI51R/6YPbF1ZH6APa5
3>D6m@JU1Z@6A@IE1VD6JPJ54fX69@HT3846e1;d7PD6:PD00_l100007`000ol0000500HZ7VD<E@a5
1RX<9@I]1VX6_PKE3;h6e@c51ZD6U@KT1]D<U@JV1^H6mQ;k1_H6YPbU1R/6APKe1_@6Y@JZ1/DIe@IZ
1Vd<9@HZ34D<EAiU1RX6007o0@0001l000?o00001@06:QiU35D<A@HZ32D6K@IZ1[h6e@bn1]D<a@JU
1YD6i0KE39D6YPKV1_HBn`Kf1ZH<Y@H[1TH6m@Kd1ZD6ZPK56MD6JPI]32D6:Pa535DNI@HZ1P01o`40
000O0003o`0000D01RXNI@aE34D6:P`U1Vd6JPJn1]D<_PKE3<D6Y@JE1^@6e@bE1ZH6iPKf4_/6mPJV
3:D6:`I61_D6m0JU1ZX6aAWE1VX6K@`U1RX<A@aE7VD6:PH00Ol100007`000ol0000500HZ7VD<E@a5
1RX<9@I]1VX6_PKE3;h6e@c51ZD6U@KT1]D<U@JV1^H6mQ;k1_H6YPbU1R/6APKe1_@6Y@JZ1/DIe@IZ
1Vd<9@HZ34D<EAiU1RX6007o0@0001l000?o00001@06:QiU35D<A@HZ32D6K@IZ1[h6e@bn1]D<a@JU
1YD6i0KE39D6YPKV1_HBn`Kf1ZH<Y@H[1TH6m@Kd1ZD6ZPK56MD6JPI]32D6:Pa535DNI@HZ1P01o`40
000O0003o`0000D01RXNI@aE34D6:P`U1Vd6JPJn1]D<_PKE3<D6Y@JE1^@6e@bE1ZH6iPKf4_/6mPJV
3:D6:`I61_D6m0JU1ZX6aAWE1VX6K@`U1RX<A@aE7VD6:PH00Ol100007`000ol0000500HZ1VXTIA9E
1RX<9@J41XD6_PcE1[h6e@K51ZX6Q@KT1TD6Y@JV4_/<5a;k1ZH<Y@H[1^D61@JU1ZXIe@IZ1Vd<9@HZ
4UDTI@IZ1RX6007o0@0001l000?o00001@06:PIZ96DBE@HZ32D6Q0J51[h<e@Jn1]D6a@JZ1XD6i0I5
1ZD6YQ;k31LBn`JV3:D6:`KU1PD6Y@JZ6MD6JPI]32D6:Q9E96D6JPHZ1P01o`40000O0003o`0000D0
1RX6JRAU4UD6:P`U1X@6Q@Jn3=D6_PKE1/D6ZPJ51^@6A@JU1ZHBn``G4_/6YPbU1R/6i@H51ZD6ZQWE
1VX6K@`U1RXBEBAU1VX6:PH00Ol100007`000ol0000500HZ1VXTIA9E1RX<9@J41XD6_PcE1[h6e@K5
1ZX6Q@KT1TD6Y@JV4_/<5a;k1ZH<Y@H[1^D61@JU1ZXIe@IZ1Vd<9@HZ4UDTI@IZ1RX6007o0@0001l0
00?o00001@06:PIZ96DBE@HZ32D6Q0J51[h<e@Jn1]D6a@JZ1XD6i0I51ZD6YQ;k31LBn`JV3:D6:`KU
1PD6Y@JZ6MD6JPI]32D6:Q9E96D6JPHZ1P01o`40000O00?o1@06:PIZ96DBE@HZ32D6Q0J51[h<e@Jn
1]D6a@JZ1XD6i0I51ZD6YQ;k31LBn`JV3:D6:`KU1PD6Y@JZ6MD6JPI]32D6:Q9E96D6JPHZ1@02o`40
000O0003o`0000D01RXZJPaU35D6A@`Z1X@6Q@bn4]D6Y@J51T@6A@JV1_/<5`HW31L69a8G1Z/<Y@KU
1_@6Y@c53=D7Q@J432X6A@aE36DZJPHZ1P01o`40000O0003o`0000D01RXZJPaU35D6A@`Z1X@6Q@bn
4]D6Y@J51T@6A@JV1_/<5`HW31L69a8G1Z/<Y@KU1_@6Y@c53=D7Q@J432X6A@aE36DZJPHZ1P01o`40
000O0003o`0000D01RXZJPaU35D6A@`Z1X@6Q@bn4]D6Y@J51T@6A@JV1_/<5`HW31L69a8G1Z/<Y@KU
1_@6Y@c53=D7Q@J432X6A@aE36DZJPHZ1P01o`40000O0003o`0000D01RXZJPaU35D6A@`Z1X@6Q@bn
4]D6Y@J51T@6A@JV1_/<5`HW31L69a8G1Z/<Y@KU1_@6Y@c53=D7Q@J432X6A@aE36DZJPHZ1P01o`40
000O0003o`0000D01RXZJPaU35D6A@`Z1X@6Q@bn4]D6Y@J51T@6A@JV1_/<5`HW31L69a8G1Z/<Y@KU
1_@6Y@c53=D7Q@J432X6A@aE36DZJPHZ1P01o`40000O0003o`0000D01RXZJPaU35D6A@`Z1X@6Q@bn
4]D6Y@J51T@6A@JV1_/<5`HW31L69a8G1Z/<Y@KU1_@6Y@c53=D7Q@J432X6A@aE36DZJPHZ1P01o`40
000O0003o`0000D01RXTJQ9U4UD6:P`U1Vd6JPKE3<D6ZPJE1^@6A0I61_H6naPG4RL65`ck1ZH6Y@HZ
1^@6U@JU1ZX6a@IZ1fT<9@HZ4UDBIBAZ1RX6007o0@0001l000?o00001@06:RAZ4VDBE@HZ32D6K@IZ
1]D<a@JZ1YD6i0I41TH6mPKk61LB9`HG3?/6YPJU1RX6i0JE1ZD6ZPK51VX7J@`U1RXBEA9U96X6:PH0
0Ol100007`000ol0000500HZ96XBIA9E1RX<9@I]1VX6e@c51ZX6U@KT1T@6APKf1_/H5a8W1QL<n`JV
1ZD6:PKT1YD6Y@JZ1/D6JPMY32D6:Q9E4VDTJPHZ1P01o`40000O0003o`0000D01RXTJQ9U4UD6:P`U
1Vd6JPKE3<D6ZPJE1^@6A0I61_H6naPG4RL65`ck1ZH6Y@HZ1^@6U@JU1ZX6a@IZ1fT<9@HZ4UDBIBAZ
1RX6007o0@0001l000?o00001@06:RAZ4VDBE@HZ32D6K@IZ1]D<a@JZ1YD6i0I41TH6mPKk61LB9`HG
3?/6YPJU1RX6i0JE1ZD6ZPK51VX7J@`U1RXBEA9U96X6:PH00Ol100007`03o`D01RXTJQ9U4UD6:P`U
1Vd6JPKE3<D6ZPJE1^@6A0I61_H6naPG4RL65`ck1ZH6Y@HZ1^@6U@JU1ZX6a@IZ1fT<9@HZ4UDBIBAZ
1RX500;o0@0001l000?o00001@06:PJ5<6X<I@aE1TD<9@I]1VX6e@JZ1ZD6m0KT1TD6YPKk1QL`9``G
1_/6YPI51T@6Q@JE1/D6I@IY3BD6:PaE66DZJPHZ1P01o`40000O0003o`0000D01RX6QC1Z36D<E@I5
32D6K@IZ1]D6ZPJU1_@6i0I51ZH6n`HG<2L<5`Kk1ZH6A@I41XD6U@K51VD6J@dU1RX<EAQU:VX6:PH0
0Ol100007`000ol0000500HZ1XD`JPaU35D6A@`U1Vd6JPKE1ZX6Y@Kd1^@6A@JV1_/65c0W31L6n`JV
1TD6A0J51YD6a@IU1VT=9@HZ35DHIBYZ1RX6007o0@0001l000?o00001@06:PJ5<6X<I@aE1TD<9@I]
1VX6e@JZ1ZD6m0KT1TD6YPKk1QL`9``G1_/6YPI51T@6Q@JE1/D6I@IY3BD6:PaE66DZJPHZ1P01o`40
000O0003o`0000D01RX6QC1Z36D<E@I532D6K@IZ1]D6ZPJU1_@6i0I51ZH6n`HG<2L<5`Kk1ZH6A@I4
1XD6U@K51VD6J@dU1RX<EAQU:VX6:PH00Ol100007`000ol0000500HZ1XD`JPaU35D6A@`U1Vd6JPKE
1ZX6Y@Kd1^@6A@JV1_/65c0W31L6n`JV1TD6A0J51YD6a@IU1VT=9@HZ35DHIBYZ1RX6007o0@0001l0
00?o00001@06:PJ5:VXBIA9E1RX69@HE1VT6E@JU3?@6i@JU1ZH6n`HG7RL6018W1QL<n`I61RT6e0J5
1TD6I0dE1RX6A@aE4VDZJPJ51RX6007o0@0001l000?o00001@06:PJ5:VXBIA9E1RX69@HE1VT6E@JU
3?@6i@JU1ZH6n`HG7RL6018W1QL<n`I61RT6e0J51TD6I0dE1RX6A@aE4VDZJPJ51RX6007o0@0001l0
00?o00001@06:PJ5:VXBIA9E1RX69@HE1VT6E@JU3?@6i@JU1ZH6n`HG7RL6018W1QL<n`I61RT6e0J5
1TD6I0dE1RX6A@aE4VDZJPJ51RX6007o0@0001@000@VJ?l51`000ol0000500HZ1XDZJQ9U4UD6:PHU
1QD6J@IE1ZD<m0KU1ZD6YPKk1QLN9`H04RL65`ck1TH6:@KD1XD6A@IT3AD6:PI535DBIBYZ1XD6:PH0
0Ol100004`001VKci^JX_PH000?o00001@06:PJ5:VXBIA9E1RX69@HE1VT6E@JU3?@6i@JU1ZH6n`HG
7RL6018W1QL<n`I61RT6e0J51TD6I0dE1RX6A@aE4VDZJPJ51RX6007o0@0001<000HY_P00__<600Co
1006:PJ5:VXBIA9E1RX69@HE1VT6E@JU3?@6i@JU1ZH6n`HG7RL6018W1QL<n`I61RT6e0J51TD6I0dE
1RX6A@aE4VDZJPJ51RX400?o0@0001<000?o00000P000ol000040003o`0000D01RXHQAiZ4VD<E@I5
1RD65@H51U@6Y0H51^D6:`JU1ZH<5``W600H9`HG1_/6UPHZ1]@6Q0I41_@65@LU1TD<EA9U7VXHQ@HZ
1P01o`40000C0003o`00008000?o000010000ol0000500HZ68DNJQ9U35D6A@HU1QD61@ID1Z@61@KU
1R/6Y@JV31L<9aP062L65`Kk1YH6:PKD1X@6A0Kd1QD79@I535DBIAiZ68D6:PH00Ol100004`000ol0
00020003o`0000@000?o00001@06:QR57VXBI@aE1TD69@HE1PD6E0JT1PD6i@H[1ZD6YP`G32LH01PW
1QL6n`JF1RX6e0J41T@6m0HE1bD6A@aE4VDNJQR51RX6007o0@0001<000HY_P00_RT60003o`0000D0
1RXHQAiZ4VD<E@I51RD65@H51U@6Y0H51^D6:`JU1ZH<5``W600H9`HG1_/6UPHZ1]@6Q0I41_@65@LU
1TD<EA9U7VXHQ@HZ1P01o`40000C0006I_?Vi_=V1P000ol0000500HZ68DNJQ9U35D6A@HU1QD61@ID
1Z@61@KU1R/6Y@JV31L<9aP062L65`Kk1YH6:PKD1X@6A0Kd1QD79@I535DBIAiZ68D6:PH00Ol10000
500012IXJ6H70003o`0000D01RXHQAiZ4VD<E@I51RD65@H51U@6Y0H51^D6:`JU1ZH<5``W600H9`HG
1_/6UPHZ1]@6Q0I41_@65@LU1TD<EA9U7VXHQ@HZ1P01o`40000O0003o`0000D01RXBQBYZ4VD6E@a5
1QD6m0ID1ZP6Y@I61R/6Y@J[31LB9a8032L65`HW1QL6n`JF1YD6JPJ31T@6i0HE1bX<A@IE4VDTJQ:5
1RX6007o0@0001l000?o00001@06:Q:5:VXBI@IE34D65@Kd1U@6Z0JU1TH6:`JU1Z/<5a8W4P0<9`HG
1RL65`Kk1YH6U@IZ1X<6A0KT1QD7:Pa51UDBIBAZ4XD6:PH00Ol100007`000ol0000500HZ4XDZJQ9U
1UD<A@HE1_@6E0JX1ZD6APH[1ZD6Z``G4RLB00`W1QL69`HG1_/6UPJE1VX6P`I41^@65@LZ34D6EA9U
96XBQ@HZ1P01o`40000O0003o`0000D01RXBQBYZ4VD6E@a51QD6m0ID1ZP6Y@I61R/6Y@J[31LB9a80
32L65`HW1QL6n`JF1YD6JPJ31T@6i0HE1bX<A@IE4VDTJQ:51RX6007o0@0001l000?o00001@06:Q:5
:VXBI@IE34D65@Kd1U@6Z0JU1TH6:`JU1Z/<5a8W4P0<9`HG1RL65`Kk1YH6U@IZ1X<6A0KT1QD7:Pa5
1UDBIBAZ4XD6:PH00Ol100007`03o`D01RXBQBYZ4VD6E@a51QD6m0ID1ZP6Y@I61R/6Y@J[31LB9a80
32L65`HW1QL6n`JF1YD6JPJ31T@6i0HE1bX<A@IE4VDTJQ:51RX500;o0@0001l000?o00001@06:PJ5
<6XBI@aE1TD69@HE1V@6A0I51_@6i@H[1ZD6YPKk1QLH9``062L<n`JF1RX6e0HU1T@6E0HE1bD<A@IE
66DZJPJ51RX6007o0@0001l000?o00001@06:PJ5<6XBI@aE1TD69@HE1V@6A0I51_@6i@H[1ZD6YPKk
1QLH9``062L<n`JF1RX6e0HU1T@6E0HE1bD<A@IE66DZJPJ51RX6007o0@0001l000?o00001@06:PJ5
<6XBI@aE1TD69@HE1V@6A0I51_@6i@H[1ZD6YPKk1QLH9``062L<n`JF1RX6e0HU1T@6E0HE1bD<A@IE
66DZJPJ51RX6007o0@0001l000?o00001@06:PJ5<6XBI@aE1TD69@HE1V@6A0I51_@6i@H[1ZD6YPKk
1QLH9``062L<n`JF1RX6e0HU1T@6E0HE1bD<A@IE66DZJPJ51RX6007o0@0001l000?o00001@06:PJ5
<6XBI@aE1TD69@HE1V@6A0I51_@6i@H[1ZD6YPKk1QLH9``062L<n`JF1RX6e0HU1T@6E0HE1bD<A@IE
66DZJPJ51RX6007o0@0001l000?o00001@06:PJ5<6XBI@aE1TD69@HE1V@6A0I51_@6i@H[1ZD6YPKk
1QLH9``062L<n`JF1RX6e0HU1T@6E0HE1bD<A@IE66DZJPJ51RX6007o0@0001l000?o00001@06:PJ5
:VXBIA9E1RX69@aY1UD<Y@Kd1^D6Y@JV1_/65ahW1P0B9`HG1_/6mPI61RT6JPJ51UD6I0IY1aD6:Q9E
4VDZJPJ51RX6007o0@0001l000?o00001@06:PJ5:VXBIA9E1RX69@aY1UD<Y@Kd1^D6Y@JV1_/65ahW
1P0B9`HG1_/6mPI61RT6JPJ51UD6I0IY1aD6:Q9E4VDZJPJ51RX6007o0@0001l000?o00001@06:PJ5
:VXBIA9E1RX69@aY1UD<Y@Kd1^D6Y@JV1_/65ahW1P0B9`HG1_/6mPI61RT6JPJ51UD6I0IY1aD6:Q9E
4VDZJPJ51RX6007o0@0001l000?o00001@06:PJ5:VXBIA9E1RX69@aY1UD<Y@Kd1^D6Y@JV1_/65ahW
1P0B9`HG1_/6mPI61RT6JPJ51UD6I0IY1aD6:Q9E4VDZJPJ51RX6007o0@0001l000?o00001@06:PJ5
:VXBIA9E1RX69@aY1UD<Y@Kd1^D6Y@JV1_/65ahW1P0B9`HG1_/6mPI61RT6JPJ51UD6I0IY1aD6:Q9E
4VDZJPJ51RX6007o0@0001l00ol500HZ1XDZJQ9U4UD6:PHU36T6E@bU1_@6i@JU1ZH6n`HG7RL6018W
1QL6n`Kf1TH6:@IZ1XD6E@IT1VT75@HZ4UDBIBYZ1XD6:PD00_l100007`000ol0000500HZ96XHIA9E
1RX69@I]1VT6I@K53:D6U@KT1RX6YPKf1_/69``G7RL65`ck1YH6:PKT1VX6U@JZ1VD=J@HU1RX6A@aE
66DTJPHZ1P01o`40000O0003o`0000D01RXTJQQU4UD6:PHU1Vd6J@IU1/D<Y@JE1^@6:PJV1_H6n`HW
31LN9`HG3?/6UPHZ1^@6JPJE1ZX6I@eY1RD6:PI535DHIBAZ1RX6007o0@0001l000?o00001@06:RAZ
66DBE@HZ1RD6K@IY1VD6a@bU1YD6i0HZ1ZH6mPKk1RL<5ahW1QL<n`JF1RX6i0IZ1YD6ZPIU3FT69@HZ
1TD<EAQU96X6:PH00Ol100007`000ol0000500HZ96XHIA9E1RX69@I]1VT6I@K53:D6U@KT1RX6YPKf
1_/69``G7RL65`ck1YH6:PKT1VX6U@JZ1VD=J@HU1RX6A@aE66DTJPHZ1P01o`40000O0003o`0000D0
1RXTJQQU4UD6:PHU1Vd6J@IU1/D<Y@JE1^@6:PJV1_H6n`HW31LN9`HG3?/6UPHZ1^@6JPJE1ZX6I@eY
1RD6:PI535DHIBAZ1RX6007o0@0001l000?o00001@06:RAZ66DBE@HZ1RD6K@IY1VD6a@bU1YD6i0HZ
1ZH6mPKk1RL<5ahW1QL<n`JF1RX6i0IZ1YD6ZPIU3FT69@HZ1TD<EAQU96X6:PH00Ol100007`000ol0
000500HZ:VXBI@aE1TD6:Pb41XD6eA;51YD6Q@I41TH<n`HG:RL<5`JV1ZD6i@KT1YD6ZPc51VX7K@J4
1RD6A@aE4VDZJPHZ1P01o`40000O0003o`0000D01RXZJQ9U35D6A@HZ38@6Q@KE4/D6U@J51T@6APck
1QLZ9``G1ZH6Y@KU1^@6U@JZ3<D6JPM]1X@69@I535DBIBYZ1RX6007o0@0001l000?o00001@06:RYZ
4VD<E@I51RX<Q0J51]DBa@JE1XD6A0I63?/65bXW31L6YPJU1^D6i0JE1ZX<a@IZ1fd6Q0HU1TD<EA9U
:VX6:PH00Ol100007`000ol0000500HZ:VXBI@aE1TD6:Pb41XD6eA;51YD6Q@I41TH<n`HG:RL<5`JV
1ZD6i@KT1YD6ZPc51VX7K@J41RD6A@aE4VDZJPHZ1P01o`40000O0003o`0000D01RXZJQ9U35D6A@HZ
38@6Q@KE4/D6U@J51T@6APck1QLZ9``G1ZH6Y@KU1^@6U@JZ3<D6JPM]1X@69@I535DBIBYZ1RX6007o
0@0001l00ol500HZ:VXBI@aE1TD6:Pb41XD6eA;51YD6Q@I41TH<n`HG:RL<5`JV1ZD6i@KT1YD6ZPc5
1VX7K@J41RD6A@aE4VDZJPHZ1@02o`40000O0003o`0000D01RX<JRAU4UD6:PHU1X@6K@IZ4]D<a@JE
1XD6i0HZ1YHBna8G1RL65`ck1ZH6Y@H[1[h6i0JU1ZX<a@KE1fX<K@HU1RXBEBAU36X6:PH00Ol10000
7`000ol0000500HZ36XTIA9E1RX69@J41Vd6JQ;E3<D6U@J51^@6:PJF4_/B5`HW1QL<n`JV1ZD6:`Jn
1^@6Y@JZ3<D6e@MZ36d69@HZ4UDTI@aZ1RX6007o0@0001l000?o00001@06:PaZ96DBE@HZ1RD6Q0I]
1VXBe@c51YD6Q@KT1RX6UQ;k4QL69`HG3?/6YPJU1R/6_PKT1ZD6ZPc51]D7JPa]1RD6:Q9E96D<JPHZ
1P01o`40000O0003o`0000D01RX<JRAU4UD6:PHU1X@6K@IZ4]D<a@JE1XD6i0HZ1YHBna8G1RL65`ck
1ZH6Y@H[1[h6i0JU1ZX<a@KE1fX<K@HU1RXBEBAU36X6:PH00Ol100007`000ol0000500HZ36XTIA9E
1RX69@J41Vd6JQ;E3<D6U@J51^@6:PJF4_/B5`HW1QL<n`JV1ZD6:`Jn1^@6Y@JZ3<D6e@MZ36d69@HZ
4UDTI@aZ1RX6007o0@0001l000?o00001@06:PaZ96DBE@HZ1RD6Q0I]1VXBe@c51YD6Q@KT1RX6UQ;k
4QL69`HG3?/6YPJU1R/6_PKT1ZD6ZPc51]D7JPa]1RD6:Q9E96D<JPHZ1P01o`40000O0003o`0000D0
1RXNIA9E34D6:PHU36d6JQSE1/D6ZPJU1XD6e0KE1YD6UPKk1_H6n``G4_/6YPJU32/6i@Kd1YD6YA;5
1mD6JPIY1Vd69@HZ34DBEAiU1RX6007o0@0001l000?o00001@06:QiU4UD<A@HZ1RD<K@IZ6=D6a@JZ
1ZD6Q@KD1]D6U@JF1_/6mPKk31LBn`JV1ZD<:`KU1_@6U@JU4/D7e@IZ1VT6K@HU1RX<AA9E7VD6:PH0
0Ol100007`000ol0000500HZ7VDBE@a51RX69@a]1VXHe@K51ZX6Y@J51]@6e@JE1YH6n`Kf1_/<5a;k
1ZH6Y@`[1^D6m0JE1ZDBa@OE1VX6J@I]1RD6:Pa54UDNI@HZ1P01o`40000O0003o`0000D01RXNIA9E
34D6:PHU36d6JQSE1/D6ZPJU1XD6e0KE1YD6UPKk1_H6n``G4_/6YPJU32/6i@Kd1YD6YA;51mD6JPIY
1Vd69@HZ34DBEAiU1RX6007o0@0001l000?o00001@06:QiU4UD<A@HZ1RD<K@IZ6=D6a@JZ1ZD6Q@KD
1]D6U@JF1_/6mPKk31LBn`JV1ZD<:`KU1_@6U@JU4/D7e@IZ1VT6K@HU1RX<AA9E7VD6:PH00Ol10000
7`03o`D01RXNIA9E34D6:PHU36d6JQSE1/D6ZPJU1XD6e0KE1YD6UPKk1_H6n``G4_/6YPJU32/6i@Kd
1YD6YA;51mD6JPIY1Vd69@HZ34DBEAiU1RX500;o0@0001l000?o00001@0<:Qh54_@6e0J132@69A9Z
1XD6JPaU34D6Q0IZ1]D6:PI61YHNYPI61TD6i@Jn1^D6Y@JD1TD6E@IU6FX69@`T1X46e1;d7PD<:PH0
0Ol100007`000ol0000500`Z7PDBm0KD1X4<90HU4VX6Q@IZ36D<A@J41VX6e@HZ1TH6UQjV1TH6A@KU
1[h6i@JU1Y@6A@IE1VDIJPHU32@6P@KD4_@N1@`Z1P01o`40000O0003o`0000D032XN1A;d1]@6P@`T
1RDBJPJ51VX<I@a51X@6JPKE1RX6APJF7ZH6API51^D6_PKU1ZD6U0I51UD6IAUZ1RD<90J11]@Bm1h5
32X6007o0@0001l000?o00001@0<:Qh54_@6e0J132@69A9Z1XD6JPaU34D6Q0IZ1]D6:PI61YHNYPI6
1TD6i@Jn1^D6Y@JD1TD6E@IU6FX69@`T1X46e1;d7PD<:PH00Ol100007`000ol0000500`Z7PDBm0KD
1X4<90HU4VX6Q@IZ36D<A@J41VX6e@HZ1TH6UQjV1TH6A@KU1[h6i@JU1Y@6A@IE1VDIJPHU32@6P@KD
4_@N1@`Z1P01o`40000O0003o`0000D032XN1A;d1]@6P@`T1RDBJPJ51VX<I@a51X@6JPKE1RX6APJF
7ZH6API51^D6_PKU1ZD6U0I51UD6IAUZ1RD<90J11]@Bm1h532X6007o0@0001l000?o00001@0<:QP4
4_<6d`K33?l6919]1X@6KA9Y1U@6A0JS1X@6e0KT1T@6A@JU1YD<Y@I51T@<i0Kd1PD6Y0JX1T@6I0aY
1X@CK@HT3?l6``KC4_<H10`Z1P01o`40000O0003o`0000D032XH11;c1]<6``co1R@BK@J41VdBJ@ID
1T@6X`J41]@6i0I41TD6Y@JE3:D6A@I43>@6m0H51Z@6Z0I41V@<J@J44fd690co1/<6da;c60@<:PH0
0Ol100007`000ol0000500`Z60@Bl`KC1/<<o`HT4Vd6Q0I]4VT6E0I41Z<6Q0KD1^@6A0I51ZD6U@bU
1TD6A0cT1_@61@JT1ZP6A0IT36T6Q1=]1R@<o`K31]<BlaP432X6007o0@0000/01?l00fP000020004
9VSo1@L000?o00001@0<:QP44_<6d`K33?l6919]1X@6KA9Y1U@6A0JS1X@6e0KT1T@6A@JU1YD<Y@I5
1T@<i0Kd1PD6Y0JX1T@6I0aY1X@CK@HT3?l6``KC4_<H10`Z1P01o`40000=0003o`0000<000IVlnKV
Z;h60003o`0000D032XH11;c1]<6``co1R@BK@J41VdBJ@ID1T@6X`J41]@6i0I41TD6Y@JE3:D6A@I4
3>@6m0H51Z@6Z0I41V@<J@J44fd690co1/<6da;c60@<:PH00Ol100003@000ol000030006:Kh00;kc
1P04o`@032XH11;c1]<6``co1R@BK@J41VdBJ@ID1T@6X`J41]@6i0I41TD6Y@JE3:D6A@I43>@6m0H5
1Z@6Z0I41V@<J@J44fd690co1/<6da;c60@<:P@00ol100003@000ol000030003o`00008000?o0000
10000ol0000500`Z4Z@BU0I]1VT<``J14RD6:Q8U31D61@KT1T@6A@J51VX6Q@KT1[h<:`Jn1^@6Q@IZ
1YD6Y@JE1TD6E0Kd1PD<5AlU1X4<``IY1VdBU1:T32X6007o0@0000d000?o00000`000ol000020003
o`0000@000?o00001@0<:Q:T4Y@6K@IY3<<6PA8U1RXB9@`E1PD6i0I41TD6Q@IZ1XD6i0Jn32/6_PKT
1XD6JPJE1ZD6U@I51U@6m0H531DO9@J13<<6J@I]4Y@BY0`Z1P01o`40000=0003o`0000<000?o0000
0P000ol000040003o`0000D032XBY1:D1Vd6J@c31X4B9@HZ4RD<5@H51^@6A0I51XD6JPJ51^@6_P`[
1[h6i0J51VX6U@JU1YD6A@ID1_@61@`E7bD6P@c31VT6KA:D4Z@<:PH00Ol100003@000ol000030006
:Kh00;hY1P000ol0000500`Z4Z@BU0I]1VT<``J14RD6:Q8U31D61@KT1T@6A@J51VX6Q@KT1[h<:`Jn
1^@6Q@IZ1YD6Y@JE1TD6E0Kd1PD<5AlU1X4<``IY1VdBU1:T32X6007o0@0000/000?o:Ol01@001VKc
i^KcIPH000?o00001@0<:Q:T4Y@6K@IY3<<6PA8U1RXB9@`E1PD6i0I41TD6Q@IZ1XD6i0Jn32/6_PKT
1XD6JPJE1ZD6U@I51U@6m0H531DO9@J13<<6J@I]4Y@BY0`Z1P01o`40000;0003IVgo00H000@VJ6QV
1`000ol00005018Z3;@<Y0JD1Vd<d`KD4RX6AAhZ1RD65@H51U@6E@bU1YD6Q@KT3>D6i0J51YD6YA:Z
1UD6I0H51QD69A<Z1TDB:PKD3=<6K@JD3:@<]18Z1P01o`40000O0003o`0000D04RX<]0bT1Y@6K@cC
1]@B:PI57RX69@HE1PD6E0IE3:D6U@J51^@<i@KT1XD6U@JU4ZX6E@IT1PD65@HU4bX6AA8Z1]@<d`I]
1Y@<Y0bd4RX6007o0@0001l000?o00001@0B:Pbd3:@6U0I]3=<6e18Z1TDN:PHU1QD61@ID1UD<Y@JE
1XD6i0cU1^@6Q@JE1ZDBZPIE1V@61@HE1RDC:PI54RX6e0cC1Vd6U0bT3;@B:PH00Ol100007`000ol0
0005018Z3;@<Y0JD1Vd<d`KD4RX6AAhZ1RD65@H51U@6E@bU1YD6Q@KT3>D6i0J51YD6YA:Z1UD6I0H5
1QD69A<Z1TDB:PKD3=<6K@JD3:@<]18Z1P01o`40000O0003o`0000D04RX<]0bT1Y@6K@cC1]@B:PI5
7RX69@HE1PD6E0IE3:D6U@J51^@<i@KT1XD6U@JU4ZX6E@IT1PD65@HU4bX6AA8Z1]@<d`I]1Y@<Y0bd
4RX6007o0@0001l000?o00001@0B:Pbd3:@6U0I]3=<6e18Z1TDN:PHU1QD61@ID1UD<Y@JE1XD6i0cU
1^@6Q@JE1ZDBZPIE1V@61@HE1RDC:PI54RX6e0cC1Vd6U0bT3;@B:PH00Ol100007`03o`D04RX6P@bd
1Z@6U0cc1_@<ABAE4TD69@HE1VT6I@c51ZX6U@JU1Y@6Y0JU1YD6ZPK51]D6a@KE1VX6J@HE1RD<A@IE
1dDBE@a51_@<l`JD1Z@<]0J14RX500;o0@0001l000?o00001@0B:PJ13;@6Y0JD3?<6m0a595DBA@HU
1QD6J@IU3<D6ZPJE1ZD6U0JT1ZD6U@JZ1/D6e@K51]D6JPIY1QD69@a51UD7AA9E34D6m0cc1Y@6Y0bd
1X4B:PH00Ol100007`000ol00005018Z1X4<]0JT1Y@<l`Kd34DTEA951RD65@IY1VD<a@JZ1YD6Y@JD
1Z@6Y@JE1ZX6a@KE1/D6e@IZ1VT65@HU34D6E@M54UD<A@Kd3?<6U0JT3;@6PA8Z1P01o`40000O0003
o`0000D04RX6P@bd1Z@6U0cc1_@<ABAE4TD69@HE1VT6I@c51ZX6U@JU1Y@6Y0JU1YD6ZPK51]D6a@KE
1VX6J@HE1RD<A@IE1dDBE@a51_@<l`JD1Z@<]0J14RX6007o0@0001l000?o00001@0B:PJ13;@6Y0JD
3?<6m0a595DBA@HU1QD6J@IU3<D6ZPJE1ZD6U0JT1ZD6U@JZ1/D6e@K51]D6JPIY1QD69@a51UD7AA9E
34D6m0cc1Y@6Y0bd1X4B:PH00Ol100007`000ol00005018Z1X4<]0JT1Y@<l`Kd34DTEA951RD65@IY
1VD<a@JZ1YD6Y@JD1Z@6Y@JE1ZX6a@KE1/D6e@IZ1VT65@HU34D6E@M54UD<A@Kd3?<6U0JT3;@6PA8Z
1P01o`40000O0003o`0000D062X6P@Jd1Y@<l`Kd4UD6I@aE1VDBE@a51RX65@IY1VXBa@JU1TD<A0I5
1ZX<a@Jn3=D6JPI]1RD6:PI57eD6IA9E1_@<l`JD3;@H:PH00Ol100007`000ol0000501PZ1X46]0JD
3?<6m19E1VD<E@IU4UD<A@HZ1QD6J@IZ4/D6Y@I534@6A@JZ3<D6_PcE1VX6K@HU1RX6AAmE1VDBE@Kd
3?<6U0bd62X6007o0@0001l000?o00001@0H:PJ11[@6U0cc1_@BE@IU35D6IA9E34D6:PHE1VT6JQ;5
1ZD6A@a41TD6ZPc51[h<e@IZ1Vd69@HZ1TDOE@IU4UD6m0cc1Y@<]1PZ1P01o`40000O0003o`0000D0
62X6P@Jd1Y@<l`Kd4UD6I@aE1VDBE@a51RX65@IY1VXBa@JU1TD<A0I51ZX<a@Jn3=D6JPI]1RD6:PI5
7eD6IA9E1_@<l`JD3;@H:PH00Ol100007`000ol0000501PZ1X46]0JD3?<6m19E1VD<E@IU4UD<A@HZ
1QD6J@IZ4/D6Y@I534@6A@JZ3<D6_PcE1VX6K@HU1RX6AAmE1VDBE@Kd3?<6U0bd62X6007o0@0001l0
00?o00001@0H:PJ11[@6U0cc1_@BE@IU35D6IA9E34D6:PHE1VT6JQ;51ZD6A@a41TD6ZPc51[h<e@IZ
1Vd69@HZ1TDOE@IU4UD6m0cc1Y@<]1PZ1P01o`40000O00?o1@0H:PJd1Z@<10H535DfI@IE1TD6:PHU
1Vd6JPKE3<D6I@ID3?@6I0IZ1]D6a@Jn1^D6_PIZ1X@69@HZ35D[I@aE1PD<10JT1[@H:PD00_l10000
7`000ol0000501PZ1[@6Y0`41PD<ECIU1UD6A@HZ1RD6K@IZ1]D<a@IU1U@<m0IT1VX6e@K51[h6i@Jn
1VX6Q0HU1RX<EB]U35D61@`41Z@6]1PZ1P01o`40000O0003o`0000D062X6]0JT30@61@aE=VD6E@I5
1RX69@I]1VX6e@c51VD6E0cd1V@6JPKE1/D6_PKU1[h6JPJ41RD6:PaE:fD<E@H530@6Y0Jd62X6007o
0@0001l000?o00001@0H:PJd1Z@<10H535DfI@IE1TD6:PHU1Vd6JPKE3<D6I@ID3?@6I0IZ1]D6a@Jn
1^D6_PIZ1X@69@HZ35D[I@aE1PD<10JT1[@H:PH00Ol100007`000ol0000501PZ1[@6Y0`41PD<ECIU
1UD6A@HZ1RD6K@IZ1]D<a@IU1U@<m0IT1VX6e@K51[h6i@Jn1VX6Q0HU1RX<EB]U35D61@`41Z@6]1PZ
1P01o`40000O0003o`0000D062X6]0JT30@61@aE=VD6E@I51RX69@I]1VX6e@c51VD6E0cd1V@6JPKE
1/D6_PKU1[h6JPJ41RD6:PaE:fD<E@H530@6Y0Jd62X6007o0@0001l000?o00001@0N:P`41PDBI@IZ
<6D<E@HZ1RD6Q0IZ1/D6e@IZ1VT65@`51QD6J@IZ1]D<_PKU1XD6K@HU1RX<EBEU1VXBI@H530@N:PH0
0Ol100007`000ol0000501hZ30@61A9U1VX`I@aE1RX69@J41VX6a@KE1VX6J@HE30D65@IY1VX6e@bn
1^D6Q@I]1RD6:PaE9FD6JQ9U1PD<11hZ1P01o`40000O0003o`0000D07RX<10H54VD6JS1U35D6:PHU
1X@6JPK51]D6JPIY1QD<1@HE1VT6JPKE3;h6i@J51Vd69@HZ35DUI@IZ4VD61@`47RX6007o0@0001l0
00?o00001@0N:P`41PDBI@IZ<6D<E@HZ1RD6Q0IZ1/D6e@IZ1VT65@`51QD6J@IZ1]D<_PKU1XD6K@HU
1RX<EBEU1VXBI@H530@N:PH00Ol100007`000ol0000501hZ30@61A9U1VX`I@aE1RX69@J41VX6a@KE
1VX6J@HE30D65@IY1VX6e@bn1^D6Q@I]1RD6:PaE9FD6JQ9U1PD<11hZ1P01o`40000O0003o`0000D0
7RX<10H54VD6JS1U35D6:PHU1X@6JPK51]D6JPIY1QD<1@HE1VT6JPKE3;h6i@J51Vd69@HZ35DUI@IZ
4VD61@`47RX6007o0@0001l00ol501hZ1P@61A9U36X6IAiZ36D<E@I51RD6K@IZ1]D6JPJ431D<9@HE
1RD6Q0J51^D<_PJ51X@69@I535D=IA9Z36D6JQ9U1PD611hZ1@02o`40000O0003o`0000D07RX610H5
4VD<JPIU7VX<I@aE1TD69@I]1VX6e@IZ1X@<5@`U1QD69@J41XD6i@bn1XD6Q0HU1TD<E@eU4VX<I@IZ
4VD61@H47RX6007o0@0001l000?o00001@0N:PH41PDBI@aZ1VDNJPaU35D6A@HU1Vd6JPKE1VX6Q0`E
32D65@HU1X@6Q@KU3;h6Q@J41RD6A@aE3FDBJPaU1VXBI@H51P@N:PH00Ol100007`000ol0000501hZ
1P@61A9U36X6IAiZ36D<E@I51RD6K@IZ1]D6JPJ431D<9@HE1RD6Q0J51^D<_PJ51X@69@I535D=IA9Z
36D6JQ9U1PD611hZ1P01o`40000O0003o`0000D07RX610H54VD<JPIU7VX<I@aE1TD69@I]1VX6e@IZ
1X@<5@`U1QD69@J41XD6i@bn1XD6Q0HU1TD<E@eU4VX<I@IZ4VD61@H47RX6007o0@0001l000?o0000
1@0N:PH41PDBI@aZ1VDNJPaU35D6A@HU1Vd6JPKE1VX6Q0`E32D65@HU1X@6Q@KU3;h6Q@J41RD6A@aE
3FDBJPaU1VXBI@H51P@N:PH00Ol100007`000ol0000502@Z4VD`JQ9U35D6A@HU1VT<JPI]32D6:Pa5
1RX<9@I]1XD6_PKE1XD6U0`Z1UDCIBYZ4VDT:PH00Ol100007`000ol0000502@Z4VD`JQ9U35D6A@HU
1VT<JPI]32D6:Pa51RX<9@I]1XD6_PKE1XD6U0`Z1UDCIBYZ4VDT:PH00Ol100007`000ol0000502@Z
4VD`JQ9U35D6A@HU1VT<JPI]32D6:Pa51RX<9@I]1XD6_PKE1XD6U0`Z1UDCIBYZ4VDT:PH00Ol10000
7`000ol0000502@Z4VD`JQ9U35D6A@HU1VT<JPI]32D6:Pa51RX<9@I]1XD6_PKE1XD6U0`Z1UDCIBYZ
4VDT:PH00Ol100007`000ol0000502@Z4VD`JQ9U35D6A@HU1VT<JPI]32D6:Pa51RX<9@I]1XD6_PKE
1XD6U0`Z1UDCIBYZ4VDT:PH00Ol100007`000ol0000502@Z4VD`JQ9U35D6A@HU1VT<JPI]32D6:Pa5
1RX<9@I]1XD6_PKE1XD6U0`Z1UDCIBYZ4VDT:PH00Ol100007`03o`D0:RY2JQ9U1UD6:PHU1Vd69@I]
32D6:Q951UD6:P`U1Y@6Q@Jn1VX6Q0HZ1TD6EA=U=VXZ:PD00_l100007`000ol0000502XZ@VXBI@IE
1RX69@I]1RD6K@`U1RXBA@IE1RX<9@JD1XD6_PIZ1X@6:PI51UDCICIZ:RX6007o0@0001l000?o0000
1@0Z:T9Z4VD6E@HZ1RD6K@HU1Vd<9@HZ4TD6E@HZ32D6U0J51[h6JPJ41RX6A@IE4fDfJRXZ1P01o`40
000O0003o`0000D0:RY2JQ9U1UD6:PHU1Vd69@I]32D6:Q951UD6:P`U1Y@6Q@Jn1VX6Q0HZ1TD6EA=U
=VXZ:PH00Ol100007`000ol0000502XZ@VXBI@IE1RX69@I]1RD6K@`U1RXBA@IE1RX<9@JD1XD6_PIZ
1X@6:PI51UDCICIZ:RX6007o0@0001l000?o00001@0Z:T9Z4VD6E@HZ1RD6K@HU1Vd<9@HZ4TD6E@HZ
32D6U0J51[h6JPJ41RX6A@IE4fDfJRXZ1P01o`40000O0003o`0000D0:RY2JQ9U1UD6:PHU32@<9@a5
7UD6A@HU1RX6Q0b51Vd69@I535D6ICeZ:RX6007o0@0001l000?o00001@0Z:T9Z4VD6E@HZ1RD<90`U
34DNE@I51RD6:PJ438D6K@HU1TD<E@IU?FXZ:PH00Ol100007`000ol0000502XZ@VXBI@IE1RX69@`T
32D<AAiE1TD69@HZ1X@<Q@I]1RD6A@aE1VDmJRXZ1P01o`40000O0003o`0000D0:RY2JQ9U1UD6:PHU
32@<9@a57UD6A@HU1RX6Q0b51Vd69@I535D6ICeZ:RX6007o0@0000X01_l400049VSo1@L000?o0000
1@0Z:T9Z4VD6E@HZ1RD<90`U34DNE@I51RD6:PJ438D6K@HU1TD<E@IU?FXZ:PH00Ol100002P000iGo
IP020006J00006Kc0^H00jRn00050003o`0000D0:RY2JQ9U1UD6:PHU32@<9@a57UD6A@HU1RX6Q0b5
1Vd69@I535D6ICeZ:RX6007o0@0000/000>EofH01@001RVn002nl`H01?l4030Z66X6QAQZ4VD6E@I5
1RX6P@Ko1X469@HZ4UD<IA9E32X69@J41RD6Q0HU1RX6E@aU=fX`:P@00ol1000030000kiXIP040003
o`00008000?o000010000ol00005030Z66X6QAQZ4VD6E@I51RX6P@Ko1X469@HZ4UD<IA9E32X69@J4
1RD6Q0HU1RX6E@aU=fX`:PH00Ol100003@000fIXIP030003o`00008000?o000010000ol00005030Z
66X6QAQZ4VD6E@I51RX6P@Ko1X469@HZ4UD<IA9E32X69@J41RD6Q0HU1RX6E@aU=fX`:PH00Ol10000
3P000kkc00020003o`00008000?o000010000ol00005030Z66X6QAQZ4VD6E@I51RX6P@Ko1X469@HZ
4UD<IA9E32X69@J41RD6Q0HU1RX6E@aU=fX`:PH00Ol100003`001_l0000Y_P8000>n:@001@000ol0
0005030Z66X6QAQZ4VD6E@I51RX6P@Ko1X469@HZ4UD<IA9E32X69@J41RD6Q0HU1RX6E@aU=fX`:PH0
0Ol100002P001_mEiP05l`<000IVlnKVlfH60003o`0000D0<2XHJPJ566XBI@IE1TD6:PJ11_l6P@HU
1RXBE@aU4UD<:PHU1X@69@J41RD6:PIE36DgJS0Z1P01o`40000:0006__?oofgV100012IXJ6H70003
o`0000D0=RX6Q@IZ38DTJPIU1UD6A@KD3<<6P@HZ4UDNI@aE1TD<9@`T1RD6:PIE4fDHJPb51VXf:PH0
0Ol100007`000ol0000503HZ1XD6JPb596X6I@IE1TD6e0c31X46:Q9E7VD<E@I532D<90HU1RX6EA=U
66X<Q@IZ=RX6007o0@0001l000?o00001@0f:PJ51VX<QBAZ1VD6E@I51]@<``J11RXBEAiU35D6A@`U
32@69@HZ1UDCIAQZ38D6JSHZ1P01o`40000O0003o`0000D0=RX6Q@IZ38DTJPIU1UD6A@KD3<<6P@HZ
4UDNI@aE1TD<9@`T1RD6:PIE4fDHJPb51VXf:PH00Ol100007`000ol0000503HZ1XD6JPb596X6I@IE
1TD6e0c31X46:Q9E7VD<E@I532D<90HU1RX6EA=U66X<Q@IZ=RX6007o0@0001l000?o00001@0f:PJ5
1VX<QBAZ1VD6E@I51]@<``J11RXBEAiU35D6A@`U32@69@HZ1UDCIAQZ38D6JSHZ1P01o`40000O00?o
1@0l:Pb596X6I@aE1_@6d`IY1/<6e0I51UD`I@aE1RX69@J11_l6P@HZ1TD6E@IU7fX<QC`Z1@02o`40
000O0003o`0000D0?2X<QBAZ1VD<E@Kd1]<6J@K31]@6A@IE<6D<E@HZ1RD6P@Ko1X46:PI51UD6IAmZ
38Dl:PH00Ol100007`000ol0000503`Z38DTJPIU35D6m0KC1VT6``KD1TD6EC1U35D6:PHU1X46o`J1
1RX6A@IE1VDOJPb5?2X6007o0@0001l000?o00001@0l:Pb596X6I@aE1_@6d`IY1/<6e0I51UD`I@aE
1RX69@J11_l6P@HZ1TD6E@IU7fX<QC`Z1P01o`40000O0003o`0000D0?2X<QBAZ1VD<E@Kd1]<6J@K3
1]@6A@IE<6D<E@HZ1RD6P@Ko1X46:PI51UD6IAmZ38Dl:PH00Ol100007`000ol0000503`Z38DTJPIU
35D6m0KC1VT6``KD1TD6EC1U35D6:PHU1X46o`J11RX6A@IE1VDOJPb5?2X6007o0@0001l000?o0000
1@12:PJ57VX<I@IE1_@6l`I]1VT6d`Kd1TD6EAQU1VXBIA9E1RX6P@c31^@6A@IE1VDUJT8Z1P01o`40
000O0003o`0000D0@RX6QAiZ36D6E@Kd1_<6K@IY1]<6m0I51UDHI@IZ4VDBE@HZ1X4<``KT1TD6E@IU
9FY2:PH00Ol100007`000ol00005048Z1XDNJPaU1UD6m0Kc1Vd6J@KC1_@6A@IE66D6JQ9U4UD6:PJ1
3<<6i0I51UD6IBEZ@RX6007o0@0001l000?o00001@12:PJ57VX<I@IE1_@6l`I]1VT6d`Kd1TD6EAQU
1VXBIA9E1RX6P@c31^@6A@IE1VDUJT8Z1P01o`40000O0003o`0000D0@RX6QAiZ36D6E@Kd1_<6K@IY
1]<6m0I51UDHI@IZ4VDBE@HZ1X4<``KT1TD6E@IU9FY2:PH00Ol100007`000ol00005048Z1XDNJPaU
1UD6m0Kc1Vd6J@KC1_@6A@IE66D6JQ9U4UD6:PJ13<<6i0I51UD6IBEZ@RX6007o0@0001l00ol504PZ
1XDBJQ9U1PD6l`JD36d6l`Kd1UDBIAQZ1VD6JPaU1UD6A@KT1/<6J@KC1_@<E@MU66Y8:PD00_l10000
7`000ol0000504PZ1XDBJQ9U1PD6l`JD36d6l`Kd1UDBIAQZ1VD6JPaU1UD6A@KT1/<6J@KC1_@<E@MU
66Y8:PH00Ol100007`000ol0000504PZ1XDBJQ9U1PD6l`JD36d6l`Kd1UDBIAQZ1VD6JPaU1UD6A@KT
1/<6J@KC1_@<E@MU66Y8:PH00Ol100007`000ol0000504PZ1XDBJQ9U1PD6l`JD36d6l`Kd1UDBIAQZ
1VD6JPaU1UD6A@KT1/<6J@KC1_@<E@MU66Y8:PH00Ol100007`000ol0000504PZ1XDBJQ9U1PD6l`JD
36d6l`Kd1UDBIAQZ1VD6JPaU1UD6A@KT1/<6J@KC1_@<E@MU66Y8:PH00Ol100007`000ol0000504PZ
1XDBJQ9U1PD6l`JD36d6l`Kd1UDBIAQZ1VD6JPaU1UD6A@KT1/<6J@KC1_@<E@MU66Y8:PH00Ol10000
7`000ol0000505@Z36X<I@H51P@HU0Kc1_@6E@IU1VX6IBAZ36D6E@I51_@6d`IY1Vd6l`Kd1UD=I@IZ
E2X6007o0@0001l000?o00001@1D:PaZ36D61@H469@6l`Kd1UD6I@IZ1VDTJPaU1UD6A@Kd1]<6J@I]
1_<6m0IE3FD6JU@Z1P01o`40000O0003o`0000D0E2X<JPaU1PD611RD1_<6m0IE1VD6JPIU96X<I@IE
1TD6m0KC1VT6K@Kc1_@6E@eU1VYD:PH00Ol100007`000ol0000505@Z36X<I@H51P@HU0Kc1_@6E@IU
1VX6IBAZ36D6E@I51_@6d`IY1Vd6l`Kd1UD=I@IZE2X6007o0@0001l000?o00001@1D:PaZ36D61@H4
69@6l`Kd1UD6I@IZ1VDTJPaU1UD6A@Kd1]<6J@I]1_<6m0IE3FD6JU@Z1P01o`40000O0003o`0000D0
E2X<JPaU1PD611RD1_<6m0IE1VD6JPIU96X<I@IE1TD6m0KC1VT6K@Kc1_@6E@eU1VYD:PH00Ol10000
7`03o`D0FRX<I@H51P@6Y0JD3:@6U0Kc1PD6E@IU<6X6I@IZ1VD6E@Kd1_<<K@JD1_<61@eUFRX500;o
0@0001l000?o00001@1J:PaU1PD610JT1Y@<Y0JD1_<61@IE1VD`JPIU1VX6I@IE1_@6l`a]1Y@6l`H5
3FEJ:PH00Ol100007`000ol0000505XZ36D61@H41Z@6U0bT1Y@6l`H51UD6IC1Z1VD6JPIU1UD6m0Kc
36d6U0Kc1PD=IEXZ1P01o`40000O0003o`0000D0FRX<I@H51P@6Y0JD3:@6U0Kc1PD6E@IU<6X6I@IZ
1VD6E@Kd1_<<K@JD1_<61@eUFRX6007o0@0001l000?o00001@1J:PaU1PD610JT1Y@<Y0JD1_<61@IE
1VD`JPIU1VX6I@IE1_@6l`a]1Y@6l`H53FEJ:PH00Ol100007`000ol0000505XZ36D61@H41Z@6U0bT
1Y@6l`H51UD6IC1Z1VD6JPIU1UD6m0Kc36d6U0Kc1PD=IEXZ1P01o`40000O0003o`0000D0IRX610bT
3;@6Y0JD1P@61@aU?6X6I@IE1_@6laRD1PAW:PH00Ol100007`000ol0000506HZ1P@<Y0bd1Z@6U0H4
1PD<ICaZ1VD6E@Kd1_<HU0H4IbX6007o0@0001l000?o00001@1V:PH43:@<]0JT1Y@610H536DlJPIU
1UD6m0Kc69@616LZ1P01o`40000O0003o`0000D0IRX610bT3;@6Y0JD1P@61@aU?6X6I@IE1_@6laRD
1PAW:PH00Ol100007`000ol0000506HZ1P@<Y0bd1Z@6U0H41PD<ICaZ1VD6E@Kd1_<HU0H4IbX6007o
0@0001l000?o00001@1V:PH43:@<]0JT1Y@610H536DlJPIU1UD6m0Kc69@616LZ1P01o`40000O00?o
1@1b:PJd1X4<]0JT1P@61@aU?6X<I@H51_<6U0bTLbX500;o0@0001l000?o00001@1b:PJd1X4<]0JT
1P@61@aU?6X<I@H51_<6U0bTLbX6007o0@0001l000?o00001@1b:PJd1X4<]0JT1P@61@aU?6X<I@H5
1_<6U0bTLbX6007o0@0001l000?o00001@1b:PJd1X4<]0JT1P@61@aU?6X<I@H51_<6U0bTLbX6007o
0@0001l000?o00001@1b:PJd1X4<]0JT1P@61@aU?6X<I@H51_<6U0bTLbX6007o0@0001l000?o0000
1@1b:PJd1X4<]0JT1P@61@aU?6X<I@H51_<6U0bTLbX6007o0@0001l000?o00001@1n:PJ11[@6Y0H4
1PD<IAQZ38DHJPaU1PD610JDObX6007o0@0001l000?o00001@1n:PJ11[@6Y0H41PD<IAQZ38DHJPaU
1PD610JDObX6007o0@0001l000?o00001@1n:PJ11[@6Y0H41PD<IAQZ38DHJPaU1PD610JDObX6007o
0@0000X000JnZ?ooKNH400049VSo1@L000?o00001@1n:PJ11[@6Y0H41PD<IAQZ38DHJPaU1PD610JD
ObX6007o0@0000X000IX_P001O<30006I_?ViZRn1P000ol0000507hZ1X46]0JT1P@61@aU66X<QAQZ
36D61@H41YAo:PH00Ol100003`001_l0000Y_P8000>nl`001@000ol0000507hZ1X46]0JT1P@61@aU
66X<QAQZ36D61@H41YAo:PH00Ol100003P000`FX00020003o`00008000?o00001004o`@0T2X610H5
1VDNJPb566X<II4Z1003o`40000<0004Z?oo9P<000?o00000P000ol000040003o`0000D0T2X610H5
1VDNJPb566X<II4Z1P01o`40000=0003iPGc00<000?o00000P000ol000040003o`0000D0T2X610H5
1VDNJPb566X<II4Z1P01o`40000?0006o`0002Vn0P000khY00050003o`0000D0T2X610H51VDNJPb5
66X<II4Z1P01o`40000:0006Z5D0087c0`001VKci^KcIPH000?o00001@2@:PH41PD6IAiZ38DHJPaU
TBX6007o0@0000X000HV:Ooo:NH400049VQXIPL000?o00001@2@:PH41PD6IAiZ38DHJPaUTBX6007o
0@0001l000?o00001@3o:X8Z1P01o`40000O0003o`0000D0obZ2:PH00Ol100007`000ol000050?lZ
PRX6007o0@0001l000?o00001@3o:X8Z1P01o`40000O0003o`0000D0obZ2:PH00Ol100007`000ol0
00050?lZPRX6007o0@0001l00ooo08`00_l100007`000ol0003o08d00Ol100007`000ol0003o08d0
0Ol100007`000ol0003o08d00Ol100007`000ol0003o08d00Ol100007`000ol0000A0003o`0003T0
00?o0000>@000ol0000i0003o`0003T000?o0000>@000ol0000i0003o`0001000Ol100007`000ol0
00050003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol00004007o0@0001l000?o00001@000ol000090003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00001001o`40000O0?ooTOl10000o`2a0000o`2a0000o`2a0000o`2a0000o`2a0000o`2a0000
\
\>"],
   ImageRangeCache->{{{54.0625, 283.438}, {535.25, 305.875}} -> {-55.5848, \
58.4185, 0.25091, 0.25091}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  DensityGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
     \(\(Image =
         Table[BFlimited[x, y, 64], {x, \(-32\), 32}, {y, \(-32\),
             32}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
     \(ListPlot3D[Image, {PlotRange \[Rule] All}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.20537 .17621 -11.6816 -9 ]
[.20537 .17621 .3184 0 ]
[.40673 .09701 -10.8998 -9 ]
[.40673 .09701 1.10024 0 ]
[.62437 .01148 -10.1179 -9 ]
[.62437 .01148 1.88209 0 ]
[.79751 .14307 0 -6.11733 ]
[.79751 .14307 12 2.88267 ]
[.88618 .27884 0 -5.98862 ]
[.88618 .27884 12 3.01138 ]
[.96394 .39793 0 -5.87889 ]
[.96394 .39793 12 3.12111 ]
[.0184 .30093 -6 -2.77259 ]
[.0184 .30093 0 6.22741 ]
[.00789 .36679 -18 -2.82842 ]
[.00789 .36679 0 6.17158 ]
[-0.00307 .43549 -18 -2.88692 ]
[-0.00307 .43549 0 6.11308 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.2144 .18574 m
.21891 .1905 L
s
[(20)] .20537 .17621 .94693 1 Mshowa
.41503 .10718 m
.41918 .11226 L
s
[(40)] .40673 .09701 .81663 1 Mshowa
.63179 .0223 m
.63551 .02771 L
s
[(60)] .62437 .01148 .68632 1 Mshowa
.125 Mabswid
.07346 .24092 m
.0763 .24365 L
s
.11958 .22286 m
.12238 .22563 L
s
.16655 .20447 m
.16931 .20728 L
s
.26314 .16665 m
.2658 .16956 L
s
.31281 .1472 m
.31541 .15015 L
s
.36343 .12738 m
.36598 .13038 L
s
.46763 .08658 m
.47006 .08968 L
s
.52127 .06557 m
.52364 .06872 L
s
.57598 .04415 m
.57828 .04735 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78517 .1475 m
.77899 .14972 L
s
[(20)] .79751 .14307 -1 .35941 Mshowa
.87372 .28296 m
.86749 .28502 L
s
[(40)] .88618 .27884 -1 .3308 Mshowa
.9514 .40178 m
.94512 .4037 L
s
[(60)] .96394 .39793 -1 .30642 Mshowa
.125 Mabswid
.71016 .03277 m
.70649 .03419 L
s
.73607 .0724 m
.73239 .07379 L
s
.76106 .11062 m
.75736 .11198 L
s
.80845 .18312 m
.80473 .18442 L
s
.83094 .21752 m
.82722 .2188 L
s
.85269 .25079 m
.84896 .25204 L
s
.89408 .3141 m
.89033 .31531 L
s
.91379 .34425 m
.91004 .34545 L
s
.93289 .37346 m
.92913 .37464 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03065 .29622 m
.03677 .29387 L
s
[(0)] .0184 .30093 1 -0.38387 Mshowa
.02019 .36222 m
.02634 .35993 L
s
[(200)] .00789 .36679 1 -0.37146 Mshowa
.00928 .43107 m
.01546 .42885 L
s
[(400)] -0.00307 .43549 1 -0.35846 Mshowa
.125 Mabswid
.02808 .31247 m
.03175 .31106 L
s
.02547 .32888 m
.02916 .32749 L
s
.02285 .34546 m
.02653 .34408 L
s
.01751 .37916 m
.0212 .3778 L
s
.01479 .39627 m
.01849 .39492 L
s
.01205 .41358 m
.01575 .41224 L
s
.0332 .28015 m
.03687 .27873 L
s
.03572 .26424 m
.03938 .26281 L
s
.00648 .44874 m
.01019 .44743 L
s
.00365 .46662 m
.00736 .46531 L
s
.00078 .48469 m
.0045 .48339 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.661 .745 .912 r
.39916 .63215 .40397 .63654 .41205 .63416 .40725 .62976 Metetra
.661 .745 .912 r
.40725 .62976 .41205 .63416 .42015 .63178 .41537 .62737 Metetra
.661 .745 .912 r
.41537 .62737 .42015 .63178 .42827 .62939 .4235 .62497 Metetra
.661 .745 .912 r
.4235 .62497 .42827 .62939 .43642 .627 .43167 .62256 Metetra
.661 .745 .912 r
.43167 .62256 .43642 .627 .44459 .6246 .43986 .62014 Metetra
.661 .745 .912 r
.43986 .62014 .44459 .6246 .45279 .62219 .44807 .61772 Metetra
.661 .745 .912 r
.44807 .61772 .45279 .62219 .46101 .61977 .45631 .61529 Metetra
.661 .745 .912 r
.45631 .61529 .46101 .61977 .46926 .61735 .46457 .61285 Metetra
.661 .745 .912 r
.46457 .61285 .46926 .61735 .47753 .61491 .47286 .61041 Metetra
.661 .745 .912 r
.47286 .61041 .47753 .61491 .48583 .61247 .48117 .60795 Metetra
.661 .745 .912 r
.48117 .60795 .48583 .61247 .49415 .61003 .48951 .60549 Metetra
.661 .745 .912 r
.48951 .60549 .49415 .61003 .5025 .60757 .49788 .60302 Metetra
.661 .745 .912 r
.49788 .60302 .5025 .60757 .51087 .60511 .50627 .60055 Metetra
.661 .745 .912 r
.50627 .60055 .51087 .60511 .51927 .60264 .51468 .59807 Metetra
.661 .745 .912 r
.51468 .59807 .51927 .60264 .5277 .60017 .52312 .59557 Metetra
.661 .745 .912 r
.52312 .59557 .5277 .60017 .53615 .59768 .53159 .59308 Metetra
.661 .745 .912 r
.53159 .59308 .53615 .59768 .54463 .59519 .54009 .59057 Metetra
.661 .745 .912 r
.54009 .59057 .54463 .59519 .55313 .59269 .54861 .58806 Metetra
.661 .745 .912 r
.54861 .58806 .55313 .59269 .56166 .59018 .55715 .58554 Metetra
.661 .745 .912 r
.55715 .58554 .56166 .59018 .57021 .58767 .56573 .58301 Metetra
.661 .745 .912 r
.56573 .58301 .57021 .58767 .5788 .58515 .57433 .58047 Metetra
.661 .745 .912 r
.57433 .58047 .5788 .58515 .5874 .58262 .58295 .57792 Metetra
.661 .745 .912 r
.58295 .57792 .5874 .58262 .59604 .58008 .59161 .57537 Metetra
.661 .745 .912 r
.59161 .57537 .59604 .58008 .6047 .57753 .60029 .57281 Metetra
.809 .774 .821 r
.60029 .57281 .6047 .57753 .61339 .57498 .60886 .56498 Metetra
.718 .629 .758 r
.60886 .56498 .61339 .57498 .62211 .57241 .61749 .55878 Metetra
.483 .454 .75 r
.61749 .55878 .62211 .57241 .63085 .56984 .62641 .56251 Metetra
.814 .709 .749 r
.62641 .56251 .63085 .56984 .63962 .56727 .63492 .55143 Metetra
.638 .528 .713 r
.63492 .55143 .63962 .56727 .64842 .56468 .64369 .54818 Metetra
.443 .403 .719 r
.64369 .54818 .64842 .56468 .65725 .56208 .65283 .55436 Metetra
.813 .703 .744 r
.65283 .55436 .65725 .56208 .6661 .55948 .66134 .54298 Metetra
.729 .621 .738 r
.67935 .54307 .68389 .55425 .69283 .55162 .68805 .53546 Metetra
.535 .465 .723 r
.68805 .53546 .69283 .55162 .7018 .54899 .69726 .5378 Metetra
.64 .577 .768 r
.69726 .5378 .7018 .54899 .71079 .54635 .70627 .53525 Metetra
.73 .624 .74 r
.70627 .53525 .71079 .54635 .71981 .54369 .71501 .52764 Metetra
.628 .522 .715 r
.71501 .52764 .71981 .54369 .72887 .54103 .72406 .52498 Metetra
.453 .415 .726 r
.72406 .52498 .72887 .54103 .73795 .53836 .73366 .53082 Metetra
.566 .613 .859 r
.73366 .53082 .73795 .53836 .74706 .53568 .74295 .53072 Metetra
.661 .745 .912 r
.74295 .53072 .74706 .53568 .75619 .533 .75211 .52802 Metetra
.661 .745 .912 r
.75211 .52802 .75619 .533 .76536 .5303 .7613 .52531 Metetra
.661 .745 .912 r
.7613 .52531 .76536 .5303 .77456 .5276 .77051 .52259 Metetra
.661 .745 .912 r
.77051 .52259 .77456 .5276 .78379 .52489 .77976 .51986 Metetra
.661 .745 .912 r
.77976 .51986 .78379 .52489 .79304 .52217 .78904 .51712 Metetra
.661 .745 .912 r
.78904 .51712 .79304 .52217 .80233 .51944 .79835 .51437 Metetra
.661 .745 .912 r
.79835 .51437 .80233 .51944 .81165 .5167 .80768 .51162 Metetra
.661 .745 .912 r
.80768 .51162 .81165 .5167 .82099 .51395 .81705 .50885 Metetra
.661 .745 .912 r
.81705 .50885 .82099 .51395 .83037 .51119 .82645 .50608 Metetra
.661 .745 .912 r
.82645 .50608 .83037 .51119 .83978 .50843 .83588 .5033 Metetra
.661 .745 .912 r
.83588 .5033 .83978 .50843 .84921 .50565 .84534 .50051 Metetra
.661 .745 .912 r
.84534 .50051 .84921 .50565 .85868 .50287 .85483 .49771 Metetra
.661 .745 .912 r
.85483 .49771 .85868 .50287 .86818 .50008 .86435 .4949 Metetra
.661 .745 .912 r
.86435 .4949 .86818 .50008 .87771 .49728 .8739 .49208 Metetra
.661 .745 .912 r
.8739 .49208 .87771 .49728 .88727 .49447 .88349 .48925 Metetra
.661 .745 .912 r
.88349 .48925 .88727 .49447 .89686 .49165 .8931 .48642 Metetra
.661 .745 .912 r
.8931 .48642 .89686 .49165 .90649 .48882 .90275 .48357 Metetra
.661 .745 .912 r
.90275 .48357 .90649 .48882 .91614 .48598 .91243 .48072 Metetra
.661 .745 .912 r
.91243 .48072 .91614 .48598 .92583 .48313 .92214 .47785 Metetra
.661 .745 .912 r
.92214 .47785 .92583 .48313 .93555 .48028 .93188 .47498 Metetra
.661 .745 .912 r
.93188 .47498 .93555 .48028 .9453 .47741 .94166 .47209 Metetra
.661 .745 .912 r
.94166 .47209 .9453 .47741 .95508 .47453 .95146 .4692 Metetra
.661 .745 .912 r
.95146 .4692 .95508 .47453 .9649 .47165 .9613 .4663 Metetra
.661 .745 .912 r
.9613 .4663 .9649 .47165 .97475 .46875 .97118 .46338 Metetra
.661 .745 .912 r
.39432 .62774 .39916 .63215 .40725 .62976 .40243 .62534 Metetra
.661 .745 .912 r
.40243 .62534 .40725 .62976 .41537 .62737 .41056 .62293 Metetra
.661 .745 .912 r
.41056 .62293 .41537 .62737 .4235 .62497 .41871 .62051 Metetra
.661 .745 .912 r
.41871 .62051 .4235 .62497 .43167 .62256 .42689 .61809 Metetra
.661 .745 .912 r
.42689 .61809 .43167 .62256 .43986 .62014 .43509 .61566 Metetra
.661 .745 .912 r
.43509 .61566 .43986 .62014 .44807 .61772 .44332 .61323 Metetra
.661 .745 .912 r
.44332 .61323 .44807 .61772 .45631 .61529 .45158 .61078 Metetra
.661 .745 .912 r
.45158 .61078 .45631 .61529 .46457 .61285 .45986 .60833 Metetra
.661 .745 .912 r
.45986 .60833 .46457 .61285 .47286 .61041 .46816 .60587 Metetra
.661 .745 .912 r
.46816 .60587 .47286 .61041 .48117 .60795 .47649 .6034 Metetra
.661 .745 .912 r
.47649 .6034 .48117 .60795 .48951 .60549 .48485 .60093 Metetra
.661 .745 .912 r
.48485 .60093 .48951 .60549 .49788 .60302 .49323 .59845 Metetra
.661 .745 .912 r
.49323 .59845 .49788 .60302 .50627 .60055 .50163 .59596 Metetra
.661 .745 .912 r
.50163 .59596 .50627 .60055 .51468 .59807 .51007 .59346 Metetra
.661 .745 .912 r
.51007 .59346 .51468 .59807 .52312 .59557 .51853 .59096 Metetra
.661 .745 .912 r
.51853 .59096 .52312 .59557 .53159 .59308 .52701 .58844 Metetra
.661 .745 .912 r
.52701 .58844 .53159 .59308 .54009 .59057 .53552 .58592 Metetra
.661 .745 .912 r
.53552 .58592 .54009 .59057 .54861 .58806 .54406 .5834 Metetra
.661 .745 .912 r
.54406 .5834 .54861 .58806 .55715 .58554 .55262 .58086 Metetra
.661 .745 .912 r
.55262 .58086 .55715 .58554 .56573 .58301 .56121 .57832 Metetra
.839 .772 .788 r
.56121 .57832 .56573 .58301 .57433 .58047 .56973 .5683 Metetra
.697 .592 .734 r
.56973 .5683 .57433 .58047 .58295 .57792 .57831 .5624 Metetra
.634 .528 .716 r
.57831 .5624 .58295 .57792 .59161 .57537 .58694 .55947 Metetra
.529 .461 .723 r
.58694 .55947 .59161 .57537 .60029 .57281 .59572 .56193 Metetra
.611 .563 .777 r
.59572 .56193 .60029 .57281 .60886 .56498 .60446 .5607 Metetra
.653 .763 .93 r
.60446 .5607 .60886 .56498 .61749 .55878 .6132 .55824 Metetra
.836 .962 .89 r
.6132 .55824 .61749 .55878 .62641 .56251 .62183 .55083 Metetra
.534 .51 .776 r
.62183 .55083 .62641 .56251 .63492 .55143 .63075 .55239 Metetra
.217 .734 .718 r
.63075 .55239 .63492 .55143 .64369 .54818 .63958 .54999 Metetra
.677 .968 .769 r
.63958 .54999 .64369 .54818 .65283 .55436 .64826 .5428 Metetra
.531 .511 .778 r
.64826 .5428 .65283 .55436 .66134 .54298 .65729 .54442 Metetra
.65729 .54442 .66134 .54298 .67043 .54539 .66621 .54211 Metetra
.821 .844 .866 r
.66621 .54211 .67043 .54539 .67935 .54307 .67494 .53484 Metetra
.501 .56 .848 r
.67494 .53484 .67935 .54307 .68805 .53546 .68409 .5364 Metetra
.179 .707 .696 r
.68409 .5364 .68805 .53546 .69726 .5378 .6931 .53415 Metetra
.819 .831 .858 r
.6931 .53415 .69726 .5378 .70627 .53525 .70187 .52675 Metetra
.473 .539 .844 r
.70187 .52675 .70627 .53525 .71501 .52764 .71118 .52902 Metetra
.71118 .52902 .71501 .52764 .72406 .52498 .72025 .52617 Metetra
.725 .986 .802 r
.72025 .52617 .72406 .52498 .73366 .53082 .72907 .51868 Metetra
.669 .582 .748 r
.72907 .51868 .73366 .53082 .74295 .53072 .73809 .51441 Metetra
.626 .52 .714 r
.73809 .51441 .74295 .53072 .75211 .52802 .74724 .51175 Metetra
.455 .415 .725 r
.74724 .51175 .75211 .52802 .7613 .52531 .75702 .51759 Metetra
.809 .711 .757 r
.75702 .51759 .7613 .52531 .77051 .52259 .76568 .507 Metetra
.395 .384 .729 r
.76568 .507 .77051 .52259 .77976 .51986 .77571 .5148 Metetra
.661 .745 .912 r
.77571 .5148 .77976 .51986 .78904 .51712 .78501 .51204 Metetra
.661 .745 .912 r
.78501 .51204 .78904 .51712 .79835 .51437 .79434 .50928 Metetra
.661 .745 .912 r
.79434 .50928 .79835 .51437 .80768 .51162 .8037 .50651 Metetra
.661 .745 .912 r
.8037 .50651 .80768 .51162 .81705 .50885 .81309 .50373 Metetra
.661 .745 .912 r
.81309 .50373 .81705 .50885 .82645 .50608 .82251 .50094 Metetra
.661 .745 .912 r
.82251 .50094 .82645 .50608 .83588 .5033 .83196 .49814 Metetra
.661 .745 .912 r
.83196 .49814 .83588 .5033 .84534 .50051 .84144 .49533 Metetra
.661 .745 .912 r
.84144 .49533 .84534 .50051 .85483 .49771 .85095 .49252 Metetra
.661 .745 .912 r
.85095 .49252 .85483 .49771 .86435 .4949 .8605 .48969 Metetra
.661 .745 .912 r
.8605 .48969 .86435 .4949 .8739 .49208 .87007 .48685 Metetra
.661 .745 .912 r
.87007 .48685 .8739 .49208 .88349 .48925 .87968 .48401 Metetra
.661 .745 .912 r
.87968 .48401 .88349 .48925 .8931 .48642 .88932 .48116 Metetra
.661 .745 .912 r
.88932 .48116 .8931 .48642 .90275 .48357 .89899 .47829 Metetra
.661 .745 .912 r
.89899 .47829 .90275 .48357 .91243 .48072 .90869 .47542 Metetra
.661 .745 .912 r
.90869 .47542 .91243 .48072 .92214 .47785 .91842 .47254 Metetra
.661 .745 .912 r
.91842 .47254 .92214 .47785 .93188 .47498 .92819 .46964 Metetra
.661 .745 .912 r
.92819 .46964 .93188 .47498 .94166 .47209 .93799 .46674 Metetra
.661 .745 .912 r
.93799 .46674 .94166 .47209 .95146 .4692 .94782 .46383 Metetra
.661 .745 .912 r
.94782 .46383 .95146 .4692 .9613 .4663 .95768 .46091 Metetra
.661 .745 .912 r
.95768 .46091 .9613 .4663 .97118 .46338 .96758 .45798 Metetra
.661 .745 .912 r
.38945 .6233 .39432 .62774 .40243 .62534 .39757 .62089 Metetra
.661 .745 .912 r
.39757 .62089 .40243 .62534 .41056 .62293 .40572 .61847 Metetra
.661 .745 .912 r
.40572 .61847 .41056 .62293 .41871 .62051 .41389 .61604 Metetra
.661 .745 .912 r
.41389 .61604 .41871 .62051 .42689 .61809 .42208 .6136 Metetra
.661 .745 .912 r
.42208 .6136 .42689 .61809 .43509 .61566 .4303 .61116 Metetra
.661 .745 .912 r
.4303 .61116 .43509 .61566 .44332 .61323 .43855 .60871 Metetra
.661 .745 .912 r
.43855 .60871 .44332 .61323 .45158 .61078 .44682 .60625 Metetra
.661 .745 .912 r
.44682 .60625 .45158 .61078 .45986 .60833 .45511 .60378 Metetra
.661 .745 .912 r
.45511 .60378 .45986 .60833 .46816 .60587 .46344 .60131 Metetra
.661 .745 .912 r
.46344 .60131 .46816 .60587 .47649 .6034 .47178 .59883 Metetra
.661 .745 .912 r
.47178 .59883 .47649 .6034 .48485 .60093 .48015 .59634 Metetra
.661 .745 .912 r
.48015 .59634 .48485 .60093 .49323 .59845 .48855 .59385 Metetra
.661 .745 .912 r
.48855 .59385 .49323 .59845 .50163 .59596 .49697 .59134 Metetra
.661 .745 .912 r
.49697 .59134 .50163 .59596 .51007 .59346 .50542 .58883 Metetra
.661 .745 .912 r
.50542 .58883 .51007 .59346 .51853 .59096 .5139 .58631 Metetra
.661 .745 .912 r
.5139 .58631 .51853 .59096 .52701 .58844 .5224 .58378 Metetra
.661 .745 .912 r
.5224 .58378 .52701 .58844 .53552 .58592 .53093 .58125 Metetra
.661 .745 .912 r
.53093 .58125 .53552 .58592 .54406 .5834 .53949 .57871 Metetra
.867 .767 .75 r
.53949 .57871 .54406 .5834 .55262 .58086 .548 .56559 Metetra
.631 .527 .718 r
.548 .56559 .55262 .58086 .56121 .57832 .55658 .56289 Metetra
.533 .467 .728 r
.55658 .56289 .56121 .57832 .56973 .5683 .56524 .56506 Metetra
.804 .832 .872 r
.56524 .56506 .56973 .5683 .57831 .5624 .57383 .55848 Metetra
.414 .685 .974 r
.57383 .55848 .57831 .5624 .58694 .55947 .58255 .5592 Metetra
.769 .973 .92 r
.58255 .5592 .58694 .55947 .59572 .56193 .59118 .55323 Metetra
.185 .361 .806 r
.59118 .55323 .59572 .56193 .60446 .5607 .60011 .56003 Metetra
.902 .928 .824 r
.60011 .56003 .60446 .5607 .6132 .55824 .60869 .54972 Metetra
.665 .633 .807 r
.60869 .54972 .6132 .55824 .62183 .55083 .61745 .5466 Metetra
0 .323 .788 r
.61745 .5466 .62183 .55083 .63075 .55239 .6265 .5521 Metetra
.914 .941 .808 r
.6265 .5521 .63075 .55239 .63958 .54999 .63508 .54108 Metetra
.655 .622 .804 r
.63508 .54108 .63958 .54999 .64826 .5428 .64393 .53827 Metetra
0 .324 .797 r
.64393 .53827 .64826 .5428 .65729 .54442 .65314 .54406 Metetra
.915 .943 .807 r
.65314 .54406 .65729 .54442 .66621 .54211 .66173 .53298 Metetra
.685 .632 .79 r
.66173 .53298 .66621 .54211 .67494 .53484 .67061 .52882 Metetra
.279 .512 .9 r
.67061 .52882 .67494 .53484 .68409 .5364 .67987 .53255 Metetra
.639 .788 .953 r
.67987 .53255 .68409 .5364 .6931 .53415 .6889 .53016 Metetra
.849 .816 .816 r
.6889 .53016 .6931 .53415 .70187 .52675 .69759 .52073 Metetra
.591 .675 .899 r
.69759 .52073 .70187 .52675 .71118 .52902 .70674 .51974 Metetra
.319 .431 .819 r
.70674 .51974 .71118 .52902 .72025 .52617 .7163 .52538 Metetra
.931 .927 .781 r
.7163 .52538 .72025 .52617 .72907 .51868 .72486 .51294 Metetra
.488 .638 .922 r
.72486 .51294 .72907 .51868 .73809 .51441 .73422 .51374 Metetra
.76 .974 .922 r
.73422 .51374 .73809 .51441 .74724 .51175 .74318 .50769 Metetra
.375 .661 .969 r
.74318 .50769 .74724 .51175 .75702 .51759 .75266 .50894 Metetra
.648 .629 .817 r
.75266 .50894 .75702 .51759 .76568 .507 .76191 .50636 Metetra
.821 .98 .888 r
.76191 .50636 .76568 .507 .77571 .5148 .77083 .49884 Metetra
.462 .424 .729 r
.77083 .49884 .77571 .5148 .78501 .51204 .78075 .50429 Metetra
.566 .612 .857 r
.78075 .50429 .78501 .51204 .79434 .50928 .79031 .50416 Metetra
.661 .745 .912 r
.79031 .50416 .79434 .50928 .8037 .50651 .79969 .50137 Metetra
.661 .745 .912 r
.79969 .50137 .8037 .50651 .81309 .50373 .8091 .49857 Metetra
.661 .745 .912 r
.8091 .49857 .81309 .50373 .82251 .50094 .81854 .49577 Metetra
.661 .745 .912 r
.81854 .49577 .82251 .50094 .83196 .49814 .82801 .49295 Metetra
.661 .745 .912 r
.82801 .49295 .83196 .49814 .84144 .49533 .83752 .49013 Metetra
.661 .745 .912 r
.83752 .49013 .84144 .49533 .85095 .49252 .84705 .48729 Metetra
.661 .745 .912 r
.84705 .48729 .85095 .49252 .8605 .48969 .85662 .48445 Metetra
.661 .745 .912 r
.85662 .48445 .8605 .48969 .87007 .48685 .86622 .48159 Metetra
.661 .745 .912 r
.86622 .48159 .87007 .48685 .87968 .48401 .87585 .47873 Metetra
.661 .745 .912 r
.87585 .47873 .87968 .48401 .88932 .48116 .88551 .47586 Metetra
.661 .745 .912 r
.88551 .47586 .88932 .48116 .89899 .47829 .8952 .47298 Metetra
.661 .745 .912 r
.8952 .47298 .89899 .47829 .90869 .47542 .90493 .47009 Metetra
.661 .745 .912 r
.90493 .47009 .90869 .47542 .91842 .47254 .91468 .46719 Metetra
.661 .745 .912 r
.91468 .46719 .91842 .47254 .92819 .46964 .92447 .46428 Metetra
.661 .745 .912 r
.92447 .46428 .92819 .46964 .93799 .46674 .9343 .46136 Metetra
.661 .745 .912 r
.9343 .46136 .93799 .46674 .94782 .46383 .94415 .45843 Metetra
.661 .745 .912 r
.94415 .45843 .94782 .46383 .95768 .46091 .95404 .45549 Metetra
.661 .745 .912 r
.95404 .45549 .95768 .46091 .96758 .45798 .96396 .45254 Metetra
.661 .745 .912 r
.38456 .61884 .38945 .6233 .39757 .62089 .3927 .61641 Metetra
.661 .745 .912 r
.3927 .61641 .39757 .62089 .40572 .61847 .40086 .61398 Metetra
.661 .745 .912 r
.40086 .61398 .40572 .61847 .41389 .61604 .40904 .61153 Metetra
.661 .745 .912 r
.40904 .61153 .41389 .61604 .42208 .6136 .41725 .60909 Metetra
.661 .745 .912 r
.41725 .60909 .42208 .6136 .4303 .61116 .42549 .60663 Metetra
.661 .745 .912 r
.42549 .60663 .4303 .61116 .43855 .60871 .43375 .60416 Metetra
.661 .745 .912 r
.43375 .60416 .43855 .60871 .44682 .60625 .44203 .60169 Metetra
.661 .745 .912 r
.44203 .60169 .44682 .60625 .45511 .60378 .45035 .59921 Metetra
.661 .745 .912 r
.45035 .59921 .45511 .60378 .46344 .60131 .45868 .59673 Metetra
.661 .745 .912 r
.45868 .59673 .46344 .60131 .47178 .59883 .46705 .59423 Metetra
.661 .745 .912 r
.46705 .59423 .47178 .59883 .48015 .59634 .47543 .59173 Metetra
.661 .745 .912 r
.47543 .59173 .48015 .59634 .48855 .59385 .48385 .58922 Metetra
.661 .745 .912 r
.48385 .58922 .48855 .59385 .49697 .59134 .49229 .5867 Metetra
.661 .745 .912 r
.49229 .5867 .49697 .59134 .50542 .58883 .50076 .58417 Metetra
.661 .745 .912 r
.50076 .58417 .50542 .58883 .5139 .58631 .50925 .58164 Metetra
.661 .745 .912 r
.50925 .58164 .5139 .58631 .5224 .58378 .51777 .5791 Metetra
.865 .765 .75 r
.51777 .5791 .5224 .58378 .53093 .58125 .52631 .56601 Metetra
.53 .467 .729 r
.52631 .56601 .53093 .58125 .53949 .57871 .53487 .56818 Metetra
.714 .62 .75 r
.53487 .56818 .53949 .57871 .548 .56559 .54343 .56192 Metetra
.658 .792 .946 r
.54343 .56192 .548 .56559 .55658 .56289 .55203 .5593 Metetra
.25 .617 .957 r
.55203 .5593 .55658 .56289 .56524 .56506 .56071 .56115 Metetra
.677 .787 .932 r
.56071 .56115 .56524 .56506 .57383 .55848 .56937 .55816 Metetra
.839 .965 .886 r
.56937 .55816 .57383 .55848 .58255 .5592 .57799 .55061 Metetra
.381 .484 .84 r
.57799 .55061 .58255 .5592 .59118 .55323 .58681 .55443 Metetra
.23 .741 .703 r
.58681 .55443 .59118 .55323 .60011 .56003 .59556 .55175 Metetra
.732 .666 .785 r
.59556 .55175 .60011 .56003 .60869 .54972 .60426 .54565 Metetra
.44 .692 .972 r
.60426 .54565 .60869 .54972 .61745 .5466 .61314 .54616 Metetra
.525 .906 .947 r
.61314 .54616 .61745 .5466 .6265 .5521 .62196 .54313 Metetra
.728 .653 .775 r
.62196 .54313 .6265 .5521 .63508 .54108 .63071 .53689 Metetra
.411 .673 .968 r
.63071 .53689 .63508 .54108 .64393 .53827 .63971 .53779 Metetra
.748 .971 .929 r
.63971 .53779 .64393 .53827 .65314 .54406 .64852 .5321 Metetra
.585 .537 .768 r
.64852 .5321 .65314 .54406 .66173 .53298 .65755 .5318 Metetra
.762 .947 .939 r
.65755 .5318 .66173 .53298 .67061 .52882 .6664 .52625 Metetra
.303 .705 .977 r
.6664 .52625 .67061 .52882 .67987 .53255 .67554 .52687 Metetra
.755 .745 .843 r
.67554 .52687 .67987 .53255 .6889 .53016 .68442 .52109 Metetra
.704 .644 .786 r
.68442 .52109 .6889 .53016 .69759 .52073 .69336 .51603 Metetra
.624 .744 .933 r
.69336 .51603 .69759 .52073 .70674 .51974 .70247 .51409 Metetra
.366 .579 .923 r
.70247 .51409 .70674 .51974 .7163 .52538 .71187 .51653 Metetra
.752 .669 .769 r
.71187 .51653 .7163 .52538 .72486 .51294 .72073 .50892 Metetra
.718 .807 .92 r
.72073 .50892 .72486 .51294 .73422 .51374 .72981 .50478 Metetra
.478 .533 .835 r
.72981 .50478 .73422 .51374 .74318 .50769 .73932 .50707 Metetra
.421 .857 .931 r
.73932 .50707 .74318 .50769 .75266 .50894 .74859 .50478 Metetra
.81 .82 .858 r
.74859 .50478 .75266 .50894 .76191 .50636 .75754 .49751 Metetra
.664 .633 .809 r
.75754 .49751 .76191 .50636 .77083 .49884 .76679 .49427 Metetra
.393 .646 .958 r
.76679 .49427 .77083 .49884 .78075 .50429 .77642 .49567 Metetra
.648 .632 .82 r
.77642 .49567 .78075 .50429 .79031 .50416 .78578 .49306 Metetra
.73 .629 .746 r
.78578 .49306 .79031 .50416 .79969 .50137 .79478 .48548 Metetra
.396 .383 .728 r
.79478 .48548 .79969 .50137 .8091 .49857 .80509 .49338 Metetra
.661 .745 .912 r
.80509 .49338 .8091 .49857 .81854 .49577 .81455 .49056 Metetra
.661 .745 .912 r
.81455 .49056 .81854 .49577 .82801 .49295 .82405 .48773 Metetra
.661 .745 .912 r
.82405 .48773 .82801 .49295 .83752 .49013 .83357 .48489 Metetra
.661 .745 .912 r
.83357 .48489 .83752 .49013 .84705 .48729 .84313 .48203 Metetra
.661 .745 .912 r
.84313 .48203 .84705 .48729 .85662 .48445 .85272 .47917 Metetra
.661 .745 .912 r
.85272 .47917 .85662 .48445 .86622 .48159 .86234 .4763 Metetra
.661 .745 .912 r
.86234 .4763 .86622 .48159 .87585 .47873 .87199 .47342 Metetra
.661 .745 .912 r
.87199 .47342 .87585 .47873 .88551 .47586 .88168 .47054 Metetra
.661 .745 .912 r
.88168 .47054 .88551 .47586 .8952 .47298 .89139 .46764 Metetra
.661 .745 .912 r
.89139 .46764 .8952 .47298 .90493 .47009 .90114 .46473 Metetra
.661 .745 .912 r
.90114 .46473 .90493 .47009 .91468 .46719 .91092 .46181 Metetra
.661 .745 .912 r
.91092 .46181 .91468 .46719 .92447 .46428 .92074 .45888 Metetra
.661 .745 .912 r
.92074 .45888 .92447 .46428 .9343 .46136 .93058 .45594 Metetra
.661 .745 .912 r
.93058 .45594 .9343 .46136 .94415 .45843 .94046 .453 Metetra
.661 .745 .912 r
.94046 .453 .94415 .45843 .95404 .45549 .95038 .45004 Metetra
.661 .745 .912 r
.95038 .45004 .95404 .45549 .96396 .45254 .96032 .44707 Metetra
.661 .745 .912 r
.37964 .61435 .38456 .61884 .3927 .61641 .38779 .61191 Metetra
.661 .745 .912 r
.38779 .61191 .3927 .61641 .40086 .61398 .39596 .60946 Metetra
.661 .745 .912 r
.39596 .60946 .40086 .61398 .40904 .61153 .40417 .60701 Metetra
.661 .745 .912 r
.40417 .60701 .40904 .61153 .41725 .60909 .41239 .60454 Metetra
.661 .745 .912 r
.41239 .60454 .41725 .60909 .42549 .60663 .42064 .60207 Metetra
.661 .745 .912 r
.42064 .60207 .42549 .60663 .43375 .60416 .42892 .59959 Metetra
.661 .745 .912 r
.42892 .59959 .43375 .60416 .44203 .60169 .43722 .59711 Metetra
.661 .745 .912 r
.43722 .59711 .44203 .60169 .45035 .59921 .44555 .59461 Metetra
.661 .745 .912 r
.44555 .59461 .45035 .59921 .45868 .59673 .4539 .59211 Metetra
.661 .745 .912 r
.4539 .59211 .45868 .59673 .46705 .59423 .46228 .5896 Metetra
.661 .745 .912 r
.46228 .5896 .46705 .59423 .47543 .59173 .47069 .58709 Metetra
.661 .745 .912 r
.47069 .58709 .47543 .59173 .48385 .58922 .47912 .58456 Metetra
.661 .745 .912 r
.47912 .58456 .48385 .58922 .49229 .5867 .48758 .58203 Metetra
.661 .745 .912 r
.48758 .58203 .49229 .5867 .50076 .58417 .49606 .57949 Metetra
.745 .763 .868 r
.49606 .57949 .50076 .58417 .50925 .58164 .50458 .57458 Metetra
.796 .705 .764 r
.50458 .57458 .50925 .58164 .51777 .5791 .51314 .56511 Metetra
.637 .542 .73 r
.51314 .56511 .51777 .5791 .52631 .56601 .52168 .56226 Metetra
.703 .798 .924 r
.52168 .56226 .52631 .56601 .53487 .56818 .53024 .55872 Metetra
.639 .601 .795 r
.53024 .55872 .53487 .56818 .54343 .56192 .53883 .55647 Metetra
.604 .696 .908 r
.53883 .55647 .54343 .56192 .55203 .5593 .54746 .55517 Metetra
.256 .593 .949 r
.54746 .55517 .55203 .5593 .56071 .56115 .55615 .55738 Metetra
.822 .81 .84 r
.55615 .55738 .56071 .56115 .56937 .55816 .56478 .54958 Metetra
.484 .542 .841 r
.56478 .54958 .56937 .55816 .57799 .55061 .57354 .55148 Metetra
.692 .981 .87 r
.57354 .55148 .57799 .55061 .58681 .55443 .58223 .54556 Metetra
.486 .537 .835 r
.58223 .54556 .58681 .55443 .59556 .55175 .59108 .54752 Metetra
.668 .774 .929 r
.59108 .54752 .59556 .55175 .60426 .54565 .59987 .54469 Metetra
.844 .943 .886 r
.59987 .54469 .60426 .54565 .61314 .54616 .60858 .53705 Metetra
.599 .591 .815 r
.60858 .53705 .61314 .54616 .62196 .54313 .61747 .53615 Metetra
.212 .436 .861 r
.61747 .53615 .62196 .54313 .63071 .53689 .62657 .54124 Metetra
.66 .891 .542 r
.62657 .54124 .63071 .53689 .63971 .53779 .63523 .53036 Metetra
.707 .678 .82 r
.63523 .53036 .63971 .53779 .64852 .5321 .64409 .52584 Metetra
.574 .659 .895 r
.64409 .52584 .64852 .5321 .65755 .5318 .65312 .52523 Metetra
.181 .432 .864 r
.65312 .52523 .65755 .5318 .6664 .52625 .66244 .53044 Metetra
.656 .887 .536 r
.66244 .53044 .6664 .52625 .67554 .52687 .67111 .51947 Metetra
.705 .68 .824 r
.67111 .51947 .67554 .52687 .68442 .52109 .68008 .51504 Metetra
.582 .672 .901 r
.68008 .51504 .68442 .52109 .69336 .51603 .68924 .51421 Metetra
.179 .666 .924 r
.68924 .51421 .69336 .51603 .70247 .51409 .69852 .51501 Metetra
.759 .995 .828 r
.69852 .51501 .70247 .51409 .71187 .51653 .7074 .50738 Metetra
.645 .617 .807 r
.7074 .50738 .71187 .51653 .72073 .50892 .71657 .50484 Metetra
.741 .81 .907 r
.71657 .50484 .72073 .50892 .72981 .50478 .72564 .50007 Metetra
.641 .753 .93 r
.72564 .50007 .72981 .50478 .73932 .50707 .73487 .49772 Metetra
.278 .407 .813 r
.73487 .49772 .73932 .50707 .74859 .50478 .74473 .50416 Metetra
.913 .953 .806 r
.74473 .50416 .74859 .50478 .75754 .49751 .75345 .49302 Metetra
.638 .764 .939 r
.75345 .49302 .75754 .49751 .76679 .49427 .76279 .49067 Metetra
.435 .721 .986 r
.76279 .49067 .76679 .49427 .77642 .49567 .77235 .49087 Metetra
.793 .796 .855 r
.77235 .49087 .77642 .49567 .78578 .49306 .78141 .48394 Metetra
.657 .626 .807 r
.78141 .48394 .78578 .49306 .79478 .48548 .79078 .4809 Metetra
.396 .649 .959 r
.79078 .4809 .79478 .48548 .80509 .49338 .80056 .48225 Metetra
.728 .629 .748 r
.80056 .48225 .80509 .49338 .81455 .49056 .80963 .47479 Metetra
.4 .388 .73 r
.80963 .47479 .81455 .49056 .82405 .48773 .82005 .48247 Metetra
.661 .745 .912 r
.82005 .48247 .82405 .48773 .83357 .48489 .8296 .47961 Metetra
.661 .745 .912 r
.8296 .47961 .83357 .48489 .84313 .48203 .83918 .47675 Metetra
.661 .745 .912 r
.83918 .47675 .84313 .48203 .85272 .47917 .84879 .47387 Metetra
.661 .745 .912 r
.84879 .47387 .85272 .47917 .86234 .4763 .85844 .47098 Metetra
.661 .745 .912 r
.85844 .47098 .86234 .4763 .87199 .47342 .86811 .46808 Metetra
.661 .745 .912 r
.86811 .46808 .87199 .47342 .88168 .47054 .87782 .46518 Metetra
.661 .745 .912 r
.87782 .46518 .88168 .47054 .89139 .46764 .88756 .46226 Metetra
.661 .745 .912 r
.88756 .46226 .89139 .46764 .90114 .46473 .89733 .45933 Metetra
.661 .745 .912 r
.89733 .45933 .90114 .46473 .91092 .46181 .90714 .4564 Metetra
.661 .745 .912 r
.90714 .4564 .91092 .46181 .92074 .45888 .91698 .45345 Metetra
.661 .745 .912 r
.91698 .45345 .92074 .45888 .93058 .45594 .92685 .4505 Metetra
.661 .745 .912 r
.92685 .4505 .93058 .45594 .94046 .453 .93675 .44753 Metetra
.661 .745 .912 r
.93675 .44753 .94046 .453 .95038 .45004 .94669 .44455 Metetra
.661 .745 .912 r
.94669 .44455 .95038 .45004 .96032 .44707 .95666 .44157 Metetra
.661 .745 .912 r
.37469 .60984 .37964 .61435 .38779 .61191 .38285 .60739 Metetra
.661 .745 .912 r
.38285 .60739 .38779 .61191 .39596 .60946 .39105 .60492 Metetra
.661 .745 .912 r
.39105 .60492 .39596 .60946 .40417 .60701 .39926 .60245 Metetra
.661 .745 .912 r
.39926 .60245 .40417 .60701 .41239 .60454 .4075 .59998 Metetra
.661 .745 .912 r
.4075 .59998 .41239 .60454 .42064 .60207 .41577 .59749 Metetra
.661 .745 .912 r
.41577 .59749 .42064 .60207 .42892 .59959 .42406 .595 Metetra
.661 .745 .912 r
.42406 .595 .42892 .59959 .43722 .59711 .43238 .5925 Metetra
.661 .745 .912 r
.43238 .5925 .43722 .59711 .44555 .59461 .44073 .58999 Metetra
.661 .745 .912 r
.44073 .58999 .44555 .59461 .4539 .59211 .4491 .58748 Metetra
.661 .745 .912 r
.4491 .58748 .4539 .59211 .46228 .5896 .45749 .58495 Metetra
.661 .745 .912 r
.45749 .58495 .46228 .5896 .47069 .58709 .46591 .58242 Metetra
.661 .745 .912 r
.46591 .58242 .47069 .58709 .47912 .58456 .47436 .57988 Metetra
.661 .745 .912 r
.47436 .57988 .47912 .58456 .48758 .58203 .48284 .57733 Metetra
.753 .764 .862 r
.48284 .57733 .48758 .58203 .49606 .57949 .49136 .57213 Metetra
.79 .698 .763 r
.49136 .57213 .49606 .57949 .50458 .57458 .49993 .56285 Metetra
.639 .567 .757 r
.49993 .56285 .50458 .57458 .51314 .56511 .50846 .56027 Metetra
.387 .628 .949 r
.50846 .56027 .51314 .56511 .52168 .56226 .51701 .56175 Metetra
.782 .96 .925 r
.51701 .56175 .52168 .56226 .53024 .55872 .5256 .5558 Metetra
.666 .834 .964 r
.5256 .5558 .53024 .55872 .53883 .55647 .53421 .55284 Metetra
.199 .588 .943 r
.53421 .55284 .53883 .55647 .54746 .55517 .54288 .55505 Metetra
.803 .975 .904 r
.54288 .55505 .54746 .55517 .55615 .55738 .55152 .54833 Metetra
.559 .571 .823 r
.55152 .54833 .55615 .55738 .56478 .54958 .56025 .54857 Metetra
.777 .944 .933 r
.56025 .54857 .56478 .54958 .57354 .55148 .56894 .54284 Metetra
.611 .606 .822 r
.56894 .54284 .57354 .55148 .58223 .54556 .57771 .54157 Metetra
.243 .594 .949 r
.57771 .54157 .58223 .54556 .59108 .54752 .58658 .54379 Metetra
.829 .817 .838 r
.58658 .54379 .59108 .54752 .59987 .54469 .59528 .53563 Metetra
.662 .623 .8 r
.59528 .53563 .59987 .54469 .60858 .53705 .60411 .53251 Metetra
.544 .718 .953 r
.60411 .53251 .60858 .53705 .61747 .53615 .61302 .5319 Metetra
.48 .705 .968 r
.61302 .5319 .61747 .53615 .62657 .54124 .622 .53201 Metetra
.752 .66 .76 r
.622 .53201 .62657 .54124 .63523 .53036 .63076 .52413 Metetra
.66 .696 .873 r
.63076 .52413 .63523 .53036 .64409 .52584 .63971 .52146 Metetra
.544 .727 .959 r
.63971 .52146 .64409 .52584 .65312 .52523 .64876 .52076 Metetra
.662 .767 .928 r
.64876 .52076 .65312 .52523 .66244 .53044 .65777 .51801 Metetra
.567 .523 .765 r
.65777 .51801 .66244 .53044 .67111 .51947 .66693 .51836 Metetra
.848 .948 .883 r
.66693 .51836 .67111 .51947 .68008 .51504 .67577 .51045 Metetra
.258 .57 .939 r
.67577 .51045 .68008 .51504 .68924 .51421 .68513 .51318 Metetra
.751 .957 .939 r
.68513 .51318 .68924 .51421 .69852 .51501 .69412 .50759 Metetra
.532 .605 .871 r
.69412 .50759 .69852 .51501 .7074 .50738 .70345 .50811 Metetra
.863 .995 .806 r
.70345 .50811 .7074 .50738 .71657 .50484 .71224 .49831 Metetra
.631 .679 .877 r
.71224 .49831 .71657 .50484 .72564 .50007 .7215 .49635 Metetra
.213 .589 .946 r
.7215 .49635 .72564 .50007 .73487 .49772 .73106 .49878 Metetra
.409 .853 .763 r
.73106 .49878 .73487 .49772 .74473 .50416 .74025 .49456 Metetra
.708 .641 .78 r
.74025 .49456 .74473 .50416 .75345 .49302 .74937 .48907 Metetra
.73 .819 .92 r
.74937 .48907 .75345 .49302 .76279 .49067 .75858 .48454 Metetra
.657 .706 .884 r
.75858 .48454 .76279 .49067 .77235 .49087 .76795 .48184 Metetra
.535 .566 .833 r
.76795 .48184 .77235 .49087 .78141 .48394 .77762 .4827 Metetra
.802 .963 .912 r
.77762 .4827 .78141 .48394 .79078 .4809 .78673 .47586 Metetra
.678 .758 .912 r
.78673 .47586 .79078 .4809 .80056 .48225 .79614 .47259 Metetra
.523 .547 .822 r
.79614 .47259 .80056 .48225 .80963 .47479 .80598 .47395 Metetra
.826 .98 .884 r
.80598 .47395 .80963 .47479 .82005 .48247 .81506 .46614 Metetra
.394 .38 .725 r
.81506 .46614 .82005 .48247 .8296 .47961 .82561 .47431 Metetra
.661 .745 .912 r
.82561 .47431 .8296 .47961 .83918 .47675 .83521 .47142 Metetra
.661 .745 .912 r
.83521 .47142 .83918 .47675 .84879 .47387 .84485 .46853 Metetra
.661 .745 .912 r
.84485 .46853 .84879 .47387 .85844 .47098 .85451 .46562 Metetra
.661 .745 .912 r
.85451 .46562 .85844 .47098 .86811 .46808 .86421 .46271 Metetra
.661 .745 .912 r
.86421 .46271 .86811 .46808 .87782 .46518 .87394 .45978 Metetra
.661 .745 .912 r
.87394 .45978 .87782 .46518 .88756 .46226 .88371 .45685 Metetra
.661 .745 .912 r
.88371 .45685 .88756 .46226 .89733 .45933 .8935 .45391 Metetra
.661 .745 .912 r
.8935 .45391 .89733 .45933 .90714 .4564 .90333 .45095 Metetra
.661 .745 .912 r
.90333 .45095 .90714 .4564 .91698 .45345 .91319 .44799 Metetra
.661 .745 .912 r
.91319 .44799 .91698 .45345 .92685 .4505 .92309 .44501 Metetra
.661 .745 .912 r
.92309 .44501 .92685 .4505 .93675 .44753 .93302 .44203 Metetra
.661 .745 .912 r
.93302 .44203 .93675 .44753 .94669 .44455 .94298 .43903 Metetra
.661 .745 .912 r
.94298 .43903 .94669 .44455 .95666 .44157 .95297 .43603 Metetra
.661 .745 .912 r
.36971 .6053 .37469 .60984 .38285 .60739 .37789 .60283 Metetra
.661 .745 .912 r
.37789 .60283 .38285 .60739 .39105 .60492 .3861 .60036 Metetra
.661 .745 .912 r
.3861 .60036 .39105 .60492 .39926 .60245 .39433 .59787 Metetra
.661 .745 .912 r
.39433 .59787 .39926 .60245 .4075 .59998 .40259 .59538 Metetra
.661 .745 .912 r
.40259 .59538 .4075 .59998 .41577 .59749 .41087 .59288 Metetra
.661 .745 .912 r
.41087 .59288 .41577 .59749 .42406 .595 .41918 .59038 Metetra
.661 .745 .912 r
.41918 .59038 .42406 .595 .43238 .5925 .42752 .58786 Metetra
.661 .745 .912 r
.42752 .58786 .43238 .5925 .44073 .58999 .43588 .58534 Metetra
.661 .745 .912 r
.43588 .58534 .44073 .58999 .4491 .58748 .44426 .58281 Metetra
.661 .745 .912 r
.44426 .58281 .4491 .58748 .45749 .58495 .45267 .58027 Metetra
.661 .745 .912 r
.45267 .58027 .45749 .58495 .46591 .58242 .46111 .57773 Metetra
.661 .745 .912 r
.46111 .57773 .46591 .58242 .47436 .57988 .46958 .57517 Metetra
.813 .768 .811 r
.46958 .57517 .47436 .57988 .48284 .57733 .47815 .56688 Metetra
.722 .624 .748 r
.47815 .56688 .48284 .57733 .49136 .57213 .4867 .56018 Metetra
.632 .561 .756 r
.4867 .56018 .49136 .57213 .49993 .56285 .49521 .55789 Metetra
.399 .629 .947 r
.49521 .55789 .49993 .56285 .50846 .56027 .50374 .55928 Metetra
.801 .938 .919 r
.50374 .55928 .50846 .56027 .51701 .56175 .51233 .55309 Metetra
.657 .626 .807 r
.51233 .55309 .51701 .56175 .5256 .5558 .52094 .55028 Metetra
.583 .688 .913 r
.52094 .55028 .5256 .5558 .53421 .55284 .52957 .54936 Metetra
.278 .643 .966 r
.52957 .54936 .53421 .55284 .54288 .55505 .53824 .55083 Metetra
.783 .793 .861 r
.53824 .55083 .54288 .55505 .55152 .54833 .54692 .5446 Metetra
.756 .813 .898 r
.54692 .5446 .55152 .54833 .56025 .54857 .55561 .53956 Metetra
.361 .465 .831 r
.55561 .53956 .56025 .54857 .56894 .54284 .56443 .54379 Metetra
.698 .983 .864 r
.56443 .54379 .56894 .54284 .57771 .54157 .57316 .53767 Metetra
.473 .72 .978 r
.57316 .53767 .57771 .54157 .58658 .54379 .58201 .53765 Metetra
.587 .669 .896 r
.58201 .53765 .58658 .54379 .59528 .53563 .59088 .53674 Metetra
.822 .999 .831 r
.59088 .53674 .59528 .53563 .60411 .53251 .59962 .52829 Metetra
.675 .779 .929 r
.59962 .52829 .60411 .53251 .61302 .5319 .60849 .52526 Metetra
.572 .646 .885 r
.60849 .52526 .61302 .5319 .622 .53201 .61746 .52475 Metetra
.136 .381 .836 r
.61746 .52475 .622 .53201 .63076 .52413 .62667 .53087 Metetra
.62667 .53087 .63076 .52413 .63971 .52146 .63536 .51886 Metetra
.759 .878 .933 r
.63536 .51886 .63971 .52146 .64876 .52076 .64428 .51374 Metetra
.652 .671 .855 r
.64428 .51374 .64876 .52076 .65777 .51801 .65331 .51119 Metetra
.637 .671 .866 r
.65331 .51119 .65777 .51801 .66693 .51836 .66238 .50908 Metetra
.348 .453 .826 r
.66238 .50908 .66693 .51836 .67577 .51045 .6718 .51393 Metetra
.495 .831 .542 r
.6718 .51393 .67577 .51045 .68513 .51318 .68068 .50585 Metetra
.707 .686 .827 r
.68068 .50585 .68513 .51318 .69412 .50759 .68974 .5013 Metetra
.675 .705 .87 r
.68974 .5013 .69412 .50759 .70345 .50811 .6989 .49812 Metetra
.532 .544 .812 r
.6989 .49812 .70345 .50811 .71224 .49831 .70831 .49923 Metetra
.751 .994 .823 r
.70831 .49923 .71224 .49831 .7215 .49635 .71727 .49159 Metetra
.632 .75 .933 r
.71727 .49159 .7215 .49635 .73106 .49878 .72657 .48939 Metetra
.304 .424 .819 r
.72657 .48939 .73106 .49878 .74025 .49456 .73641 .49529 Metetra
.922 .975 .752 r
.73641 .49529 .74025 .49456 .74937 .48907 .74511 .48269 Metetra
.635 .689 .884 r
.74511 .48269 .74937 .48907 .75858 .48454 .75451 .48058 Metetra
.652 .798 .952 r
.75451 .48058 .75858 .48454 .76795 .48184 .76389 .47777 Metetra
.387 .674 .973 r
.76389 .47777 .76795 .48184 .77762 .4827 .77359 .47879 Metetra
.823 .84 .861 r
.77359 .47879 .77762 .4827 .78673 .47586 .78266 .47103 Metetra
.704 .777 .909 r
.78266 .47103 .78673 .47586 .79614 .47259 .79205 .4671 Metetra
.676 .741 .9 r
.79205 .4671 .79614 .47259 .80598 .47395 .80152 .46387 Metetra
.616 .59 .801 r
.80152 .46387 .80598 .47395 .81506 .46614 .81116 .46223 Metetra
.651 .805 .957 r
.81116 .46223 .81506 .46614 .82561 .47431 .82072 .45937 Metetra
.414 .406 .742 r
.82072 .45937 .82561 .47431 .83521 .47142 .83122 .46607 Metetra
.661 .745 .912 r
.83122 .46607 .83521 .47142 .84485 .46853 .84087 .46316 Metetra
.661 .745 .912 r
.84087 .46316 .84485 .46853 .85451 .46562 .85056 .46023 Metetra
.661 .745 .912 r
.85056 .46023 .85451 .46562 .86421 .46271 .86029 .4573 Metetra
.661 .745 .912 r
.86029 .4573 .86421 .46271 .87394 .45978 .87004 .45436 Metetra
.661 .745 .912 r
.87004 .45436 .87394 .45978 .88371 .45685 .87983 .45141 Metetra
.661 .745 .912 r
.87983 .45141 .88371 .45685 .8935 .45391 .88965 .44844 Metetra
.661 .745 .912 r
.88965 .44844 .8935 .45391 .90333 .45095 .8995 .44547 Metetra
.661 .745 .912 r
.8995 .44547 .90333 .45095 .91319 .44799 .90939 .44249 Metetra
.661 .745 .912 r
.90939 .44249 .91319 .44799 .92309 .44501 .91931 .4395 Metetra
.661 .745 .912 r
.91931 .4395 .92309 .44501 .93302 .44203 .92926 .43649 Metetra
.661 .745 .912 r
.92926 .43649 .93302 .44203 .94298 .43903 .93925 .43348 Metetra
.661 .745 .912 r
.93925 .43348 .94298 .43903 .95297 .43603 .94927 .43046 Metetra
.661 .745 .912 r
.3647 .60074 .36971 .6053 .37789 .60283 .3729 .59826 Metetra
.661 .745 .912 r
.3729 .59826 .37789 .60283 .3861 .60036 .38112 .59577 Metetra
.661 .745 .912 r
.38112 .59577 .3861 .60036 .39433 .59787 .38937 .59327 Metetra
.661 .745 .912 r
.38937 .59327 .39433 .59787 .40259 .59538 .39765 .59076 Metetra
.661 .745 .912 r
.39765 .59076 .40259 .59538 .41087 .59288 .40595 .58825 Metetra
.661 .745 .912 r
.40595 .58825 .41087 .59288 .41918 .59038 .41427 .58573 Metetra
.661 .745 .912 r
.41427 .58573 .41918 .59038 .42752 .58786 .42262 .5832 Metetra
.661 .745 .912 r
.42262 .5832 .42752 .58786 .43588 .58534 .431 .58066 Metetra
.661 .745 .912 r
.431 .58066 .43588 .58534 .44426 .58281 .4394 .57812 Metetra
.661 .745 .912 r
.4394 .57812 .44426 .58281 .45267 .58027 .44783 .57557 Metetra
.861 .761 .751 r
.44783 .57557 .45267 .58027 .46111 .57773 .4565 .56258 Metetra
.527 .466 .731 r
.4565 .56258 .46111 .57773 .46958 .57517 .46487 .56465 Metetra
.613 .57 .783 r
.46487 .56465 .46958 .57517 .47815 .56688 .47334 .56326 Metetra
.827 .808 .832 r
.47334 .56326 .47815 .56688 .4867 .56018 .48194 .55513 Metetra
.608 .715 .921 r
.48194 .55513 .4867 .56018 .49521 .55789 .49046 .55367 Metetra
.233 .579 .944 r
.49046 .55367 .49521 .55789 .50374 .55928 .49899 .556 Metetra
.833 .825 .841 r
.49899 .556 .50374 .55928 .51233 .55309 .50762 .5479 Metetra
.601 .708 .919 r
.50762 .5479 .51233 .55309 .52094 .55028 .51624 .54656 Metetra
.256 .619 .958 r
.51624 .54656 .52094 .55028 .52957 .54936 .52489 .54836 Metetra
.802 .941 .918 r
.52489 .54836 .52957 .54936 .53824 .55083 .53356 .54205 Metetra
.672 .632 .801 r
.53356 .54205 .53824 .55083 .54692 .5446 .54227 .53859 Metetra
.582 .671 .9 r
.54227 .53859 .54692 .5446 .55561 .53956 .55101 .53775 Metetra
.68 .899 .975 r
.55101 .53775 .55561 .53956 .56443 .54379 .55976 .53405 Metetra
.578 .57 .808 r
.55976 .53405 .56443 .54379 .57316 .53767 .56858 .53377 Metetra
.263 .613 .956 r
.56858 .53377 .57316 .53767 .58201 .53765 .57748 .53571 Metetra
.865 .891 .852 r
.57748 .53571 .58201 .53765 .59088 .53674 .58623 .52686 Metetra
.684 .62 .778 r
.58623 .52686 .59088 .53674 .59962 .52829 .59507 .52252 Metetra
.196 .481 .895 r
.59507 .52252 .59962 .52829 .60849 .52526 .60413 .52662 Metetra
.74 .992 .821 r
.60413 .52662 .60849 .52526 .61746 .52475 .61295 .51921 Metetra
.638 .715 .903 r
.61295 .51921 .61746 .52475 .62667 .53087 .62193 .51705 Metetra
.625 .54 .739 r
.62193 .51705 .62667 .53087 .63536 .51886 .63093 .51475 Metetra
.399 .676 .972 r
.63093 .51475 .63536 .51886 .64428 .51374 .64008 .51562 Metetra
.718 .978 .763 r
.64008 .51562 .64428 .51374 .65331 .51119 .64894 .50758 Metetra
.537 .768 .983 r
.64894 .50758 .65331 .51119 .66238 .50908 .65809 .50656 Metetra
.697 .877 .966 r
.65809 .50656 .66238 .50908 .6718 .51393 .66715 .50267 Metetra
.619 .569 .776 r
.66715 .50267 .6718 .51393 .68068 .50585 .67633 .50089 Metetra
.44 .656 .952 r
.67633 .50089 .68068 .50585 .68974 .5013 .68568 .50182 Metetra
.878 .99 .812 r
.68568 .50182 .68974 .5013 .6989 .49812 .69452 .49177 Metetra
.642 .692 .881 r
.69452 .49177 .6989 .49812 .70831 .49923 .70376 .48947 Metetra
.62 .595 .804 r
.70376 .48947 .70831 .49923 .71727 .49159 .71308 .48775 Metetra
.657 .804 .953 r
.71308 .48775 .71727 .49159 .72657 .48939 .72236 .48485 Metetra
.406 .66 .963 r
.72236 .48485 .72657 .48939 .73641 .49529 .73191 .48595 Metetra
.714 .65 .784 r
.73191 .48595 .73641 .49529 .74511 .48269 .74108 .48025 Metetra
.709 .893 .964 r
.74108 .48025 .74511 .48269 .75451 .48058 .75036 .47593 Metetra
.709 .785 .911 r
.75036 .47593 .75451 .48058 .76389 .47777 .75968 .47189 Metetra
.655 .718 .894 r
.75968 .47189 .76389 .47777 .77359 .47879 .76912 .46919 Metetra
.527 .552 .824 r
.76912 .46919 .77359 .47879 .78266 .47103 .7789 .47034 Metetra
.813 .983 .889 r
.7789 .47034 .78266 .47103 .79205 .4671 .78803 .46278 Metetra
.639 .781 .949 r
.78803 .46278 .79205 .4671 .80152 .46387 .79758 .46024 Metetra
.417 .716 .986 r
.79758 .46024 .80152 .46387 .81116 .46223 .80742 .46056 Metetra
.804 .951 .915 r
.80742 .46056 .81116 .46223 .82072 .45937 .81667 .4537 Metetra
.656 .73 .904 r
.81667 .4537 .82072 .45937 .83122 .46607 .8263 .45093 Metetra
.484 .449 .743 r
.8263 .45093 .83122 .46607 .84087 .46316 .83662 .45504 Metetra
.566 .61 .856 r
.83662 .45504 .84087 .46316 .85056 .46023 .84659 .45481 Metetra
.661 .745 .912 r
.84659 .45481 .85056 .46023 .86029 .4573 .85633 .45186 Metetra
.661 .745 .912 r
.85633 .45186 .86029 .4573 .87004 .45436 .86611 .4489 Metetra
.661 .745 .912 r
.86611 .4489 .87004 .45436 .87983 .45141 .87592 .44593 Metetra
.661 .745 .912 r
.87592 .44593 .87983 .45141 .88965 .44844 .88577 .44295 Metetra
.661 .745 .912 r
.88577 .44295 .88965 .44844 .8995 .44547 .89564 .43996 Metetra
.661 .745 .912 r
.89564 .43996 .8995 .44547 .90939 .44249 .90556 .43696 Metetra
.661 .745 .912 r
.90556 .43696 .90939 .44249 .91931 .4395 .9155 .43394 Metetra
.661 .745 .912 r
.9155 .43394 .91931 .4395 .92926 .43649 .92548 .43092 Metetra
.661 .745 .912 r
.92548 .43092 .92926 .43649 .93925 .43348 .93549 .42789 Metetra
.661 .745 .912 r
.93549 .42789 .93925 .43348 .94927 .43046 .94553 .42485 Metetra
.661 .745 .912 r
.35967 .59615 .3647 .60074 .3729 .59826 .36788 .59365 Metetra
.661 .745 .912 r
.36788 .59365 .3729 .59826 .38112 .59577 .37612 .59115 Metetra
.661 .745 .912 r
.37612 .59115 .38112 .59577 .38937 .59327 .38439 .58864 Metetra
.661 .745 .912 r
.38439 .58864 .38937 .59327 .39765 .59076 .39268 .58612 Metetra
.661 .745 .912 r
.39268 .58612 .39765 .59076 .40595 .58825 .40099 .58359 Metetra
.661 .745 .912 r
.40099 .58359 .40595 .58825 .41427 .58573 .40933 .58105 Metetra
.661 .745 .912 r
.40933 .58105 .41427 .58573 .42262 .5832 .4177 .57851 Metetra
.661 .745 .912 r
.4177 .57851 .42262 .5832 .431 .58066 .42609 .57596 Metetra
.661 .745 .912 r
.42609 .57596 .431 .58066 .4394 .57812 .43451 .5734 Metetra
.859 .761 .753 r
.43451 .5734 .4394 .57812 .44783 .57557 .4432 .56057 Metetra
.529 .469 .732 r
.4432 .56057 .44783 .57557 .4565 .56258 .45155 .56247 Metetra
.557 .922 .943 r
.45155 .56247 .4565 .56258 .46487 .56465 .46005 .55916 Metetra
.722 .732 .859 r
.46005 .55916 .46487 .56465 .47334 .56326 .46859 .55475 Metetra
.672 .636 .805 r
.46859 .55475 .47334 .56326 .48194 .55513 .47713 .55139 Metetra
.224 .6 .95 r
.47713 .55139 .48194 .55513 .49046 .55367 .48563 .55338 Metetra
.302 .791 .887 r
.48563 .55338 .49046 .55367 .49899 .556 .49422 .55194 Metetra
.817 .797 .833 r
.49422 .55194 .49899 .556 .50762 .5479 .50288 .54409 Metetra
.017 .463 .873 r
.50288 .54409 .50762 .5479 .51624 .54656 .51149 .5476 Metetra
.832 .995 .849 r
.51149 .5476 .51624 .54656 .52489 .54836 .52018 .53935 Metetra
.484 .536 .834 r
.52018 .53935 .52489 .54836 .53356 .54205 .52888 .54122 Metetra
.819 .947 .906 r
.52888 .54122 .53356 .54205 .54227 .53859 .5376 .53436 Metetra
.674 .777 .927 r
.5376 .53436 .54227 .53859 .55101 .53775 .54635 .53137 Metetra
.473 .61 .906 r
.54635 .53137 .55101 .53775 .55976 .53405 .55516 .5325 Metetra
.649 .906 .982 r
.55516 .5325 .55976 .53405 .56858 .53377 .56397 .52906 Metetra
.445 .668 .958 r
.56397 .52906 .56858 .53377 .57748 .53571 .57286 .52977 Metetra
.72 .726 .855 r
.57286 .52977 .57748 .53571 .58623 .52686 .5817 .52524 Metetra
.77 .923 .937 r
.5817 .52524 .58623 .52686 .59507 .52252 .59055 .51972 Metetra
.644 .845 .977 r
.59055 .51972 .59507 .52252 .60413 .52662 .59947 .51689 Metetra
.66 .613 .791 r
.59947 .51689 .60413 .52662 .61295 .51921 .60841 .51366 Metetra
.654 .721 .898 r
.60841 .51366 .61295 .51921 .62193 .51705 .6174 .51112 Metetra
.534 .658 .915 r
.6174 .51112 .62193 .51705 .63093 .51475 .62649 .51108 Metetra
.652 .806 .957 r
.62649 .51108 .63093 .51475 .64008 .51562 .63554 .50834 Metetra
.662 .67 .847 r
.63554 .50834 .64008 .51562 .64894 .50758 .64461 .50544 Metetra
.094 .596 .896 r
.64461 .50544 .64894 .50758 .65809 .50656 .65388 .50707 Metetra
.871 .99 .823 r
.65388 .50707 .65809 .50656 .66715 .50267 .66274 .49738 Metetra
.665 .739 .905 r
.66274 .49738 .66715 .50267 .67633 .50089 .67189 .4945 Metetra
.659 .697 .875 r
.67189 .4945 .67633 .50089 .68568 .50182 .68108 .49175 Metetra
.643 .602 .793 r
.68108 .49175 .68568 .50182 .69452 .49177 .6903 .48909 Metetra
.158 .614 .933 r
.6903 .48909 .69452 .49177 .70376 .48947 .69979 .49085 Metetra
.825 .997 .774 r
.69979 .49085 .70376 .48947 .71308 .48775 .7087 .48109 Metetra
.579 .656 .89 r
.7087 .48109 .71308 .48775 .72236 .48485 .71812 .48033 Metetra
0 .28 .762 r
.71812 .48033 .72236 .48485 .73191 .48595 .72804 .48702 Metetra
.917 .979 .739 r
.72804 .48702 .73191 .48595 .74108 .48025 .73679 .47418 Metetra
.664 .714 .886 r
.73679 .47418 .74108 .48025 .75036 .47593 .74619 .47125 Metetra
.708 .785 .912 r
.74619 .47125 .75036 .47593 .75968 .47189 .75553 .46722 Metetra
.636 .762 .939 r
.75553 .46722 .75968 .47189 .76912 .46919 .76502 .46484 Metetra
0 .322 .792 r
.76502 .46484 .76912 .46919 .7789 .47034 .77521 .47112 Metetra
.911 .982 .743 r
.77521 .47112 .7789 .47034 .78803 .46278 .784 .45859 Metetra
.433 .695 .975 r
.784 .45859 .78803 .46278 .79758 .46024 .79383 .45911 Metetra
.811 .971 .902 r
.79383 .45911 .79758 .46024 .80742 .46056 .80305 .45182 Metetra
.541 .581 .844 r
.80305 .45182 .80742 .46056 .81667 .4537 .81297 .45236 Metetra
.612 .925 .971 r
.81297 .45236 .81667 .4537 .8263 .45093 .82254 .44858 Metetra
.78 .921 .931 r
.82254 .44858 .8263 .45093 .83662 .45504 .83193 .44249 Metetra
.457 .464 .777 r
.83193 .44249 .83662 .45504 .84659 .45481 .84233 .44663 Metetra
.566 .61 .856 r
.84233 .44663 .84659 .45481 .85633 .45186 .85236 .44639 Metetra
.661 .745 .912 r
.85236 .44639 .85633 .45186 .86611 .4489 .86216 .44341 Metetra
.661 .745 .912 r
.86216 .44341 .86611 .4489 .87592 .44593 .872 .44042 Metetra
.661 .745 .912 r
.872 .44042 .87592 .44593 .88577 .44295 .88186 .43742 Metetra
.661 .745 .912 r
.88186 .43742 .88577 .44295 .89564 .43996 .89177 .43441 Metetra
.661 .745 .912 r
.89177 .43441 .89564 .43996 .90556 .43696 .9017 .43139 Metetra
.661 .745 .912 r
.9017 .43139 .90556 .43696 .9155 .43394 .91167 .42836 Metetra
.661 .745 .912 r
.91167 .42836 .9155 .43394 .92548 .43092 .92167 .42532 Metetra
.661 .745 .912 r
.92167 .42532 .92548 .43092 .93549 .42789 .93171 .42227 Metetra
.661 .745 .912 r
.93171 .42227 .93549 .42789 .94553 .42485 .94178 .41921 Metetra
.661 .745 .912 r
.35461 .59154 .35967 .59615 .36788 .59365 .36284 .58902 Metetra
.661 .745 .912 r
.36284 .58902 .36788 .59365 .37612 .59115 .37109 .58651 Metetra
.661 .745 .912 r
.37109 .58651 .37612 .59115 .38439 .58864 .37937 .58398 Metetra
.661 .745 .912 r
.37937 .58398 .38439 .58864 .39268 .58612 .38768 .58145 Metetra
.661 .745 .912 r
.38768 .58145 .39268 .58612 .40099 .58359 .39601 .5789 Metetra
.661 .745 .912 r
.39601 .5789 .40099 .58359 .40933 .58105 .40436 .57635 Metetra
.661 .745 .912 r
.40436 .57635 .40933 .58105 .4177 .57851 .41275 .5738 Metetra
.661 .745 .912 r
.41275 .5738 .4177 .57851 .42609 .57596 .42116 .57123 Metetra
.747 .762 .865 r
.42116 .57123 .42609 .57596 .43451 .5734 .42966 .56622 Metetra
.814 .706 .746 r
.42966 .56622 .43451 .5734 .4432 .56057 .43834 .55485 Metetra
.371 .583 .925 r
.43834 .55485 .4432 .56057 .45155 .56247 .4467 .55687 Metetra
.723 .729 .855 r
.4467 .55687 .45155 .56247 .46005 .55916 .45523 .55241 Metetra
.675 .68 .847 r
.45523 .55241 .46005 .55916 .46859 .55475 .46376 .54928 Metetra
.378 .598 .933 r
.46376 .54928 .46859 .55475 .47713 .55139 .47224 .5511 Metetra
.309 .795 .891 r
.47224 .5511 .47713 .55139 .48563 .55338 .48081 .54961 Metetra
.827 .807 .831 r
.48081 .54961 .48563 .55338 .49422 .55194 .48949 .54137 Metetra
.551 .54 .795 r
.48949 .54137 .49422 .55194 .50288 .54409 .49809 .54193 Metetra
.772 .887 .928 r
.49809 .54193 .50288 .54409 .51149 .5476 .50676 .53659 Metetra
.596 .557 .781 r
.50676 .53659 .51149 .5476 .52018 .53935 .51544 .53571 Metetra
.721 .814 .923 r
.51544 .53571 .52018 .53935 .52888 .54122 .52416 .53164 Metetra
.368 .457 .821 r
.52416 .53164 .52888 .54122 .5376 .53436 .53292 .5359 Metetra
.728 .99 .827 r
.53292 .5359 .5376 .53436 .54635 .53137 .54168 .52879 Metetra
.602 .842 .99 r
.54168 .52879 .54635 .53137 .55516 .5325 .55049 .52651 Metetra
.527 .652 .914 r
.55049 .52651 .55516 .5325 .56397 .52906 .55935 .52661 Metetra
.3 .714 .975 r
.55935 .52661 .56397 .52906 .57286 .52977 .56825 .52702 Metetra
.843 .862 .858 r
.56825 .52702 .57286 .52977 .5817 .52524 .57707 .51886 Metetra
.724 .715 .841 r
.57707 .51886 .5817 .52524 .59055 .51972 .58595 .51401 Metetra
.517 .659 .925 r
.58595 .51401 .59055 .51972 .59947 .51689 .59495 .51416 Metetra
.665 .856 .973 r
.59495 .51416 .59947 .51689 .60841 .51366 .60392 .51094 Metetra
.634 .849 .982 r
.60392 .51094 .60841 .51366 .6174 .51112 .61293 .50818 Metetra
.655 .844 .973 r
.61293 .50818 .6174 .51112 .62649 .51108 .62195 .50517 Metetra
.667 .715 .884 r
.62195 .50517 .62649 .51108 .63554 .50834 .63101 .50223 Metetra
.662 .707 .881 r
.63101 .50223 .63554 .50834 .64461 .50544 .6401 .49942 Metetra
.66 .709 .885 r
.6401 .49942 .64461 .50544 .65388 .50707 .64922 .49667 Metetra
.643 .596 .787 r
.64922 .49667 .65388 .50707 .66274 .49738 .65838 .49398 Metetra
.639 .819 .969 r
.65838 .49398 .66274 .49738 .67189 .4945 .66757 .49132 Metetra
.68 .843 .961 r
.66757 .49132 .67189 .4945 .68108 .49175 .67675 .48785 Metetra
.742 .822 .914 r
.67675 .48785 .68108 .49175 .6903 .48909 .68589 .48301 Metetra
.642 .704 .891 r
.68589 .48301 .6903 .48909 .69979 .49085 .69518 .48066 Metetra
.643 .601 .792 r
.69518 .48066 .69979 .49085 .7087 .48109 .70449 .47797 Metetra
0 .467 .856 r
.70449 .47797 .7087 .48109 .71812 .48033 .71418 .48159 Metetra
.433 .863 .751 r
.71418 .48159 .71812 .48033 .72804 .48702 .72345 .4769 Metetra
.697 .63 .778 r
.72345 .4769 .72804 .48702 .73679 .47418 .73271 .47176 Metetra
.722 .899 .959 r
.73271 .47176 .73679 .47418 .74619 .47125 .74202 .46713 Metetra
.738 .819 .914 r
.74202 .46713 .74619 .47125 .75553 .46722 .75134 .46229 Metetra
.401 .641 .954 r
.75134 .46229 .75553 .46722 .76502 .46484 .76113 .46367 Metetra
.826 .966 .895 r
.76113 .46367 .76502 .46484 .77521 .47112 .7703 .45604 Metetra
.413 .405 .741 r
.7703 .45604 .77521 .47112 .784 .45859 .78057 .46252 Metetra
.675 .878 .501 r
.78057 .46252 .784 .45859 .79383 .45911 .7894 .45006 Metetra
.541 .574 .838 r
.7894 .45006 .79383 .45911 .80305 .45182 .7993 .45064 Metetra
.815 .971 .899 r
.7993 .45064 .80305 .45182 .81297 .45236 .80855 .4432 Metetra
.539 .571 .836 r
.80855 .4432 .81297 .45236 .82254 .44858 .81855 .44386 Metetra
.706 .791 .917 r
.81855 .44386 .82254 .44858 .83193 .44249 .82815 .43977 Metetra
.834 .909 .889 r
.82815 .43977 .83193 .44249 .84233 .44663 .83743 .43201 Metetra
.613 .532 .739 r
.83743 .43201 .84233 .44663 .85236 .44639 .84728 .43003 Metetra
.399 .386 .728 r
.84728 .43003 .85236 .44639 .86216 .44341 .85819 .43788 Metetra
.661 .745 .912 r
.85819 .43788 .86216 .44341 .872 .44042 .86804 .43487 Metetra
.661 .745 .912 r
.86804 .43487 .872 .44042 .88186 .43742 .87794 .43185 Metetra
.661 .745 .912 r
.87794 .43185 .88186 .43742 .89177 .43441 .88786 .42883 Metetra
.661 .745 .912 r
.88786 .42883 .89177 .43441 .9017 .43139 .89782 .42579 Metetra
.661 .745 .912 r
.89782 .42579 .9017 .43139 .91167 .42836 .90781 .42274 Metetra
.661 .745 .912 r
.90781 .42274 .91167 .42836 .92167 .42532 .91784 .41968 Metetra
.661 .745 .912 r
.91784 .41968 .92167 .42532 .93171 .42227 .9279 .41661 Metetra
.661 .745 .912 r
.9279 .41661 .93171 .42227 .94178 .41921 .938 .41353 Metetra
.661 .745 .912 r
.34952 .58689 .35461 .59154 .36284 .58902 .35776 .58437 Metetra
.661 .745 .912 r
.35776 .58437 .36284 .58902 .37109 .58651 .36603 .58184 Metetra
.661 .745 .912 r
.36603 .58184 .37109 .58651 .37937 .58398 .37433 .57929 Metetra
.661 .745 .912 r
.37433 .57929 .37937 .58398 .38768 .58145 .38265 .57675 Metetra
.661 .745 .912 r
.38265 .57675 .38768 .58145 .39601 .5789 .39099 .57419 Metetra
.661 .745 .912 r
.39099 .57419 .39601 .5789 .40436 .57635 .39937 .57162 Metetra
.661 .745 .912 r
.39937 .57162 .40436 .57635 .41275 .5738 .40777 .56905 Metetra
.746 .762 .865 r
.40777 .56905 .41275 .5738 .42116 .57123 .41627 .56404 Metetra
.793 .702 .764 r
.41627 .56404 .42116 .57123 .42966 .56622 .42492 .5546 Metetra
.568 .531 .774 r
.42492 .5546 .42966 .56622 .43834 .55485 .4333 .55472 Metetra
.256 .764 .859 r
.4333 .55472 .43834 .55485 .4467 .55687 .44176 .55344 Metetra
.797 .82 .87 r
.44176 .55344 .4467 .55687 .45523 .55241 .45036 .547 Metetra
.372 .6 .935 r
.45036 .547 .45523 .55241 .46376 .54928 .45881 .54881 Metetra
.345 .813 .916 r
.45881 .54881 .46376 .54928 .47224 .5511 .46737 .54727 Metetra
.827 .804 .829 r
.46737 .54727 .47224 .5511 .48081 .54961 .47606 .53896 Metetra
.559 .543 .793 r
.47606 .53896 .48081 .54961 .48949 .54137 .48464 .53927 Metetra
.668 .879 .977 r
.48464 .53927 .48949 .54137 .49809 .54193 .4933 .53594 Metetra
.697 .714 .862 r
.4933 .53594 .49809 .54193 .50676 .53659 .50198 .53221 Metetra
.567 .737 .956 r
.50198 .53221 .50676 .53659 .51544 .53571 .51068 .53116 Metetra
.636 .753 .933 r
.51068 .53116 .51544 .53571 .52416 .53164 .51941 .52898 Metetra
.642 .849 .979 r
.51941 .52898 .52416 .53164 .53292 .5359 .52818 .52619 Metetra
.569 .568 .812 r
.52818 .52619 .53292 .5359 .54168 .52879 .53698 .52609 Metetra
.633 .845 .981 r
.53698 .52609 .54168 .52879 .55049 .52651 .5458 .52341 Metetra
.649 .83 .97 r
.5458 .52341 .55049 .52651 .55935 .52661 .55466 .52062 Metetra
.255 .511 .905 r
.55466 .52062 .55935 .52661 .56825 .52702 .56361 .52414 Metetra
.85 .855 .846 r
.56361 .52414 .56825 .52702 .57707 .51886 .57246 .51547 Metetra
.75 .837 .918 r
.57246 .51547 .57707 .51886 .58595 .51401 .58136 .51055 Metetra
.695 .826 .945 r
.58136 .51055 .58595 .51401 .59495 .51416 .59031 .50695 Metetra
.68 .679 .842 r
.59031 .50695 .59495 .51416 .60392 .51094 .59929 .50345 Metetra
.669 .667 .839 r
.59929 .50345 .60392 .51094 .61293 .50818 .60829 .50028 Metetra
.74 .685 .798 r
.60829 .50028 .61293 .50818 .62195 .50517 .61724 .494 Metetra
.492 .501 .794 r
.61724 .494 .62195 .50517 .63101 .50223 .62647 .49634 Metetra
.651 .712 .892 r
.62647 .49634 .63101 .50223 .6401 .49942 .63559 .4938 Metetra
.644 .72 .903 r
.63559 .4938 .6401 .49942 .64922 .49667 .64474 .49142 Metetra
.651 .737 .913 r
.64474 .49142 .64922 .49667 .65838 .49398 .65392 .48886 Metetra
.653 .744 .917 r
.65392 .48886 .65838 .49398 .66757 .49132 .66313 .48623 Metetra
.803 .784 .835 r
.66313 .48623 .66757 .49132 .67675 .48785 .67215 .47855 Metetra
.649 .621 .808 r
.67215 .47855 .67675 .48785 .68589 .48301 .6814 .47573 Metetra
.5 .599 .884 r
.6814 .47573 .68589 .48301 .69518 .48066 .69087 .47671 Metetra
.761 .827 .904 r
.69087 .47671 .69518 .48066 .70449 .47797 .70006 .47127 Metetra
.564 .65 .893 r
.70006 .47127 .70449 .47797 .71418 .48159 .70954 .47078 Metetra
.471 .498 .805 r
.70954 .47078 .71418 .48159 .72345 .4769 .71926 .47365 Metetra
.803 .868 .896 r
.71926 .47365 .72345 .4769 .73271 .47176 .72845 .46694 Metetra
.742 .79 .891 r
.72845 .46694 .73271 .47176 .74202 .46713 .73776 .46186 Metetra
.611 .728 .929 r
.73776 .46186 .74202 .46713 .75134 .46229 .74731 .46007 Metetra
.804 .921 .915 r
.74731 .46007 .75134 .46229 .76113 .46367 .75655 .45337 Metetra
.62 .591 .799 r
.75655 .45337 .76113 .46367 .7703 .45604 .76616 .45149 Metetra
.709 .796 .919 r
.76616 .45149 .7703 .45604 .78057 .46252 .77563 .44736 Metetra
.411 .403 .741 r
.77563 .44736 .78057 .46252 .7894 .45006 .78598 .4539 Metetra
.676 .881 .506 r
.78598 .4539 .7894 .45006 .7993 .45064 .79486 .44149 Metetra
.541 .573 .837 r
.79486 .44149 .7993 .45064 .80855 .4432 .80482 .44206 Metetra
.812 .974 .899 r
.80482 .44206 .80855 .4432 .81855 .44386 .81412 .4346 Metetra
.527 .564 .836 r
.81412 .4346 .81855 .44386 .82815 .43977 .82421 .43556 Metetra
.716 .82 .93 r
.82421 .43556 .82815 .43977 .83743 .43201 .83384 .43119 Metetra
.385 .836 .925 r
.83384 .43119 .83743 .43201 .84728 .43003 .84372 .42907 Metetra
.815 .984 .886 r
.84372 .42907 .84728 .43003 .85819 .43788 .85307 .42125 Metetra
.397 .382 .726 r
.85307 .42125 .85819 .43788 .86804 .43487 .86407 .42929 Metetra
.661 .745 .912 r
.86407 .42929 .86804 .43487 .87794 .43185 .87398 .42625 Metetra
.661 .745 .912 r
.87398 .42625 .87794 .43185 .88786 .42883 .88393 .42321 Metetra
.661 .745 .912 r
.88393 .42321 .88786 .42883 .89782 .42579 .89392 .42015 Metetra
.661 .745 .912 r
.89392 .42015 .89782 .42579 .90781 .42274 .90394 .41708 Metetra
.661 .745 .912 r
.90394 .41708 .90781 .42274 .91784 .41968 .91399 .414 Metetra
.661 .745 .912 r
.91399 .414 .91784 .41968 .9279 .41661 .92408 .41091 Metetra
.661 .745 .912 r
.92408 .41091 .9279 .41661 .938 .41353 .9342 .40781 Metetra
.661 .745 .912 r
.34439 .58223 .34952 .58689 .35776 .58437 .35265 .57969 Metetra
.661 .745 .912 r
.35265 .57969 .35776 .58437 .36603 .58184 .36094 .57714 Metetra
.661 .745 .912 r
.36094 .57714 .36603 .58184 .37433 .57929 .36925 .57458 Metetra
.661 .745 .912 r
.36925 .57458 .37433 .57929 .38265 .57675 .37759 .57202 Metetra
.661 .745 .912 r
.37759 .57202 .38265 .57675 .39099 .57419 .38595 .56945 Metetra
.661 .745 .912 r
.38595 .56945 .39099 .57419 .39937 .57162 .39434 .56687 Metetra
.661 .745 .912 r
.39434 .56687 .39937 .57162 .40777 .56905 .40276 .56428 Metetra
.85 .761 .764 r
.40276 .56428 .40777 .56905 .41627 .56404 .41151 .55245 Metetra
.557 .526 .776 r
.41151 .55245 .41627 .56404 .42492 .5546 .41986 .55288 Metetra
.528 .854 .997 r
.41986 .55288 .42492 .5546 .4333 .55472 .42832 .55103 Metetra
.788 .809 .869 r
.42832 .55103 .4333 .55472 .44176 .55344 .43693 .54482 Metetra
.478 .543 .844 r
.43693 .54482 .44176 .55344 .45036 .547 .44535 .54655 Metetra
.813 .955 .909 r
.44535 .54655 .45036 .547 .45881 .54881 .454 .53987 Metetra
.613 .603 .817 r
.454 .53987 .45881 .54881 .46737 .54727 .46256 .53843 Metetra
.481 .539 .84 r
.46256 .53843 .46737 .54727 .47606 .53896 .4711 .54019 Metetra
.4711 .54019 .47606 .53896 .48464 .53927 .47973 .53879 Metetra
.878 .937 .853 r
.47973 .53879 .48464 .53927 .4933 .53594 .48848 .52969 Metetra
.491 .626 .91 r
.48848 .52969 .4933 .53594 .50198 .53221 .49715 .5304 Metetra
.696 .901 .97 r
.49715 .5304 .50198 .53221 .51068 .53116 .50589 .52646 Metetra
.493 .693 .957 r
.50589 .52646 .51068 .53116 .51941 .52898 .51463 .52651 Metetra
.632 .857 .984 r
.51463 .52651 .51941 .52898 .52818 .52619 .52342 .52376 Metetra
.672 .869 .973 r
.52342 .52376 .52818 .52619 .53698 .52609 .53223 .52039 Metetra
.245 .519 .912 r
.53223 .52039 .53698 .52609 .5458 .52341 .54111 .52372 Metetra
.939 .927 .767 r
.54111 .52372 .5458 .52341 .55466 .52062 .54991 .51021 Metetra
.516 .527 .806 r
.54991 .51021 .55466 .52062 .56361 .52414 .55885 .51165 Metetra
.566 .523 .767 r
.55885 .51165 .56361 .52414 .57246 .51547 .56781 .51184 Metetra
.518 .761 .985 r
.56781 .51184 .57246 .51547 .58136 .51055 .57681 .51102 Metetra
.377 .843 .841 r
.57681 .51102 .58136 .51055 .59031 .50695 .5858 .50811 Metetra
.281 .777 .733 r
.5858 .50811 .59031 .50695 .59929 .50345 .59482 .50509 Metetra
.248 .744 .666 r
.59482 .50509 .59929 .50345 .60829 .50028 .60387 .50174 Metetra
.60387 .50174 .60829 .50028 .61724 .494 .61295 .49885 Metetra
.209 0 0 r
.61295 .49885 .61724 .494 .62647 .49634 .62206 .49603 Metetra
.456 .879 .922 r
.62206 .49603 .62647 .49634 .63559 .4938 .63121 .49323 Metetra
.493 .892 .944 r
.63121 .49323 .63559 .4938 .64474 .49142 .64038 .49036 Metetra
.459 .862 .965 r
.64038 .49036 .64474 .49142 .65392 .48886 .64961 .48821 Metetra
.503 .895 .948 r
.64961 .48821 .65392 .48886 .66313 .48623 .65884 .48527 Metetra
.527 .897 .966 r
.65884 .48527 .66313 .48623 .67215 .47855 .6681 .48239 Metetra
.6681 .48239 .67215 .47855 .6814 .47573 .67722 .47572 Metetra
.236 .753 .825 r
.67722 .47572 .6814 .47573 .69087 .47671 .6866 .47411 Metetra
.717 .886 .958 r
.6866 .47411 .69087 .47671 .70006 .47127 .69587 .46967 Metetra
.829 .941 .899 r
.69587 .46967 .70006 .47127 .70954 .47078 .705 .46219 Metetra
.564 .597 .845 r
.705 .46219 .70954 .47078 .71926 .47365 .71455 .46201 Metetra
.482 .491 .791 r
.71455 .46201 .71926 .47365 .72845 .46694 .72433 .46482 Metetra
.763 .921 .941 r
.72433 .46482 .72845 .46694 .73776 .46186 .73364 .45917 Metetra
.769 .895 .932 r
.73364 .45917 .73776 .46186 .74731 .46007 .74296 .45347 Metetra
.653 .697 .878 r
.74296 .45347 .74731 .46007 .75655 .45337 .7525 .45076 Metetra
.684 .885 .972 r
.7525 .45076 .75655 .45337 .76616 .45149 .76199 .44681 Metetra
.71 .792 .915 r
.76199 .44681 .76616 .45149 .77563 .44736 .77149 .44262 Metetra
.703 .788 .917 r
.77149 .44262 .77563 .44736 .78598 .4539 .78102 .43862 Metetra
.498 .457 .742 r
.78102 .43862 .78598 .4539 .79486 .44149 .79118 .44193 Metetra
.839 .999 .803 r
.79118 .44193 .79486 .44149 .80482 .44206 .80031 .43222 Metetra
.519 .548 .825 r
.80031 .43222 .80482 .44206 .81412 .4346 .8104 .43352 Metetra
.81 .977 .897 r
.8104 .43352 .81412 .4346 .82421 .43556 .81975 .42601 Metetra
.633 .615 .814 r
.81975 .42601 .82421 .43556 .83384 .43119 .82959 .42364 Metetra
.586 .641 .872 r
.82959 .42364 .83384 .43119 .84372 .42907 .8396 .42268 Metetra
.632 .701 .896 r
.8396 .42268 .84372 .42907 .85307 .42125 .84953 .42043 Metetra
.244 0 0 r
.84953 .42043 .85307 .42125 .86407 .42929 .86007 .42368 Metetra
.661 .745 .912 r
.86007 .42368 .86407 .42929 .87398 .42625 .87001 .42062 Metetra
.661 .745 .912 r
.87001 .42062 .87398 .42625 .88393 .42321 .87998 .41755 Metetra
.661 .745 .912 r
.87998 .41755 .88393 .42321 .89392 .42015 .88999 .41448 Metetra
.661 .745 .912 r
.88999 .41448 .89392 .42015 .90394 .41708 .90003 .41139 Metetra
.661 .745 .912 r
.90003 .41139 .90394 .41708 .91399 .414 .91011 .40829 Metetra
.661 .745 .912 r
.91011 .40829 .91399 .414 .92408 .41091 .92022 .40518 Metetra
.661 .745 .912 r
.92022 .40518 .92408 .41091 .9342 .40781 .93037 .40206 Metetra
.661 .745 .912 r
.33924 .57753 .34439 .58223 .35265 .57969 .34752 .57498 Metetra
.661 .745 .912 r
.34752 .57498 .35265 .57969 .36094 .57714 .35582 .57241 Metetra
.661 .745 .912 r
.35582 .57241 .36094 .57714 .36925 .57458 .36415 .56984 Metetra
.661 .745 .912 r
.36415 .56984 .36925 .57458 .37759 .57202 .3725 .56727 Metetra
.661 .745 .912 r
.3725 .56727 .37759 .57202 .38595 .56945 .38088 .56468 Metetra
.661 .745 .912 r
.38088 .56468 .38595 .56945 .39434 .56687 .38929 .56208 Metetra
.848 .761 .766 r
.38929 .56208 .39434 .56687 .40276 .56428 .39806 .55038 Metetra
.635 .542 .733 r
.39806 .55038 .40276 .56428 .41151 .55245 .40651 .54752 Metetra
.379 .627 .951 r
.40651 .54752 .41151 .55245 .41986 .55288 .41484 .54891 Metetra
.784 .797 .863 r
.41484 .54891 .41986 .55288 .42832 .55103 .42345 .5427 Metetra
.476 .55 .853 r
.42345 .5427 .42832 .55103 .43693 .54482 .43185 .54435 Metetra
.817 .952 .906 r
.43185 .54435 .43693 .54482 .44535 .54655 .44051 .53755 Metetra
.593 .593 .821 r
.44051 .53755 .44535 .54655 .454 .53987 .44904 .5367 Metetra
.248 .649 .962 r
.44904 .5367 .454 .53987 .46256 .53843 .45756 .53798 Metetra
.794 .959 .919 r
.45756 .53798 .46256 .53843 .4711 .54019 .46627 .53168 Metetra
.686 .646 .804 r
.46627 .53168 .4711 .54019 .47973 .53879 .47495 .52767 Metetra
.573 .545 .785 r
.47495 .52767 .47973 .53879 .48848 .52969 .4836 .5275 Metetra
.604 .861 .992 r
.4836 .5275 .48848 .52969 .49715 .5304 .49231 .52501 Metetra
.522 .676 .934 r
.49231 .52501 .49715 .5304 .50589 .52646 .50104 .52492 Metetra
.763 .921 .941 r
.50104 .52492 .50589 .52646 .51463 .52651 .50983 .51958 Metetra
.628 .665 .866 r
.50983 .51958 .51463 .52651 .52342 .52376 .51863 .51768 Metetra
.698 .717 .863 r
.51863 .51768 .52342 .52376 .53223 .52039 .52747 .51385 Metetra
.651 .687 .87 r
.52747 .51385 .53223 .52039 .54111 .52372 .53632 .51134 Metetra
.667 .58 .748 r
.53632 .51134 .54111 .52372 .54991 .51021 .5452 .50704 Metetra
.213 .629 .952 r
.5452 .50704 .54991 .51021 .55885 .51165 .55415 .50863 Metetra
.568 .813 .991 r
.55415 .50863 .55885 .51165 .56781 .51184 .56312 .50689 Metetra
.774 .777 .855 r
.56312 .50689 .56781 .51184 .57681 .51102 .57205 .50064 Metetra
.486 .513 .81 r
.57205 .50064 .57681 .51102 .5858 .50811 .58114 .5028 Metetra
.676 .742 .9 r
.58114 .5028 .5858 .50811 .59482 .50509 .59018 .49964 Metetra
.681 .739 .895 r
.59018 .49964 .59482 .50509 .60387 .50174 .59924 .49632 Metetra
.666 .736 .902 r
.59924 .49632 .60387 .50174 .61295 .49885 .60834 .49339 Metetra
.675 .738 .898 r
.60834 .49339 .61295 .49885 .62206 .49603 .61747 .49023 Metetra
.799 .758 .815 r
.61747 .49023 .62206 .49603 .63121 .49323 .62647 .48216 Metetra
.643 .587 .777 r
.62647 .48216 .63121 .49323 .64038 .49036 .63564 .47929 Metetra
.545 .535 .795 r
.63564 .47929 .64038 .49036 .64961 .48821 .64498 .48002 Metetra
.654 .648 .832 r
.64498 .48002 .64961 .48821 .65884 .48527 .65423 .47718 Metetra
.622 .637 .844 r
.65423 .47718 .65884 .48527 .6681 .48239 .66355 .47535 Metetra
.633 .672 .869 r
.66355 .47535 .6681 .48239 .67722 .47572 .6729 .4732 Metetra
.591 .855 .994 r
.6729 .4732 .67722 .47572 .6866 .47411 .68226 .47072 Metetra
.713 .847 .946 r
.68226 .47072 .6866 .47411 .69587 .46967 .69157 .4665 Metetra
.897 .856 .794 r
.69157 .4665 .69587 .46967 .705 .46219 .70049 .45458 Metetra
.463 .572 .879 r
.70049 .45458 .705 .46219 .71455 .46201 .71017 .45633 Metetra
.625 .718 .913 r
.71017 .45633 .71455 .46201 .72433 .46482 .71967 .45428 Metetra
.688 .621 .777 r
.71967 .45428 .72433 .46482 .73364 .45917 .72904 .44941 Metetra
.586 .584 .817 r
.72904 .44941 .73364 .45917 .74296 .45347 .7387 .44868 Metetra
0 .26 .751 r
.7387 .44868 .74296 .45347 .7525 .45076 .74895 .45595 Metetra
.613 .816 .409 r
.74895 .45595 .7525 .45076 .76199 .44681 .75781 .44247 Metetra
.367 .657 .968 r
.75781 .44247 .76199 .44681 .77149 .44262 .76775 .44376 Metetra
.812 .996 .766 r
.76775 .44376 .77149 .44262 .78102 .43862 .77687 .43386 Metetra
.685 .784 .926 r
.77687 .43386 .78102 .43862 .79118 .44193 .7865 .43027 Metetra
.615 .569 .78 r
.7865 .43027 .79118 .44193 .80031 .43222 .7963 .42844 Metetra
.73 .845 .935 r
.7963 .42844 .80031 .43222 .8104 .43352 .80589 .4237 Metetra
.519 .55 .827 r
.80589 .4237 .8104 .43352 .81975 .42601 .81604 .42495 Metetra
.807 .979 .897 r
.81604 .42495 .81975 .42601 .82959 .42364 .82544 .41744 Metetra
.634 .709 .901 r
.82544 .41744 .82959 .42364 .8396 .42268 .83534 .41512 Metetra
.508 .602 .882 r
.83534 .41512 .8396 .42268 .84953 .42043 .8456 .41597 Metetra
.706 .811 .93 r
.8456 .41597 .84953 .42043 .86007 .42368 .8554 .41176 Metetra
.475 .488 .791 r
.8554 .41176 .86007 .42368 .87001 .42062 .866 .41495 Metetra
.661 .745 .912 r
.866 .41495 .87001 .42062 .87998 .41755 .876 .41186 Metetra
.661 .745 .912 r
.876 .41186 .87998 .41755 .88999 .41448 .88604 .40877 Metetra
.661 .745 .912 r
.88604 .40877 .88999 .41448 .90003 .41139 .89611 .40566 Metetra
.661 .745 .912 r
.89611 .40566 .90003 .41139 .91011 .40829 .90621 .40254 Metetra
.661 .745 .912 r
.90621 .40254 .91011 .40829 .92022 .40518 .91635 .39941 Metetra
.661 .745 .912 r
.91635 .39941 .92022 .40518 .93037 .40206 .92652 .39627 Metetra
.661 .745 .912 r
.33406 .57281 .33924 .57753 .34752 .57498 .34236 .57024 Metetra
.661 .745 .912 r
.34236 .57024 .34752 .57498 .35582 .57241 .35067 .56766 Metetra
.661 .745 .912 r
.35067 .56766 .35582 .57241 .36415 .56984 .35902 .56508 Metetra
.661 .745 .912 r
.35902 .56508 .36415 .56984 .3725 .56727 .36739 .56248 Metetra
.661 .745 .912 r
.36739 .56248 .3725 .56727 .38088 .56468 .37578 .55988 Metetra
.859 .758 .75 r
.37578 .55988 .38088 .56468 .38929 .56208 .38464 .54675 Metetra
.598 .508 .724 r
.38464 .54675 .38929 .56208 .39806 .55038 .39301 .54556 Metetra
.408 .648 .956 r
.39301 .54556 .39806 .55038 .40651 .54752 .40133 .54657 Metetra
.788 .934 .927 r
.40133 .54657 .40651 .54752 .41484 .54891 .40993 .54071 Metetra
.477 .555 .856 r
.40993 .54071 .41484 .54891 .42345 .5427 .41831 .54225 Metetra
.792 .956 .921 r
.41831 .54225 .42345 .5427 .43185 .54435 .42695 .53608 Metetra
.375 .499 .856 r
.42695 .53608 .43185 .54435 .44051 .53755 .43536 .53926 Metetra
.827 .999 .83 r
.43536 .53926 .44051 .53755 .44904 .5367 .44411 .5307 Metetra
.634 .695 .889 r
.44411 .5307 .44904 .5367 .45756 .53798 .45271 .52867 Metetra
.605 .594 .813 r
.45271 .52867 .45756 .53798 .46627 .53168 .46133 .52743 Metetra
.596 .756 .954 r
.46133 .52743 .46627 .53168 .47495 .52767 .46999 .52585 Metetra
.255 0 0 r
.46999 .52585 .47495 .52767 .4836 .5275 .47862 .52909 Metetra
.879 .99 .807 r
.47862 .52909 .4836 .5275 .49231 .52501 .48746 .51892 Metetra
.557 .664 .908 r
.48746 .51892 .49231 .52501 .50104 .52492 .4962 .51844 Metetra
.688 .701 .857 r
.4962 .51844 .50104 .52492 .50983 .51958 .505 .51485 Metetra
.479 .689 .96 r
.505 .51485 .50983 .51958 .51863 .51768 .51381 .51503 Metetra
.721 .868 .95 r
.51381 .51503 .51863 .51768 .52747 .51385 .52267 .51079 Metetra
.822 .85 .869 r
.52267 .51079 .52747 .51385 .53632 .51134 .53154 .5034 Metetra
.529 .592 .862 r
.53154 .5034 .53632 .51134 .5452 .50704 .54046 .50389 Metetra
.215 .632 .953 r
.54046 .50389 .5452 .50704 .55415 .50863 .54942 .50543 Metetra
.559 .801 .989 r
.54942 .50543 .55415 .50863 .56312 .50689 .55841 .50388 Metetra
.8 .86 .894 r
.55841 .50388 .56312 .50689 .57205 .50064 .56737 .49739 Metetra
.68 .836 .958 r
.56737 .49739 .57205 .50064 .58114 .5028 .57639 .49398 Metetra
.676 .642 .808 r
.57639 .49398 .58114 .5028 .59018 .49964 .58543 .49021 Metetra
.73 .654 .774 r
.58543 .49021 .59018 .49964 .59924 .49632 .59444 .4836 Metetra
.631 .559 .755 r
.59444 .4836 .59924 .49632 .60834 .49339 .60354 .481 Metetra
.388 .422 .774 r
.60354 .481 .60834 .49339 .61747 .49023 .61289 .48626 Metetra
.554 .763 .975 r
.61289 .48626 .61747 .49023 .62647 .48216 .62213 .48505 Metetra
.62213 .48505 .62647 .48216 .63564 .47929 .63134 .48208 Metetra
.63134 .48208 .63564 .47929 .64498 .48002 .64056 .4781 Metetra
.834 .92 .892 r
.64056 .4781 .64498 .48002 .65423 .47718 .64966 .47051 Metetra
.486 .616 .905 r
.64966 .47051 .65423 .47718 .66355 .47535 .6591 .47141 Metetra
.634 .798 .961 r
.6591 .47141 .66355 .47535 .6729 .4732 .66846 .46887 Metetra
.706 .801 .924 r
.66846 .46887 .6729 .4732 .68226 .47072 .67777 .46485 Metetra
.819 .767 .804 r
.67777 .46485 .68226 .47072 .69157 .4665 .68686 .45564 Metetra
.669 .607 .777 r
.68686 .45564 .69157 .4665 .70049 .45458 .69621 .45159 Metetra
.208 .635 .951 r
.69621 .45159 .70049 .45458 .71017 .45633 .7059 .45318 Metetra
.571 .818 .991 r
.7059 .45318 .71017 .45633 .71967 .45428 .71544 .45124 Metetra
.763 .878 .93 r
.71544 .45124 .71967 .45428 .72904 .44941 .7248 .44571 Metetra
.609 .806 .975 r
.7248 .44571 .72904 .44941 .7387 .44868 .73439 .44343 Metetra
.745 .779 .881 r
.73439 .44343 .7387 .44868 .74895 .45595 .7438 .43809 Metetra
.612 .506 .709 r
.7438 .43809 .74895 .45595 .75781 .44247 .75345 .43573 Metetra
.676 .706 .87 r
.75345 .43573 .75781 .44247 .76775 .44376 .76305 .43228 Metetra
.559 .541 .792 r
.76305 .43228 .76775 .44376 .77687 .43386 .77296 .43256 Metetra
.807 .967 .907 r
.77296 .43256 .77687 .43386 .7865 .43027 .78234 .42531 Metetra
.381 .636 .955 r
.78234 .42531 .7865 .43027 .7963 .42844 .79244 .42686 Metetra
.822 .959 .902 r
.79244 .42686 .7963 .42844 .80589 .4237 .80183 .41929 Metetra
.386 .666 .97 r
.80183 .41929 .80589 .4237 .81604 .42495 .81199 .4204 Metetra
.701 .803 .929 r
.81199 .4204 .81604 .42495 .82544 .41744 .82174 .41635 Metetra
.813 .98 .893 r
.82174 .41635 .82544 .41744 .83534 .41512 .83117 .40862 Metetra
.697 .727 .873 r
.83117 .40862 .83534 .41512 .8456 .41597 .84096 .40447 Metetra
.636 .585 .781 r
.84096 .40447 .8456 .41597 .8554 .41176 .85091 .4017 Metetra
.396 .475 .824 r
.85091 .4017 .8554 .41176 .866 .41495 .86165 .40616 Metetra
.555 .596 .85 r
.86165 .40616 .866 .41495 .876 .41186 .872 .40614 Metetra
.661 .745 .912 r
.872 .40614 .876 .41186 .88604 .40877 .88206 .40302 Metetra
.661 .745 .912 r
.88206 .40302 .88604 .40877 .89611 .40566 .89215 .39989 Metetra
.661 .745 .912 r
.89215 .39989 .89611 .40566 .90621 .40254 .90228 .39676 Metetra
.661 .745 .912 r
.90228 .39676 .90621 .40254 .91635 .39941 .91244 .39361 Metetra
.661 .745 .912 r
.91244 .39361 .91635 .39941 .92652 .39627 .92264 .39045 Metetra
.661 .745 .912 r
.32885 .56806 .33406 .57281 .34236 .57024 .33716 .56548 Metetra
.661 .745 .912 r
.33716 .56548 .34236 .57024 .35067 .56766 .3455 .56288 Metetra
.661 .745 .912 r
.3455 .56288 .35067 .56766 .35902 .56508 .35386 .56028 Metetra
.661 .745 .912 r
.35386 .56028 .35902 .56508 .36739 .56248 .36224 .55768 Metetra
.854 .758 .755 r
.36224 .55768 .36739 .56248 .37578 .55988 .37111 .54503 Metetra
.525 .469 .736 r
.37111 .54503 .37578 .55988 .38464 .54675 .37934 .54679 Metetra
.831 .962 .894 r
.37934 .54679 .38464 .54675 .39301 .54556 .38798 .53952 Metetra
.583 .672 .901 r
.38798 .53952 .39301 .54556 .40133 .54657 .39638 .5386 Metetra
.47 .559 .864 r
.39638 .5386 .40133 .54657 .40993 .54071 .40473 .54015 Metetra
.793 .95 .922 r
.40473 .54015 .40993 .54071 .41831 .54225 .41338 .53398 Metetra
.08 .321 .8 r
.41338 .53398 .41831 .54225 .42695 .53608 .42165 .54045 Metetra
.844 .979 .682 r
.42165 .54045 .42695 .53608 .43536 .53926 .43052 .52826 Metetra
.62 .572 .778 r
.43052 .52826 .43536 .53926 .44411 .5307 .43911 .5264 Metetra
.318 .631 .962 r
.43911 .5264 .44411 .5307 .45271 .52867 .44765 .52791 Metetra
.231 .738 .89 r
.44765 .52791 .45271 .52867 .46133 .52743 .45628 .52728 Metetra
.832 .965 .891 r
.45628 .52728 .46133 .52743 .46999 .52585 .46508 .5198 Metetra
.544 .66 .912 r
.46508 .5198 .46999 .52585 .47862 .52909 .47377 .51954 Metetra
.671 .622 .791 r
.47377 .51954 .47862 .52909 .48746 .51892 .48254 .51583 Metetra
.379 .727 .99 r
.48254 .51583 .48746 .51892 .4962 .51844 .49129 .51603 Metetra
.706 .876 .961 r
.49129 .51603 .4962 .51844 .505 .51485 .50012 .51204 Metetra
.582 .827 .991 r
.50012 .51204 .505 .51485 .51381 .51503 .50896 .51004 Metetra
.631 .739 .925 r
.50896 .51004 .51381 .51503 .52267 .51079 .51784 .50793 Metetra
.82 .86 .877 r
.51784 .50793 .52267 .51079 .53154 .5034 .52674 .5007 Metetra
.581 .834 .993 r
.52674 .5007 .53154 .5034 .54046 .50389 .53567 .49862 Metetra
.192 .511 .913 r
.53567 .49862 .54046 .50389 .54942 .50543 .54466 .50205 Metetra
.593 .805 .981 r
.54466 .50205 .54942 .50543 .55841 .50388 .55367 .5001 Metetra
.799 .827 .873 r
.55367 .5001 .55841 .50388 .56737 .49739 .56266 .49334 Metetra
.688 .801 .934 r
.56266 .49334 .56737 .49739 .57639 .49398 .5717 .48985 Metetra
.803 .815 .861 r
.5717 .48985 .57639 .49398 .58543 .49021 .5807 .48275 Metetra
.434 .562 .884 r
.5807 .48275 .58543 .49021 .59444 .4836 .5899 .48479 Metetra
.36 0 0 r
.5899 .48479 .59444 .4836 .60354 .481 .59914 .48652 Metetra
.111 0 0 r
.59914 .48652 .60354 .481 .61289 .48626 .60829 .48214 Metetra
.775 .818 .887 r
.60829 .48214 .61289 .48626 .62213 .48505 .61741 .47615 Metetra
.766 .68 .768 r
.61741 .47615 .62213 .48505 .63134 .48208 .62647 .46769 Metetra
.505 .468 .75 r
.62647 .46769 .63134 .48208 .64056 .4781 .63589 .47023 Metetra
.589 .63 .859 r
.63589 .47023 .64056 .4781 .64966 .47051 .64526 .46926 Metetra
.445 .85 .97 r
.64526 .46926 .64966 .47051 .6591 .47141 .65462 .46732 Metetra
.81 .828 .865 r
.65462 .46732 .6591 .47141 .66846 .46887 .66379 .45995 Metetra
.686 .65 .808 r
.66379 .45995 .66846 .46887 .67777 .46485 .67311 .45568 Metetra
.581 .595 .831 r
.67311 .45568 .67777 .46485 .68686 .45564 .68263 .45502 Metetra
.777 .979 .911 r
.68263 .45502 .68686 .45564 .69621 .45159 .69188 .44832 Metetra
.276 .663 .969 r
.69188 .44832 .69621 .45159 .7059 .45318 .70158 .44956 Metetra
.771 .852 .911 r
.70158 .44956 .7059 .45318 .71544 .45124 .71092 .44376 Metetra
.59 .644 .872 r
.71092 .44376 .71544 .45124 .7248 .44571 .72057 .44267 Metetra
.581 .83 .992 r
.72057 .44267 .7248 .44571 .73439 .44343 .73019 .44048 Metetra
.768 .887 .93 r
.73019 .44048 .73439 .44343 .7438 .43809 .73962 .43476 Metetra
.601 .824 .985 r
.73962 .43476 .7438 .43809 .75345 .43573 .74929 .4324 Metetra
.765 .87 .925 r
.74929 .4324 .75345 .43573 .76305 .43228 .75877 .42674 Metetra
.356 .596 .937 r
.75877 .42674 .76305 .43228 .77296 .43256 .76885 .42897 Metetra
.828 .867 .874 r
.76885 .42897 .77296 .43256 .78234 .42531 .77821 .42108 Metetra
.686 .812 .943 r
.77821 .42108 .78234 .42531 .79244 .42686 .78791 .41738 Metetra
.532 .566 .835 r
.78791 .41738 .79244 .42686 .80183 .41929 .79802 .41811 Metetra
.868 .97 .857 r
.79802 .41811 .80183 .41929 .81199 .4204 .8073 .40877 Metetra
.474 .492 .796 r
.8073 .40877 .81199 .4204 .82174 .41635 .8177 .41176 Metetra
.703 .805 .928 r
.8177 .41176 .82174 .41635 .83117 .40862 .8275 .40762 Metetra
.809 .984 .89 r
.8275 .40762 .83117 .40862 .84096 .40447 .83697 .39985 Metetra
.682 .798 .936 r
.83697 .39985 .84096 .40447 .85091 .4017 .84687 .39619 Metetra
.652 .748 .92 r
.84687 .39619 .85091 .4017 .86165 .40616 .85687 .3933 Metetra
.45 .46 .778 r
.85687 .3933 .86165 .40616 .872 .40614 .86767 .39754 Metetra
.563 .607 .855 r
.86767 .39754 .872 .40614 .88206 .40302 .87806 .39724 Metetra
.661 .745 .912 r
.87806 .39724 .88206 .40302 .89215 .39989 .88817 .39409 Metetra
.661 .745 .912 r
.88817 .39409 .89215 .39989 .90228 .39676 .89833 .39093 Metetra
.661 .745 .912 r
.89833 .39093 .90228 .39676 .91244 .39361 .90852 .38777 Metetra
.661 .745 .912 r
.90852 .38777 .91244 .39361 .92264 .39045 .91874 .38459 Metetra
.661 .745 .912 r
.32361 .56328 .32885 .56806 .33716 .56548 .33194 .56068 Metetra
.661 .745 .912 r
.33194 .56068 .33716 .56548 .3455 .56288 .34029 .55808 Metetra
.661 .745 .912 r
.34029 .55808 .3455 .56288 .35386 .56028 .34866 .55546 Metetra
.661 .745 .912 r
.34866 .55546 .35386 .56028 .36224 .55768 .35707 .55284 Metetra
.806 .764 .814 r
.35707 .55284 .36224 .55768 .37111 .54503 .36575 .54476 Metetra
.822 .952 .903 r
.36575 .54476 .37111 .54503 .37934 .54679 .37439 .53784 Metetra
.653 .622 .806 r
.37439 .53784 .37934 .54679 .38798 .53952 .38285 .53504 Metetra
.605 .746 .944 r
.38285 .53504 .38798 .53952 .39638 .5386 .39129 .53341 Metetra
.603 .715 .923 r
.39129 .53341 .39638 .5386 .40473 .54015 .39976 .53195 Metetra
.061 .313 .797 r
.39976 .53195 .40473 .54015 .41338 .53398 .40799 .53845 Metetra
.841 .979 .683 r
.40799 .53845 .41338 .53398 .42165 .54045 .41689 .52631 Metetra
.613 .53 .737 r
.41689 .52631 .42165 .54045 .43052 .52826 .42546 .5244 Metetra
0 .405 .826 r
.42546 .5244 .43052 .52826 .43911 .5264 .43391 .52826 Metetra
.81 1 .824 r
.43391 .52826 .43911 .5264 .44765 .52791 .44273 .51982 Metetra
.649 .642 .83 r
.44273 .51982 .44765 .52791 .45628 .52728 .45141 .51725 Metetra
.567 .562 .808 r
.45141 .51725 .45628 .52728 .46508 .5198 .46007 .51711 Metetra
.724 .863 .947 r
.46007 .51711 .46508 .5198 .47377 .51954 .46885 .51286 Metetra
.499 .619 .901 r
.46885 .51286 .47377 .51954 .48254 .51583 .47757 .51349 Metetra
.384 .768 .99 r
.47757 .51349 .48254 .51583 .49129 .51603 .48635 .5131 Metetra
.706 .852 .952 r
.48635 .5131 .49129 .51603 .50012 .51204 .49521 .50921 Metetra
.591 .83 .99 r
.49521 .50921 .50012 .51204 .50896 .51004 .50407 .50709 Metetra
.634 .837 .978 r
.50407 .50709 .50896 .51004 .51784 .50793 .51297 .50442 Metetra
.806 .834 .872 r
.51297 .50442 .51784 .50793 .52674 .5007 .52191 .49747 Metetra
.593 .812 .984 r
.52191 .49747 .52674 .5007 .53567 .49862 .53086 .49547 Metetra
.037 .517 .883 r
.53086 .49547 .53567 .49862 .54466 .50205 .53986 .49821 Metetra
.75 .821 .908 r
.53986 .49821 .54466 .50205 .55367 .5001 .54887 .49317 Metetra
.692 .695 .849 r
.54887 .49317 .55367 .5001 .56266 .49334 .55791 .48928 Metetra
.799 .818 .867 r
.55791 .48928 .56266 .49334 .5717 .48985 .56693 .4824 Metetra
.476 .585 .884 r
.56693 .4824 .5717 .48985 .5807 .48275 .57608 .48371 Metetra
.519 .916 .836 r
.57608 .48371 .5807 .48275 .5899 .48479 .58519 .4791 Metetra
.619 .713 .913 r
.58519 .4791 .5899 .48479 .59914 .48652 .59437 .47723 Metetra
.487 .541 .838 r
.59437 .47723 .59914 .48652 .60829 .48214 .60367 .47895 Metetra
.784 .861 .907 r
.60367 .47895 .60829 .48214 .61741 .47615 .61282 .47289 Metetra
.774 .859 .913 r
.61282 .47289 .61741 .47615 .62647 .46769 .62199 .46712 Metetra
.313 .796 .9 r
.62199 .46712 .62647 .46769 .63589 .47023 .63132 .46557 Metetra
.802 .804 .853 r
.63132 .46557 .63589 .47023 .64526 .46926 .64047 .45822 Metetra
.582 .559 .794 r
.64047 .45822 .64526 .46926 .65462 .46732 .64989 .4576 Metetra
.739 .658 .77 r
.64989 .4576 .65462 .46732 .66379 .45995 .65908 .45029 Metetra
.622 .605 .813 r
.65908 .45029 .66379 .45995 .67311 .45568 .66852 .44832 Metetra
.385 .541 .888 r
.66852 .44832 .67311 .45568 .68263 .45502 .67821 .45113 Metetra
.802 .841 .881 r
.67821 .45113 .68263 .45502 .69188 .44832 .68748 .44419 Metetra
.489 .734 .98 r
.68748 .44419 .69188 .44832 .70158 .44956 .69711 .4438 Metetra
.682 .741 .896 r
.69711 .4438 .70158 .44956 .71092 .44376 .70661 .44029 Metetra
.508 .778 .993 r
.70661 .44029 .71092 .44376 .72057 .44267 .71629 .43928 Metetra
.863 .866 .839 r
.71629 .43928 .72057 .44267 .73019 .44048 .72548 .4297 Metetra
.494 .517 .81 r
.72548 .4297 .73019 .44048 .73962 .43476 .73542 .43175 Metetra
.761 .886 .934 r
.73542 .43175 .73962 .43476 .74929 .4324 .74491 .42617 Metetra
.641 .712 .898 r
.74491 .42617 .74929 .4324 .75877 .42674 .75463 .42366 Metetra
.749 .883 .94 r
.75463 .42366 .75877 .42674 .76885 .42897 .76419 .41837 Metetra
.616 .589 .8 r
.76419 .41837 .76885 .42897 .77821 .42108 .77402 .41649 Metetra
.774 .82 .889 r
.77402 .41649 .77821 .42108 .78791 .41738 .78355 .41027 Metetra
.349 .531 .893 r
.78355 .41027 .78791 .41738 .79802 .41811 .7939 .41366 Metetra
.811 .835 .868 r
.7939 .41366 .79802 .41811 .8073 .40877 .80337 .40607 Metetra
.768 .91 .937 r
.80337 .40607 .8073 .40877 .8177 .41176 .813 .40016 Metetra
.476 .495 .798 r
.813 .40016 .8177 .41176 .8275 .40762 .82345 .40304 Metetra
.69 .803 .935 r
.82345 .40304 .8275 .40762 .83697 .39985 .83334 .39918 Metetra
.604 .946 .928 r
.83334 .39918 .83697 .39985 .84687 .39619 .84318 .39451 Metetra
.795 .963 .916 r
.84318 .39451 .84687 .39619 .85687 .3933 .85279 .38744 Metetra
.656 .739 .911 r
.85279 .38744 .85687 .3933 .86767 .39754 .86285 .38443 Metetra
.363 .404 .77 r
.86285 .38443 .86767 .39754 .87806 .39724 .87403 .39142 Metetra
.661 .745 .912 r
.87403 .39142 .87806 .39724 .88817 .39409 .88417 .38825 Metetra
.661 .745 .912 r
.88417 .38825 .88817 .39409 .89833 .39093 .89435 .38508 Metetra
.661 .745 .912 r
.89435 .38508 .89833 .39093 .90852 .38777 .90457 .38189 Metetra
.661 .745 .912 r
.90457 .38189 .90852 .38777 .91874 .38459 .91482 .37868 Metetra
.661 .745 .912 r
.31834 .55848 .32361 .56328 .33194 .56068 .32668 .55587 Metetra
.661 .745 .912 r
.32668 .55587 .33194 .56068 .34029 .55808 .33505 .55324 Metetra
.661 .745 .912 r
.33505 .55324 .34029 .55808 .34866 .55546 .34344 .55061 Metetra
.855 .757 .754 r
.34344 .55061 .34866 .55546 .35707 .55284 .35238 .53782 Metetra
.613 .52 .726 r
.35238 .53782 .35707 .55284 .36575 .54476 .36077 .53584 Metetra
.642 .617 .81 r
.36077 .53584 .36575 .54476 .37439 .53784 .36921 .53343 Metetra
.636 .758 .936 r
.36921 .53343 .37439 .53784 .38285 .53504 .37766 .53124 Metetra
.207 .597 .947 r
.37766 .53124 .38285 .53504 .39129 .53341 .38598 .53314 Metetra
.465 0 0 r
.38598 .53314 .39129 .53341 .39976 .53195 .39428 .53653 Metetra
.84 .978 .681 r
.39428 .53653 .39976 .53195 .40799 .53845 .40321 .52437 Metetra
.61 .529 .738 r
.40321 .52437 .40799 .53845 .41689 .52631 .41177 .52261 Metetra
.603 .785 .968 r
.41177 .52261 .41689 .52631 .42546 .5244 .42036 .52074 Metetra
.577 .78 .975 r
.42036 .52074 .42546 .5244 .43391 .52826 .42898 .51921 Metetra
.678 .634 .799 r
.42898 .51921 .43391 .52826 .44273 .51982 .43768 .51537 Metetra
.515 .719 .965 r
.43768 .51537 .44273 .51982 .45141 .51725 .44634 .51493 Metetra
.659 .871 .979 r
.44634 .51493 .45141 .51725 .46007 .51711 .45508 .51172 Metetra
.806 .759 .81 r
.45508 .51172 .46007 .51711 .46885 .51286 .46395 .50336 Metetra
.393 .481 .831 r
.46395 .50336 .46885 .51286 .47757 .51349 .47263 .5068 Metetra
.647 .683 .87 r
.47263 .5068 .47757 .51349 .48635 .5131 .48145 .50437 Metetra
.712 .657 .793 r
.48145 .50437 .48635 .5131 .49521 .50921 .49033 .49907 Metetra
.631 .595 .795 r
.49033 .49907 .49521 .50921 .50407 .50709 .4992 .49681 Metetra
.453 .498 .816 r
.4992 .49681 .50407 .50709 .51297 .50442 .50808 .49948 Metetra
.517 .701 .954 r
.50808 .49948 .51297 .50442 .52191 .49747 .51703 .49918 Metetra
.712 .985 .815 r
.51703 .49918 .52191 .49747 .53086 .49547 .52601 .49194 Metetra
.477 .754 .991 r
.52601 .49194 .53086 .49547 .53986 .49821 .53502 .49143 Metetra
.653 .686 .869 r
.53502 .49143 .53986 .49821 .54887 .49317 .54406 .48875 Metetra
.808 .803 .847 r
.54406 .48875 .54887 .49317 .55791 .48928 .55309 .48121 Metetra
.463 .56 .869 r
.55309 .48121 .55791 .48928 .56693 .4824 .56223 .48293 Metetra
.649 .968 .89 r
.56223 .48293 .56693 .4824 .57608 .48371 .57132 .47753 Metetra
.415 .601 .923 r
.57132 .47753 .57608 .48371 .58519 .4791 .58055 .47917 Metetra
.78 .987 .895 r
.58055 .47917 .58519 .4791 .59437 .47723 .58966 .4722 Metetra
.462 .675 .957 r
.58966 .4722 .59437 .47723 .60367 .47895 .59895 .47264 Metetra
.67 .712 .879 r
.59895 .47264 .60367 .47895 .61282 .47289 .6082 .46947 Metetra
.765 .851 .916 r
.6082 .46947 .61282 .47289 .62199 .46712 .61741 .46394 Metetra
.729 .859 .942 r
.61741 .46394 .62199 .46712 .63132 .46557 .62666 .45933 Metetra
.573 .677 .91 r
.62666 .45933 .63132 .46557 .64047 .45822 .63606 .45842 Metetra
.776 .993 .88 r
.63606 .45842 .64047 .45822 .64989 .4576 .64527 .45115 Metetra
.559 .663 .907 r
.64527 .45115 .64989 .4576 .65908 .45029 .65475 .45056 Metetra
.739 .99 .88 r
.65475 .45056 .65908 .45029 .66852 .44832 .66402 .44377 Metetra
.162 .528 .921 r
.66402 .44377 .66852 .44832 .67821 .45113 .67375 .44709 Metetra
.802 .836 .877 r
.67375 .44709 .67821 .45113 .68748 .44419 .68305 .44005 Metetra
.459 .72 .981 r
.68305 .44005 .68748 .44419 .69711 .4438 .69272 .44002 Metetra
.675 .825 .955 r
.69272 .44002 .69711 .4438 .70661 .44029 .70225 .43653 Metetra
.508 .763 .988 r
.70225 .43653 .70661 .44029 .71629 .43928 .71197 .43566 Metetra
.836 .86 .863 r
.71197 .43566 .71629 .43928 .72548 .4297 .72128 .42737 Metetra
.796 .92 .921 r
.72128 .42737 .72548 .4297 .73542 .43175 .73069 .42079 Metetra
.708 .629 .767 r
.73069 .42079 .73542 .43175 .74491 .42617 .74015 .41463 Metetra
.514 .517 .796 r
.74015 .41463 .74491 .42617 .75463 .42366 .75017 .41626 Metetra
.592 .652 .878 r
.75017 .41626 .75463 .42366 .76419 .41837 .76004 .41505 Metetra
.228 .633 .957 r
.76004 .41505 .76419 .41837 .77402 .41649 .77018 .41677 Metetra
.843 .999 .813 r
.77018 .41677 .77402 .41649 .78355 .41027 .77948 .407 Metetra
.769 .882 .927 r
.77948 .407 .78355 .41027 .7939 .41366 .78909 .40112 Metetra
.606 .556 .772 r
.78909 .40112 .7939 .41366 .80337 .40607 .79907 .39948 Metetra
.614 .692 .899 r
.79907 .39948 .80337 .40607 .813 .40016 .80908 .39759 Metetra
.764 .918 .94 r
.80908 .39759 .813 .40016 .82345 .40304 .81877 .3917 Metetra
.666 .606 .778 r
.81877 .3917 .82345 .40304 .83334 .39918 .82863 .38753 Metetra
.632 .584 .782 r
.82863 .38753 .83334 .39918 .84318 .39451 .83867 .38481 Metetra
.525 .561 .835 r
.83867 .38481 .84318 .39451 .85279 .38744 .84911 .38573 Metetra
.813 .965 .905 r
.84911 .38573 .85279 .38744 .86285 .38443 .85873 .37815 Metetra
.697 .741 .886 r
.85873 .37815 .86285 .38443 .87403 .39142 .86872 .37397 Metetra
.389 .374 .722 r
.86872 .37397 .87403 .39142 .88417 .38825 .88014 .38238 Metetra
.661 .745 .912 r
.88014 .38238 .88417 .38825 .89435 .38508 .89035 .37918 Metetra
.661 .745 .912 r
.89035 .37918 .89435 .38508 .90457 .38189 .90059 .37597 Metetra
.661 .745 .912 r
.90059 .37597 .90457 .38189 .91482 .37868 .91086 .37275 Metetra
.661 .745 .912 r
.31304 .55365 .31834 .55848 .32668 .55587 .3214 .55102 Metetra
.661 .745 .912 r
.3214 .55102 .32668 .55587 .33505 .55324 .32978 .54838 Metetra
.661 .745 .912 r
.32978 .54838 .33505 .55324 .34344 .55061 .33819 .54573 Metetra
.805 .763 .815 r
.33819 .54573 .34344 .55061 .35238 .53782 .34691 .53772 Metetra
.802 .961 .913 r
.34691 .53772 .35238 .53782 .36077 .53584 .35555 .53123 Metetra
.35 .635 .96 r
.35555 .53123 .36077 .53584 .36921 .53343 .36382 .53255 Metetra
.366 .814 .946 r
.36382 .53255 .36921 .53343 .37766 .53124 .37226 .53123 Metetra
.814 .965 .904 r
.37226 .53123 .37766 .53124 .38598 .53314 .38098 .52434 Metetra
.618 .612 .822 r
.38098 .52434 .38598 .53314 .39428 .53653 .38949 .52266 Metetra
.526 .482 .75 r
.38949 .52266 .39428 .53653 .40321 .52437 .39791 .52413 Metetra
.833 .957 .894 r
.39791 .52413 .40321 .52437 .41177 .52261 .40669 .51672 Metetra
.512 .655 .923 r
.40669 .51672 .41177 .52261 .42036 .52074 .41523 .51684 Metetra
.573 .035 0 r
.41523 .51684 .42036 .52074 .42898 .51921 .42358 .52467 Metetra
.872 .963 .632 r
.42358 .52467 .42898 .51921 .43768 .51537 .43264 .5099 Metetra
.541 .685 .933 r
.43264 .5099 .43768 .51537 .44634 .51493 .4413 .50945 Metetra
.519 .676 .936 r
.4413 .50945 .44634 .51493 .45508 .51172 .45 .50932 Metetra
.836 .872 .87 r
.45 .50932 .45508 .51172 .46395 .50336 .45889 .50152 Metetra
0 .38 .695 r
.45889 .50152 .46395 .50336 .47263 .5068 .4676 .50443 Metetra
.368 .759 .987 r
.4676 .50443 .47263 .5068 .48145 .50437 .47641 .50415 Metetra
.83 .968 .891 r
.47641 .50415 .48145 .50437 .49033 .49907 .48535 .49656 Metetra
.01 .529 .859 r
.48535 .49656 .49033 .49907 .4992 .49681 .49421 .49878 Metetra
.882 .992 .781 r
.49421 .49878 .4992 .49681 .50808 .49948 .50321 .48779 Metetra
.327 .397 .782 r
.50321 .48779 .50808 .49948 .51703 .49918 .51212 .49352 Metetra
.782 .757 .83 r
.51212 .49352 .51703 .49918 .52601 .49194 .52113 .4864 Metetra
.492 .665 .939 r
.52113 .4864 .52601 .49194 .53502 .49143 .53016 .48665 Metetra
.504 .706 .961 r
.53016 .48665 .53502 .49143 .54406 .48875 .53923 .48642 Metetra
.842 .889 .874 r
.53923 .48642 .54406 .48875 .55309 .48121 .54829 .47839 Metetra
.544 .82 .997 r
.54829 .47839 .55309 .48121 .56223 .48293 .55741 .4767 Metetra
.317 .547 .915 r
.55741 .4767 .56223 .48293 .57132 .47753 .56663 .47953 Metetra
.704 .977 .776 r
.56663 .47953 .57132 .47753 .58055 .47917 .57575 .47168 Metetra
.518 .608 .883 r
.57575 .47168 .58055 .47917 .58966 .4722 .58502 .47216 Metetra
.688 .972 .919 r
.58502 .47216 .58966 .4722 .59895 .47264 .59421 .4667 Metetra
.566 .685 .921 r
.59421 .4667 .59895 .47264 .6082 .46947 .60353 .46586 Metetra
.777 .845 .903 r
.60353 .46586 .6082 .46947 .61741 .46394 .61276 .45991 Metetra
.712 .817 .931 r
.61276 .45991 .61741 .46394 .62666 .45933 .62206 .45573 Metetra
.734 .843 .931 r
.62206 .45573 .62666 .45933 .63606 .45842 .63136 .451 Metetra
.688 .688 .845 r
.63136 .451 .63606 .45842 .64527 .45115 .64071 .44703 Metetra
.664 .803 .949 r
.64071 .44703 .64527 .45115 .65475 .45056 .65011 .44387 Metetra
.533 .645 .906 r
.65011 .44387 .65475 .45056 .66402 .44377 .65968 .44382 Metetra
.819 .993 .865 r
.65968 .44382 .66402 .44377 .67375 .44709 .66893 .43558 Metetra
.565 .545 .791 r
.66893 .43558 .67375 .44709 .68305 .44005 .67857 .43551 Metetra
.461 .703 .972 r
.67857 .43551 .68305 .44005 .69272 .44002 .68827 .43565 Metetra
.828 .828 .848 r
.68827 .43565 .69272 .44002 .70225 .43653 .69757 .42725 Metetra
.649 .631 .818 r
.69757 .42725 .70225 .43653 .71197 .43566 .70717 .42428 Metetra
.695 .617 .765 r
.70717 .42428 .71197 .43566 .72128 .42737 .71665 .41865 Metetra
.465 .549 .858 r
.71665 .41865 .72128 .42737 .73069 .42079 .72663 .42064 Metetra
.656 .968 .904 r
.72663 .42064 .73069 .42079 .74015 .41463 .73617 .41512 Metetra
.089 .646 .704 r
.73617 .41512 .74015 .41463 .75017 .41626 .74603 .41388 Metetra
.759 .92 .943 r
.74603 .41388 .75017 .41626 .76004 .41505 .75561 .40816 Metetra
.718 .723 .854 r
.75561 .40816 .76004 .41505 .77018 .41677 .76527 .40319 Metetra
.609 .544 .757 r
.76527 .40319 .77018 .41677 .77948 .407 .77519 .40134 Metetra
.639 .737 .92 r
.77519 .40134 .77948 .407 .78909 .40112 .78509 .39875 Metetra
.778 .927 .933 r
.78509 .39875 .78909 .40112 .79907 .39948 .79472 .39248 Metetra
.675 .706 .871 r
.79472 .39248 .79907 .39948 .80908 .39759 .80461 .38891 Metetra
.405 .518 .859 r
.80461 .38891 .80908 .39759 .81877 .3917 .81514 .39219 Metetra
.796 .998 .8 r
.81514 .39219 .81877 .3917 .82863 .38753 .82458 .38294 Metetra
.706 .812 .931 r
.82458 .38294 .82863 .38753 .83867 .38481 .83449 .37865 Metetra
.631 .719 .91 r
.83449 .37865 .83867 .38481 .84911 .38573 .84463 .37625 Metetra
.698 .656 .805 r
.84463 .37625 .84911 .38573 .85873 .37815 .85452 .37116 Metetra
.44 .591 .906 r
.85452 .37116 .85873 .37815 .86872 .37397 .86518 .37295 Metetra
.232 0 0 r
.86518 .37295 .86872 .37397 .88014 .38238 .87609 .37646 Metetra
.661 .745 .912 r
.87609 .37646 .88014 .38238 .89035 .37918 .88632 .37324 Metetra
.661 .745 .912 r
.88632 .37324 .89035 .37918 .90059 .37597 .89658 .37001 Metetra
.661 .745 .912 r
.89658 .37001 .90059 .37597 .91086 .37275 .90689 .36677 Metetra
.661 .745 .912 r
.30771 .54879 .31304 .55365 .3214 .55102 .31608 .54614 Metetra
.661 .745 .912 r
.31608 .54614 .3214 .55102 .32978 .54838 .32448 .54349 Metetra
.735 .759 .872 r
.32448 .54349 .32978 .54838 .33819 .54573 .33302 .53879 Metetra
.745 .7 .808 r
.33302 .53879 .33819 .54573 .34691 .53772 .34165 .53274 Metetra
.642 .737 .917 r
.34165 .53274 .34691 .53772 .35555 .53123 .3501 .53047 Metetra
.805 .937 .916 r
.3501 .53047 .35555 .53123 .36382 .53255 .35877 .52407 Metetra
.612 .617 .831 r
.35877 .52407 .36382 .53255 .37226 .53123 .36723 .52257 Metetra
.666 .636 .81 r
.36723 .52257 .37226 .53123 .38098 .52434 .37579 .5193 Metetra
.628 .733 .923 r
.37579 .5193 .38098 .52434 .38949 .52266 .38433 .51729 Metetra
.64 .724 .909 r
.38433 .51729 .38949 .52266 .39791 .52413 .39291 .51505 Metetra
.533 .566 .835 r
.39291 .51505 .39791 .52413 .40669 .51672 .40141 .51557 Metetra
.66 .921 .976 r
.40141 .51557 .40669 .51672 .41523 .51684 .41011 .51181 Metetra
.625 .735 .925 r
.41011 .51181 .41523 .51684 .42358 .52467 .41877 .50981 Metetra
.62 .529 .73 r
.41877 .50981 .42358 .52467 .43264 .5099 .42748 .50738 Metetra
.358 .748 .987 r
.42748 .50738 .43264 .5099 .4413 .50945 .43615 .50727 Metetra
.837 .881 .874 r
.43615 .50727 .4413 .50945 .45 .50932 .44505 .49951 Metetra
.531 .551 .821 r
.44505 .49951 .45 .50932 .45889 .50152 .45378 .5002 Metetra
.768 .931 .939 r
.45378 .5002 .45889 .50152 .4676 .50443 .46266 .49461 Metetra
.584 .579 .813 r
.46266 .49461 .4676 .50443 .47641 .50415 .47148 .49386 Metetra
.454 .5 .817 r
.47148 .49386 .47641 .50415 .48535 .49656 .4803 .49641 Metetra
.634 .951 .94 r
.4803 .49641 .48535 .49656 .49421 .49878 .48925 .49204 Metetra
.667 .693 .865 r
.48925 .49204 .49421 .49878 .50321 .48779 .49821 .48898 Metetra
.069 0 0 r
.49821 .48898 .50321 .48779 .51212 .49352 .50719 .48834 Metetra
.654 .745 .916 r
.50719 .48834 .51212 .49352 .52113 .4864 .51621 .48565 Metetra
.373 .825 .934 r
.51621 .48565 .52113 .4864 .53016 .48665 .52526 .48395 Metetra
.774 .878 .922 r
.52526 .48395 .53016 .48665 .53923 .48642 .53434 .47826 Metetra
.513 .586 .865 r
.53434 .47826 .53923 .48642 .54829 .47839 .54347 .479 Metetra
.692 .98 .886 r
.54347 .479 .54829 .47839 .55741 .4767 .55259 .473 Metetra
.64 .81 .965 r
.55259 .473 .55741 .4767 .56663 .47953 .56177 .47031 Metetra
.568 .588 .833 r
.56177 .47031 .56663 .47953 .57575 .47168 .571 .46995 Metetra
.5 .856 .991 r
.571 .46995 .57575 .47168 .58502 .47216 .58026 .46794 Metetra
.736 .812 .912 r
.58026 .46794 .58502 .47216 .59421 .4667 .58949 .46314 Metetra
.812 .848 .877 r
.58949 .46314 .59421 .4667 .60353 .46586 .59869 .45589 Metetra
.507 .541 .825 r
.59869 .45589 .60353 .46586 .61276 .45991 .60812 .45722 Metetra
.728 .885 .952 r
.60812 .45722 .61276 .45991 .62206 .45573 .61743 .4525 Metetra
.406 .742 .993 r
.61743 .4525 .62206 .45573 .63136 .451 .62691 .45241 Metetra
.588 .941 .794 r
.62691 .45241 .63136 .451 .64071 .44703 .63623 .4463 Metetra
.197 0 0 r
.63623 .4463 .64071 .44703 .65011 .44387 .64587 .44851 Metetra
.64587 .44851 .65011 .44387 .65968 .44382 .65514 .43983 Metetra
.858 .837 .824 r
.65514 .43983 .65968 .44382 .66893 .43558 .66435 .4299 Metetra
.673 .743 .903 r
.66435 .4299 .66893 .43558 .67857 .43551 .67386 .4266 Metetra
.347 .476 .848 r
.67386 .4266 .67857 .43551 .68827 .43565 .68377 .43083 Metetra
.809 .81 .852 r
.68377 .43083 .68827 .43565 .69757 .42725 .69314 .42307 Metetra
.666 .807 .951 r
.69314 .42307 .69757 .42725 .70717 .42428 .70275 .41979 Metetra
.743 .815 .909 r
.70275 .41979 .70717 .42428 .71665 .41865 .71229 .41462 Metetra
.199 .581 .942 r
.71229 .41462 .71665 .41865 .72663 .42064 .72232 .41717 Metetra
.826 .872 .879 r
.72232 .41717 .72663 .42064 .73617 .41512 .73175 .40934 Metetra
.452 .645 .94 r
.73175 .40934 .73617 .41512 .74603 .41388 .74177 .41023 Metetra
.741 .857 .934 r
.74177 .41023 .74603 .41388 .75561 .40816 .75143 .40511 Metetra
.761 .891 .936 r
.75143 .40511 .75561 .40816 .76527 .40319 .76107 .39943 Metetra
.545 .787 .988 r
.76107 .39943 .76527 .40319 .77519 .40134 .77104 .39793 Metetra
.792 .881 .911 r
.77104 .39793 .77519 .40134 .78509 .39875 .78066 .39133 Metetra
.662 .688 .864 r
.78066 .39133 .78509 .39875 .79472 .39248 .79057 .38809 Metetra
.667 .807 .95 r
.79057 .38809 .79472 .39248 .80461 .38891 .8005 .38468 Metetra
.71 .829 .938 r
.8005 .38468 .80461 .38891 .81514 .39219 .81037 .38027 Metetra
.528 .523 .793 r
.81037 .38027 .81514 .39219 .82458 .38294 .82079 .38147 Metetra
.792 .971 .913 r
.82079 .38147 .82458 .38294 .83449 .37865 .83047 .3743 Metetra
.715 .828 .935 r
.83047 .3743 .83449 .37865 .84463 .37625 .84042 .36973 Metetra
.7 .737 .879 r
.84042 .36973 .84463 .37625 .85452 .37116 .85042 .36537 Metetra
.631 .736 .923 r
.85042 .36537 .85452 .37116 .86518 .37295 .86064 .36289 Metetra
.675 .636 .803 r
.86064 .36289 .86518 .37295 .87609 .37646 .87071 .35859 Metetra
.384 .368 .718 r
.87071 .35859 .87609 .37646 .88632 .37324 .88226 .36727 Metetra
.661 .745 .912 r
.88226 .36727 .88632 .37324 .89658 .37001 .89255 .36402 Metetra
.661 .745 .912 r
.89255 .36402 .89658 .37001 .90689 .36677 .90288 .36075 Metetra
.661 .745 .912 r
.30235 .5439 .30771 .54879 .31608 .54614 .31073 .54124 Metetra
.661 .745 .912 r
.31073 .54124 .31608 .54614 .32448 .54349 .31915 .53857 Metetra
.853 .757 .756 r
.31915 .53857 .32448 .54349 .33302 .53879 .32818 .52587 Metetra
.618 .546 .751 r
.32818 .52587 .33302 .53879 .34165 .53274 .33659 .52382 Metetra
.598 .6 .825 r
.33659 .52382 .34165 .53274 .3501 .53047 .34497 .52271 Metetra
.679 .662 .825 r
.34497 .52271 .3501 .53047 .35877 .52407 .35352 .51915 Metetra
.593 .726 .937 r
.35352 .51915 .35877 .52407 .36723 .52257 .36198 .51775 Metetra
.629 .742 .929 r
.36198 .51775 .36723 .52257 .37579 .5193 .37051 .51567 Metetra
.613 .793 .968 r
.37051 .51567 .37579 .5193 .38433 .51729 .37907 .51362 Metetra
.571 .779 .977 r
.37907 .51362 .38433 .51729 .39291 .51505 .38763 .51215 Metetra
.628 .834 .98 r
.38763 .51215 .39291 .51505 .40141 .51557 .39627 .50962 Metetra
.511 .655 .924 r
.39627 .50962 .40141 .51557 .41011 .51181 .40485 .50973 Metetra
.818 .886 .893 r
.40485 .50973 .41011 .51181 .41877 .50981 .4137 .50282 Metetra
.582 .649 .881 r
.4137 .50282 .41877 .50981 .42748 .50738 .42237 .50191 Metetra
.522 .68 .938 r
.42237 .50191 .42748 .50738 .43615 .50727 .43106 .50169 Metetra
.54 .684 .932 r
.43106 .50169 .43615 .50727 .44505 .49951 .4398 .50123 Metetra
.128 0 0 r
.4398 .50123 .44505 .49951 .45378 .5002 .44858 .50059 Metetra
.84 .98 .873 r
.44858 .50059 .45378 .5002 .46266 .49461 .45756 .49241 Metetra
.453 .81 .997 r
.45756 .49241 .46266 .49461 .47148 .49386 .46641 .49129 Metetra
.463 .797 .999 r
.46641 .49129 .47148 .49386 .4803 .49641 .4753 .49032 Metetra
.663 .713 .885 r
.4753 .49032 .4803 .49641 .48925 .49204 .48425 .4874 Metetra
.578 .743 .954 r
.48425 .4874 .48925 .49204 .49821 .48898 .49321 .48603 Metetra
.499 .796 .998 r
.49321 .48603 .49821 .48898 .50719 .48834 .50221 .48491 Metetra
.797 .843 .886 r
.50221 .48491 .50719 .48834 .51621 .48565 .51128 .47831 Metetra
.116 .385 .842 r
.51128 .47831 .51621 .48565 .52526 .48395 .52033 .48393 Metetra
.785 .982 .903 r
.52033 .48393 .52526 .48395 .53434 .47826 .52945 .47705 Metetra
.538 .89 .98 r
.52945 .47705 .53434 .47826 .54347 .479 .53859 .47434 Metetra
.732 .79 .899 r
.53859 .47434 .54347 .479 .55259 .473 .54774 .4696 Metetra
.511 .78 .993 r
.54774 .4696 .55259 .473 .56177 .47031 .55696 .46854 Metetra
.565 .881 .992 r
.55696 .46854 .56177 .47031 .571 .46995 .56619 .46589 Metetra
.853 .823 .818 r
.56619 .46589 .571 .46995 .58026 .46794 .57535 .456 Metetra
.549 .529 .785 r
.57535 .456 .58026 .46794 .58949 .46314 .58468 .45643 Metetra
.529 .643 .906 r
.58468 .45643 .58949 .46314 .59869 .45589 .59406 .45642 Metetra
.712 .985 .878 r
.59406 .45642 .59869 .45589 .60812 .45722 .60333 .44995 Metetra
.625 .669 .872 r
.60333 .44995 .60812 .45722 .61743 .4525 .61273 .4479 Metetra
.751 .804 .895 r
.61273 .4479 .61743 .4525 .62691 .45241 .62207 .4425 Metetra
.616 .601 .813 r
.62207 .4425 .62691 .45241 .63623 .4463 .63155 .44065 Metetra
.752 .767 .865 r
.63155 .44065 .63623 .4463 .64587 .44851 .64092 .43488 Metetra
.667 .574 .741 r
.64092 .43488 .64587 .44851 .65514 .43983 .65034 .43004 Metetra
.577 .585 .824 r
.65034 .43004 .65514 .43983 .66435 .4299 .65996 .42939 Metetra
.373 .833 .908 r
.65996 .42939 .66435 .4299 .67386 .4266 .66956 .42719 Metetra
.525 .92 .849 r
.66956 .42719 .67386 .4266 .68377 .43083 .67907 .42247 Metetra
.687 .67 .828 r
.67907 .42247 .68377 .43083 .69314 .42307 .68864 .41824 Metetra
.647 .772 .94 r
.68864 .41824 .69314 .42307 .70275 .41979 .6983 .41544 Metetra
.57 .766 .971 r
.6983 .41544 .70275 .41979 .71229 .41462 .70808 .41388 Metetra
.811 .981 .892 r
.70808 .41388 .71229 .41462 .72232 .41717 .71752 .40615 Metetra
.694 .624 .773 r
.71752 .40615 .72232 .41717 .73175 .40934 .72712 .40071 Metetra
.447 .544 .863 r
.72712 .40071 .73175 .40934 .74177 .41023 .73724 .40295 Metetra
.72 .715 .845 r
.73724 .40295 .74177 .41023 .75143 .40511 .74692 .39777 Metetra
.722 .714 .842 r
.74692 .39777 .75143 .40511 .76107 .39943 .75661 .39247 Metetra
.666 .704 .875 r
.75661 .39247 .76107 .39943 .77104 .39793 .76647 .38915 Metetra
.586 .616 .849 r
.76647 .38915 .77104 .39793 .78066 .39133 .77654 .38812 Metetra
.753 .886 .939 r
.77654 .38812 .78066 .39133 .79057 .38809 .78629 .38258 Metetra
.741 .784 .887 r
.78629 .38258 .79057 .38809 .8005 .38468 .79608 .37714 Metetra
.45 .581 .893 r
.79608 .37714 .8005 .38468 .81037 .38027 .80652 .3789 Metetra
.798 .974 .908 r
.80652 .3789 .81037 .38027 .82079 .38147 .81619 .37153 Metetra
.522 .557 .833 r
.81619 .37153 .82079 .38147 .83047 .3743 .82665 .37248 Metetra
.612 .915 .979 r
.82665 .37248 .83047 .3743 .84042 .36973 .83672 .36867 Metetra
.812 .986 .885 r
.83672 .36867 .84042 .36973 .85042 .36537 .84639 .3606 Metetra
.687 .803 .937 r
.84639 .3606 .85042 .36537 .86064 .36289 .85649 .35669 Metetra
.702 .752 .89 r
.85649 .35669 .86064 .36289 .87071 .35859 .86658 .35229 Metetra
0 .271 .776 r
.86658 .35229 .87071 .35859 .88226 .36727 .87818 .36126 Metetra
.661 .745 .912 r
.87818 .36126 .88226 .36727 .89255 .36402 .8885 .35798 Metetra
.661 .745 .912 r
.8885 .35798 .89255 .36402 .90288 .36075 .89886 .3547 Metetra
.661 .745 .912 r
.29695 .53898 .30235 .5439 .31073 .54124 .30536 .5363 Metetra
.849 .757 .761 r
.30536 .5363 .31073 .54124 .31915 .53857 .31439 .52409 Metetra
.515 .468 .743 r
.31439 .52409 .31915 .53857 .32818 .52587 .32255 .52586 Metetra
.793 .964 .917 r
.32255 .52586 .32818 .52587 .33659 .52382 .33123 .51951 Metetra
.622 .763 .946 r
.33123 .51951 .33659 .52382 .34497 .52271 .33968 .51749 Metetra
.596 .716 .928 r
.33968 .51749 .34497 .52271 .35352 .51915 .34813 .51608 Metetra
.707 .838 .945 r
.34813 .51608 .35352 .51915 .36198 .51775 .35674 .51226 Metetra
.501 .669 .939 r
.35674 .51226 .36198 .51775 .37051 .51567 .36518 .51234 Metetra
.69 .825 .948 r
.36518 .51234 .37051 .51567 .37907 .51362 .37382 .50889 Metetra
.467 .689 .963 r
.37382 .50889 .37907 .51362 .38763 .51215 .38233 .50907 Metetra
.594 .817 .985 r
.38233 .50907 .38763 .51215 .39627 .50962 .39097 .50704 Metetra
.219 .669 .951 r
.39097 .50704 .39627 .50962 .40485 .50973 .39953 .50789 Metetra
.838 .892 .878 r
.39953 .50789 .40485 .50973 .4137 .50282 .40844 .50016 Metetra
.391 .759 .992 r
.40844 .50016 .4137 .50282 .42237 .50191 .41712 .49987 Metetra
.729 .896 .955 r
.41712 .49987 .42237 .50191 .43106 .50169 .42596 .4953 Metetra
.555 .66 .906 r
.42596 .4953 .43106 .50169 .4398 .50123 .43471 .49477 Metetra
.568 .664 .902 r
.43471 .49477 .4398 .50123 .44858 .50059 .44351 .49402 Metetra
.749 .722 .827 r
.44351 .49402 .44858 .50059 .45756 .49241 .45246 .48797 Metetra
.536 .735 .967 r
.45246 .48797 .45756 .49241 .46641 .49129 .46132 .48714 Metetra
.575 .764 .968 r
.46132 .48714 .46641 .49129 .4753 .49032 .47024 .48566 Metetra
.638 .762 .938 r
.47024 .48566 .4753 .49032 .48425 .4874 .4792 .48325 Metetra
.716 .804 .919 r
.4792 .48325 .48425 .4874 .49321 .48603 .48822 .47906 Metetra
.597 .661 .883 r
.48822 .47906 .49321 .48603 .50221 .48491 .49723 .47773 Metetra
.51 .616 .893 r
.49723 .47773 .50221 .48491 .51128 .47831 .50627 .47818 Metetra
.593 .025 0 r
.50627 .47818 .51128 .47831 .52033 .48393 .51535 .48375 Metetra
.786 .979 .908 r
.51535 .48375 .52033 .48393 .52945 .47705 .52451 .47693 Metetra
.899 .954 .827 r
.52451 .47693 .52945 .47705 .53859 .47434 .53366 .46627 Metetra
.604 .635 .855 r
.53366 .46627 .53859 .47434 .54774 .4696 .54285 .46482 Metetra
.478 .699 .966 r
.54285 .46482 .54774 .4696 .55696 .46854 .55209 .46482 Metetra
.613 .805 .973 r
.55209 .46482 .55696 .46854 .56619 .46589 .56136 .46251 Metetra
.194 .615 .947 r
.56136 .46251 .56619 .46589 .57535 .456 .57071 .46429 Metetra
.57071 .46429 .57535 .456 .58468 .45643 .57996 .45625 Metetra
.84 .981 .873 r
.57996 .45625 .58468 .45643 .59406 .45642 .5892 .44782 Metetra
.338 .482 .857 r
.5892 .44782 .59406 .45642 .60333 .44995 .59873 .45175 Metetra
.829 .997 .772 r
.59873 .45175 .60333 .44995 .61273 .4479 .60796 .44153 Metetra
.568 .676 .912 r
.60796 .44153 .61273 .4479 .62207 .4425 .61745 .44065 Metetra
.712 .924 .963 r
.61745 .44065 .62207 .4425 .63155 .44065 .62686 .43587 Metetra
.634 .767 .943 r
.62686 .43587 .63155 .44065 .64092 .43488 .63637 .43336 Metetra
.887 .932 .843 r
.63637 .43336 .64092 .43488 .65034 .43004 .64564 .42324 Metetra
.738 .729 .842 r
.64564 .42324 .65034 .43004 .65996 .42939 .65507 .41753 Metetra
.578 .549 .786 r
.65507 .41753 .65996 .42939 .66956 .42719 .66474 .41693 Metetra
.371 .46 .822 r
.66474 .41693 .66956 .42719 .67907 .42247 .67469 .42135 Metetra
.879 .956 .851 r
.67469 .42135 .67907 .42247 .68864 .41824 .68402 .41161 Metetra
.661 .71 .884 r
.68402 .41161 .68864 .41824 .6983 .41544 .69369 .40852 Metetra
.659 .7 .877 r
.69369 .40852 .6983 .41544 .70808 .41388 .7034 .40544 Metetra
.585 .623 .856 r
.7034 .40544 .70808 .41388 .71752 .40615 .71326 .40442 Metetra
.883 .939 .848 r
.71326 .40442 .71752 .40615 .72712 .40071 .72262 .39446 Metetra
.359 .576 .923 r
.72262 .39446 .72712 .40071 .73724 .40295 .73277 .39688 Metetra
.727 .756 .876 r
.73277 .39688 .73724 .40295 .74692 .39777 .74248 .39182 Metetra
.657 .736 .908 r
.74248 .39182 .74692 .39777 .75661 .39247 .75236 .38878 Metetra
.753 .863 .93 r
.75236 .38878 .75661 .39247 .76647 .38915 .76209 .38329 Metetra
.609 .721 .925 r
.76209 .38329 .76647 .38915 .77654 .38812 .77211 .38135 Metetra
.73 .737 .857 r
.77211 .38135 .77654 .38812 .78629 .38258 .7819 .37592 Metetra
.41 .591 .917 r
.7819 .37592 .78629 .38258 .79608 .37714 .79233 .37788 Metetra
.807 .997 .781 r
.79233 .37788 .79608 .37714 .80652 .3789 .8018 .36803 Metetra
.66 .613 .791 r
.8018 .36803 .80652 .3789 .81619 .37153 .81181 .36417 Metetra
.616 .674 .883 r
.81181 .36417 .81619 .37153 .82665 .37248 .82202 .36217 Metetra
.674 .632 .799 r
.82202 .36217 .82665 .37248 .83672 .36867 .83204 .35782 Metetra
.516 .537 .816 r
.83204 .35782 .83672 .36867 .84639 .3606 .84266 .35911 Metetra
.622 .933 .964 r
.84266 .35911 .84639 .3606 .85649 .35669 .85277 .3548 Metetra
.628 .921 .976 r
.85277 .3548 .85649 .35669 .86658 .35229 .86293 .3507 Metetra
.659 .945 .96 r
.86293 .3507 .86658 .35229 .87818 .36126 .87305 .34586 Metetra
.418 .415 .748 r
.87305 .34586 .87818 .36126 .8885 .35798 .88442 .35191 Metetra
.661 .745 .912 r
.88442 .35191 .8885 .35798 .89886 .3547 .8948 .34861 Metetra
.661 .745 .912 r
.29153 .53403 .29695 .53898 .30536 .5363 .29995 .53134 Metetra
.711 .755 .887 r
.29995 .53134 .30536 .5363 .31439 .52409 .30847 .52736 Metetra
.548 .908 .713 r
.30847 .52736 .31439 .52409 .32255 .52586 .31716 .52112 Metetra
.609 .74 .939 r
.31716 .52112 .32255 .52586 .33123 .51951 .32559 .5194 Metetra
.298 0 0 r
.32559 .5194 .33123 .51951 .33968 .51749 .33385 .52127 Metetra
.568 .907 .676 r
.33385 .52127 .33968 .51749 .34813 .51608 .34265 .51418 Metetra
.294 0 0 r
.34265 .51418 .34813 .51608 .35674 .51226 .35091 .51744 Metetra
.35091 .51744 .35674 .51226 .36518 .51234 .35972 .51065 Metetra
.356 0 0 r
.35972 .51065 .36518 .51234 .37382 .50889 .36806 .51423 Metetra
.36806 .51423 .37382 .50889 .38233 .50907 .37695 .50677 Metetra
.383 .772 .989 r
.37695 .50677 .38233 .50907 .39097 .50704 .38555 .5063 Metetra
.859 .93 .871 r
.38555 .5063 .39097 .50704 .39953 .50789 .3945 .49784 Metetra
.648 .606 .793 r
.3945 .49784 .39953 .50789 .40844 .50016 .40325 .49491 Metetra
.527 .694 .945 r
.40325 .49491 .40844 .50016 .41712 .49987 .41194 .4945 Metetra
.548 .698 .939 r
.41194 .4945 .41712 .49987 .42596 .4953 .42067 .49382 Metetra
.582 .891 .989 r
.42067 .49382 .42596 .4953 .43471 .49477 .42951 .49103 Metetra
.498 .754 .987 r
.42951 .49103 .43471 .49477 .44351 .49402 .43833 .49035 Metetra
.535 .773 .985 r
.43833 .49035 .44351 .49402 .45246 .48797 .44719 .4892 Metetra
.44719 .4892 .45246 .48797 .46132 .48714 .4561 .48788 Metetra
.6 .951 .887 r
.4561 .48788 .46132 .48714 .47024 .48566 .46511 .48306 Metetra
0 .373 .737 r
.46511 .48306 .47024 .48566 .4792 .48325 .47401 .48658 Metetra
.47401 .48658 .4792 .48325 .48822 .47906 .48308 .48117 Metetra
.381 .827 .704 r
.48308 .48117 .48822 .47906 .49723 .47773 .49216 .47664 Metetra
0 .466 .71 r
.49216 .47664 .49723 .47773 .50627 .47818 .50122 .47841 Metetra
.269 0 0 r
.50122 .47841 .50627 .47818 .51535 .48375 .51034 .4801 Metetra
.741 .836 .923 r
.51034 .4801 .51535 .48375 .52451 .47693 .51952 .4752 Metetra
.257 .729 .942 r
.51952 .4752 .52451 .47693 .53366 .46627 .52873 .47509 Metetra
.52873 .47509 .53366 .46627 .54285 .46482 .53795 .46663 Metetra
.624 .097 0 r
.53795 .46663 .54285 .46482 .55209 .46482 .54727 .47211 Metetra
.54727 .47211 .55209 .46482 .56136 .46251 .55653 .46451 Metetra
.815 .997 .776 r
.55653 .46451 .56136 .46251 .57071 .46429 .56578 .45464 Metetra
.801 .684 .736 r
.56578 .45464 .57071 .46429 .57996 .45625 .57499 .44268 Metetra
.471 .462 .766 r
.57499 .44268 .57996 .45625 .5892 .44782 .58444 .44575 Metetra
.168 .659 .92 r
.58444 .44575 .5892 .44782 .59873 .45175 .59392 .44658 Metetra
.833 .793 .814 r
.59392 .44658 .59873 .45175 .60796 .44153 .60321 .43703 Metetra
.507 .73 .973 r
.60321 .43703 .60796 .44153 .61745 .44065 .61273 .43647 Metetra
.831 .831 .847 r
.61273 .43647 .61745 .44065 .62686 .43587 .62206 .42794 Metetra
.635 .658 .855 r
.62206 .42794 .62686 .43587 .63637 .43336 .63159 .42553 Metetra
.803 .722 .775 r
.63159 .42553 .63637 .43336 .64564 .42324 .64088 .41556 Metetra
.452 .576 .888 r
.64088 .41556 .64564 .42324 .65507 .41753 .65062 .41719 Metetra
.474 .89 .917 r
.65062 .41719 .65507 .41753 .66474 .41693 .66021 .41395 Metetra
.617 .852 .988 r
.66021 .41395 .66474 .41693 .67469 .42135 .66986 .4111 Metetra
.753 .662 .761 r
.66986 .4111 .67469 .42135 .68402 .41161 .67927 .40259 Metetra
.538 .585 .85 r
.67927 .40259 .68402 .41161 .69369 .40852 .68912 .40284 Metetra
.718 .765 .89 r
.68912 .40284 .69369 .40852 .7034 .40544 .69877 .39818 Metetra
.798 .739 .798 r
.69877 .39818 .7034 .40544 .71326 .40442 .70819 .3892 Metetra
.461 .439 .748 r
.70819 .3892 .71326 .40442 .72262 .39446 .7184 .39326 Metetra
.511 .89 .965 r
.7184 .39326 .72262 .39446 .73277 .39688 .72824 .39031 Metetra
.705 .733 .873 r
.72824 .39031 .73277 .39688 .74248 .39182 .73801 .38582 Metetra
.73 .761 .878 r
.73801 .38582 .74248 .39182 .75236 .38878 .74776 .38065 Metetra
.709 .691 .831 r
.74776 .38065 .75236 .38878 .76209 .38329 .75755 .37556 Metetra
.598 .653 .876 r
.75755 .37556 .76209 .38329 .77211 .38135 .76763 .37408 Metetra
.612 .675 .885 r
.76763 .37408 .77211 .38135 .7819 .37592 .77772 .37218 Metetra
.744 .863 .935 r
.77772 .37218 .7819 .37592 .79233 .37788 .78757 .36685 Metetra
.695 .629 .778 r
.78757 .36685 .79233 .37788 .8018 .36803 .79743 .36128 Metetra
.6 .688 .904 r
.79743 .36128 .8018 .36803 .81181 .36417 .80765 .35961 Metetra
.777 .837 .898 r
.80765 .35961 .81181 .36417 .82202 .36217 .81749 .35319 Metetra
.499 .569 .858 r
.81749 .35319 .82202 .36217 .83204 .35782 .82806 .35439 Metetra
.807 .895 .906 r
.82806 .35439 .83204 .35782 .84266 .35911 .83787 .34718 Metetra
.536 .531 .797 r
.83787 .34718 .84266 .35911 .85277 .3548 .84851 .34797 Metetra
.788 .763 .83 r
.84851 .34797 .85277 .3548 .86293 .3507 .85829 .34002 Metetra
.667 .624 .797 r
.85829 .34002 .86293 .3507 .87305 .34586 .8685 .33587 Metetra
.118 .307 .779 r
.8685 .33587 .87305 .34586 .88442 .35191 .88031 .3458 Metetra
.661 .745 .912 r
.88031 .3458 .88442 .35191 .8948 .34861 .89072 .34247 Metetra
.661 .745 .912 r
.28607 .52906 .29153 .53403 .29995 .53134 .2945 .52635 Metetra
.846 .757 .765 r
.2945 .52635 .29995 .53134 .30847 .52736 .30358 .51439 Metetra
.607 .54 .754 r
.30358 .51439 .30847 .52736 .31716 .52112 .31198 .51273 Metetra
.446 .542 .861 r
.31198 .51273 .31716 .52112 .32559 .5194 .3202 .51452 Metetra
.785 .769 .838 r
.3202 .51452 .32559 .5194 .33385 .52127 .32897 .50766 Metetra
.44 .435 .757 r
.32897 .50766 .33385 .52127 .34265 .51418 .33717 .51123 Metetra
.808 .844 .877 r
.33717 .51123 .34265 .51418 .35091 .51744 .34599 .50439 Metetra
.615 .545 .753 r
.34599 .50439 .35091 .51744 .35972 .51065 .35456 .50235 Metetra
.626 .632 .837 r
.35456 .50235 .35972 .51065 .36806 .51423 .36317 .50037 Metetra
.433 .429 .755 r
.36317 .50037 .36806 .51423 .37695 .50677 .37154 .50423 Metetra
.832 .861 .867 r
.37154 .50423 .37695 .50677 .38555 .5063 .38047 .49644 Metetra
.645 .609 .798 r
.38047 .49644 .38555 .5063 .3945 .49784 .38921 .49363 Metetra
.743 .799 .898 r
.38921 .49363 .3945 .49784 .40325 .49491 .39805 .48874 Metetra
.527 .658 .919 r
.39805 .48874 .40325 .49491 .41194 .4945 .40674 .48859 Metetra
.537 .673 .925 r
.40674 .48859 .41194 .4945 .42067 .49382 .41548 .4882 Metetra
.565 .696 .929 r
.41548 .4882 .42067 .49382 .42951 .49103 .42428 .48727 Metetra
.531 .769 .984 r
.42428 .48727 .42951 .49103 .43833 .49035 .43313 .48619 Metetra
.555 .758 .972 r
.43313 .48619 .43833 .49035 .44719 .4892 .44201 .48496 Metetra
.746 .805 .899 r
.44201 .48496 .44719 .4892 .4561 .48788 .45102 .47992 Metetra
.268 .461 .864 r
.45102 .47992 .4561 .48788 .46511 .48306 .45987 .48406 Metetra
.624 .961 .871 r
.45987 .48406 .46511 .48306 .47401 .48658 .46894 .47869 Metetra
.191 .418 .851 r
.46894 .47869 .47401 .48658 .48308 .48117 .47789 .4837 Metetra
.482 .878 .706 r
.47789 .4837 .48308 .48117 .49216 .47664 .48703 .47792 Metetra
.434 .871 .8 r
.48703 .47792 .49216 .47664 .50122 .47841 .49617 .47383 Metetra
0 .195 .674 r
.49617 .47383 .50122 .47841 .51034 .4801 .50527 .48038 Metetra
.187 0 0 r
.50527 .48038 .51034 .4801 .51952 .4752 .51447 .48142 Metetra
.389 0 .045 r
.51447 .48142 .51952 .4752 .52873 .47509 .52373 .48069 Metetra
.426 0 .037 r
.52373 .48069 .52873 .47509 .53795 .46663 .53303 .48089 Metetra
.622 .274 .36 r
.53303 .48089 .53795 .46663 .54727 .47211 .54241 .48679 Metetra
.584 .239 .35 r
.54241 .48679 .54727 .47211 .55653 .46451 .55186 .49047 Metetra
.541 .248 .418 r
.55186 .49047 .55653 .46451 .56578 .45464 .56134 .4912 Metetra
.554 .281 .456 r
.56134 .4912 .56578 .45464 .57499 .44268 .57089 .49285 Metetra
.366 .142 .436 r
.57089 .49285 .57499 .44268 .58444 .44575 .58012 .47192 Metetra
.1 0 .277 r
.58012 .47192 .58444 .44575 .59392 .44658 .58926 .45025 Metetra
.995 .871 .574 r
.58926 .45025 .59392 .44658 .60321 .43703 .59815 .42036 Metetra
.832 .638 .64 r
.59815 .42036 .60321 .43703 .61273 .43647 .60699 .39391 Metetra
.425 .302 .608 r
.60699 .39391 .61273 .43647 .62206 .42794 .61688 .40791 Metetra
.619 .498 .692 r
.61688 .40791 .62206 .42794 .63159 .42553 .62636 .40446 Metetra
.631 .5 .684 r
.62636 .40446 .63159 .42553 .64088 .41556 .63583 .39993 Metetra
.584 .508 .735 r
.63583 .39993 .64088 .41556 .65062 .41719 .64545 .39899 Metetra
.656 .531 .7 r
.64545 .39899 .65062 .41719 .66021 .41395 .65494 .39335 Metetra
.577 .469 .694 r
.65494 .39335 .66021 .41395 .66986 .4111 .66465 .39257 Metetra
.601 .496 .707 r
.66465 .39257 .66986 .4111 .67927 .40259 .67435 .39049 Metetra
.541 .527 .789 r
.67435 .39049 .67927 .40259 .68912 .40284 .68422 .39111 Metetra
.661 .598 .773 r
.68422 .39111 .68912 .40284 .69877 .39818 .69391 .38701 Metetra
.618 .585 .794 r
.69391 .38701 .69877 .39818 .70819 .3892 .70373 .38488 Metetra
.592 .781 .97 r
.70373 .38488 .70819 .3892 .7184 .39326 .71359 .38285 Metetra
.772 .671 .752 r
.71359 .38285 .7184 .39326 .72824 .39031 .72302 .37303 Metetra
.643 .531 .712 r
.72302 .37303 .72824 .39031 .73801 .38582 .73278 .36849 Metetra
.656 .539 .709 r
.73278 .36849 .73801 .38582 .74776 .38065 .74251 .36307 Metetra
.564 .482 .721 r
.74251 .36307 .74776 .38065 .75755 .37556 .75265 .36308 Metetra
.416 .449 .787 r
.75265 .36308 .75755 .37556 .76763 .37408 .76317 .36757 Metetra
.731 .749 .866 r
.76317 .36757 .76763 .37408 .77772 .37218 .77302 .36216 Metetra
.685 .642 .801 r
.77302 .36216 .77772 .37218 .78757 .36685 .78294 .35746 Metetra
.617 .622 .833 r
.78294 .35746 .78757 .36685 .79743 .36128 .79311 .35542 Metetra
.772 .786 .864 r
.79311 .35542 .79743 .36128 .80765 .35961 .80292 .34871 Metetra
.494 .525 .818 r
.80292 .34871 .80765 .35961 .81749 .35319 .81351 .35054 Metetra
.863 .928 .868 r
.81351 .35054 .81749 .35319 .82806 .35439 .82314 .34129 Metetra
.54 .516 .778 r
.82314 .34129 .82806 .35439 .83787 .34718 .83374 .34209 Metetra
.837 .832 .842 r
.83374 .34209 .83787 .34718 .84851 .34797 .8434 .33292 Metetra
.546 .497 .752 r
.8434 .33292 .84851 .34797 .85829 .34002 .85409 .33365 Metetra
.796 .782 .84 r
.85409 .33365 .85829 .34002 .8685 .33587 .86391 .32563 Metetra
0 .166 .699 r
.86391 .32563 .8685 .33587 .88031 .3458 .87617 .33965 Metetra
.661 .745 .912 r
.87617 .33965 .88031 .3458 .89072 .34247 .88661 .3363 Metetra
.661 .745 .912 r
.28058 .52405 .28607 .52906 .2945 .52635 .28903 .52133 Metetra
.813 .762 .805 r
.28903 .52133 .2945 .52635 .30358 .51439 .29792 .51258 Metetra
0 .506 .788 r
.29792 .51258 .30358 .51439 .31198 .51273 .30612 .5143 Metetra
.739 .991 .871 r
.30612 .5143 .31198 .51273 .3202 .51452 .31489 .50772 Metetra
.63 .674 .873 r
.31489 .50772 .3202 .51452 .32897 .50766 .32339 .50569 Metetra
.459 .821 .995 r
.32339 .50569 .32897 .50766 .33717 .51123 .33188 .50443 Metetra
.634 .677 .873 r
.33188 .50443 .33717 .51123 .34599 .50439 .34046 .50228 Metetra
.481 .825 .998 r
.34046 .50228 .34599 .50439 .35456 .50235 .34902 .50091 Metetra
.696 .915 .969 r
.34902 .50091 .35456 .50235 .36317 .50037 .35776 .49676 Metetra
.477 .753 .99 r
.35776 .49676 .36317 .50037 .37154 .50423 .36634 .49623 Metetra
.674 .661 .829 r
.36634 .49623 .37154 .50423 .38047 .49644 .37511 .49272 Metetra
.576 .784 .978 r
.37511 .49272 .38047 .49644 .38921 .49363 .38381 .49109 Metetra
.391 .767 .992 r
.38381 .49109 .38921 .49363 .39805 .48874 .3925 .49067 Metetra
.78 .998 .831 r
.3925 .49067 .39805 .48874 .40674 .48859 .40152 .48264 Metetra
.294 .554 .924 r
.40152 .48264 .40674 .48859 .41548 .4882 .41017 .48516 Metetra
.462 .777 .998 r
.41017 .48516 .41548 .4882 .42428 .48727 .41899 .48442 Metetra
.478 .793 .999 r
.41899 .48442 .42428 .48727 .43313 .48619 .42785 .48342 Metetra
.755 .869 .931 r
.42785 .48342 .43313 .48619 .44201 .48496 .43686 .47826 Metetra
.612 .678 .888 r
.43686 .47826 .44201 .48496 .45102 .47992 .44581 .47654 Metetra
0 .438 .827 r
.44581 .47654 .45102 .47992 .45987 .48406 .45468 .47992 Metetra
.698 .805 .931 r
.45468 .47992 .45987 .48406 .46894 .47869 .46376 .47612 Metetra
.415 .78 .995 r
.46376 .47612 .46894 .47869 .47789 .4837 .4728 .47546 Metetra
.51 .588 .868 r
.4728 .47546 .47789 .4837 .48703 .47792 .48188 .47609 Metetra
.51 .856 .993 r
.48188 .47609 .48703 .47792 .49617 .47383 .49103 .47405 Metetra
.639 .09 0 r
.49103 .47405 .49617 .47383 .50527 .48038 .50015 .48038 Metetra
.466 .888 .908 r
.50015 .48038 .50527 .48038 .51447 .48142 .5094 .4772 Metetra
.246 .61 .955 r
.5094 .4772 .51447 .48142 .52373 .48069 .51867 .47911 Metetra
0 .466 .747 r
.51867 .47911 .52373 .48069 .53303 .48089 .528 .4813 Metetra
.783 .3 .076 r
.528 .4813 .53303 .48089 .54241 .48679 .53743 .49281 Metetra
.551 .1 .133 r
.53743 .49281 .54241 .48679 .55186 .49047 .54691 .4957 Metetra
.646 .193 .163 r
.54691 .4957 .55186 .49047 .56134 .4912 .55649 .50168 Metetra
.553 .167 .265 r
.55649 .50168 .56134 .4912 .57089 .49285 .56611 .50409 Metetra
.54 .162 .273 r
.56611 .50409 .57089 .49285 .58012 .47192 .57579 .50595 Metetra
.57 .289 .45 r
.57579 .50595 .58012 .47192 .58926 .45025 .58556 .50956 Metetra
.522 .275 .481 r
.58556 .50956 .58926 .45025 .59815 .42036 .59525 .50582 Metetra
.529 .292 .5 r
.59525 .50582 .59815 .42036 .60699 .39391 .60494 .50125 Metetra
.237 .071 .443 r
.60494 .50125 .60699 .39391 .61688 .40791 .61289 .43118 Metetra
.61289 .43118 .61688 .40791 .62636 .40446 .62117 .38425 Metetra
0 .045 .577 r
.62117 .38425 .62636 .40446 .63583 .39993 .63148 .40576 Metetra
.63148 .40576 .63583 .39993 .64545 .39899 .64088 .39689 Metetra
.573 .878 .993 r
.64088 .39689 .64545 .39899 .65494 .39335 .65051 .39409 Metetra
.711 .187 0 r
.65051 .39409 .65494 .39335 .66465 .39257 .66068 .40328 Metetra
0 0 .021 r
.66068 .40328 .66465 .39257 .67435 .39049 .67002 .39151 Metetra
.293 .785 .743 r
.67002 .39151 .67435 .39049 .68422 .39111 .67974 .38819 Metetra
.334 .726 .983 r
.67974 .38819 .68422 .39111 .69391 .38701 .68968 .38839 Metetra
.586 .937 .775 r
.68968 .38839 .69391 .38701 .70373 .38488 .6993 .38184 Metetra
.264 .679 .967 r
.6993 .38184 .70373 .38488 .71359 .38285 .70937 .38277 Metetra
.55 .93 .897 r
.70937 .38277 .71359 .38285 .72302 .37303 .71917 .37826 Metetra
.078 0 0 r
.71917 .37826 .72302 .37303 .73278 .36849 .72899 .3736 Metetra
.238 0 0 r
.72899 .3736 .73278 .36849 .74251 .36307 .73897 .3711 Metetra
.229 0 .053 r
.73897 .3711 .74251 .36307 .75265 .36308 .74883 .36614 Metetra
.74883 .36614 .75265 .36308 .76317 .36757 .7587 .36116 Metetra
.526 .666 .925 r
.7587 .36116 .76317 .36757 .77302 .36216 .76897 .36091 Metetra
.347 .805 .939 r
.76897 .36091 .77302 .36216 .78294 .35746 .77919 .3594 Metetra
.386 .815 .645 r
.77919 .3594 .78294 .35746 .79311 .35542 .7891 .35364 Metetra
.577 .904 .981 r
.7891 .35364 .79311 .35542 .80292 .34871 .79924 .3502 Metetra
.289 .768 .664 r
.79924 .3502 .80292 .34871 .81351 .35054 .80933 .34589 Metetra
.693 .815 .94 r
.80933 .34589 .81351 .35054 .82314 .34129 .81947 .34176 Metetra
.405 .856 .803 r
.81947 .34176 .82314 .34129 .83374 .34209 .82964 .33762 Metetra
.351 .66 .971 r
.82964 .33762 .83374 .34209 .8434 .33292 .84038 .33889 Metetra
.84038 .33889 .8434 .33292 .85409 .33365 .85007 .32927 Metetra
.377 .679 .977 r
.85007 .32927 .85409 .33365 .86391 .32563 .86087 .33015 Metetra
.522 .015 0 r
.86087 .33015 .86391 .32563 .87617 .33965 .87201 .33345 Metetra
.661 .745 .912 r
.87201 .33345 .87617 .33965 .88661 .3363 .88247 .33008 Metetra
.745 .76 .865 r
.27505 .51902 .28058 .52405 .28903 .52133 .28369 .51387 Metetra
.756 .695 .793 r
.28369 .51387 .28903 .52133 .29792 .51258 .29248 .50687 Metetra
.684 .726 .882 r
.29248 .50687 .29792 .51258 .30612 .5143 .30103 .50353 Metetra
.611 .575 .789 r
.30103 .50353 .30612 .5143 .31489 .50772 .30949 .50185 Metetra
.598 .696 .911 r
.30949 .50185 .31489 .50772 .32339 .50569 .31797 .50042 Metetra
.705 .749 .886 r
.31797 .50042 .32339 .50569 .33188 .50443 .32663 .4965 Metetra
.294 .477 .869 r
.32663 .4965 .33188 .50443 .34046 .50228 .33489 .50002 Metetra
.824 .873 .881 r
.33489 .50002 .34046 .50228 .34902 .50091 .3438 .49273 Metetra
.278 .46 .86 r
.3438 .49273 .34902 .50091 .35776 .49676 .35213 .4966 Metetra
.835 .958 .892 r
.35213 .4966 .35776 .49676 .36634 .49623 .36109 .48895 Metetra
.573 .641 .88 r
.36109 .48895 .36634 .49623 .37511 .49272 .36974 .48817 Metetra
.809 .789 .834 r
.36974 .48817 .37511 .49272 .38381 .49109 .37874 .48029 Metetra
.576 .56 .799 r
.37874 .48029 .38381 .49109 .3925 .49067 .38744 .47969 Metetra
.642 .591 .781 r
.38744 .47969 .3925 .49067 .40152 .48264 .39626 .47676 Metetra
.756 .745 .842 r
.39626 .47676 .40152 .48264 .41017 .48516 .40523 .47073 Metetra
.593 .52 .742 r
.40523 .47073 .41017 .48516 .41899 .48442 .41406 .46946 Metetra
.596 .517 .736 r
.41406 .46946 .41899 .48442 .42785 .48342 .42292 .46799 Metetra
.603 .517 .73 r
.42292 .46799 .42785 .48342 .43686 .47826 .43184 .46615 Metetra
.454 .471 .787 r
.43184 .46615 .43686 .47826 .44581 .47654 .44066 .46899 Metetra
.729 .697 .819 r
.44066 .46899 .44581 .47654 .45468 .47992 .44975 .46338 Metetra
.532 .465 .726 r
.44975 .46338 .45468 .47992 .46376 .47612 .45871 .46466 Metetra
.754 .64 .734 r
.45871 .46466 .46376 .47612 .4728 .47546 .46791 .455 Metetra
.563 .458 .692 r
.46791 .455 .4728 .47546 .48188 .47609 .47696 .455 Metetra
.51 .42 .689 r
.47696 .455 .48188 .47609 .49103 .47405 .48603 .45778 Metetra
.595 .507 .725 r
.48603 .45778 .49103 .47405 .50015 .48038 .4952 .45622 Metetra
.443 .36 .668 r
.4952 .45622 .50015 .48038 .5094 .4772 .50436 .46288 Metetra
.631 .547 .742 r
.50436 .46288 .5094 .4772 .51867 .47911 .51364 .45979 Metetra
.722 .564 .675 r
.51364 .45979 .51867 .47911 .528 .4813 .52295 .44769 Metetra
.337 .255 .614 r
.52295 .44769 .528 .4813 .53743 .49281 .5323 .46341 Metetra
0 0 .459 r
.5323 .46341 .53743 .49281 .54691 .4957 .54189 .49683 Metetra
.916 .554 .33 r
.54189 .49683 .54691 .4957 .55649 .50168 .55175 .5344 Metetra
.741 .442 .475 r
.55175 .5344 .55649 .50168 .56611 .50409 .56182 .56679 Metetra
.559 .306 .488 r
.56182 .56679 .56611 .50409 .57579 .50595 .57172 .56981 Metetra
.547 .296 .487 r
.57172 .56981 .57579 .50595 .58556 .50956 .58166 .57052 Metetra
.532 .282 .482 r
.58166 .57052 .58556 .50956 .59525 .50582 .5916 .56858 Metetra
.467 .23 .471 r
.5916 .56858 .59525 .50582 .60494 .50125 .60134 .55577 Metetra
.346 .128 .433 r
.60134 .55577 .60494 .50125 .61289 .43118 .61075 .53097 Metetra
.219 .055 .434 r
.61075 .53097 .61289 .43118 .62117 .38425 .61884 .46337 Metetra
.238 .063 .43 r
.61884 .46337 .62117 .38425 .63148 .40576 .62709 .412 Metetra
.5 .044 .1 r
.62709 .412 .63148 .40576 .64088 .39689 .63692 .41369 Metetra
.383 .067 .3 r
.63692 .41369 .64088 .39689 .65051 .39409 .64653 .40804 Metetra
.53 .176 .311 r
.64653 .40804 .65051 .39409 .66068 .40328 .65645 .40928 Metetra
.65645 .40928 .66068 .40328 .67002 .39151 .66595 .39971 Metetra
.317 0 .089 r
.66595 .39971 .67002 .39151 .67974 .38819 .67575 .39654 Metetra
.106 0 .002 r
.67575 .39654 .67974 .38819 .68968 .38839 .68539 .38955 Metetra
.68539 .38955 .68968 .38839 .6993 .38184 .69533 .38797 Metetra
.69533 .38797 .6993 .38184 .70937 .38277 .70494 .37976 Metetra
.465 .794 .999 r
.70494 .37976 .70937 .38277 .71917 .37826 .71498 .37866 Metetra
.71498 .37866 .71917 .37826 .72899 .3736 .72507 .37772 Metetra
.72507 .37772 .72899 .3736 .73897 .3711 .73499 .37327 Metetra
.73499 .37327 .73897 .3711 .74883 .36614 .74491 .36852 Metetra
.74491 .36852 .74883 .36614 .7587 .36116 .75484 .36343 Metetra
.75484 .36343 .7587 .36116 .76897 .36091 .76491 .35993 Metetra
.628 .947 .945 r
.76491 .35993 .76897 .36091 .77919 .3594 .77491 .35517 Metetra
.746 .847 .926 r
.77491 .35517 .77919 .3594 .7891 .35364 .78488 .34969 Metetra
.583 .805 .984 r
.78488 .34969 .7891 .35364 .79924 .3502 .79516 .34749 Metetra
.772 .923 .936 r
.79516 .34749 .79924 .3502 .80933 .34589 .80511 .34117 Metetra
.576 .767 .969 r
.80511 .34117 .80933 .34589 .81947 .34176 .8155 .33936 Metetra
.657 .911 .979 r
.8155 .33936 .81947 .34176 .82964 .33762 .8257 .33513 Metetra
.622 .895 .987 r
.8257 .33513 .82964 .33762 .84038 .33889 .836 .33147 Metetra
.509 .627 .902 r
.836 .33147 .84038 .33889 .85007 .32927 .84673 .33182 Metetra
.84673 .33182 .85007 .32927 .86087 .33015 .85669 .32422 Metetra
.542 .7 .942 r
.85669 .32422 .86087 .33015 .87201 .33345 .8674 .3234 Metetra
.534 .57 .838 r
.8674 .3234 .87201 .33345 .88247 .33008 .87831 .32382 Metetra
.867 .751 .732 r
.2695 .51395 .27505 .51902 .28369 .51387 .27892 .49853 Metetra
.608 .517 .726 r
.27892 .49853 .28369 .51387 .29248 .50687 .28734 .49652 Metetra
.484 .517 .816 r
.28734 .49652 .29248 .50687 .30103 .50353 .29555 .49809 Metetra
.771 .752 .836 r
.29555 .49809 .30103 .50353 .30949 .50185 .30435 .49159 Metetra
.67 .612 .782 r
.30435 .49159 .30949 .50185 .31797 .50042 .31299 .48771 Metetra
.434 .446 .773 r
.31299 .48771 .31797 .50042 .32663 .4965 .3212 .491 Metetra
.786 .754 .824 r
.3212 .491 .32663 .4965 .33489 .50002 .3301 .48371 Metetra
.638 .529 .714 r
.3301 .48371 .33489 .50002 .3438 .49273 .33881 .47989 Metetra
.565 .522 .766 r
.33881 .47989 .3438 .49273 .35213 .4966 .34735 .47967 Metetra
.63 .52 .71 r
.34735 .47967 .35213 .4966 .36109 .48895 .3561 .47617 Metetra
.595 .54 .763 r
.3561 .47617 .36109 .48895 .36974 .48817 .36476 .47487 Metetra
.636 .556 .748 r
.36476 .47487 .36974 .48817 .37874 .48029 .37354 .4718 Metetra
.533 .589 .857 r
.37354 .4718 .37874 .48029 .38744 .47969 .38221 .47198 Metetra
.589 .638 .867 r
.38221 .47198 .38744 .47969 .39626 .47676 .39098 .47084 Metetra
.668 .724 .891 r
.39098 .47084 .39626 .47676 .40523 .47073 .39986 .46777 Metetra
.798 .858 .895 r
.39986 .46777 .40523 .47073 .41406 .46946 .40889 .46126 Metetra
.616 .637 .848 r
.40889 .46126 .41406 .46946 .42292 .46799 .41777 .45946 Metetra
.715 .669 .803 r
.41777 .45946 .42292 .46799 .43184 .46615 .4268 .45406 Metetra
.449 .469 .788 r
.4268 .45406 .43184 .46615 .44066 .46899 .43562 .45697 Metetra
.701 .608 .749 r
.43562 .45697 .44066 .46899 .44975 .46338 .44472 .45072 Metetra
.525 .505 .777 r
.44472 .45072 .44975 .46338 .45871 .46466 .45368 .45176 Metetra
.488 .481 .775 r
.45368 .45176 .45871 .46466 .46791 .455 .46266 .4539 Metetra
.584 .911 .977 r
.46266 .4539 .46791 .455 .47696 .455 .4718 .45063 Metetra
.846 .808 .813 r
.4718 .45063 .47696 .455 .48603 .45778 .48105 .44068 Metetra
.179 .232 .681 r
.48105 .44068 .48603 .45778 .4952 .45622 .49007 .45215 Metetra
.868 .817 .797 r
.49007 .45215 .4952 .45622 .50436 .46288 .49938 .4408 Metetra
.667 .517 .672 r
.49938 .4408 .50436 .46288 .51364 .45979 .50865 .43296 Metetra
.846 .577 .036 r
.50865 .43296 .51364 .45979 .52295 .44769 .51778 .49529 Metetra
.773 .486 .501 r
.51778 .49529 .52295 .44769 .5323 .46341 .52731 .55467 Metetra
.579 .333 .507 r
.52731 .55467 .5323 .46341 .54189 .49683 .53705 .56429 Metetra
.604 .345 .498 r
.53705 .56429 .54189 .49683 .55175 .5344 .54692 .57772 Metetra
.616 .338 .474 r
.54692 .57772 .55175 .5344 .56182 .56679 .55691 .58916 Metetra
.473 .169 .368 r
.55691 .58916 .56182 .56679 .57172 .56981 .56684 .58622 Metetra
.42 .088 .294 r
.56684 .58622 .57172 .56981 .58166 .57052 .57679 .58244 Metetra
.373 .003 .201 r
.57679 .58244 .58166 .57052 .5916 .56858 .58677 .5789 Metetra
.25 0 .106 r
.58677 .5789 .5916 .56858 .60134 .55577 .59675 .57339 Metetra
.399 .078 .302 r
.59675 .57339 .60134 .55577 .61075 .53097 .60676 .5683 Metetra
.07 0 .308 r
.60676 .5683 .61075 .53097 .61884 .46337 .61604 .53564 Metetra
0 0 .326 r
.61604 .53564 .61884 .46337 .62709 .412 .62393 .46128 Metetra
0 0 .18 r
.62393 .46128 .62709 .412 .63692 .41369 .6316 .3926 Metetra
.285 .276 .673 r
.6316 .3926 .63692 .41369 .64653 .40804 .64185 .40479 Metetra
.599 .837 .989 r
.64185 .40479 .64653 .40804 .65645 .40928 .65164 .40221 Metetra
.484 .621 .91 r
.65164 .40221 .65645 .40928 .66595 .39971 .6616 .4029 Metetra
.576 .89 .616 r
.6616 .4029 .66595 .39971 .67575 .39654 .67119 .39405 Metetra
.558 .86 .997 r
.67119 .39405 .67575 .39654 .68539 .38955 .68109 .39153 Metetra
.312 .776 .648 r
.68109 .39153 .68539 .38955 .69533 .38797 .69092 .38686 Metetra
.803 .973 .905 r
.69092 .38686 .69533 .38797 .70494 .37976 .70062 .37934 Metetra
.831 .99 .864 r
.70062 .37934 .70494 .37976 .71498 .37866 .71025 .37053 Metetra
.568 .631 .874 r
.71025 .37053 .71498 .37866 .72507 .37772 .72037 .36975 Metetra
.586 .645 .876 r
.72037 .36975 .72507 .37772 .73499 .37327 .73051 .3685 Metetra
.717 .813 .925 r
.73051 .3685 .73499 .37327 .74491 .36852 .74047 .36381 Metetra
.65 .795 .952 r
.74047 .36381 .74491 .36852 .75484 .36343 .75057 .36066 Metetra
.884 .913 .841 r
.75057 .36066 .75484 .36343 .76491 .35993 .76016 .3502 Metetra
.592 .605 .834 r
.76016 .3502 .76491 .35993 .77491 .35517 .77044 .34888 Metetra
.591 .706 .923 r
.77044 .34888 .77491 .35517 .78488 .34969 .78075 .34723 Metetra
.785 .935 .929 r
.78075 .34723 .78488 .34969 .79516 .34749 .79069 .34048 Metetra
.405 .583 .913 r
.79069 .34048 .79516 .34749 .80511 .34117 .8014 .34254 Metetra
.714 .971 .735 r
.8014 .34254 .80511 .34117 .8155 .33936 .81116 .33325 Metetra
.421 .627 .939 r
.81116 .33325 .8155 .33936 .8257 .33513 .82191 .33456 Metetra
.54 .923 .912 r
.82191 .33456 .8257 .33513 .836 .33147 .83219 .3302 Metetra
.575 .924 .955 r
.83219 .3302 .836 .33147 .84673 .33182 .84252 .32612 Metetra
.445 .66 .953 r
.84252 .32612 .84673 .33182 .85669 .32422 .85338 .32683 Metetra
.77 .933 .578 r
.85338 .32683 .85669 .32422 .8674 .3234 .86276 .31317 Metetra
.381 .477 .833 r
.86276 .31317 .8674 .3234 .87831 .32382 .87412 .31753 Metetra
.85 .756 .758 r
.26391 .50885 .2695 .51395 .27892 .49853 .27316 .49621 Metetra
.51 .826 1 r
.27316 .49621 .27892 .49853 .28734 .49652 .28156 .49471 Metetra
.815 .89 .897 r
.28156 .49471 .28734 .49652 .29555 .49809 .29038 .48793 Metetra
.656 .608 .789 r
.29038 .48793 .29555 .49809 .30435 .49159 .29897 .48462 Metetra
.635 .673 .87 r
.29897 .48462 .30435 .49159 .31299 .48771 .30751 .48242 Metetra
.631 .731 .92 r
.30751 .48242 .31299 .48771 .3212 .491 .31608 .48024 Metetra
.663 .603 .777 r
.31608 .48024 .3212 .491 .3301 .48371 .32477 .47649 Metetra
.266 .489 .887 r
.32477 .47649 .3301 .48371 .33881 .47989 .33307 .47984 Metetra
.834 .961 .892 r
.33307 .47984 .33881 .47989 .34735 .47967 .34205 .47219 Metetra
.599 .647 .869 r
.34205 .47219 .34735 .47967 .3561 .47617 .3507 .47083 Metetra
.681 .746 .9 r
.3507 .47083 .3561 .47617 .36476 .47487 .35948 .46748 Metetra
.363 .538 .893 r
.35948 .46748 .36476 .47487 .37354 .4718 .36801 .46991 Metetra
.696 .901 .97 r
.36801 .46991 .37354 .4718 .38221 .47198 .37689 .46582 Metetra
.572 .682 .915 r
.37689 .46582 .38221 .47198 .39098 .47084 .38567 .46482 Metetra
.689 .727 .88 r
.38567 .46482 .39098 .47084 .39986 .46777 .39458 .46116 Metetra
.756 .727 .826 r
.39458 .46116 .39986 .46777 .40889 .46126 .40363 .45478 Metetra
.733 .726 .844 r
.40363 .45478 .40889 .46126 .41777 .45946 .41265 .44944 Metetra
.651 .614 .799 r
.41265 .44944 .41777 .45946 .4268 .45406 .42161 .44628 Metetra
0 .124 .669 r
.42161 .44628 .4268 .45406 .43562 .45697 .43026 .45511 Metetra
.87 .894 .848 r
.43026 .45511 .43562 .45697 .44472 .45072 .43949 .44561 Metetra
.691 .765 .908 r
.43949 .44561 .44472 .45072 .45368 .45176 .44857 .44193 Metetra
.284 .42 .824 r
.44857 .44193 .45368 .45176 .46266 .4539 .4575 .44683 Metetra
.735 .714 .831 r
.4575 .44683 .46266 .4539 .4718 .45063 .46669 .44113 Metetra
.675 .637 .805 r
.46669 .44113 .4718 .45063 .48105 .44068 .47587 .43711 Metetra
.575 .031 0 r
.47587 .43711 .48105 .44068 .49007 .45215 .48493 .44536 Metetra
.868 .744 .723 r
.48493 .44536 .49007 .45215 .49938 .4408 .49431 .42925 Metetra
.971 .659 .346 r
.49431 .42925 .49938 .4408 .50865 .43296 .50299 .51395 Metetra
.681 .416 .515 r
.50299 .51395 .50865 .43296 .51778 .49529 .51235 .5576 Metetra
.671 .401 .503 r
.51235 .5576 .51778 .49529 .52731 .55467 .52202 .58849 Metetra
.527 .246 .433 r
.52202 .58849 .52731 .55467 .53705 .56429 .53186 .58797 Metetra
.514 .208 .386 r
.53186 .58797 .53705 .56429 .54692 .57772 .54175 .58738 Metetra
.427 .023 .168 r
.54175 .58738 .54692 .57772 .55691 .58916 .55168 .58629 Metetra
.464 .802 .999 r
.55168 .58629 .55691 .58916 .56684 .58622 .56166 .58507 Metetra
.45 .86 .96 r
.56166 .58507 .56684 .58622 .57679 .58244 .57166 .58269 Metetra
.259 .769 .816 r
.57166 .58269 .57679 .58244 .58677 .5789 .58172 .58053 Metetra
.615 .952 .797 r
.58172 .58053 .58677 .5789 .59675 .57339 .59172 .57363 Metetra
.623 .958 .898 r
.59172 .57363 .59675 .57339 .60676 .5683 .60176 .56811 Metetra
.743 .984 .906 r
.60176 .56811 .60676 .5683 .61604 .53564 .61179 .56117 Metetra
0 0 .038 r
.61179 .56117 .61604 .53564 .62393 .46128 .62091 .52203 Metetra
0 0 .172 r
.62091 .52203 .62393 .46128 .6316 .3926 .62831 .43464 Metetra
.207 .006 .373 r
.62831 .43464 .6316 .3926 .64185 .40479 .63727 .40576 Metetra
.546 .927 .822 r
.63727 .40576 .64185 .40479 .65164 .40221 .647 .40031 Metetra
.805 .941 .916 r
.647 .40031 .65164 .40221 .6616 .4029 .65667 .39315 Metetra
.621 .617 .826 r
.65667 .39315 .6616 .4029 .67119 .39405 .66657 .39092 Metetra
.878 .885 .835 r
.66657 .39092 .67119 .39405 .68109 .39153 .67613 .38046 Metetra
.615 .59 .801 r
.67613 .38046 .68109 .39153 .69092 .38686 .6861 .37832 Metetra
.754 .702 .803 r
.6861 .37832 .69092 .38686 .70062 .37934 .69582 .37096 Metetra
.606 .644 .862 r
.69582 .37096 .70062 .37934 .71025 .37053 .70588 .36918 Metetra
.567 .912 .97 r
.70588 .36918 .71025 .37053 .72037 .36975 .71587 .36561 Metetra
.782 .854 .904 r
.71587 .36561 .72037 .36975 .73051 .3685 .72571 .35907 Metetra
.688 .659 .815 r
.72571 .35907 .73051 .3685 .74047 .36381 .73568 .35435 Metetra
.426 .521 .852 r
.73568 .35435 .74047 .36381 .75057 .36066 .7462 .35711 Metetra
.911 .874 .788 r
.7462 .35711 .75057 .36066 .76016 .3502 .75565 .34407 Metetra
.57 .704 .932 r
.75565 .34407 .76016 .3502 .77044 .34888 .76596 .34279 Metetra
.623 .73 .923 r
.76596 .34279 .77044 .34888 .78075 .34723 .77624 .34038 Metetra
.73 .746 .865 r
.77624 .34038 .78075 .34723 .79069 .34048 .7863 .33484 Metetra
.597 .738 .943 r
.7863 .33484 .79069 .34048 .8014 .34254 .79669 .33287 Metetra
.664 .646 .822 r
.79669 .33287 .8014 .34254 .81116 .33325 .80696 .32901 Metetra
.478 .747 .988 r
.80696 .32901 .81116 .33325 .82191 .33456 .81756 .32838 Metetra
.703 .763 .898 r
.81756 .32838 .82191 .33456 .83219 .3302 .82785 .32383 Metetra
.794 .786 .845 r
.82785 .32383 .83219 .3302 .84252 .32612 .83782 .31587 Metetra
.656 .632 .814 r
.83782 .31587 .84252 .32612 .85338 .32683 .84824 .31215 Metetra
.591 .531 .756 r
.84824 .31215 .85338 .32683 .86276 .31317 .85894 .3107 Metetra
.25 .701 .955 r
.85894 .3107 .86276 .31317 .87412 .31753 .8699 .31119 Metetra
.856 .755 .751 r
.25828 .50373 .26391 .50885 .27316 .49621 .26763 .4903 Metetra
.585 .692 .915 r
.26763 .4903 .27316 .49621 .28156 .49471 .27603 .48909 Metetra
.691 .734 .884 r
.27603 .48909 .28156 .49471 .29038 .48793 .28463 .4855 Metetra
.576 .845 .995 r
.28463 .4855 .29038 .48793 .29897 .48462 .29316 .48336 Metetra
.727 .924 .958 r
.29316 .48336 .29897 .48462 .30751 .48242 .30189 .47867 Metetra
.717 .815 .926 r
.30189 .47867 .30751 .48242 .31608 .48024 .3106 .47456 Metetra
.63 .718 .91 r
.3106 .47456 .31608 .48024 .32477 .47649 .31921 .47241 Metetra
.605 .778 .963 r
.31921 .47241 .32477 .47649 .33307 .47984 .32785 .47045 Metetra
.677 .634 .799 r
.32785 .47045 .33307 .47984 .34205 .47219 .33663 .46644 Metetra
.546 .687 .931 r
.33663 .46644 .34205 .47219 .3507 .47083 .34525 .46578 Metetra
.73 .768 .883 r
.34525 .46578 .3507 .47083 .35948 .46748 .35412 .46106 Metetra
.202 .486 .897 r
.35412 .46106 .35948 .46748 .36801 .46991 .3626 .46454 Metetra
.735 .76 .872 r
.3626 .46454 .36801 .46991 .37689 .46582 .37155 .45954 Metetra
.573 .68 .912 r
.37155 .45954 .37689 .46582 .38567 .46482 .38033 .45851 Metetra
.682 .717 .876 r
.38033 .45851 .38567 .46482 .39458 .46116 .38926 .455 Metetra
.821 .748 .782 r
.38926 .455 .39458 .46116 .40363 .45478 .39848 .44474 Metetra
.389 .477 .829 r
.39848 .44474 .40363 .45478 .41265 .44944 .4072 .44798 Metetra
.778 .929 .933 r
.4072 .44798 .41265 .44944 .42161 .44628 .41629 .44202 Metetra
0 .334 .775 r
.41629 .44202 .42161 .44628 .43026 .45511 .42507 .44669 Metetra
.72 .676 .807 r
.42507 .44669 .43026 .45511 .43949 .44561 .4342 .44112 Metetra
.66 .784 .94 r
.4342 .44112 .43949 .44561 .44857 .44193 .44329 .4381 Metetra
.351 .691 .981 r
.44329 .4381 .44857 .44193 .4575 .44683 .45232 .43873 Metetra
.693 .676 .829 r
.45232 .43873 .4575 .44683 .46669 .44113 .46151 .43438 Metetra
.742 .727 .837 r
.46151 .43438 .46669 .44113 .47587 .43711 .47074 .42851 Metetra
.562 .608 .856 r
.47074 .42851 .47587 .43711 .48493 .44536 .47991 .42798 Metetra
.951 .636 .207 r
.47991 .42798 .48493 .44536 .49431 .42925 .48846 .48774 Metetra
.763 .482 .509 r
.48846 .48774 .49431 .42925 .50299 .51395 .49735 .55422 Metetra
.717 .427 .485 r
.49735 .55422 .50299 .51395 .51235 .5576 .50685 .58602 Metetra
.546 .25 .417 r
.50685 .58602 .51235 .5576 .52202 .58849 .51666 .5876 Metetra
.188 .711 .868 r
.51666 .5876 .52202 .58849 .53186 .58797 .52654 .58708 Metetra
.155 .688 .853 r
.52654 .58708 .53186 .58797 .54175 .58738 .53646 .58679 Metetra
.135 .678 .824 r
.53646 .58679 .54175 .58738 .55168 .58629 .54643 .58636 Metetra
.527 .918 .906 r
.54643 .58636 .55168 .58629 .56166 .58507 .55641 .58217 Metetra
.693 .883 .968 r
.55641 .58217 .56166 .58507 .57166 .58269 .56643 .57775 Metetra
.69 .796 .93 r
.56643 .57775 .57166 .58269 .58172 .58053 .57648 .57371 Metetra
.584 .689 .913 r
.57648 .57371 .58172 .58053 .59172 .57363 .5866 .57227 Metetra
.767 .956 .934 r
.5866 .57227 .59172 .57363 .60176 .56811 .59666 .56564 Metetra
.79 .917 .924 r
.59666 .56564 .60176 .56811 .61179 .56117 .60673 .55875 Metetra
.942 .864 .734 r
.60673 .55875 .61179 .56117 .62091 .52203 .61652 .54111 Metetra
.61652 .54111 .62091 .52203 .62831 .43464 .62574 .50619 Metetra
0 0 .098 r
.62574 .50619 .62831 .43464 .63727 .40576 .63196 .38632 Metetra
.307 .304 .692 r
.63196 .38632 .63727 .40576 .647 .40031 .64225 .39668 Metetra
.83 .87 .874 r
.64225 .39668 .647 .40031 .65667 .39315 .65192 .38847 Metetra
.812 .829 .863 r
.65192 .38847 .65667 .39315 .66657 .39092 .66161 .38055 Metetra
.649 .62 .807 r
.66161 .38055 .66657 .39092 .67613 .38046 .67151 .37719 Metetra
.689 .87 .967 r
.67151 .37719 .67613 .38046 .6861 .37832 .68141 .37299 Metetra
.663 .772 .931 r
.68141 .37299 .6861 .37832 .69582 .37096 .69138 .36967 Metetra
.842 .968 .882 r
.69138 .36967 .69582 .37096 .70588 .36918 .70109 .36099 Metetra
.636 .665 .861 r
.70109 .36099 .70588 .36918 .71587 .36561 .71115 .35832 Metetra
.804 .751 .804 r
.71115 .35832 .71587 .36561 .72571 .35907 .72085 .34906 Metetra
.382 .483 .838 r
.72085 .34906 .72571 .35907 .73568 .35435 .7314 .35292 Metetra
.451 .858 .964 r
.7314 .35292 .73568 .35435 .7462 .35711 .7416 .35055 Metetra
.786 .771 .84 r
.7416 .35055 .7462 .35711 .75565 .34407 .75147 .34284 Metetra
.505 .891 .958 r
.75147 .34284 .75565 .34407 .76596 .34279 .76168 .3397 Metetra
.742 .901 .949 r
.76168 .3397 .76596 .34279 .77624 .34038 .77175 .33415 Metetra
.394 .61 .936 r
.77175 .33415 .77624 .34038 .7863 .33484 .78243 .33585 Metetra
.747 .986 .769 r
.78243 .33585 .7863 .33484 .79669 .33287 .79225 .32655 Metetra
.412 .618 .936 r
.79225 .32655 .79669 .33287 .80696 .32901 .80302 .32803 Metetra
.853 .987 .85 r
.80302 .32803 .80696 .32901 .81756 .32838 .81284 .31834 Metetra
.722 .668 .796 r
.81284 .31834 .81756 .32838 .82785 .32383 .82295 .31179 Metetra
.513 .522 .803 r
.82295 .31179 .82785 .32383 .83782 .31587 .83385 .3131 Metetra
.823 .936 .903 r
.83385 .3131 .83782 .31587 .84824 .31215 .84387 .30511 Metetra
.686 .73 .884 r
.84387 .30511 .84824 .31215 .85894 .3107 .85431 .30093 Metetra
.387 .494 .846 r
.85431 .30093 .85894 .3107 .8699 .31119 .86565 .3048 Metetra
.879 .746 .711 r
.25263 .49857 .25828 .50373 .26763 .4903 .26239 .48025 Metetra
.538 .554 .819 r
.26239 .48025 .26763 .4903 .27603 .48909 .27068 .48049 Metetra
.477 .559 .86 r
.27068 .48049 .27603 .48909 .28463 .4855 .27894 .48166 Metetra
.793 .811 .866 r
.27894 .48166 .28463 .4855 .29316 .48336 .28781 .475 Metetra
.452 .553 .868 r
.28781 .475 .29316 .48336 .30189 .47867 .29612 .47651 Metetra
.558 .853 .997 r
.29612 .47651 .30189 .47867 .3106 .47456 .30473 .47439 Metetra
.704 .959 .946 r
.30473 .47439 .3106 .47456 .31921 .47241 .31355 .46943 Metetra
.767 .853 .915 r
.31355 .46943 .31921 .47241 .32785 .47045 .32241 .46399 Metetra
.662 .703 .878 r
.32241 .46399 .32785 .47045 .33663 .46644 .33115 .46105 Metetra
.553 .706 .941 r
.33115 .46105 .33663 .46644 .34525 .46578 .33979 .46017 Metetra
.728 .749 .869 r
.33979 .46017 .34525 .46578 .35412 .46106 .34869 .45537 Metetra
.091 .45 .883 r
.34869 .45537 .35412 .46106 .3626 .46454 .35716 .4592 Metetra
.738 .762 .872 r
.35716 .4592 .3626 .46454 .37155 .45954 .36613 .4541 Metetra
.596 .721 .932 r
.36613 .4541 .37155 .45954 .38033 .45851 .37496 .45249 Metetra
.774 .748 .829 r
.37496 .45249 .38033 .45851 .38926 .455 .38405 .44551 Metetra
.61 .606 .823 r
.38405 .44551 .38926 .455 .39848 .44474 .39294 .44379 Metetra
.601 .919 .974 r
.39294 .44379 .39848 .44474 .4072 .44798 .40193 .44033 Metetra
.376 .54 .89 r
.40193 .44033 .4072 .44798 .41629 .44202 .41075 .44271 Metetra
.729 .986 .896 r
.41075 .44271 .41629 .44202 .42507 .44669 .41991 .43637 Metetra
.478 .522 .825 r
.41991 .43637 .42507 .44669 .4342 .44112 .42884 .43802 Metetra
.777 .863 .913 r
.42884 .43802 .4342 .44112 .44329 .4381 .43803 .43211 Metetra
.293 .559 .928 r
.43803 .43211 .44329 .4381 .45232 .43873 .44703 .43458 Metetra
.367 .685 .979 r
.44703 .43458 .45232 .43873 .46151 .43438 .45613 .43524 Metetra
.618 .958 .878 r
.45613 .43524 .46151 .43438 .47074 .42851 .4654 .42992 Metetra
.728 .233 .064 r
.4654 .42992 .47074 .42851 .47991 .42798 .47446 .43861 Metetra
.923 .62 .453 r
.47446 .43861 .47991 .42798 .48846 .48774 .4824 .54437 Metetra
.702 .425 .501 r
.4824 .54437 .48846 .48774 .49735 .55422 .49165 .58248 Metetra
.556 .259 .418 r
.49165 .58248 .49735 .55422 .50685 .58602 .50142 .58511 Metetra
.004 .575 .775 r
.50142 .58511 .50685 .58602 .51666 .5876 .51126 .58589 Metetra
.131 .652 .884 r
.51126 .58589 .51666 .5876 .52654 .58708 .52116 .58648 Metetra
.465 .879 .938 r
.52116 .58648 .52654 .58708 .53646 .58679 .53111 .58353 Metetra
.645 .854 .98 r
.53111 .58353 .53646 .58679 .54643 .58636 .54109 .58011 Metetra
.605 .717 .924 r
.54109 .58011 .54643 .58636 .55641 .58217 .55112 .57814 Metetra
.612 .812 .977 r
.55112 .57814 .55641 .58217 .56643 .57775 .56118 .57551 Metetra
.688 .91 .972 r
.56118 .57551 .56643 .57775 .57648 .57371 .57126 .57088 Metetra
.736 .896 .952 r
.57126 .57088 .57648 .57371 .5866 .57227 .58135 .56548 Metetra
.561 .682 .92 r
.58135 .56548 .5866 .57227 .59666 .56564 .59155 .56447 Metetra
.822 .963 .9 r
.59155 .56447 .59666 .56564 .60673 .55875 .60163 .55626 Metetra
.818 .917 .904 r
.60163 .55626 .60673 .55875 .61652 .54111 .61173 .54843 Metetra
.985 .859 .487 r
.61173 .54843 .61652 .54111 .62574 .50619 .62097 .51017 Metetra
.99 .745 .464 r
.62097 .51017 .62574 .50619 .63196 .38632 .62796 .40725 Metetra
.271 0 .293 r
.62796 .40725 .63196 .38632 .64225 .39668 .63756 .3957 Metetra
.906 .951 .818 r
.63756 .3957 .64225 .39668 .65192 .38847 .64715 .38412 Metetra
.803 .842 .881 r
.64715 .38412 .65192 .38847 .66161 .38055 .6569 .37675 Metetra
.634 .829 .976 r
.6569 .37675 .66161 .38055 .67151 .37719 .66685 .3737 Metetra
.731 .871 .947 r
.66685 .3737 .67151 .37719 .68141 .37299 .67674 .36862 Metetra
.797 .845 .887 r
.67674 .36862 .68141 .37299 .69138 .36967 .68654 .36145 Metetra
.612 .654 .867 r
.68654 .36145 .69138 .36967 .70109 .36099 .69664 .35944 Metetra
.857 .959 .872 r
.69664 .35944 .70109 .36099 .71115 .35832 .70637 .35027 Metetra
.631 .668 .868 r
.70637 .35027 .71115 .35832 .72085 .34906 .7165 .34773 Metetra
.293 .77 .927 r
.7165 .34773 .72085 .34906 .7314 .35292 .72677 .34672 Metetra
.615 .723 .923 r
.72677 .34672 .7314 .35292 .7416 .35055 .73701 .34448 Metetra
.801 .791 .843 r
.73701 .34448 .7416 .35055 .75147 .34284 .74687 .3363 Metetra
.643 .724 .907 r
.74687 .3363 .75147 .34284 .76168 .3397 .75713 .33341 Metetra
.736 .768 .879 r
.75713 .33341 .76168 .3397 .77175 .33415 .76723 .32782 Metetra
.635 .73 .916 r
.76723 .32782 .77175 .33415 .78243 .33585 .77757 .32508 Metetra
.514 .546 .826 r
.77757 .32508 .78243 .33585 .79225 .32655 .78827 .32604 Metetra
.903 .982 .787 r
.78827 .32604 .79225 .32655 .80302 .32803 .79789 .31386 Metetra
.52 .495 .77 r
.79789 .31386 .80302 .32803 .81284 .31834 .80872 .31526 Metetra
.812 .92 .909 r
.80872 .31526 .81284 .31834 .82295 .31179 .81878 .30766 Metetra
.669 .84 .965 r
.81878 .30766 .82295 .31179 .83385 .3131 .8292 .30378 Metetra
.363 .492 .855 r
.8292 .30378 .83385 .3131 .84387 .30511 .84046 .30782 Metetra
.493 .838 .564 r
.84046 .30782 .84387 .30511 .85431 .30093 .85049 .29911 Metetra
.301 .763 .948 r
.85049 .29911 .85431 .30093 .86565 .3048 .86138 .29838 Metetra
.855 .755 .752 r
.24693 .49338 .25263 .49857 .26239 .48025 .25634 .48004 Metetra
.3 .79 .885 r
.25634 .48004 .26239 .48025 .27068 .48049 .26478 .47856 Metetra
.821 .884 .889 r
.26478 .47856 .27068 .48049 .27894 .48166 .27369 .47143 Metetra
.659 .61 .789 r
.27369 .47143 .27894 .48166 .28781 .475 .28234 .46798 Metetra
.546 .641 .895 r
.28234 .46798 .28781 .475 .29612 .47651 .29079 .46757 Metetra
.463 .545 .854 r
.29079 .46757 .29612 .47651 .30473 .47439 .29916 .46903 Metetra
.611 .727 .928 r
.29916 .46903 .30473 .47439 .31355 .46943 .30779 .46719 Metetra
.838 .872 .868 r
.30779 .46719 .31355 .46943 .32241 .46399 .31685 .45914 Metetra
.042 .459 .879 r
.31685 .45914 .32241 .46399 .33115 .46105 .32521 .4626 Metetra
.804 .997 .859 r
.32521 .4626 .33115 .46105 .33979 .46017 .3343 .45462 Metetra
.733 .754 .869 r
.3343 .45462 .33979 .46017 .34869 .45537 .34322 .44965 Metetra
.121 .47 .893 r
.34322 .44965 .34869 .45537 .35716 .4592 .35171 .45324 Metetra
.738 .743 .856 r
.35171 .45324 .35716 .4592 .36613 .4541 .36071 .44793 Metetra
.725 .734 .858 r
.36071 .44793 .36613 .4541 .37496 .45249 .36971 .44301 Metetra
.656 .628 .81 r
.36971 .44301 .37496 .45249 .38405 .44551 .37866 .43972 Metetra
.686 .739 .891 r
.37866 .43972 .38405 .44551 .39294 .44379 .38764 .43611 Metetra
.318 .508 .886 r
.38764 .43611 .39294 .44379 .40193 .44033 .39639 .43917 Metetra
.788 .94 .927 r
.39639 .43917 .40193 .44033 .41075 .44271 .40554 .43282 Metetra
.584 .588 .822 r
.40554 .43282 .41075 .44271 .41991 .43637 .41453 .43178 Metetra
.514 .732 .973 r
.41453 .43178 .41991 .43637 .42884 .43802 .42355 .43108 Metetra
.407 .584 .913 r
.42355 .43108 .42884 .43802 .43803 .43211 .43255 .43271 Metetra
.764 .99 .89 r
.43255 .43271 .43803 .43211 .44703 .43458 .44182 .42572 Metetra
.12 .35 .815 r
.44182 .42572 .44703 .43458 .45613 .43524 .4508 .4319 Metetra
.883 .837 .796 r
.4508 .4319 .45613 .43524 .4654 .42992 .46022 .41993 Metetra
.956 .614 .25 r
.46022 .41993 .4654 .42992 .47446 .43861 .46863 .46632 Metetra
.861 .563 .481 r
.46863 .46632 .47446 .43861 .4824 .54437 .47682 .5502 Metetra
.861 .496 .358 r
.47682 .5502 .4824 .54437 .49165 .58248 .48618 .57834 Metetra
.124 .554 .92 r
.48618 .57834 .49165 .58248 .50142 .58511 .49596 .58098 Metetra
.262 .64 .964 r
.49596 .58098 .50142 .58511 .51126 .58589 .50582 .58247 Metetra
.683 .856 .965 r
.50582 .58247 .51126 .58589 .52116 .58648 .51575 .57843 Metetra
.546 .633 .888 r
.51575 .57843 .52116 .58648 .53111 .58353 .52572 .57801 Metetra
.421 .665 .962 r
.52572 .57801 .53111 .58353 .54109 .58011 .53574 .57871 Metetra
.596 .914 .977 r
.53574 .57871 .54109 .58011 .55112 .57814 .54579 .57496 Metetra
.649 .862 .98 r
.54579 .57496 .55112 .57814 .56118 .57551 .55588 .57137 Metetra
.637 .817 .969 r
.55588 .57137 .56118 .57551 .57126 .57088 .566 .5683 Metetra
.772 .911 .934 r
.566 .5683 .57126 .57088 .58135 .56548 .57611 .56191 Metetra
.614 .836 .985 r
.57611 .56191 .58135 .56548 .59155 .56447 .58631 .55901 Metetra
.768 .799 .878 r
.58631 .55901 .59155 .56447 .60163 .55626 .59646 .55235 Metetra
.806 .862 .89 r
.59646 .55235 .60163 .55626 .61173 .54843 .6066 .54471 Metetra
.958 .8 .642 r
.6066 .54471 .61173 .54843 .62097 .51017 .61618 .51612 Metetra
.996 .767 .464 r
.61618 .51612 .62097 .51017 .62796 .40725 .624 .43359 Metetra
0 0 .075 r
.624 .43359 .62796 .40725 .63756 .3957 .63284 .39493 Metetra
.947 .925 .752 r
.63284 .39493 .63756 .3957 .64715 .38412 .64235 .37968 Metetra
.824 .841 .862 r
.64235 .37968 .64715 .38412 .6569 .37675 .65209 .37133 Metetra
.5 .702 .96 r
.65209 .37133 .6569 .37675 .66685 .3737 .66218 .37098 Metetra
.826 .914 .897 r
.66218 .37098 .66685 .3737 .67674 .36862 .67197 .36306 Metetra
.752 .792 .886 r
.67197 .36306 .67674 .36862 .68654 .36145 .68188 .35715 Metetra
.725 .837 .934 r
.68188 .35715 .68654 .36145 .69664 .35944 .69185 .35223 Metetra
.791 .751 .816 r
.69185 .35223 .69664 .35944 .70637 .35027 .70165 .34375 Metetra
.555 .685 .925 r
.70165 .34375 .70637 .35027 .7165 .34773 .7119 .3428 Metetra
.756 .822 .904 r
.7119 .3428 .7165 .34773 .72677 .34672 .72189 .3369 Metetra
.522 .571 .846 r
.72189 .3369 .72677 .34672 .73701 .34448 .73232 .3374 Metetra
.781 .757 .831 r
.73232 .3374 .73701 .34448 .74687 .3363 .74224 .32957 Metetra
.627 .712 .907 r
.74224 .32957 .74687 .3363 .75713 .33341 .75255 .32706 Metetra
.729 .765 .882 r
.75255 .32706 .75713 .33341 .76723 .32782 .76269 .32166 Metetra
.589 .717 .933 r
.76269 .32166 .76723 .32782 .77757 .32508 .77314 .3199 Metetra
.6 .764 .958 r
.77314 .3199 .77757 .32508 .78827 .32604 .7836 .31768 Metetra
.808 .736 .784 r
.7836 .31768 .78827 .32604 .79789 .31386 .79342 .3074 Metetra
.588 .707 .925 r
.79342 .3074 .79789 .31386 .80872 .31526 .80399 .30568 Metetra
.351 .479 .849 r
.80399 .30568 .80872 .31526 .81878 .30766 .81517 .31001 Metetra
.503 .86 .615 r
.81517 .31001 .81878 .30766 .8292 .30378 .82526 .30195 Metetra
.857 .97 .867 r
.82526 .30195 .8292 .30378 .84046 .30782 .83521 .29243 Metetra
.581 .519 .751 r
.83521 .29243 .84046 .30782 .85049 .29911 .84602 .29129 Metetra
.494 .614 .9 r
.84602 .29129 .85049 .29911 .86138 .29838 .85707 .29191 Metetra
.858 .754 .747 r
.24121 .48816 .24693 .49338 .25634 .48004 .2507 .47423 Metetra
.563 .691 .927 r
.2507 .47423 .25634 .48004 .26478 .47856 .25911 .47329 Metetra
.694 .751 .895 r
.25911 .47329 .26478 .47856 .27369 .47143 .26777 .46963 Metetra
.761 .902 .939 r
.26777 .46963 .27369 .47143 .28234 .46798 .27658 .46435 Metetra
.227 .634 .957 r
.27658 .46435 .28234 .46798 .29079 .46757 .28492 .46566 Metetra
.823 .89 .89 r
.28492 .46566 .29079 .46757 .29916 .46903 .29392 .45843 Metetra
.63 .593 .793 r
.29392 .45843 .29916 .46903 .30779 .46719 .30259 .45595 Metetra
.598 .567 .79 r
.30259 .45595 .30779 .46719 .31685 .45914 .31123 .45449 Metetra
.603 .757 .952 r
.31123 .45449 .31685 .45914 .32521 .4626 .31994 .45262 Metetra
.662 .62 .796 r
.31994 .45262 .32521 .4626 .3343 .45462 .32878 .44902 Metetra
.743 .754 .862 r
.32878 .44902 .3343 .45462 .34322 .44965 .33774 .44364 Metetra
.073 .427 .871 r
.33774 .44364 .34322 .44965 .35171 .45324 .34621 .44777 Metetra
.743 .761 .867 r
.34621 .44777 .35171 .45324 .36071 .44793 .35523 .44242 Metetra
.728 .758 .876 r
.35523 .44242 .36071 .44793 .36971 .44301 .36425 .43758 Metetra
.59 .723 .936 r
.36425 .43758 .36971 .44301 .37866 .43972 .37313 .43603 Metetra
.593 .801 .979 r
.37313 .43603 .37866 .43972 .38764 .43611 .38207 .43398 Metetra
.383 .786 .984 r
.38207 .43398 .38764 .43611 .39639 .43917 .39099 .4332 Metetra
.263 .546 .925 r
.39099 .4332 .39639 .43917 .40554 .43282 .39982 .43582 Metetra
.748 .985 .761 r
.39982 .43582 .40554 .43282 .41453 .43178 .40913 .42684 Metetra
.742 .786 .888 r
.40913 .42684 .41453 .43178 .42355 .43108 .41832 .42166 Metetra
.512 .564 .845 r
.41832 .42166 .42355 .43108 .43255 .43271 .42734 .42231 Metetra
.547 .561 .82 r
.42734 .42231 .43255 .43271 .44182 .42572 .43644 .42229 Metetra
.388 .733 .991 r
.43644 .42229 .44182 .42572 .4508 .4319 .44558 .42227 Metetra
.819 .691 .723 r
.44558 .42227 .4508 .4319 .46022 .41993 .45507 .40831 Metetra
.971 .663 .362 r
.45507 .40831 .46022 .41993 .46863 .46632 .46262 .49612 Metetra
.829 .529 .481 r
.46262 .49612 .46863 .46632 .47682 .5502 .47111 .55999 Metetra
.75 .374 .341 r
.47111 .55999 .47682 .5502 .48618 .57834 .48065 .57478 Metetra
.027 .513 .877 r
.48065 .57478 .48618 .57834 .49596 .58098 .49045 .57767 Metetra
.51 .805 .999 r
.49045 .57767 .49596 .58098 .50582 .58247 .50035 .57615 Metetra
.577 .704 .929 r
.50035 .57615 .50582 .58247 .51575 .57843 .5103 .57474 Metetra
.343 .708 .984 r
.5103 .57474 .51575 .57843 .52572 .57801 .52029 .57516 Metetra
.536 .838 .999 r
.52029 .57516 .52572 .57801 .53574 .57871 .53033 .57303 Metetra
.588 .736 .945 r
.53033 .57303 .53574 .57871 .54579 .57496 .54042 .57122 Metetra
.679 .847 .963 r
.54042 .57122 .54579 .57496 .55588 .57137 .55053 .56722 Metetra
.679 .83 .956 r
.55053 .56722 .55588 .57137 .566 .5683 .56068 .56328 Metetra
.72 .805 .918 r
.56068 .56328 .566 .5683 .57611 .56191 .57084 .55834 Metetra
.722 .866 .949 r
.57084 .55834 .57611 .56191 .58631 .55901 .58103 .55332 Metetra
.704 .778 .909 r
.58103 .55332 .58631 .55901 .59646 .55235 .59125 .54877 Metetra
.822 .876 .884 r
.59125 .54877 .59646 .55235 .6066 .54471 .60142 .54053 Metetra
.936 .816 .701 r
.60142 .54053 .6066 .54471 .61618 .51612 .61127 .51969 Metetra
.996 .781 .494 r
.61127 .51969 .61618 .51612 .624 .43359 .61979 .45542 Metetra
.949 .774 .315 r
.61979 .45542 .624 .43359 .63284 .39493 .62747 .37574 Metetra
.543 .46 .711 r
.62747 .37574 .63284 .39493 .64235 .37968 .63754 .37644 Metetra
.879 .883 .833 r
.63754 .37644 .64235 .37968 .65209 .37133 .64724 .36575 Metetra
.72 .782 .902 r
.64724 .36575 .65209 .37133 .66218 .37098 .65716 .36086 Metetra
.711 .657 .794 r
.65716 .36086 .66218 .37098 .67197 .36306 .66706 .35485 Metetra
.699 .694 .842 r
.66706 .35485 .67197 .36306 .68188 .35715 .67704 .35005 Metetra
.661 .711 .885 r
.67704 .35005 .68188 .35715 .69185 .35223 .68712 .34668 Metetra
.497 .698 .958 r
.68712 .34668 .69185 .35223 .70165 .34375 .6974 .34637 Metetra
.642 .929 .663 r
.6974 .34637 .70165 .34375 .7119 .3428 .70721 .33699 Metetra
.759 .79 .879 r
.70721 .33699 .7119 .3428 .72189 .3369 .71721 .33072 Metetra
.462 .654 .943 r
.71721 .33072 .72189 .3369 .73232 .3374 .72766 .33124 Metetra
.853 .798 .796 r
.72766 .33124 .73232 .3374 .74224 .32957 .73738 .31988 Metetra
.505 .566 .851 r
.73738 .31988 .74224 .32957 .75255 .32706 .74795 .32075 Metetra
.615 .724 .924 r
.74795 .32075 .75255 .32706 .76269 .32166 .75834 .31844 Metetra
.792 .908 .921 r
.75834 .31844 .76269 .32166 .77314 .3199 .76843 .31151 Metetra
.686 .69 .849 r
.76843 .31151 .77314 .3199 .7836 .31768 .77873 .30707 Metetra
.653 .626 .81 r
.77873 .30707 .7836 .31768 .79342 .3074 .78913 .30337 Metetra
.472 .76 .993 r
.78913 .30337 .79342 .3074 .80399 .30568 .79981 .30258 Metetra
.805 .921 .915 r
.79981 .30258 .80399 .30568 .81517 .31001 .80995 .29516 Metetra
.579 .524 .758 r
.80995 .29516 .81517 .31001 .82526 .30195 .82071 .2941 Metetra
.777 .744 .823 r
.82071 .2941 .82526 .30195 .83521 .29243 .83084 .28608 Metetra
.704 .765 .9 r
.83084 .28608 .83521 .29243 .84602 .29129 .84131 .28139 Metetra
.376 .488 .846 r
.84131 .28139 .84602 .29129 .85707 .29191 .85274 .28539 Metetra
.629 .5 .687 r
.23674 .46819 .24121 .48816 .2507 .47423 .24539 .46402 Metetra
.527 .547 .82 r
.24539 .46402 .2507 .47423 .25911 .47329 .25369 .46446 Metetra
.684 .649 .809 r
.25369 .46446 .25911 .47329 .26777 .46963 .2624 .46033 Metetra
.025 .275 .773 r
.2624 .46033 .26777 .46963 .27658 .46435 .2703 .46694 Metetra
.841 .999 .817 r
.2703 .46694 .27658 .46435 .28492 .46566 .27948 .45744 Metetra
.707 .672 .813 r
.27948 .45744 .28492 .46566 .29392 .45843 .28832 .45255 Metetra
.699 .734 .878 r
.28832 .45255 .29392 .45843 .30259 .45595 .29711 .4486 Metetra
.605 .154 0 r
.29711 .4486 .30259 .45595 .31123 .45449 .30492 .45961 Metetra
.833 .98 .69 r
.30492 .45961 .31123 .45449 .31994 .45262 .31435 .44723 Metetra
.693 .753 .898 r
.31435 .44723 .31994 .45262 .32878 .44902 .32321 .44351 Metetra
.752 .76 .86 r
.32321 .44351 .32878 .44902 .33774 .44364 .33222 .43783 Metetra
.017 .401 .853 r
.33222 .43783 .33774 .44364 .34621 .44777 .34067 .44219 Metetra
.751 .76 .86 r
.34067 .44219 .34621 .44777 .35523 .44242 .34974 .4365 Metetra
.558 .692 .93 r
.34974 .4365 .35523 .44242 .36425 .43758 .35857 .43557 Metetra
.493 .842 .996 r
.35857 .43557 .36425 .43758 .37313 .43603 .36749 .4338 Metetra
.565 .86 .997 r
.36749 .4338 .37313 .43603 .38207 .43398 .37647 .43144 Metetra
.859 .868 .846 r
.37647 .43144 .38207 .43398 .39099 .4332 .38578 .42209 Metetra
.545 .545 .805 r
.38578 .42209 .39099 .4332 .39982 .43582 .39471 .42216 Metetra
.603 .54 .756 r
.39471 .42216 .39982 .43582 .40913 .42684 .40376 .42028 Metetra
.645 .705 .89 r
.40376 .42028 .40913 .42684 .41832 .42166 .41287 .41762 Metetra
0 .444 .849 r
.41287 .41762 .41832 .42166 .42734 .42231 .42182 .42116 Metetra
.781 .946 .93 r
.42182 .42116 .42734 .42231 .43644 .42229 .43113 .41484 Metetra
.507 .62 .898 r
.43113 .41484 .43644 .42229 .44558 .42227 .44027 .41509 Metetra
.892 .736 .681 r
.44027 .41509 .44558 .42227 .45507 .40831 .44999 .39282 Metetra
.976 .679 .386 r
.44999 .39282 .45507 .40831 .46262 .49612 .4566 .51881 Metetra
.825 .513 .462 r
.4566 .51881 .46262 .49612 .47111 .55999 .46535 .56719 Metetra
.543 .1 .147 r
.46535 .56719 .47111 .55999 .48065 .57478 .4751 .57007 Metetra
.009 .453 .868 r
.4751 .57007 .48065 .57478 .49045 .57767 .4849 .57405 Metetra
.739 .858 .936 r
.4849 .57405 .49045 .57767 .50035 .57615 .49486 .56872 Metetra
.327 .542 .908 r
.49486 .56872 .50035 .57615 .5103 .57474 .5048 .57155 Metetra
.644 .86 .981 r
.5048 .57155 .5103 .57474 .52029 .57516 .51483 .56807 Metetra
.397 .594 .924 r
.51483 .56807 .52029 .57516 .53033 .57303 .52489 .5698 Metetra
.614 .85 .988 r
.52489 .5698 .53033 .57303 .54042 .57122 .535 .56677 Metetra
.641 .807 .963 r
.535 .56677 .54042 .57122 .55053 .56722 .54515 .56365 Metetra
.745 .868 .937 r
.54515 .56365 .55053 .56722 .56068 .56328 .55531 .55804 Metetra
.665 .783 .937 r
.55531 .55804 .56068 .56328 .57084 .55834 .56552 .5545 Metetra
.805 .864 .893 r
.56552 .5545 .57084 .55834 .58103 .55332 .5757 .5469 Metetra
.609 .72 .924 r
.5757 .5469 .58103 .55332 .59125 .54877 .586 .54474 Metetra
.836 .859 .862 r
.586 .54474 .59125 .54877 .60142 .54053 .59618 .53565 Metetra
.845 .829 .832 r
.59618 .53565 .60142 .54053 .61127 .51969 .60635 .52546 Metetra
1 .818 .494 r
.60635 .52546 .61127 .51969 .61979 .45542 .6154 .47493 Metetra
.991 .76 .383 r
.6154 .47493 .61979 .45542 .62747 .37574 .6221 .35605 Metetra
.309 .305 .692 r
.6221 .35605 .62747 .37574 .63754 .37644 .63247 .3661 Metetra
.74 .666 .777 r
.63247 .3661 .63754 .37644 .64724 .36575 .64229 .35841 Metetra
.526 .643 .907 r
.64229 .35841 .64724 .36575 .65716 .36086 .65243 .3582 Metetra
.761 .916 .942 r
.65243 .3582 .65716 .36086 .66706 .35485 .66237 .35218 Metetra
.181 .651 .935 r
.66237 .35218 .66706 .35485 .67704 .35005 .67266 .3533 Metetra
.469 .834 .581 r
.67266 .3533 .67704 .35005 .68712 .34668 .68257 .3454 Metetra
.777 .971 .92 r
.68257 .3454 .68712 .34668 .6974 .34637 .69253 .33834 Metetra
.691 .699 .853 r
.69253 .33834 .6974 .34637 .70721 .33699 .70264 .33384 Metetra
.658 .876 .98 r
.70264 .33384 .70721 .33699 .71721 .33072 .71283 .32996 Metetra
.622 .95 .934 r
.71283 .32996 .71721 .33072 .72766 .33124 .72297 .32498 Metetra
.746 .775 .876 r
.72297 .32498 .72766 .33124 .73738 .31988 .73308 .319 Metetra
.604 .942 .939 r
.73308 .319 .73738 .31988 .74795 .32075 .7433 .31429 Metetra
.607 .717 .922 r
.7433 .31429 .74795 .32075 .75834 .31844 .75374 .31215 Metetra
.808 .792 .838 r
.75374 .31215 .75834 .31844 .76843 .31151 .76373 .30353 Metetra
.663 .693 .868 r
.76373 .30353 .76843 .31151 .77873 .30707 .77412 .29991 Metetra
.526 .654 .916 r
.77412 .29991 .77873 .30707 .78913 .30337 .78482 .29959 Metetra
.781 .888 .922 r
.78482 .29959 .78913 .30337 .79981 .30258 .79503 .2929 Metetra
.735 .685 .802 r
.79503 .2929 .79981 .30258 .80995 .29516 .80524 .28592 Metetra
.593 .628 .855 r
.80524 .28592 .80995 .29516 .82071 .2941 .81596 .28432 Metetra
.359 .482 .848 r
.81596 .28432 .82071 .2941 .83084 .28608 .8273 .28852 Metetra
.8273 .28852 .83084 .28608 .84131 .28139 .83796 .28503 Metetra
.676 .87 .482 r
.22965 .47763 .23674 .46819 .24539 .46402 .23922 .46357 Metetra
.239 .749 .873 r
.23922 .46357 .24539 .46402 .25369 .46446 .24766 .4626 Metetra
.675 .895 .976 r
.24766 .4626 .25369 .46446 .2624 .46033 .25636 .4589 Metetra
.758 .918 .944 r
.25636 .4589 .2624 .46033 .2703 .46694 .26521 .45358 Metetra
.508 .486 .767 r
.26521 .45358 .2703 .46694 .27948 .45744 .27357 .45486 Metetra
.819 .864 .881 r
.27357 .45486 .27948 .45744 .28832 .45255 .28262 .44758 Metetra
.641 .755 .932 r
.28262 .44758 .28832 .45255 .29711 .4486 .29133 .44507 Metetra
.547 .791 .989 r
.29133 .44507 .29711 .4486 .30492 .45961 .3 .44358 Metetra
.599 .51 .726 r
.3 .44358 .30492 .45961 .31435 .44723 .30873 .44167 Metetra
.689 .747 .896 r
.30873 .44167 .31435 .44723 .32321 .44351 .31761 .43803 Metetra
.745 .761 .866 r
.31761 .43803 .32321 .44351 .33222 .43783 .32662 .43261 Metetra
0 .405 .849 r
.32662 .43261 .33222 .43783 .34067 .44219 .33509 .43673 Metetra
.744 .763 .869 r
.33509 .43673 .34067 .44219 .34974 .4365 .34416 .43133 Metetra
.731 .773 .886 r
.34416 .43133 .34974 .4365 .35857 .43557 .35322 .42645 Metetra
.602 .615 .837 r
.35322 .42645 .35857 .43557 .36749 .4338 .36213 .42487 Metetra
.62 .627 .836 r
.36213 .42487 .36749 .4338 .37647 .43144 .37111 .42278 Metetra
.571 .613 .855 r
.37111 .42278 .37647 .43144 .38578 .42209 .38006 .42197 Metetra
.353 0 0 r
.38006 .42197 .38578 .42209 .39471 .42216 .38891 .42457 Metetra
.789 .998 .801 r
.38891 .42457 .39471 .42216 .40376 .42028 .39828 .41554 Metetra
.744 .796 .895 r
.39828 .41554 .40376 .42028 .41287 .41762 .40751 .41031 Metetra
.48 .612 .904 r
.40751 .41031 .41287 .41762 .42182 .42116 .41656 .41093 Metetra
.545 .565 .826 r
.41656 .41093 .42182 .42116 .43113 .41484 .42568 .41088 Metetra
.419 .725 .989 r
.42568 .41088 .43113 .41484 .44027 .41509 .43486 .41083 Metetra
.888 .806 .762 r
.43486 .41083 .44027 .41509 .44999 .39282 .44443 .3968 Metetra
.934 .625 .431 r
.44443 .3968 .44999 .39282 .4566 .51881 .45171 .48483 Metetra
.77 .54 0 r
.45171 .48483 .4566 .51881 .46535 .56719 .46001 .54888 Metetra
.033 .132 .637 r
.46001 .54888 .46535 .56719 .4751 .57007 .46953 .56369 Metetra
.265 .547 .926 r
.46953 .56369 .4751 .57007 .4849 .57405 .47936 .56655 Metetra
.59 .672 .897 r
.47936 .56655 .4849 .57405 .49486 .56872 .4893 .565 Metetra
.517 .792 .995 r
.4893 .565 .49486 .56872 .5048 .57155 .49929 .56355 Metetra
.499 .616 .899 r
.49929 .56355 .5048 .57155 .51483 .56807 .50932 .56395 Metetra
.58 .8 .983 r
.50932 .56395 .51483 .56807 .52489 .5698 .51941 .56178 Metetra
.602 .665 .883 r
.51941 .56178 .52489 .5698 .535 .56677 .52954 .55993 Metetra
.683 .732 .888 r
.52954 .55993 .535 .56677 .54515 .56365 .5397 .55589 Metetra
.676 .703 .867 r
.5397 .55589 .54515 .56365 .55531 .55804 .5499 .55191 Metetra
.716 .767 .893 r
.5499 .55191 .55531 .55804 .56552 .5545 .56012 .54692 Metetra
.708 .72 .859 r
.56012 .54692 .56552 .5545 .5757 .5469 .57036 .54185 Metetra
.706 .805 .927 r
.57036 .54185 .5757 .5469 .586 .54474 .58064 .53725 Metetra
.78 .745 .821 r
.58064 .53725 .586 .54474 .59618 .53565 .59088 .52894 Metetra
.908 .771 .698 r
.59088 .52894 .59618 .53565 .60635 .52546 .60083 .50801 Metetra
.917 .678 .561 r
.60083 .50801 .60635 .52546 .6154 .47493 .60958 .4435 Metetra
.885 .634 .553 r
.60958 .4435 .6154 .47493 .6221 .35605 .61754 .36356 Metetra
.457 .012 .102 r
.61754 .36356 .6221 .35605 .63247 .3661 .62764 .36422 Metetra
.889 .932 .84 r
.62764 .36422 .63247 .3661 .64229 .35841 .6374 .35347 Metetra
.723 .811 .919 r
.6374 .35347 .64229 .35841 .65243 .3582 .64738 .34854 Metetra
.716 .67 .804 r
.64738 .34854 .65243 .3582 .66237 .35218 .65734 .34247 Metetra
.688 .657 .814 r
.65734 .34247 .66237 .35218 .67266 .3533 .66737 .33762 Metetra
.625 .54 .738 r
.66737 .33762 .67266 .3533 .68257 .3454 .67749 .33421 Metetra
.556 .563 .816 r
.67749 .33421 .68257 .3454 .69253 .33834 .68781 .33386 Metetra
.845 .853 .849 r
.68781 .33386 .69253 .33834 .70264 .33384 .69769 .32443 Metetra
.724 .681 .808 r
.69769 .32443 .70264 .33384 .71283 .32996 .70775 .3181 Metetra
.531 .538 .807 r
.70775 .3181 .71283 .32996 .72297 .32498 .71825 .31859 Metetra
.851 .793 .794 r
.71825 .31859 .72297 .32498 .73308 .319 .72803 .30716 Metetra
.519 .532 .809 r
.72803 .30716 .73308 .319 .7433 .31429 .73864 .308 Metetra
.614 .728 .927 r
.73864 .308 .7433 .31429 .75374 .31215 .74909 .30565 Metetra
.769 .778 .86 r
.74909 .30565 .75374 .31215 .76373 .30353 .75923 .29866 Metetra
.7 .82 .939 r
.75923 .29866 .76373 .30353 .77412 .29991 .76959 .29417 Metetra
.67 .774 .928 r
.76959 .29417 .77412 .29991 .78482 .29959 .78004 .29042 Metetra
.564 .616 .862 r
.78004 .29042 .78482 .29959 .79503 .2929 .79078 .28959 Metetra
.805 .914 .913 r
.79078 .28959 .79503 .2929 .80524 .28592 .80098 .28211 Metetra
.478 .778 .997 r
.80098 .28211 .80524 .28592 .81596 .28432 .81178 .28101 Metetra
.822 .919 .901 r
.81178 .28101 .81596 .28432 .8273 .28852 .82198 .27293 Metetra
.648 .558 .739 r
.82198 .27293 .8273 .28852 .83796 .28503 .83251 .26819 Metetra
.854 .755 .752 r
.22382 .47231 .22965 .47763 .23922 .46357 .23338 .45885 Metetra
.583 .747 .955 r
.23338 .45885 .23922 .46357 .24766 .4626 .24188 .45731 Metetra
.786 .765 .833 r
.24188 .45731 .24766 .4626 .25636 .4589 .25089 .45009 Metetra
.667 .645 .819 r
.25089 .45009 .25636 .4589 .26521 .45358 .2596 .44656 Metetra
.543 .645 .9 r
.2596 .44656 .26521 .45358 .27357 .45486 .26811 .44609 Metetra
.455 .55 .863 r
.26811 .44609 .27357 .45486 .28262 .44758 .27651 .44751 Metetra
.34 .816 .889 r
.27651 .44751 .28262 .44758 .29133 .44507 .2852 .4456 Metetra
.838 .974 .881 r
.2852 .4456 .29133 .44507 .3 .44358 .29437 .43745 Metetra
.154 .478 .897 r
.29437 .43745 .3 .44358 .30873 .44167 .30275 .44087 Metetra
.844 .933 .886 r
.30275 .44087 .30873 .44167 .31761 .43803 .31195 .4328 Metetra
.737 .77 .879 r
.31195 .4328 .31761 .43803 .32662 .43261 .32096 .42774 Metetra
.022 .449 .871 r
.32096 .42774 .32662 .43261 .33509 .43673 .32948 .43129 Metetra
.744 .766 .87 r
.32948 .43129 .33509 .43673 .34416 .43133 .33857 .42589 Metetra
.733 .765 .878 r
.33857 .42589 .34416 .43133 .35322 .42645 .34765 .42089 Metetra
.675 .748 .906 r
.34765 .42089 .35322 .42645 .36213 .42487 .35667 .41753 Metetra
.679 .692 .856 r
.35667 .41753 .36213 .42487 .37111 .42278 .36574 .41384 Metetra
.356 .495 .86 r
.36574 .41384 .37111 .42278 .38006 .42197 .37452 .41685 Metetra
.773 .785 .863 r
.37452 .41685 .38006 .42197 .38891 .42457 .38377 .41041 Metetra
.581 .522 .754 r
.38377 .41041 .38891 .42457 .39828 .41554 .39282 .40931 Metetra
.547 .682 .927 r
.39282 .40931 .39828 .41554 .40751 .41031 .4019 .40854 Metetra
0 .535 .804 r
.4019 .40854 .40751 .41031 .41656 .41093 .41094 .41012 Metetra
.805 .957 .913 r
.41094 .41012 .41656 .41093 .42568 .41088 .42032 .40303 Metetra
.026 .328 .812 r
.42032 .40303 .42568 .41088 .43486 .41083 .42932 .40918 Metetra
.904 .892 .807 r
.42932 .40918 .43486 .41083 .44443 .3968 .43889 .39709 Metetra
.928 .588 .369 r
.43889 .39709 .44443 .3968 .45171 .48483 .44704 .44368 Metetra
.827 .597 .045 r
.44704 .44368 .45171 .48483 .46001 .54888 .45472 .52803 Metetra
0 0 .357 r
.45472 .52803 .46001 .54888 .46953 .56369 .46395 .55631 Metetra
.335 .551 .912 r
.46395 .55631 .46953 .56369 .47936 .56655 .47379 .5589 Metetra
.428 .592 .911 r
.47379 .5589 .47936 .56655 .4893 .565 .48371 .56034 Metetra
.691 .81 .939 r
.48371 .56034 .4893 .565 .49929 .56355 .49375 .55622 Metetra
.535 .656 .913 r
.49375 .55622 .49929 .56355 .50932 .56395 .50379 .55572 Metetra
.487 .605 .896 r
.50379 .55572 .50932 .56395 .51941 .56178 .51389 .55637 Metetra
.678 .781 .928 r
.51389 .55637 .51941 .56178 .52954 .55993 .52404 .55253 Metetra
.668 .711 .88 r
.52404 .55253 .52954 .55993 .5397 .55589 .53423 .54886 Metetra
.65 .717 .897 r
.53423 .54886 .5397 .55589 .5499 .55191 .54445 .5457 Metetra
.756 .775 .869 r
.54445 .5457 .5499 .55191 .56012 .54692 .55468 .53921 Metetra
.642 .694 .883 r
.55468 .53921 .56012 .54692 .57036 .54185 .56498 .53623 Metetra
.768 .799 .878 r
.56498 .53623 .57036 .54185 .58064 .53725 .57525 .52946 Metetra
.767 .735 .824 r
.57525 .52946 .58064 .53725 .59088 .52894 .58552 .5217 Metetra
.928 .754 .647 r
.58552 .5217 .59088 .52894 .60083 .50801 .59536 .49285 Metetra
.94 .691 .534 r
.59536 .49285 .60083 .50801 .60958 .4435 .60375 .40974 Metetra
.796 .572 .598 r
.60375 .40974 .60958 .4435 .61754 .36356 .61289 .37078 Metetra
.614 .807 .39 r
.61289 .37078 .61754 .36356 .62764 .36422 .62256 .35539 Metetra
.77 .707 .793 r
.62256 .35539 .62764 .36422 .6374 .35347 .63243 .34692 Metetra
.522 .673 .932 r
.63243 .34692 .6374 .35347 .64738 .34854 .6426 .34649 Metetra
.825 .944 .902 r
.6426 .34649 .64738 .34854 .65734 .34247 .65252 .33847 Metetra
.762 .861 .923 r
.65252 .33847 .65734 .34247 .66737 .33762 .66253 .33245 Metetra
.724 .806 .916 r
.66253 .33245 .66737 .33762 .67749 .33421 .67261 .32743 Metetra
.799 .77 .826 r
.67261 .32743 .67749 .33421 .68781 .33386 .68254 .31884 Metetra
.576 .519 .754 r
.68254 .31884 .68781 .33386 .69769 .32443 .69287 .31781 Metetra
.743 .763 .869 r
.69287 .31781 .69769 .32443 .70775 .3181 .70298 .31181 Metetra
.463 .655 .943 r
.70298 .31181 .70775 .3181 .71825 .31859 .71349 .31224 Metetra
.793 .787 .847 r
.71349 .31224 .71825 .31859 .72803 .30716 .72354 .3043 Metetra
.554 .855 .997 r
.72354 .3043 .72803 .30716 .73864 .308 .73395 .30169 Metetra
.731 .773 .887 r
.73395 .30169 .73864 .308 .74909 .30565 .7442 .29619 Metetra
.6 .627 .85 r
.7442 .29619 .74909 .30565 .75923 .29866 .75475 .29435 Metetra
.581 .802 .983 r
.75475 .29435 .75923 .29866 .76959 .29417 .76531 .29204 Metetra
.88 .953 .851 r
.76531 .29204 .76959 .29417 .78004 .29042 .77527 .28163 Metetra
.598 .644 .867 r
.77527 .28163 .78004 .29042 .79078 .28959 .78594 .27983 Metetra
.347 .478 .849 r
.78594 .27983 .79078 .28959 .80098 .28211 .7972 .2841 Metetra
.556 .899 .668 r
.7972 .2841 .80098 .28211 .81178 .28101 .80742 .27592 Metetra
.845 .851 .848 r
.80742 .27592 .81178 .28101 .82198 .27293 .8175 .26628 Metetra
.559 .695 .931 r
.8175 .26628 .82198 .27293 .83251 .26819 .82841 .26505 Metetra
.288 .702 .972 r
.82841 .26505 .83251 .26819 .84398 .27224 .83956 .26559 Metetra
.88 .746 .71 r
.21795 .46697 .22382 .47231 .23338 .45885 .22802 .44826 Metetra
.536 .548 .814 r
.22802 .44826 .23338 .45885 .24188 .45731 .23637 .44842 Metetra
.474 .556 .86 r
.23637 .44842 .24188 .45731 .25089 .45009 .24468 .44952 Metetra
.808 .945 .914 r
.24468 .44952 .25089 .45009 .2596 .44656 .2537 .44272 Metetra
.215 .621 .952 r
.2537 .44272 .2596 .44656 .26811 .44609 .26206 .44416 Metetra
.545 .862 .996 r
.26206 .44416 .26811 .44609 .27651 .44751 .27076 .44194 Metetra
.735 .756 .869 r
.27076 .44194 .27651 .44751 .2852 .4456 .27971 .43686 Metetra
.716 .668 .801 r
.27971 .43686 .2852 .4456 .29437 .43745 .28871 .43129 Metetra
.663 .721 .892 r
.28871 .43129 .29437 .43745 .30275 .44087 .29755 .42824 Metetra
.579 .539 .774 r
.29755 .42824 .30275 .44087 .31195 .4328 .30628 .42726 Metetra
.73 .759 .876 r
.30628 .42726 .31195 .4328 .32096 .42774 .3153 .42234 Metetra
.041 .44 .873 r
.3153 .42234 .32096 .42774 .32948 .43129 .32381 .42612 Metetra
.741 .776 .881 r
.32381 .42612 .32948 .43129 .33857 .42589 .33291 .42089 Metetra
.589 .745 .951 r
.33291 .42089 .33857 .42589 .34765 .42089 .34183 .41918 Metetra
.816 .914 .905 r
.34183 .41918 .34765 .42089 .35667 .41753 .35108 .41205 Metetra
.6 .731 .936 r
.35108 .41205 .35667 .41753 .36574 .41384 .36007 .41023 Metetra
.679 .832 .957 r
.36007 .41023 .36574 .41384 .37452 .41685 .36918 .40665 Metetra
.429 .504 .835 r
.36918 .40665 .37452 .41685 .38377 .41041 .37805 .40896 Metetra
.791 .932 .925 r
.37805 .40896 .38377 .41041 .39282 .40931 .38736 .40248 Metetra
.393 .588 .921 r
.38736 .40248 .39282 .40931 .4019 .40854 .39636 .40405 Metetra
.769 .812 .887 r
.39636 .40405 .4019 .40854 .41094 .41012 .4057 .398 Metetra
.454 .481 .797 r
.4057 .398 .41094 .41012 .42032 .40303 .41476 .4004 Metetra
.23 .685 .951 r
.41476 .4004 .42032 .40303 .42932 .40918 .42394 .40098 Metetra
.717 .69 .823 r
.42394 .40098 .42932 .40918 .43889 .39709 .43335 .39552 Metetra
.693 .15 0 r
.43335 .39552 .43889 .39709 .44704 .44368 .44242 .40419 Metetra
.933 .67 .192 r
.44242 .40419 .44704 .44368 .45472 .52803 .44936 .51082 Metetra
.842 .521 0 r
.44936 .51082 .45472 .52803 .46395 .55631 .45833 .54923 Metetra
.321 .555 .919 r
.45833 .54923 .46395 .55631 .47379 .5589 .46818 .55179 Metetra
.461 .629 .926 r
.46818 .55179 .47379 .5589 .48371 .56034 .47812 .55248 Metetra
.487 .617 .906 r
.47812 .55248 .48371 .56034 .49375 .55622 .48813 .553 Metetra
.615 .852 .988 r
.48813 .553 .49375 .55622 .50379 .55572 .49822 .54992 Metetra
.666 .763 .922 r
.49822 .54992 .50379 .55572 .51389 .55637 .50835 .54638 Metetra
.61 .621 .838 r
.50835 .54638 .51389 .55637 .52404 .55253 .51851 .54429 Metetra
.634 .675 .872 r
.51851 .54429 .52404 .55253 .53423 .54886 .52872 .54153 Metetra
.701 .727 .87 r
.52872 .54153 .53423 .54886 .54445 .5457 .53896 .53677 Metetra
.709 .689 .828 r
.53896 .53677 .54445 .5457 .55468 .53921 .54922 .53122 Metetra
.568 .655 .895 r
.54922 .53122 .55468 .53921 .56498 .53623 .55955 .5301 Metetra
.798 .788 .844 r
.55955 .5301 .56498 .53623 .57525 .52946 .56983 .52171 Metetra
.772 .739 .823 r
.56983 .52171 .57525 .52946 .58552 .5217 .58013 .51371 Metetra
.939 .739 .606 r
.58013 .51371 .58552 .5217 .59536 .49285 .58983 .47497 Metetra
.941 .684 .52 r
.58983 .47497 .59536 .49285 .60375 .40974 .59785 .37101 Metetra
.647 .462 .619 r
.59785 .37101 .60375 .40974 .61289 .37078 .60767 .35927 Metetra
.785 .668 .735 r
.60767 .35927 .61289 .37078 .62256 .35539 .61748 .34749 Metetra
.764 .728 .819 r
.61748 .34749 .62256 .35539 .63243 .34692 .62741 .33995 Metetra
.652 .716 .895 r
.62741 .33995 .63243 .34692 .6426 .34649 .6375 .33678 Metetra
.697 .663 .813 r
.6375 .33678 .6426 .34649 .65252 .33847 .64755 .33155 Metetra
.772 .759 .841 r
.64755 .33155 .65252 .33847 .66253 .33245 .65753 .32421 Metetra
.611 .661 .874 r
.65753 .32421 .66253 .33245 .67261 .32743 .66776 .32208 Metetra
.832 .822 .839 r
.66776 .32208 .67261 .32743 .68254 .31884 .67769 .31273 Metetra
.628 .74 .928 r
.67769 .31273 .68254 .31884 .69287 .31781 .68797 .31007 Metetra
.568 .657 .897 r
.68797 .31007 .69287 .31781 .70298 .31181 .69837 .30893 Metetra
.537 .846 .999 r
.69837 .30893 .70298 .31181 .71349 .31224 .70875 .30657 Metetra
.809 .814 .854 r
.70875 .30657 .71349 .31224 .72354 .3043 .71881 .29822 Metetra
.641 .75 .928 r
.71881 .29822 .72354 .3043 .73395 .30169 .72922 .29519 Metetra
.736 .77 .88 r
.72922 .29519 .73395 .30169 .7442 .29619 .73949 .28945 Metetra
.636 .724 .912 r
.73949 .28945 .7442 .29619 .75475 .29435 .74998 .28657 Metetra
.471 .608 .906 r
.74998 .28657 .75475 .29435 .76531 .29204 .76081 .28743 Metetra
.892 .86 .802 r
.76081 .28743 .76531 .29204 .77527 .28163 .77065 .27505 Metetra
.416 .621 .937 r
.77065 .27505 .77527 .28163 .78594 .27983 .78161 .27634 Metetra
.813 .91 .906 r
.78161 .27634 .78594 .27983 .7972 .2841 .79186 .26856 Metetra
.635 .551 .743 r
.79186 .26856 .7972 .2841 .80742 .27592 .80245 .26454 Metetra
.397 .473 .821 r
.80245 .26454 .80742 .27592 .8175 .26628 .81383 .26849 Metetra
.569 .895 .639 r
.81383 .26849 .8175 .26628 .82841 .26505 .82405 .2596 Metetra
.505 .719 .968 r
.82405 .2596 .82841 .26505 .83956 .26559 .83511 .2589 Metetra
.855 .755 .752 r
.21205 .46159 .21795 .46697 .22802 .44826 .22169 .44801 Metetra
.274 .774 .876 r
.22169 .44801 .22802 .44826 .23637 .44842 .23019 .44667 Metetra
.671 .9 .978 r
.23019 .44667 .23637 .44842 .24468 .44952 .23895 .44294 Metetra
.631 .695 .891 r
.23895 .44294 .24468 .44952 .2537 .44272 .2476 .44067 Metetra
.738 .895 .95 r
.2476 .44067 .2537 .44272 .26206 .44416 .2565 .43581 Metetra
.689 .667 .823 r
.2565 .43581 .26206 .44416 .27076 .44194 .26537 .43155 Metetra
.622 .597 .804 r
.26537 .43155 .27076 .44194 .27971 .43686 .27411 .42926 Metetra
.622 .663 .868 r
.27411 .42926 .27971 .43686 .28871 .43129 .28286 .42716 Metetra
.712 .809 .926 r
.28286 .42716 .28871 .43129 .29755 .42824 .2918 .423 Metetra
.531 .713 .955 r
.2918 .423 .29755 .42824 .30628 .42726 .30053 .42222 Metetra
.732 .778 .89 r
.30053 .42222 .30628 .42726 .3153 .42234 .30958 .41733 Metetra
.049 .465 .883 r
.30958 .41733 .3153 .42234 .32381 .42612 .31811 .42073 Metetra
.737 .769 .878 r
.31811 .42073 .32381 .42612 .33291 .42089 .32723 .41557 Metetra
.557 .722 .951 r
.32723 .41557 .33291 .42089 .34183 .41918 .33614 .41441 Metetra
.688 .785 .924 r
.33614 .41441 .34183 .41918 .35108 .41205 .34522 .41074 Metetra
.885 .903 .836 r
.34522 .41074 .35108 .41205 .36007 .41023 .3547 .40025 Metetra
.37 .477 .838 r
.3547 .40025 .36007 .41023 .36918 .40665 .36348 .40341 Metetra
.781 .859 .909 r
.36348 .40341 .36918 .40665 .37805 .40896 .37276 .39726 Metetra
.327 .413 .798 r
.37276 .39726 .37805 .40896 .38736 .40248 .38159 .40187 Metetra
.739 .961 .94 r
.38159 .40187 .38736 .40248 .39636 .40405 .39091 .39611 Metetra
.656 .673 .855 r
.39091 .39611 .39636 .40405 .4057 .398 .40016 .39295 Metetra
.412 .674 .969 r
.40016 .39295 .4057 .398 .41476 .4004 .4093 .39346 Metetra
.704 .719 .861 r
.4093 .39346 .41476 .4004 .42394 .40098 .41866 .38894 Metetra
.697 .613 .759 r
.41866 .38894 .42394 .40098 .43335 .39552 .42809 .38288 Metetra
.567 .538 .782 r
.42809 .38288 .43335 .39552 .44242 .40419 .43739 .38222 Metetra
.928 .628 .156 r
.43739 .38222 .44242 .40419 .44936 .51082 .44525 .44256 Metetra
0 0 .383 r
.44525 .44256 .44936 .51082 .45833 .54923 .45337 .50976 Metetra
.014 .011 .506 r
.45337 .50976 .45833 .54923 .46818 .55179 .46259 .54188 Metetra
.465 .549 .857 r
.46259 .54188 .46818 .55179 .47812 .55248 .47252 .54336 Metetra
.555 .615 .867 r
.47252 .54336 .47812 .55248 .48813 .553 .48255 .54272 Metetra
.551 .586 .843 r
.48255 .54272 .48813 .553 .49822 .54992 .49262 .5423 Metetra
.539 .652 .908 r
.49262 .5423 .49822 .54992 .50835 .54638 .50275 .54174 Metetra
.697 .818 .94 r
.50275 .54174 .50835 .54638 .51851 .54429 .51295 .53737 Metetra
.699 .738 .882 r
.51295 .53737 .51851 .54429 .52872 .54153 .52318 .53277 Metetra
.677 .681 .846 r
.52318 .53277 .52872 .54153 .53896 .53677 .53344 .52854 Metetra
.588 .658 .886 r
.53344 .52854 .53896 .53677 .54922 .53122 .54374 .52695 Metetra
.78 .851 .904 r
.54374 .52695 .54922 .53122 .55955 .5301 .55405 .52011 Metetra
.732 .677 .798 r
.55405 .52011 .55955 .5301 .56983 .52171 .56437 .513 Metetra
.869 .737 .714 r
.56437 .513 .56983 .52171 .58013 .51371 .57454 .49499 Metetra
.859 .649 .617 r
.57454 .49499 .58013 .51371 .58983 .47497 .58434 .45947 Metetra
.952 .691 .504 r
.58434 .45947 .58983 .47497 .59785 .37101 .59215 .33803 Metetra
.409 .309 .63 r
.59215 .33803 .59785 .37101 .60767 .35927 .60246 .34837 Metetra
.747 .663 .767 r
.60246 .34837 .60767 .35927 .61748 .34749 .61238 .33993 Metetra
.78 .742 .818 r
.61238 .33993 .61748 .34749 .62741 .33995 .62232 .33179 Metetra
.66 .685 .862 r
.62232 .33179 .62741 .33995 .6375 .33678 .63241 .32825 Metetra
.683 .685 .846 r
.63241 .32825 .6375 .33678 .64755 .33155 .64252 .32387 Metetra
.66 .7 .876 r
.64252 .32387 .64755 .33155 .65753 .32421 .65269 .32037 Metetra
.841 .877 .868 r
.65269 .32037 .65753 .32421 .66776 .32208 .66265 .31145 Metetra
.629 .615 .817 r
.66265 .31145 .66776 .32208 .67769 .31273 .67291 .30861 Metetra
.85 .869 .855 r
.67291 .30861 .67769 .31273 .68797 .31007 .68287 .29911 Metetra
.386 .474 .828 r
.68287 .29911 .68797 .31007 .69837 .30893 .69354 .30287 Metetra
.619 .741 .934 r
.69354 .30287 .69837 .30893 .70875 .30657 .70394 .30033 Metetra
.794 .793 .852 r
.70394 .30033 .70875 .30657 .71881 .29822 .71406 .29239 Metetra
.652 .765 .932 r
.71406 .29239 .71881 .29822 .72922 .29519 .72448 .28907 Metetra
.739 .785 .89 r
.72448 .28907 .72922 .29519 .73949 .28945 .73478 .2833 Metetra
.377 .618 .946 r
.73478 .2833 .73949 .28945 .74998 .28657 .74562 .28488 Metetra
.855 .97 .869 r
.74562 .28488 .74998 .28657 .76081 .28743 .75571 .27533 Metetra
.5 .521 .81 r
.75571 .27533 .76081 .28743 .77065 .27505 .76665 .27667 Metetra
.715 .967 .718 r
.76665 .27667 .77065 .27505 .78161 .27634 .77674 .26673 Metetra
.73 .689 .81 r
.77674 .26673 .78161 .27634 .79186 .26856 .7871 .25996 Metetra
.469 .584 .887 r
.7871 .25996 .79186 .26856 .80245 .26454 .79818 .26113 Metetra
.824 .918 .9 r
.79818 .26113 .80245 .26454 .81383 .26849 .80846 .2529 Metetra
.64 .555 .743 r
.80846 .2529 .81383 .26849 .82405 .2596 .81913 .24852 Metetra
.404 .485 .83 r
.81913 .24852 .82405 .2596 .83511 .2589 .83062 .25216 Metetra
.852 .755 .756 r
.20611 .45617 .21205 .46159 .22169 .44801 .21575 .44297 Metetra
.59 .739 .947 r
.21575 .44297 .22169 .44801 .23019 .44667 .2243 .44132 Metetra
.782 .766 .838 r
.2243 .44132 .23019 .44667 .23895 .44294 .23336 .4343 Metetra
.666 .651 .826 r
.23336 .4343 .23895 .44294 .2476 .44067 .24213 .4308 Metetra
.626 .609 .813 r
.24213 .4308 .2476 .44067 .2565 .43581 .25082 .42844 Metetra
.632 .673 .871 r
.25082 .42844 .2565 .43581 .26537 .43155 .25955 .4261 Metetra
.699 .755 .895 r
.25955 .4261 .26537 .43155 .27411 .42926 .26843 .42215 Metetra
.229 .487 .894 r
.26843 .42215 .27411 .42926 .28286 .42716 .27679 .42541 Metetra
.836 .899 .883 r
.27679 .42541 .28286 .42716 .2918 .423 .28604 .41751 Metetra
.584 .724 .939 r
.28604 .41751 .2918 .423 .30053 .42222 .29483 .41598 Metetra
.679 .727 .886 r
.29483 .41598 .30053 .42222 .30958 .41733 .3038 .41244 Metetra
.186 .558 .933 r
.3038 .41244 .30958 .41733 .31811 .42073 .31241 .41477 Metetra
.706 .744 .881 r
.31241 .41477 .31811 .42073 .32723 .41557 .3215 .41048 Metetra
.551 .731 .959 r
.3215 .41048 .32723 .41557 .33614 .41441 .33042 .40932 Metetra
.694 .774 .913 r
.33042 .40932 .33614 .41441 .34522 .41074 .33954 .40547 Metetra
.775 .781 .858 r
.33954 .40547 .34522 .41074 .3547 .40025 .34883 .39884 Metetra
.751 .933 .947 r
.34883 .39884 .3547 .40025 .36348 .40341 .35809 .39328 Metetra
.651 .621 .806 r
.35809 .39328 .36348 .40341 .37276 .39726 .36725 .38993 Metetra
0 .074 .616 r
.36725 .38993 .37276 .39726 .38159 .40187 .37587 .39873 Metetra
.858 .854 .837 r
.37587 .39873 .38159 .40187 .39091 .39611 .38541 .38895 Metetra
.683 .706 .865 r
.38541 .38895 .39091 .39611 .40016 .39295 .3947 .38507 Metetra
.146 .41 .855 r
.3947 .38507 .40016 .39295 .4093 .39346 .40368 .38988 Metetra
.77 .853 .913 r
.40368 .38988 .4093 .39346 .41866 .38894 .41312 .38395 Metetra
.704 .789 .917 r
.41312 .38395 .41866 .38894 .42809 .38288 .42252 .37972 Metetra
.61 .056 0 r
.42252 .37972 .42809 .38288 .43739 .38222 .43159 .38794 Metetra
.875 .958 .618 r
.43159 .38794 .43739 .38222 .44525 .44256 .4414 .37145 Metetra
0 0 .269 r
.4414 .37145 .44525 .44256 .45337 .50976 .44879 .45723 Metetra
0 0 .462 r
.44879 .45723 .45337 .50976 .46259 .54188 .45759 .50142 Metetra
.05 .035 .517 r
.45759 .50142 .46259 .54188 .47252 .54336 .46692 .53268 Metetra
.561 .583 .833 r
.46692 .53268 .47252 .54336 .48255 .54272 .47695 .532 Metetra
.564 .584 .832 r
.47695 .532 .48255 .54272 .49262 .5423 .48704 .53124 Metetra
.581 .587 .823 r
.48704 .53124 .49262 .5423 .50275 .54174 .49718 .52998 Metetra
.585 .577 .81 r
.49718 .52998 .50275 .54174 .51295 .53737 .50737 .52858 Metetra
.625 .659 .863 r
.50737 .52858 .51295 .53737 .52318 .53277 .51761 .526 Metetra
.614 .716 .918 r
.51761 .526 .52318 .53277 .53344 .52854 .52789 .52365 Metetra
.784 .828 .886 r
.52789 .52365 .53344 .52854 .54374 .52695 .5382 .51647 Metetra
.701 .657 .803 r
.5382 .51647 .54374 .52695 .55405 .52011 .54853 .5107 Metetra
.739 .693 .806 r
.54853 .5107 .55405 .52011 .56437 .513 .55887 .50348 Metetra
.929 .725 .605 r
.55887 .50348 .56437 .513 .57454 .49499 .56879 .46353 Metetra
.894 .64 .547 r
.56879 .46353 .57454 .49499 .58434 .45947 .5777 .37464 Metetra
.654 .434 .573 r
.5777 .37464 .58434 .45947 .59215 .33803 .58728 .34519 Metetra
.064 0 0 r
.58728 .34519 .59215 .33803 .60246 .34837 .59728 .33949 Metetra
.751 .702 .806 r
.59728 .33949 .60246 .34837 .61238 .33993 .60725 .33206 Metetra
.622 .678 .882 r
.60725 .33206 .61238 .33993 .62232 .33179 .61738 .32962 Metetra
.887 .927 .842 r
.61738 .32962 .62232 .33179 .63241 .32825 .62728 .31885 Metetra
.617 .636 .846 r
.62728 .31885 .63241 .32825 .64252 .32387 .63747 .3165 Metetra
.773 .749 .831 r
.63747 .3165 .64252 .32387 .65269 .32037 .6475 .30887 Metetra
.602 .586 .807 r
.6475 .30887 .65269 .32037 .66265 .31145 .65778 .30688 Metetra
.669 .82 .956 r
.65778 .30688 .66265 .31145 .67291 .30861 .66802 .30308 Metetra
.774 .811 .883 r
.66802 .30308 .67291 .30861 .68287 .29911 .67816 .29628 Metetra
.703 .908 .967 r
.67816 .29628 .68287 .29911 .69354 .30287 .6884 .29131 Metetra
.444 .498 .82 r
.6884 .29131 .69354 .30287 .70394 .30033 .6991 .29393 Metetra
.875 .799 .771 r
.6991 .29393 .70394 .30033 .71406 .29239 .70893 .28054 Metetra
.586 .573 .805 r
.70893 .28054 .71406 .29239 .72448 .28907 .71947 .27905 Metetra
.622 .628 .836 r
.71947 .27905 .72448 .28907 .73478 .2833 .73 .27643 Metetra
.734 .76 .874 r
.73 .27643 .73478 .2833 .74562 .28488 .74035 .27062 Metetra
.6 .546 .766 r
.74035 .27062 .74562 .28488 .75571 .27533 .75098 .26844 Metetra
.679 .742 .898 r
.75098 .26844 .75571 .27533 .76665 .27667 .76153 .26435 Metetra
.567 .556 .802 r
.76153 .26435 .76665 .27667 .77674 .26673 .77237 .26351 Metetra
.69 .898 .972 r
.77237 .26351 .77674 .26673 .7871 .25996 .78293 .25871 Metetra
.797 .987 .891 r
.78293 .25871 .7871 .25996 .79818 .26113 .79323 .25046 Metetra
.656 .635 .817 r
.79323 .25046 .79818 .26113 .80846 .2529 .80393 .2465 Metetra
.573 .716 .94 r
.80393 .2465 .80846 .2529 .81913 .24852 .81488 .24483 Metetra
.322 .701 .981 r
.81488 .24483 .81913 .24852 .83062 .25216 .82611 .24537 Metetra
.868 .751 .731 r
.20014 .45072 .20611 .45617 .21575 .44297 .21008 .43472 Metetra
.625 .645 .85 r
.21008 .43472 .21575 .44297 .2243 .44132 .21868 .43252 Metetra
.444 .547 .867 r
.21868 .43252 .2243 .44132 .23336 .4343 .22699 .43396 Metetra
.802 .954 .916 r
.22699 .43396 .23336 .4343 .24213 .4308 .23608 .42718 Metetra
.71 .828 .938 r
.23608 .42718 .24213 .4308 .25082 .42844 .24494 .42307 Metetra
.092 .48 .895 r
.24494 .42307 .25082 .42844 .25955 .4261 .25322 .42625 Metetra
.822 .967 .897 r
.25322 .42625 .25955 .4261 .26843 .42215 .26243 .41867 Metetra
.705 .837 .945 r
.26243 .41867 .26843 .42215 .27679 .42541 .27138 .41461 Metetra
.555 .559 .813 r
.27138 .41461 .27679 .42541 .28604 .41751 .28006 .41422 Metetra
.686 .844 .959 r
.28006 .41422 .28604 .41751 .29483 .41598 .28904 .4105 Metetra
.579 .724 .942 r
.28904 .4105 .29483 .41598 .3038 .41244 .29788 .409 Metetra
.663 .835 .966 r
.29788 .409 .3038 .41244 .31241 .41477 .30689 .4057 Metetra
.529 .586 .857 r
.30689 .4057 .31241 .41477 .3215 .41048 .31571 .40572 Metetra
.555 .748 .967 r
.31571 .40572 .3215 .41048 .33042 .40932 .32466 .40439 Metetra
.67 .776 .93 r
.32466 .40439 .33042 .40932 .33954 .40547 .33376 .40108 Metetra
.788 .814 .873 r
.33376 .40108 .33954 .40547 .34883 .39884 .3431 .39429 Metetra
.595 .772 .965 r
.3431 .39429 .34883 .39884 .35809 .39328 .35218 .39228 Metetra
.746 .948 .945 r
.35218 .39228 .35809 .39328 .36725 .38993 .36149 .38661 Metetra
0 .479 .842 r
.36149 .38661 .36725 .38993 .37587 .39873 .37041 .38939 Metetra
.729 .67 .792 r
.37041 .38939 .37587 .39873 .38541 .38895 .37982 .38286 Metetra
.416 .634 .945 r
.37982 .38286 .38541 .38895 .3947 .38507 .38893 .38374 Metetra
0 .447 .7 r
.38893 .38374 .3947 .38507 .40368 .38988 .39804 .38573 Metetra
.671 .816 .953 r
.39804 .38573 .40368 .38988 .41312 .38395 .40742 .38222 Metetra
.88 .907 .843 r
.40742 .38222 .41312 .38395 .42252 .37972 .41706 .37192 Metetra
0 0 .489 r
.41706 .37192 .42252 .37972 .43159 .38794 .42602 .3834 Metetra
.866 .813 .796 r
.42602 .3834 .43159 .38794 .4414 .37145 .43575 .37167 Metetra
.815 .987 .882 r
.43575 .37167 .4414 .37145 .44879 .45723 .44537 .36351 Metetra
.123 .031 .47 r
.44537 .36351 .44879 .45723 .45759 .50142 .45342 .42673 Metetra
.011 0 .445 r
.45342 .42673 .45759 .50142 .46692 .53268 .46196 .48705 Metetra
.45 .311 .6 r
.46196 .48705 .46692 .53268 .47695 .532 .47173 .49668 Metetra
.353 .263 .614 r
.47173 .49668 .47695 .532 .48704 .53124 .48156 .5102 Metetra
.242 .255 .674 r
.48156 .5102 .48704 .53124 .49718 .52998 .49154 .52169 Metetra
.647 .682 .869 r
.49154 .52169 .49718 .52998 .50737 .52858 .50176 .5185 Metetra
.664 .648 .824 r
.50176 .5185 .50737 .52858 .51761 .526 .51202 .51445 Metetra
.65 .614 .8 r
.51202 .51445 .51761 .526 .52789 .52365 .52231 .51065 Metetra
.683 .609 .767 r
.52231 .51065 .52789 .52365 .5382 .51647 .53263 .50484 Metetra
.685 .63 .789 r
.53263 .50484 .5382 .51647 .54853 .5107 .54298 .49945 Metetra
.904 .709 .629 r
.54298 .49945 .54853 .5107 .55887 .50348 .55311 .46595 Metetra
.861 .613 .562 r
.55311 .46595 .55887 .50348 .56879 .46353 .56259 .38999 Metetra
.769 .524 .564 r
.56259 .38999 .56879 .46353 .5777 .37464 .57173 .31994 Metetra
.447 .299 .586 r
.57173 .31994 .5777 .37464 .58728 .34519 .58198 .33213 Metetra
.62 .57 .776 r
.58198 .33213 .58728 .34519 .59728 .33949 .59204 .3293 Metetra
.513 .565 .845 r
.59204 .3293 .59728 .33949 .60725 .33206 .60223 .32979 Metetra
.855 .931 .876 r
.60223 .32979 .60725 .33206 .61738 .32962 .6122 .32059 Metetra
.631 .652 .853 r
.6122 .32059 .61738 .32962 .62728 .31885 .62238 .31782 Metetra
.643 .949 .95 r
.62238 .31782 .62728 .31885 .63747 .3165 .63252 .31286 Metetra
.816 .886 .894 r
.63252 .31286 .63747 .3165 .6475 .30887 .64259 .30501 Metetra
.845 .878 .865 r
.64259 .30501 .6475 .30887 .65778 .30688 .6526 .29584 Metetra
.571 .579 .822 r
.6526 .29584 .65778 .30688 .66802 .30308 .66298 .29483 Metetra
.582 .653 .885 r
.66298 .29483 .66802 .30308 .67816 .29628 .6734 .29335 Metetra
.704 .905 .967 r
.6734 .29335 .67816 .29628 .6884 .29131 .68368 .28836 Metetra
.611 .876 .991 r
.68368 .28836 .6884 .29131 .6991 .29393 .69408 .28495 Metetra
.808 .727 .775 r
.69408 .28495 .6991 .29393 .70893 .28054 .70409 .2741 Metetra
.572 .71 .936 r
.70409 .2741 .70893 .28054 .71947 .27905 .71466 .27253 Metetra
.588 .716 .932 r
.71466 .27253 .71947 .27905 .73 .27643 .72525 .27063 Metetra
.778 .811 .879 r
.72525 .27063 .73 .27643 .74035 .27062 .73555 .26355 Metetra
.387 .591 .925 r
.73555 .26355 .74035 .27062 .75098 .26844 .7465 .26541 Metetra
.861 .927 .87 r
.7465 .26541 .75098 .26844 .76153 .26435 .75667 .25575 Metetra
.467 .586 .889 r
.75667 .25575 .76153 .26435 .77237 .26351 .76768 .25686 Metetra
.698 .761 .901 r
.76768 .25686 .77237 .26351 .78293 .25871 .77829 .2522 Metetra
.688 .763 .909 r
.77829 .2522 .78293 .25871 .79323 .25046 .78896 .24782 Metetra
.237 .695 .95 r
.78896 .24782 .79323 .25046 .80393 .2465 .8001 .24831 Metetra
.838 .97 .653 r
.8001 .24831 .80393 .2465 .81488 .24483 .80996 .2342 Metetra
.359 .47 .837 r
.80996 .2342 .81488 .24483 .82611 .24537 .82156 .23854 Metetra
.786 .762 .831 r
.19412 .44524 .20014 .45072 .21008 .43472 .20326 .43787 Metetra
.69 .977 .798 r
.20326 .43787 .21008 .43472 .21868 .43252 .21239 .43054 Metetra
.664 .891 .98 r
.21239 .43054 .21868 .43252 .22699 .43396 .22118 .42694 Metetra
.612 .678 .888 r
.22118 .42694 .22699 .43396 .23608 .42718 .22985 .42503 Metetra
.489 .835 .997 r
.22985 .42503 .23608 .42718 .24494 .42307 .23852 .42338 Metetra
.6 .943 .932 r
.23852 .42338 .24494 .42307 .25322 .42625 .24745 .41918 Metetra
.2 .476 .891 r
.24745 .41918 .25322 .42625 .26243 .41867 .25578 .42257 Metetra
.624 .94 .722 r
.25578 .42257 .26243 .41867 .27138 .41461 .26505 .41495 Metetra
.507 0 0 r
.26505 .41495 .27138 .41461 .28006 .41422 .27344 .41868 Metetra
.594 .915 .672 r
.27344 .41868 .28006 .41422 .28904 .4105 .28278 .41069 Metetra
.145 .689 .779 r
.28278 .41069 .28904 .4105 .29788 .409 .29162 .40969 Metetra
.829 .982 .879 r
.29162 .40969 .29788 .409 .30689 .4057 .301 .40146 Metetra
.498 .75 .985 r
.301 .40146 .30689 .4057 .31571 .40572 .30989 .40064 Metetra
.664 .77 .928 r
.30989 .40064 .31571 .40572 .32466 .40439 .31898 .39745 Metetra
.75 .729 .832 r
.31898 .39745 .32466 .40439 .33376 .40108 .32828 .3911 Metetra
.593 .598 .826 r
.32828 .3911 .33376 .40108 .3431 .39429 .33732 .38959 Metetra
.576 .761 .966 r
.33732 .38959 .3431 .39429 .35218 .39228 .34641 .38788 Metetra
.595 .781 .969 r
.34641 .38788 .35218 .39228 .36149 .38661 .35556 .3858 Metetra
.298 0 0 r
.35556 .3858 .36149 .38661 .37041 .38939 .36451 .38848 Metetra
.753 .954 .94 r
.36451 .38848 .37041 .38939 .37982 .38286 .37392 .38255 Metetra
.127 0 0 r
.37392 .38255 .37982 .38286 .38893 .38374 .38305 .38363 Metetra
.879 .959 .85 r
.38305 .38363 .38893 .38374 .39804 .38573 .39269 .37358 Metetra
.549 .538 .795 r
.39269 .37358 .39804 .38573 .40742 .38222 .40195 .37336 Metetra
.372 .516 .872 r
.40195 .37336 .40742 .38222 .41706 .37192 .41115 .37597 Metetra
.156 0 0 r
.41115 .37597 .41706 .37192 .42602 .3834 .42057 .37416 Metetra
.074 .323 .802 r
.42057 .37416 .42602 .3834 .43575 .37167 .42978 .38073 Metetra
.272 0 .042 r
.42978 .38073 .43575 .37167 .44537 .36351 .43934 .37735 Metetra
.43934 .37735 .44537 .36351 .45342 .42673 .44916 .3648 Metetra
.421 .27 .569 r
.44916 .3648 .45342 .42673 .46196 .48705 .45836 .38059 Metetra
.382 .22 .534 r
.45836 .38059 .46196 .48705 .47173 .49668 .4674 .41444 Metetra
.291 .162 .527 r
.4674 .41444 .47173 .49668 .48156 .5102 .47663 .45255 Metetra
.218 .128 .534 r
.47663 .45255 .48156 .5102 .49154 .52169 .48621 .48543 Metetra
.513 .374 .629 r
.48621 .48543 .49154 .52169 .50176 .5185 .4963 .48828 Metetra
.541 .41 .651 r
.4963 .48828 .50176 .5185 .51202 .51445 .50649 .48879 Metetra
.581 .453 .672 r
.50649 .48879 .51202 .51445 .52231 .51065 .51674 .48657 Metetra
.708 .542 .661 r
.51674 .48657 .52231 .51065 .53263 .50484 .52703 .47325 Metetra
.752 .548 .62 r
.52703 .47325 .53263 .50484 .54298 .49945 .53725 .44768 Metetra
.812 .567 .568 r
.53725 .44768 .54298 .49945 .55311 .46595 .54706 .37846 Metetra
.711 .476 .567 r
.54706 .37846 .55311 .46595 .56259 .38999 .55667 .32589 Metetra
.534 .353 .582 r
.55667 .32589 .56259 .38999 .57173 .31994 .56671 .32736 Metetra
.047 0 0 r
.56671 .32736 .57173 .31994 .58198 .33213 .5767 .32137 Metetra
.495 .542 .835 r
.5767 .32137 .58198 .33213 .59204 .3293 .58685 .32239 Metetra
.82 .77 .806 r
.58685 .32239 .59204 .3293 .60223 .32979 .59681 .3124 Metetra
.618 .522 .723 r
.59681 .3124 .60223 .32979 .6122 .32059 .60694 .30892 Metetra
.722 .643 .769 r
.60694 .30892 .6122 .32059 .62238 .31782 .61698 .30156 Metetra
.589 .516 .74 r
.61698 .30156 .62238 .31782 .63252 .31286 .62723 .2997 Metetra
.729 .626 .744 r
.62723 .2997 .63252 .31286 .64259 .30501 .63727 .29109 Metetra
.581 .538 .772 r
.63727 .29109 .64259 .30501 .6526 .29584 .64761 .28972 Metetra
.549 .711 .947 r
.64761 .28972 .6526 .29584 .66298 .29483 .658 .28851 Metetra
.707 .767 .899 r
.658 .28851 .66298 .29483 .6734 .29335 .66828 .28372 Metetra
.692 .67 .823 r
.66828 .28372 .6734 .29335 .68368 .28836 .67858 .27862 Metetra
.7 .671 .819 r
.67858 .27862 .68368 .28836 .69408 .28495 .68889 .27318 Metetra
.647 .608 .796 r
.68889 .27318 .69408 .28495 .70409 .2741 .69932 .26936 Metetra
.721 .837 .936 r
.69932 .26936 .70409 .2741 .71466 .27253 .7097 .26426 Metetra
.722 .717 .845 r
.7097 .26426 .71466 .27253 .72525 .27063 .72007 .25842 Metetra
.612 .583 .797 r
.72007 .25842 .72525 .27063 .73555 .26355 .73069 .25591 Metetra
.749 .746 .849 r
.73069 .25591 .73555 .26355 .7465 .26541 .74106 .24921 Metetra
.593 .522 .744 r
.74106 .24921 .7465 .26541 .75667 .25575 .75179 .2471 Metetra
.684 .695 .854 r
.75179 .2471 .75667 .25575 .76768 .25686 .76237 .24253 Metetra
.638 .569 .761 r
.76237 .24253 .76768 .25686 .77829 .2522 .77304 .23853 Metetra
.541 .523 .785 r
.77304 .23853 .77829 .2522 .78896 .24782 .7841 .23861 Metetra
.76 .715 .81 r
.7841 .23861 .78896 .24782 .8001 .24831 .7945 .2306 Metetra
.57 .495 .732 r
.7945 .2306 .8001 .24831 .80996 .2342 .80555 .22948 Metetra
.248 .608 .954 r
.80555 .22948 .80996 .2342 .82156 .23854 .81698 .23166 Metetra
.661 .745 .912 r
.18807 .43973 .19412 .44524 .20326 .43787 .19679 .43672 Metetra
.912 .853 .771 r
.19679 .43672 .20326 .43787 .21239 .43054 .20666 .42226 Metetra
.421 .554 .884 r
.20666 .42226 .21239 .43054 .22118 .42694 .21497 .4238 Metetra
.804 .847 .883 r
.21497 .4238 .22118 .42694 .22985 .42503 .22412 .41685 Metetra
.627 .651 .855 r
.22412 .41685 .22985 .42503 .23852 .42338 .23286 .41455 Metetra
.595 .622 .849 r
.23286 .41455 .23852 .42338 .24745 .41918 .24157 .41303 Metetra
.633 .717 .908 r
.24157 .41303 .24745 .41918 .25578 .42257 .25039 .4106 Metetra
.596 .561 .786 r
.25039 .4106 .25578 .42257 .26505 .41495 .25917 .40896 Metetra
.711 .745 .879 r
.25917 .40896 .26505 .41495 .27344 .41868 .26822 .4045 Metetra
.568 .515 .757 r
.26822 .4045 .27344 .41868 .28278 .41069 .27701 .40372 Metetra
.683 .709 .867 r
.27701 .40372 .28278 .41069 .29162 .40969 .28607 .3999 Metetra
.607 .609 .827 r
.28607 .3999 .29162 .40969 .301 .40146 .29502 .39799 Metetra
.446 .765 .996 r
.29502 .39799 .301 .40146 .30989 .40064 .30391 .39732 Metetra
.832 .848 .858 r
.30391 .39732 .30989 .40064 .31898 .39745 .31337 .38888 Metetra
.375 .525 .878 r
.31337 .38888 .31898 .39745 .32828 .3911 .32215 .39121 Metetra
.148 .692 .786 r
.32215 .39121 .32828 .3911 .33732 .38959 .33118 .39021 Metetra
.128 .676 .736 r
.33118 .39021 .33732 .38959 .34641 .38788 .34028 .38893 Metetra
.632 .963 .883 r
.34028 .38893 .34641 .38788 .35556 .3858 .34965 .38343 Metetra
.518 .844 .998 r
.34965 .38343 .35556 .3858 .36451 .38848 .35886 .38141 Metetra
.239 .502 .902 r
.35886 .38141 .36451 .38848 .37392 .38255 .36785 .38461 Metetra
.359 .821 .73 r
.36785 .38461 .37392 .38255 .38305 .38363 .37725 .38048 Metetra
.447 .783 .998 r
.37725 .38048 .38305 .38363 .39269 .37358 .38654 .37955 Metetra
.409 0 .001 r
.38654 .37955 .39269 .37358 .40195 .37336 .39582 .37994 Metetra
.244 0 0 r
.39582 .37994 .40195 .37336 .41115 .37597 .40526 .3776 Metetra
.636 .107 0 r
.40526 .3776 .41115 .37597 .42057 .37416 .41444 .38379 Metetra
.277 0 .059 r
.41444 .38379 .42057 .37416 .42978 .38073 .42401 .38029 Metetra
.184 0 0 r
.42401 .38029 .42978 .38073 .43934 .37735 .43347 .38197 Metetra
.467 0 0 r
.43347 .38197 .43934 .37735 .44916 .3648 .44298 .38394 Metetra
.663 .322 .386 r
.44298 .38394 .44916 .3648 .45836 .38059 .45235 .39542 Metetra
.543 .177 .295 r
.45235 .39542 .45836 .38059 .4674 .41444 .46201 .3981 Metetra
.361 .374 .738 r
.46201 .3981 .4674 .41444 .47663 .45255 .47169 .40393 Metetra
.524 .36 .6 r
.47169 .40393 .47663 .45255 .48621 .48543 .48152 .40613 Metetra
.532 .343 .57 r
.48152 .40613 .48621 .48543 .4963 .48828 .49141 .40776 Metetra
.523 .336 .569 r
.49141 .40776 .4963 .48828 .50649 .48879 .50136 .41117 Metetra
.561 .366 .574 r
.50136 .41117 .50649 .48879 .51674 .48657 .51142 .40707 Metetra
.564 .368 .573 r
.51142 .40707 .51674 .48657 .52703 .47325 .52152 .40214 Metetra
.776 .531 .565 r
.52152 .40214 .52703 .47325 .53725 .44768 .5315 .33038 Metetra
.669 .437 .56 r
.5315 .33038 .53725 .44768 .54706 .37846 .54121 .28232 Metetra
.438 .266 .55 r
.54121 .28232 .54706 .37846 .55667 .32589 .55126 .30392 Metetra
.68 .529 .674 r
.55126 .30392 .55667 .32589 .56671 .32736 .56114 .2946 Metetra
.581 .427 .637 r
.56114 .2946 .56671 .32736 .5767 .32137 .57112 .29147 Metetra
.405 .315 .64 r
.57112 .29147 .5767 .32137 .58685 .32239 .58135 .30053 Metetra
.711 .549 .668 r
.58135 .30053 .58685 .32239 .59681 .3124 .59125 .28825 Metetra
.602 .47 .673 r
.59125 .28825 .59681 .3124 .60694 .30892 .60134 .28459 Metetra
.549 .435 .676 r
.60134 .28459 .60694 .30892 .61698 .30156 .61156 .2845 Metetra
.676 .559 .715 r
.61156 .2845 .61698 .30156 .62723 .2997 .62163 .27753 Metetra
.536 .438 .691 r
.62163 .27753 .62723 .2997 .63727 .29109 .63198 .27817 Metetra
.665 .598 .77 r
.63198 .27817 .63727 .29109 .64761 .28972 .64218 .27329 Metetra
.648 .549 .729 r
.64218 .27329 .64761 .28972 .658 .28851 .65241 .26823 Metetra
.598 .489 .701 r
.65241 .26823 .658 .28851 .66828 .28372 .66276 .26539 Metetra
.644 .532 .711 r
.66276 .26539 .66828 .28372 .67858 .27862 .67304 .26004 Metetra
.644 .529 .709 r
.67304 .26004 .67858 .27862 .68889 .27318 .68334 .25465 Metetra
.558 .479 .721 r
.68334 .25465 .68889 .27318 .69932 .26936 .69393 .25409 Metetra
.589 .529 .755 r
.69393 .25409 .69932 .26936 .7097 .26426 .70451 .25224 Metetra
.697 .63 .779 r
.70451 .25224 .7097 .26426 .72007 .25842 .71487 .24607 Metetra
.643 .599 .789 r
.71487 .24607 .72007 .25842 .73069 .25591 .72541 .24225 Metetra
.655 .586 .766 r
.72541 .24225 .73069 .25591 .74106 .24921 .73592 .23755 Metetra
.663 .621 .797 r
.73592 .23755 .74106 .24921 .75179 .2471 .74648 .23303 Metetra
.649 .579 .762 r
.74648 .23303 .75179 .2471 .76237 .24253 .75708 .2285 Metetra
.515 .503 .781 r
.75708 .2285 .76237 .24253 .77304 .23853 .76815 .22946 Metetra
.8 .732 .789 r
.76815 .22946 .77304 .23853 .7841 .23861 .77837 .21935 Metetra
.536 .461 .719 r
.77837 .21935 .7841 .23861 .7945 .2306 .78952 .21992 Metetra
.144 .332 .793 r
.78952 .21992 .7945 .2306 .80555 .22948 .80146 .22849 Metetra
.485 .894 .926 r
.80146 .22849 .80555 .22948 .81698 .23166 .81237 .22473 Metetra
.661 .745 .912 r
.18198 .43418 .18807 .43973 .19679 .43672 .19072 .43116 Metetra
.812 .762 .806 r
.19072 .43116 .19679 .43672 .20666 .42226 .20009 .422 Metetra
.368 .829 .912 r
.20009 .422 .20666 .42226 .21497 .4238 .20877 .42005 Metetra
.157 .597 .934 r
.20877 .42005 .21497 .4238 .22412 .41685 .21713 .42166 Metetra
.519 .875 .638 r
.21713 .42166 .22412 .41685 .23286 .41455 .22638 .41436 Metetra
.461 0 0 r
.22638 .41436 .23286 .41455 .24157 .41303 .23467 .41779 Metetra
.51 .869 .633 r
.23467 .41779 .24157 .41303 .25039 .4106 .24395 .41052 Metetra
.396 .847 .908 r
.24395 .41052 .25039 .4106 .25917 .40896 .25282 .40818 Metetra
.453 .864 .956 r
.25282 .40818 .25917 .40896 .26822 .4045 .26173 .40589 Metetra
.533 0 0 r
.26173 .40589 .26822 .4045 .27701 .40372 .27019 .40962 Metetra
.472 .82 .54 r
.27019 .40962 .27701 .40372 .28607 .3999 .27964 .40136 Metetra
.325 .808 .775 r
.27964 .40136 .28607 .3999 .29502 .39799 .28871 .39823 Metetra
.68 .967 .93 r
.28871 .39823 .29502 .39799 .30391 .39732 .29796 .39294 Metetra
.459 .731 .986 r
.29796 .39294 .30391 .39732 .31337 .38888 .3069 .39253 Metetra
.238 0 0 r
.3069 .39253 .31337 .38888 .32215 .39121 .31591 .39188 Metetra
.112 .664 .724 r
.31591 .39188 .32215 .39121 .33118 .39021 .32499 .39067 Metetra
.161 .701 .767 r
.32499 .39067 .33118 .39021 .34028 .38893 .33413 .3893 Metetra
.194 .725 .79 r
.33413 .3893 .34028 .38893 .34965 .38343 .34331 .38778 Metetra
.34331 .38778 .34965 .38343 .35886 .38141 .35275 .38234 Metetra
.516 0 0 r
.35275 .38234 .35886 .38141 .36785 .38461 .36173 .38633 Metetra
.588 .945 .83 r
.36173 .38633 .36785 .38461 .37725 .38048 .37125 .38055 Metetra
.545 0 0 r
.37125 .38055 .37725 .38048 .38654 .37955 .38031 .38544 Metetra
.38031 .38544 .38654 .37955 .39582 .37994 .38992 .37922 Metetra
.637 .942 .958 r
.38992 .37922 .39582 .37994 .40526 .3776 .39947 .37476 Metetra
.504 0 0 r
.39947 .37476 .40526 .3776 .41444 .38379 .40865 .38122 Metetra
.174 .657 .926 r
.40865 .38122 .41444 .38379 .42401 .38029 .41811 .38203 Metetra
.046 0 0 r
.41811 .38203 .42401 .38029 .43347 .38197 .42769 .381 Metetra
.122 .664 .839 r
.42769 .381 .43347 .38197 .44298 .38394 .43729 .38093 Metetra
.408 0 0 r
.43729 .38093 .44298 .38394 .45235 .39542 .4468 .38673 Metetra
.299 .487 .876 r
.4468 .38673 .45235 .39542 .46201 .3981 .45645 .39024 Metetra
.481 .614 .906 r
.45645 .39024 .46201 .3981 .47169 .40393 .46623 .39071 Metetra
.492 .497 .791 r
.46623 .39071 .47169 .40393 .48152 .40613 .47605 .39214 Metetra
.837 .664 .668 r
.47605 .39214 .48152 .40613 .49141 .40776 .48622 .37031 Metetra
.715 .511 .612 r
.48622 .37031 .49141 .40776 .50136 .41117 .49632 .34775 Metetra
.689 .468 .582 r
.49632 .34775 .50136 .41117 .51142 .40707 .50639 .31675 Metetra
.641 .421 .568 r
.50639 .31675 .51142 .40707 .52152 .40214 .5163 .28932 Metetra
.483 .295 .549 r
.5163 .28932 .52152 .40214 .5315 .33038 .52612 .30339 Metetra
.598 .455 .658 r
.52612 .30339 .5315 .33038 .54121 .28232 .53602 .29956 Metetra
.363 .026 .253 r
.53602 .29956 .54121 .28232 .55126 .30392 .54595 .29461 Metetra
.576 .619 .858 r
.54595 .29461 .55126 .30392 .56114 .2946 .55594 .29335 Metetra
.733 .961 .941 r
.55594 .29335 .56114 .2946 .57112 .29147 .56592 .28726 Metetra
.494 .767 .992 r
.56592 .28726 .57112 .29147 .58135 .30053 .576 .28615 Metetra
.605 .545 .761 r
.576 .28615 .58135 .30053 .59125 .28825 .5861 .28372 Metetra
.386 .699 .983 r
.5861 .28372 .59125 .28825 .60134 .28459 .59631 .28405 Metetra
.574 .934 .93 r
.59631 .28405 .60134 .28459 .61156 .2845 .60646 .27954 Metetra
.604 .783 .967 r
.60646 .27954 .61156 .2845 .62163 .27753 .6167 .27704 Metetra
.347 .821 .889 r
.6167 .27704 .62163 .27753 .63198 .27817 .62698 .27465 Metetra
.87 .89 .846 r
.62698 .27465 .63198 .27817 .64218 .27329 .63703 .26426 Metetra
.694 .685 .837 r
.63703 .26426 .64218 .27329 .65241 .26823 .64728 .25928 Metetra
.717 .696 .829 r
.64728 .25928 .65241 .26823 .66276 .26539 .65752 .25341 Metetra
.547 .551 .811 r
.65752 .25341 .66276 .26539 .67304 .26004 .66804 .25309 Metetra
.191 .479 .895 r
.66804 .25309 .67304 .26004 .68334 .25465 .67885 .25738 Metetra
.67885 .25738 .68334 .25465 .69393 .25409 .68921 .25151 Metetra
.697 .923 .968 r
.68921 .25151 .69393 .25409 .70451 .25224 .69964 .24636 Metetra
.604 .752 .948 r
.69964 .24636 .70451 .25224 .71487 .24607 .71027 .24394 Metetra
.78 .957 .927 r
.71027 .24394 .71487 .24607 .72541 .24225 .72063 .23674 Metetra
.336 .63 .96 r
.72063 .23674 .72541 .24225 .73592 .23755 .73161 .23828 Metetra
.775 .995 .79 r
.73161 .23828 .73592 .23755 .74648 .23303 .74185 .22846 Metetra
.371 .694 .982 r
.74185 .22846 .74648 .23303 .75708 .2285 .75286 .22895 Metetra
.78 .997 .801 r
.75286 .22895 .75708 .2285 .76815 .22946 .76314 .2192 Metetra
.512 .572 .852 r
.76314 .2192 .76815 .22946 .77837 .21935 .77425 .21961 Metetra
.729 .989 .822 r
.77425 .21961 .77837 .21935 .78952 .21992 .78466 .21104 Metetra
0 .23 .749 r
.78466 .21104 .78952 .21992 .80146 .22849 .79679 .22154 Metetra
.661 .745 .912 r
.79679 .22154 .80146 .22849 .81237 .22473 .80773 .21776 Metetra
.661 .745 .912 r
.17586 .42859 .18198 .43418 .19072 .43116 .18461 .42555 Metetra
.7 .753 .893 r
.18461 .42555 .19072 .43116 .20009 .422 .19349 .42152 Metetra
.797 .949 .92 r
.19349 .42152 .20009 .422 .20877 .42005 .20266 .41482 Metetra
.608 .746 .942 r
.20266 .41482 .20877 .42005 .21713 .42166 .21139 .41278 Metetra
.421 .54 .871 r
.21139 .41278 .21713 .42166 .22638 .41436 .2198 .41443 Metetra
.82 .964 .9 r
.2198 .41443 .22638 .41436 .23467 .41779 .22912 .40685 Metetra
.372 .46 .822 r
.22912 .40685 .23467 .41779 .24395 .41052 .23749 .40994 Metetra
.815 .948 .909 r
.23749 .40994 .24395 .41052 .25282 .40818 .24682 .40267 Metetra
.063 .461 .884 r
.24682 .40267 .25282 .40818 .26173 .40589 .25527 .40607 Metetra
.827 .969 .892 r
.25527 .40607 .26173 .40589 .27019 .40962 .26469 .39811 Metetra
.565 .556 .803 r
.26469 .39811 .27019 .40962 .27964 .40136 .27357 .39734 Metetra
.832 .821 .838 r
.27357 .39734 .27964 .40136 .28871 .39823 .2831 .38834 Metetra
.649 .628 .815 r
.2831 .38834 .28871 .39823 .29796 .39294 .29222 .38504 Metetra
.55 .635 .888 r
.29222 .38504 .29796 .39294 .3069 .39253 .30119 .38433 Metetra
.566 .634 .878 r
.30119 .38433 .3069 .39253 .31591 .39188 .31022 .38334 Metetra
.651 .661 .846 r
.31022 .38334 .31591 .39188 .32499 .39067 .31944 .38017 Metetra
.571 .581 .824 r
.31944 .38017 .32499 .39067 .33413 .3893 .32855 .37918 Metetra
.589 .598 .829 r
.32855 .37918 .33413 .3893 .34331 .38778 .33774 .3777 Metetra
.595 .602 .829 r
.33774 .3777 .34331 .38778 .35275 .38234 .34698 .37605 Metetra
.728 .751 .87 r
.34698 .37605 .35275 .38234 .36173 .38633 .35645 .37079 Metetra
.435 .425 .749 r
.35645 .37079 .36173 .38633 .37125 .38055 .36551 .37411 Metetra
.743 .752 .859 r
.36551 .37411 .37125 .38055 .38031 .38544 .37508 .36823 Metetra
.646 .536 .716 r
.37508 .36823 .38031 .38544 .38992 .37922 .38462 .36327 Metetra
.5 .461 .745 r
.38462 .36327 .38992 .37922 .39947 .37476 .39392 .36479 Metetra
.458 .539 .852 r
.39392 .36479 .39947 .37476 .40865 .38122 .40329 .36622 Metetra
.663 .567 .737 r
.40329 .36622 .40865 .38122 .41811 .38203 .41296 .36087 Metetra
.553 .452 .694 r
.41296 .36087 .41811 .38203 .42769 .381 .42248 .36044 Metetra
.684 .538 .682 r
.42248 .36044 .42769 .381 .43729 .38093 .43232 .35142 Metetra
.459 .351 .643 r
.43232 .35142 .43729 .38093 .4468 .38673 .44177 .35674 Metetra
.638 .473 .642 r
.44177 .35674 .4468 .38673 .45645 .39024 .45163 .3486 Metetra
.63 .444 .612 r
.45163 .3486 .45645 .39024 .46623 .39071 .46153 .33813 Metetra
.625 .428 .595 r
.46153 .33813 .46623 .39071 .47605 .39214 .47147 .32551 Metetra
.521 .34 .576 r
.47147 .32551 .47605 .39214 .48622 .37031 .48116 .32834 Metetra
.537 .376 .611 r
.48116 .32834 .48622 .37031 .49632 .34775 .49096 .32886 Metetra
.706 .562 .689 r
.49096 .32886 .49632 .34775 .50639 .31675 .5009 .31872 Metetra
.088 0 0 r
.5009 .31872 .50639 .31675 .5163 .28932 .51079 .31781 Metetra
.36 .074 .337 r
.51079 .31781 .5163 .28932 .52612 .30339 .52074 .30871 Metetra
.152 0 0 r
.52074 .30871 .52612 .30339 .53602 .29956 .5307 .3059 Metetra
.5307 .3059 .53602 .29956 .54595 .29461 .54067 .29532 Metetra
.227 0 0 r
.54067 .29532 .54595 .29461 .55594 .29335 .55072 .29665 Metetra
.55072 .29665 .55594 .29335 .56592 .28726 .56079 .29298 Metetra
.144 0 0 r
.56079 .29298 .56592 .28726 .576 .28615 .5709 .2897 Metetra
.583 .898 .632 r
.5709 .2897 .576 .28615 .5861 .28372 .58094 .28062 Metetra
.331 .735 .981 r
.58094 .28062 .5861 .28372 .59631 .28405 .59117 .28052 Metetra
.721 .881 .955 r
.59117 .28052 .59631 .28405 .60646 .27954 .60134 .27538 Metetra
.849 .867 .855 r
.60134 .27538 .60646 .27954 .6167 .27704 .61141 .26582 Metetra
.369 .464 .826 r
.61141 .26582 .6167 .27704 .62698 .27465 .6219 .26963 Metetra
.648 .8 .956 r
.6219 .26963 .62698 .27465 .63703 .26426 .63223 .26624 Metetra
.346 .803 .68 r
.63223 .26624 .63703 .26426 .64728 .25928 .64254 .26126 Metetra
.411 .841 .696 r
.64254 .26126 .64728 .25928 .65752 .25341 .65284 .2556 Metetra
.375 .814 .665 r
.65284 .2556 .65752 .25341 .66804 .25309 .66318 .25001 Metetra
.494 .824 .999 r
.66318 .25001 .66804 .25309 .67885 .25738 .67372 .24812 Metetra
.61 .645 .86 r
.67372 .24812 .67885 .25738 .68921 .25151 .68429 .2458 Metetra
.742 .808 .905 r
.68429 .2458 .68921 .25151 .69964 .24636 .69472 .23995 Metetra
.744 .785 .886 r
.69472 .23995 .69964 .24636 .71027 .24394 .70515 .23386 Metetra
.601 .622 .845 r
.70515 .23386 .71027 .24394 .72063 .23674 .71586 .23178 Metetra
.78 .85 .903 r
.71586 .23178 .72063 .23674 .73161 .23828 .7263 .22481 Metetra
.513 .512 .792 r
.7263 .22481 .73161 .23828 .74185 .22846 .7373 .22565 Metetra
.805 .94 .916 r
.7373 .22565 .74185 .22846 .75286 .22895 .74774 .21787 Metetra
.515 .556 .836 r
.74774 .21787 .75286 .22895 .76314 .2192 .75883 .2183 Metetra
.79 .993 .877 r
.75883 .2183 .76314 .2192 .77425 .21961 .76927 .20975 Metetra
.676 .668 .834 r
.76927 .20975 .77425 .21961 .78466 .21104 .78004 .2051 Metetra
0 .2 .712 r
.78004 .2051 .78466 .21104 .79679 .22154 .79208 .21455 Metetra
.661 .745 .912 r
.79208 .21455 .79679 .22154 .80773 .21776 .80306 .21073 Metetra
.661 .745 .912 r
.16969 .42297 .17586 .42859 .18461 .42555 .17846 .41991 Metetra
.846 .758 .765 r
.17846 .41991 .18461 .42555 .19349 .42152 .18824 .40742 Metetra
.486 .469 .764 r
.18824 .40742 .19349 .42152 .20266 .41482 .19658 .40895 Metetra
.772 .757 .839 r
.19658 .40895 .20266 .41482 .21139 .41278 .20579 .4021 Metetra
.62 .597 .805 r
.20579 .4021 .21139 .41278 .2198 .41443 .21459 .39971 Metetra
.591 .523 .747 r
.21459 .39971 .2198 .41443 .22912 .40685 .22336 .39795 Metetra
.682 .66 .821 r
.22336 .39795 .22912 .40685 .23749 .40994 .2324 .3937 Metetra
.549 .483 .734 r
.2324 .3937 .23749 .40994 .24682 .40267 .2411 .39348 Metetra
.67 .65 .821 r
.2411 .39348 .24682 .40267 .25527 .40607 .25016 .3896 Metetra
.546 .479 .732 r
.25016 .3896 .25527 .40607 .26469 .39811 .25894 .38948 Metetra
.626 .647 .851 r
.25894 .38948 .26469 .39811 .27357 .39734 .26795 .38707 Metetra
.503 .551 .837 r
.26795 .38707 .27357 .39734 .2831 .38834 .27676 .38763 Metetra
.842 .943 .888 r
.27676 .38763 .2831 .38834 .29222 .38504 .28628 .37934 Metetra
.514 .7 .954 r
.28628 .37934 .29222 .38504 .30119 .38433 .29526 .37871 Metetra
.728 .77 .886 r
.29526 .37871 .30119 .38433 .31022 .38334 .30459 .37368 Metetra
.564 .596 .844 r
.30459 .37368 .31022 .38334 .31944 .38017 .31366 .37281 Metetra
.564 .661 .902 r
.31366 .37281 .31944 .38017 .32855 .37918 .32279 .37171 Metetra
.749 .722 .827 r
.32279 .37171 .32855 .37918 .33774 .3777 .33229 .36514 Metetra
.576 .548 .786 r
.33229 .36514 .33774 .3777 .34698 .37605 .3415 .36395 Metetra
.597 .567 .791 r
.3415 .36395 .34698 .37605 .35645 .37079 .35079 .3621 Metetra
.637 .656 .851 r
.35079 .3621 .35645 .37079 .36551 .37411 .36017 .35928 Metetra
.652 .561 .74 r
.36017 .35928 .36551 .37411 .37508 .36823 .36968 .35462 Metetra
.589 .542 .769 r
.36968 .35462 .37508 .36823 .38462 .36327 .37907 .35292 Metetra
.523 .564 .838 r
.37907 .35292 .38462 .36327 .39392 .36479 .38843 .35304 Metetra
.261 .383 .798 r
.38843 .35304 .39392 .36479 .40329 .36622 .39763 .35845 Metetra
.762 .725 .818 r
.39763 .35845 .40329 .36622 .41296 .36087 .40739 .35107 Metetra
.796 .694 .752 r
.40739 .35107 .41296 .36087 .42248 .36044 .4173 .33973 Metetra
.579 .472 .696 r
.4173 .33973 .42248 .36044 .43232 .35142 .4269 .33788 Metetra
.549 .523 .778 r
.4269 .33788 .43232 .35142 .44177 .35674 .43649 .33754 Metetra
.598 .494 .707 r
.43649 .33754 .44177 .35674 .45163 .3486 .4462 .3348 Metetra
.49 .486 .779 r
.4462 .3348 .45163 .3486 .46153 .33813 .45586 .33628 Metetra
.843 .932 .887 r
.45586 .33628 .46153 .33813 .47147 .32551 .46577 .32764 Metetra
.75 .991 .791 r
.46577 .32764 .47147 .32551 .48116 .32834 .47569 .31859 Metetra
.322 .47 .853 r
.47569 .31859 .48116 .32834 .49096 .32886 .48545 .32228 Metetra
.834 .775 .796 r
.48545 .32228 .49096 .32886 .5009 .31872 .49543 .31138 Metetra
.566 .673 .911 r
.49543 .31138 .5009 .31872 .51079 .31781 .50534 .3101 Metetra
.714 .721 .855 r
.50534 .3101 .51079 .31781 .52074 .30871 .51531 .30481 Metetra
.616 .83 .982 r
.51531 .30481 .52074 .30871 .5307 .3059 .5253 .30185 Metetra
.868 .857 .829 r
.5253 .30185 .5307 .3059 .54067 .29532 .53531 .29106 Metetra
.767 .853 .915 r
.53531 .29106 .54067 .29532 .55072 .29665 .54534 .2848 Metetra
.567 .563 .809 r
.54534 .2848 .55072 .29665 .56079 .29298 .55544 .2838 Metetra
.28 .463 .862 r
.55544 .2838 .56079 .29298 .5709 .2897 .56566 .28798 Metetra
.879 .944 .853 r
.56566 .28798 .5709 .2897 .58094 .28062 .57573 .27755 Metetra
.628 .875 .988 r
.57573 .27755 .58094 .28062 .59117 .28052 .58592 .27399 Metetra
.661 .745 .913 r
.58592 .27399 .59117 .28052 .60134 .27538 .59616 .27043 Metetra
.534 .757 .979 r
.59616 .27043 .60134 .27538 .61141 .26582 .60648 .26899 Metetra
.695 .946 .664 r
.60648 .26899 .61141 .26582 .6219 .26963 .61659 .25834 Metetra
.447 .51 .83 r
.61659 .25834 .6219 .26963 .63223 .26624 .62711 .26044 Metetra
.735 .799 .903 r
.62711 .26044 .63223 .26624 .64254 .26126 .63743 .25483 Metetra
.657 .752 .92 r
.63743 .25483 .64254 .26126 .65284 .2556 .64785 .25131 Metetra
.755 .865 .929 r
.64785 .25131 .65284 .2556 .66318 .25001 .65821 .24525 Metetra
.586 .792 .978 r
.65821 .24525 .66318 .25001 .67372 .24812 .66876 .24285 Metetra
.748 .827 .913 r
.66876 .24285 .67372 .24812 .68429 .2458 .67917 .23686 Metetra
.436 .564 .885 r
.67917 .23686 .68429 .2458 .69472 .23995 .69003 .23847 Metetra
.874 .971 .849 r
.69003 .23847 .69472 .23995 .70515 .23386 .70026 .22791 Metetra
.688 .786 .925 r
.70026 .22791 .70515 .23386 .71586 .23178 .71085 .22353 Metetra
.613 .679 .888 r
.71085 .22353 .71586 .23178 .7263 .22481 .72161 .22105 Metetra
.697 .881 .966 r
.72161 .22105 .7263 .22481 .7373 .22565 .73226 .21616 Metetra
.48 .575 .873 r
.73226 .21616 .7373 .22565 .74774 .21787 .74335 .21706 Metetra
.571 .934 .922 r
.74335 .21706 .74774 .21787 .75883 .2183 .75408 .21219 Metetra
.694 .788 .923 r
.75408 .21219 .75883 .2183 .76927 .20975 .76487 .20756 Metetra
.68 .942 .963 r
.76487 .20756 .76927 .20975 .78004 .2051 .77563 .20215 Metetra
0 .339 .735 r
.77563 .20215 .78004 .2051 .79208 .21455 .78735 .2075 Metetra
.661 .745 .912 r
.78735 .2075 .79208 .21455 .80306 .21073 .79835 .20366 Metetra
.661 .745 .912 r
.16349 .41732 .16969 .42297 .17846 .41991 .17227 .41424 Metetra
.661 .745 .912 r
.17227 .41424 .17846 .41991 .18824 .40742 .18109 .41115 Metetra
.915 .978 .768 r
.18109 .41115 .18824 .40742 .19658 .40895 .191 .3978 Metetra
.62 .588 .797 r
.191 .3978 .19658 .40895 .20579 .4021 .19978 .39535 Metetra
.584 .684 .91 r
.19978 .39535 .20579 .4021 .21459 .39971 .2085 .39387 Metetra
.696 .749 .893 r
.2085 .39387 .21459 .39971 .22336 .39795 .2175 .38985 Metetra
.602 .65 .87 r
.2175 .38985 .22336 .39795 .2324 .3937 .22632 .38806 Metetra
.63 .741 .928 r
.22632 .38806 .2324 .3937 .2411 .39348 .23524 .38558 Metetra
.629 .667 .868 r
.23524 .38558 .2411 .39348 .25016 .3896 .24419 .38312 Metetra
.601 .702 .915 r
.24419 .38312 .25016 .3896 .25894 .38948 .25312 .38125 Metetra
.646 .666 .855 r
.25312 .38125 .25894 .38948 .26795 .38707 .26218 .37829 Metetra
.529 .602 .87 r
.26218 .37829 .26795 .38707 .27676 .38763 .27106 .37806 Metetra
.744 .673 .781 r
.27106 .37806 .27676 .38763 .28628 .37934 .28054 .37056 Metetra
.579 .626 .862 r
.28054 .37056 .28628 .37934 .29526 .37871 .28957 .36927 Metetra
.549 .596 .853 r
.28957 .36927 .29526 .37871 .30459 .37368 .29859 .3687 Metetra
.509 .731 .973 r
.29859 .3687 .30459 .37368 .31366 .37281 .30768 .36786 Metetra
.522 .738 .973 r
.30768 .36786 .31366 .37281 .32279 .37171 .31682 .36685 Metetra
.821 .805 .836 r
.31682 .36685 .32279 .37171 .33229 .36514 .32649 .35802 Metetra
.582 .679 .907 r
.32649 .35802 .33229 .36514 .3415 .36395 .33573 .3565 Metetra
.576 .666 .9 r
.33573 .3565 .3415 .36395 .35079 .3621 .34501 .35514 Metetra
.662 .715 .888 r
.34501 .35514 .35079 .3621 .36017 .35928 .35443 .35176 Metetra
.595 .674 .895 r
.35443 .35176 .36017 .35928 .36968 .35462 .36381 .34997 Metetra
.549 .765 .978 r
.36381 .34997 .36968 .35462 .37907 .35292 .37322 .34844 Metetra
.794 .828 .878 r
.37322 .34844 .37907 .35292 .38843 .35304 .38292 .34125 Metetra
.257 .38 .797 r
.38292 .34125 .38843 .35304 .39763 .35845 .39211 .34669 Metetra
.723 .637 .761 r
.39211 .34669 .39763 .35845 .40739 .35107 .40189 .33919 Metetra
.633 .593 .791 r
.40189 .33919 .40739 .35107 .4173 .33973 .41152 .33601 Metetra
.739 .858 .936 r
.41152 .33601 .4173 .33973 .4269 .33788 .42125 .33073 Metetra
.576 .681 .912 r
.42125 .33073 .4269 .33788 .43649 .33754 .4309 .32925 Metetra
.645 .676 .865 r
.4309 .32925 .43649 .33754 .4462 .3348 .44063 .32613 Metetra
.802 .719 .773 r
.44063 .32613 .4462 .3348 .45586 .33628 .45058 .31552 Metetra
.541 .448 .699 r
.45058 .31552 .45586 .33628 .46577 .32764 .4603 .31557 Metetra
.548 .548 .806 r
.4603 .31557 .46577 .32764 .47569 .31859 .47008 .31517 Metetra
.797 .882 .908 r
.47008 .31517 .47569 .31859 .48545 .32228 .48002 .30809 Metetra
.606 .548 .764 r
.48002 .30809 .48545 .32228 .49543 .31138 .48992 .30557 Metetra
.749 .789 .886 r
.48992 .30557 .49543 .31138 .50534 .3101 .49988 .29959 Metetra
.61 .611 .827 r
.49988 .29959 .50534 .3101 .51531 .30481 .50985 .29728 Metetra
.743 .736 .846 r
.50985 .29728 .51531 .30481 .5253 .30185 .51987 .29091 Metetra
.69 .641 .796 r
.51987 .29091 .5253 .30185 .53531 .29106 .52991 .2855 Metetra
.526 .726 .965 r
.52991 .2855 .53531 .29106 .54534 .2848 .53999 .28442 Metetra
.381 .841 .895 r
.53999 .28442 .54534 .2848 .55544 .2838 .55012 .28174 Metetra
.705 .933 .963 r
.55012 .28174 .55544 .2838 .56566 .28798 .56026 .27644 Metetra
.671 .624 .794 r
.56026 .27644 .56566 .28798 .57573 .27755 .57043 .27165 Metetra
.649 .765 .934 r
.57043 .27165 .57573 .27755 .58592 .27399 .58066 .26834 Metetra
.582 .75 .957 r
.58066 .26834 .58592 .27399 .59616 .27043 .59095 .26631 Metetra
.824 .872 .881 r
.59095 .26631 .59616 .27043 .60648 .26899 .60114 .2579 Metetra
.702 .648 .793 r
.60114 .2579 .60648 .26899 .61659 .25834 .6114 .25185 Metetra
.34 .595 .94 r
.6114 .25185 .61659 .25834 .62711 .26044 .62193 .25374 Metetra
.733 .769 .882 r
.62193 .25374 .62711 .26044 .63743 .25483 .63227 .24796 Metetra
.735 .765 .877 r
.63227 .24796 .63743 .25483 .64785 .25131 .64263 .24205 Metetra
.659 .67 .849 r
.64263 .24205 .64785 .25131 .65821 .24525 .6531 .23818 Metetra
.567 .693 .926 r
.6531 .23818 .65821 .24525 .66876 .24285 .66371 .23668 Metetra
.748 .795 .891 r
.66371 .23668 .66876 .24285 .67917 .23686 .67416 .23051 Metetra
.743 .789 .89 r
.67416 .23051 .67917 .23686 .69003 .23847 .68463 .22446 Metetra
.496 .495 .785 r
.68463 .22446 .69003 .23847 .70026 .22791 .69554 .22582 Metetra
.807 .962 .91 r
.69554 .22582 .70026 .22791 .71085 .22353 .70597 .21777 Metetra
.415 .67 .966 r
.70597 .21777 .71085 .22353 .72161 .22105 .71695 .21828 Metetra
.645 .907 .982 r
.71695 .21828 .72161 .22105 .73226 .21616 .72767 .2139 Metetra
.83 .961 .895 r
.72767 .2139 .73226 .21616 .74335 .21706 .73812 .20511 Metetra
.658 .619 .799 r
.73812 .20511 .74335 .21706 .75408 .21219 .7489 .20061 Metetra
.673 .633 .802 r
.7489 .20061 .75408 .21219 .76487 .20756 .75967 .19561 Metetra
.171 .328 .781 r
.75967 .19561 .76487 .20756 .77563 .20215 .77159 .20425 Metetra
.77159 .20425 .77563 .20215 .78735 .2075 .78258 .2004 Metetra
.661 .745 .912 r
.78258 .2004 .78735 .2075 .79835 .20366 .79361 .19653 Metetra
.661 .745 .912 r
.15724 .41163 .16349 .41732 .17227 .41424 .16605 .40853 Metetra
.661 .745 .912 r
.16605 .40853 .17227 .41424 .18109 .41115 .17488 .40542 Metetra
.731 .758 .875 r
.17488 .40542 .18109 .41115 .191 .3978 .18395 .40034 Metetra
.67 .974 .832 r
.18395 .40034 .191 .3978 .19978 .39535 .1932 .3937 Metetra
.563 .883 .991 r
.1932 .3937 .19978 .39535 .2085 .39387 .20207 .39098 Metetra
.804 .864 .893 r
.20207 .39098 .2085 .39387 .2175 .38985 .21138 .38399 Metetra
.6 .724 .932 r
.21138 .38399 .2175 .38985 .22632 .38806 .22023 .38207 Metetra
.684 .744 .897 r
.22023 .38207 .22632 .38806 .23524 .38558 .22928 .37831 Metetra
.629 .687 .885 r
.22928 .37831 .23524 .38558 .24419 .38312 .23824 .37585 Metetra
.639 .691 .883 r
.23824 .37585 .24419 .38312 .25312 .38125 .24726 .37315 Metetra
.499 .608 .893 r
.24726 .37315 .25312 .38125 .26218 .37829 .25607 .37331 Metetra
.706 .789 .916 r
.25607 .37331 .26218 .37829 .27106 .37806 .26528 .36904 Metetra
.624 .64 .846 r
.26528 .36904 .27106 .37806 .28054 .37056 .27439 .36659 Metetra
.635 .816 .97 r
.27439 .36659 .28054 .37056 .28957 .36927 .28356 .36368 Metetra
.496 .701 .961 r
.28356 .36368 .28957 .36927 .29859 .3687 .29259 .3632 Metetra
.806 .784 .832 r
.29259 .3632 .29859 .3687 .30768 .36786 .30222 .35476 Metetra
.524 .512 .784 r
.30222 .35476 .30768 .36786 .31682 .36685 .31127 .35509 Metetra
.701 .624 .767 r
.31127 .35509 .31682 .36685 .32649 .35802 .32078 .3489 Metetra
.572 .617 .859 r
.32078 .3489 .32649 .35802 .33573 .3565 .33001 .34774 Metetra
.373 .527 .881 r
.33001 .34774 .33573 .3565 .34501 .35514 .33908 .34999 Metetra
.725 .794 .907 r
.33908 .34999 .34501 .35514 .35443 .35176 .34861 .34506 Metetra
.669 .728 .893 r
.34861 .34506 .35443 .35176 .36381 .34997 .3581 .34148 Metetra
.564 .633 .878 r
.3581 .34148 .36381 .34997 .37322 .34844 .36749 .34042 Metetra
.65 .683 .868 r
.36749 .34042 .37322 .34844 .38292 .34125 .37703 .33723 Metetra
.576 .804 .986 r
.37703 .33723 .38292 .34125 .39211 .34669 .38656 .33506 Metetra
.704 .631 .773 r
.38656 .33506 .39211 .34669 .40189 .33919 .3963 .32875 Metetra
.51 .559 .841 r
.3963 .32875 .40189 .33919 .41152 .33601 .40581 .3291 Metetra
.755 .75 .847 r
.40581 .3291 .41152 .33601 .42125 .33073 .41561 .32247 Metetra
.648 .679 .865 r
.41561 .32247 .42125 .33073 .4309 .32925 .42532 .31926 Metetra
.556 .594 .847 r
.42532 .31926 .4309 .32925 .44063 .32613 .435 .31848 Metetra
.622 .687 .89 r
.435 .31848 .44063 .32613 .45058 .31552 .44477 .31597 Metetra
.612 .955 .895 r
.44477 .31597 .45058 .31552 .4603 .31557 .45465 .31058 Metetra
.805 .822 .864 r
.45465 .31058 .4603 .31557 .47008 .31517 .4646 .30263 Metetra
.499 .514 .803 r
.4646 .30263 .47008 .31517 .48002 .30809 .47442 .30358 Metetra
.735 .835 .927 r
.47442 .30358 .48002 .30809 .48992 .30557 .48438 .29826 Metetra
.522 .658 .921 r
.48438 .29826 .48992 .30557 .49988 .29959 .49432 .29773 Metetra
.778 .944 .932 r
.49432 .29773 .49988 .29959 .50985 .29728 .50435 .29096 Metetra
.325 .593 .942 r
.50435 .29096 .50985 .29728 .51987 .29091 .51437 .29282 Metetra
.759 .992 .787 r
.51437 .29282 .51987 .29091 .52991 .2855 .52447 .28338 Metetra
.883 .925 .846 r
.52447 .28338 .52991 .2855 .53999 .28442 .53456 .27265 Metetra
.647 .608 .796 r
.53456 .27265 .53999 .28442 .55012 .28174 .54468 .26879 Metetra
.383 .441 .796 r
.54468 .26879 .55012 .28174 .56026 .27644 .55491 .27271 Metetra
.829 .883 .883 r
.55491 .27271 .56026 .27644 .57043 .27165 .56507 .26423 Metetra
.669 .721 .888 r
.56507 .26423 .57043 .27165 .58066 .26834 .57531 .26037 Metetra
.723 .726 .852 r
.57531 .26037 .58066 .26834 .59095 .26631 .58555 .25456 Metetra
.445 .501 .823 r
.58555 .25456 .59095 .26631 .60114 .2579 .596 .25673 Metetra
.821 .976 .892 r
.596 .25673 .60114 .2579 .6114 .25185 .60624 .24817 Metetra
.308 .7 .978 r
.60624 .24817 .6114 .25185 .62193 .25374 .61676 .24861 Metetra
.742 .829 .918 r
.61676 .24861 .62193 .25374 .63227 .24796 .62714 .24285 Metetra
.761 .835 .909 r
.62714 .24285 .63227 .24796 .64263 .24205 .63752 .23649 Metetra
.575 .756 .964 r
.63752 .23649 .64263 .24205 .6531 .23818 .64809 .23446 Metetra
.795 .897 .916 r
.64809 .23446 .6531 .23818 .66371 .23668 .65849 .22716 Metetra
.656 .664 .847 r
.65849 .22716 .66371 .23668 .67416 .23051 .66906 .22332 Metetra
.671 .737 .9 r
.66906 .22332 .67416 .23051 .68463 .22446 .67967 .21931 Metetra
.713 .827 .936 r
.67967 .21931 .68463 .22446 .69554 .22582 .69026 .21426 Metetra
.502 .541 .829 r
.69026 .21426 .69554 .22582 .70597 .21777 .70122 .215 Metetra
.807 .942 .915 r
.70122 .215 .70597 .21777 .71695 .21828 .71172 .2071 Metetra
.681 .644 .807 r
.71172 .2071 .71695 .21828 .72767 .2139 .7224 .20187 Metetra
.67 .624 .795 r
.7224 .20187 .72767 .2139 .73812 .20511 .73313 .19686 Metetra
.632 .692 .888 r
.73313 .19686 .73812 .20511 .7489 .20061 .74404 .19379 Metetra
.702 .768 .903 r
.74404 .19379 .7489 .20061 .75967 .19561 .75485 .18883 Metetra
0 .278 .777 r
.75485 .18883 .75967 .19561 .77159 .20425 .76675 .19713 Metetra
.661 .745 .912 r
.76675 .19713 .77159 .20425 .78258 .2004 .77777 .19325 Metetra
.661 .745 .912 r
.77777 .19325 .78258 .2004 .79361 .19653 .78883 .18936 Metetra
.661 .745 .912 r
.15096 .4059 .15724 .41163 .16605 .40853 .15978 .40278 Metetra
.661 .745 .912 r
.15978 .40278 .16605 .40853 .17488 .40542 .16863 .39965 Metetra
.661 .745 .912 r
.16863 .39965 .17488 .40542 .18395 .40034 .17751 .39651 Metetra
.827 .822 .844 r
.17751 .39651 .18395 .40034 .1932 .3937 .187 .38785 Metetra
.778 .762 .839 r
.187 .38785 .1932 .3937 .20207 .39098 .19634 .3807 Metetra
.475 .536 .84 r
.19634 .3807 .20207 .39098 .21138 .38399 .20487 .38169 Metetra
.493 .836 .997 r
.20487 .38169 .21138 .38399 .22023 .38207 .21372 .37992 Metetra
.822 .892 .892 r
.21372 .37992 .22023 .38207 .22928 .37831 .22316 .37235 Metetra
.611 .727 .928 r
.22316 .37235 .22928 .37831 .23824 .37585 .23211 .37021 Metetra
.347 .628 .957 r
.23211 .37021 .23824 .37585 .24726 .37315 .2408 .37134 Metetra
.836 .905 .886 r
.2408 .37134 .24726 .37315 .25607 .37331 .25035 .36322 Metetra
.536 .574 .841 r
.25035 .36322 .25607 .37331 .26528 .36904 .25924 .36295 Metetra
0 .049 .553 r
.25924 .36295 .26528 .36904 .27439 .36659 .26753 .37069 Metetra
.934 .969 .725 r
.26753 .37069 .27439 .36659 .28356 .36368 .27775 .3549 Metetra
.558 .619 .869 r
.27775 .3549 .28356 .36368 .29259 .3632 .28682 .35403 Metetra
.544 .603 .863 r
.28682 .35403 .29259 .3632 .30222 .35476 .2959 .35347 Metetra
.845 .929 .885 r
.2959 .35347 .30222 .35476 .31127 .35509 .30558 .34495 Metetra
.38 .493 .848 r
.30558 .34495 .31127 .35509 .32078 .3489 .31453 .34755 Metetra
.259 .748 .918 r
.31453 .34755 .32078 .3489 .33001 .34774 .32376 .34684 Metetra
.837 .949 .892 r
.32376 .34684 .33001 .34774 .33908 .34999 .33349 .33852 Metetra
.445 .5 .821 r
.33349 .33852 .33908 .34999 .34861 .34506 .34264 .3404 Metetra
.864 .811 .796 r
.34264 .3404 .34861 .34506 .3581 .34148 .3526 .32854 Metetra
.274 .368 .778 r
.3526 .32854 .3581 .34148 .36749 .34042 .36165 .33407 Metetra
.787 .768 .836 r
.36165 .33407 .36749 .34042 .37703 .33723 .37144 .32623 Metetra
.534 .559 .827 r
.37144 .32623 .37703 .33723 .38656 .33506 .38088 .32605 Metetra
.547 .614 .871 r
.38088 .32605 .38656 .33506 .3963 .32875 .3904 .32537 Metetra
.838 .87 .867 r
.3904 .32537 .3963 .32875 .40581 .3291 .40029 .31658 Metetra
.602 .569 .789 r
.40029 .31658 .40581 .3291 .41561 .32247 .40994 .31437 Metetra
.336 .533 .899 r
.40994 .31437 .41561 .32247 .42532 .31926 .41947 .31687 Metetra
.84 .912 .885 r
.41947 .31687 .42532 .31926 .435 .31848 .42942 .30826 Metetra
.521 .572 .848 r
.42942 .30826 .435 .31848 .44477 .31597 .43913 .3083 Metetra
.736 .728 .844 r
.43913 .3083 .44477 .31597 .45465 .31058 .44904 .30217 Metetra
.572 .646 .885 r
.44904 .30217 .45465 .31058 .4646 .30263 .45888 .30083 Metetra
.774 .943 .934 r
.45888 .30083 .4646 .30263 .47442 .30358 .46886 .29419 Metetra
.687 .671 .829 r
.46886 .29419 .47442 .30358 .48438 .29826 .47883 .28939 Metetra
.706 .691 .833 r
.47883 .28939 .48438 .29826 .49432 .29773 .48883 .284 Metetra
.653 .582 .762 r
.48883 .284 .49432 .29773 .50435 .29096 .49886 .27941 Metetra
.646 .611 .8 r
.49886 .27941 .50435 .29096 .51437 .29282 .5089 .27565 Metetra
.552 .486 .735 r
.5089 .27565 .51437 .29282 .52447 .28338 .51898 .27512 Metetra
.788 .734 .803 r
.51898 .27512 .52447 .28338 .53456 .27265 .5291 .26608 Metetra
.509 .682 .944 r
.5291 .26608 .53456 .27265 .54468 .26879 .53927 .26553 Metetra
.359 .747 .987 r
.53927 .26553 .54468 .26879 .55491 .27271 .54949 .26518 Metetra
.8 .758 .814 r
.54949 .26518 .55491 .27271 .56507 .26423 .55967 .25597 Metetra
.655 .693 .873 r
.55967 .25597 .56507 .26423 .57531 .26037 .56994 .25239 Metetra
.736 .731 .846 r
.56994 .25239 .57531 .26037 .58555 .25456 .5802 .24606 Metetra
.42 .57 .897 r
.5802 .24606 .58555 .25456 .596 .25673 .59064 .24762 Metetra
.723 .7 .828 r
.59064 .24762 .596 .25673 .60624 .24817 .60097 .24139 Metetra
.577 .709 .933 r
.60097 .24139 .60624 .24817 .61676 .24861 .61144 .2396 Metetra
.729 .706 .829 r
.61144 .2396 .61676 .24861 .62714 .24285 .62182 .23315 Metetra
.704 .681 .825 r
.62182 .23315 .62714 .24285 .63752 .23649 .63224 .22749 Metetra
.611 .657 .871 r
.63224 .22749 .63752 .23649 .64809 .23446 .64282 .22505 Metetra
.636 .659 .855 r
.64282 .22505 .64809 .23446 .65849 .22716 .65342 .22185 Metetra
.778 .836 .897 r
.65342 .22185 .65849 .22716 .66906 .22332 .66388 .21482 Metetra
.672 .7 .868 r
.66388 .21482 .66906 .22332 .67967 .21931 .6745 .21059 Metetra
.351 .527 .889 r
.6745 .21059 .67967 .21931 .69026 .21426 .68553 .21347 Metetra
.846 .991 .849 r
.68553 .21347 .69026 .21426 .70122 .215 .69592 .20335 Metetra
.672 .631 .801 r
.69592 .20335 .70122 .215 .71172 .2071 .70661 .19836 Metetra
.63 .678 .877 r
.70661 .19836 .71172 .2071 .7224 .20187 .71746 .19533 Metetra
.732 .788 .897 r
.71746 .19533 .7224 .20187 .73313 .19686 .72818 .18951 Metetra
.409 .608 .93 r
.72818 .18951 .73313 .19686 .74404 .19379 .73942 .19082 Metetra
0 .509 .852 r
.73942 .19082 .74404 .19379 .75485 .18883 .75088 .19385 Metetra
.081 0 0 r
.75088 .19385 .75485 .18883 .76675 .19713 .76188 .18996 Metetra
.661 .745 .912 r
.76188 .18996 .76675 .19713 .77777 .19325 .77293 .18605 Metetra
.661 .745 .912 r
.77293 .18605 .77777 .19325 .78883 .18936 .78403 .18213 Metetra
.661 .745 .912 r
.14464 .40014 .15096 .4059 .15978 .40278 .15348 .397 Metetra
.661 .745 .912 r
.15348 .397 .15978 .40278 .16863 .39965 .16234 .39385 Metetra
.661 .745 .912 r
.16234 .39385 .16863 .39965 .17751 .39651 .17124 .39069 Metetra
.854 .757 .755 r
.17124 .39069 .17751 .39651 .187 .38785 .1813 .377 Metetra
.62 .597 .806 r
.1813 .377 .187 .38785 .19634 .3807 .19016 .37451 Metetra
.65 .73 .908 r
.19016 .37451 .19634 .3807 .20487 .38169 .1991 .37159 Metetra
.629 .617 .819 r
.1991 .37159 .20487 .38169 .21372 .37992 .20804 .36888 Metetra
.451 .508 .826 r
.20804 .36888 .21372 .37992 .22316 .37235 .21661 .37044 Metetra
.288 0 0 r
.21661 .37044 .22316 .37235 .23211 .37021 .22509 .37355 Metetra
.908 .982 .771 r
.22509 .37355 .23211 .37021 .2408 .37134 .23511 .36042 Metetra
.611 .594 .809 r
.23511 .36042 .2408 .37134 .25035 .36322 .24416 .35815 Metetra
.614 .766 .952 r
.24416 .35815 .25035 .36322 .25924 .36295 .25324 .35577 Metetra
.606 .687 .9 r
.25324 .35577 .25924 .36295 .26753 .37069 .26234 .35374 Metetra
.637 .532 .719 r
.26234 .35374 .26753 .37069 .27775 .3549 .27166 .34929 Metetra
.524 .714 .959 r
.27166 .34929 .27775 .3549 .28682 .35403 .28074 .34839 Metetra
.682 .766 .914 r
.28074 .34839 .28682 .35403 .2959 .35347 .29008 .34459 Metetra
.777 .701 .779 r
.29008 .34459 .2959 .35347 .30558 .34495 .29983 .33543 Metetra
.322 .478 .859 r
.29983 .33543 .30558 .34495 .31453 .34755 .30874 .33857 Metetra
.64 .653 .847 r
.30874 .33857 .31453 .34755 .32376 .34684 .31812 .33557 Metetra
.701 .634 .778 r
.31812 .33557 .32376 .34684 .33349 .33852 .32772 .32959 Metetra
.633 .653 .851 r
.32772 .32959 .33349 .33852 .34264 .3404 .33715 .32677 Metetra
.446 .462 .782 r
.33715 .32677 .34264 .3404 .3526 .32854 .34632 .3291 Metetra
.34632 .3291 .3526 .32854 .36165 .33407 .35573 .32832 Metetra
.797 .788 .844 r
.35573 .32832 .36165 .33407 .37144 .32623 .36556 .32031 Metetra
.531 .71 .954 r
.36556 .32031 .37144 .32623 .38088 .32605 .37505 .31931 Metetra
.654 .727 .903 r
.37505 .31931 .38088 .32605 .3904 .32537 .3847 .31604 Metetra
.762 .695 .788 r
.3847 .31604 .3904 .32537 .40029 .31658 .39459 .3077 Metetra
.436 .564 .885 r
.39459 .3077 .40029 .31658 .40994 .31437 .40412 .30901 Metetra
.757 .802 .89 r
.40412 .30901 .40994 .31437 .41947 .31687 .41397 .3029 Metetra
.493 .487 .779 r
.41397 .3029 .41947 .31687 .42942 .30826 .42361 .30412 Metetra
.808 .853 .882 r
.42361 .30412 .42942 .30826 .43913 .3083 .43357 .29638 Metetra
.53 .543 .813 r
.43357 .29638 .43913 .3083 .44904 .30217 .44334 .29634 Metetra
.673 .771 .924 r
.44334 .29634 .44904 .30217 .45888 .30083 .45325 .29254 Metetra
.732 .714 .834 r
.45325 .29254 .45888 .30083 .46886 .29419 .46325 .28628 Metetra
.712 .718 .854 r
.46325 .28628 .46886 .29419 .47883 .28939 .47324 .28098 Metetra
.575 .65 .887 r
.47324 .28098 .47883 .28939 .48883 .284 .48322 .27953 Metetra
.813 .849 .876 r
.48322 .27953 .48883 .284 .49886 .27941 .49331 .27145 Metetra
.556 .656 .902 r
.49331 .27145 .49886 .27941 .5089 .27565 .50336 .27033 Metetra
.793 .82 .873 r
.50336 .27033 .5089 .27565 .51898 .27512 .51348 .26274 Metetra
.412 .47 .81 r
.51348 .26274 .51898 .27512 .5291 .26608 .52361 .26569 Metetra
.782 .987 .896 r
.52361 .26569 .5291 .26608 .53927 .26553 .5338 .25784 Metetra
.523 .651 .915 r
.5338 .25784 .53927 .26553 .54949 .26518 .54404 .25728 Metetra
.676 .712 .876 r
.54404 .25728 .54949 .26518 .55967 .25597 .5543 .25312 Metetra
.436 .807 .994 r
.5543 .25312 .55967 .25597 .56994 .25239 .56463 .25169 Metetra
.832 .984 .875 r
.56463 .25169 .56994 .25239 .5802 .24606 .57489 .24253 Metetra
.799 .898 .913 r
.57489 .24253 .5802 .24606 .59064 .24762 .58519 .23515 Metetra
.707 .631 .77 r
.58519 .23515 .59064 .24762 .60097 .24139 .59551 .2282 Metetra
.493 .506 .799 r
.59551 .2282 .60097 .24139 .61144 .2396 .60606 .22935 Metetra
.588 .615 .847 r
.60606 .22935 .61144 .2396 .62182 .23315 .6166 .22754 Metetra
.342 .639 .963 r
.6166 .22754 .62182 .23315 .63224 .22749 .62729 .22879 Metetra
.802 .996 .776 r
.62729 .22879 .63224 .22749 .64282 .22505 .63762 .21807 Metetra
.754 .774 .87 r
.63762 .21807 .64282 .22505 .65342 .22185 .6481 .21141 Metetra
.602 .62 .842 r
.6481 .21141 .65342 .22185 .66388 .21482 .65879 .20913 Metetra
.598 .767 .96 r
.65879 .20913 .66388 .21482 .6745 .21059 .66953 .20661 Metetra
.771 .89 .93 r
.66953 .20661 .6745 .21059 .68553 .21347 .6801 .19992 Metetra
.658 .595 .773 r
.6801 .19992 .68553 .21347 .69592 .20335 .69079 .19501 Metetra
.643 .696 .884 r
.69079 .19501 .69592 .20335 .70661 .19836 .7016 .19161 Metetra
.448 .653 .947 r
.7016 .19161 .70661 .19836 .71746 .19533 .71269 .19198 Metetra
.823 .926 .902 r
.71269 .19198 .71746 .19533 .72818 .18951 .72328 .18352 Metetra
.702 .801 .926 r
.72328 .18352 .72818 .18951 .73942 .19082 .73412 .17859 Metetra
.192 .341 .785 r
.73412 .17859 .73942 .19082 .75088 .19385 .74594 .18666 Metetra
.661 .745 .912 r
.74594 .18666 .75088 .19385 .76188 .18996 .75698 .18274 Metetra
.661 .745 .912 r
.75698 .18274 .76188 .18996 .77293 .18605 .76806 .1788 Metetra
.661 .745 .912 r
.76806 .1788 .77293 .18605 .78403 .18213 .77918 .17486 Metetra
.661 .745 .912 r
.13828 .39433 .14464 .40014 .15348 .397 .14713 .39118 Metetra
.661 .745 .912 r
.14713 .39118 .15348 .397 .16234 .39385 .15601 .38801 Metetra
.661 .745 .912 r
.15601 .38801 .16234 .39385 .17124 .39069 .16493 .38483 Metetra
.661 .745 .912 r
.16493 .38483 .17124 .39069 .1813 .377 .17388 .38164 Metetra
.693 .964 .729 r
.17388 .38164 .1813 .377 .19016 .37451 .18346 .37278 Metetra
.826 .905 .894 r
.18346 .37278 .19016 .37451 .1991 .37159 .19292 .36509 Metetra
.667 .726 .894 r
.19292 .36509 .1991 .37159 .20804 .36888 .20195 .3617 Metetra
.614 .688 .896 r
.20195 .3617 .20804 .36888 .21661 .37044 .21089 .35954 Metetra
.602 .59 .812 r
.21089 .35954 .21661 .37044 .22509 .37355 .21984 .35755 Metetra
.275 .317 .724 r
.21984 .35755 .22509 .37355 .23511 .36042 .22806 .3639 Metetra
.904 .984 .768 r
.22806 .3639 .23511 .36042 .24416 .35815 .23813 .35074 Metetra
.625 .687 .888 r
.23813 .35074 .24416 .35815 .25324 .35577 .24724 .34827 Metetra
.178 .461 .885 r
.24724 .34827 .25324 .35577 .26234 .35374 .25587 .35184 Metetra
.858 .899 .863 r
.25587 .35184 .26234 .35374 .27166 .34929 .26562 .34254 Metetra
.654 .72 .897 r
.26562 .34254 .27166 .34929 .28074 .34839 .27489 .33937 Metetra
.543 .609 .869 r
.27489 .33937 .28074 .34839 .29008 .34459 .284 .33876 Metetra
.721 .769 .891 r
.284 .33876 .29008 .34459 .29983 .33543 .29347 .33383 Metetra
.148 .67 .881 r
.29347 .33383 .29983 .33543 .30874 .33857 .3026 .33401 Metetra
.49 .748 .986 r
.3026 .33401 .30874 .33857 .31812 .33557 .31186 .33312 Metetra
.699 .899 .968 r
.31186 .33312 .31812 .33557 .32772 .32959 .32141 .32855 Metetra
.485 .878 .963 r
.32141 .32855 .32772 .32959 .33715 .32677 .33086 .32585 Metetra
.537 .903 .964 r
.33086 .32585 .33715 .32677 .34632 .3291 .34039 .32256 Metetra
.783 .763 .835 r
.34039 .32256 .34632 .3291 .35573 .32832 .3502 .3148 Metetra
.609 .558 .772 r
.3502 .3148 .35573 .32832 .36556 .32031 .35975 .31221 Metetra
.337 .535 .9 r
.35975 .31221 .36556 .32031 .37505 .31931 .36909 .31457 Metetra
.751 .823 .908 r
.36909 .31457 .37505 .31931 .3847 .31604 .37888 .3088 Metetra
.697 .727 .874 r
.37888 .3088 .3847 .31604 .39459 .3077 .38864 .30423 Metetra
.813 .874 .891 r
.38864 .30423 .39459 .3077 .40412 .30901 .39855 .29652 Metetra
.497 .514 .805 r
.39855 .29652 .40412 .30901 .41397 .3029 .40815 .29737 Metetra
.731 .795 .903 r
.40815 .29737 .41397 .3029 .42361 .30412 .41802 .29204 Metetra
.609 .583 .799 r
.41802 .29204 .42361 .30412 .43357 .29638 .42783 .28956 Metetra
.383 .609 .938 r
.42783 .28956 .43357 .29638 .44334 .29634 .43758 .29083 Metetra
.774 .806 .878 r
.43758 .29083 .44334 .29634 .45325 .29254 .44759 .28398 Metetra
.736 .71 .826 r
.44759 .28398 .45325 .29254 .46325 .28628 .45762 .27742 Metetra
.604 .651 .87 r
.45762 .27742 .46325 .28628 .47324 .28098 .46758 .27526 Metetra
.803 .805 .853 r
.46758 .27526 .47324 .28098 .48322 .27953 .47767 .26705 Metetra
.568 .557 .801 r
.47767 .26705 .48322 .27953 .49331 .27145 .48769 .26586 Metetra
.804 .812 .858 r
.48769 .26586 .49331 .27145 .50336 .27033 .49783 .25768 Metetra
.609 .577 .792 r
.49783 .25768 .50336 .27033 .51348 .26274 .50794 .25507 Metetra
.331 .55 .913 r
.50794 .25507 .51348 .26274 .52361 .26569 .51808 .25746 Metetra
.766 .733 .822 r
.51808 .25746 .52361 .26569 .5338 .25784 .52829 .24966 Metetra
.547 .648 .901 r
.52829 .24966 .5338 .25784 .54404 .25728 .53854 .2487 Metetra
.673 .693 .86 r
.53854 .2487 .54404 .25728 .5543 .25312 .54882 .24447 Metetra
.579 .651 .885 r
.54882 .24447 .5543 .25312 .56463 .25169 .55917 .24284 Metetra
.805 .733 .784 r
.55917 .24284 .56463 .25169 .57489 .24253 .56944 .23229 Metetra
.446 .54 .859 r
.56944 .23229 .57489 .24253 .58519 .23515 .57992 .23385 Metetra
.727 .966 .937 r
.57992 .23385 .58519 .23515 .59551 .2282 .5903 .22745 Metetra
.445 .873 .923 r
.5903 .22745 .59551 .2282 .60606 .22935 .60078 .22426 Metetra
.751 .837 .916 r
.60078 .22426 .60606 .22935 .6166 .22754 .61123 .21815 Metetra
.613 .65 .863 r
.61123 .21815 .6166 .22754 .62729 .22879 .62181 .2156 Metetra
.703 .622 .763 r
.62181 .2156 .62729 .22879 .63762 .21807 .63228 .20853 Metetra
.363 .512 .872 r
.63228 .20853 .63762 .21807 .6481 .21141 .64316 .21146 Metetra
.761 .995 .857 r
.64316 .21146 .6481 .21141 .65879 .20913 .65364 .20295 Metetra
.762 .806 .888 r
.65364 .20295 .65879 .20913 .66953 .20661 .66421 .19619 Metetra
.411 .518 .857 r
.66421 .19619 .66953 .20661 .6801 .19992 .67526 .19858 Metetra
.591 .932 .952 r
.67526 .19858 .6801 .19992 .69079 .19501 .68602 .19395 Metetra
.633 .953 .934 r
.68602 .19395 .69079 .19501 .7016 .19161 .69676 .18846 Metetra
.808 .932 .914 r
.69676 .18846 .7016 .19161 .71269 .19198 .70738 .18049 Metetra
.641 .622 .816 r
.70738 .18049 .71269 .19198 .72328 .18352 .71829 .17673 Metetra
0 .359 .831 r
.71829 .17673 .72328 .18352 .73412 .17859 .72995 .18334 Metetra
.051 0 0 r
.72995 .18334 .73412 .17859 .74594 .18666 .74098 .17941 Metetra
.661 .745 .912 r
.74098 .17941 .74594 .18666 .75698 .18274 .75204 .17546 Metetra
.661 .745 .912 r
.75204 .17546 .75698 .18274 .76806 .1788 .76315 .1715 Metetra
.661 .745 .912 r
.76315 .1715 .76806 .1788 .77918 .17486 .77431 .16753 Metetra
.661 .745 .912 r
.13187 .3885 .13828 .39433 .14713 .39118 .14074 .38532 Metetra
.661 .745 .912 r
.14074 .38532 .14713 .39118 .15601 .38801 .14965 .38213 Metetra
.661 .745 .912 r
.14965 .38213 .15601 .38801 .16493 .38483 .15858 .37893 Metetra
.661 .745 .912 r
.15858 .37893 .16493 .38483 .17388 .38164 .16754 .37572 Metetra
.854 .758 .756 r
.16754 .37572 .17388 .38164 .18346 .37278 .17768 .36202 Metetra
.454 .518 .834 r
.17768 .36202 .18346 .37278 .19292 .36509 .18619 .36338 Metetra
.835 .905 .886 r
.18619 .36338 .19292 .36509 .20195 .3617 .19574 .35527 Metetra
.572 .699 .928 r
.19574 .35527 .20195 .3617 .21089 .35954 .20462 .35383 Metetra
.339 .625 .957 r
.20462 .35383 .21089 .35954 .21984 .35755 .21328 .35496 Metetra
.802 .884 .905 r
.21328 .35496 .21984 .35755 .22806 .3639 .22277 .34801 Metetra
.272 .318 .727 r
.22277 .34801 .22806 .3639 .23813 .35074 .23105 .3543 Metetra
.904 .985 .764 r
.23105 .3543 .23813 .35074 .24724 .34827 .24117 .34102 Metetra
.624 .694 .894 r
.24117 .34102 .24724 .34827 .25587 .35184 .25033 .33856 Metetra
.489 .492 .786 r
.25033 .33856 .25587 .35184 .26562 .34254 .25922 .33965 Metetra
.443 .797 .997 r
.25922 .33965 .26562 .34254 .27489 .33937 .26835 .33848 Metetra
.838 .944 .892 r
.26835 .33848 .27489 .33937 .284 .33876 .27809 .33013 Metetra
.548 .624 .88 r
.27809 .33013 .284 .33876 .29347 .33383 .28726 .32934 Metetra
.705 .818 .935 r
.28726 .32934 .29347 .33383 .3026 .33401 .29675 .32495 Metetra
.526 .603 .873 r
.29675 .32495 .3026 .33401 .31186 .33312 .30597 .32464 Metetra
.693 .689 .841 r
.30597 .32464 .31186 .33312 .32141 .32855 .31554 .31993 Metetra
.625 .66 .864 r
.31554 .31993 .32141 .32855 .33086 .32585 .325 .31732 Metetra
.63 .665 .865 r
.325 .31732 .33086 .32585 .34039 .32256 .33451 .31457 Metetra
.772 .725 .809 r
.33451 .31457 .34039 .32256 .3502 .3148 .34436 .30647 Metetra
.628 .67 .871 r
.34436 .30647 .3502 .3148 .35975 .31221 .35393 .30376 Metetra
.29 .498 .886 r
.35393 .30376 .35975 .31221 .36909 .31457 .36324 .30682 Metetra
.623 .687 .889 r
.36324 .30682 .36909 .31457 .37888 .3088 .37289 .30423 Metetra
.802 .834 .876 r
.37289 .30423 .37888 .3088 .38864 .30423 .38282 .2966 Metetra
.682 .713 .872 r
.38282 .2966 .38864 .30423 .39855 .29652 .3926 .2924 Metetra
.814 .852 .878 r
.3926 .2924 .39855 .29652 .40815 .29737 .40257 .28442 Metetra
.469 .491 .799 r
.40257 .28442 .40815 .29737 .41802 .29204 .4122 .286 Metetra
.349 .623 .954 r
.4122 .286 .41802 .29204 .42783 .28956 .42191 .28726 Metetra
.711 .919 .964 r
.42191 .28726 .42783 .28956 .43758 .29083 .43187 .28211 Metetra
.74 .708 .821 r
.43187 .28211 .43758 .29083 .44759 .28398 .44191 .27527 Metetra
.788 .722 .791 r
.44191 .27527 .44759 .28398 .45762 .27742 .45202 .26584 Metetra
.433 .499 .827 r
.45202 .26584 .45762 .27742 .46758 .27526 .4619 .26794 Metetra
.573 .686 .917 r
.4619 .26794 .46758 .27526 .47767 .26705 .47191 .26634 Metetra
.405 .85 .922 r
.47191 .26634 .47767 .26705 .48769 .26586 .48199 .26374 Metetra
.827 .937 .9 r
.48199 .26374 .48769 .26586 .49783 .25768 .49217 .25544 Metetra
.694 .924 .968 r
.49217 .25544 .49783 .25768 .50794 .25507 .50234 .25039 Metetra
.506 .762 .988 r
.50234 .25039 .50794 .25507 .51808 .25746 .51252 .24911 Metetra
.761 .73 .824 r
.51252 .24911 .51808 .25746 .52829 .24966 .52275 .2415 Metetra
.455 .604 .91 r
.52275 .2415 .52829 .24966 .53854 .2487 .53302 .24221 Metetra
.759 .783 .873 r
.53302 .24221 .53854 .2487 .54882 .24447 .54332 .23554 Metetra
.583 .646 .878 r
.54332 .23554 .54882 .24447 .55917 .24284 .55368 .2338 Metetra
.626 .664 .867 r
.55368 .2338 .55917 .24284 .56944 .23229 .56407 .2309 Metetra
.74 .966 .935 r
.56407 .2309 .56944 .23229 .57992 .23385 .57446 .2243 Metetra
.631 .654 .855 r
.57446 .2243 .57992 .23385 .5903 .22745 .58493 .22122 Metetra
.756 .797 .886 r
.58493 .22122 .5903 .22745 .60078 .22426 .59536 .21468 Metetra
.426 .549 .877 r
.59536 .21468 .60078 .22426 .61123 .21815 .60604 .21639 Metetra
.831 .966 .892 r
.60604 .21639 .61123 .21815 .62181 .2156 .61647 .20752 Metetra
.682 .718 .877 r
.61647 .20752 .62181 .2156 .63228 .20853 .62706 .20303 Metetra
.421 .691 .975 r
.62706 .20303 .63228 .20853 .64316 .21146 .63786 .20315 Metetra
.813 .756 .8 r
.63786 .20315 .64316 .21146 .65364 .20295 .64829 .19276 Metetra
.4 .519 .862 r
.64829 .19276 .65364 .20295 .66421 .19619 .6593 .19523 Metetra
.594 .94 .935 r
.6593 .19523 .66421 .19619 .67526 .19858 .67003 .19026 Metetra
.785 .752 .823 r
.67003 .19026 .67526 .19858 .68602 .19395 .6806 .1815 Metetra
.654 .612 .795 r
.6806 .1815 .68602 .19395 .69676 .18846 .69141 .17701 Metetra
.638 .623 .818 r
.69141 .17701 .69676 .18846 .70738 .18049 .70231 .17334 Metetra
.224 .508 .908 r
.70231 .17334 .70738 .18049 .71829 .17673 .71373 .17711 Metetra
.069 .631 .709 r
.71373 .17711 .71829 .17673 .72995 .18334 .72492 .17607 Metetra
.661 .745 .912 r
.72492 .17607 .72995 .18334 .74098 .17941 .73597 .17211 Metetra
.661 .745 .912 r
.73597 .17211 .74098 .17941 .75204 .17546 .74707 .16814 Metetra
.661 .745 .912 r
.74707 .16814 .75204 .17546 .76315 .1715 .75821 .16415 Metetra
.661 .745 .912 r
.75821 .16415 .76315 .1715 .77431 .16753 .76939 .16014 Metetra
.661 .745 .912 r
.12543 .38262 .13187 .3885 .14074 .38532 .13432 .37942 Metetra
.661 .745 .912 r
.13432 .37942 .14074 .38532 .14965 .38213 .14324 .37622 Metetra
.661 .745 .912 r
.14324 .37622 .14965 .38213 .15858 .37893 .15219 .37299 Metetra
.661 .745 .912 r
.15219 .37299 .15858 .37893 .16754 .37572 .16117 .36976 Metetra
.661 .745 .912 r
.16117 .36976 .16754 .37572 .17768 .36202 .17018 .36652 Metetra
.915 .98 .748 r
.17018 .36652 .17768 .36202 .18619 .36338 .18043 .35222 Metetra
.592 .582 .81 r
.18043 .35222 .18619 .36338 .19574 .35527 .18931 .35045 Metetra
.355 .673 .976 r
.18931 .35045 .19574 .35527 .20462 .35383 .198 .351 Metetra
.793 .876 .908 r
.198 .351 .20462 .35383 .21328 .35496 .20747 .34432 Metetra
.465 .529 .839 r
.20747 .34432 .21328 .35496 .22277 .34801 .21619 .34542 Metetra
.803 .886 .905 r
.21619 .34542 .22277 .34801 .23105 .3543 .22573 .3384 Metetra
.435 .422 .746 r
.22573 .3384 .23105 .3543 .24117 .34102 .23438 .34122 Metetra
.864 .962 .865 r
.23438 .34122 .24117 .34102 .25033 .33856 .2442 .33169 Metetra
.631 .71 .904 r
.2442 .33169 .25033 .33856 .25922 .33965 .25342 .32903 Metetra
.594 .597 .824 r
.25342 .32903 .25922 .33965 .26835 .33848 .26261 .32718 Metetra
.605 .589 .809 r
.26261 .32718 .26835 .33848 .27809 .33013 .27187 .32498 Metetra
.088 .505 .902 r
.27187 .32498 .27809 .33013 .28726 .32934 .28078 .32785 Metetra
.889 .904 .832 r
.28078 .32785 .28726 .32934 .29675 .32495 .2908 .31661 Metetra
.557 .639 .887 r
.2908 .31661 .29675 .32495 .30597 .32464 .30009 .31556 Metetra
.678 .67 .835 r
.30009 .31556 .30597 .32464 .31554 .31993 .30964 .31124 Metetra
.524 .614 .884 r
.30964 .31124 .31554 .31993 .325 .31732 .31897 .31087 Metetra
.717 .755 .883 r
.31897 .31087 .325 .31732 .33451 .31457 .32864 .30585 Metetra
.768 .709 .796 r
.32864 .30585 .33451 .31457 .34436 .30647 .33853 .29752 Metetra
.508 .601 .881 r
.33853 .29752 .34436 .30647 .35393 .30376 .34795 .29747 Metetra
.374 .626 .951 r
.34795 .29747 .35393 .30376 .36324 .30682 .35737 .29852 Metetra
.607 .666 .881 r
.35737 .29852 .36324 .30682 .37289 .30423 .36702 .29631 Metetra
.76 .729 .823 r
.36702 .29631 .37289 .30423 .38282 .2966 .37696 .28892 Metetra
.68 .712 .873 r
.37696 .28892 .38282 .2966 .3926 .2924 .38677 .28476 Metetra
.692 .718 .869 r
.38677 .28476 .3926 .2924 .40257 .28442 .39662 .28022 Metetra
.802 .852 .888 r
.39662 .28022 .40257 .28442 .4122 .286 .40661 .27269 Metetra
.626 .574 .776 r
.40661 .27269 .4122 .286 .42191 .28726 .41647 .26937 Metetra
.385 .375 .725 r
.41647 .26937 .42191 .28726 .43187 .28211 .42611 .2743 Metetra
.588 .677 .902 r
.42611 .2743 .43187 .28211 .44191 .27527 .43602 .27244 Metetra
.633 .883 .987 r
.43602 .27244 .44191 .27527 .45202 .26584 .44604 .26871 Metetra
.44604 .26871 .45202 .26584 .4619 .26794 .45611 .26393 Metetra
.827 .867 .875 r
.45611 .26393 .4619 .26794 .47191 .26634 .46628 .25535 Metetra
.505 .554 .84 r
.46628 .25535 .47191 .26634 .48199 .26374 .47632 .25569 Metetra
.644 .696 .883 r
.47632 .25569 .48199 .26374 .49217 .25544 .48647 .2524 Metetra
.696 .897 .969 r
.48647 .2524 .49217 .25544 .50234 .25039 .49667 .24756 Metetra
.869 .909 .856 r
.49667 .24756 .50234 .25039 .51252 .24911 .50694 .23727 Metetra
.669 .623 .794 r
.50694 .23727 .51252 .24911 .52275 .2415 .51718 .23239 Metetra
.451 .574 .887 r
.51718 .23239 .52275 .2415 .53302 .24221 .52746 .23343 Metetra
.618 .668 .875 r
.52746 .23343 .53302 .24221 .54332 .23554 .5378 .23076 Metetra
.764 .847 .914 r
.5378 .23076 .54332 .23554 .55368 .2338 .54815 .22433 Metetra
.629 .656 .857 r
.54815 .22433 .55368 .2338 .56407 .2309 .55856 .22129 Metetra
.718 .691 .823 r
.55856 .22129 .56407 .2309 .57446 .2243 .56897 .21504 Metetra
.632 .663 .862 r
.56897 .21504 .57446 .2243 .58493 .22122 .57946 .21192 Metetra
.668 .679 .851 r
.57946 .21192 .58493 .22122 .59536 .21468 .58997 .20764 Metetra
.494 .668 .94 r
.58997 .20764 .59536 .21468 .60604 .21639 .60061 .20727 Metetra
.765 .722 .812 r
.60061 .20727 .60604 .21639 .61647 .20752 .61109 .19901 Metetra
.446 .593 .905 r
.61109 .19901 .61647 .20752 .62706 .20303 .62188 .19996 Metetra
.828 .928 .898 r
.62188 .19996 .62706 .20303 .63786 .20315 .6324 .19136 Metetra
.504 .543 .83 r
.6324 .19136 .63786 .20315 .64829 .19276 .64329 .19184 Metetra
.589 .938 .934 r
.64329 .19184 .64829 .19276 .6593 .19523 .65401 .18692 Metetra
.785 .753 .823 r
.65401 .18692 .6593 .19523 .67003 .19026 .66459 .17814 Metetra
.668 .626 .797 r
.66459 .17814 .67003 .19026 .6806 .1815 .67537 .1731 Metetra
.647 .701 .885 r
.67537 .1731 .6806 .1815 .69141 .17701 .68626 .16951 Metetra
.221 .495 .9 r
.68626 .16951 .69141 .17701 .70231 .17334 .69763 .17347 Metetra
.065 .629 .728 r
.69763 .17347 .70231 .17334 .71373 .17711 .70881 .17272 Metetra
.645 .851 .979 r
.70881 .17272 .71373 .17711 .72492 .17607 .71985 .16875 Metetra
.661 .745 .912 r
.71985 .16875 .72492 .17607 .73597 .17211 .73093 .16476 Metetra
.661 .745 .912 r
.73093 .16476 .73597 .17211 .74707 .16814 .74206 .16076 Metetra
.661 .745 .912 r
.74206 .16076 .74707 .16814 .75821 .16415 .75323 .15674 Metetra
.661 .745 .912 r
.75323 .15674 .75821 .16415 .76939 .16014 .76444 .15271 Metetra
.661 .745 .912 r
.11894 .37671 .12543 .38262 .13432 .37942 .12785 .37349 Metetra
.661 .745 .912 r
.12785 .37349 .13432 .37942 .14324 .37622 .13678 .37026 Metetra
.661 .745 .912 r
.13678 .37026 .14324 .37622 .15219 .37299 .14575 .36702 Metetra
.661 .745 .912 r
.14575 .36702 .15219 .37299 .16117 .36976 .15475 .36377 Metetra
.661 .745 .912 r
.15475 .36377 .16117 .36976 .17018 .36652 .16378 .3605 Metetra
.661 .745 .912 r
.16378 .3605 .17018 .36652 .18043 .35222 .17285 .35723 Metetra
.868 .992 .74 r
.17285 .35723 .18043 .35222 .18931 .35045 .18298 .34436 Metetra
.672 .746 .906 r
.18298 .34436 .18931 .35045 .198 .351 .19211 .3408 Metetra
.468 .542 .849 r
.19211 .3408 .198 .351 .20747 .34432 .2008 .34172 Metetra
.805 .885 .903 r
.2008 .34172 .20747 .34432 .21619 .34542 .21036 .33462 Metetra
.46 .524 .837 r
.21036 .33462 .21619 .34542 .22573 .3384 .21912 .33581 Metetra
.82 .885 .891 r
.21912 .33581 .22573 .3384 .23438 .34122 .22878 .32808 Metetra
.577 .544 .781 r
.22878 .32808 .23438 .34122 .2442 .33169 .23787 .32662 Metetra
.338 .657 .971 r
.23787 .32662 .2442 .33169 .25342 .32903 .2468 .32741 Metetra
.806 .927 .915 r
.2468 .32741 .25342 .32903 .26261 .32718 .25648 .32019 Metetra
.707 .732 .87 r
.25648 .32019 .26261 .32718 .27187 .32498 .26597 .3154 Metetra
.548 .601 .859 r
.26597 .3154 .27187 .32498 .28078 .32785 .27516 .31465 Metetra
.625 .57 .773 r
.27516 .31465 .28078 .32785 .2908 .31661 .28458 .31145 Metetra
.483 .724 .977 r
.28458 .31145 .2908 .31661 .30009 .31556 .29386 .31077 Metetra
.764 .818 .895 r
.29386 .31077 .30009 .31556 .30964 .31124 .30357 .30456 Metetra
.623 .721 .916 r
.30357 .30456 .30964 .31124 .31897 .31087 .31306 .30197 Metetra
.687 .68 .837 r
.31306 .30197 .31897 .31087 .32864 .30585 .32272 .29734 Metetra
.646 .675 .863 r
.32272 .29734 .32864 .30585 .33853 .29752 .33231 .2941 Metetra
.729 .872 .948 r
.33231 .2941 .33853 .29752 .34795 .29747 .34206 .28897 Metetra
.433 .578 .898 r
.34206 .28897 .34795 .29747 .35737 .29852 .35149 .29005 Metetra
.615 .666 .876 r
.35149 .29005 .35737 .29852 .36702 .29631 .36116 .28761 Metetra
.748 .708 .814 r
.36116 .28761 .36702 .29631 .37696 .28892 .37111 .28041 Metetra
.394 .558 .898 r
.37111 .28041 .37696 .28892 .38677 .28476 .38066 .28208 Metetra
.65 .89 .983 r
.38066 .28208 .38677 .28476 .39662 .28022 .39052 .27813 Metetra
.642 .91 .981 r
.39052 .27813 .39662 .28022 .40661 .27269 .40042 .27402 Metetra
.354 .826 .782 r
.40042 .27402 .40661 .27269 .41647 .26937 .41034 .27031 Metetra
.419 .866 .83 r
.41034 .27031 .41647 .26937 .42611 .2743 .42031 .26635 Metetra
.792 .742 .807 r
.42031 .26635 .42611 .2743 .43602 .27244 .43046 .25722 Metetra
.624 .55 .751 r
.43046 .25722 .43602 .27244 .44604 .26871 .44047 .25356 Metetra
.526 .496 .765 r
.44047 .25356 .44604 .26871 .45611 .26393 .45042 .25369 Metetra
.647 .642 .831 r
.45042 .25369 .45611 .26393 .46628 .25535 .46051 .25005 Metetra
.603 .777 .964 r
.46051 .25005 .46628 .25535 .47632 .25569 .47063 .24748 Metetra
.629 .687 .885 r
.47063 .24748 .47632 .25569 .48647 .2524 .48079 .24457 Metetra
.643 .704 .891 r
.48079 .24457 .48647 .2524 .49667 .24756 .49099 .2413 Metetra
.714 .78 .904 r
.49099 .2413 .49667 .24756 .50694 .23727 .50126 .2362 Metetra
.918 .943 .802 r
.50126 .2362 .50694 .23727 .51718 .23239 .51158 .22299 Metetra
.445 .564 .881 r
.51158 .22299 .51718 .23239 .52746 .23343 .52187 .22417 Metetra
.622 .658 .864 r
.52187 .22417 .52746 .23343 .5378 .23076 .53222 .22134 Metetra
.709 .691 .831 r
.53222 .22134 .5378 .23076 .54815 .22433 .5426 .21555 Metetra
.567 .646 .888 r
.5426 .21555 .54815 .22433 .55856 .22129 .55305 .2141 Metetra
0 .296 .79 r
.55305 .2141 .55856 .22129 .56897 .21504 .56365 .22105 Metetra
.697 .889 .512 r
.56365 .22105 .56897 .21504 .57946 .21192 .57402 .20619 Metetra
.382 .663 .969 r
.57402 .20619 .57946 .21192 .58997 .20764 .58466 .20685 Metetra
.877 .979 .837 r
.58466 .20685 .58997 .20764 .60061 .20727 .5951 .19575 Metetra
.659 .63 .809 r
.5951 .19575 .60061 .20727 .61109 .19901 .6057 .19128 Metetra
.612 .703 .909 r
.6057 .19128 .61109 .19901 .62188 .19996 .61639 .18865 Metetra
.69 .649 .805 r
.61639 .18865 .62188 .19996 .6324 .19136 .62704 .18296 Metetra
.461 .608 .91 r
.62704 .18296 .6324 .19136 .64329 .19184 .63794 .18355 Metetra
.782 .753 .826 r
.63794 .18355 .64329 .19184 .65401 .18692 .64854 .17494 Metetra
.621 .605 .813 r
.64854 .17494 .65401 .18692 .66459 .17814 .6594 .17178 Metetra
.44 .671 .961 r
.6594 .17178 .66459 .17814 .67537 .1731 .67046 .17194 Metetra
.61 .944 .94 r
.67046 .17194 .67537 .1731 .68626 .16951 .68132 .16678 Metetra
0 .523 .844 r
.68132 .16678 .68626 .16951 .69763 .17347 .69265 .16936 Metetra
.641 .86 .983 r
.69265 .16936 .69763 .17347 .70881 .17272 .70368 .16538 Metetra
.661 .745 .912 r
.70368 .16538 .70881 .17272 .71985 .16875 .71475 .16138 Metetra
.661 .745 .912 r
.71475 .16138 .71985 .16875 .73093 .16476 .72586 .15736 Metetra
.661 .745 .912 r
.72586 .15736 .73093 .16476 .74206 .16076 .73701 .15333 Metetra
.661 .745 .912 r
.73701 .15333 .74206 .16076 .75323 .15674 .74822 .14928 Metetra
.661 .745 .912 r
.74822 .14928 .75323 .15674 .76444 .15271 .75946 .14522 Metetra
.661 .745 .912 r
.11241 .37076 .11894 .37671 .12785 .37349 .12134 .36752 Metetra
.661 .745 .912 r
.12134 .36752 .12785 .37349 .13678 .37026 .13029 .36427 Metetra
.661 .745 .912 r
.13029 .36427 .13678 .37026 .14575 .36702 .13928 .36101 Metetra
.661 .745 .912 r
.13928 .36101 .14575 .36702 .15475 .36377 .14829 .35773 Metetra
.661 .745 .912 r
.14829 .35773 .15475 .36377 .16378 .3605 .15734 .35445 Metetra
.661 .745 .912 r
.15734 .35445 .16378 .3605 .17285 .35723 .16643 .35115 Metetra
.661 .745 .912 r
.16643 .35115 .17285 .35723 .18298 .34436 .17554 .34784 Metetra
.905 .983 .777 r
.17554 .34784 .18298 .34436 .19211 .3408 .18573 .33476 Metetra
.464 .676 .957 r
.18573 .33476 .19211 .3408 .2008 .34172 .19455 .33464 Metetra
.626 .702 .9 r
.19455 .33464 .2008 .34172 .21036 .33462 .20366 .3321 Metetra
.805 .89 .905 r
.20366 .3321 .21036 .33462 .21912 .33581 .21326 .32496 Metetra
.455 .522 .838 r
.21326 .32496 .21912 .33581 .22878 .32808 .22207 .32619 Metetra
.82 .912 .901 r
.22207 .32619 .22878 .32808 .23787 .32662 .23177 .31853 Metetra
.605 .666 .882 r
.23177 .31853 .23787 .32662 .2468 .32741 .24097 .31642 Metetra
.456 .521 .836 r
.24097 .31642 .2468 .32741 .25648 .32019 .24992 .31769 Metetra
.511 .843 .998 r
.24992 .31769 .25648 .32019 .26597 .3154 .2592 .31561 Metetra
.875 .962 .853 r
.2592 .31561 .26597 .3154 .27516 .31465 .2692 .30538 Metetra
.499 .587 .874 r
.2692 .30538 .27516 .31465 .28458 .31145 .27837 .30552 Metetra
.713 .771 .899 r
.27837 .30552 .28458 .31145 .29386 .31077 .28797 .30074 Metetra
.538 .588 .852 r
.28797 .30074 .29386 .31077 .30357 .30456 .29729 .30018 Metetra
.659 .819 .961 r
.29729 .30018 .30357 .30456 .31306 .30197 .30686 .29665 Metetra
.691 .791 .927 r
.30686 .29665 .31306 .30197 .32272 .29734 .31652 .29246 Metetra
.065 .504 .895 r
.31652 .29246 .32272 .29734 .33231 .2941 .32575 .29536 Metetra
.936 .949 .768 r
.32575 .29536 .33231 .2941 .34206 .28897 .33614 .28045 Metetra
.443 .584 .899 r
.33614 .28045 .34206 .28897 .35149 .29005 .34558 .28134 Metetra
.523 .619 .889 r
.34558 .28134 .35149 .29005 .36116 .28761 .35515 .2809 Metetra
.563 .703 .935 r
.35515 .2809 .36116 .28761 .37111 .28041 .36484 .2794 Metetra
.563 .914 .964 r
.36484 .2794 .37111 .28041 .38066 .28208 .37468 .27567 Metetra
.672 .754 .912 r
.37468 .27567 .38066 .28208 .39052 .27813 .38456 .27183 Metetra
.685 .762 .91 r
.38456 .27183 .39052 .27813 .40042 .27402 .39448 .26763 Metetra
.665 .754 .917 r
.39448 .26763 .40042 .27402 .41034 .27031 .40443 .26393 Metetra
.662 .754 .919 r
.40443 .26393 .41034 .27031 .42031 .26635 .4144 .26029 Metetra
.661 .766 .928 r
.4144 .26029 .42031 .26635 .43046 .25722 .42441 .25666 Metetra
.514 .905 .936 r
.42441 .25666 .43046 .25722 .44047 .25356 .43447 .25296 Metetra
.435 .867 .924 r
.43447 .25296 .44047 .25356 .45042 .25369 .44453 .25002 Metetra
.649 .859 .98 r
.44453 .25002 .45042 .25369 .46051 .25005 .45466 .24623 Metetra
.647 .853 .979 r
.45466 .24623 .46051 .25005 .47063 .24748 .46483 .24251 Metetra
.798 .838 .882 r
.46483 .24251 .47063 .24748 .48079 .24457 .4751 .23479 Metetra
.606 .637 .855 r
.4751 .23479 .48079 .24457 .49099 .2413 .48531 .23239 Metetra
.703 .7 .844 r
.48531 .23239 .49099 .2413 .50126 .2362 .49559 .22701 Metetra
.77 .717 .803 r
.49559 .22701 .50126 .2362 .51158 .22299 .50593 .21843 Metetra
.463 .753 .992 r
.50593 .21843 .51158 .22299 .52187 .22417 .51624 .21754 Metetra
.286 .57 .936 r
.51624 .21754 .52187 .22417 .53222 .22134 .52662 .21979 Metetra
.748 .962 .937 r
.52662 .21979 .53222 .22134 .5426 .21555 .53705 .21311 Metetra
.765 .938 .94 r
.53705 .21311 .5426 .21555 .55305 .2141 .54749 .20639 Metetra
.651 .718 .897 r
.54749 .20639 .55305 .2141 .56365 .22105 .55798 .2028 Metetra
.632 .53 .72 r
.55798 .2028 .56365 .22105 .57402 .20619 .5685 .19792 Metetra
.7 .721 .867 r
.5685 .19792 .57402 .20619 .58466 .20685 .57905 .19277 Metetra
.655 .587 .767 r
.57905 .19277 .58466 .20685 .5951 .19575 .58964 .18781 Metetra
.308 .537 .91 r
.58964 .18781 .5951 .19575 .6057 .19128 .60045 .19056 Metetra
.869 .985 .838 r
.60045 .19056 .6057 .19128 .61639 .18865 .61095 .17958 Metetra
.468 .592 .894 r
.61095 .17958 .61639 .18865 .62704 .18296 .62182 .1802 Metetra
.826 .941 .901 r
.62182 .1802 .62704 .18296 .63794 .18355 .63243 .17154 Metetra
.623 .606 .813 r
.63243 .17154 .63794 .18355 .64854 .17494 .64327 .16829 Metetra
.56 .722 .949 r
.64327 .16829 .64854 .17494 .6594 .17178 .65421 .16651 Metetra
.615 .801 .971 r
.65421 .16651 .6594 .17178 .67046 .17194 .66515 .16337 Metetra
.344 .539 .901 r
.66515 .16337 .67046 .17194 .68132 .16678 .67643 .16599 Metetra
.485 .896 .917 r
.67643 .16599 .68132 .16678 .69265 .16936 .68745 .16199 Metetra
.661 .745 .912 r
.68745 .16199 .69265 .16936 .70368 .16538 .6985 .15798 Metetra
.661 .745 .912 r
.6985 .15798 .70368 .16538 .71475 .16138 .7096 .15395 Metetra
.661 .745 .912 r
.7096 .15395 .71475 .16138 .72586 .15736 .72075 .1499 Metetra
.661 .745 .912 r
.72075 .1499 .72586 .15736 .73701 .15333 .73193 .14584 Metetra
.661 .745 .912 r
.73193 .14584 .73701 .15333 .74822 .14928 .74316 .14177 Metetra
.661 .745 .912 r
.74316 .14177 .74822 .14928 .75946 .14522 .75444 .13767 Metetra
.661 .745 .912 r
.10584 .36477 .11241 .37076 .12134 .36752 .11478 .36151 Metetra
.661 .745 .912 r
.11478 .36151 .12134 .36752 .13029 .36427 .12376 .35824 Metetra
.661 .745 .912 r
.12376 .35824 .13029 .36427 .13928 .36101 .13276 .35495 Metetra
.661 .745 .912 r
.13276 .35495 .13928 .36101 .14829 .35773 .14179 .35166 Metetra
.661 .745 .912 r
.14179 .35166 .14829 .35773 .15734 .35445 .15086 .34835 Metetra
.661 .745 .912 r
.15086 .34835 .15734 .35445 .16643 .35115 .15996 .34503 Metetra
.661 .745 .912 r
.15996 .34503 .16643 .35115 .17554 .34784 .16909 .3417 Metetra
.746 .762 .866 r
.16909 .3417 .17554 .34784 .18573 .33476 .17854 .3358 Metetra
.882 .966 .842 r
.17854 .3358 .18573 .33476 .19455 .33464 .18851 .32518 Metetra
.533 .596 .863 r
.18851 .32518 .19455 .33464 .20366 .3321 .19741 .32469 Metetra
.598 .684 .902 r
.19741 .32469 .20366 .3321 .21326 .32496 .20651 .32272 Metetra
.813 .901 .903 r
.20651 .32272 .21326 .32496 .22207 .32619 .21619 .31527 Metetra
.451 .52 .838 r
.21619 .31527 .22207 .32619 .23177 .31853 .22505 .31657 Metetra
.501 .858 .991 r
.22505 .31657 .23177 .31853 .24097 .31642 .23429 .31431 Metetra
.857 .896 .863 r
.23429 .31431 .24097 .31642 .24992 .31769 .24421 .30487 Metetra
.535 .529 .796 r
.24421 .30487 .24992 .31769 .2592 .31561 .25334 .30457 Metetra
.66 .624 .802 r
.25334 .30457 .2592 .31561 .2692 .30538 .26285 .3004 Metetra
.71 .805 .924 r
.26285 .3004 .2692 .30538 .27837 .30552 .27242 .29581 Metetra
.588 .62 .851 r
.27242 .29581 .27837 .30552 .28797 .30074 .2818 .29405 Metetra
.638 .728 .913 r
.2818 .29405 .28797 .30074 .29729 .30018 .29131 .29109 Metetra
.655 .665 .847 r
.29131 .29109 .29729 .30018 .30686 .29665 .3009 .28748 Metetra
.542 .614 .874 r
.3009 .28748 .30686 .29665 .31652 .29246 .31033 .28671 Metetra
.66 .77 .931 r
.31033 .28671 .31652 .29246 .32575 .29536 .31999 .28322 Metetra
.638 .598 .792 r
.31999 .28322 .32575 .29536 .33614 .28045 .32969 .2796 Metetra
.319 0 0 r
.32969 .2796 .33614 .28045 .34558 .28134 .33903 .28266 Metetra
.836 .996 .84 r
.33903 .28266 .34558 .28134 .35515 .2809 .34918 .2728 Metetra
.725 .718 .844 r
.34918 .2728 .35515 .2809 .36484 .2794 .35911 .26692 Metetra
.657 .604 .783 r
.35911 .26692 .36484 .2794 .37468 .27567 .36899 .26242 Metetra
.65 .589 .773 r
.36899 .26242 .37468 .27567 .38456 .27183 .3789 .25803 Metetra
.639 .576 .768 r
.3789 .25803 .38456 .27183 .39448 .26763 .38882 .25398 Metetra
.705 .612 .75 r
.38882 .25398 .39448 .26763 .40443 .26393 .39892 .24664 Metetra
.478 .441 .738 r
.39892 .24664 .40443 .26393 .4144 .26029 .40867 .24843 Metetra
.632 .604 .804 r
.40867 .24843 .4144 .26029 .42441 .25666 .41868 .24503 Metetra
.628 .606 .809 r
.41868 .24503 .42441 .25666 .43447 .25296 .42873 .2418 Metetra
.635 .619 .817 r
.42873 .2418 .43447 .25296 .44453 .25002 .43882 .23839 Metetra
.635 .611 .809 r
.43882 .23839 .44453 .25002 .45466 .24623 .44895 .23489 Metetra
.75 .668 .77 r
.44895 .23489 .45466 .24623 .46483 .24251 .45923 .22604 Metetra
.618 .536 .739 r
.45923 .22604 .46483 .24251 .4751 .23479 .46943 .22234 Metetra
.509 .531 .814 r
.46943 .22234 .4751 .23479 .48531 .23239 .4796 .22265 Metetra
.722 .689 .817 r
.4796 .22265 .48531 .23239 .49559 .22701 .48992 .21616 Metetra
.563 .593 .842 r
.48992 .21616 .49559 .22701 .50593 .21843 .50021 .21491 Metetra
.058 .551 .889 r
.50021 .21491 .50593 .21843 .51624 .21754 .51054 .2172 Metetra
.767 .988 .895 r
.51054 .2172 .51624 .21754 .52662 .21979 .52097 .20936 Metetra
.707 .671 .813 r
.52097 .20936 .52662 .21979 .53705 .21311 .53142 .20324 Metetra
.612 .642 .856 r
.53142 .20324 .53705 .21311 .54749 .20639 .5419 .20059 Metetra
.793 .822 .875 r
.5419 .20059 .54749 .20639 .55798 .2028 .55239 .19275 Metetra
.615 .64 .852 r
.55239 .19275 .55798 .2028 .5685 .19792 .56296 .18999 Metetra
.701 .733 .876 r
.56296 .18999 .5685 .19792 .57905 .19277 .57353 .18486 Metetra
.038 .363 .834 r
.57353 .18486 .57905 .19277 .58964 .18781 .58436 .191 Metetra
.819 .972 .667 r
.58436 .191 .58964 .18781 .60045 .19056 .59484 .17711 Metetra
.529 .53 .8 r
.59484 .17711 .60045 .19056 .61095 .17958 .60565 .17692 Metetra
.826 .944 .901 r
.60565 .17692 .61095 .17958 .62182 .1802 .61628 .16826 Metetra
.509 .547 .83 r
.61628 .16826 .62182 .1802 .63243 .17154 .62721 .16847 Metetra
.701 .916 .968 r
.62721 .16847 .63243 .17154 .64327 .16829 .63801 .16306 Metetra
.609 .801 .973 r
.63801 .16306 .64327 .16829 .65421 .16651 .64893 .16001 Metetra
.813 .817 .853 r
.64893 .16001 .65421 .16651 .66515 .16337 .65964 .15095 Metetra
.181 .337 .786 r
.65964 .15095 .66515 .16337 .67643 .16599 .67116 .1586 Metetra
.661 .745 .912 r
.67116 .1586 .67643 .16599 .68745 .16199 .68221 .15457 Metetra
.661 .745 .912 r
.68221 .15457 .68745 .16199 .6985 .15798 .69329 .15053 Metetra
.661 .745 .912 r
.69329 .15053 .6985 .15798 .7096 .15395 .70442 .14647 Metetra
.661 .745 .912 r
.70442 .14647 .7096 .15395 .72075 .1499 .7156 .14239 Metetra
.661 .745 .912 r
.7156 .14239 .72075 .1499 .73193 .14584 .72681 .1383 Metetra
.661 .745 .912 r
.72681 .1383 .73193 .14584 .74316 .14177 .73808 .1342 Metetra
.661 .745 .912 r
.73808 .1342 .74316 .14177 .75444 .13767 .74938 .13007 Metetra
.661 .745 .912 r
.09923 .35874 .10584 .36477 .11478 .36151 .10819 .35546 Metetra
.661 .745 .912 r
.10819 .35546 .11478 .36151 .12376 .35824 .11718 .35217 Metetra
.661 .745 .912 r
.11718 .35217 .12376 .35824 .13276 .35495 .1262 .34886 Metetra
.661 .745 .912 r
.1262 .34886 .13276 .35495 .14179 .35166 .13525 .34554 Metetra
.661 .745 .912 r
.13525 .34554 .14179 .35166 .15086 .34835 .14434 .34221 Metetra
.661 .745 .912 r
.14434 .34221 .15086 .34835 .15996 .34503 .15346 .33887 Metetra
.661 .745 .912 r
.15346 .33887 .15996 .34503 .16909 .3417 .16261 .33552 Metetra
.661 .745 .912 r
.16261 .33552 .16909 .3417 .17854 .3358 .17179 .33216 Metetra
.765 .851 .915 r
.17179 .33216 .17854 .3358 .18851 .32518 .18129 .3262 Metetra
.914 .944 .808 r
.18129 .3262 .18851 .32518 .19741 .32469 .19152 .31347 Metetra
.441 .508 .832 r
.19152 .31347 .19741 .32469 .20651 .32272 .20027 .31497 Metetra
.718 .714 .846 r
.20027 .31497 .20651 .32272 .21619 .31527 .20976 .30957 Metetra
.685 .771 .916 r
.20976 .30957 .21619 .31527 .22505 .31657 .21914 .30559 Metetra
.45 .52 .838 r
.21914 .30559 .22505 .31657 .23429 .31431 .22805 .30687 Metetra
.608 .691 .902 r
.22805 .30687 .23429 .31431 .24421 .30487 .23734 .30463 Metetra
.859 .956 .872 r
.23734 .30463 .24421 .30487 .25334 .30457 .24731 .2952 Metetra
.508 .591 .873 r
.24731 .2952 .25334 .30457 .26285 .3004 .25648 .29513 Metetra
.764 .803 .884 r
.25648 .29513 .26285 .3004 .27242 .29581 .26622 .28878 Metetra
.572 .693 .923 r
.26622 .28878 .27242 .29581 .2818 .29405 .27559 .28717 Metetra
.712 .744 .877 r
.27559 .28717 .2818 .29405 .29131 .29109 .28528 .28216 Metetra
.215 .444 .866 r
.28528 .28216 .29131 .29109 .3009 .28748 .29433 .286 Metetra
.829 .937 .898 r
.29433 .286 .3009 .28748 .31033 .28671 .30432 .27776 Metetra
.638 .664 .859 r
.30432 .27776 .31033 .28671 .31999 .28322 .31397 .27464 Metetra
.527 .627 .894 r
.31397 .27464 .31999 .28322 .32969 .2796 .32349 .27405 Metetra
.45 .7 .974 r
.32349 .27405 .32969 .2796 .33903 .28266 .33304 .27379 Metetra
.784 .717 .789 r
.33304 .27379 .33903 .28266 .34918 .2728 .34319 .26441 Metetra
.721 .711 .84 r
.34319 .26441 .34918 .2728 .35911 .26692 .35314 .25855 Metetra
.522 .633 .901 r
.35314 .25855 .35911 .26692 .36899 .26242 .36283 .258 Metetra
.68 .833 .956 r
.36283 .258 .36899 .26242 .3789 .25803 .37276 .25386 Metetra
.653 .837 .971 r
.37276 .25386 .3789 .25803 .38882 .25398 .38269 .25021 Metetra
.662 .856 .974 r
.38269 .25021 .38882 .25398 .39892 .24664 .39268 .24628 Metetra
.518 .909 .929 r
.39268 .24628 .39892 .24664 .40867 .24843 .40269 .24243 Metetra
.663 .772 .93 r
.40269 .24243 .40867 .24843 .41868 .24503 .41274 .23871 Metetra
.66 .76 .924 r
.41274 .23871 .41868 .24503 .42873 .2418 .42282 .23505 Metetra
.657 .745 .915 r
.42282 .23505 .42873 .2418 .43882 .23839 .43294 .23145 Metetra
.655 .739 .911 r
.43294 .23145 .43882 .23839 .44895 .23489 .44309 .22787 Metetra
.687 .748 .898 r
.44309 .22787 .44895 .23489 .45923 .22604 .4533 .22343 Metetra
.738 .922 .953 r
.4533 .22343 .45923 .22604 .46943 .22234 .46358 .21754 Metetra
.629 .812 .97 r
.46358 .21754 .46943 .22234 .4796 .22265 .47384 .21429 Metetra
.652 .697 .879 r
.47384 .21429 .4796 .22265 .48992 .21616 .48414 .21067 Metetra
.127 .521 .914 r
.48414 .21067 .48992 .21616 .50021 .21491 .49442 .21373 Metetra
.686 .958 .947 r
.49442 .21373 .50021 .21491 .51054 .2172 .50484 .20798 Metetra
.721 .704 .834 r
.50484 .20798 .51054 .2172 .52097 .20936 .51529 .20175 Metetra
.72 .747 .873 r
.51529 .20175 .52097 .20936 .53142 .20324 .52576 .19605 Metetra
.73 .763 .88 r
.52576 .19605 .53142 .20324 .5419 .20059 .53626 .19013 Metetra
.478 .561 .862 r
.53626 .19013 .5419 .20059 .55239 .19275 .54683 .19079 Metetra
.831 .958 .895 r
.54683 .19079 .55239 .19275 .56296 .18999 .55737 .18191 Metetra
.047 .365 .835 r
.55737 .18191 .56296 .18999 .57353 .18486 .56814 .18796 Metetra
.831 .977 .677 r
.56814 .18796 .57353 .18486 .58436 .191 .57865 .17395 Metetra
.533 .484 .748 r
.57865 .17395 .58436 .191 .59484 .17711 .58943 .17374 Metetra
.828 .919 .897 r
.58943 .17374 .59484 .17711 .60565 .17692 .60007 .16503 Metetra
.52 .555 .831 r
.60007 .16503 .60565 .17692 .61628 .16826 .61096 .1649 Metetra
.693 .903 .971 r
.61096 .1649 .61628 .16826 .62721 .16847 .62175 .15974 Metetra
.786 .747 .817 r
.62175 .15974 .62721 .16847 .63801 .16306 .63244 .15069 Metetra
.611 .596 .811 r
.63244 .15069 .63801 .16306 .64893 .16001 .64338 .14775 Metetra
.179 .34 .789 r
.64338 .14775 .64893 .16001 .65964 .15095 .65483 .15519 Metetra
.65483 .15519 .65964 .15095 .67116 .1586 .66586 .15115 Metetra
.661 .745 .912 r
.66586 .15115 .67116 .1586 .68221 .15457 .67693 .14709 Metetra
.661 .745 .912 r
.67693 .14709 .68221 .15457 .69329 .15053 .68804 .14302 Metetra
.661 .745 .912 r
.68804 .14302 .69329 .15053 .70442 .14647 .6992 .13893 Metetra
.661 .745 .912 r
.6992 .13893 .70442 .14647 .7156 .14239 .71041 .13483 Metetra
.661 .745 .912 r
.71041 .13483 .7156 .14239 .72681 .1383 .72166 .13071 Metetra
.661 .745 .912 r
.72166 .13071 .72681 .1383 .73808 .1342 .73295 .12657 Metetra
.661 .745 .912 r
.73295 .12657 .73808 .1342 .74938 .13007 .74429 .12242 Metetra
.661 .745 .912 r
.09257 .35267 .09923 .35874 .10819 .35546 .10155 .34937 Metetra
.661 .745 .912 r
.10155 .34937 .10819 .35546 .11718 .35217 .11056 .34605 Metetra
.661 .745 .912 r
.11056 .34605 .11718 .35217 .1262 .34886 .1196 .34273 Metetra
.661 .745 .912 r
.1196 .34273 .1262 .34886 .13525 .34554 .12867 .33939 Metetra
.661 .745 .912 r
.12867 .33939 .13525 .34554 .14434 .34221 .13777 .33604 Metetra
.661 .745 .912 r
.13777 .33604 .14434 .34221 .15346 .33887 .14691 .33268 Metetra
.661 .745 .912 r
.14691 .33268 .15346 .33887 .16261 .33552 .15608 .3293 Metetra
.661 .745 .912 r
.15608 .3293 .16261 .33552 .17179 .33216 .16528 .32591 Metetra
.661 .745 .912 r
.16528 .32591 .17179 .33216 .18129 .3262 .17451 .32252 Metetra
.888 .816 .771 r
.17451 .32252 .18129 .3262 .19152 .31347 .18497 .30817 Metetra
.27 .616 .958 r
.18497 .30817 .19152 .31347 .20027 .31497 .19374 .30952 Metetra
.695 .782 .918 r
.19374 .30952 .20027 .31497 .20976 .30957 .20313 .30531 Metetra
.742 .833 .921 r
.20313 .30531 .20976 .30957 .21914 .30559 .21268 .29993 Metetra
.696 .776 .913 r
.21268 .29993 .21914 .30559 .22805 .30687 .22213 .29565 Metetra
.442 .512 .835 r
.22213 .29565 .22805 .30687 .23734 .30463 .23108 .29708 Metetra
.606 .689 .901 r
.23108 .29708 .23734 .30463 .24731 .2952 .24042 .29485 Metetra
.849 .958 .88 r
.24042 .29485 .24731 .2952 .25648 .29513 .25041 .28577 Metetra
.293 .479 .87 r
.25041 .28577 .25648 .29513 .26622 .28878 .25937 .28882 Metetra
.856 .968 .87 r
.25937 .28882 .26622 .28878 .27559 .28717 .26943 .27932 Metetra
.39 .582 .918 r
.26943 .27932 .27559 .28717 .28528 .28216 .27863 .2806 Metetra
.824 .935 .903 r
.27863 .2806 .28528 .28216 .29433 .286 .28861 .27256 Metetra
.638 .579 .772 r
.28861 .27256 .29433 .286 .30432 .27776 .29829 .26866 Metetra
.471 .585 .886 r
.29829 .26866 .30432 .27776 .31397 .27464 .3077 .26913 Metetra
.696 .791 .924 r
.3077 .26913 .31397 .27464 .32349 .27405 .31749 .26474 Metetra
.499 .594 .88 r
.31749 .26474 .32349 .27405 .33304 .27379 .32703 .26476 Metetra
.708 .692 .832 r
.32703 .26476 .33304 .27379 .34319 .26441 .33697 .25919 Metetra
.769 .817 .89 r
.33697 .25919 .34319 .26441 .35314 .25855 .34699 .25257 Metetra
.667 .771 .927 r
.34699 .25257 .35314 .25855 .36283 .258 .35688 .24881 Metetra
.669 .676 .848 r
.35688 .24881 .36283 .258 .37276 .25386 .36682 .24462 Metetra
.645 .665 .855 r
.36682 .24462 .37276 .25386 .38269 .25021 .37676 .24116 Metetra
.537 .623 .885 r
.37676 .24116 .38269 .25021 .39268 .24628 .38662 .24036 Metetra
.661 .775 .933 r
.38662 .24036 .39268 .24628 .40269 .24243 .39665 .23667 Metetra
.668 .783 .935 r
.39665 .23667 .40269 .24243 .41274 .23871 .40673 .23281 Metetra
.35 .641 .963 r
.40673 .23281 .41274 .23871 .42282 .23505 .41667 .23377 Metetra
.885 .946 .845 r
.41667 .23377 .42282 .23505 .43294 .23145 .42707 .22268 Metetra
.658 .687 .866 r
.42707 .22268 .43294 .23145 .44309 .22787 .43725 .21883 Metetra
.652 .678 .862 r
.43725 .21883 .44309 .22787 .4533 .22343 .44746 .21511 Metetra
.652 .698 .88 r
.44746 .21511 .4533 .22343 .46358 .21754 .45771 .21149 Metetra
.348 .634 .96 r
.45771 .21149 .46358 .21754 .47384 .21429 .46792 .21256 Metetra
.886 .942 .845 r
.46792 .21256 .47384 .21429 .48414 .21067 .47838 .20138 Metetra
.572 .638 .878 r
.47838 .20138 .48414 .21067 .49442 .21373 .48872 .19975 Metetra
.255 .353 .772 r
.48872 .19975 .49442 .21373 .50484 .20798 .49904 .20605 Metetra
.927 .918 .786 r
.49904 .20605 .50484 .20798 .51529 .20175 .50958 .19158 Metetra
.651 .655 .841 r
.50958 .19158 .51529 .20175 .52576 .19605 .52007 .18764 Metetra
.697 .719 .866 r
.52007 .18764 .52576 .19605 .53626 .19013 .53059 .18253 Metetra
.64 .721 .907 r
.53059 .18253 .53626 .19013 .54683 .19079 .54116 .17916 Metetra
.222 .381 .812 r
.54116 .17916 .54683 .19079 .55737 .18191 .55185 .18499 Metetra
.84 .979 .683 r
.55185 .18499 .55737 .18191 .56814 .18796 .56241 .17084 Metetra
.534 .485 .747 r
.56241 .17084 .56814 .18796 .57865 .17395 .57315 .17053 Metetra
.825 .917 .899 r
.57315 .17053 .57865 .17395 .58943 .17374 .58381 .16193 Metetra
.524 .56 .834 r
.58381 .16193 .58943 .17374 .60007 .16503 .59466 .16164 Metetra
.679 .898 .975 r
.59466 .16164 .60007 .16503 .61096 .1649 .60546 .15676 Metetra
.756 .754 .85 r
.60546 .15676 .61096 .1649 .62175 .15974 .61621 .14942 Metetra
.328 .482 .861 r
.61621 .14942 .62175 .15974 .63244 .15069 .62736 .15293 Metetra
.073 0 0 r
.62736 .15293 .63244 .15069 .64338 .14775 .63844 .15177 Metetra
.63844 .15177 .64338 .14775 .65483 .15519 .64945 .14772 Metetra
.661 .745 .912 r
.64945 .14772 .65483 .15519 .66586 .15115 .66051 .14365 Metetra
.661 .745 .912 r
.66051 .14365 .66586 .15115 .67693 .14709 .67161 .13956 Metetra
.661 .745 .912 r
.67161 .13956 .67693 .14709 .68804 .14302 .68276 .13546 Metetra
.661 .745 .912 r
.68276 .13546 .68804 .14302 .6992 .13893 .69395 .13134 Metetra
.661 .745 .912 r
.69395 .13134 .6992 .13893 .71041 .13483 .70518 .12721 Metetra
.661 .745 .912 r
.70518 .12721 .71041 .13483 .72166 .13071 .71646 .12306 Metetra
.661 .745 .912 r
.71646 .12306 .72166 .13071 .73295 .12657 .72779 .11889 Metetra
.661 .745 .912 r
.72779 .11889 .73295 .12657 .74429 .12242 .73916 .1147 Metetra
.661 .745 .912 r
.08587 .34657 .09257 .35267 .10155 .34937 .09487 .34324 Metetra
.661 .745 .912 r
.09487 .34324 .10155 .34937 .11056 .34605 .10389 .3399 Metetra
.661 .745 .912 r
.10389 .3399 .11056 .34605 .1196 .34273 .11295 .33655 Metetra
.661 .745 .912 r
.11295 .33655 .1196 .34273 .12867 .33939 .12204 .33319 Metetra
.661 .745 .912 r
.12204 .33319 .12867 .33939 .13777 .33604 .13116 .32982 Metetra
.661 .745 .912 r
.13116 .32982 .13777 .33604 .14691 .33268 .14031 .32644 Metetra
.661 .745 .912 r
.14031 .32644 .14691 .33268 .15608 .3293 .1495 .32304 Metetra
.661 .745 .912 r
.1495 .32304 .15608 .3293 .16528 .32591 .15872 .31963 Metetra
.661 .745 .912 r
.15872 .31963 .16528 .32591 .17451 .32252 .16798 .31621 Metetra
.661 .745 .912 r
.16798 .31621 .17451 .32252 .18497 .30817 .17727 .31277 Metetra
.91 .982 .742 r
.17727 .31277 .18497 .30817 .19374 .30952 .18779 .29818 Metetra
.437 .506 .832 r
.18779 .29818 .19374 .30952 .20313 .30531 .19659 .29968 Metetra
.595 .752 .952 r
.19659 .29968 .20313 .30531 .21268 .29993 .20583 .29748 Metetra
.852 .886 .862 r
.20583 .29748 .21268 .29993 .22213 .29565 .21583 .28807 Metetra
.608 .689 .9 r
.21583 .28807 .22213 .29565 .23108 .29708 .22514 .28579 Metetra
.423 .501 .835 r
.22514 .28579 .23108 .29708 .24042 .29485 .23411 .28755 Metetra
.8 .748 .805 r
.23411 .28755 .24042 .29485 .25041 .28577 .24416 .27815 Metetra
.601 .687 .903 r
.24416 .27815 .25041 .28577 .25937 .28882 .25357 .27599 Metetra
.469 .497 .804 r
.25357 .27599 .25937 .28882 .26943 .27932 .26274 .27717 Metetra
.809 .917 .911 r
.26274 .27717 .26943 .27932 .27863 .2806 .27268 .26968 Metetra
.666 .634 .808 r
.27268 .26968 .27863 .2806 .28861 .27256 .28239 .26523 Metetra
.572 .688 .919 r
.28239 .26523 .28861 .27256 .29829 .26866 .29192 .26358 Metetra
.709 .81 .928 r
.29192 .26358 .29829 .26866 .3077 .26913 .30172 .25887 Metetra
.554 .598 .852 r
.30172 .25887 .3077 .26913 .31749 .26474 .31129 .25781 Metetra
.356 .602 .941 r
.31129 .25781 .31749 .26474 .32703 .26476 .32076 .25911 Metetra
.835 .804 .821 r
.32076 .25911 .32703 .26476 .33697 .25919 .33102 .24888 Metetra
.693 .66 .813 r
.33102 .24888 .33697 .25919 .34699 .25257 .34099 .24347 Metetra
.246 .463 .872 r
.34099 .24347 .34699 .25257 .35688 .24881 .35047 .24707 Metetra
.836 .938 .893 r
.35047 .24707 .35688 .24881 .36682 .24462 .36069 .23837 Metetra
.635 .754 .934 r
.36069 .23837 .36682 .24462 .37676 .24116 .37063 .23527 Metetra
.641 .77 .942 r
.37063 .23527 .37676 .24116 .38662 .24036 .38062 .23201 Metetra
.477 .617 .91 r
.38062 .23201 .38662 .24036 .39665 .23667 .39051 .23214 Metetra
.836 .85 .856 r
.39051 .23214 .39665 .23667 .40673 .23281 .40084 .22276 Metetra
.585 .623 .856 r
.40084 .22276 .40673 .23281 .41667 .23377 .4109 .22085 Metetra
.663 .606 .781 r
.4109 .22085 .41667 .23377 .42707 .22268 .4211 .21588 Metetra
.615 .732 .93 r
.4211 .21588 .42707 .22268 .43725 .21883 .43127 .21317 Metetra
.407 .683 .974 r
.43127 .21317 .43725 .21883 .44746 .21511 .44141 .21333 Metetra
.891 .935 .838 r
.44141 .21333 .44746 .21511 .45771 .21149 .45189 .20178 Metetra
.634 .656 .854 r
.45189 .20178 .45771 .21149 .46792 .21256 .46219 .19849 Metetra
.6 .558 .779 r
.46219 .19849 .46792 .21256 .47838 .20138 .47252 .19581 Metetra
.664 .799 .947 r
.47252 .19581 .47838 .20138 .48872 .19975 .48291 .19188 Metetra
.456 .626 .926 r
.48291 .19188 .48872 .19975 .49904 .20605 .4933 .19219 Metetra
.695 .612 .76 r
.4933 .19219 .49904 .20605 .50958 .19158 .50381 .18526 Metetra
.721 .791 .907 r
.50381 .18526 .50958 .19158 .52007 .18764 .51433 .17979 Metetra
.702 .738 .879 r
.51433 .17979 .52007 .18764 .53059 .18253 .52489 .17462 Metetra
.653 .719 .896 r
.52489 .17462 .53059 .18253 .54116 .17916 .53548 .17087 Metetra
.461 .617 .917 r
.53548 .17087 .54116 .17916 .55185 .18499 .54614 .17121 Metetra
.729 .632 .75 r
.54614 .17121 .55185 .18499 .56241 .17084 .55677 .16228 Metetra
.644 .698 .885 r
.55677 .16228 .56241 .17084 .57315 .17053 .56749 .15868 Metetra
.533 .564 .833 r
.56749 .15868 .57315 .17053 .58381 .16193 .5783 .15813 Metetra
.812 .906 .905 r
.5783 .15813 .58381 .16193 .59466 .16164 .58902 .14992 Metetra
.638 .623 .818 r
.58902 .14992 .59466 .16164 .60546 .15676 .59986 .14606 Metetra
.336 .479 .855 r
.59986 .14606 .60546 .15676 .61621 .14942 .61095 .14951 Metetra
.118 .67 .757 r
.61095 .14951 .61621 .14942 .62736 .15293 .62199 .14834 Metetra
.649 .847 .976 r
.62199 .14834 .62736 .15293 .63844 .15177 .63299 .14428 Metetra
.661 .745 .912 r
.63299 .14428 .63844 .15177 .64945 .14772 .64404 .14019 Metetra
.661 .745 .912 r
.64404 .14019 .64945 .14772 .66051 .14365 .65513 .13609 Metetra
.661 .745 .912 r
.65513 .13609 .66051 .14365 .67161 .13956 .66626 .13198 Metetra
.661 .745 .912 r
.66626 .13198 .67161 .13956 .68276 .13546 .67743 .12784 Metetra
.661 .745 .912 r
.67743 .12784 .68276 .13546 .69395 .13134 .68865 .1237 Metetra
.661 .745 .912 r
.68865 .1237 .69395 .13134 .70518 .12721 .69992 .11953 Metetra
.661 .745 .912 r
.69992 .11953 .70518 .12721 .71646 .12306 .71123 .11535 Metetra
.661 .745 .912 r
.71123 .11535 .71646 .12306 .72779 .11889 .72259 .11115 Metetra
.661 .745 .912 r
.72259 .11115 .72779 .11889 .73916 .1147 .73399 .10694 Metetra
.661 .745 .912 r
.07913 .34042 .08587 .34657 .09487 .34324 .08814 .33707 Metetra
.661 .745 .912 r
.08814 .33707 .09487 .34324 .10389 .3399 .09718 .33371 Metetra
.661 .745 .912 r
.09718 .33371 .10389 .3399 .11295 .33655 .10626 .33034 Metetra
.661 .745 .912 r
.10626 .33034 .11295 .33655 .12204 .33319 .11536 .32696 Metetra
.661 .745 .912 r
.11536 .32696 .12204 .33319 .13116 .32982 .12451 .32356 Metetra
.661 .745 .912 r
.12451 .32356 .13116 .32982 .14031 .32644 .13368 .32015 Metetra
.661 .745 .912 r
.13368 .32015 .14031 .32644 .1495 .32304 .14288 .31674 Metetra
.661 .745 .912 r
.14288 .31674 .1495 .32304 .15872 .31963 .15212 .3133 Metetra
.661 .745 .912 r
.15212 .3133 .15872 .31963 .16798 .31621 .1614 .30986 Metetra
.661 .745 .912 r
.1614 .30986 .16798 .31621 .17727 .31277 .1707 .3064 Metetra
.661 .745 .912 r
.1707 .3064 .17727 .31277 .18779 .29818 .18004 .30293 Metetra
.18004 .30293 .18779 .29818 .19659 .29968 .18942 .29945 Metetra
.862 .951 .869 r
.18942 .29945 .19659 .29968 .20583 .29748 .19947 .28982 Metetra
.772 .734 .817 r
.19947 .28982 .20583 .29748 .21583 .28807 .20934 .28189 Metetra
.649 .75 .923 r
.20934 .28189 .21583 .28807 .22514 .28579 .21876 .27867 Metetra
.407 .619 .938 r
.21876 .27867 .22514 .28579 .23411 .28755 .22783 .2794 Metetra
.758 .722 .82 r
.22783 .2794 .23411 .28755 .24416 .27815 .23772 .272 Metetra
.671 .76 .917 r
.23772 .272 .24416 .27815 .25357 .27599 .24729 .26822 Metetra
.58 .676 .906 r
.24729 .26822 .25357 .27599 .26274 .27717 .25672 .26646 Metetra
.467 .542 .85 r
.25672 .26646 .26274 .27717 .27268 .26968 .26598 .26726 Metetra
.807 .91 .911 r
.26598 .26726 .27268 .26968 .28239 .26523 .27597 .25979 Metetra
.756 .805 .892 r
.27597 .25979 .28239 .26523 .29192 .26358 .28587 .2536 Metetra
.256 .443 .853 r
.28587 .2536 .29192 .26358 .30172 .25887 .29505 .25734 Metetra
.797 .944 .921 r
.29505 .25734 .30172 .25887 .31129 .25781 .30511 .25 Metetra
.527 .656 .917 r
.30511 .25 .31129 .25781 .32076 .25911 .31473 .24917 Metetra
.582 .621 .856 r
.31473 .24917 .32076 .25911 .33102 .24888 .32446 .24738 Metetra
.863 .936 .869 r
.32446 .24738 .33102 .24888 .34099 .24347 .33475 .23752 Metetra
.677 .777 .926 r
.33475 .23752 .34099 .24347 .35047 .24707 .34469 .23347 Metetra
.564 .542 .788 r
.34469 .23347 .35047 .24707 .36069 .23837 .35451 .2321 Metetra
0 .294 .771 r
.35451 .2321 .36069 .23837 .37063 .23527 .36401 .23783 Metetra
.896 .988 .759 r
.36401 .23783 .37063 .23527 .38062 .23201 .37457 .22413 Metetra
.736 .737 .852 r
.37457 .22413 .38062 .23201 .39051 .23214 .38476 .21781 Metetra
.622 .564 .769 r
.38476 .21781 .39051 .23214 .40084 .22276 .39486 .21425 Metetra
.632 .685 .882 r
.39486 .21425 .40084 .22276 .4109 .22085 .40497 .21114 Metetra
.219 .431 .855 r
.40497 .21114 .4109 .22085 .4211 .21588 .41486 .21548 Metetra
.84 .981 .873 r
.41486 .21548 .4211 .21588 .43127 .21317 .4253 .20597 Metetra
.725 .758 .879 r
.4253 .20597 .43127 .21317 .44141 .21333 .43562 .20025 Metetra
.644 .596 .786 r
.43562 .20025 .44141 .21333 .45189 .20178 .44593 .19598 Metetra
.396 .674 .972 r
.44593 .19598 .45189 .20178 .46219 .19849 .45618 .19629 Metetra
.839 .941 .89 r
.45618 .19629 .46219 .19849 .47252 .19581 .46667 .18724 Metetra
.634 .689 .884 r
.46667 .18724 .47252 .19581 .48291 .19188 .47707 .184 Metetra
.051 .382 .845 r
.47707 .184 .48291 .19188 .4933 .19219 .48741 .18941 Metetra
.92 .899 .789 r
.48741 .18941 .4933 .19219 .50381 .18526 .49804 .17506 Metetra
.625 .646 .85 r
.49804 .17506 .50381 .18526 .51433 .17979 .50856 .1719 Metetra
.658 .722 .896 r
.50856 .1719 .51433 .17979 .52489 .17462 .51914 .16799 Metetra
.432 .663 .958 r
.51914 .16799 .52489 .17462 .53548 .17087 .52977 .16817 Metetra
.84 .936 .89 r
.52977 .16817 .53548 .17087 .54614 .17121 .54041 .15896 Metetra
.668 .627 .799 r
.54041 .15896 .54614 .17121 .55677 .16228 .5511 .15384 Metetra
.671 .714 .881 r
.5511 .15384 .55677 .16228 .56749 .15868 .56183 .14946 Metetra
.608 .666 .88 r
.56183 .14946 .56749 .15868 .5783 .15813 .57262 .14678 Metetra
.644 .634 .825 r
.57262 .14678 .5783 .15813 .58902 .14992 .58344 .14278 Metetra
0 .351 .825 r
.58344 .14278 .58902 .14992 .59986 .14606 .59455 .14897 Metetra
.59455 .14897 .59986 .14606 .61095 .14951 .60549 .1449 Metetra
.649 .847 .976 r
.60549 .1449 .61095 .14951 .62199 .14834 .61648 .14082 Metetra
.661 .745 .912 r
.61648 .14082 .62199 .14834 .63299 .14428 .62751 .13672 Metetra
.661 .745 .912 r
.62751 .13672 .63299 .14428 .64404 .14019 .63858 .13261 Metetra
.661 .745 .912 r
.63858 .13261 .64404 .14019 .65513 .13609 .6497 .12848 Metetra
.661 .745 .912 r
.6497 .12848 .65513 .13609 .66626 .13198 .66086 .12434 Metetra
.661 .745 .912 r
.66086 .12434 .66626 .13198 .67743 .12784 .67207 .12017 Metetra
.661 .745 .912 r
.67207 .12017 .67743 .12784 .68865 .1237 .68332 .11599 Metetra
.661 .745 .912 r
.68332 .11599 .68865 .1237 .69992 .11953 .69462 .1118 Metetra
.661 .745 .912 r
.69462 .1118 .69992 .11953 .71123 .11535 .70596 .10758 Metetra
.661 .745 .912 r
.70596 .10758 .71123 .11535 .72259 .11115 .71735 .10336 Metetra
.661 .745 .912 r
.71735 .10336 .72259 .11115 .73399 .10694 .72878 .09911 Metetra
.661 .745 .912 r
.07234 .33423 .07913 .34042 .08814 .33707 .08137 .33086 Metetra
.661 .745 .912 r
.08137 .33086 .08814 .33707 .09718 .33371 .09043 .32748 Metetra
.661 .745 .912 r
.09043 .32748 .09718 .33371 .10626 .33034 .09952 .32409 Metetra
.661 .745 .912 r
.09952 .32409 .10626 .33034 .11536 .32696 .10865 .32068 Metetra
.661 .745 .912 r
.10865 .32068 .11536 .32696 .12451 .32356 .11781 .31726 Metetra
.661 .745 .912 r
.11781 .31726 .12451 .32356 .13368 .32015 .127 .31383 Metetra
.661 .745 .912 r
.127 .31383 .13368 .32015 .14288 .31674 .13622 .31039 Metetra
.661 .745 .912 r
.13622 .31039 .14288 .31674 .15212 .3133 .14548 .30693 Metetra
.661 .745 .912 r
.14548 .30693 .15212 .3133 .1614 .30986 .15477 .30347 Metetra
.661 .745 .912 r
.15477 .30347 .1614 .30986 .1707 .3064 .1641 .29999 Metetra
.661 .745 .912 r
.1641 .29999 .1707 .3064 .18004 .30293 .17346 .29649 Metetra
.661 .745 .912 r
.17346 .29649 .18004 .30293 .18942 .29945 .18285 .29299 Metetra
.661 .745 .912 r
.18285 .29299 .18942 .29945 .19947 .28982 .19228 .28947 Metetra
.749 .966 .933 r
.19228 .28947 .19947 .28982 .20934 .28189 .20204 .28309 Metetra
.876 .977 .84 r
.20204 .28309 .20934 .28189 .21876 .27867 .21226 .27233 Metetra
.662 .751 .916 r
.21226 .27233 .21876 .27867 .22783 .2794 .22176 .26877 Metetra
.464 .542 .852 r
.22176 .26877 .22783 .2794 .23772 .272 .23089 .26955 Metetra
.8 .907 .915 r
.23089 .26955 .23772 .272 .24729 .26822 .2408 .26236 Metetra
.679 .774 .923 r
.2408 .26236 .24729 .26822 .25672 .26646 .25045 .25838 Metetra
.365 .566 .914 r
.25045 .25838 .25672 .26646 .26598 .26726 .25965 .25993 Metetra
.779 .751 .828 r
.25965 .25993 .26598 .26726 .27597 .25979 .26971 .25189 Metetra
.512 .646 .917 r
.26971 .25189 .27597 .25979 .28587 .2536 .27918 .25133 Metetra
.789 .92 .925 r
.27918 .25133 .28587 .2536 .29505 .25734 .2892 .24435 Metetra
.591 .565 .793 r
.2892 .24435 .29505 .25734 .30511 .25 .29889 .24215 Metetra
.36 .573 .921 r
.29889 .24215 .30511 .25 .31473 .24917 .30835 .2437 Metetra
.827 .812 .836 r
.30835 .2437 .31473 .24917 .32446 .24738 .31863 .2341 Metetra
.643 .589 .778 r
.31863 .2341 .32446 .24738 .33475 .23752 .32857 .2299 Metetra
.56 .68 .919 r
.32857 .2299 .33475 .23752 .34469 .23347 .33837 .2284 Metetra
.462 .734 .986 r
.33837 .2284 .34469 .23347 .35451 .2321 .34818 .22765 Metetra
.835 .85 .858 r
.34818 .22765 .35451 .2321 .36401 .23783 .35851 .21834 Metetra
.604 .501 .71 r
.35851 .21834 .36401 .23783 .37457 .22413 .36856 .21461 Metetra
.572 .631 .872 r
.36856 .21461 .37457 .22413 .38476 .21781 .37855 .21298 Metetra
.66 .821 .961 r
.37855 .21298 .38476 .21781 .39486 .21425 .38868 .20915 Metetra
.439 .724 .986 r
.38868 .20915 .39486 .21425 .40497 .21114 .39872 .20865 Metetra
.849 .922 .88 r
.39872 .20865 .40497 .21114 .41486 .21548 .40915 .19927 Metetra
.455 .445 .758 r
.40915 .19927 .41486 .21548 .4253 .20597 .41919 .2013 Metetra
.776 .854 .909 r
.41919 .2013 .4253 .20597 .43562 .20025 .42958 .19441 Metetra
.449 .701 .974 r
.42958 .19441 .43562 .20025 .44593 .19598 .43982 .19406 Metetra
.888 .935 .842 r
.43982 .19406 .44593 .19598 .45618 .19629 .45038 .18264 Metetra
.609 .571 .786 r
.45038 .18264 .45618 .19629 .46667 .18724 .46076 .17962 Metetra
.348 .58 .929 r
.46076 .17962 .46667 .18724 .47707 .184 .4711 .18131 Metetra
.706 .921 .966 r
.4711 .18131 .47707 .184 .48741 .18941 .48162 .17585 Metetra
.694 .618 .766 r
.48162 .17585 .48741 .18941 .49804 .17506 .49218 .16904 Metetra
.732 .807 .911 r
.49218 .16904 .49804 .17506 .50856 .1719 .50276 .16325 Metetra
.653 .699 .88 r
.50276 .16325 .50856 .1719 .51914 .16799 .51336 .1594 Metetra
.482 .622 .912 r
.51336 .1594 .51914 .16799 .52977 .16817 .524 .15938 Metetra
.769 .739 .825 r
.524 .15938 .52977 .16817 .54041 .15896 .53468 .15109 Metetra
.676 .734 .894 r
.53468 .15109 .54041 .15896 .5511 .15384 .5454 .14663 Metetra
.424 .64 .946 r
.5454 .14663 .5511 .15384 .56183 .14946 .55621 .14711 Metetra
.839 .952 .89 r
.55621 .14711 .56183 .14946 .57262 .14678 .56695 .13778 Metetra
0 .283 .785 r
.56695 .13778 .57262 .14678 .58344 .14278 .57801 .14553 Metetra
.57801 .14553 .58344 .14278 .59455 .14897 .58894 .14145 Metetra
.661 .745 .912 r
.58894 .14145 .59455 .14897 .60549 .1449 .59991 .13736 Metetra
.661 .745 .912 r
.59991 .13736 .60549 .1449 .61648 .14082 .61093 .13324 Metetra
.661 .745 .912 r
.61093 .13324 .61648 .14082 .62751 .13672 .62199 .12912 Metetra
.661 .745 .912 r
.62199 .12912 .62751 .13672 .63858 .13261 .63309 .12497 Metetra
.661 .745 .912 r
.63309 .12497 .63858 .13261 .6497 .12848 .64424 .12081 Metetra
.661 .745 .912 r
.64424 .12081 .6497 .12848 .66086 .12434 .65543 .11664 Metetra
.661 .745 .912 r
.65543 .11664 .66086 .12434 .67207 .12017 .66667 .11244 Metetra
.661 .745 .912 r
.66667 .11244 .67207 .12017 .68332 .11599 .67795 .10823 Metetra
.661 .745 .912 r
.67795 .10823 .68332 .11599 .69462 .1118 .68928 .10401 Metetra
.661 .745 .912 r
.68928 .10401 .69462 .1118 .70596 .10758 .70065 .09976 Metetra
.661 .745 .912 r
.70065 .09976 .70596 .10758 .71735 .10336 .71207 .0955 Metetra
.661 .745 .912 r
.71207 .0955 .71735 .10336 .72878 .09911 .72353 .09122 Metetra
.661 .745 .912 r
.06551 .328 .07234 .33423 .08137 .33086 .07455 .32461 Metetra
.661 .745 .912 r
.07455 .32461 .08137 .33086 .09043 .32748 .08363 .3212 Metetra
.661 .745 .912 r
.08363 .3212 .09043 .32748 .09952 .32409 .09274 .31779 Metetra
.661 .745 .912 r
.09274 .31779 .09952 .32409 .10865 .32068 .10189 .31436 Metetra
.661 .745 .912 r
.10189 .31436 .10865 .32068 .11781 .31726 .11106 .31092 Metetra
.661 .745 .912 r
.11106 .31092 .11781 .31726 .127 .31383 .12027 .30747 Metetra
.661 .745 .912 r
.12027 .30747 .127 .31383 .13622 .31039 .12952 .304 Metetra
.661 .745 .912 r
.12952 .304 .13622 .31039 .14548 .30693 .13879 .30052 Metetra
.661 .745 .912 r
.13879 .30052 .14548 .30693 .15477 .30347 .14811 .29703 Metetra
.661 .745 .912 r
.14811 .29703 .15477 .30347 .1641 .29999 .15745 .29353 Metetra
.661 .745 .912 r
.15745 .29353 .1641 .29999 .17346 .29649 .16683 .29001 Metetra
.661 .745 .912 r
.16683 .29001 .17346 .29649 .18285 .29299 .17624 .28648 Metetra
.661 .745 .912 r
.17624 .28648 .18285 .29299 .19228 .28947 .18569 .28294 Metetra
.661 .745 .912 r
.18569 .28294 .19228 .28947 .20204 .28309 .19517 .27939 Metetra
.764 .861 .921 r
.19517 .27939 .20204 .28309 .21226 .27233 .20495 .27327 Metetra
.882 .971 .839 r
.20495 .27327 .21226 .27233 .22176 .26877 .21525 .26225 Metetra
.674 .75 .908 r
.21525 .26225 .22176 .26877 .23089 .26955 .22484 .25834 Metetra
.669 .631 .803 r
.22484 .25834 .23089 .26955 .2408 .26236 .23453 .25369 Metetra
.641 .677 .868 r
.23453 .25369 .2408 .26236 .25045 .25838 .24412 .25043 Metetra
.6 .682 .899 r
.24412 .25043 .25045 .25838 .25965 .25993 .25366 .24818 Metetra
.434 .503 .831 r
.25366 .24818 .25965 .25993 .26971 .25189 .26292 .24971 Metetra
.849 .912 .876 r
.26292 .24971 .26971 .25189 .27918 .25133 .27313 .24046 Metetra
.443 .529 .851 r
.27313 .24046 .27918 .25133 .2892 .24435 .28252 .24163 Metetra
.797 .907 .917 r
.28252 .24163 .2892 .24435 .29889 .24215 .29262 .2344 Metetra
.378 .588 .926 r
.29262 .2344 .29889 .24215 .30835 .2437 .30211 .23564 Metetra
.665 .708 .879 r
.30211 .23564 .30835 .2437 .31863 .2341 .31202 .23171 Metetra
.844 .914 .882 r
.31202 .23171 .31863 .2341 .32857 .2299 .32232 .22261 Metetra
.575 .699 .926 r
.32232 .22261 .32857 .2299 .33837 .2284 .33216 .22075 Metetra
.062 .402 .857 r
.33216 .22075 .33837 .2284 .34818 .22765 .34166 .22533 Metetra
.9 .899 .816 r
.34166 .22533 .34818 .22765 .35851 .21834 .35224 .21272 Metetra
.738 .809 .908 r
.35224 .21272 .35851 .21834 .36856 .21461 .36242 .20697 Metetra
.56 .683 .922 r
.36242 .20697 .36856 .21461 .37855 .21298 .37242 .2054 Metetra
.059 .403 .857 r
.37242 .2054 .37855 .21298 .38868 .20915 .38217 .21009 Metetra
.898 .981 .801 r
.38217 .21009 .38868 .20915 .39872 .20865 .39278 .19737 Metetra
.69 .649 .804 r
.39278 .19737 .39872 .20865 .40915 .19927 .40309 .19168 Metetra
.571 .693 .923 r
.40309 .19168 .40915 .19927 .41919 .2013 .41328 .18985 Metetra
.509 .558 .841 r
.41328 .18985 .41919 .2013 .42958 .19441 .42346 .18978 Metetra
.83 .859 .867 r
.42346 .18978 .42958 .19441 .43982 .19406 .43398 .18063 Metetra
.626 .584 .787 r
.43398 .18063 .43982 .19406 .45038 .18264 .44436 .17696 Metetra
.744 .818 .91 r
.44436 .17696 .45038 .18264 .46076 .17962 .45484 .17088 Metetra
.641 .69 .88 r
.45484 .17088 .46076 .17962 .4711 .18131 .46529 .16739 Metetra
.254 .358 .778 r
.46529 .16739 .4711 .18131 .48162 .17585 .47563 .17334 Metetra
.907 .917 .815 r
.47563 .17334 .48162 .17585 .49218 .16904 .48632 .1604 Metetra
.64 .695 .885 r
.48632 .1604 .49218 .16904 .50276 .16325 .4969 .1569 Metetra
.486 .704 .966 r
.4969 .1569 .50276 .16325 .51336 .1594 .50751 .15613 Metetra
.819 .919 .904 r
.50751 .15613 .51336 .1594 .524 .15938 .5182 .14769 Metetra
.649 .63 .817 r
.5182 .14769 .524 .15938 .53468 .15109 .52891 .14343 Metetra
.434 .63 .937 r
.52891 .14343 .53468 .15109 .5454 .14663 .53968 .14388 Metetra
.832 .94 .896 r
.53968 .14388 .5454 .14663 .55621 .14711 .55044 .13487 Metetra
.149 .327 .787 r
.55044 .13487 .55621 .14711 .56695 .13778 .56141 .14208 Metetra
.56141 .14208 .56695 .13778 .57801 .14553 .57233 .13799 Metetra
.661 .745 .912 r
.57233 .13799 .57801 .14553 .58894 .14145 .58329 .13388 Metetra
.661 .745 .912 r
.58329 .13388 .58894 .14145 .59991 .13736 .59429 .12975 Metetra
.661 .745 .912 r
.59429 .12975 .59991 .13736 .61093 .13324 .60533 .12561 Metetra
.661 .745 .912 r
.60533 .12561 .61093 .13324 .62199 .12912 .61642 .12146 Metetra
.661 .745 .912 r
.61642 .12146 .62199 .12912 .63309 .12497 .62756 .11728 Metetra
.661 .745 .912 r
.62756 .11728 .63309 .12497 .64424 .12081 .63873 .11309 Metetra
.661 .745 .912 r
.63873 .11309 .64424 .12081 .65543 .11664 .64996 .10888 Metetra
.661 .745 .912 r
.64996 .10888 .65543 .11664 .66667 .11244 .66122 .10466 Metetra
.661 .745 .912 r
.66122 .10466 .66667 .11244 .67795 .10823 .67254 .10042 Metetra
.661 .745 .912 r
.67254 .10042 .67795 .10823 .68928 .10401 .6839 .09616 Metetra
.661 .745 .912 r
.6839 .09616 .68928 .10401 .70065 .09976 .6953 .09188 Metetra
.661 .745 .912 r
.6953 .09188 .70065 .09976 .71207 .0955 .70675 .08759 Metetra
.661 .745 .912 r
.70675 .08759 .71207 .0955 .72353 .09122 .71825 .08328 Metetra
.661 .745 .912 r
.05863 .32173 .06551 .328 .07455 .32461 .06769 .31832 Metetra
.661 .745 .912 r
.06769 .31832 .07455 .32461 .08363 .3212 .07679 .31489 Metetra
.661 .745 .912 r
.07679 .31489 .08363 .3212 .09274 .31779 .08592 .31145 Metetra
.661 .745 .912 r
.08592 .31145 .09274 .31779 .10189 .31436 .09508 .308 Metetra
.661 .745 .912 r
.09508 .308 .10189 .31436 .11106 .31092 .10427 .30454 Metetra
.661 .745 .912 r
.10427 .30454 .11106 .31092 .12027 .30747 .1135 .30106 Metetra
.661 .745 .912 r
.1135 .30106 .12027 .30747 .12952 .304 .12277 .29757 Metetra
.661 .745 .912 r
.12277 .29757 .12952 .304 .13879 .30052 .13206 .29407 Metetra
.661 .745 .912 r
.13206 .29407 .13879 .30052 .14811 .29703 .14139 .29055 Metetra
.661 .745 .912 r
.14139 .29055 .14811 .29703 .15745 .29353 .15076 .28703 Metetra
.661 .745 .912 r
.15076 .28703 .15745 .29353 .16683 .29001 .16016 .28349 Metetra
.661 .745 .912 r
.16016 .28349 .16683 .29001 .17624 .28648 .16959 .27993 Metetra
.661 .745 .912 r
.16959 .27993 .17624 .28648 .18569 .28294 .17906 .27637 Metetra
.661 .745 .912 r
.17906 .27637 .18569 .28294 .19517 .27939 .18856 .27279 Metetra
.661 .745 .912 r
.18856 .27279 .19517 .27939 .20495 .27327 .1981 .26919 Metetra
.654 .836 .97 r
.1981 .26919 .20495 .27327 .21525 .26225 .20767 .26559 Metetra
.924 .973 .756 r
.20767 .26559 .21525 .26225 .22484 .25834 .21841 .25058 Metetra
.354 .574 .923 r
.21841 .25058 .22484 .25834 .23453 .25369 .22753 .25206 Metetra
.809 .935 .913 r
.22753 .25206 .23453 .25369 .24412 .25043 .23757 .24442 Metetra
.665 .769 .928 r
.23757 .24442 .24412 .25043 .25366 .24818 .24726 .24071 Metetra
.376 .597 .933 r
.24726 .24071 .25366 .24818 .26292 .24971 .25656 .24182 Metetra
.673 .713 .879 r
.25656 .24182 .26292 .24971 .27313 .24046 .26637 .23771 Metetra
.842 .897 .877 r
.26637 .23771 .27313 .24046 .28252 .24163 .27661 .22866 Metetra
.358 .436 .805 r
.27661 .22866 .28252 .24163 .29262 .2344 .28589 .23188 Metetra
.625 .893 .987 r
.28589 .23188 .29262 .2344 .30211 .23564 .29578 .22809 Metetra
.766 .751 .839 r
.29578 .22809 .30211 .23564 .31202 .23171 .30598 .22058 Metetra
.52 .567 .844 r
.30598 .22058 .31202 .23171 .32232 .22261 .31569 .22022 Metetra
.644 .905 .983 r
.31569 .22022 .32232 .22261 .33216 .22075 .32572 .21603 Metetra
.797 .844 .887 r
.32572 .21603 .33216 .22075 .34166 .22533 .33599 .20837 Metetra
.517 .473 .746 r
.33599 .20837 .34166 .22533 .35224 .21272 .34583 .2084 Metetra
.784 .861 .907 r
.34583 .2084 .35224 .21272 .36242 .20697 .35612 .20133 Metetra
.512 .738 .976 r
.35612 .20133 .36242 .20697 .37242 .2054 .36612 .20006 Metetra
.773 .827 .895 r
.36612 .20006 .37242 .2054 .38217 .21009 .37646 .19312 Metetra
.527 .48 .748 r
.37646 .19312 .38217 .21009 .39278 .19737 .38651 .19283 Metetra
.785 .859 .905 r
.38651 .19283 .39278 .19737 .40309 .19168 .39692 .18563 Metetra
.753 .804 .894 r
.39692 .18563 .40309 .19168 .41328 .18985 .40731 .17922 Metetra
.62 .633 .842 r
.40731 .17922 .41328 .18985 .42346 .18978 .4176 .17615 Metetra
.448 .483 .802 r
.4176 .17615 .42346 .18978 .43398 .18063 .42779 .17779 Metetra
.841 .921 .886 r
.42779 .17779 .43398 .18063 .44436 .17696 .43837 .16861 Metetra
.706 .726 .866 r
.43837 .16861 .44436 .17696 .45484 .17088 .44885 .16316 Metetra
.36 .587 .93 r
.44885 .16316 .45484 .17088 .46529 .16739 .45922 .16463 Metetra
.579 .883 .992 r
.45922 .16463 .46529 .16739 .47563 .17334 .46975 .16116 Metetra
.743 .662 .771 r
.46975 .16116 .47563 .17334 .48632 .1604 .48041 .15231 Metetra
.677 .727 .888 r
.48041 .15231 .48632 .1604 .4969 .1569 .49102 .14781 Metetra
.456 .596 .903 r
.49102 .14781 .4969 .1569 .50751 .15613 .50164 .14829 Metetra
.653 .728 .904 r
.50164 .14829 .50751 .15613 .5182 .14769 .51234 .14445 Metetra
.838 .921 .889 r
.51234 .14445 .5182 .14769 .52891 .14343 .52309 .13525 Metetra
0 .272 .776 r
.52309 .13525 .52891 .14343 .53968 .14388 .5339 .14271 Metetra
.532 .91 .947 r
.5339 .14271 .53968 .14388 .55044 .13487 .54476 .13862 Metetra
.54476 .13862 .55044 .13487 .56141 .14208 .55566 .13451 Metetra
.661 .745 .912 r
.55566 .13451 .56141 .14208 .57233 .13799 .5666 .13039 Metetra
.661 .745 .912 r
.5666 .13039 .57233 .13799 .58329 .13388 .57759 .12625 Metetra
.661 .745 .912 r
.57759 .12625 .58329 .13388 .59429 .12975 .58862 .1221 Metetra
.661 .745 .912 r
.58862 .1221 .59429 .12975 .60533 .12561 .5997 .11792 Metetra
.661 .745 .912 r
.5997 .11792 .60533 .12561 .61642 .12146 .61082 .11374 Metetra
.661 .745 .912 r
.61082 .11374 .61642 .12146 .62756 .11728 .62198 .10953 Metetra
.661 .745 .912 r
.62198 .10953 .62756 .11728 .63873 .11309 .63319 .10531 Metetra
.661 .745 .912 r
.63319 .10531 .63873 .11309 .64996 .10888 .64444 .10107 Metetra
.661 .745 .912 r
.64444 .10107 .64996 .10888 .66122 .10466 .65574 .09681 Metetra
.661 .745 .912 r
.65574 .09681 .66122 .10466 .67254 .10042 .66708 .09254 Metetra
.661 .745 .912 r
.66708 .09254 .67254 .10042 .6839 .09616 .67847 .08825 Metetra
.661 .745 .912 r
.67847 .08825 .6839 .09616 .6953 .09188 .68991 .08394 Metetra
.661 .745 .912 r
.68991 .08394 .6953 .09188 .70675 .08759 .70139 .07962 Metetra
.661 .745 .912 r
.70139 .07962 .70675 .08759 .71825 .08328 .71292 .07528 Metetra
.661 .745 .912 r
.0517 .31542 .05863 .32173 .06769 .31832 .06078 .31198 Metetra
.661 .745 .912 r
.06078 .31198 .06769 .31832 .07679 .31489 .0699 .30853 Metetra
.661 .745 .912 r
.0699 .30853 .07679 .31489 .08592 .31145 .07905 .30507 Metetra
.661 .745 .912 r
.07905 .30507 .08592 .31145 .09508 .308 .08823 .30159 Metetra
.661 .745 .912 r
.08823 .30159 .09508 .308 .10427 .30454 .09744 .29811 Metetra
.661 .745 .912 r
.09744 .29811 .10427 .30454 .1135 .30106 .10669 .29461 Metetra
.661 .745 .912 r
.10669 .29461 .1135 .30106 .12277 .29757 .11597 .2911 Metetra
.661 .745 .912 r
.11597 .2911 .12277 .29757 .13206 .29407 .12528 .28757 Metetra
.661 .745 .912 r
.12528 .28757 .13206 .29407 .14139 .29055 .13463 .28403 Metetra
.661 .745 .912 r
.13463 .28403 .14139 .29055 .15076 .28703 .14402 .28048 Metetra
.661 .745 .912 r
.14402 .28048 .15076 .28703 .16016 .28349 .15344 .27692 Metetra
.661 .745 .912 r
.15344 .27692 .16016 .28349 .16959 .27993 .16289 .27334 Metetra
.661 .745 .912 r
.16289 .27334 .16959 .27993 .17906 .27637 .17238 .26975 Metetra
.661 .745 .912 r
.17238 .26975 .17906 .27637 .18856 .27279 .1819 .26614 Metetra
.661 .745 .912 r
.1819 .26614 .18856 .27279 .1981 .26919 .19146 .26253 Metetra
.661 .745 .912 r
.19146 .26253 .1981 .26919 .20767 .26559 .20105 .2589 Metetra
.661 .745 .912 r
.20105 .2589 .20767 .26559 .21841 .25058 .21068 .25525 Metetra
.21068 .25525 .21841 .25058 .22753 .25206 .22035 .25159 Metetra
.928 .905 .779 r
.22035 .25159 .22753 .25206 .23757 .24442 .23115 .23648 Metetra
.663 .708 .881 r
.23115 .23648 .23757 .24442 .24726 .24071 .24086 .23265 Metetra
.365 .572 .919 r
.24086 .23265 .24726 .24071 .25656 .24182 .25014 .23407 Metetra
.774 .745 .826 r
.25014 .23407 .25656 .24182 .26637 .23771 .26031 .22602 Metetra
.511 .55 .832 r
.26031 .22602 .26637 .23771 .27661 .22866 .26982 .22587 Metetra
.8 .905 .914 r
.26982 .22587 .27661 .22866 .28589 .23188 .27998 .21847 Metetra
.162 .306 .764 r
.27998 .21847 .28589 .23188 .29578 .22809 .28908 .2249 Metetra
.885 .872 .819 r
.28908 .2249 .29578 .22809 .30598 .22058 .29966 .21279 Metetra
.678 .723 .883 r
.29966 .21279 .30598 .22058 .31569 .22022 .30966 .20846 Metetra
.214 .377 .811 r
.30966 .20846 .31569 .22022 .32572 .21603 .31907 .21346 Metetra
.9 .89 .812 r
.31907 .21346 .32572 .21603 .33599 .20837 .32973 .20057 Metetra
.666 .721 .89 r
.32973 .20057 .33599 .20837 .34583 .2084 .33982 .19656 Metetra
.201 .368 .807 r
.33982 .19656 .34583 .2084 .35612 .20133 .34941 .20185 Metetra
.907 .969 .805 r
.34941 .20185 .35612 .20133 .36612 .20006 .3601 .18888 Metetra
.686 .65 .809 r
.3601 .18888 .36612 .20006 .37646 .19312 .37037 .1834 Metetra
.298 .485 .874 r
.37037 .1834 .37646 .19312 .38651 .19283 .38027 .18644 Metetra
.649 .766 .935 r
.38027 .18644 .38651 .19283 .39692 .18563 .39055 .18285 Metetra
.879 .908 .845 r
.39055 .18285 .39692 .18563 .40731 .17922 .40118 .17166 Metetra
.58 .701 .925 r
.40118 .17166 .40731 .17922 .4176 .17615 .41146 .16957 Metetra
0 .37 .83 r
.41146 .16957 .4176 .17615 .42779 .17779 .42154 .17465 Metetra
.915 .884 .788 r
.42154 .17465 .42779 .17779 .43837 .16861 .43233 .16018 Metetra
.482 .629 .917 r
.43233 .16018 .43837 .16861 .44885 .16316 .4427 .16001 Metetra
.795 .918 .921 r
.4427 .16001 .44885 .16316 .45922 .16463 .45331 .15245 Metetra
.492 .538 .832 r
.45331 .15245 .45922 .16463 .46975 .16116 .46377 .15275 Metetra
.652 .709 .89 r
.46377 .15275 .46975 .16116 .48041 .15231 .47437 .14891 Metetra
.837 .912 .887 r
.47437 .14891 .48041 .15231 .49102 .14781 .48509 .13975 Metetra
.104 .419 .865 r
.48509 .13975 .49102 .14781 .50164 .14829 .49568 .14455 Metetra
.424 .782 .996 r
.49568 .14455 .50164 .14829 .51234 .14445 .50641 .14334 Metetra
.532 .91 .946 r
.50641 .14334 .51234 .14445 .52309 .13525 .51721 .13925 Metetra
.51721 .13925 .52309 .13525 .5339 .14271 .52805 .13514 Metetra
.661 .745 .912 r
.52805 .13514 .5339 .14271 .54476 .13862 .53894 .13102 Metetra
.661 .745 .912 r
.53894 .13102 .54476 .13862 .55566 .13451 .54987 .12689 Metetra
.661 .745 .912 r
.54987 .12689 .55566 .13451 .5666 .13039 .56084 .12274 Metetra
.661 .745 .912 r
.56084 .12274 .5666 .13039 .57759 .12625 .57186 .11857 Metetra
.661 .745 .912 r
.57186 .11857 .57759 .12625 .58862 .1221 .58292 .11438 Metetra
.661 .745 .912 r
.58292 .11438 .58862 .1221 .5997 .11792 .59402 .11018 Metetra
.661 .745 .912 r
.59402 .11018 .5997 .11792 .61082 .11374 .60517 .10596 Metetra
.661 .745 .912 r
.60517 .10596 .61082 .11374 .62198 .10953 .61636 .10172 Metetra
.661 .745 .912 r
.61636 .10172 .62198 .10953 .63319 .10531 .6276 .09747 Metetra
.661 .745 .912 r
.6276 .09747 .63319 .10531 .64444 .10107 .63889 .0932 Metetra
.661 .745 .912 r
.63889 .0932 .64444 .10107 .65574 .09681 .65022 .08891 Metetra
.661 .745 .912 r
.65022 .08891 .65574 .09681 .66708 .09254 .66159 .08461 Metetra
.661 .745 .912 r
.66159 .08461 .66708 .09254 .67847 .08825 .67301 .08029 Metetra
.661 .745 .912 r
.67301 .08029 .67847 .08825 .68991 .08394 .68448 .07595 Metetra
.661 .745 .912 r
.68448 .07595 .68991 .08394 .70139 .07962 .69599 .07159 Metetra
.661 .745 .912 r
.69599 .07159 .70139 .07962 .71292 .07528 .70755 .06721 Metetra
.661 .745 .912 r
.04473 .30906 .0517 .31542 .06078 .31198 .05383 .3056 Metetra
.661 .745 .912 r
.05383 .3056 .06078 .31198 .0699 .30853 .06296 .30213 Metetra
.661 .745 .912 r
.06296 .30213 .0699 .30853 .07905 .30507 .07213 .29865 Metetra
.661 .745 .912 r
.07213 .29865 .07905 .30507 .08823 .30159 .08133 .29515 Metetra
.661 .745 .912 r
.08133 .29515 .08823 .30159 .09744 .29811 .09056 .29164 Metetra
.661 .745 .912 r
.09056 .29164 .09744 .29811 .10669 .29461 .09983 .28811 Metetra
.661 .745 .912 r
.09983 .28811 .10669 .29461 .11597 .2911 .10913 .28458 Metetra
.661 .745 .912 r
.10913 .28458 .11597 .2911 .12528 .28757 .11846 .28103 Metetra
.661 .745 .912 r
.11846 .28103 .12528 .28757 .13463 .28403 .12783 .27747 Metetra
.661 .745 .912 r
.12783 .27747 .13463 .28403 .14402 .28048 .13723 .27389 Metetra
.661 .745 .912 r
.13723 .27389 .14402 .28048 .15344 .27692 .14667 .2703 Metetra
.661 .745 .912 r
.14667 .2703 .15344 .27692 .16289 .27334 .15614 .2667 Metetra
.661 .745 .912 r
.15614 .2667 .16289 .27334 .17238 .26975 .16565 .26308 Metetra
.661 .745 .912 r
.16565 .26308 .17238 .26975 .1819 .26614 .17519 .25946 Metetra
.661 .745 .912 r
.17519 .25946 .1819 .26614 .19146 .26253 .18477 .25581 Metetra
.661 .745 .912 r
.18477 .25581 .19146 .26253 .20105 .2589 .19439 .25216 Metetra
.661 .745 .912 r
.19439 .25216 .20105 .2589 .21068 .25525 .20404 .24849 Metetra
.661 .745 .912 r
.20404 .24849 .21068 .25525 .22035 .25159 .21372 .24481 Metetra
.661 .745 .912 r
.21372 .24481 .22035 .25159 .23115 .23648 .22345 .24111 Metetra
.22345 .24111 .23115 .23648 .24086 .23265 .2332 .2374 Metetra
.796 .986 .728 r
.2332 .2374 .24086 .23265 .25014 .23407 .24375 .22557 Metetra
.753 .723 .825 r
.24375 .22557 .25014 .23407 .26031 .22602 .25388 .21821 Metetra
.673 .719 .884 r
.25388 .21821 .26031 .22602 .26982 .22587 .26375 .21406 Metetra
.418 .498 .834 r
.26375 .21406 .26982 .22587 .27998 .21847 .27316 .21576 Metetra
.506 .846 .996 r
.27316 .21576 .27998 .21847 .28908 .2249 .28297 .21345 Metetra
.636 .62 .817 r
.28297 .21345 .28908 .2249 .29966 .21279 .29292 .2098 Metetra
.839 .898 .881 r
.29292 .2098 .29966 .21279 .30966 .20846 .30331 .20077 Metetra
.41 .614 .933 r
.30331 .20077 .30966 .20846 .31907 .21346 .31302 .20146 Metetra
.632 .609 .81 r
.31302 .20146 .31907 .21346 .32973 .20057 .32308 .19786 Metetra
.834 .913 .89 r
.32308 .19786 .32973 .20057 .33982 .19656 .33351 .18906 Metetra
.402 .617 .939 r
.33351 .18906 .33982 .19656 .34941 .20185 .34338 .1898 Metetra
.628 .608 .811 r
.34338 .1898 .34941 .20185 .3601 .18888 .35355 .18629 Metetra
.836 .921 .891 r
.35355 .18629 .3601 .18888 .37037 .1834 .36405 .17737 Metetra
.359 .652 .967 r
.36405 .17737 .37037 .1834 .38027 .18644 .37408 .17803 Metetra
.641 .7 .889 r
.37408 .17803 .38027 .18644 .39055 .18285 .38437 .17456 Metetra
.788 .75 .818 r
.38437 .17456 .39055 .18285 .40118 .17166 .39495 .1655 Metetra
.296 .612 .956 r
.39495 .1655 .40118 .17166 .41146 .16957 .40511 .16691 Metetra
.627 .901 .985 r
.40511 .16691 .41146 .16957 .42154 .17465 .41555 .16276 Metetra
.751 .67 .771 r
.41555 .16276 .42154 .17465 .43233 .16018 .4262 .15359 Metetra
.725 .788 .902 r
.4262 .15359 .43233 .16018 .4427 .16001 .43675 .1479 Metetra
.638 .616 .812 r
.43675 .1479 .4427 .16001 .45331 .15245 .44728 .14394 Metetra
.078 .388 .848 r
.44728 .14394 .45331 .15245 .46377 .15275 .45764 .14918 Metetra
.894 .892 .821 r
.45764 .14918 .46377 .15275 .47437 .14891 .46845 .13662 Metetra
.108 .302 .777 r
.46845 .13662 .47437 .14891 .48509 .13975 .47894 .14396 Metetra
.47894 .14396 .48509 .13975 .49568 .14455 .48968 .13988 Metetra
.652 .844 .974 r
.48968 .13988 .49568 .14455 .50641 .14334 .50046 .13578 Metetra
.661 .745 .912 r
.50046 .13578 .50641 .14334 .51721 .13925 .51129 .13166 Metetra
.661 .745 .912 r
.51129 .13166 .51721 .13925 .52805 .13514 .52216 .12753 Metetra
.661 .745 .912 r
.52216 .12753 .52805 .13514 .53894 .13102 .53308 .12338 Metetra
.661 .745 .912 r
.53308 .12338 .53894 .13102 .54987 .12689 .54403 .11921 Metetra
.661 .745 .912 r
.54403 .11921 .54987 .12689 .56084 .12274 .55504 .11503 Metetra
.661 .745 .912 r
.55504 .11503 .56084 .12274 .57186 .11857 .56608 .11083 Metetra
.661 .745 .912 r
.56608 .11083 .57186 .11857 .58292 .11438 .57717 .10661 Metetra
.661 .745 .912 r
.57717 .10661 .58292 .11438 .59402 .11018 .5883 .10238 Metetra
.661 .745 .912 r
.5883 .10238 .59402 .11018 .60517 .10596 .59948 .09813 Metetra
.661 .745 .912 r
.59948 .09813 .60517 .10596 .61636 .10172 .61071 .09386 Metetra
.661 .745 .912 r
.61071 .09386 .61636 .10172 .6276 .09747 .62197 .08957 Metetra
.661 .745 .912 r
.62197 .08957 .6276 .09747 .63889 .0932 .63329 .08527 Metetra
.661 .745 .912 r
.63329 .08527 .63889 .0932 .65022 .08891 .64465 .08095 Metetra
.661 .745 .912 r
.64465 .08095 .65022 .08891 .66159 .08461 .65606 .07661 Metetra
.661 .745 .912 r
.65606 .07661 .66159 .08461 .67301 .08029 .66751 .07226 Metetra
.661 .745 .912 r
.66751 .07226 .67301 .08029 .68448 .07595 .67901 .06789 Metetra
.661 .745 .912 r
.67901 .06789 .68448 .07595 .69599 .07159 .69055 .0635 Metetra
.661 .745 .912 r
.69055 .0635 .69599 .07159 .70755 .06721 .70215 .05909 Metetra
.661 .745 .912 r
.03771 .30267 .04473 .30906 .05383 .3056 .04683 .29918 Metetra
.661 .745 .912 r
.04683 .29918 .05383 .3056 .06296 .30213 .05598 .29569 Metetra
.661 .745 .912 r
.05598 .29569 .06296 .30213 .07213 .29865 .06516 .29218 Metetra
.661 .745 .912 r
.06516 .29218 .07213 .29865 .08133 .29515 .07438 .28866 Metetra
.661 .745 .912 r
.07438 .28866 .08133 .29515 .09056 .29164 .08363 .28512 Metetra
.661 .745 .912 r
.08363 .28512 .09056 .29164 .09983 .28811 .09292 .28157 Metetra
.661 .745 .912 r
.09292 .28157 .09983 .28811 .10913 .28458 .10224 .27801 Metetra
.661 .745 .912 r
.10224 .27801 .10913 .28458 .11846 .28103 .11159 .27444 Metetra
.661 .745 .912 r
.11159 .27444 .11846 .28103 .12783 .27747 .12098 .27085 Metetra
.661 .745 .912 r
.12098 .27085 .12783 .27747 .13723 .27389 .1304 .26725 Metetra
.661 .745 .912 r
.1304 .26725 .13723 .27389 .14667 .2703 .13986 .26364 Metetra
.661 .745 .912 r
.13986 .26364 .14667 .2703 .15614 .2667 .14935 .26002 Metetra
.661 .745 .912 r
.14935 .26002 .15614 .2667 .16565 .26308 .15888 .25638 Metetra
.661 .745 .912 r
.15888 .25638 .16565 .26308 .17519 .25946 .16844 .25272 Metetra
.661 .745 .912 r
.16844 .25272 .17519 .25946 .18477 .25581 .17804 .24905 Metetra
.661 .745 .912 r
.17804 .24905 .18477 .25581 .19439 .25216 .18767 .24537 Metetra
.661 .745 .912 r
.18767 .24537 .19439 .25216 .20404 .24849 .19735 .24168 Metetra
.661 .745 .912 r
.19735 .24168 .20404 .24849 .21372 .24481 .20705 .23797 Metetra
.661 .745 .912 r
.20705 .23797 .21372 .24481 .22345 .24111 .2168 .23425 Metetra
.661 .745 .912 r
.2168 .23425 .22345 .24111 .2332 .2374 .22658 .23051 Metetra
.661 .745 .912 r
.22658 .23051 .2332 .2374 .24375 .22557 .2364 .22676 Metetra
.404 .858 .83 r
.2364 .22676 .24375 .22557 .25388 .21821 .24625 .223 Metetra
.24625 .223 .25388 .21821 .26375 .21406 .25614 .21922 Metetra
.25614 .21922 .26375 .21406 .27316 .21576 .26607 .21542 Metetra
.847 .969 .877 r
.26607 .21542 .27316 .21576 .28297 .21345 .27651 .20589 Metetra
.771 .756 .839 r
.27651 .20589 .28297 .21345 .29292 .2098 .28681 .19812 Metetra
.335 .456 .835 r
.28681 .19812 .29292 .2098 .30331 .20077 .2963 .20116 Metetra
.91 .96 .808 r
.2963 .20116 .30331 .20077 .31302 .20146 .30704 .18808 Metetra
.648 .595 .781 r
.30704 .18808 .31302 .20146 .32308 .19786 .31717 .18352 Metetra
.24 .342 .768 r
.31717 .18352 .32308 .19786 .33351 .18906 .32666 .18919 Metetra
.915 .956 .803 r
.32666 .18919 .33351 .18906 .34338 .1898 .33744 .17577 Metetra
.446 .475 .796 r
.33744 .17577 .34338 .1898 .35355 .18629 .34731 .17733 Metetra
.643 .686 .875 r
.34731 .17733 .35355 .18629 .36405 .17737 .35755 .17375 Metetra
.84 .889 .875 r
.35755 .17375 .36405 .17737 .37408 .17803 .36812 .16441 Metetra
.448 .485 .805 r
.36812 .16441 .37408 .17803 .38437 .17456 .37817 .16588 Metetra
.653 .699 .881 r
.37817 .16588 .38437 .17456 .39495 .1655 .38854 .16202 Metetra
.841 .899 .879 r
.38854 .16202 .39495 .1655 .40511 .16691 .39918 .15268 Metetra
.628 .576 .777 r
.39918 .15268 .40511 .16691 .41555 .16276 .40962 .14869 Metetra
.273 .371 .782 r
.40962 .14869 .41555 .16276 .4262 .15359 .41977 .15393 Metetra
.119 .67 .749 r
.41977 .15393 .4262 .15359 .43675 .1479 .43023 .15271 Metetra
.43023 .15271 .43675 .1479 .44728 .14394 .44083 .14866 Metetra
.44083 .14866 .44728 .14394 .45764 .14918 .45148 .14459 Metetra
.652 .845 .974 r
.45148 .14459 .45764 .14918 .46845 .13662 .46216 .14051 Metetra
.46216 .14051 .46845 .13662 .47894 .14396 .47289 .13641 Metetra
.661 .745 .912 r
.47289 .13641 .47894 .14396 .48968 .13988 .48366 .13229 Metetra
.661 .745 .912 r
.48366 .13229 .48968 .13988 .50046 .13578 .49447 .12816 Metetra
.661 .745 .912 r
.49447 .12816 .50046 .13578 .51129 .13166 .50533 .12402 Metetra
.661 .745 .912 r
.50533 .12402 .51129 .13166 .52216 .12753 .51623 .11985 Metetra
.661 .745 .912 r
.51623 .11985 .52216 .12753 .53308 .12338 .52717 .11567 Metetra
.661 .745 .912 r
.52717 .11567 .53308 .12338 .54403 .11921 .53816 .11147 Metetra
.661 .745 .912 r
.53816 .11147 .54403 .11921 .55504 .11503 .54919 .10726 Metetra
.661 .745 .912 r
.54919 .10726 .55504 .11503 .56608 .11083 .56026 .10303 Metetra
.661 .745 .912 r
.56026 .10303 .56608 .11083 .57717 .10661 .57138 .09878 Metetra
.661 .745 .912 r
.57138 .09878 .57717 .10661 .5883 .10238 .58254 .09452 Metetra
.661 .745 .912 r
.58254 .09452 .5883 .10238 .59948 .09813 .59375 .09023 Metetra
.661 .745 .912 r
.59375 .09023 .59948 .09813 .61071 .09386 .60501 .08593 Metetra
.661 .745 .912 r
.60501 .08593 .61071 .09386 .62197 .08957 .61631 .08162 Metetra
.661 .745 .912 r
.61631 .08162 .62197 .08957 .63329 .08527 .62765 .07728 Metetra
.661 .745 .912 r
.62765 .07728 .63329 .08527 .64465 .08095 .63904 .07293 Metetra
.661 .745 .912 r
.63904 .07293 .64465 .08095 .65606 .07661 .65048 .06856 Metetra
.661 .745 .912 r
.65048 .06856 .65606 .07661 .66751 .07226 .66196 .06417 Metetra
.661 .745 .912 r
.66196 .06417 .66751 .07226 .67901 .06789 .6735 .05977 Metetra
.661 .745 .912 r
.6735 .05977 .67901 .06789 .69055 .0635 .68508 .05534 Metetra
.661 .745 .912 r
.68508 .05534 .69055 .0635 .70215 .05909 .6967 .0509 Metetra
.661 .745 .912 r
.03065 .29622 .03771 .30267 .04683 .29918 .03978 .29272 Metetra
.661 .745 .912 r
.03978 .29272 .04683 .29918 .05598 .29569 .04895 .2892 Metetra
.661 .745 .912 r
.04895 .2892 .05598 .29569 .06516 .29218 .05815 .28567 Metetra
.661 .745 .912 r
.05815 .28567 .06516 .29218 .07438 .28866 .06739 .28212 Metetra
.661 .745 .912 r
.06739 .28212 .07438 .28866 .08363 .28512 .07666 .27856 Metetra
.661 .745 .912 r
.07666 .27856 .08363 .28512 .09292 .28157 .08596 .27499 Metetra
.661 .745 .912 r
.08596 .27499 .09292 .28157 .10224 .27801 .0953 .27141 Metetra
.661 .745 .912 r
.0953 .27141 .10224 .27801 .11159 .27444 .10467 .26781 Metetra
.661 .745 .912 r
.10467 .26781 .11159 .27444 .12098 .27085 .11408 .2642 Metetra
.661 .745 .912 r
.11408 .2642 .12098 .27085 .1304 .26725 .12352 .26057 Metetra
.661 .745 .912 r
.12352 .26057 .1304 .26725 .13986 .26364 .133 .25694 Metetra
.661 .745 .912 r
.133 .25694 .13986 .26364 .14935 .26002 .14251 .25328 Metetra
.661 .745 .912 r
.14251 .25328 .14935 .26002 .15888 .25638 .15206 .24962 Metetra
.661 .745 .912 r
.15206 .24962 .15888 .25638 .16844 .25272 .16164 .24594 Metetra
.661 .745 .912 r
.16164 .24594 .16844 .25272 .17804 .24905 .17126 .24225 Metetra
.661 .745 .912 r
.17126 .24225 .17804 .24905 .18767 .24537 .18092 .23854 Metetra
.661 .745 .912 r
.18092 .23854 .18767 .24537 .19735 .24168 .19061 .23482 Metetra
.661 .745 .912 r
.19061 .23482 .19735 .24168 .20705 .23797 .20034 .23109 Metetra
.661 .745 .912 r
.20034 .23109 .20705 .23797 .2168 .23425 .2101 .22734 Metetra
.661 .745 .912 r
.2101 .22734 .2168 .23425 .22658 .23051 .2199 .22358 Metetra
.661 .745 .912 r
.2199 .22358 .22658 .23051 .2364 .22676 .22974 .2198 Metetra
.661 .745 .912 r
.22974 .2198 .2364 .22676 .24625 .223 .23962 .21601 Metetra
.661 .745 .912 r
.23962 .21601 .24625 .223 .25614 .21922 .24953 .2122 Metetra
.661 .745 .912 r
.24953 .2122 .25614 .21922 .26607 .21542 .25949 .20838 Metetra
.661 .745 .912 r
.25949 .20838 .26607 .21542 .27651 .20589 .26948 .20455 Metetra
.574 .913 .971 r
.26948 .20455 .27651 .20589 .28681 .19812 .2795 .2007 Metetra
.275 .764 .685 r
.2795 .2007 .28681 .19812 .2963 .20116 .28957 .19683 Metetra
.653 .842 .973 r
.28957 .19683 .2963 .20116 .30704 .18808 .29968 .19295 Metetra
.29968 .19295 .30704 .18808 .31717 .18352 .30982 .18906 Metetra
.30982 .18906 .31717 .18352 .32666 .18919 .32 .18515 Metetra
.649 .854 .978 r
.32 .18515 .32666 .18919 .33744 .17577 .33023 .18123 Metetra
.845 .974 .666 r
.33023 .18123 .33744 .17577 .34731 .17733 .34119 .16592 Metetra
.008 .257 .761 r
.34119 .16592 .34731 .17733 .35755 .17375 .35079 .17333 Metetra
.51 .906 .927 r
.35079 .17333 .35755 .17375 .36812 .16441 .36113 .16936 Metetra
.36113 .16936 .36812 .16441 .37817 .16588 .37151 .16538 Metetra
.512 .906 .929 r
.37151 .16538 .37817 .16588 .38854 .16202 .38193 .16138 Metetra
.52 .908 .935 r
.38193 .16138 .38854 .16202 .39918 .15268 .3924 .15736 Metetra
.3924 .15736 .39918 .15268 .40962 .14869 .4029 .15333 Metetra
.4029 .15333 .40962 .14869 .41977 .15393 .41345 .14928 Metetra
.653 .842 .973 r
.41345 .14928 .41977 .15393 .43023 .15271 .42403 .14522 Metetra
.661 .745 .912 r
.42403 .14522 .43023 .15271 .44083 .14866 .43466 .14114 Metetra
.661 .745 .912 r
.43466 .14114 .44083 .14866 .45148 .14459 .44533 .13704 Metetra
.661 .745 .912 r
.44533 .13704 .45148 .14459 .46216 .14051 .45605 .13293 Metetra
.661 .745 .912 r
.45605 .13293 .46216 .14051 .47289 .13641 .4668 .1288 Metetra
.661 .745 .912 r
.4668 .1288 .47289 .13641 .48366 .13229 .4776 .12465 Metetra
.661 .745 .912 r
.4776 .12465 .48366 .13229 .49447 .12816 .48844 .12049 Metetra
.661 .745 .912 r
.48844 .12049 .49447 .12816 .50533 .12402 .49932 .11632 Metetra
.661 .745 .912 r
.49932 .11632 .50533 .12402 .51623 .11985 .51025 .11212 Metetra
.661 .745 .912 r
.51025 .11212 .51623 .11985 .52717 .11567 .52122 .10791 Metetra
.661 .745 .912 r
.52122 .10791 .52717 .11567 .53816 .11147 .53224 .10368 Metetra
.661 .745 .912 r
.53224 .10368 .53816 .11147 .54919 .10726 .54329 .09944 Metetra
.661 .745 .912 r
.54329 .09944 .54919 .10726 .56026 .10303 .5544 .09517 Metetra
.661 .745 .912 r
.5544 .09517 .56026 .10303 .57138 .09878 .56555 .09089 Metetra
.661 .745 .912 r
.56555 .09089 .57138 .09878 .58254 .09452 .57674 .0866 Metetra
.661 .745 .912 r
.57674 .0866 .58254 .09452 .59375 .09023 .58798 .08228 Metetra
.661 .745 .912 r
.58798 .08228 .59375 .09023 .60501 .08593 .59926 .07795 Metetra
.661 .745 .912 r
.59926 .07795 .60501 .08593 .61631 .08162 .61059 .0736 Metetra
.661 .745 .912 r
.61059 .0736 .61631 .08162 .62765 .07728 .62197 .06923 Metetra
.661 .745 .912 r
.62197 .06923 .62765 .07728 .63904 .07293 .63339 .06485 Metetra
.661 .745 .912 r
.63339 .06485 .63904 .07293 .65048 .06856 .64486 .06045 Metetra
.661 .745 .912 r
.64486 .06045 .65048 .06856 .66196 .06417 .65638 .05603 Metetra
.661 .745 .912 r
.65638 .05603 .66196 .06417 .6735 .05977 .66794 .05159 Metetra
.661 .745 .912 r
.66794 .05159 .6735 .05977 .68508 .05534 .67955 .04713 Metetra
.661 .745 .912 r
.67955 .04713 .68508 .05534 .6967 .0509 .69121 .04265 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.2144 .18574 m
.21891 .1905 L
s
[(20)] .20537 .17621 .94693 1 Mshowa
.41503 .10718 m
.41918 .11226 L
s
[(40)] .40673 .09701 .81663 1 Mshowa
.63179 .0223 m
.63551 .02771 L
s
[(60)] .62437 .01148 .68632 1 Mshowa
.125 Mabswid
.07346 .24092 m
.0763 .24365 L
s
.11958 .22286 m
.12238 .22563 L
s
.16655 .20447 m
.16931 .20728 L
s
.26314 .16665 m
.2658 .16956 L
s
.31281 .1472 m
.31541 .15015 L
s
.36343 .12738 m
.36598 .13038 L
s
.46763 .08658 m
.47006 .08968 L
s
.52127 .06557 m
.52364 .06872 L
s
.57598 .04415 m
.57828 .04735 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 233.562},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GPP10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0/@000?l0/@000?l0/@000?l0/@000?l0
/@000?l0/@000?l0/@000?l0/@000?l0/@000?l0/@000?l0/@000?l0/@000?l020001^HYoom]iP@0
00@VJ?l5V`000?l020001Vd50005K@<000IVlnKVZ;jJ0000o`080003J000008000Ko0000:Kh20003
__<009T0003o00P000?oiP000P001Ol0003o00@000?o0000V0000?l020001_m]iP05K@<000?o0000
0P000ol0002H0000o`080006Z0GoofgV0`000ol000020003o`0001H00_n00000o`080003EH4000H0
00HY_P00_RTE00?o00<0o`00O`000?l02@000o>1YP050006I_?Vi_=V4`02o`@00_mo0000o`0:0004
1FSoZ0@000@VJ6QV4@03o`H000?o0?l0OP000?l09@02o`T000?o0?l0OP000?l08P03o`/000Co003o
O@000?l07`03o`h000Go0000o`1l0000o`0M00;o4@001Ol0003o07`0003o01X00olC0003o`000080
00?o0000N@000?l06002oaH000?o00000`000ol0001h0000o`0E00?o00<0o`005@000ol000030003
o`0007P0003o01<00_l50003o`0001@000?o00000`000ol0001g0000o`0@00?o7P000ol000030003
o`0007L0003o00h00_lQ0003o`0000@000?o0000MP000?l02`03ob<000?o00000`000ol0o`1g0000
o`0800?o9P000ol000050003o`0007D0003o00H00_lY0003o`0000H000?o0000M0000?l00`03obX0
0_l90003o`0007<0003o00400olY00?o00=[o`0020000ol0001c0000o@03o`<000?o00009002o`04
AW96LP;o2@000ol0001b0000n`02obX00ol01/kocV_>J`;o2P000ol0001a0000n003obX00_l02G96
LTIbog96LP03o`T000?o0000L@000?H00_l[00;o00U[c_o>Jli[of/00ol00f_o00090003o`000700
003c00?o:`02o`08LTIbAW;oLTH3o`06AW;oLTKo2P000ol0001_0000l@02ob/00ol01f_oJli[cV/0
0ol026_>oli[of_>0_l90003o`0006l0003^00?o:P03o`07AW96LTKoAP03o`08A_m6LTIbog83o`03
L_l000T000?o0000KP000>/00olZ00?o00Q[c_o>Jli[cP;o00U[cV_>Jom[cV/00ol01F_>Jlko00X0
00?o0000K@000>T00_l00`3o000W00?o00Q6odIbAW;oLP?o00Ubog96LTIbog800_l01dIbog96LTH0
0_l90003o`0006d0003V00?o10000ol0000S00;o00U[cV_>Jom[cV/00_l02Li[cV_>oli[cP03o`04
cV_>J`;o00G>oom[o`0:0003o`0006`0002b00;o00=X00000P0012IXo`DW00;o:P03o`09L_mbAW96
L_mb00;o00M6L_mbAW9600Co00MbA_m6LTIb00?o00EbAW96o`0900;oK@000;<000?o00000P001VKc
i^JX_R<00olZ00;o00W>Jli[c_o>Jlh00ol01li[cV_>olh00_l02F_oJli[cV_oJ`05o`04Jli[cP;o
1`000ol0o`1]0000[`06o`<000HY_P00__<Q00;o:`02o`07AW;oLTIbAP04o`08LTKoAW96LTH2o`08
LTIbA_m6LTH3o`07AW96odKoAP02o`03L_l000T000?o0000JP000:l000D5_P00o`040003o`000080
00?o00007003obX00ol01li[cV_>olh00_l02F_>oli[cV_oJ`03o`06Jom[cV_>1?l026_>oli[c_o>
0_l01F_>Jlko00X000?o0000J@000:l000GVlnH0o`040003o`00008000?o00006P02obT01?l02796
odIbAW960_l02796LTIbog960ol01dIbAW96odH00_l02G;oLTIbAW;oLP03o`07L_mbAW96o`0:0003
o`0006T0002`0004_X40o`@000?o00000P000ol0000G00?o:@02o`09JlkocV_>Jom[00?o00M[of_>
Jli[00?o00Q[c_o>Jli[cP;o00U[cV_>oli[cV/00_l02<kocV_>oli[0ol:0003o`0006P0002a0003
:FKo00@000HY_P00_RTG00;o:P02o`08LTIbAW;oLTH3o`07AW96LTKoAP03o`08A_m6LTIbog83o`09
L_mbAW96L_mb00;o00M6odKoAW9600?o00A6LTKo2@000ol0001X0000/@000jHYo`040006I_?Vi_=V
5003o`8000?o00009003o`07Jom[cV_>J`03o`08Jli[of_>Jlh2o`09Jli[cV_oJli[00;o00W>Jli[
c_o>Jlh00ol01<i[cV/5o`08Jom[cV_>Jol90003o`0006L0002b00031FP000@000@VJ6QV4P03obT0
0ol01dIbAW96odH00ol02DKoAW96LTKoAP02o`09L_mbAW96L_mb00;o00M6odIbAW9600Co00MbA_m6
LTIb00;o00Y6LTIbA_m6LTIb0_l90003o`0006H0003=00;o:@03o`08Jli[of_>Jlh2o`0:Jli[cV_o
Jli[cP;o00Q[cV_>oli[cP?o00K>Jli[of/3o`09Jom[cV_>Jom[00;o00W>oli[cV_>olh00ol00lko
00080003o`0006H0003:00?o:@02o`09A_m6LTIbA_m600;o00UbA_m6LTIbog800ol01W;oLTIbAPCo
00MbA_m6LTIb00;o00U6LTIbA_m6LTH00ol00dIbAP02o`03LTIb00?o00IbAW96L_l90003o`0006D0
003800;o:P02o`09cV_>Jom[cV_>00;o00Q[cV_>Jom[cP?o00O>Jli[c_o>00;o00U[of_>Jli[of/0
0_l01li[of_>Jlh01?l01V_>oli[cPGo00S>Jom[cV_>J`;o2@000ol0001T0000a@03obT00ol024Ko
AW96L_mb0ol01g;oLTIbAW800ol02796odIbAW960_l02796LTKoAW960ol01dIbAW96odH00_l02G;o
LTIbAW;oLP02o`09AW;oLTIbA_m600?o00=6o`0020000ol0001T0000``02obT00ol026_>Jli[of_>
0ol01li[cV_>olh00ol02<kocV_>Jom[0ol01V_oJli[cPCo00Q[c_o>Jli[cP;o00U[cV_>oli[cV/0
0_l02<kocV_>oli[0ol01V_>Jli[o`T000?o0000H`000<000olX00?o00Q6LTKoAW96LP?o00QbAW;o
LTIbAP;o00QbAW96L_mbAP?o00M6LTIbA_m600;o00Ubog96LTIbog800ol027;oLTIbA_m60ol01dKo
A_m6LTH00ol024Ibog96LTIb0_l90003o`000680002n00;o0P000ol0000S00?o00U[of_>Jli[of/0
0_l02LkocV_>JlkocP02o`07Jom[cV_>J`03o`08Jli[of_>Jlh2o`09Jli[c_o>Jli[00;o00S>Jli[
c_o>J`?o00E[cV_>J`05o`08Jom[cV_>olh3o`03c_l000P000?o0000HP000;/00ol50003o`000200
0_l02TIbAW96odIbAW82o`08AW96L_mbAW83o`06LTIbA_m60ol02DKoAW96LTKoAP02o`09L_mbAW96
L_mb00;o00M6odIbAW9600?o00Q6L_mbAW96LP;o00Q6LTIbA_m6LP?o00IbAW96L_l700?oH`000;P0
0olY00;o00W>Jom[cV_>olh00ol01/kocV_>J`Co00O>Jom[cV_>00;o00U[cV_>Jom[cV/00ol026_>
JlkocV_>0ol01/i[cV_oJ`?o00Q[of_>JlkocP?o00O>oli[cV_>00?o00S>Jom[cV_>J`;o2@000ol0
001P0000]P02obX00_l024IbAW96odIb0ol01g96LTIbog800_l02DIbog96LTKoAP02o`07LTKoAW96
LP04o`07AW;oLTIbAP04o`07LTKoAW96LP02o`08AW96LTKoAW83o`04LTIbAP;o00abooooL_mbAW96
odH3o`03A_l000P000?o0000H0000;<00olZ00;o00O>oli[cV_>00?o00S>JlkocV_>J`;o00S>Jli[
c_o>J`?o00M[cV_>Jom[00;o00W>oli[cV_>olh00_l02F_oJli[cV_oJ`02o`07cV_oJli[cP03o`07
cV_>oli[cP03o`09cV_>JlkocV_>00;o00I[cV_>Jol90003o`0005l0002a00;o:P03o`06AW96L_mb
0ol02G;oLTIbAW;oLP02o`07A_m6LTIbAP03o`08AW;oLTIbAW82o`09AW96L_mbAW9600;o00QbAW96
odIbAP?o00M6LTIbA_m600;o00Ubog96LTIbog800_l02DKoAW96LTKoAP02o`07L_mbAW96LP02o`T0
00?o0000GP000:h00olX00Co00M[c_o>Jli[00;o00W>Jli[c_o>Jlh00ol01/i[cV_oJ`?o00Q[of_>
JlkocP?o00S>oli[cV_oJ`?o00I[of_>Jlh4o`08JlkocV_>Jlh2o`08Jli[c_o>Jlh3o`08cV_oJom[
cV/3o`06Jli[c_o>0ol00lko00080003o`0005h0002/00;o:@02o`09LTKoAW96L_mb00;o00M6L_mb
AW9600Co00MbA_m6LTIb00;o00Q6LTIbA_m6LP?o00QbAW96L_mbAP?o00M6LTIbA_m600;o00UbA_m6
LTIbog800ol01W;oLTIbAPCo00MbA_m6L_mb00Co00M6L_mbAW9600;o00IbAW96L_l90003o`0005d0
002Y00?o0P000ol0000S00?o00Q[cV_>Jom[cP?o00O>Jli[c_o>00;o00U[c_o>Jli[of/00_l01li[
of_>Jlh00ol02<i[c_o>Jli[0ol026_>Jom[cV_>0_l026_>Jli[of_>0ol01li[cV_>olh00_l02F_o
Jli[cV_oJ`02o`09c_o>Jli[c_o>00;o00M[of_>Jli[00;o2@000ol0000700Ko100012IXo`E70000
Y`02obP00ol024Ibog96LTIb0ol02796odIbAW960_l02796LTIbog960ol01dIbAW96odH00_l02G;o
LTIbAW;oLP02o`09A_m6LTIbA_m600;o00Mbog96LTIb00?o00QbA_m6LTIbAP;o00QbAW96odIbAPCo
00MbAW;oLTIb00?o00IbAW96odH3o`03A_l000P000?o00001`000iGoIP020006J00006Kc0^H00jRn
00150000Y003obL00ol026_oJli[c_o>0ol02<kocV_>Jom[0ol01f_oJli[cV/00ol026_>oli[cV_>
0_l026_>JlkocV_>0ol02<i[cV_oJli[0ol01V_>JlkocP?o00S>oli[cV_oJ`?o00I[of_>Jlh4o`07
Jlkoof_>J`04o`07cV_oJli[cP02o`06Jli[cV_o2@000ol000070003UOmV00D000HY_P00__=60000
XP02obP00_l024IbAW96odIb0ol02796LTIbog960ol01dIbAW96odH00ol027coAW96L_mb1Ol01796
LTH4o`07LTKoAW96LP04o`07AW;oLTIbAP02o`08LTIbAW;oLTH3o`07AW96LTKoAP02o`09L_mbAW96
L_mb00;o00U6odIbAW96odH00_l01g;oLTIbAW800_l80003o`0000P000>nJ6H010000ol000020003
o`0004@0002O00?o:002o`07cV_oJli[cP05o`06O?o>Jli[0ol02<h?c_m[cV_>0_l020o63on<of_>
0ol01lH?ohelolh01?l01f_>Jli[of/00_l02LkocV_>JlkocP02o`07Jom[cV_>J`03o`08JlkocV_>
Jlh2o`08Jli[c_o>Jlh3o`08cV_>Jom[cV/3o`06Jli[c_o>0ol00lko00080003o`0000P000=VJ6H0
0`000ol000020003o`0004@0002L00?o:003o`07AW96LTKoAP02o`093lko0EKo??mb00Ko00G>3lko
AP03o`07IP5V0OllO002o`0<3ol1YP6Vohelo`6V0ol014IbAW82o`08AW96L_mbAW83o`06LTIbA_m6
0ol024KoAW96L_mb0ol01W;oLTIbAPCo00Mboom6LTIb00Co00M6L_mbAW9600;o00IbAW96L_l90003
o`0000P000>nl`000P000ol000020003o`0004@0002J00;o:003o`08Jli[of_>Jlh2o`0AcPo>o`76
0OnRO?o6ZlKoS;d02Ol00`o6o`07o`0>3lH?a_mlolH?a_mlolh3o`06S?o>Jli[1?l01`o>of_>Jlh0
0_l026_>Jli[of_>0ol01li[cV_>olh00_l02F_oJli[of_oJ`02o`09c_o>Jli[c_o>00;o00M[of_>
Jli[00;o20000ol000090006o`0002Vn0P000khY00150000U`03obP00_l02LkoAW96LTKoAP05o`0=
c_l1EP5Focco3`4?0@05o`06L_ooLS5b0ol01c7=olk0c/002?l00jH1o`02o`09<OlacC7oO?mb00Ko
00G>3lkoAP02o`073lkoAW96LP03o`08LTIbog96LTH2o`07LTIbA_m6LP04o`08AW96L_mbAW83o`06
LTIbA_m60ol00dKo000700;o1@001_mEiP05l`<000IVlnKVlfI60000U@02o`<000?o00008005o`08
3lh?c_m[cV/3o`05cC7=og`00ol00`76o`03o`08ZoooodKo<Ld2o`0=E/iFc_oFoljZcZ[o<@02o`07
cUKoc/g>c@03o`09c[koYLjUcZG>00?o00DaohfmS@07o`063lh?c_m[0_l02GcocV_>JlkocP02o`06
Jom[cV_>1?l01f_>oli[cV/01?l01li[of_>Jlh00_l01V_>Jli[o`H000Co003o10001[kcoom]iP@0
00@VJ6QVA`0005d01_l400049VSo1BL00olU00Ko00FRool?cP05o`06E_la<S4b1ol06G8aLS7oE/iF
cUKo5Z;oLS5boiJVU_lacC400_l01c5b<G8aokd00_l02lkocC7=<Oo=<Lda00;o00O></hbohfm00;o
00@[ohfm1ol024DboggoLTIb0ol01W96LTKoAP;o00UbA_ooLTIbog800_l02DKoAW96LTKoAP02o`07
L_mbAW96LP02o`P000?o0000E`0005d000>EofH00P001VP0001Vl`;V00>X_P008`02obL01Ol01C5U
oj9m00Co00O>E/iFoc7=00;o02OVoeG=EOo>:lh[oc7oA/i6c_o=<Lgoc_oF3mH?oj[>odKocUK>E/h0
0_l05R_>:lkoc[k>__nUc_oF3oo=<Lgo_Ol4:`0>ohfmoeKocC7=<LgoSG`3o`07O?ooJli[cP02o`08
Jli[cV_oJlh3o`08cV_>Jom[cV/3o`06Jli[c_o>0ol00lko00080003o`0005H0001N0003UOmV00D0
00HY_P00__<Q00?o9`04o`0U3oo>9LhUoj9mo`HaoeH?E_laonJ6iXKoS[f>og8aoc7e<OmFcP09o`0;
UZJFoc7o<2/`og800ol05KkocTK>A_lacC7=oc7oI]IVoc;><P02o`0CAR]6:dKo_Om6<4KoAC95<_mm
o`03J`05ogelodH00_l01g;oLTIbAW800ol01g96odIbAW801?l01dIbog96LTH00_l01W96LTIbo`T0
00?o0000E@0005l000>nJ6H010000ol000020003o`0001d00_lX00;o00<>oj/00Z/03?mU<FDaoggo
<BHa9PKo013V3nH?oleEcOl[oc4V<BHa0_l02<hFolibcW;>1_l5AP09okk>_/jnolh[00Wo00D?ePoo
c@02o`033lko00@[0_l4EP04oc7=<@?o16/02on=O8goJli[c_o>00Go00K>Jli[of/2o`09c_o>Jli[
c_o>00;o00M[of_>Jli[00;o20000ol0001E0000H0000fIXIP030003o`00008000?o00006P03obL0
1ol020l13oo>9LhU0_l01PHa1S46o`G=00OoQ^J6ohjm00?o00damC7e<OGoLS5b<Oo>00?o00XaofG=
IOl[<2/`0_l01S6n<Kha_P;o00PaL_oecOG=m@Oo10l02_m6ool?oc16<4H4o`03LV_o00A[00WoOGam
og96LTH00_l02796L_mbog960ol024IbAW;oLTIb0ol01W96LTKoAP?o00=6o`0020000ol0001D0000
H@000kkc00020003o`00008000?o00005`03obH01Ol01W;oolhVcP?o00>[ool00_l03G;o9S4V<Ol1
oldacC401ol03W8?obHa9S4VomKocQK>0_l02RK>9/hVoc7=<Ol2AP08olH?oljnc[h2o`0@5/hFc_la
XS7oa_mUcFG=I@Ko00G>3lh?o`02EP09ohKoJg9[LV_o009[1ol02/kooeKoJli[of/3o`07JlkocV_>
J`04o`07cV_oJli[cP02o`06Jli[cV_o2@000ol0001C0000HP001_l0000Y_P8000>n:@005P03oah0
0_l700?o00amc_oo<G8aL_l`og84o`0<3mH?oc46o`5F0Oo=0_l01/kocH3=P0?o00X?ooDamOm[0Ola
0_l01c26oc5b<G801Ol06c3o0IH1U_la__oE<OlaLS5booGoYZ^VohkUSP02o`06_XjnS[ko0`l00om6
o`033`04of]bJ`Co00IbQ_n=cHd7o`0<A_ooog;oAW96L_mb0_l02DIbog96LTKoAP02o`07L_mbAW96
LP02o`P000?o0000D`0005d000KoENH01O<30006I_?Vi_=V5003o`<000?o00006`000om<o`0400;o
00_6Y/KoSBGocRK>o`03EP03olfR00Co00P?oc4VodH1AP;o00HFcQK>old2o`03c_mm00?o00DV<Ol1
eP03o`06IPmV3olV0_l01<kocLh3o`0>3lH?a_nnoaHa5_o>5/h3o`0?aPo63oo=IOo63oo=ILeU00Oo
00<?Q_l01?l02Libc_n6LXKoO@03o`8?1?l02<kocPo>of_>0ol02<i[cV_>oli[0ol01V_>JlkocP?o
00?>o`0020000ol0001B0000G@001[kcoom]iP@000@VJ6QV4`02ob<000Koo_llo`03o`0@3jH?Y_o>
OLkoL_l`ES1F<0;o00C>iOo10_l0137oEP42o`06I_o>E/iF0_l04c5b<G;oOGco<Ol1JolacS7o<8H0
0ol01C5b<G;o00;=2?l01MDaeC7E00?o012mHKgoYZ^VohkoY/JVohjn0_l01P7oS[f>_@?o00MU<VDb
ooEb00So00MbooooL_n=00?o00<?L_l00ol020o>odIbAW960ol01TIbA_m6LP?o00IbAW96L_l90003
o`000540001k00?o90001_on0_mlC0Go00K6Y/KoSBD3o`EF0_l01g;>L/koS7`00_l0207oaPo63oo>
0_l02V/?o`K>1_nROJ82o`07e_laZS6Z<@02o`07Z/kocUK>EP03o`0DA/i6oc7=<Ola5S4F<On>EHiE
SUD6o`0E3lH?olgo3mH?e_mUcOl?oldacC7=00?o00O=<Oo=c/g>00;o00S>9/hVc_nR`@Oo00G>3lko
J`03o`06Jom[cV_>0ol02<i[of_>Jli[0_l80003o`000540001i00;o9`06o`051/h6cPH01_l03G8a
L_l`ES3oUZKoc^D02?l016H1IP43o`0<cV_>JolaLS7oO7el0_l03C7><Lhac_lacS7>og800_l07LiV
og8aLS7oLZ9boc7E<Ol2of6mHKeQof6mHKeQ00Oo01JV0JKo_OnV0JKoIC9Uoc3oIC9U<_o=0_l01c7o
<G8aLS400ol01/koc_n=c@Ko00M6LTIbA_m600;o00Qbog96LTKoAP?o00=6o`0020000ol0001@0000
MP03obP00_l038dESOl6cPK>1_l?o`;=00cocRK>9/koE_n[0J/3o`0:cYGoSAF=5Hgo3`;o0c400om[
3`06o`0@OOooU_nZ<JXaZ_mVoj[>ZP;o00PVcRK>9_o>APCo00c=oaHaooh2oeF>EHh2o`0;EHiESUGo
ELiEcUD01ol01mH?e_lacOl00eH01?o=<Ld2o`06_/jnc_lV0ol01c7ocC7o<Ld00_l0137=og`2o`05
cV_>Jlh00_l01f_>JlkocV/00ol01V_>Jli[o`T000?o0000C`0007@00_lX00Co00h1ogg>OOl6cPKo
EP5Fo`;=00GoLS5b<@02o`0?UZJFo`oocS7><OmmcWg>00;o00J>_HjmS[d2o`05YLkoL[d00ol33`09
olhac_mV0Oo>00;o00M6oliVcVK>00?o00@FL_nR0_l07C7oool2U_nmHOl2Q_nmHKgoo_n0cX3o3onR
1Z8600Go011Uoc16<4Ko<VGo<?la_S6n0_l02Ljmc[g>olkocP02o`06<S4b<Oml0_l00g;oo`03o`04
LTIbAP?o00Q6L_mbAW96LP;o20000ol0001?0000L@03ob@01_l04@o>ohH1Q_n=5Hgo1_l?aPo600Go
01K>oonVc_n[ofK>I_o>ULjEohdEojKo1C42o`07P360<Oo=S@04o`083olaZ_mV0FH2o`06E/iFc_o>
0ol02LkoA/i6c_nRO@03o`05O?ooohh00ol05_koSUGo0_kocUGoYP6Voldaoc3o<Ld2o`EF00?ocOl0
0eH01_o>__mFo`Da00[o<Ooo3mKo<Lda0_l01g9VofIboh`01Ol026_oJli[c_o>0ol00lko000600?o
D00006l01?lR00Ko00Emooo>o`040@03olim00Co00P1ooooiOn=c@;o00AbcW;>0ol06TH?APoocS7>
olkoYYJVokf>_On6U_nUcZG>0_l0135boj82o`0<c_mV0FKoc_m63dH?0_l04Li6cTK>oaIb5_mlX_l1
3oml00?o00?>og`00_l00keQo`03o`0EP?l?0@l1o`Koc]G>og:RL_l`AS1600;o01T`ES1Fokko<4H`
okg>_Lkoc_l?UPoo<C;o00:V017oc]K>e_mmO?m6LTIbA_m6LP03o`06LTIbAW;o2@000ol0001=0000
K003o`@000?o00007P04o`<a00?oOH`02Ol04<dacC7oiC3U<>GoX[fRolh2o`063jH?oliV1ol4YP0;
oc4aolH1a_laP3400_l01`K>1/koS7`00ol01fKoYC6Uolh00_l01lko5/hFcQH01Ol01:;oaPl3o`07
cRK>9/koO004o`03X/go00?o00>V0Ol00_l02c3e<?GocC7=<OmF00;o00<?oeH00eH2o`EF00Co<C4a
0ol02MH?e_laomH?eP06o`08S7gocV_>Jlh3o`08cV_oJli[cV/2o`P000?o0000C@0006T00olV00Co
00N6oc6m<Kgo009m01;oY_o=ELgo<C8a<S7oc^G>iLh7o`04EXIFQP?o01`aL_nmS[f>ojJFY_nmohJF
QYKoYLko0JKo<G8a1ol04lhacS7>olG>aLkoA/i6oiKoS/d01Ol0237><Oo>I/iV0_l02HGoQLkoP<f0
c@03o`07cW;oeLkEcP0<o`0<E_ooo_m6<4H`A_o>0_l00fKoo`06o`05Y_oo3ol00ld5o`03L_oo00?o
00IbAW96odH3o`03A_l000P000?o0000C00006L00_lW00;o00H?c_m[0Ol4<@03ohco00?601SocLg=
oldacOl1oc3U<?l?ohi5STF>o`l2o`0:mOo>L/iboleUc@So00C60LH10_l01LH?a_o>00;o02D?c_o=
<Lgo<JDaYC7oc/G>aLko5_m6cTKoILgoQ_nUcZG>YOo>00;o00PFoc5Z<F[oc@?o017>obK>9/komC3o
3oo=ELeEc@02o`03cGgo00;o0`l00omFEP02EPGo00O>ooo>cLk=00;o00S>E/iFoleUc@Go00=6c_l0
0ol00li[o`02o`06Jli[cV_o20000ol0001<0000I003obH01?l02`o>3ol1QP7o_C6m00?o00<?Y_l0
0ol09eGo<S7o0F/1olko3c7o_F6mHKeQolkEc]Go<G8aohjmodIVA_o=cP08o`03YP7o00?o01=b5W8F
oj9bX_lacS7o0Oo>aLk500;o00nFcYK>olgo<@laoc7><Lh00_l02/i6cTKocXG>QOl5<@0Eolibc_o>
of/1JonmS[goQS7ocWg>00Go00<`ool00_l02HGo<G8aoc7o<@02o`06c_l?IPmV1?l01Libc_l?00;o
00<aogd00ol01dIbA_m6LTH00ol80003o`0004/0001R00;o:003o`0;_Ooo3ol1J`5[oc400_l00c7=
<@02o`04A/koO@;o00?=o`400P43o`093hH?Q_m5STF>00;o00Ge<?D`m@04o`06cOl?YPnV0ol3<@03
olg=00Co00LaP360o`o>00Co00TaojDao`66olD00ol01/kocTK>AP;o00J6JhI[olh3o`0:Z_lFcQK>
ofXaJP;o00GEc]G>e@07o`07aPo6oeG=o`03IP08oggoofKocGd4o`09<HDaQOlFc_o>00;o00Kec_G>
oeH2o`07aOlFcQK>5P02o`0;iLkUc_n=of_>Jlh01?l00f_>o`090003o`0004X0001O00?o9`04o`05
<6_oOHd02?l03C4b<C8aoc5b<G;oOJ801Ol04/ibc_l?<@ooHKeQonKnomG>e@;o00NR<OooAVI600;o
00NFokg>_Ljm00;o00W5c_o>J/iZcVX00_l01<fUohd2o`05<LkoUP400_l01lj6cXK>olh00_l01/ko
3c4?<@;o00g>J/iZc_m6cTKocXGo00:F00?o<C400_l01VKocHk=SPGo00JmohHaQS42o`0A3jH?Y_o>
OOl?ohG>QLj5oc400_l01^Goc/g>c@;o00K>QLj5og83o`0;<OlaiC7UogamodH01?l01W96LTIbo`P0
00?o0000BP0005d00_lW00Co00<?odH00dH07_nmSOn[oleUcOlacC7=ofKoA/i6c_mmS?l?Y_mbcPCo
00F6odF>o`030@04oc3eo`:[00coS@F=o`oocR_>:ol4<@0:olG>aLko<H0aP0;o00K><Lhaoh`3o`0:
Q_oo5/kocRK>9P;o00JUcZG>of/2o`0<A_mnZWjZO_o>5/hF0_l03:H1Y_o>oc56<DKoc@;o00@[oleb
0_l4IP0BojKoI/iVc_mmo`o63on5<HDa0ol01NG>iOo>00;o01?>olDaaC75ojXaZS6ZolkUc_n=00?o
00<?ool00_l00li[o`02o`T000?o0000B@0005X00ol20003o`0002800_l00dIbAP02o`0<<6/`Jc3o
SOnV3jKo0ld04Olb<Ol1YP7o<G8aoj;oEXIF00?o00?=<Ld01Ol03^Kni_koeOl?0@oo<J8a0_l07LjF
cYK>oljmc_nVolG>aLkocV[oUZKocJG=oh2=00?o00LFAQI65_o>00;o00HVolhacS42o`0:LS5b<OmZ
cV[>JP_o01TFIQIV5VKocR_>:oo=c_laQS7oo/KnojH?00Co00UF3eKocXG>ojH00_l00c7U<@02o`08
mC7e<On5cXD2o`09cS7><LkoiC7U00?o00J6ooo>od`3o`03AW;o00X000?o0000B00005P00_lW00Co
00A[cV_o0Z/00om6AP02AP?o00?6Zol00ol026GocC7o0FH11ol03:Koo`mVolibcW;oO0Wo0j/03?n=
1OnVZoo>:lh[o`8a01go0LKoc/G>aOn0oj/1ZolacS7oS7go3olFcQK>5P02o`06cPK>1_o>0_l03:_o
A/i6c_nZOZYnZP;o00k=ooo>olg>cOm6<DHaAP;o00@[cR_>1Ol01FKoYPnV00Co00=VLVH00ol01@oo
QC7o00>F01OoiLko0Oo>iLkUoc75o`o6oc6Z<J[ocP02o`0@EW9Foljnc[ko??m[cV_>o`T000?o0000
B00005D00olV00?o00ebAW96odKo0@l13ol`00;o00<a<S400_l01<i6ohd2o`0F<_nV0JKo3onmHKeQ
_Oo>Jli[c_lac@Co00K>3lkocW85o`0<0Ooo3`4?0Oo>U/jF0_l00jI[o`08o`03YYKo00Co016UoonF
3iKoAQI6o`oo9S4V<@03o`0<Z`n[oc5b<OmZcV[>1?l04OG>mLkocNG=ofHFI_l13ol[00;o00@aolf0
1_l01NG>iOo>00;o00<[ohd01?l06JJFYYKo<Ol?QPoo<ODaohGo3`4?oc7><Lh00_l01<k6c/H2o`04
c_G>m@Co00=6L_l00_l90003o`0004L0001C00;o9`02o`07cV_oJli[cP04o`:[0ol01C7=<Lda00;o
00I6cTKoOJ83o`030OnF00:F00GoAHi5SP02o`04IPmV3`?o00JEcYGocPl4o`051/koXWd01?l00jJ[
o`09o`05cQK>5_l00/d4o`055/hFol402?l02aKo3`4?o`K>ojH?00Oo00G>A_mnZP02o`07eLkoc_G>
m@06o`04A_o63`?o00K5<LDaold2o`07c_o=<Ldac@02o`071/h6c_mmc@09o`073`4?onG>i@03o`05
aPo6oc400ol03`ooEW9Fo`l1okk>o`ooO003o`04cV_>o`T000?o0000AP0005000olV00Co00IbAW96
odH3o`03_Hko00;o0W803ola<S4boeJFodK>A_n=O003o`0=3c4?<OmQ_F7o0FKocP02o`06:_l`cC3=
0ol03<hUc_o>L/ko`7g0O@?o00G>L/kocP02o`07c_o>9/hVcP03o`07LUKo9/hVcP03o`06ILiUc_o1
1ol02c7o3`oo:ol`cC3=00Co013>J_oEc]G>olkeojKo_G:m1Ol06/g>oc75<LDaoiI[UV_oc^G>omKo
:lh[c_o=0_l01fKo_Hjmokd01Ol01C7oolh?00co01;6o`l13ooeo`4?0Omlog96LTH2o`P000?o0000
AP0004d00olV00?o00M[cV_>oli[00?o00M6cTKocH3=00?o00P?oldaojH1YPOo00@?LPoo0iH01om5
S_l1aP400_l05IEQUF7oULko9_laAC55<Oo>1/koXP02o`8a00?ocVH00ol04OG>mLkocQK>o`nFo`o>
3olF00;o00LFoc7=<Lda00?o0W800onRc@03o`0j3ol6cPKoc[g>_On<ogkoc_oEc]GomOo>I/koHLeQ
o`ooZ/jZc_laaC75oli6cTK>olgo3hH?olh6cP;o00N63hH?oleE00;o00@1olg=0ol03PooodKoO/en
o`7ocFG=4?l01Lkoof_o00L000?o0?l0A`0004/00_lX0008odIbog96LTH3o`0=ES3ocTK>ohjmoj_o
O@02o`0=<_mFUUKo<?l6c@K=1P07o`0I3ooo0FH1oiKo:PHZ1_o=ofHVI_o>9LhUcP05o`05_C6m<Kd0
0_l03PK>1_oUc^G>olko3iH?1_l0334F<AKoILiUoeHFEPCo00>R_Ol00_l022/6:`H[oc3=0ol01bKo
9RKoc]D00ol5YP0DokgoQS26olg>cOo5<LGo0_m[UV/3o`06eS7F<Oo>0_l02C5boliVc_n>_@02o`05
aPoocLh01?l03Lh?c_m5ojH?Y_nnS[h00_l011K=5/d2o`06P6Z0J_nR0_l01G96LTKo00T000?o0000
A00004P00ol20003o`0002800ol01V_>JlkocP?o1B/03?o>A_o=o`oF3on=O0?o00>VodH00TH03?la
XS7oZoo>L/koS0Co01@1ojJFoiEQUF6EobK>9/koAC55<@;o00C=<Lgo1C402Ol6cPK>1_oecP04o`0H
U_ooYOmEcEGo5/hFcQKo<Om6<DHaofG=0ol02<k5olh6cPK>0ol01lG>oaK>5/h00ol01lG>aOo>I/h0
0ol03@n63hKocZ[>oc75ooh01Ol01/G>aOl?QP?o00C>I/iV1Ol00lgo0@06o`03c_G>00Ko01`13`4?
ofG=ooh1oc6Roc5FoeF>EHkoSOm[cV_>0_l80003o`0004@0001600;o9`03o`06AW96odIb1?l01dKo
ES1F<5H01ol01j^6ZommO7d00_l04S1[<6_oc@Ko0HH1omG>eOnR`@?o19H01Ol6:PHZ00;o00QV9VHV
obG>o`:F00oocC7=oc6m<OnFo`K>1/h00ol00g9FLP02o`0=AFI5I_n>QHko5S4F<@02o`0AEQIF5_l1
og:=olk5c/Go1R/00_l01dKoaLk5c_l00RH01ol?oj[>Z/h01?l01Pi63_n6<0Go00?>ool00_l02<g>
olkEc]G>0ol01LkEc_mb00;o00C>obG>1Ol01Z_>ob_=:`;o0226oheESEGoYPnVokkooPonolgoAVI6
ofZ0JX3oO:;oAP;o00<>o`0020000ol000130000@`03obL00_l01V_oJli[cP?o00O>Jli[o`7o00<[
00OoE_o=ILeU00Go00Eloombo`04AP07oc7oZ`n[3`07o`0McW;>ojJFY_mQUF7ooP7o9/hVoc7oUZJF
oc7=<Ol00S401_o60LKo1P;o01;>oliVc_lVojEQYF7ocEG=olh3o`0Wc_laAS7oQP7ocFG=olk5c_l6
oiH?UPooaLk5olkoYPnVolG>o`nV00So00DacC7oc@02o`09c_o5c/G>olk500;o00K6olkEc]D2o`09
E/iFc_n=9HdU00;o00mbEW;omOl?UPnFodG>ALh02ol02S5F<EKoEHiESUD9o`T000?o0000@P000440
0_lW00?o00IbAW96odH2o`06LTKoAW961Ol03EKo:c0[okf>oj_oOHd01?l01@m6of/`00Go00`1oon>
oldacC7ocG84o`05U_l6:_l00P47o`BF1Ol00c7oUP02UP?o014[LR]bog;o1S46ofI5I_n>Q@03o`09
cRK>9/ko5UKo00811Ol00lG>o`04o`06ETIFolk52?l00lko3`02o`0;<Om5STF>oj[>Z/h00_l08RHa
9S7ocLk=omGoYXJVQ_o>eOl?olk6c/KocRG>o`ooZlh3o`0;AXI6QTKoEHeEooh00ol046[>oleUcOmV
AVI6I_n0JX02o`079HDUQOnRc@02o`P000?o0000@P0003h00olV00?o00K>JlkocV/3o`0<Jli[cV_o
JolVoh3=0_l01eI6ETKoIOl00j/01OmmcGg=00Ko00K>9/hVc_l4<@03og;>00Co00=m<Gd02?l02Lh?
oc7=<LgoUP02o`043oo=c@Ko00M[c_o>I/iV00;o00PV<BHaof6UH@?o00bEc_l6cPK>1_m6o`42o`04
aOmQc@?o00C>_/jn1ol00mG>e@02o`03ELgo00?o01H6<@HaoldZcB[o<Lgo9_o>1/h6olk51?l05<H?
aPooeOo>I/kocUK>ohdUojH10ol02ldacOl?UPnFodG>00?o01[5ofDaIC7o:XhZoeHaES7oSUGo:omZ
SVZ>JP;o00<>o`0020000ol000110000?002obL00_l01W96odIbAP?o00Q6LTKoAW96LP;o00@[cR_o
0/d01Ol`:c0[00Co016[3j_oOHgo3oo=P?o>:lh[cP02o`05S[f>_Hh00_l02_G>ogibOW9noc`2o`09
L_o>9/hVoeG=00?o00KUc^G>old3o`089_lVLRIbog82o`0E<Ola1S46ofI5oc7ocLk=c_lVcRK>00Co
00_>QLj5okebolk=cP02o`0BU_o><<koeLkEobI[ohg>ojKo1C403_m5STGoc_mFcUKo<BHa0ol00g;>
LP07o`043jH?YPCo00C>ool?1?l01<jnc[h5o`0RQ_ooJ/iZcV[oJ/iZofG=IOm6ITIVoh3oEQIFohDU
QBGoS@?o2@000ol000100000>@03obH01?l04<i[cV_oJom[c_o>Jli[of/4o`03cRK>00Go00M6ool[
cR_>00Co00K=o`oF3ol2c@05olhVc_l00XH03ola<C7oZol?cPooOC5m<@02o`07U/jFc_o>3`04o`06
cPo>olh?1?l01ljFcYKoJlh00ol02C7=<Lgo<BHa9P02o`0:UXJFoiG>ULko1P;o02_>E_ooaC75<Oo=
HLgoc_mFcUK>okg>_OoEoc5F<Oo=o`o63ola1S46ob[=00?o00HV5RHFo`H2o`043hKoLP;o00WUog;>
L/ibolh00_l018KocED4o`0<E/koc_o=<Ol?a_o=1?l03375<LDaoc5U<OlZSPSo00l[<B/aohiZS_on
okf=_Ol020000ol000100000=P04obD00ol01dIbAW;oLTH00ol01dIbAW;oLTH00ol02dKoJ`7oc_mb
9_o=00;o00G>:lh[cP02o`03cXgo00;o00=[3ol01Ol06LkoJhI[okf>oj^VZoo>mLkoOW;o0JKocW80
1?l01bG>omG>eLh00ol01lkEc]GoLRH01?l02c8aoc4b<C;o1S4600?o00L?<@laolg>00?o00X?9Poo
Y]KoQLj51_l028JFQYJ6oc3>0ol02bI[9V/VojJ6YXKo00@a0ol01ljnoliFcUH00_l0131V<6H2o`08
c[k>__mb<G83o`0DJli[c_n=L_m[o`nVojKo__l?aPl2o`0=QLj5c_o>J/iZof[>JP03o`0GILkoSIF=
UOlFEQIFohDUooh2oh2=P?l02@000ol0000o0000=002o`@000?o00008002o`07JlkocV_>J`03o`07
JlkocV_>J`03o`07Jli[ofH1IP02o`05cZK>Y_l00/d01Oo>:lko00:[00CocDG=0ol01H0aP?n000;o
18H01olaoj^VZjH01Ol01C7oaPo600?o00W>eOnmc[g>olh00_l01`h?olh?cPl00ol03Ldaoc7=<Lgo
cC7=oc400_l01Po>3on6UPCo01S>9/koE_nV0JKo<LGoAR_ocC7=oeK>E/h3o`0?_LkoES5F<Ol?o`o6
3ola00?o00k>5_o>L/ko5RKo3hKoQP;o00K>onG>iLh4o`0=EW9Fo`n63omEo`mV3`07o`0?a_oo<Ola
JS5Z<OlaaC7500?o01C>oeDaEC7oELiEc_la:c7oSV[o0POo20000ol0000o0000<@03obH01?l01TIb
AW;oLP;o00Q6odIbAW;oLP;o00m6L_mbAW;o0F_oaYKoLRH01_l04LkoYPnVohg>o`oo<LhacS7o00;=
00?oJhH01Ol01J_ooaKo00:R0ol03:Koolkoc[k>__lUcPWo013Eooo>oc4b<C;o<S4boc8a1Ol00lh?
o`03o`07L/koLS5b<@03o`0@eZKFohGoAS16<?nRLZ;oQP;o00`Volh`cS3oJbKoUP46o`069R/V:bH[
1?l01EKoJli[00;o00jVcZK>okk>obJVoeIbEPOo00=[<?l01?l00libcP02o`0<c[g>_Oo>QLj5of[>
0ol03AK>5/koILiUoiF=UHd01?l00aKoo`02o`07cQK>og;=o`090003o`0003h0000_00;o9P03o`07
cV_>Jom[cP03o`07cV_>Jom[cP04o`0=Jli[c_o>o`5Vo`oF3`03o`05mLkocGh00ol3Z`0;olgo3nH?
oh0aP3401_l03LdacC7=olkec_GoX[d00ol02>G>iLkoc]G>0ol020o>3ol6oaF=0_l4<@07oldacOo=
<@04o`04cPo>3`?o00UbI_l6cPK>olh00_l00lh?o`05o`05AR]6:dH01_l03?G>mLko_Ljmoc7o3`;o
00lVoldZcOlFcQK>5_o6old00_l040n63oo>oli6cTKoc_nV3jH4o`063g;ocZG>1Ol00`nFo`03o`03
mOla00<a00GoJS5Z<@03o`0=UHkoc_G>mOlaEC7oE@03o`03AW;o00?o00G>olibcP06o`T000?o0000
?@0002`00olW0008og96odIbAW83o`07LTKoAW96LP03o`07LTIbA_m6LP07o`0=U_oomOl6c@K=oj:U
XP08o`0A3hH?oc7>ojKoZ/gocC7=<Ld00_l011Ha5S43o`0Pc[k>ooG>mLkoc_l?cPoo3onE<?n=YHgo
c[g>_Olb<C84o`05T4J@og800_l02LjUog;>L_mbcP04o`03Zooo008?00_oLW9bodH`A_lVo`03cP05
obK>9/h02?l03bIV9VKocHk=ob/V:ol13`05o`08Joo>Y/kocZH4o`04Y_ooD0Co00<?cOl00_l01<ko
ool23`Co00XacC7o_Ljmolj50_l03S3oZTFZAOo>5/koILiU0_l01<m[cf/2o`05<LhacS400ol01IG5
ofF=00;o1`02ocl0000[00;o9P03o`06cV_>Jom[0_l02<i[of_>Jom[0_l01li[of_>Jlh01?l01@7o
SLf=00;o01?>iLkUooG>mOmncOmFA_o=c/g>00Go01dao`o63oo>cOo=<LgoQV_omLko3f_ocPo>3ooU
cP04o`03cPoo00;o00T6<@HaohdESOl00c401_o=ool?LPOo00FZcZ[>ZP06o`04cQK>5P;o00<?U_l0
1_l00dKoAP02AP06okg>_Oo>0_l01<h[og82o`06mOlVcRK>1_l00aKoaP02o`04<?o=c@;o00C>A/i6
0ol00lj6cP05o`03ILko00Co00>Uool01Ol0280aooGomC7o1342o`09:bH[9_nESYF>00?o013>oooo
c_mbAW;o0@oocZ[>0_l02Hk5S/F>olf0o`090003o`0003`0000[0003o`3o02401?l01W96L_mbAPCo
00MbAW96odIb00?o00IbAW96odH2o`07LTKo0OkoLP02o`0C<NGoc_G>mOl6cOnRoeH`ES3oc@02o`04
3onR_@?o00<?Y_l01Ol00lgoJ`02J`0:oc7oUS6F<OnncPCo00>6LXH00ol03/iEoc2E<9GoYHfUokg>
1ol02eG>okeQ_Oo>YLjU00;o00^>_HkoLS5b<OnF0@02o`06aLk5olfm0_l012H`9S06o`04LQIb5P;o
00HVcRK>ofH2o`055_mQcF401?l02Z[>Z/ko_Hfmolh2o`053omb5W800ol00b_oS@04o`03`Ooo00;o
00UU5FDEoldacC400_l01Ldaokg>00?o00T?<0l`3om5ZTD00_l07Z;Uool?<@laof_o0@l1olhaoiJ[
olFEaIGoSFF=o`T000?o0000>`0002/000Co003o7@03o`07Jli[of_>J`03o`07Jli[c_o>J`04o`06
cV_>oli[1?l01<i[c_l20@;o00Rnc[k>__o>i@Ko00EFAUI6EP02o`08cVK>I_nROJ83o`03<Lgo00;=
0_l018I[QV/3o`04J`m[3`?o00Fmc[gocP02o`0><OlaIC5Uoc46<On=5Hd3o`04Y/jVcP;o00`U<BDa
odF>AOo>Z_l2YP0:ofG=IOo>5_l?eP;o00V0<H0aP?n=cOl00dH04Ol?olk=c_o>:lkoI_oec_G>00;o
00TFcQK>ohdZSBX00_l01C06<0H`00Go00K>I/iVolh2o`03cQKo00;o00=UcVD00_l04Gk5O/GoIHiU
S_n0<H3o<Ola00?o01Jm<OlV:bH[9_nES_n[Y_o=<Oo>:lh[1ol02lkoePoFolF>aHk500Go20000ol0
000k0000:`001Ol0003o01X00_l04DIbog96LTKoA_m6L_mbAW9600?o00M6L_mbAW9600?o00I6LTIb
og84o`07JolaiC7U<@03o`03IW;o00?=00goES1FohK6odH?A_nm00;o00c>oeG>ELkocH3=of/2o`05
9/hVoc400_l01QKocLk=cP;o00eUcVG>oliEc_nE<9D`00?o02P[L_mb9W;o<EKoELiEof6mHOnUojJ[
Y_nmS[go<OnF0OmVJoo5c/G>1Ol04C3o3`4?ojG=YOlFoc66<Oo>00;o015FoaIF5UHFof7=o`mFoljZ
cP02o`08SC6=o`mV3fH2o`085_ooob/FolD2o`0A<OlaEC5EoaEU5FGo<Ldaoc400_l031Ko:S0Z<?l`
3c0?<0;o00V[YZ_oiJ;Uoc400_l01Poo1_nR_P?o00R[UZ^FoiG5U@;o00DaLS5bo`080003o`0003X0
000Z0003o`0000<000?o00005@02o`08cV_>JlkocV/3o`06Jli[c_o>0_l026_>oli[c_o>0_l01f_>
oli[cV/01Ol066_>Joo>_/ko3mKocYK>olf0cOmFomH?ePOo00MV3fKo<Lda00Ko00g>1/h6cPKo5/hF
c_nm00;o00daoc65<HGoIC5Uoc4600Co01:6cXK>olkoEVIFoc4U<Om5STD3o`>V00?oILd01?l03]Ko
IXIVQ_n0<Om[oh3=0ol00`4?o`06o`AV0_l04li6cTKocQK>5_lZojJ[Y_l6<?l00_h01_lZcB[oIP;o
00?>ool00_l00aK>o`02o`0AO/EnaOo5O/EnohiUS_n0<H000_l021Ko5/ko_C6m1ol01:^VZjH7o`09
3olFcQKocC7=00?o00GF3on>a@09o`P000?o0000>@0002X000?o000010000ol0000A00?o00M6L_mb
AW9600?o00I6LTKoAW83o`08LTIbAW;oLTH3o`06AW96L_mb0_l03lh?o`6Vof]bJolaolJ6aP0<o`0K
Q_la<Oo=<Ldaoli6c_mEomKocDG=obK>9/hV00;o00@FAQI60_l0336m<KgocVG>oliEcP?o00MbAW96
ob]b00?o00TaES5FoeG>ELh04_l03V]VJfKoc_l?<@ooHLeQ0ol05@K=1_mbcOn6<HKoA_mFcUK>E_lF
EP04o`05EPmFolh01Ol00c6=o`05o`03cQK>00?o0155__laIC5UoeDaEC7oIAEU5@03o`08U_lFA_m6
oc02o`03<0oo00?=00?oY_l00_l03W;oSZF>YHko1S46<Onn0_l00e3oS@03o`06UOoo1/d60ol00lco
00070003o`0000X00_l00fP0000200049VSo1B@0000Z0003o`0000D000?o00003P02o`08Jom[cV_>
olh2o`06JlkocV_>0ol02<i[c_o>Jli[0ol01V_>Jom[cPGo00@?o`4?2Ol03@ooQ_nmc[gocEG=ELd0
0_l01kk>_/koL/h01ol045IbE_o=<Lgo1/h6oeHaolh2o`035_la00<a00GoQC65<@03o`07cV_oQ/j6
cP06o`07IUIVEVKo9@03o`0D<Oo=P<goL/ibofKo_C6m<KgoQVH3o`0=JhI[Q_o=P?mF<Oo=cP06o`09
I_o6ZlKoA/i600Co00?>L/h01_l019Ko_Hd6o`04ZjKom@;o018aof6EHOmnaGk5olEnaGkoSVD3o`07
QPn63oo>5P03o`04IV]VJ`Ko00W>I/iVc_la_C400_l01<hFcQH2o`0<SZZ>Z_n0cH3oU_mb0_l00hko
0003o`P000?o00002P000ol000020006I_?ViZRn8`0002X000?o00001P000ol0000:00Co00I6LTKo
AW84o`0@AW96L_mbog96odIbAW;oLP;o00I6odIbAW83o`04LTIbAPGo00P[L_n>cHk=SP;o00AFLUKo
0lh01oo=S/goa_l01343o`0RcUGoiJ;UX_oFc]KocDG=obKoAUI6E_lFEQIFokda_Oo>I@Co00IbQW:6
odH3o`045LkoS@;o00=F<Ol00ol00`ooEP02EP0?okf>_Oo=ofI[I_nmS[f>00?o0lh02ol?<@ooHOm[
:f/[00;o00Fmc_n=_@02o`04APm63`Co00DVLRKoLP02o`0:LTKoc_nFYYKoS@?o00Ebo`6V0@02o`0A
P360oki5_TGoIC5U<OlaEC400ol01[g>_Oo>UPCo02Keool`3c3oc_mEcUG>og9FLUKoYHkooP7o<@Ko
Jom@OU1nodF=o`>F00GoD7i@o`040003o`0000H000?o00001@06o`<000HY_P00__<S0000:P000ol0
00070003o`0000H00ol01li[cV_oJlh00ol01li[cV_oJlh00ol01li[cV_oJlh00ol01/i[cV_oJ`;o
037>Jom[cV_o3jKo0Oo>Q/koELeEob]6ohK>Q_nmc[gocOl?ePooc[koe_laIC5Uoc7=00_o00AF<EHa
0_l01AK>5/ko00<a0ol01hK>Q/kocV/00ol02JKoIC5Uoh1mP002o`03c^G>00;o00LaES5Foh3=00?o
1FH02_nm<OnFoljmc[d6o`06ES5F<EKo13401_n=P8goaP;o00HaaC7ocZH3o`04Jli[cP;o00>FYYH0
0ol00kgoo`02o`0HY_ooUOlaaC75oiEQUOo5O/Enogk5o`Ko1C42o`0BL/kocW;oL_m[olh[c_n0<H0a
1Ol00c7oo`03o`0<5_oF3mKoZXjZoh3o0iH2o`05S/F>aOl030000ol0000500051Kh00?l010000ol0
00020003o`000240000Z0003o`0000P000?o00000`02o`07LTKoAW96LP03o`07LTKoAW96LP03o`06
LTIbog961?l01W96L_mbAPCo01QbAW96odKoJdKo0HH1og8[L_n>oc0[<2/:o`0>U/JFoc7o0HH1oliE
cUD2o`0Gc]GocLk=c_o>cOmFAUKoQYKoEQIFokd00_l01iH?og9FLUH00ol04`ooQPn6oaG>5On0SOo=
c/go5_l015H3o`0@cLk=ofI[IV_oS_nV3jKocP;o01C>ogjmO_l[Jb][ojKo_Ljmokf=_@;o00J5cXG>
QLh2o`053hH?odH00_l00`mFo`0;o`0TcYG>oh0aP37oAKi5ofDaIC7o<OlF<AKo_LjmofKoeG;EooG>
0ol02<jVcZKocUG>0_l00fF>I@03o`03XS6R00;o00Q[eV_Fogi@OP;o0iH02?nFoe1nD7ko3@000ol0
00040005i_?V0?l010000ol000020003o`000240000Y00;o2`000ol00003o`06cV_>Jom[0_l02<ko
cV_>Jom[0_l01/kocV_>J`?o00M[cV_oJli[00?o00M[cV_>oli[00Co00FVo`4?0@07o`0?:dH[A_mV
o`K>obG=9LdU00Oo00KF3omU<FD2o`07c]G>eOnmcP06o`08<On6UXKocQH9o`05c_oocPl00_l07ZJF
YYKo<FDaogf0OOo>obK>9_mF<Oo>oj[>Z/jZo`9V0ol4UP;o0c403?mUSVF>oc5Foj/1o`<a00koSOoo
3olaaC75<Ol1aPGo00=63ol01?l06W9Voc7oHEEQoiDaUC7oaC75oiEQUOo5O/En0_l01@K>1/ko008a
00CoAS561_l058GoQOo>:lkoP37oYZ_ocDG=ojKo0/d4o`0C3mKoZXkoD?koU_oF3mKoaHk5o`0>0003
o`0000@000BnP@3o10000ol000020003o`000240000Y0003o`0000T01?l01W96L_mbAPCo00IbAW;o
LTH4o`05LTIbog800_l04DIbog96LTKoA_m6L_mbAW9600?o00=6LTH01_l06786LPKocOl[<2_oIS5V
o`K=ohj0S_nVo`C=1?l02LiEojH1olkEcP03o`05_Ljmc[d02Ol02<EbaOl6olf=0ol04@ooolh[ohH?
Q_lEcQGoP8f000;o00lFJaI[oeKoIRIVolg>cLh00ol01C3><?nV00;o01=Zoljmc[go_Gjmof_oYYJV
okg>00Co0`l03?o>QLko3`7oD?mbc@Go01Wn3ombojYnofZ0JX3oULjEoc60<Om5_TFn00Co01G>oc4F
<AKo_OmV9VHVooF>mOlacS401Ol03LkoojJ[Y_n>IOm[0V/00_l01<k=okd:o`09UZJFY_mnD7i@00Go
2002o`L000<YI_l010001RVn002n:B<0000Y0003o`0000H00ol01f_>oli[cV/00ol01f_>JlkocV/0
0ol01f_>JlkocV/00ol01f_>JlkocV/00ol01V_>JlkocP;o00U[of_>JonV3ol00dH00oo>QP05o`03
A_mV00AV0ol02<dUojJ[Y_o=0_l00lkoO@03o`093lH?a_o>olko00Da01Co0Oo=IOnmc[g>olko9S0V
old5c@;o00C>5/hF1?l01JKoIC5U00?o00J6olhVcRH2o`07cRK>9/koZP02o`065_o>_Ljm0_l01C5Z
<F[o00<a00CoSVF>4_l01S7o0LKoD0go01@aiC7UoeEQEOlaUC7oaC75oiEQU@;o00W>mLkec_o>1/h0
0_l044HaAS7o_onm<KgoQLkoE_l2c@?o00J[YZ_ocOl3YP;o00O>YLjUokf=00;o00@?og9b1?l01PoF
olF>a@;o00C>olf00_l50004o`00o`H000>V:Ol010001VKci^KcIR<0000Y0003o`0000@00_l024Ib
og96L_mb0_l01dIbog96LTH00ol01dIbog96LTH00ol01TIbA_m6LPCo00I6LTKoAW84o`0>AW96odKo
YPoo<2H`9S02o`0;cW;oXYGoIS5V<FH00_l01lgoS_nVZjH00ol01XK>Q/koO@So015b:g;o_Ljmo`81
ohk=S_n=cP03o`061UH6E_n=0_l02/kocR_>oiKocX08o`8?00_oJaKoYYKoIRIV9P02o`061TH6A_l`
0_l07lkoJ/iZc_nmc[go_Gkoo_o>olibc_mFoken_GkoSGd00ol00`7oo`02o`03cVG>00;o01R>EOla
OC7oOZYnZ_n0JX3oULjEc_n0<H03o`093olFcQK>5_lF00;o01EbobIV9_nVU_n>mHkoc_o6olKoALd0
1ol046/2Jol13oo>cLkoSOn6eXH3o`04c/go_@Ko00P?<@ooSH2=o`T000?o000010000`EX00040004
9VQXIR@0000Y0003o`0000800ol01f_>JlkocV/00ol01V_>JlkocP;o00Q[of_>JlkocP;o00I[of_>
Jlh3o`07cV_>oli[cP03o`07cV_>Jom[cP05o`E60_l020K>1/kocGko0fH01On[ZonR00Go00W>L_o>
9/hVoj800_l02mGocC7=<Oo>Y/ko008a00?oYP401ol01ljnoc0V<2H00_l04<h6cPKo5_nFYYKo9HdU
SOl2c@Go00PVofK>I/kocP;o00HVoaK>5/h2o`091/h6c_mZ<F[o00@a0_l04oko<?D`olko3iH?olda
cC7oX[d01Ol06H0aP360ogjEO_n0OX3o<NDaiOmEHEEQoiD01ol02Li6cTKomLkecP03o`0<LPmboc56
ofJookda0ol00eK>EP04o`0=E/kocC7=<OnVomH1eP07o`0<3ooo9_o>QLj5okf=0_l02dKocTK>A_n0
cH3o00P000?o0000<`0002T000?o0?l00_l01TIbA_m6LPCo00I6LTKoAW84o`06AW96odIb1?l01DIb
A_m600;o015bA_m6LTIbog;oLTKoAW96LP03o`0:LTIbojKo<2H`o`:V013ocW;>oiFRUOmVo`4?0OnR
0_l02IH?og8aL_o>QP03o`08c[k>__oecOD5o`03c_l100;o01@?<?n>cOo>cLk=oeH6oc16oeK>EP?o
00P?UPnFolj0cP?o00D`:_o=9@02o`04UZJFYP;o00IVcVK>odH2o`0:c_o>9/hVoliZcPSo00G>Z/jZ
cP03o`=F00Co_Gjm1ol01G;oILiU00;o011ESUF>ogdaOOnZOZ[oP6Z00ol03VG>og;5L/Go5PlF3olF
0_l23`Go00EVoiJVUP03o`05LRIbolH01?l01oEbmG;oXW801?l02@ooolkocC7=<@02o`0?_S2n<?o>
cLkoSOl`:c0[00[o20000ol0000b0000:@02o`06Jom[cV_>0ol01li[c_o>Jlh00ol01li[cV_oJlh0
0ol01li[cV_oJlh00ol01li[cV_oJlh00ol01/i[cV_oJ`;o00c>oli[c_nVZjKoA_l3YPGo00?=O_l0
2Ol00fK>IP07o`09cUKoeLkEc_la00;o00=bEW801ol07EH?E_mEcOo>_/ko9_l[AR]6olkocPK>ojJF
Y_n=00;o00MVoc6m<Kgo00?=00[oc_ooc_lV5RHF0_l02/kUc^GocPK>ofX2o`043lKoc@;o00XVooD`
mC3oUZJF1?l00c7oo`03o`04OTGoHP;o01haP?nU<_nEOYGoOX1nonDaiOmEHOlaogdaOC7oLS08o`08
3oooo`oo9Ld2o`09I[mVofIFojK>00?o00M6c_o>oeK>00Co00=VLVH00_l02/h?cPoocC7oa_l49PKo
00AFAUI60_l02C5m<Oo=<Ldao`090003o`000340000X00;o00E6LTKoAP02o`0ALTKoAW96L_mbog96
odIbAW800ol01g96odIbAW800ol01W96L_mbAPCo00IbAW;oLTH4o`09LTIbog;oYZ^V00Go00JVonKo
SC43o`03cW;>00;o01EbZW:ZL_nFonKo<Kda_C7oLPKo_/h01?l01<k6c/H3o`03c_G>00So00?=c_l0
0_l01C16<4H`00;o00AFcUK>1_l025H?EPoo<2X`1_l01/kUc^GocP;o00K6olhFcQH7o`033j_o00;o
00Q6ITIVoj[>o`BV00?oEOl00_l0237=oomnAGko0Wd04omUokdC_On>EHkoOC5mojYnZWh00_l01c7E
<OmUcVD00ol01hj5olhacS400ol43`07ohimS_nFo`04IP;o00Ibc_o>Y/h4o`05c/g>og800_l09PmV
onG>iOlaoeH?E_l`__oFolk5c_l[<2_oYZ_o<H0aole5cDGo20000ol0000a0000:0001Ol0of_>00?o
00O>Jli[of_>00?o00K>Jli[of/2o`08c_o>Jli[of/2o`06c_o>Jli[0ol01f_>Jom[cV/00ol01f_>
JlkocV/01_l0179FLUH2o`0BAW96ob[=o`K>1_n[Y_laXS6R0_l026IbI_lacC7=1_l01Po>3lkoLP;o
00c>olkUc_m6oljmc_l2c@;o02G>_/ko:dH[ohKo1/h6ojKo:/dZcOo>I/ko_C7oU_mEcUG>o`o>00Co
00f[3j_oiLkoQ_o>cLk=00?o00k=<OlVcRK>oc3oUZJFYPGo01`acOmnodEnAOmROF;oYC:U<_nEOYGo
OX1nP?la0ol0434F<AKo<GgoY_o=<Ldaolh2o`033fH?00Go00?=9Ol00_l016IFIUH2o`06cXK>Q_o>
1?l01<j5cXD2o`043lh?cPKo01763lH?obKo3mH?ogdaOOm6o`03YP04ogdaO@Oo20000ol0000`0000
700012IXo`D80003o`0000;o00IbAW;oLTH4o`06LTIbog961?l01W96L_mbAPCo00EbAW;oLP02o`0A
AW;oLTIbA_m6odIbog96LTH01?l01okoXZFRolh00_l04XK>onH`i_n=<Oo>ojJ[YZ_oLP;o00Pac_oV
c^Ko<@;o00TVolhUcRGocPl00ol09/h6cPKoc_l[9R_oS/f>oeG=oc7=<Lgo<?l?c`ooc_l?IPooSVF>
1Ol02C3o3f/?ohfZS@03o`03<<d`00Go00LFoljFc_o500;o00T?olhbcS;oITH01?l2YPCo00eE?Oo=
oc4bogi5OTGo009m00go4kdC_On>EHkoOC5m00?o014ZZ_oE<MDaofGoZjJ[ohj5SP02o`04<IHaUP;o
00>=9Hd00ol00ld?o`03IP06ohIVog;>0ol01W:[oj_ocP;o00C>E_mV0_l02BKocJ[=Z_mF3`04o`07
U]JFolG>a@03o`08ZjJ[oc60oe06o`P000?o0000<00001/000IVlnKVZ;h70008o`000?m[cV/3o`07
Jli[of_>J`03o`07Jli[c_o>J`03o`07Jli[c_o>J`03o`07Jli[c_o>J`03o`06Jli[c_o>0_l02F_>
o`42ogk=OP02o`04QPn63`Go00?=:_l02?l01C75<LDa00Go00Q6cTK>oldac@?o00M6c_o>mLke00;o
00M6<DHaokg>00Ko00>nc_l00_l4QP?o00_6Y/KocB[oI_lUS@03o`05YYJVolh00_l02RKoc[g>of_o
:/d3o`033hKo00;o00QFcUK>oldac@?o00?>3lh01Ol0:5Go?O@mogkUO^GoOTEnogeRojDbYC;oUGjE
O_n0oc7oSXF>QOlF<AH2o`BV01So<Oooc_l?IPooUZKoP<f0oli[cV_oE_l3J`?o00H?LPoocTH3o`04
ETIFAP;o00Oec_G>olg>00Co0W84o`063omm<Om@1Ol00jKoo`02o`05A/koP<d00_l80003o`0002l0
000K0006:Kh00;kc1`000ol00002000DodKoAW;oLTIbA_m6odIbog96LTH3o`07AW;oLTIbAP03o`06
AW96odIb1?l01TIbA_m6LP?o00=bAW801Ol01j;oolkFolh00_l018Ko<Hd3o`03L/ib00;o00S>P<ko
<LhacP;o00[>SLko9PlV3olU0_l02:KocW;>L_l60_l01W;o9R/V:`?o00G>__o=S@03o`05cEK=o`l0
0_l00liFcP04o`0:S_nV3jKocQG>5@Go00hVIRIVoc3oJhI[ohiUSP?o00W>IOl?YPnVoc800_l00aI6
5P06o`0AJ_lbK_lmEOlb<C8aodEnAOl00gd02Onm4kdCoeF>E@02o`0@aC75obZZ:_laeOmFa_n[YP?o
019VLVIboiKoUZJFobF=9Hgoc@l3o`06QVJ6oeIV1ol03DKooliFc_m[obK>9/h00ol3<@?o00C=L_nm
1_l01@oeokf=00;o00Z6oc5b<G;oSC7o2@000ol0000^00006`000ol000020003o`0000D000?o0000
0`002?m[cV_>oli[0ol01V_>JlkocP;o00Q[of_>JlkocP;o00I[of_>Jlh3o`06cV_>oli[1?l01Li[
c_o>00;o00A[oj;=0_l00g9FLP03o`0;Q/j6ole5olh6c_l00ZH04Oo>ELkoaC7oYP7o_/fnoli600Co
00H?J`ooA/h3o`0F:lh[c_laA_m6<OoUc^Go_J;ocPK>1P;o00@FcQK>0_l03<eEoomVcVK>ohdUS@;o
00PaXS7o9/hVcP;o015[QV^6oldZoj_o<H0aP?o>EP03o`035/ko00Ko01eQUF7oEGkom3goO^EniOmn
AGkoOF9moc:U<ZGoOP03o`0><AHa5_n5SXGo5_o63lH3o`06<Ldao`o>1?l00jJFo`08o`0B3g8?of_o
EVIFoleEcEGocW;>0_l01DKoJfI[00Co01oeolG>aLko9/hVcRKo_Hgoe_l?cPo>okgo3mH?odK>00Ko
20000ol0000^00006`000ol000020003o`0000@00_l60003odIb00Co00I6LTKoAW84o`06AW96odIb
1?l01DIbA_m600;o00IbA_m6LTH3o`07AW96odIbAP02o`0HLTKo0Oo1L/7oc_l6APKoQW:6oc6=og;o
0jH03_n0cX3oc_l?0@l1olj=0ol01g;=L/goYS400ol04G;>og:FLYKo:omV5VHFokk>00Go03;=oom[
oliFc_l[5_n=LXgoYPnVolhEo`4?oaK=5_mV9_l?L_m[QV_oS_nFIYKocVG>I@;o00?ec_l00_l06QI6
ogjdO[CoYF[o<Vko?EDmoc4b<Om5OTGo0gd01Onm4kdC00;o00]5:olaaC75obZZ:P02o`0:E/IFoc3o
YHjUSP?o00@a<S4b0_l00libo`04cPOo00eFIUKo<On5SXF>odK>00?o00=[IV/00_l01PK>1/h6o`8a
00co5_mbcG;=ohgoUZ/7o`03QP7o00Co00<acC401?l80003o`0002d0000K0003o`00008000?o0000
10000ol0000600;o00O>Jli[of_>00?o00O>Jli[of_>00?o00O>Jli[of_>00?o01S>Jli[of_oJlko
cV_>Jom[of_>Jol1J`45o`04cQK>5PGo00=5cOl00ol2YP03oliE00_o00HaEC7oL/h4o`09c^GoP<j0
olh[00?o00E6<DHaAP03o`04<H3oO@;o00i[3f/?olko<DHaA_o=E@Co00aVoon[aZ_oXS6Rolh;o`08
3j/?oh0aP344o`04cLko5P;o01hm5CdEoiGoOUEnoo@mm?oUO^GoOTEnogeROOlbYC82o`09HJEQYOlF
<AHa00?o0Pl00oo6o`03AP0:oc7=ojKocC7=<@;o00I[cV_>olh2o`0@cTKocLk=ofIFoeIVoeG=E@Co
01=boomVJol?olkec_G>olko<EHa00Ko00[Foolaoli5cTG>0_l02/jZoh0aP360old3o`H00ol^0000
6`001RVn002n:@H000?o00001`001Om6LTIb00?o00MbA_m6LTIb00?o00IbAW;oLTH4o`06LTIbog96
0ol01dIbAW;oLTH00ol05DIbA_l1m@7eohdaSOm61TKoJon=<@03o`9b2?l03W;ooeKoELiEolhUcRG>
0_l02[g=ooG>mLkocW83o`0Dc[k>ofHFI_mFoliZcV[oSLgo<6/3o`05:aH[5R/00ol0137>old4o`05
0@oo5/d01?l04Lgo<GgocX3>P<koIYIVofG>00Co00?>mOl00_l06WkoO[An]?nUofhbK_lmECgo<C8a
odEnAGko0Wd03Onm4om[ob]5:dGoaC401?l00`jFo`02o`0><5H`E_n>ojJ[Y_la<_l2QP03olib00?o
00B6EXIF1?l02<gooc41<On50_l01W;nog8aLP?o00L?J`oocPK>00?o01<FQQJ6okf>_HjmolkUc^Go
JXeZ00;o00lacS7>oldacOl2obZ=:_l01`000ol0000/00006`001VKci^KcIPH000?o000020003?m[
ooo>oli[cV_oJ`;o00K>oli[cV/3o`07JlkocV_>J`03o`06Jli[of_>1?l06V_>Jom[o`5[0F_o0OlZ
cB[o5_o63lKoALe50ol01ljnole5cDD00_l03<hVcRKo<Ldaoc5E<@;o00PacS7>olkUcP?o00[>aOoE
c]G>odKo0eH01?laP346o`0AE/iFoc56<OnVoh0aP37ocGd01ol010K>1/h2o`08HEEQoliUcVD7o`04
IUIVEP?o01lZORYnoaDm5OnEogiEO_od?OCoiGkUogi5OTGoHWeR00;o0fH01OnUHJEQ00;o00C>Z/jZ
0_l00ljEo`04AP;o1:H00olao`03QP?o00/aOOo>A/koc_o>E@02o`04EVIFIPgo00?F3ol01?l036Ib
oeHaE_l1odF>A@;o01Ta5S4FodG>oeIVoljZc_laP?l3o_n0cH3o00P000?o0000:`0001`000@VJ6QV
1`000ol0000900;o00IbAW;oLTH4o`05LTIbog800_l024Ibog96L_mb0_l01TIbog96LP?o00MbAW;o
LTIb00?o00Ce0OGo0`400on=<@04o`0VJlKo<HgoQZKo<Ldaoj:>oiH?oliFc_o>ELko9LkoIZKo_Lfm
olh2o`095_o>eLkEokk>00?o01aF<5H`of[>oeKocW;>og8aLS7o:onVZjKo<Lha0ol05_G>oeG>EOo=
E/goERKoOC5molj0ooh5o`06I[mV_ola0_l06Wj^OZko]7jdojGoKS9^oceE?EGo<S4bogi51_l026/a
Jc7oAB]50_l01<k5c/D2o`06cS7><OmF0_l01LhFojJ[00?o0hH04omVoc6m<KgoE_la1S7oYHfUoc40
0_l02jIVY_oecOGoL/ib00Co02g>1/koL/iboaJ6ookVohjmoiJVonG>iOmZoeIVE_o><LkocC7oD0;o
:XdZSOl020000ol0000Z00009`000ol0000;0003oli[00?o00M[cV_>oli[00?o00M[cV_>oli[00?o
01I[cV_>olkocV_oJli[c_o>oli[c_m[2?l00`K>1P04o`0CAOoF3mH?okk>odGoePoF3oo>9P05o`05
<Oo60LH01_l02<kec_Goc/G>0ol00`mbo`04EP03oc7o00=V00OoL/iboliF00?o1:H06_laP?l`ooG>
mLko<LdaolkoAS56oeEQEOmU1Ol02HfmoeIVE_mnm@02o`09:WhZO_lE?ADm00;o00QnEGkom3gd?@?o
00=nool00ol01<eEcOl4IP04ojEQo`:[00WocZ[o0LKocYD00ol012K>9/h3o`06c]G>ohKo0fH03_la
OC5molhFcQKoELiE0_l03<i6cTKoI_laXS7ocP?o00A6olib1Ol00fKoo`030@09odGoYYJVoaHa00?o
00UFIUIVoljZcZX02ol80003o`0002X0000V00;o3P02o`06AW96odIb1?l01TIbA_m6LPCo00I6LTKo
AW83o`07LTIbA_m6LP03o`04LTIbAPGo00c=ALgoc/g>oiKocHh=o`03UPoo00?o00>Z<JX01?l03jKo
olkoELeEoaK>5/koe@02o`033YKo00Co00<`E_l00_l015IVEVH7o`0DcC7=ojJ[Y_laoiIFU_oec_Go
cUD3o`07ERIF9_mm<@03o`040OmmOPGo00Fooc46<@02o`0FOZin[_ndO[Anoc9^<Vko?EDmEOmmOP;o
00=mogd00_l02;f>_OlaJc5[0_l02@nV3oo5oiJ6UP03o`0=c_GocQK>oc3oc/g>c@02o`08IS1V<?nm
<Kd2o`061S46<OnU0_l02fKoYVJVo`4aolge00?o00>VLZH01?l01Libohk500Wo00>VU_l00ol01S4?
<OmFIPWo00W>_Lko1/d6cOl020000ol0000Y00009P000ol0000>0004oli[cP?o00O>JlkocV_>00?o
00K>JlkocV/4o`06cV_>oli[1?l01Li[c_o>00;o01X?U_l1Zoo=<Lgo1_l?aPoocDGoZolaOC5mo`;=
1?l02<daoc7=<Lda1Ol02V/?JolacC7omLh7o`04aOn=1@Ko0fH02omFoliUc_o=<Lda00Ko00@`:c0[
1ol01lkUoc56<DH00ol00eGoaP02o`065F8Eogj00_l07WkeO_mRobYn:Wko5CdE?OmEOUEnoo@mm3go
:V8ZHP;o00F0H_mEc@08o`:[1?l03<Koo`KomLkec_o>o`=600Koc_ooc_l4IP04oc5mo`:F00Co5/hF
1ol00dKoIP02IP?o00G>:lkoAP02o`0=c_mVcVK>oeG=ojKno`02c@Co0W801Oo>A/i600?o00D?LPoo
c@06o`06cW;o<J8a0_l80003o`0002P0000V0003o`0000l001?oL_mbA_m6LTIbog;oLTKoAW9600?o
00M6LTKoAW9600?o00M6LTIbog9600Co00=FoiH00YH00om5c@05o`0=UV_oS_l?IPoocV[>JP02o`0;
LS7oHLEQaOnZ<JX00_l01DG>ALko00?>00?oELd01?l030oookgoZ/jZogg>O@;o00imoomVoeH`E_oU
SNGoc@;o01HaohjmS_mFUUKoc_oEc]Goc_G>mOlV0ol0;Gdao`7oEOmmOWgoP7j0o`Ha1_nEogj^OZko
]7jdO_lbKS9^oceE?EGoOGimOP02o`03O@Em00;o00LEc_oecOG=00?o00?=c/d00_l02<kec_Goc_G>
0_l01326<8H2o`093dH?A_l`IS1V00;o00FFYYKo<@02o`063onFolda0_l02P4a0Om6og;>L/h2o`0=
Y/koc_o>L/koaOl?oP04o`04aLk5cPCo00<aool02_l01<goIS03o`05cOooL_l020000ol0000X0000
9P000ol0000@0008oli[cV_oJlh3o`0HcV_>Jom[of_>oli[cV_oJom[c_o>Jli[0ol00f_>J`09o`04
9/hVcPOo01Z[a_mm<GgoY_l[cR_ocC7=oldaolH?okg>_@Oo00?>L/h00_l04@Ha1S7oaLko1HgoJfKo
OJ;o00AF00?oILh00ol05C46<@KoILeUob_oYPnVolibc_o>i@05o`0X<Oooa_mRaOlEHQGoOX1nogke
O_mRobYn:Wko5CdE?OmEOUEnoo@mm0;o020ZHRYRoc;oHX3oEC5E<OlaX_lVooG>mOm6o`K>1/kocP;o
00?>odH00TH01_l?Y_mVcPSo0YH4o`0<3omFcUKocLk=ofKo0eH02Oo>oomFoli6cP0:o`07cW;oaLk5
cP02o`03c/go00?o00Ub3oo>_LkoEHh00_l00fIFIP04o`05Jli[c_l020000ol0000W00009P000ol0
000A0003og9600Co00IbAW;oLTH3o`07AW96L_mbAP03o`06AW96L_mb0_l02TKoAW96oeJ6EXH2o`0=
cG;oLS5bof_oS/f>c@04o`0EcV[oZjJ[oc5bolEQaOnZo`6[0Oo>00;o00EbYW;oP002o`0IL_ooZ_nm
<KdaoljZoggo<@4a0OmmX_mF<004o`033g;o00@a00?o_Hh01?l00j_>o`07o`05:^GocPD01?l095En
EOmmOWgoP7j0O_laoc:Eogj^OZko]7jdO_lbKS9^oceE?@;o01emOWenoc;o1Gd5oaG>5Oo=oaH`5_o=
odH`A_oecP03o`0:9S4V<On6ohH[QP?o00NUUOnn<Kha00?o00W>9/hVoiJVUZH01_l014H`AS02o`06
LQIb5_o>0ol00f_oc@02o`0<Q_lVcRK>olG>oofV0ol00`o>o`04o`08c_oo<Kdaoc02o`07c_mlog96
LP03o`P000?o00009P0002H000?o00004P02o`07Jli[c_o>J`03o`06Jli[of_>1?l01V_>Jom[cPCo
00a[cV_oJoo>A/i6o`45o`0<c_o63lKoALgo3on=0ol3YQ7o017>A/ko<OnmSOo>aLk5oc46<@06o`07
IV]VJonRO@03o`0;c_G>mOmVL_l6<@H00ol4<@;o00>5HOl00_l0<8koHIEQUOlUSBF=olERaOlEHQER
oh1nP?oeoc9RobYn:Wko5CdE?OmEOUEnoo@mm0;o00hZHRYRoc;oHX1Roc5E<@;o00@V:bH[0_l014IF
AUH3o`07cTKoc_G>m@03o`0GY_ooc_n>YHjUoc6Ro`7oc_G>mOonoeH00_l01PooXS6Ro`=F00KoIVKo
cUH3o`03J`oo00?o00?>9/h01_l00lkooP04o`073oooL_goc@02o`05Q_mESUD00_l01/DaaC7oO0?o
00?>Jol020000ol0000V00009@000ol0000D0005og96LTH00ol01TIbog96LP?o00MbAW96odIb00?o
00MbAW96odIb00?o00Z6EXKoo_mbohk=1?l02V^FolgoUV_oJX05o`08<G;ocQG>5Lh2o`0Q<G;oILeU
cOmboc4[<On0oj[>Z/ko<KgoZonmS[f>o`4a00Co00O=UOl6cPK>00Co0S402?laokg>_Ljm1?l03B[o
c[goiB[U:_l5cPD00_l06UEnEOmmOWenogj0O_laoc:E<_n^OZko]7jd0_l05S9^<Vko?EDmob[oOWen
oc;o1Gd5oaD2o`0HP?l`5S3o1_l`AS3oJomb<G8aoc4Vo`6V0_l04`Ha1S7oYIFUoc7oZ`n[olhVooh0
0ol02c1V<6Koc@K=oc3o00=V0ol00`ooo`04o`07L_n6c_l?o`03c@Co00<?cOl02?l04iJ6U_la_OmV
olj5cXGo?GcoLTH00ol80003o`0002D0000U00;o5P005?o>oom[of_>Jlkoc_o>Jom[cV_>0ol01/i[
c_o>J`Co00G>JlkoAP03o`08cVK>oeG=ELd7o`073lKoP8f0S@02o`07cQK>obF=9@02o`07A/i6c_la
c@03o`05<DHaAS400ol03LG>aOlao`o63oo=9Ld00ol02EK>olhacS7om@02o`0:Q_mmo`Ko5S4Fo`8a
0ol0;665HHGoIHiUoiEQUOlUSOmRolERaF;oHQERoh1nP7koHS9R<_mn:Wko5CdE0_l0>UEnEGkom3gd
oc;oHRYRoc;oHX1RP?mEof9mob_o9S4VoeKoAS56oli6c_oeomH?oc3oc_G>mOnUSZD3o`053`4?ooD0
0ol02/ibc_m[3f_o<J83o`=V00?oEUH00_l027;>oliVc_o>0_l01@oV3olU00;o00?V3ol00_l03Lko
Y_n>EHiEohJFQYH00_l3EP04oc75<@?o00Iloom[c_l700?o9P0002D000?o00005P02o`06AW96odIb
1?l01DIbA_m600;o00Ibog96LTH3o`07AW;oLTIbAP03o`0@A_ooLV]bohk=ofKocHk=SP;o00NFoh1Z
P?l100?o00DaoaG>o`02YP03oc5b00Co00N6L_l[<B/a00;o00>=<Ol02Ol038koodKo<G8aL_o=U@?o
00/a3c4?oggo<JDaY@04o`0?5RKo:ZXZoljmc_lZiB[U00;o01enYOmEOUEnogimO_mnP7j0oiDbUC;o
[Wj^okAn]002o`0G<VhbK_lmEOlb:_mnOOmo<_l5O@Emoc800_l03Gf0o`Ha1S46of_>Jlh01ol03ZKo
c^G>oc46<OnUUOlE1ol01C5[olda00So00W>L/koI_mF<5H00_l01/G>aOmbcPCo00>V3ol00ol03YKo
okgoc_nVZjKoc[g>1_l01VH`IS3oQ@;o00<?odD00_l01DIbAW;o00P000?o0000900002D000?o0000
60000om[cP03o`07cV_>Jom[cP03o`05cV_>olh00_l026_>oli[c_o>0_l01F_>Joon00Go00[=o`n[
3oo=AOn[0ol00h2=o`02o`031/ko00;o00<UojH00ZH3o`0AL/koQ/j6c_m6<Ol?a_n0cH000ol0137o
cH02o`07I/iVc_mFcP04o`04cW;>o`>600GoX_la5P03o`0A<Ol[<B_oQF65HOn>IOnEHID00_l07V:U
H_o5H/ERof8EH_n0OX1nof8bHS;oORYnoaDm5@;o01MEOUEnoo@mof8bof8ZodDbof:0H_mnE@02o`0C
OF;o<BHa9S7o<DHaoc7ocLk=cP02o`09<1H`5_oec_G>00Co00[>:lkoL_mFIUIV0_l00ljncP05o`03
cUKo00;o0eH00ol1YP06o`039_lV00?o00=VLVH02?l3YP0:oeF>o`oocUG>o`AF0ol23`07ohf0SOm[
cP03o`P000?o00008`0002D000?o00006@02o`06LTIbog961?l01W96L_mbAP?o00M6LTIbog9600?o
00=6LTH00ol00aIn5P04o`06QVJ6ohko0XH00on0o`02o`08P?mbcW;>ohd2o`0EY_oocXG>olk=ohIb
Q_laohH1Q_la00;o00c>oc7=<Oo=SLgo3dH4o`06cLk=o`o=2_l0336UoolF9QHVobZZ:P?o01O>ob[U
ogkoYGjUO_mnEGkoOWenogj0OP02o`0<UC:E<_n^OZko]7jd0_l05c9^<Vko?EGo<R[oOWgoOc;o1Gd5
of8b00;o00amP7go<@Haokkoc_l3:`0:olgoolkoiLkUcPKo00HFog8aLS42o`04<F/aJ`;o00?>iLh0
0_l00eF=E@03o`083W;o<5Ko0B/2o`06c/G>aOo=0_l010lFog83o`06c_n>QHj51Ol02lkoYXJVolj0
c_l`00;o00YbZooo3eKoP4F00_l01796L_l70003o`0002<0000U0003o`0001T000GocV_>J`03o`06
Jli[of_>1?l01V_>Jom[cPCo00a[cV_oJom[oldacC4:o`0<3j/?oggoOOono`K>1_l01WjZOZYnZPko
00_5<LDaoc7=<Oo=P003o`07A/koc^G>i@03o`04P37o<@?o00=moaH00_l03C56ob/a:on5HOmnof80
1?l04gjUof:UHZGoH/ERof8EH_n0OX000_l0368bHS;oORYnoaDm5@;o01MEOUEnEOlmof8bof8ZodDb
of:0H_mnE@02o`0@OF9mobHaoc4V<OlaAS56<@;o00EV3fKo5P02o`0:YPooolh6cPKocP;o00/?ofIF
I_n[Y_o>o`02IP04olf0c@Ko00YFojKoZ`7ocC7=0_l019H?o`l3o`AF00SoALgo3omnc@?o00O63lKo
ELiE00?o00@?ooo>0_l02@ooP8f0oli[cP03o`L000?o00008P0002D000?o00006P002_mboom6L_mb
AW83o`07LTKoAW96LP03o`06LTIbog960ol03TKo0OlFO_l?olG>aLko0/d3o`05Q_n<P?l00P43o`0D
cW;o5/gocXG>QLj5oldacOo>ELh2o`09SFZ=olhbcS;>00Ko0/h01_mb<G;oc@;o00Ceob[>0ol03oG=
mOmmofK>I/iVoaHV5P02o`0YOPKoAGe5ogjUO_nUOZEnogiEO_mnOGkoOX3oUOnE<YDbojin[_ndO[@0
0_l05c9^<VhboeGo<R[oOWgoOc;o1Ggo<V8b00;o00]mP7go<Onn_kjoo`04:`03oiJ600Ko00VFoooE
oaK>5/h00_l02/jFcYKoJonVZjH2o`05<F/aohd00_l01NGoOLem00;o00<[oiH00YH02?o5ool>Q_lF
0_l04C7eolk6c/KoQOl?<@ooHG9Q00Go00C>oomb0ol010la3c43o`03P4F000Co00=bA_l020000ol0
000Q00009003oa`00_l03f_>Jlkoc_o>Jom[cV_oJ`02o`06cV_oJli[0ol016_>Jol20@09oc7oaZ_6
olib00Co00<aogd00_l2O@?o01LacC7oLXKo1/koZWjZO_l2oldacOo=o`02IP08odG>AOlaaC42o`0;
L/ibokg>_LkocTH00_l00lF>a@03o`0><H3oXS6Roj;o<DHaAS45o`0aO^Enof9mH_nUOZGoHZERYOmR
aF;oHQERoh1nogkoHS9R<_mn:Wko5Cgo<_mEOUEnE@02o`0S<V8bof8ZodDbof:0oeEnokooOF9mH_la
9S4Voe7oAS7o0LH00_l01<g>cLh2o`06<0H`1_l60_l01LiFohH?00Co00FVoooEo`03IP;o00Sec_G>
ogk=OP?o00<1Zol02_l0137=<Ol2EP?o00H?QPn6old2o`04c_o=E@Go00G>3oo>:`08o`06Jom[cV_>
0_l70003o`000240000T0003o`0001h000?oAW800ol01g96LTKoAW800ol03G96LTKoA_m6L_mbAW80
1ol00`nFo`02o`08cW;oZXjZoh`3o`07S?lb:S8Z<P06o`09QLj5o`9Voc7=00?o00]VJfI[oheZoc;>
o`02J`05olkUc_l00/h4o`03aOoo00;o00E@olhZcP05o`0mOJ;ocVK>ohko1IGo1Wh6O_mmAOmnYGjU
ogjUO_mnEGkoOWenOOn0oiGoUC:E<_n^OZko]7koKS7oKS9^<P02o`0W:S8ZogimoglbOommoc9Ro`?o
OH1mP?no_[ookU7o:onFQ_oUc_o>00;o00H?omGUeND2o`BV0ol00lg>c@02o`04c[k>_P?o00P`onDa
iC7oc@;o00=b5_l01?l02;k=ooo5c/G>0_l00oDao`02o`06cW;>o`la0ol02>DaiC7oYHjU0_l00bK>
o`03o`04iC7oP0;o00IbAW96odH2o`03L_l000L000?o0000800002@000?o00007`02o`06cV_>oli[
1?l01/i[c_o>J`?o00e[cV_>olkoc_m5cDG=00?o00YFc_o>1/ko<Lgo0Wd02?mmo`7o<Lda0_l00j8a
XP03o`04OZ[o0@Co00?>L_l016H02_o>AOlaof^6JhH6o`03<H3o00Co00F>aHkoP002o`04aOlUSPGo
024aoc7EofEQogkUO^GoOF;oYGjUO_nUHZGoH/ERof8EHQD00_l03c9n<_lbHS;oORYnoaDmo`02<P05
ogiEOUD00_l02S9R<_mRoc95<TD2o`0>OUEnokn_of9mojGo9S46o`0Pa_lV<BHaoliFcUKo1S3oe_o>
E/koU_o5c/Go3ooEc]D2o`08YPnV3oo>mLh2o`03cPo>00Go00_>ooo>oc3U<>Go<@02o`05<OGocPH0
1?l03<kUolkUc^GoELgo0@?o00eVc_oUc^GoOH1moli[00?o00E[cV_>o`080003o`0001l0000500Ko
100012IXo`D500049VSo1@P000?o00008@000ombAP03o`06AW96odIb1?l01TIbA_m6LP?o02Aboc7o
SZ;oQ_laLS5bog;>ohjZS_n0S?on0OlZ<_l?U_o=5/d2o`03c_oo00;o00UVL_o=c/goJfH01ol3J`;o
00K>QLkocS43o`0BaLkoD?E@mOmUcVGoHKeQolf>0_l088i5STGoU@GoOPInoge5OOnUOZGoOZEnogiE
O_mnOGim0_l05S:E<_lbUC;o[Wj^okAnofhaofhbKS82o`0::S8Zogko<WlbO`;o00eR<V;o0c;oP?lb
O_nn00;o02:_oomQOOoUc^G>iOl?<@laonGoQPn6ojKoQPn6olgoUP6F0ol0278?of/`Jola0_l01<kV
oaH2o`0=P?ml<OnFcYK>olk5cP03o`04cC7=<@;o00eUc_o>cLk=oc7U<OnU00?o00k>olibcW;oiC7U
ohf0S@;o00I6LTKoAW83o`L000?o00007`0000D000>EofH00P001VP0001Vl`;V00>X_P000P001VKc
i^JX_PL000?o00008P02o`06Jli[of_>0ol01/i[c_o>J`Co00W>Jlko:`7ocOl00lH00omFcP07o`04
<OmmO@Co00PaolJ[a_laXPCo00?>YLh02_l03libc_o>L/koQ_l[9_laO@03o`03P37o00;o00C>olF>
0_l0?LEnaGkoSRF>oleEomDaeC7oHFGoiGkUogeROOmnYGkoYF:Uof;5H_mR5F8EoghbOS;o<V8boghZ
O_lE?Ol00S801OmnEGiE00;o00XbHS;oH_lbAC950_l01WiEO_no[`;o00RUHZERoc;o<P;o0Wd02_la
9S4Voj_oE/h3o`04e/KFaP?o0YHCo`03LV_o00;o00eZHF[oP8gocRK>9_oU00;o00H?oc7o<OD2o`0;
ZS6Z<Oo>iLkoiLh01?l052K>9/koI/iVolkUc_n0OH1moli[1?l00li[o`080003o`0001h000060003
UOmV00D000HY_P00__<30006:Kh00;kc1`000ol0000R0005odIbAW800ol01W96odIbAP?o00]6LTIb
og;o<Kla_`03o`03QPoo00;o00Lbc_nmS[f>00;o00B0oli62_l04`H?olhac_oeoldaoli5cTGoL/h0
1ol00fH`IP03o`08QOlac_n6ofX2o`1amOl[Q_o>ILko_F6mohk=S_m5STGoU@GoOPInoge5OOnUOZGo
OZEnogiEO_mnOGimoiDbUC;o<YDbojin[_ndO_m^<Om^<Vhboc8Z<R[oO_lbOc9ooc9R<V;o0c;o<Whb
OS;o<_n_ojooOF7oc^GoAZ/00ol01Lk=c_n600;o00<?<?l00_l02<kEooo=c/g>0_l02<k=c_o5cLG=
1?l036GoP>F0og`aO?o>UPCo00F[cZ_oc@02o`063`;oILiU2Ol01V_ocVK>IPOo00KUohf0SH03o`05
AW;oLTH00ol80003o`0001d000070003_VQV00@000?o00000P001Ol0003o00@000?o000010000ol0
000T000Dof_oolkocV_>Jom[of_>oli[cV/2o`06:`4[0OmF1?l02/ko<LdacOo=:_l2aP03og;>00Co
01L6oc7=<LgoE/iFolko9S4Volj5oldac@03o`06cC7oc[g>1?l06B_oOC7o<Ol[c_n=P8gocR_>ogk5
O_n>9Hh00ol08<go<MDaof5UonEniGkoHWgoOZEnojERYOmRaF;oHQER0_l047hbOS;o<V8boghZO_lE
?Ol2<P0;ogiEOUGoHS9R<V800_l06395<TGoEGiEO_no[omRYF:UH_lboc;o[`Co00XVoj/1ohJFog;>
1?l03PooobH?olko:c7oYLko0ZH01_nEcYGo<@Co00OEO]GoJV5Z00Oo00?>iLh01Ol03_Goooh1oc6Z
o`7ocFG=0_l01XH?QPoocP;o00Ge<?mUc@08o`05Jom[cV/00ol00f_>o`0700;o7`0000P000=VJ6H0
0`000ol000020005o`000?l010000ol0000400;o9P02o`06LTIbog960ol01TIbAW;oLP;o00E6okla
_`03o`0@ILeUobIboc;><_n>o`mF3`?o00[>L_laLS7oALe51_l04OG>mLko<LdaolkoLZKoILiU00Go
00<`I_l01_l03lj6c_n0JX3o:hH[ofG>I@03o`033XKo00;o01i5STGoU@FEo`In1_m5OOnUOZGoOZEn
ogiEOUGoOGh2o`0=UC:E<_lbUC;o[Wj^OP02o`0><FhaofhbKS;o<RXb:S82o`0K<WlbOolbHS9Ro`<b
oc9n<Whboc;o[on_oh1Z00?o00>[oiH00YH3o`03cPoo00?o00?>3ol00_l032/6:oo>ojH?Y_o=cP?o
00QE<EGoIC5U<@?o00`[oldVcOo=A/goI_l2c@Oo00eUojH?ohkUoiH?oli[00?o00C>iLkU0ol00`oo
S@02o`05AW96LTH00ol01dKoAW96L_l020000ol0000L00002@000kkc00020003o`00008000Go0000
o`040003o`0000@000?o00009`000oo>J`03o`06Jli[of_>1?l026_>Jol1of_o1345o`03<Lgo00?o
01W6oliVo`K>1_l6cPKo<OnnoldacOla9S4V00Ko00C>A/i62_l03/daoc7=<LgocR_oP8f00ol012_o
aGh6o`09IOooomDaeOmU00Oo021mogjUO_nUHZERolERaOlEokkoOS9n<_lbHS;oORYn:P;o0c802omn
EGiEof8bHS9R00;o00`bAC95oeEnEGko_jl2o`0GYF:Uoc;o_ol3[on>EHiES_n6UXKoQYH00ol0137=
<Ld2o`07<Kgo<B/a:`08o`0:9S7oaGk5omEne@;o01K>1/h6olk5c_o>obK>9_o=oeKocOo=1Ol01@oo
o`4?00Co0196c_oe<?Goe_lVcRKoOH3oJlh3o`07cV_>Jom[cP03o`P000?o00006`0000X000Ko0000
:Kh20003_RT0008000HY_P00_RT60003o`0002P00_l01TIbA_m6LP?o00MbAW96odIb00;o00]6okoo
ILgo<?n>c@03o`9b0ol01g9FLUKoL/h01_l04mG>eOo=ELgoc_Go0JKoc/g>og801Ol03/GoSXF>ohjZ
SZ[oaF751?l0181Zog84o`09IOoo3`4?oh3>00So00?Vo`401Ol07dGoOZEnojEnYOmEOUGoOOnoiOlb
UC;o<YDbojin[Wh00_l0735^<Om^<Vhboc8Z<RXboglbOc9ooc9R<V;o0c82o`08OS9noc;o<_l2[`;o
00AZP6Z00_l02iKoUPooQ_lb<C8a00;o00L`AC15o`H[00So00Pa5S7oEC5E<@?o00JVob/6:`H6o`04
IRIV9P;o00F[cZ_o3P02o`045_o>P0Go01C>E_oeL_EbonGo0@l1o`laoh2=P0;o00IbAW;oLTH4o`03
LTKo00P000?o00006`0000D000KoENH01O<30006I_?Vi_=V0`001VKci^KcIPH000?o0000:@000oo>
J`04o`06cV_>oli[1?l03li[o`4[oc7oETIFoeG=E@03o`06cW;>oliV1?l04ljnobK>oljnc[kocC7o
9_o63lH01ol04<haomG>eOo=<LgocC7=old:o`043j_o<@Wo00?>3lh00_l01eIbE_laof/00_l08Oko
oonUOZGoHZERolERaOlEokjooc9n<_lbHS;oORYn:P02o`<b01WoOUEnEOmR<V8bH_m5<TDbAOmEOUEn
okn_00;o00ZUHZGo<_noo`>_0_l01UF>EOl1UP;o00>FohH00XH03?lacOl1Zola_C7o:`Ko00YFL_la
9S7oaGk50_l04<h[cR_o1/ko3ombcW;>obH2o`04U_o>EP?o00P?o`l`oli5cP;o00=V3ol01ol00mH?
o`03o`099/koP7f0of_>00Co00E[c_o>J`03o`P000?o00006P0000D000JnloooKNH400049VQXIPD0
00@VJ6QV1`000ol0000Z00;o00M6L_mbAW9600?o0156LTKoA_no<Klaoc1V<6Koc@02o`063hH?obK>
0ol03Liboljnc[kocW;oc]D02_l0537oooo>olfEcIGoaLkoQHj5ojZ>1Ol00c1b<005o`0;3ooec_Go
X_l[ol400_l025KoodIVonKo0c401?o>o`85o`09O_nUOZGoEGiE00;o013U_nGo<YDboc:E<YGoOZin
0_l01c5^<Om^<Vh00_l04c8Z<RXboglbOc9ooc9R<V;o0c800_l027hbO_lboc;o0Zl2o`09JX3o0P7o
UP7o00B600[o<On[EZ_oAC151?l02c1Eoc1b<?la5S4F00?o00mVojK>Y/ko1_l?9PoocR/00ol00lkF
cP03o`03:g8[00;o00LF3on0c_l100?o00MQ_Ol`P32000?o00@[L_n=0ol00hf0S@03o`05LTKoAW80
1?l014IbA_l80003o`0000L000KV:OooKNH400049VSo1@@0000R0003o`0002`000KocV_>olh2o`06
JlkocV_>0_l01@4[0B/100;o00=FAUH00ol4YP?o00VZof_>Jlkoc[h01ol01j[>ofG=ILd01?l03<jZ
okg>olhac_o>e@Wo00@[L_mb0_l00lH?o`03o`0<<AHa5S7ocPK>ogbR0_l00`nFo`02o`08<JXaZ_mm
ooh3o`03_J;o00Oo01?5oono_[oo<Whboc9R<V;o:WhZ00;o0c801?mnEGh2o`0CHS9R<V;oAC95<TGo
EGiEO_no[`02o`0FYF:Uoc;o_ol3ojooEHkoU_n60OnVo`:60ol01P6[0J_o<@?o00Haoc6m<Kd3o`03
E_lV00?o00O>9/hVob_>00Co00>V3ol00ol0137=oiH2o`05mLko3lh01_l01/koo_lao`@a00ooILgo
iPoocVK>ogf0oh000_l01LkocV_>00?o00O>Jom[cV_>00;o1`000ol000070006K@D000E]0`001VKc
i^JX_P<0000R0003o`0002d000?oLTH00ol064IbAW;oL_mbA_no<KooQV_o<?l?LPoo3`;o00Paolg>
cOo>LPCo00c>mOnmO_lacS7>ohh3o`05Q_lacC403ol01/EQaOo>LPKo00S><Oooc_G>m@;o00?>:lh0
1ol00dK>o`04<@04olko0PCo00W=SOo=ALgoSRD00_l04KoU_nGo<YDboc:E<YGoOZin00;o00LaKS7o
KS9^00;o01Pb:S8Z<_mo<Wlboc;oHS9Ro`?o0c;o<_l2<P07oc;o[omB[`02o`070OnF0OnV3`03o`06
cS;>oj]F1?l01hG>QLko<5D00_l00c5mo`02o`073g;oI/iVcP03o`03<G8a00?o00I6c_nUcZD2o`04
5/hFcP?o00C>A_mm1Ol03C6m<OmQ_F7oP?l?QPl00ol02R_ocHg=odIbAW83o`08L_mbAW96odH2o`03
L_l000L000?o00001P000fP000020006o`0002Vn0P000kkc000200008P02obl00_l01V_>Jom[cP?o
00O>Jli[o`7o00>62?l01bK>9/koZ/h00ol03FF>olG>aOn>EHkoZ/h01?l3QP09oj[oo`nVolko00>F
00[oP?oo9_lacC7=0ol02EIbo`oo<LDaa@02o`0F5S7oYYKo1_o>iLkocOlFcQK>ojXaZP;o00<aool0
1ol06LdacOlUcOnn_kjooc9n<_lbHS9RobYn:_l013807_mnEGko<_lbHS9RodDbAC;o_omnEGko_ono
[omRo`8b00Oo_ol3ojo_00Co00/1ojJ[o`7ocC7=<@04o`0AcUGo<IDaUOnmoc5Vo`F=1Hd01?l01bKo
olh[olh00_l05LkocPK>1_laoj_omLkeonKo1/h6cP04o`033ola008a00Co<C4a0ol01PooohKoS@;o
00ImP7gocV/3o`07Jli[c_o>J`03o`05Jli[c_l020000ol000050003onH0008000Go0000o`040003
o`000040000R0003o`0002l000?oLTH01?l01W96L_mbAPCo00=[ool00_l02Hjmolg>cOl?<@04o`0=
9_n0aH35olkec_mn_@06o`B62Ol2UP?o01B6<8H`olEQojK>olko3jH?olhacP;o00GeoiJVUP02o`04
c^G>i@Co00E6cTKo<@02o`039_mU00Co00B`obUQ0ol0>DGo9HhUonFoiOlbUC:EoiDbUOmn[WkoKS5^
<Om^<Vko<_lZ<RXboglbOc;o<_mR<V;o0ol3<_lbo`02<P0;oc;o[omB[oobogd00_l02PooYPnVolhb
oe03o`07P<j0olj5cP02o`0;EVIFogdaOOnFold00_l019K>U/h2o`07AQI65_m6cP03o`0<QV^6olko
YPnVoli61?l020nVoc6m<OmQ0_l02g;ooomb1W86oj8a00Ko00I6LTKoAW84o`06AW96odIb0ol70003
o`0000D000KoKNH01Fd30003o`00008000?o00000@00028000?o0000<002o`07Jli[c_o>J`03o`03
Jli[00?o00?>oc400c400oo>1P03o`0>SXGoc/G>ofF>IOo>aLh3o`08EOla_C6mohH4o`04<Ldao`9b
0ol02ZK>obH[9R_ocOl3J`Oo00C5oonV0ol03IKooj_oiLkUo`ooSAD01Ol011K>5/h5o`04/OmRP0;o
01R0oolUcBGo_kjo__mn<WkoHS9RobYn:_l4<P0NogiEO_lboc9R<V;oAC95<_noogiEojnookn_of;o
0S801onoo`?o[nl00_l3O@?o00D?0@oo<@03o`08UF7ocUG>oiD2o`0;A_mV<FKo1HgoZ`401Ol02B_o
olkocQK>5P03o`05L/ko3j/01?l00`oVo`03o`035/ko00?o00>Voc401_l04/jVohK>Q/ko1HgocC7=
<Oo>J`Co00K>Jom[cV/4o`03cV_o00P000?o000010001ZP5oom]iP<000?o00000P000ol000010000
8P000ol0000b0003odIb00Co00m6LTKoA_o>U/ko0On>_Hh00ol03VGoALE5aOlVc_o5P<F01?l02Gjm
o`7oSZF>Y@02o`06c_lbcC;=0ol3LP06ob]boc261?l02LkooeI6E_o=P002o`06EV]FJonm1_l02NGo
US6Fogg>O@03o`@V1Ol01;3o:F42o`0FSH3oohhUonFoiKooUC:EoiDbUOmn[P;o029^<FhaofhbK_lb
obXb:S;oOc9o<_lbof8boc83o`<boc;o0S801_lbojooDPKo00=Fool01ol01?DZmBX5o`08LZIbY_mV
EVH2o`07UZKoc_n=cP02o`06AQI65_lF0_l00eKoo`05o`03L/ib00?o00W>IOlVcOm[olh01?l01ljV
ojKoLZH01?l02W86oj8aX_o>ILh3o`05AW;oLTH01Ol01DIbog9600?o1P03o`D000=EP@001P001RVn
002n:@<0000R0003o`0003<00_l01/i[c_o>J`?o00C>:lko0P401_la<Om6o`<a00[oSXF>olG>aOn>
0ol00`ooo`04o`04a_la_@;o00T6cPKo<Lgo3j/02_l00`o>3`03o`=F017o0OnmSKgo3jH?ohemonKo
c@03o`08IPmVoaF=o`43o`04cQKo0@Co00Vaof:0of;oOH000ol03Lgo_[nnoghbO_mR<V800ol00eGo
<P03<P04ogiEo`8b01Oo<V8boc;o<TDbokooOUGo[koo_jnoo`02<P07oc:oo`?o[`02o`03l_oo00;o
00`?c_lacC7oHOmQUF42o`07<LdacOo>AP07o`0=0OlaaC7oELgocQK>5P02o`0;3ooo5_laP360ofH0
0_l01Z_o<H0aP0;o00?F3mH00_l01hdUofKo3`400ol2<@03oh3o00?o00B=1Ola0_l01F_oJli[00?o
00I[cV_oJlh4o`04Jli[o`@000Co003o1P000o>1YP050006I_?Vi_=V0`00024000?o0000=0001Omb
AW9600?o00I6L_nFcYH4o`0<S_m[<6_oILgoaDG51ol2YPCo00=bool00_l09JGo_C7ocR_ocOnF0Ol?
obG=9LgocW;>olko<=H`oeKoQV_oP<d01_l01[goUPnFo`;=1Ol01GgoUPnF00;o00<Voj/01Ol03;3o
:F7ol?n0SOmmOPOo00DbUOnE<P02o`0<HUERofhaKS7oKS;o0S805olZ<R[o<_lbOc;o<_mR<_lb0ol3
<P?o008b00Oo[c;o[omB00Co00>`OOl01?l03VGo:ZGomB[o<BKo9LhU0ol01/hFoldac@;o00[>aLk5
olj=c_lF0_l05LjVoaIF5UKocV[>J_l?APm6oliUcP02o`073f/?oh3oP003o`0<3oo>of6mHKgoSDF=
1Ol01796LTH3o`06A_m6LTIb0ol01W96L_mbAP?o1`000ol0000400041FSoZ0@000@VJ6QV10000240
00?o0000=@004Oo>oom[of_>Jlko:oo>obF=00;o0dH01_la<On>Q@Co00>mool02Ol02<hVc_mm<Gda
2?l01/h?oc7=<@Ko00AbAW960ol00lH1o`02o`05cPoocGh02Ol00g;>o`0<o`03I_l200;o01>aof:0
of;oOH3oAF95obER9OlE00Go00IEoeEREOl4<P04ogiEo`8b01Oo<V8boc;o<TDbokooOUGo[koo_jno
o`02<P07oc:oo`?o[`02o`08l_mmohkoO]D2o`04HHEQQ@;o00DF<AKoc@02o`0?c_o>9/ko<Lgo0Oo5
<LDa00Ko00<?YPl00_l02QK>5/koP360o`42o`07Z`ooP37oQP05o`059OooLVH00_l01<hFc_l3<@0;
olf0cOo=<LgoJlh00ol01/i[cV_oJ`;o00K>oli[cV/3o`03Jlko00L000?o0000500002400_lg00;o
00I6LTKoAW83o`0:L_l1oc5m<Ol`J`Oo00D?0On0S@03o`0>mG;ocXG>QOo>Q_la_C42o`05cPoo1W80
1Ol02lgoohK>og;>L_l`00;o00>[c_l00_l08<hVc_mbQ_nRYOn[oljZcZ[o<Oo63olZcOoU<NDaolib
0_l00`?o3`02o`0T:F7ol67oSOmmOWgoHX1RogenOOmRAF;oHUERofhaKS7oKS;o0S805olZ<R[o<_lb
Oc;o<_mR<_lb0ol3<P?o008b00Oo[c;o[omB00Ko00REoc55<DGo:P?o00ha9S4V<OlaLS5bolhFcP;o
01/13`7oaLko3eKo<LdaojKoYPooEQIFoliZooH00_l03<goooo>ohKo0Oo>P0;o00cFc_oo0OmFcUKo
_F45o`03AOo>00Co00IbAW;oLTH3o`06AW96L_mb0_l01DKoAW9600;o1`000ol0000C00008@000ol0
000h0003of_>00?o00[>JlkoAR_oSBF=0ol00g;oo`07o`0<_Oo=<Oo>A/ko<H0a1?l00gdao`02o`03
3`Ko00;o00E6cTKo`@02o`039/hV00Ko00UbEW;o3mKocW801Ol00gkoEP02EP0AogdaOC7oI/iVc_la
cOlaXS401ol07j_ooon0of8Toh3oAF95obER9OlEHQGoEF9EoeEREOl013801?mnEOl2<P0Goc9R<_lb
oc95<_noogiEojnookn__ol00S801Olb_ol300;o00D2oooo_P04o`03eOoo00;o00c>3ola5S4FomKo
:lh;o`05<OnVZjH01_l00iH?o`04o`0>5_oo0Ol?Joo=OLgoQ_l3YP08obF=9OmVolH8o`053fKo9Hd0
0ol01V_>Jom[cPCo00I[cV_oJlh3o`04cV_>J`?o00=[o`001`000ol0000B00008@000ol0000i00;o
00ibAW;oL_l1<@7o<Ggo3`?o00C>ohg=0ol03Lk5olk5c/GoL_GoQLh00ol01XKooon=i@?o00Ib1_o>
A/h5o`0=Q_nVcZKomG;oc_n[QP04o`0C9/koSKgoZlj[c_nZcZ[o3oo63`05o`08<NGo3oo>SLh6o`0S
HOo`HOn=ogenOOmRP6;oOGimof95H_mREF;oKS5^<Om^<_l00S805olZ<R[o<_lbOc;o<_mR<_lb0ol3
<P?o008b00So[on_ojoo[`;o00F>oomb_@08o`073olV<Ol13`03o`04cR_ocP;o00C>JonR0ol025Ko
oolaoeF=0ol00lg>c@06o`03YS7o00Oo00H?0@ooP<h5o`0BLS7ocHk=S_o>E/kocX3>og961?l01W96
L_mbAPCo00EbA_m6LP03o`05LTIbA_l01`000ol0000B00008@000ol0000j0003of_>00?o00E6:dH[
AP04o`03a_oo00;o00_=oooocZ[>Z_o=<@05o`03<Ooo00;o01;>3omUc_o6Zoo>L/koc_mFcUH3o`04
A/i6cPSo00_>I_o>mLkeohfmo`03EP05ogdao`401?l00bK>9P02o`08<Ol?aPooc[d4o`0Ml?n0of8T
oh1mof95obER9OlEHQGoEF9EoeEREOl01C800omEo`02<P0Foc9R<_lboc95oc:o<_mEojnookn__`;o
00Lboc;o[oo_00Go00<aA_l00_l01bKo<Gdaohd00_l00aKoeP02o`04c_o>3`?o00@?J`m[1ol04PHa
1S7ocTGocZ[>o`oo<Kda_@;o00O>3onR<J8a00Oo00]Vo`ooc_o>:onmcP04o`053on=9Hd00ol01V_>
Jom[cPCo00E[c_o>J`04o`06cV_>oli[0ol70003o`000140000P0003o`0003`00_l01W96L_l1<@go
00FF3oo>a@07o`05XX3oo`l01Ol01NGoQPn600Ko00@?<@la0ol04/jVc_o>Y_m6ojK>ohIbQ_lVcPSo
00>[ool00_l01c7=oc5b<G803_l01_7oHOo`H@;o01Z0ogimof:0H_mmOWgoHTERof9EHUGo<FhaKP;o
13807_lb:_lboc9oojlb[olboc83o`<boc;o<_n_ojoo[`Co00lFIQKoAUI6E_o>ULkoP8d00ol01<hF
cQH2o`05LR]bof/00_l01C7oS/f>00;o13403_n=EHgocOl?QPoo<4D`0_l04/i6c_o=mOl1olg>cOoF
olH?aP;o00<aool00_l00g8aLP03o`09c_ooA_m6LTIb00?o00EbA_m6LP04o`06AW96odIb1?l00dIb
o`080003o`000100000P0003o`0003h000?ocV/01?l012_>:ol2IP;o00C=oooo0YH4o`05L_oo<0l0
0_l02L7oooo>:onR_@03o`0:a_l?IPoocW;oEP;o00W>:oooc_o>A/h00_l01dK>A/koI/h00ol01lj5
oldacC400ol026Go<H0aP?lV0_l02EKo<J;ocVG>I@05o`06l?n0of8T0_l05WgoHTGo9F8UoaER5OmE
HUGoEF9EH_l4<P;o13807_mR<_lboc95oc:o<_mEojoo[kn_ojoo<_lbojook`?o00laAS56obK>9/ko
OC5mokd00_l02Pooc^G>ofKocPl3o`0@ZS6Z<OmUonH?oc46<Oo>A@Co00R63hKo_C7oYPGo00@aomH?
3Ol01ZG>olhVcP;o00V=ooo>Jli[of/00_l01LkocV_>00?o00K>JlkocV/4o`05cV_oJlh00ol70003
o`000100000P0003o`0003l00ol03W;o3c4?oc6FofJooheb0ol00c7=<@03o`031Poo00?o00OUc_l?
<@oo00:R0ol014K>A/h5o`04Y/jVcP?o00[>Y/koE_o>Y/jV0ol04nGocS7><Oo=<OnVU_o>P?lacC40
0_l030n[3j_omLgomHgo3`Co00Kaof7ol642o`0JP?mnOOmRP6;oOGimof95H_mREF9Eoc5^<Fh2o`@b
00Co<R[o0S805_moojlb[olboc;o<P<boc;o<_n_ojl5o`0<IQIVohKoETIFoljE2?l011KoJfH3o`07
cC7o<LhacP02o`04Q^J6o`<a0ol00g8VLP05o`08<?n[omH?oeD5o`0FY_o5S/Go3ola<S7o<OlacOmb
o`4?o`:000?oLTH00ol014IbAW83o`06L_mbAW960ol01DIbog9600Co00AbAW;o1`000ol0000?0000
7`04oc`01?l01f_>Jlko:ol00VH01?l1UP43o`08c_oec_GoePl3o`0:<LgoiLkUc_l[cP?o00GEc]Go
3`02o`07c_laOC7o:`02o`0;cTKoolkocTK>olh00_l034Ko<Ldaolj5c_lao`>V00coILkoP37ooZKo
cUH5o`04IOl?0@Co00K`oh3oHR@2o`0FOOmRAF;oHRERof8EoeEREF;oHUERo`@b0_l4<P0Lof;o_c:o
odGo<[lboeGo[on__joo[olboc;o[`Ko00A6olH12Ol01FK>ohfm00;o00eVJon6oj[>Z/ko<J[o00:V
1?l01c7oolH?ob/00_l01:KocLd2o`05Y_l?0@l00ol04S60o`nF3oo=o`4?0Oo=<LgoY@Ko00G6oh2=
P002o`05JlkocV/00ol01V_>JlkocP;o00E[of_>J`03o`06Jli[of_>0ol500?o4000020000?o0000
>@03o`@000?oAW800ol02C6F<OnoI_on9P04o`0><Ol?U_o>oc8a<S7oiLh4o`06c_nmc[g>0_l0235b
<G;ocVG>0_l00ljVcP03o`04EYIFUP;o00YbZg:[onDaoc7>1?l00iJVo`04o`03<Ooo00Go00Ebc_n=
c@08o`08lOmQoo1Qok02o`0HOWenoh1RP?mnOOmRAF95oeEREOlaKS5^0_l4<P03oc;o00<b013oOon_
<Zoo<_lboc83<_lb0_l013:_ojl8o`0DU_oeohjESYGoQ_mbIW;oSKgoI_l3QP07oldacOo>o`03YP03
oeF>00?o00=63ol00_l00iI6o`07o`093oooL_o>YLjU00Ko00K63lKo<S45o`04AEKoP0;o0h000om6
LP04o`06AW96odIb0ol01796LTH3o`06A_m6LTIb0ol00g96o`0200?o0P000ol0000>00001002o`03
J000008000@VJ?l51@0012IXo`D80003o`0003H00ol800;o00S>JlkoI_nF0@Co00C>ofG=1?l01lk5
c_lacC400ol00oG>o`03<@0EomGooaH`odK>A_mm<Oo63oo>olh[00;o00S>oom6c_o>AQ3o00o=X_oo
Zoo=<LgocW;>obX00_l00jH?o`03o`08l?n0H_lTok@2o`0DHTERof8UH_mR5F;oHUERof9EH_l4<P;o
13805_mRoklb_om5oc:o<_mEojoo[kn_ojl2o`04_c;o[`;o00F_olh?cP02o`0:S[j>oldaohJFQPSo
18H00oo>ZP03o`>V00KoY_o=ALd3o`03cPoo00;o01H6c_o>ILiUc_nFcYK>oc60<OmUcFG=1ol00`oo
aP02o`05YF7oSH000_l00hgoo`02o`06cV_>oli[1?l01Li[of_>00?o00K>Jli[of/2o`05c_o>Jlh0
0ol50003o`0000h000050003o`00008000IVlnKVZ;h30006I_?ViZRn1P000ol0000e00;o3@000omb
AP06o`0KE_o>Z/koSLkoE_oEc]G>oc;o3ol6<0H`oljm00;o1ND4o`05c_l1UP400_l00eJFEP04o`03
QUJ600?o00?=1/d00ol02@K>1_mbog;oXP02o`08X_l?ePooHJD7o`03IUKo00Co00Oaof4Yof7`00?o
01QnOGkoP6:0ogimO_m5HTGoEF9Eoc5^<Fh2o`@b00?o<_l00c805_moojlb[olboc;o<P<boc82oc:_
ojl2o`03_olV00;o00^6oe3eD?nEohJFQP02o`04mG;eo`?=00?oQXH01?l3LP03ojKo00:V00KoS_oo
3dH3o`0:1_o>A/i6olj0cPCo01IbQ_nUc_ofohjZo`oocOG=ofKoUPnF0_l00eI5o`02P0;o00I6LTKo
AW84o`05AW;oLTH01?l01W96L_mbAP?o00A6LTIb0ol00g;o00050003o`0000h000000`3oo`04o`<0
00HY_P00__<30006:Kh00;kc1P000ol0000b00?o4002o`03Jlko00=F00So:oo>YOo=o`=F00?oaLh0
1?l04fH?ooG>mOlaob_>oc0F<?l?ol400ol02`ooobK>olkoAR]600;o00e6ob_>:ombob_>og;>00?o
00K>E/kocGd6o`08<Ol?odG=ALd3o`033lko00;o01k`oomRobARok3oHTERof8UH_mR5F;oHUERof9E
H_l4<P03oc8b00<b01coH_no<[ooAOlb_c;oEOn_ojno[on__ono<_n_0_l04:oooli6cTKo_XjnohJF
Q_l2YP04ogdaO@Ko00<?cPl01_l2YPCo00l?oomFojEQYOl6cPKoILh00_l00eKo9@03o`0=<Ol1o_o=
o`4?oc6R<@03o`?600_oYOnUoh2=P?o>J`04o`05cV_oJlh01?l01V_>Jom[cPCo00E[c_o>J`03o`05
Jli[c_l01@000ol0000>000000<01Kh00P000ol000020003o`00008000Go0000o`040003o`0000@0
00?o0000;`03oa@000[oL_mF<5KoQ[n61Ol00c1F<003o`03LS5b00Co00<`1_l00_l02IK>U/koiOnF
0@06o`04<@la3`;o00BFcYK>0ol018IFQUH2o`03U/jF00?o0c402ombEW;oX_l?olf=00Ko00R>_Ola
mOo>:`?o00WaoolYof7`oh000_l067enoh1RP?mnOGkoAF95oeEREOlaKS5^o`Db00?o<_l00c801_mo
ojlb[`;o00h3<_lb0ol2<P;o<Zoo[`;o00Zooon6IXIVooE@0ol048Ko3`4?og;eoc7oL/ebo`l2o`05
LVKo3lh00ol00`o>o`02o`08cZK>odD6A@H4o`0:c_ooi/koHKeQ_@Wo00K6oooo3`H3o`06U_m5odGo
0h03o`05AW;oLTH01?l01W96L_mbAPCo00EbA_m6LP04o`06AW96odIb0ol50003o`0000d000001P3V
lnH0o`@000?o00000P001Ol0003o00@000?o000010000ol0000/00?o6002o`=F00Co_b^o0_l04<ib
c_mFo`oocQK>o`l1oi06o`03:lko00Go00QboiEQUF7ocP;o00/[ob]6:ol[ohco:`02o`0;cR_o:olV
omG>eLh02_l01Lgoo`oV00;o00K=olhFcQH3o`03l_o`00;o00IRobARok02o`0CAF;oHRERof8EH_mR
EF;oHUERo`04<P03oc8b00<b00coH_no<[ooAOlb_c82o`0<_joo[koo_jnooklb1?l02Joo<Om6cTKo
_P0:o`04OOnFQPKo00AFcUK>0ol00ljUo`02o`0;Jg;oE/iFc_mQYF400_l04LgoolkoLUIbohhUSRGo
<J8a00;o00>R<Ol00_l01UKoo`ooS@?o00=Qof400ol01F_oJli[00?o00I[cV_oJlh4o`05JlkocV/0
1?l01/i[c_o>J`Co00?>Jol01@000ol0000=00000P001;j10?l40003o`00008000Go0000o`040003
o`0000@00_lZ00?o7@002Ol`okn6_ono<@09o`05L_n63hH00ol2cP03olj=00Go00=bc_l00_l05dDF
AAI5oc4?<@ooc_n6AXKoX_nFEYIF00;o00AV9VKo0S401ol`olhbcS800_l01RZ=ool?YPCo00HamC7e
o`42o`03l_oa00;o00HYof7`oh02o`0HOGkoP6:0ogimO_m5HTGoEF9Eoc5^<Fko1C800olbo`03<P0D
ogoo[c:_<_l3<_lb0ol2<P;o<Zl4o`03_omE00Ko00<Volh00_l00okoo`03o`05<Ooo3c401Ol05FKo
ofKocBKo3b_oLV]bojK>Y_l6A@04o`033aH?00?o013VokeQ_OmAo`Ko0@ooc@K=0ol01PnF3onR<@Go
00AbAW960ol01TKoAW96LP?o00EbA_m6LP04o`06AW96odIb1?l01DIbog9600?o10000ol0000=0000
0`000bUVo`040006:Kh00;hY0`001RVn002n:@D00_lX00?o8@004Ono:koo0B/1o`4[ofG>oleU00Go
00[>Z/koc[gocFGo0ZH02onFolkoc_mQUF6E00;o00?>:ol00_l012_>:lh4o`0B:oooc_o>9/koc_mF
AUKocC7o0UH00oo=P003o`0?<J[ooaK>5_nVZjKol_o`00;o01]RobARok2dodERof8UH_mR5F;oHUER
of9EH_l013800olb<P03<P06of;o_c:o0_l04[lb_c:ookn_ojnookn__ono<PCo00N_oooomLke00So
00k=<Oo=P?n6UXKo0@ooc@;o00@?UPnF0_l00`n[3`07o`03c_mQ00;o00T?cPooE_mVoh000_l00hhU
o`04o`05aPo6oc400_l00g8?o`02o`08i_l5SOo=<Ld2o`0:cV_ooli[cV_oJ`;o00G>oli[cP03o`06
cV_>oli[1?l01Li[of_>00Co00A[cV_o0`000ol0000=00000`000jHYo`040006I_?Vi_=V0`001VKc
i^KcIPD000?o00009003obD001So_ono<Koo_c7oQ_n=Z_o=S_mFo`K>1/h4o`05SOnV3jH00_l00liV
cP02o`055TDFo`800ol01LiZc_n600;o00c>U_n=of/[Jb_o9VH3o`0BAS16oc;o<F/aohgoE_o>ILiU
0_l01OGo0HH100Co027aoolYof7`oh2`ogenoh1RP?mnOGkoAF95oeEREOlaKS400_l6<P;o13804?lb
[c:_<_l3<_lb0ol2<P82o`03[ooo00;o00Joool6cPH2o`0Bc^G>oc7oIC9U<_o=SOlaoiH?2ol02B_o
olGoHJEQY@0;o`05i/kVobD01?l01<d6c@H6o`063oooL_la0_l01Z8aX_o=<@Co00E6L_mbAP03o`04
AW96LP?o00Ibog96LTH3o`05AW;oLTH01?l01W96L_mbAP?o0P000ol0000=000010000`EX00040004
9VQXIPD000@VJ6QV1P000ol0000R00;o:@004?l1:`7o0B/1okoocVGoIOl3EP08oljZoiKoSRX2o`08
Y_oo1/kocRH2o`03HIGo00;o00aboc75<LDaob_>:lh3o`04cRK>9P?o00K>L/koAUH2o`AF0_l01bK>
9_laZS401Ol00jKo1P03o`0Nl?ooH_lTH_n`]?m5H_mR9F;oHQERof9EH_mREF;o0c82o`Hb01Wo<[lb
_c;o_c:o<[oo_joo[koo_joo<_lb00Co016_oiKomOl?0Oo=oc4V<Oo=<@09o`<a1?l00ld?o`02o`07
<LDaaOo=<@02o`065/koo`oo1342o`04L_n=P0;o00AAoj8a0_l01:8aXS42o`07I/iVc_lES@06o`05
c_ooJlh01?l01F_>oli[00?o00I[cV_>olh2o`05Jom[cV/00ol01V_>Jom[cPCo00=[c_l00P000ol0
000=00007P000ol0000O00?o:`003Ola_c7o<Koo_hKoSJX00ol04S1F<?o>oiH?U_n>_Hko<BHa9P?o
016moooocS7oL/kocV[>o`7oUP02o`05cYKoob/00_l01II6olhF00Co00C>5_la0_l01fKo9UHVofD0
0_l010KocWd2o`03UC3o00;o027aoolYof7`oh2`ogenoh1RP?mnOGkoAF95oeEREF;oKS400_l6<P03
oc8b00<b017o<Zlb[c;o0c;o<P?o0S;o0`02o`05[ooookl02Ol03C7U<NGo<_oUojF>YHh00_l01kda
_C7oYG800ol05G;>olG>aLkoYOmV3olVomJFe_n>_@02o`05P?oo9H001?l01PKoePooc@;o010?og8a
LS7oOC7o<Ldaog961?l01W96L_mbAP?o00I6LTKoAW83o`04LTIbAP?o00I6odIbAW83o`05LTKoAW80
0ol00`3o000>00007P000ol0000L00?o;`002_l[ob/1:olV_bH2o`04L/ibo`9F1Ol030oo:XhZo`K>
1_o6o`<a0_l00h0aP004o`03<Ooo00Co00?>9/h00ol01<i6cTH3o`06cW;o:lh[0_l4:`03olhV00;o
00[>1/h6o`F=oc460ol00o3ol002o`0596;o/;@00_l05f;oHRERof8EH_mREF;oHUEREOlbogko00Hb
01Oo<[lb_c;o_c:o<[oo_ono[koo_joo<P02o`080oooojooc/d2o`08<KdaobHa9S42o`07iC3Uoc7=
o`02IP0Aoc4aoiKoHLeQodK>A_o5<LD00_l00lH?o`03o`0:ePoFoc7oaPooS@Co00=bcOl01ol00`l1
o`02o`08I/ko5HdEoc44o`06Jom[of_>1?l01F_>oli[00Co00G>Jom[cP03o`06cV_>Jom[0_l01Lko
cV_>00?o00?>Jol00P000ol0000<00007P000ol0000I00?o<`02o`09_c7oQ[n6_ono00Ko00D?okko
?002o`0ES[goo_lVo`mV3onmc[gocS7oY_o100;o00k>og8aLS7oc_mbokgoAP;o00nV:oo>aLkoc_mV
ofH`IS000ol03Lhaoc46<OmmcWgo<9D00_l00o7ol002o`05HO3oP;000_l05GkoP6:0ogimO_m5HTGo
EF9EH_m^o`02<P03oc8b00<b00?o<S800c804Olb[c:_<_l3o`<b0ol2<_l300Ko01joolkoJfKoSZZ>
onDaohKoc^G>ohkocfK?oc7oIP89o`04c_ooYP?o00?>A/h01_l01P4?0OlZP0;o00WnoomFcUKocLh0
1?l00g;oP004o`0:<Oooog96L_mbAPCo00EbA_m6LP04o`05AW;oLTH01?l01W96L_mbAP?o00A6LTIb
0ol01G;oLTIb00;o00<0o`003@0001h00_lG00?o>0002Ol1oklV_ol1:`07o`05iC3Uog`02Ol00lJ[
o`03<@03oh3o00:V0ol01/hVc_mb<0?o00G>A/ko`@02o`03:lh[00Ko00G>5/ko:`02o`09Y_o>ULjE
olh600?o00@5o`Ha0_l00o3ol002o`0596;o/;@00_l04V;oHRERof8EH_mREF;oHUERE@;o00@bOS;o
1C803?lb_c:o<_no<[lb_`?o00Ro[on__joo<PKo00>_ool00fH01onm<Kgo<Ol00hH00ol`i@02o`AV
00go<OnVolKo<LdaobF=00?o00JVoliFolh2o`043oo=c@Co00/?ohf0o`7oa_o>3`04o`0:<Kdaolh?
ohf0S@;o00G>Jom[cP04o`05JooocV/01?l01/i[c_o>J`?o00I[cV_oJlh4o`05JlkocV/00ol016_>
Jlh3o`04c_l0o`h0000M00;o5@03oc`000Oo_hJookla00;o00n>IOn=Z_o>_/jnoccoUPl02?l00kg>
o`03o`03ZomF009F00?ocRH00ol01/dacOmbYPGo00^Vo`ooaLk5c_mVcP03o`063fH?olha1?l00b_o
cP02o`03<?oo00;o01f`ooooHO3oP;3o/?mmof:0ogimO_m5HTGoEF9EHP02o`<b00?o<S800c800olb
<P03<P07oc:_<Zoo<P02o`080c;o<P8bo`<3o`04[ooo_`?o00E[I_n>ZP03o`0<QV^6JooUonK>olmV
0ol03@;o0JH1ofG>IOo>P<h00_l00`o63`02o`03cVK>00?o00<aLS401Ol00oko0@04o`06IW;o<4D`
0ol02BKo:X0Zog96LP03o`05LTKoAW801?l01TIbA_m6LPCo00E6L_mbAP04o`05LTKoAW801?l01TIb
A_m6LP;o00A6LTIb0_l>00007@000ol0000A00?o@0001Onoo`4[00;o00ZnO[inofG>oc3U1?l02ZKo
<C7oc[gocED2o`03L/ib00?o00<?U_l00ol01LkUolib00Co00C>olf00ol01Lh?olib00Co00?>E/h0
1_l02f6EoiEQUOlESOo>00?o00Zaoooo96;o/;B`0_l04DGo9F8UoaERof9EHUGoEF9E00;o00@bOS;o
1382o`04<[lb_`;o00Jo<[lbokl2o`09_joo[kn_oc:o00;o00Jooon_obX:o`:60ol00fIbo`03o`03
3b_o00;o00<?a_l01Ol01XgoojKoEP;o00YV3om[oeK>o`o>2Ol03EIbE_o>I_nm<On[oh000_l018f0
SH03o`05c_o>Jlh00ol01/koc_o>J`Co00G>Jom[cP04o`05JlkocV/01?l01/i[c_o>J`Co00G>Jom[
cP03o`h0000M0003o`0000l00_m40004okla_`;o00MUSVF>ojZ=00?o00<?<@l00_l01C2m<;go00;>
00GocHkoAP02o`033hKo00;o00O>L_laiC7U00;o00TacC7oIW;ocHd01ol01S7=og8aLP;o0115ZTGo
P2^0:ol[:_mmc_lV0ol02[3ooomQl?n0/802o`0BOOmRP6;oOGimof95H_mREF;o13800olb<P02<P;o
13801on_ojlb[ol00S802_l3<_lb0S;o0c82o`0?[ooo_omQ_Oo>cOmFodG=00?o00?>U_l00_l020o>
3ol?odH?0ol01C3=oh2>00;o00=[3f/00ol00fH?o`02o`033`Ko00?o00Mb<OoESMF=00;o00>Fcol0
1_l01@6V0On000;o0120ooooAW96L_mbog;oLTIb1?l01DIbog9600Co00EbA_m6LP04o`06AW96odIb
1?l01DIbog9600Co0P000ol0000<00007@000ol0000<00?oA`000ol1o`020005ogjnO[h00_l01<ib
olh2o`03Zola00<a1?l00eG=o`05o`09cTKoIW9VolkU00;o00BZcZ[>1_l03HjZoc7=ojG>YLkoc_l0
0R/03on>UHkoHIEQof6EoaF=5@04o`0</OooobARok2d/?n`0_l05BER9OlEHQGoEF9EoeEREOmn<Whb
o`04<P;o01Lb_c:ooeKo<[oo<[lbokn_ojno[olb_`03o`070on_obZ>:P02o`063lH?oc7=1?l00nG>
o`06o`0B3on63onmc[gocBG=ojKo<ODa0_l00lh[o`02o`0<cUK>odK>A_o>IOnF0ol01Lj6oleU00Co
00@?ohf00_l01V_>Jom[cP?o00G>JlkocP04o`03Jli[00?o00I[cV_oJlh3o`06cV_>oli[1?l01Li[
of_>00Co1P000ol0000<00007@000ol0000900?oB`002Ol0003oSVF>I@02o`03LS7o00?o00YF3onm
<?l?olj=1?l01UK>E_o>LPGo00KUo`4?oc42o`0?<Oo>:_laD35@ob[=oc7=00?o00h`YS3oZTFZob^0
:ol[:PSo00b`ooooHO3oP;20ogd2o`0>HX1RogenOOmRAF;oHUD2o`@b00So<S8bodJ_o`<b00Ko[on_
<_l3<P0:o`<boc82oc83<P?o00J_ooooHKd3o`030EKo00?o00G><OoUcP02o`05<C;ocED00_l00c1F
o`03o`05<?n>P8h00_l01<dacC42o`07A_o>3ol?5P06o`0@SOnFof_oLV]bohjZoc7oP0;o0h000omb
AP04o`05LTKoAW800ol00g96LP04o`05AW;oLTH01?l01G96odIb00Co00E6L_mbAP04o`X000?o0000
300001d000?o00001P03oe8000OoO[inob^o00Wo00daof]VJoo=oiH?of/?00Co0S400onmo`06o`0;
OZYnZ_laP?n>ZXh01_l3<@0<ob/[ohjES_mQUF6E0_l01@oomLke00?o00baoo7o968TokB`ok02o`0E
9F8UoaER5OmEHUGoEOnUoghbOS;o00<b01[o_b_o_c;o_eKo<[oo<[lbokn_ojnooklb_`?o00@3oolV
1ol01lG>oljEcYD00ol01ldacC7ocC400ol4<@;o00[=oombooDamOl10_l00eH?o`03o`033lko00;=
0_l019Ko3nH4o`08c_oo<AHaoh02o`03P?oo00;o00E[c_o>J`04o`05cV_oJlh00ol01<i[cV/3o`05
JlkocV/01?l01Li[of_>00Co3`000ol0000;00007@02o`@00omE000@ohiUohI6Q_laohgESOn>c@;o
00=[3ol00ol23`?o00O>L_nm<Kda00;o01XaIOlUc_laP360ob[>oe0aof_oaHko_HjmSPGo00E5ZTGo
P004o`049Poo<@Ko01g`of7`HOn`P?mm/?mRP6;oOGimof95H_mRoa>0o`03<P08oc8b<_m6[ol2<P07
okn_ojlbo`02<P0;o`?o<_lb0_lb0c800ol00jooo`03o`0;cX3>oj[>Z/kocS400_l01VH`oc4b<@?o
00Haoljmc[d2o`03c_o>00?o00?=<Ol00_l02/jZoomb<G;o5W87o`063ola<Oo>0_l01c7E<MGoSH00
0_l01G96odIb00Co00I6LTKoAW83o`05LTKoog800_l01DKoAW9600?o00E6L_mbAP04oa<000?o0000
2`0001`000Co00000omI00;o00h[_b_o:olVofG>IOmUc@Co00<?L_l00_l01nG>iOmVc_l00S42o`0H
ZWjZO_mmogjZOZ[o<H3oS_m[IV_o_C7o0S401Ol?Q_nR00Ko0W86o`03c_oo00?o00_aobAR9?nd/?n`
:@03o`099OlEHQGoEF9E00;o00PbYC;o<Whbo`8b01;o:kl[oklbokmFoc;o_c:ookl2o`08_jnooklb
okl2o`030ooo00<a00OocUG>olG>00Co16H02_laool?obK>9_l2<@05o`7nokd01ol02C46<@KocPK>
1P03o`069_nR<J8a0_l00lkEcP04o`055S4F<Ol00h000om[cP03o`06cV_>oli[1?l01Li[of_>00?o
00C>Jli[0ol01F_oJli[00?o5`000ol0000;00007004oe`001?oQTJ6oc6ookn6ohgEolgoI/iV00?o
00H`onG>iLh4o`0B<Ol`ofDaIC7ocRGoP360<Oo>0_l02F]VJfKoS/GoSP0>o`06L/ibog960_l04_3o
ooo`of7`HOn`P?mm/?n0OPCo00=mof800ol01A>04h3o00<b00So<S;o[dJ_o`8b00Ko_joo[ol3<P0<
o`?oo`8b0_lb0ol30ol02:ooohjmoh3>1?l020koL_mV<6H`0_l03<i[cV_o<G;o_OnV0@?o00=b9W80
0_l02LkocZ[>ookoLP02o`07I_l[cR_oc@02o`08E_la<Olaoh02o`06eC7E<On01?l01G96odIb00Co
00E6L_mbAP04o`05L_ooAW800ol01g96LTKoA_l06P000ol0000;00007002oel000[o:ol[0Ono9[lV
1?l01/hVc_l?o`<a00WoiOoo<On0SOl00eH02omnZWkoOC7oZWjZ00?o00G><Om[IP07o`0<I_o>cOo=
c/goL/ib2Ol01O7ooooa00;o00mR9?nd/?n`:On0OX3oP7h00ol06HEQojDbYC;o<WhbO_lbob^o:ono
oeJoE[l00_l01;lb_ol2_`07okn__ono<P02o`040ooo0P;o0S43o`033g;o00;o00G>JlkoIP02o`05
cPooJ`l02Ol2<@03olh?00Co00C=o`Ko0P42o`03J`oo00Ko16H2o`08<AKoP8go<AH4o`05JlkocV/0
1?l01Li[of_>00Co00I[cV_oJlh3o`06cV_>oli[0olK0003o`0000/0000N0003o`0005d00_l01kla
ohJoQ[l00_l02lg>ofKoaVK6oc2m00;o00ha_C6moiGoES1Foc5U<@Co00R0<Ol13onmc@?o00=bcW80
0_l04@o63lKoaLgocNG=og;oLPoo00=b00CoL_o`0ol05?3oOOmQok20ogf`oh1nP?mUHFGo0fX01_lC
P1>0o`@b0_l034J_AZoo<_n__jnoo`<b00_o<@<ao`8b0_lb0`02o`04_ooo[`Co00?nool00_l01W8V
L_mb5P?o00=bY_l00ol00ljmcP02o`06cPKoc[g>0ol01<iboj82o`06Z_ooomDa0_l02QK>5_mbcW;o
IUH2o`05<Kha__l00X02o`05LTKoAW801?l01TIbA_m6LP?o00IbAW;oLTH4o`05L_ooAW801?lN0003
o`0000/0000O0003o`0005h000Wo0Ono9[oo_b/01Ol02<H?a_laodKo13401?n=P?l2EP07ogjZojKo
XP03o`03aPo600?o00K>eLkoL_l2<@03oliV01?o00<Vool00_l01?7oP682o`0K];3o/2WoP7j0oh1n
P?mQQF65oc:U<_lbOS9n00;o00Fo:kl[_`02o`09E[mF_olb_c;o00>o00Oo_jnooklb00;o00H3ool2
ob/3o`06A/i6ofK>1?l00lkoo`02o`03mLko00<a00KoQ_lFc_l2<@0:o`m[olj6c_nRP0;o00@6<@Ha
0_l00lh?o`07o`0=c_lF<AHaohf0SOm[cP03o`06cV_>oli[1?l01Li[of_>00Co00E[c_o>J`04ob80
00?o00002`00020000?o0000GP002_noQ[ooAXI6okl8o`0:<6H`okda_OnES@Ko00D?EPooS@05o`06
c_oec_G>0_l01;g>_Lh2o`08_Ljmoc7=oc42o`033oo>00;>00Coc/k>0ol05o3ol?mm1Ggo/82`ok1m
ogj0O_mQIF7o00=Z00GoP1>0o`04<P;o00E6[dJ_AP02o`05[kn__ol00c802ola0on_oc82oc8300;o
00Booon_0_l01C5bog8V00Co00>mc[d00_l036IbI_m6c_nmc_l?0@ko00R0ooooeC7Eo`810_l2<@0=
oc7<<OlacC7o_S6no`03P0?o00EbA_m6LP04o`05AW;oLTH01?l01G96odIb00Co00<0o`0090000ol0
000:00008@02oel001;o_ono:koo0B_oYF7ocDG=AOl2AP03oc4a00Co00C>oh2R0ol00jJ[o`02o`8?
1Ol01LkEojKo00@a00?o<C400S46o`063fH?oljm2Ol08?7`of:0okB`]?lY/?mnP7koOX1nohEQQOlb
YC:Uoghb0_l02b^o:kl[_onoE[mF00;o00<b_ol00kl02?nFojoo<[lb0_l010?oo`82o`03cR_o00;o
00<[c_l01342o`03cVKo00Ko00f6ool6oeG>olkomLke00Ko00NRoolaohH100;o00C>eLkE0_l02/go
Z/jZoc4F<AH3o`04c_o>J`Co00G>Jom[cP04o`05JlkocV/01?l60003o`00028000?o00002P0002<0
00?o0000G@001om6QTKo_c400_l01bXV:_n0SX001_l02G;>L_nFc_nRc@04o`03LPoo00;o00O>UOn0
olko00>V00_oc[goY_nmc_l?Z`0:o`05cC7oolD01?l2l003o`Em00;o00j0/?n`OOmnP7koHFEQo`=Z
00GoP1>04`03o`07YOn_AZm6[`02o`0?_jno[omVoc;o0c43ojn600;o00@3<_no0_l00joo[`04o`0;
:lkoLS5bokg>o`l00ol01AG>olfm00?o01U6cTK>ohfZo`7oL_n6<?mbmG;oOOlao`7o009[00?o<C40
0_l02F7oooo=<Onn<@03o`03AW9600?o00I6LTKoAW83o`06LTIbog960ol;0003o`00024000?o0000
2P0002@000?o0000G0003_l[_b_o:`7o_omQYOm50_l024KoP360oaK>1ol00lkUcP03o`08<Oo>ULjE
ohd2o`>V00So<OnVZolao`:[00ooa_o>_LkocW;>olkoY/H00_l07o7ooo7`of:0oggo]?lY/?mnP7ko
OX1nohEQQOlbYC800_l0533U<>Go_b^oobKo_eJoobJookoo0[l01?noU[l2o`04<[oo0`;o00Roo`;o
A_lVcPKo00Xaoooo:omE<EDa0_l02lh6c_o>1/koc_on00?o00<?IPl01Ol00gfRo`02o`0;JhI[omGo
aPooAH001_l036_>Jom[of_oJli[cP?o00G>Jom[cP04o`l000?o000080000ol0000:00009@000ol0
001L000<ohKo<Koo_hKo9RXV0_l01b_>:onZcZX00_l4cP?o013eool?oljEc_o>ULkoJX1Z2ol02:_o
E/IFoc3>1ol01@nVoooa00?o00O`o`Em1OoD00;o00^`OOmnP7koHFEQo`04JP?o02;>ojG>YLjUojoo
<?D`ojooI[mVoc;o0c7oQZn6[ol3<_no0_l01Jooooo>00?o00?>_/h01_l03<h?c_lEcQGo1RH69PSo
00@a<_l`0_l012_o_Hh6o`9[1Ol0307oSF7ocC7=<OmbAP?o00E6LTKoAP02o`04L_mbAPCo4`000ol0
000P0003o`0000X0000V00;oG@006Ol[0Ono:kooHJGo:c7oA/ko<H3oo_oUc^D00_l0182=ool3UP04
oc60<@;o00BEohf01Ol00`o>o`06o`033lKo00?o00=QYF402?l02_7oooo`of:0H_l2O@0?obV`ogj0
O_mnP7j0of6500;o00VU<JDaonD`iC000_l49P08oeKo_bJo9_l3_`0:oknF_iKo<[oo0`;o00>ookl0
0_l01lkoc^G>ooh01ol010oo<ED3o`08c_oo3olacC42o`04cC7=<@;o00X?IPoocOnF3oo=0ol01LjZ
c_n000;o00I5P4GocC44o`05JlkocV/00ol00f_>J`03oaP000?o00007`000ol0000:0000:0000ol0
001K0007oc7oQ[n6_`02o`@V0ol00j[oo`03o`0>c_mF<?n5P8Go3c7oULh7o`03I_oo00Go00EbY_o=
ZP03o`07L/koEDIEAP02o`07cC7=olgol@03o`0Dl?l5O@Goe3go/7goOX1nP?mUHFD3o`0A<?o>aLk5
c_nUc_o>ooD`mC000_l03KmV_fJooc43ojn6[hH00_l01@<boon_00Co00K=og8[olh3o`07c^GoiLko
O@02o`045Oooc@?o0`l02omUoojVoc4boaHa00Go00>V3ol01?l01c7=<OmFoh000_l00f7oo`02o`05
LTKoAW801?l014Ibog82oa`000?o00007P000ol0000:0000:@000ol0001K00;o00>o:kl00_l01B/a
:c7o009V0_l0183ocED2o`=F00CoSH2=1?l01S7o3oo>c@Co00EbQ_o>LP07o`8?00WoI/iVof6Uo`80
1ol00o7ol003o`04HX1Ro`9m0_l02;0Yoh1nP?n00ol04;da_C7o<JDaYOl`oc06<?l29P07obKo9[lV
_`02o`:o00WoU[nF_om6okl00_l00koo0P08o`0;Zoo>iLkUonG>ohd00_l00lKoo`0<o`05<Ola9S40
0_l00c7=o`02o`04ZV7oH@;o00O>ob/aohf000;o00I[cV_oJlh3o`06cV_>oli[0_lN0003o`0001l0
00?o00002@0002X000?o0000G0001OnoodKo00<V017oUS6FoldacOo>SLkoES3oQ@03o`065/hFohH?
0ol01/ibc_mbcP?o00Mb1_o=mLge00Go00AbodIE0_l01ODaoc5b00So00L5O@Goe3gD00;o00B`oh1n
0ol03<G>oc2n<;koaLk5cP;o01_>eLkEoc3omLkeofJoob/`o`?o[hJ_o`;eoc801Ol03@?oYIGoL_l[
3b_oc^D01ol03`7o<BKoc_lac_o>L/koc@02o`055S4Fo`800ol03U3o1VX6J_n0_OmF1UKo0h000omb
AP04o`05LTKoAW801?lQ0003o`0001h000?o00002@0002/00_mM0007olh[c_lao`03IP06ob_oP360
2?l01G:Fog;>00Co00Ebc_o>J`04o`0>cVKoE/iFoj8aolKoc/d3o`07HOooiLkUcP02o`03cZ[o00Go
00ARP6;o0gd00ommo`03o`0<mOo5c/G>oc6m<Ola0ol01XKo1S06<0;o00LV<BHaokoo00=60_l01knF
_iKo_dH00_l01;oookl2o`04SZF>Y@;o00<?Zol00ol02jKoOC5m<GgocPK>00;o00@6<@Ha1ol062Ha
o`7oo_nnS[koZV6Zoh1Qoc4[<B_oP0Co00E[c_o>J`04obH000?o00007@000ol000090000;@000ol0
001K0003odJF00;o00fF<IKoY[oo<Lgoo_o>00;o00>63ol00/h3o`061/h6oaK>0ol3<@03olib00Go
00Ceo`6[0ol00c1bo`03o`03<ODa00;o00G>Z/kol002o`0Hl?ooO@Goe3gDogf0olh6cPKoaLk5okh`
1?l03Z/aZc7oeLko<?o>mLke0_l012/`:c02o`08QZn6[ol2m@84o`070_ooojFEY@04o`0:cW;o9W8V
obG>9@;o00lV<OnVolhacS7ocLk=ogd00_l0537oo`7n0Om@5_mZ1V[oP;f0o`IF0ol01W96L_mbAP?o
:`000ol0000L0003o`0000T0000^0003o`0005/00_l02/i[ofKo:dH[oh0<o`06<Oo>eLkE0ol01/go
c[k>_P?o00@aodF>1Ol00f6UH@07o`09c_m[Q_o>Z_oa00;o00O`oon0HX3o009m00_oOCcomLkec_o>
a@04o`0DcW;>L_l?QPoo<?l?UPoo<BKoI_l3AP0;odI6oiJoodJoA[l00_l00f_o_`03o`06YHkoooG>
1_l01<ko<Gd5o`<[00co<@KoJoo>iLkoSKd5o`0;3on>__nZHJYQof401?l01Li[of_>00Co;P000ol0
000L0003o`0000T0000_0003o`0005/000?oAW800_l01:JoY[l2o`0@L_mQ_F6mHOnEc_oEHMGo1P;o
00L?oc7e<Ola00;o01D1oc;><_nmHKeQoeE6EDKoAUE6EDH03?l04?3oogd5OOlme3goP7go1/h4o`08
eLkEofHaIS47o`0HQS26ooGoIUIVoc3o<2/`:on6ooD2mOn60_l00c;o0`02o`04YOoocP;o00Haolk>
old2o`039Ooo00?o00NV<:H`oc7o009[1Ol01j;ooc60oh000_l01E0FD?l600Co00E6L_mbAP04oc<0
00?o00006`000ol000090000<0000ol0001K00;o00C>Jol[0_l042_>ob_oSRZ>o`7oP37o<Ld7o`03
cC7o00Ko01LacOn>AHkoo_mQYOl2ojEQYF7oEC5E<@02o`035_oo00;o00S`??n0HX3oO@So00XacOo5
c/G>aOmb0_l01/koc/G>a@Ko16H2o`E60_l02Km6_on6o`;o0P02o`0?X_oo5S7o1/h6c_nmc_nR00?o
00?Uoj800_l2:`?o0V/01On6oleE00?o00NZOZYnof6000Go00K>JlkocV/3ocP000?o00006P000ol0
00090000<@02oe`000?oAW801?l03G;oY[oo_F7o_c7ocYD00ol01`Ibof/?old01?l00g;>LP05o`0H
_F7ooiKoA_nV0_mEAUGo0_lEcQGo<G8a0ol00o2ao`05o`0@cVGoYHjUojEQYF7oeLkEcP;o00[ec_G>
olg>o`Ko1<h04?mVoonVU_l`:c3o<4KomOl2QP04okoo<P?o00TV<BHaoc4V<BH01ol01ZG>YOnRc@;o
00GeL_m[o`03QP0Colgo<Kko<H0aokf0oldacOm6LP04oc`000?o00006@000ol000090000<`000ol0
001J00;o00?>Jlh00_l04b]6:on>o`4[0On0oc0Volko3nH01?l01C7=oiK>00Co00=bool00_l017co
of44o`0=YF7oo`;o<EGoQ_lFcP04o`0D??o=<LgocC7=<OlacC7o<Ldaolh3o`0@9_o>mLkeolGocPK>
okg>_@;o00eVcVK>I_m6oeI6ETKo00:600KoJonoo`<2o`075S4Foe7ocP02o`0;3olaOC5moc3U<>D0
1?l00`o>o`02o`:60ol03C4F<OmnZWkoHH1Qold01?m00003o`0001X000?o0000200003@000?o0000
FP002Om6oombA_nV_`02o`04_c6o<@;o00A6mDKe1?l01dDVoc8a<S400_l01/hac_m6cPCo00Ilool?
oh`4o`04SOoo5@[o01:al?o>ILkocVG>ohjUS_mQYF42o`09I/iVcVKoc_G>00;o00H6:`H[olh2o`07
<OnVUZJFYP02o`0<<4H`A_nFohKo_ol21Ol00c7oo`05o`0:Y_mUcVGo0Oo>Y@;o00?=S_l00_l00h0a
o`02o`0=ELko_S6noc60<H3oP003odD000?o00006@000ol000080000=@000ol0001J0005of_>Jlh0
0ol01<i[o`42o`06:olV<2Ko0VH02?mQYF6Uoc7=0_l01375<LD3o`04_Oo=I@Ko00f<omH?ohfmo`oo
cC7=00?o01;`occ`oc7=<OlacC7o<Ldaoc42o`09cPoo9/hVc_oe00;o00HFo`K>1/h2o`06cQK>5_o>
0ol01W;oAUI6o`:V0_l0109[okl3o`05X_oo<AH00_l03LDaoonVoggoQP7oiOl00YH04oo=oc7oSUF>
ofDaIOla5S4FojX01?m90003o`0001P000?o0000200003H00_mK0009odKoog96odIb00;o01/[YR^V
ooGoJc7o_om59TGo<Ol?0Oo><Ol?0Ol00/h00oo=SP02o`03cHko00Go00WEo`l1olEQojH05Ol01`mF
3eKoI/h00ol01/iFcUKo:`;o00I[oc5b<G83o`0<i/kVc_m6oiJVojH?0_l00c82o`03o`09eLkEc_la
cS7>00Co0P43o`03UXKo00;o00daeC7o<H0aoeG>EOla00CoCP000ol0000G0003o`0000P0000h0003
o`0005T00ol00f_>o`02o`05cV_ocR/00ol2IP07o`4[ojEQY@06o`04aOl?aPGo00aUonH?oleUofKo
ILd7o`033mH?00?o01C=ILgocC7=oldacC7oc/g>cOo>3`Co00KUc^GocQH3o`06A/i6c_lF0_l01QK>
5_mVLPCo00>Voj/00Z/6o`0:L_la5S7oQ_o5<@;o00>>ool00ol200;o0P002olF<AKoEHiEoc5U00?o
DP000ol0000G0003o`0000P0000i0003o`0005/00_l01G96odIb00?o019bAW;oJola_om59_m[<F_o
P344o`055RXFoc401Ol038koEVIFohkoc_n>c@Oo017aolf>cOo=<LgocTG>AOnUcP04o`07mC7omLke
cP03o`07LS7oJiI[UP02o`05cTK>A/h00ol00lh[cP02o`06YPnVo`n61Ol0297oc_n60Oo>0_l01BKo
c[g>00;o1`002_oE<OlaP37oEOmF0003o`0001H000?o0000200003X000?o0000F`000om[cP03o`05
cV_oJlh00ol012/1:`42o`=V00co:om5STGoUF6EHID2o`04SZ[oc@;o0VH3o`09IV]VoeGoJhKo00;=
1?l02/eUcOo=<LgocC44o`09U/ko<LdacOoU00;o00S>oli6cTKocP;o00E6oaK>5P02o`:V00Woc_oo
LUKoZol00ZH01Ol?oonn00?o00@Fo`660_l02Z[ooomES_no9_l60006oc4F<On>0omH0003o`0001D0
00?o0000200003/00_mL00;o00EbA_m6LP03o`06LTIboc6o0_l05F/aJola_olaP?n6oaHZ5R[oaIG5
U@05o`06LPmboljV0_l00`o?3`05o`03_Ooo00Wo00X?LPooLR]booDa0ol01b_>:lkoLS400ol02g:V
LZKoA_l?QPn600;o00C?U/nF0ol01HKoY_l200;o00<1okd01?l036DaIOmmolkoIPIVo`H000?oeC40
0omK0003o`0001H000?o00001`0003d000?o0000FP000om[cP03o`06cV_>oli[0ol04F_>ofKo:`4[
odGo:kooHIEQ00;o00VZSZZ>ohiUSVD02Ol01F_o5_o>00Go00S=<LgocC7=<@_o00NVc_o>:lh[00?o
00K>1/kocTH5o`0<Y_ooE_mbEW;ocVK>0_l06=Ko0Oo63lKoEHiEojYnZWkoP?no9[lVo`L00_mO0003
o`0001D000?o00001`0003h000?o0000FP02o`05LTKoAW801?l01DIbog9600;o00Da_c6o<@02o`0P
EXKo5R[oU_o5ULGo4oo=mLgoALi5c_mFolgoIQIVolh2o`08cOooXW:Rold2o`0@c_o>Z/ko9LdUofIb
IW;ocP;o00IFob_>:lh3o`04iLkUcP;o00`?<0l`oiKoYYJVo`l7o`0CY_o>_OmFoc5U<On>o`IV1VH6
o`1X0003o`0001@000?o00001`0003l000?o0000FP000om[cP03o`06cV_>oli[0ol01F_>ob/100?o
00Bo:kl[0_l3AP0Aohko:dKoIHko<Omm<OlV<BH00ol00aK>o`02o`04O?n=c@Go00o>3lh?olg>cOla
cC7oY/h00ol01/i6cTKocP;o00FV3jKocP02o`05cVKo3eH00ol02<iVc_l?o`oV1?l038gooeGo9S7o
OZYno`:000?o9[l00omY0003o`0001<000?o00001`0004000_mK00;o00EbA_m6LP04o`05AW;oLTH0
0ol01TIbA_mFQP;o00BF_iJo0_l01Q<14oo=o`8V00[oc_mF_eJooc601Ol00cb`o`02o`07c/g>cOm6
cP06o`03cBGo00?o00O=9_mFLUIb00;o00D?cPo>3`02o`043b/?:`?o00X?LPooY_l?o`n60ol0436E
ogdaoeJoE_laIC5Uogd3of`000?o00004`000ol000070000@P000ol0001I0003of_>00?o00K>Jlko
cV/3o`05JlkocV/01?l00li[o`02AP;o00@[AR]60_l00c56<@02o`049S4V<@;o00]5STF>ohi5occo
XP02o`03ALgo00?o00G>L_o=<@03o`09IW;oc]G>eOm600;o00C>3ol?0ol01<h?ofH2o`033mKo00So
017Voooo5S4FoaF=oc4V<BKoZP04og0000?o00004P000ol000070000@`000ol0001I00;o00EbA_m6
LP04o`05AW;oLTH00ol01TIbA_m6LP?o00AbA_lC0_l058IFobKoE_noE[oo_olaP37oI_la1?l01kfR
ooo=c/d00ol01@kocEG=00Go00?=9_l00ol00g:6o`04o`03LXKo00?o00/?ool?oc7=<Ol?YP05o`0:
UC6EogdaOOnoEP?oM@000ol0000A0003o`0000L000140003o`0005T000?oJlh00ol01/i[c_o>J`?o
00E[c_o>J`04o`05cV_oJlh00ol00dK>o`02o`0CcTK>oc7o0B/1ohko_b_oAHkoP004o`07c^G>ojKo
c@02o`07<Ooo3oo=A@03o`03LPoo00?o00Ce3oD?0ol00`o>3`03o`073fH?olko3`04o`09JfI[oc4F
<On=00CoN@000ol0000@0003o`0000L0001500;oFP02o`05LTKoAW801?l01DIbog9600?o00I6LTKo
AW83o`03LTKo00;o00I6LTKoEXH2o`04_c6o<@;o00]VQVKo<H3oc_m[<@02o`08cOo>Zlko_J82o`04
3g8?o`;=1?l01RIb9W;ocP;o00@?L_m[0_l00bH?o`0:o`07<FHaI_laU@03ogd000?o00004@000ol0
00060000A`000ol0001H0003of_>00?o00K>JlkocV/3o`05JlkocV/01?l00li[o`02o`05JlkocV/0
1?l01Li[o`4[00;o00No:kl[_on>00;o00AVJfI[0ol00`nVo`0<o`06LPmbolib1?l00`o>o`03o`08
3oooL_l6cPH4o`05cV_oJfH01?n10003o`00010000?o00001P0004P000?o0000F002o`05LTKoAW80
1?l01DIbog9600?o00=6LTH00ol01DIbog9600?o00I6LTKoAW83o`05LTKoIXH01?l01DIbof/a00;o
00>6ool00_l01lh?okk>_/h02ol23`Co00=[LV/00_l01ZK>Y/kocP;o00EbA_m6LP03ohH000?o0000
3`000ol000060000B@000ol0001H0003of_>00?o00K>JlkocV/3o`04JlkocP;o00E[c_o>J`03o`05
JlkocV/01?l01Li[of_>00?o00K>JlkocV/3o`06JlkoA_o01Ol03<koo`Ko_Ljmc_o=cPCo00G>L/ko
LP02o`05APooIW801?l00li[o`03ohT000?o00003`000ol000060000BP02oeT00_l01W96L_mbAP?o
00E6L_mbAP03o`03AW;o00?o00E6L_mbAP03o`06AW96odIb0ol01G96odIb00Co00E6L_mbAP07o`08
X_ooolh?c_l3cP?o00K>3lkocRH4o`03cPoo00Co00=bA_l00_n>0003o`0000h000?o00001P0004`0
00?o0000E`000om[cP04o`05JlkocV/00ol00f_>o`02o`06cV_>oli[0ol01F_>oli[00Co00G>Jom[
cP03o`06cV_>oli[0ol01F_>oli[00[o00S>oomb3_l?cPco00?>ool00_nB0003o`0000d000?o0000
1P0004d000?o0000E`02o`06LTIbog960ol00dIbo`02o`05LTKoAW801?l01DIbog9600?o00I6LTKo
AW83o`05LTKoAW801?l01DIbog9600?o00=6L_l00_l00g96o`0@o`04c_ooLP?oU`000ol0000<0003
o`0000H0001>0003o`0005L000?oJlh01?l00f_>o`02o`05cV_oJlh00ol01/i[c_o>J`?o00E[c_o>
J`04o`05cV_oJlh00ol01/i[c_o>J`?o00=[c_l00_l01Li[of_>00Co00E[c_o>J`03o`05Jli[of/0
1?nJ0003o`0000d000?o00001@0004l00_mH00;o00=bA_l00ol01G96odIb00?o00EbA_m6LP04o`05
AW;oLTH00ol01TIbA_m6LP?o00EbA_m6LP04o`03A_oo00;o00EbA_m6LP03o`06LTIbog960ol01DIb
og9600CoWP000ol0000<0003o`0000D0001A0003o`0005L00_l01V_>Jom[cP?o00G>Jom[cP03o`06
cV_>oli[0ol01F_>oli[00Co00G>Jom[cP03o`03cV_o00;o00I[cV_oJlh3o`05cV_oJlh01?l01F_>
oli[00?oX`000ol0000;0003o`0000D0001B0003o`0005L000?oLTH01?l01G96odIb00?o00EbA_m6
LP04o`05AW;oLTH00ol01DIbog9600Co00=bA_l00_l01DIbog9600Co00EbA_m6LP03o`05LTKoAW80
1?nW0003o`0000X000?o00001@0005<000?o0000E`02o`06Jli[of_>0ol01Li[of_>00?o00K>Jlko
cV/3o`05JlkocV/00ol00f_>o`03o`05JlkocV/00ol01F_>oli[00Co00G>Jom[cP03oj/000?o0000
2P000ol000050000E002oeP000?oLTH01?l01G96odIb00?o00EbA_m6LP04o`05AW;oLTH00ol00dIb
o`02o`06LTIbog960ol01DIbog9600?o00I6LTKoAW83ojl000?o00002@000ol000050000EP000ol0
001F00;o00I[cV_oJlh3o`05cV_oJlh00ol01/i[c_o>J`?o00=[c_l00_l01Li[of_>00Co00E[c_o>
J`03o`05JlkocV/01?nc0003o`0000P000?o00001@0005L000?o0000EP000ombAP04o`05LTKoAW80
0ol01G96odIb00Co00=6ool00_l01G96odIb00?o00EbA_m6LP04o`05AW;oLTH00ong0003o`0000T0
00?o0000100005P000?o0000EP02o`06Jli[of_>0ol01Li[of_>00?o00?>Jol00_l01V_>Jom[cP?o
00G>Jom[cP03o`06cV_>oli[0onk0003o`0000P000?o0000100005T000?o0000EP000ombAP04o`03
L_oo00Go00=bA_l00_l01DIbog9600Co00EbA_m6LP03o`05LTKoAW801?no0003o`0000L000?o0000
100005X00_mG00;o00=[c_l00_l01/i[c_o>J`?o00E[c_o>J`03o`06Jli[of_>0ol01Li[of_>00?o
a0000ol000060003o`0000@0001L0003o`0005H00_l01G96odIb00Co00E6L_mbAP03o`05AW;oLTH0
1?l01G96odIb00?oa`000ol000060003o`0000@0001M0003o`0005H000?oJlh00ol01/i[c_o>J`?o
00E[c_o>J`03o`05JlkocV/01?o;0003o`0000D000?o0000100005h000?o0000EP02o`05LTKoAW80
1?l01DIbog9600?o00E6L_mbAP03om0000?o000010000ol000040000G`02oeL000?oJlh00ol01/i[
c_o>J`?o00E[c_o>J`03om@000?o00000`000ol000040000H@000ol0001E00;o00EbA_m6LP04o`05
AW;oLTH00ooG0003o`0000@000?o00000`00068000?o0000E@000om[cP03o`05cV_oJlh01?oK0003
o`0000<000?o00000`0006<000?o0000E@02o`05LTKoAW800ooP0003o`00008000?o00000`0006@0
0_mG00Goi0001Ol0003o00D0001V0003o`0005@000?o0000iP001Ol0003o00D0001W0003o`0005<0
00?o0000i`001?l00?l50000J0000ol0001B0003o`000>P000?o0?l01@0006T00_mB0003o`000>P0
00Co003o100006/000?o0000C`000ol0003Y0003o`3o00@0001/0003o`0004h000?o0000jP02o`@0
001]0003o`0004d000?o0000j@03o`@0001^00;oC@000ol0003U00Co1`00070000?o0000BP000ol0
003Q00Co2`00074000?o0000B@000ol0003N00?o3`00078000?o0000B0000ol0003J00Co4P0007<0
0_m80003o`000=H01?lF0000M@000ol000150003o`000=801?lJ0000MP000ol000140003o`000<h0
1?lN0000M`000ol000130003o`000</00olR0000N002od<000?o0000a`04obD0001j0003o`000400
00?o0000``04obT0001k0003o`0003l000?o0000_`04obd0001l0003o`0003h000?o0000^`04oc40
001m00;o?P000ol0002h00?o=@0007l000?o0000>`000ol0002d00Co>000080000?o0000>P000ol0
002`00Co?000084000?o0000>@000ol0002/00Co@000088000?o0000>0000ol0002X00CoA00008<0
0_lh0003o`000:D00om80000Q@000ol0000e0003o`000:401?m;0000QP000ol0000d0003o`0009d0
1?m?0000Q`000ol0000b0003o`0009X01?mC0000R002oc8000?o0000UP04oeL0002:0003o`0002l0
00?o0000TP04oe/0002;0003o`0002h000?o0000S`03oel0002<0003o`0002d000?o0000R`04of80
002=00;o;@000ol0002700CoIP0008l000?o0000:P000ol0002300CoJP00090000?o0000:@000ol0
001o00CoKP00094000?o0000:0000ol0001l00?oLP0009800_lX0003o`0007P01?me0000U0000ol0
000U0003o`0007@01?mi0000U@000ol0000T0003o`0007001?mm0000UP000ol0000S0003o`0006`0
1?n10000U`02ob<000?o0000J@03ohD0002I0003o`00020000?o0000I@04ohP0002J0003o`0001l0
00?o0000H@04oh`0002K0003o`0001h000?o0000G@04oi00002L00;o7P000ol0001I00CoU00009h0
00?o00006`000ol0001F00?oV00009l000?o00006P000ol0001B00CoV`000:0000?o00006@000ol0
001>00CoW`000:400_lI0003o`0004X01?nS0000X`000ol0000F0003o`0004H01?nW0000Y0000ol0
000E0003o`0004801?n[0000Y@000ol0000D0003o`0003l00on_0000YP02oa@000?o0000>`04ok80
002X0003o`00014000?o0000=`04okH0002Y0003o`00010000?o0000<`04okX0002Z0003o`0000l0
00?o0000;`04okh0002[0003o`0000d000?o0000;@03ol80002/00;o3@000ol0000Y00Coa@000:h0
00?o00002P000ol0000U00Cob@000:l000?o00002@000ol0000Q00Coc@000;0000?o000020000ol0
000M00Cod@000;400_l80003o`0001X00ooE0000/`000ol000050003o`0001H01?oH0000]0000ol0
00040003o`0001801?oL0000]@000ol000030003o`0000h01?oP0000]P02o`<000?o00002P04on@0
002h0004o`00o`T00ooX0000^@000ol0o`0500Coj`000;X00_l00`3oo`02onl0002k00;ol`000?l0
/@000?l0/@000?l0/@000?l0/@000?l0/@000?l0/@000?l0/@000?l0/@000001\
\>"],
   ImageRangeCache->{{{54.0625, 283.438}, {794.438, 608.625}} -> {-0.310005, \
2.75356, 0.00358826, 0.00358826}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
     \(ListDensityPlot[
       Image, {PlotRange \[Rule] {0, 500}, Mesh \[Rule] False}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0147929 0.0192308 0.0147929 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16716 -0.0125 -6 -9 ]
[.16716 -0.0125 6 0 ]
[.31509 -0.0125 -6 -9 ]
[.31509 -0.0125 6 0 ]
[.46302 -0.0125 -6 -9 ]
[.46302 -0.0125 6 0 ]
[.61095 -0.0125 -6 -9 ]
[.61095 -0.0125 6 0 ]
[.75888 -0.0125 -6 -9 ]
[.75888 -0.0125 6 0 ]
[.9068 -0.0125 -6 -9 ]
[.9068 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16716 -12 -4.5 ]
[-0.0125 .16716 0 4.5 ]
[-0.0125 .31509 -12 -4.5 ]
[-0.0125 .31509 0 4.5 ]
[-0.0125 .46302 -12 -4.5 ]
[-0.0125 .46302 0 4.5 ]
[-0.0125 .61095 -12 -4.5 ]
[-0.0125 .61095 0 4.5 ]
[-0.0125 .75888 -12 -4.5 ]
[-0.0125 .75888 0 4.5 ]
[-0.0125 .9068 -12 -4.5 ]
[-0.0125 .9068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16716 0 m
.16716 .00625 L
s
[(10)] .16716 -0.0125 0 1 Mshowa
.31509 0 m
.31509 .00625 L
s
[(20)] .31509 -0.0125 0 1 Mshowa
.46302 0 m
.46302 .00625 L
s
[(30)] .46302 -0.0125 0 1 Mshowa
.61095 0 m
.61095 .00625 L
s
[(40)] .61095 -0.0125 0 1 Mshowa
.75888 0 m
.75888 .00625 L
s
[(50)] .75888 -0.0125 0 1 Mshowa
.9068 0 m
.9068 .00625 L
s
[(60)] .9068 -0.0125 0 1 Mshowa
.125 Mabswid
.04882 0 m
.04882 .00375 L
s
.0784 0 m
.0784 .00375 L
s
.10799 0 m
.10799 .00375 L
s
.13757 0 m
.13757 .00375 L
s
.19675 0 m
.19675 .00375 L
s
.22633 0 m
.22633 .00375 L
s
.25592 0 m
.25592 .00375 L
s
.2855 0 m
.2855 .00375 L
s
.34467 0 m
.34467 .00375 L
s
.37426 0 m
.37426 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.43343 0 m
.43343 .00375 L
s
.4926 0 m
.4926 .00375 L
s
.52219 0 m
.52219 .00375 L
s
.55178 0 m
.55178 .00375 L
s
.58136 0 m
.58136 .00375 L
s
.64053 0 m
.64053 .00375 L
s
.67012 0 m
.67012 .00375 L
s
.6997 0 m
.6997 .00375 L
s
.72929 0 m
.72929 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.81805 0 m
.81805 .00375 L
s
.84763 0 m
.84763 .00375 L
s
.87722 0 m
.87722 .00375 L
s
.93639 0 m
.93639 .00375 L
s
.96598 0 m
.96598 .00375 L
s
.99556 0 m
.99556 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16716 m
.00625 .16716 L
s
[(10)] -0.0125 .16716 1 0 Mshowa
0 .31509 m
.00625 .31509 L
s
[(20)] -0.0125 .31509 1 0 Mshowa
0 .46302 m
.00625 .46302 L
s
[(30)] -0.0125 .46302 1 0 Mshowa
0 .61095 m
.00625 .61095 L
s
[(40)] -0.0125 .61095 1 0 Mshowa
0 .75888 m
.00625 .75888 L
s
[(50)] -0.0125 .75888 1 0 Mshowa
0 .9068 m
.00625 .9068 L
s
[(60)] -0.0125 .9068 1 0 Mshowa
.125 Mabswid
0 .04882 m
.00375 .04882 L
s
0 .0784 m
.00375 .0784 L
s
0 .10799 m
.00375 .10799 L
s
0 .13757 m
.00375 .13757 L
s
0 .19675 m
.00375 .19675 L
s
0 .22633 m
.00375 .22633 L
s
0 .25592 m
.00375 .25592 L
s
0 .2855 m
.00375 .2855 L
s
0 .34467 m
.00375 .34467 L
s
0 .37426 m
.00375 .37426 L
s
0 .40385 m
.00375 .40385 L
s
0 .43343 m
.00375 .43343 L
s
0 .4926 m
.00375 .4926 L
s
0 .52219 m
.00375 .52219 L
s
0 .55178 m
.00375 .55178 L
s
0 .58136 m
.00375 .58136 L
s
0 .64053 m
.00375 .64053 L
s
0 .67012 m
.00375 .67012 L
s
0 .6997 m
.00375 .6997 L
s
0 .72929 m
.00375 .72929 L
s
0 .78846 m
.00375 .78846 L
s
0 .81805 m
.00375 .81805 L
s
0 .84763 m
.00375 .84763 L
s
0 .87722 m
.00375 .87722 L
s
0 .93639 m
.00375 .93639 L
s
0 .96598 m
.00375 .96598 L
s
0 .99556 m
.00375 .99556 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16716 .99375 m
.16716 1 L
s
.31509 .99375 m
.31509 1 L
s
.46302 .99375 m
.46302 1 L
s
.61095 .99375 m
.61095 1 L
s
.75888 .99375 m
.75888 1 L
s
.9068 .99375 m
.9068 1 L
s
.125 Mabswid
.04882 .99625 m
.04882 1 L
s
.0784 .99625 m
.0784 1 L
s
.10799 .99625 m
.10799 1 L
s
.13757 .99625 m
.13757 1 L
s
.19675 .99625 m
.19675 1 L
s
.22633 .99625 m
.22633 1 L
s
.25592 .99625 m
.25592 1 L
s
.2855 .99625 m
.2855 1 L
s
.34467 .99625 m
.34467 1 L
s
.37426 .99625 m
.37426 1 L
s
.40385 .99625 m
.40385 1 L
s
.43343 .99625 m
.43343 1 L
s
.4926 .99625 m
.4926 1 L
s
.52219 .99625 m
.52219 1 L
s
.55178 .99625 m
.55178 1 L
s
.58136 .99625 m
.58136 1 L
s
.64053 .99625 m
.64053 1 L
s
.67012 .99625 m
.67012 1 L
s
.6997 .99625 m
.6997 1 L
s
.72929 .99625 m
.72929 1 L
s
.78846 .99625 m
.78846 1 L
s
.81805 .99625 m
.81805 1 L
s
.84763 .99625 m
.84763 1 L
s
.87722 .99625 m
.87722 1 L
s
.93639 .99625 m
.93639 1 L
s
.96598 .99625 m
.96598 1 L
s
.99556 .99625 m
.99556 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16716 m
1 .16716 L
s
.99375 .31509 m
1 .31509 L
s
.99375 .46302 m
1 .46302 L
s
.99375 .61095 m
1 .61095 L
s
.99375 .75888 m
1 .75888 L
s
.99375 .9068 m
1 .9068 L
s
.125 Mabswid
.99625 .04882 m
1 .04882 L
s
.99625 .0784 m
1 .0784 L
s
.99625 .10799 m
1 .10799 L
s
.99625 .13757 m
1 .13757 L
s
.99625 .19675 m
1 .19675 L
s
.99625 .22633 m
1 .22633 L
s
.99625 .25592 m
1 .25592 L
s
.99625 .2855 m
1 .2855 L
s
.99625 .34467 m
1 .34467 L
s
.99625 .37426 m
1 .37426 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .43343 m
1 .43343 L
s
.99625 .4926 m
1 .4926 L
s
.99625 .52219 m
1 .52219 L
s
.99625 .55178 m
1 .55178 L
s
.99625 .58136 m
1 .58136 L
s
.99625 .64053 m
1 .64053 L
s
.99625 .67012 m
1 .67012 L
s
.99625 .6997 m
1 .6997 L
s
.99625 .72929 m
1 .72929 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .81805 m
1 .81805 L
s
.99625 .84763 m
1 .84763 L
s
.99625 .87722 m
1 .87722 L
s
.99625 .93639 m
1 .93639 L
s
.99625 .96598 m
1 .96598 L
s
.99625 .99556 m
1 .99556 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
65 string
65 65 8 [65 0 0 65 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001000000010000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000050000000000
0000000000000100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000400000000020000000000000000000000000000000000
000000000000000000000000000000000000000000000000000100000000000000000000
0000000000000000000000000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000400000000000000000000
0000000000000000000000000001000000000000000000000000000000
000000000000000000000000000000000000000000000003000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000007000000000000000000000000000000000000
000000000000000000000000000000000001000000000000000000000000000000020200
0000000000000000000000000000000000000000000000000000000000
000000000000000000000002000000000000000000000000000103000000000401000000
0001000000000000000000000000000000000000000000000000000000
000000000000000000000200000000000000000100000000000400000000000005000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000030000000000000000000000000005000101000100040003030000
0000000000000000010000000000000000000000000000000000000000
000000000000000000000000000900000000000300030004000206000009010602060100
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000003010004040602070203070805000502
07020A0100000100000000000000000000000000000000000000000000
000000000000000000000000000000000105000002020407010F08090609090003080204
0002000000000000000000000000000000000000000000000000000000
0000000000000000000000000300000000030001030402040A181105070C0D150C030F03
0603040000000400000000000000000000000000000000000000000000
000000000001000400080004000000020205080B08120E0B131A171C1320190E00090F04
0800000000000000000000000000000000000000000000000000000000
00000000000003000000090101000206090C0F0B1713201B19292F32384650565D412300
0000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000200000B090D131423232A334A53616A717B7A
780E000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000000000200050000080A1A1A0B2963A2D7E0E6E7
D9B854070F0B1208080204000003010000000000000000000000000000
000000000000000000000000000000000000000000000403000F020063C3D6EEFFFFFFFF
FEFBCF620012131910110F080003060404000000000100000000030000
000000000000000000000000000000000000000000000100000D0084CBFEFFFFFFFFFFFF
FFFFFCC7461D191314090A040606000008000000000000000000000000
00000000000000000000000000000000000000000000000000005FCAFEFFFFFFFFFFFFFF
FFFFFFECBD081D150E0E0C0C0304000608010100060004000000000000
0000000000000000000000000000000000000000000000050114BFFCFFFFFFFFFFFFFFFF
FFFFFFFFCB32251711110E080A01020607000000000500000000030000
000000000000000000000000000000000000000000010009004AD0FEFFFFFFFFFFFFFFFF
FFFFFFFFDD652D1A12170F0B0900040006000100000200000600000000
0000000000000000000000000000000000000000000000020081E7FFFFFFFFFFFFFFFFFF
FFFFFFFFEA8F181E13100C09090E050006000002000000000000000000
00000000000000000000000000000000000000000000000000ADFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFBB5021811161118110B0A0906020002000000000000040400
0000000000000000000000000000000000000000000000030081E7FFFFFFFFFFFFFFFFFF
FFFFFFFFEA8F181F13100C0A090E050006000002000000000000000000
000000000000000000000000000000000000000000010009004AD0FEFFFFFFFFFFFFFFFF
FFFFFFFFDD652D1A12170F0B0900040006000000000200000600000000
0000000000000000000000000000000000000000000000050215BFFCFFFFFFFFFFFFFFFF
FFFFFFFFCB32251811110F080A01020608000100000500000000030000
00000000000000000000000000000000000000000000000000005FCAFEFFFFFFFFFFFFFF
FFFFFFECBD071D150E0D0C0C0304000608010100050004000000000000
000000000000000000000000000000000000000000000100000E0084CBFEFFFFFFFFFFFF
FFFFFDC7461D1A1315090B040706010008000000000000000000000000
0000000000000000000000000000000000000000000004030010020063C3D6EFFFFFFFFF
FEFBCF620012131910110F080003060404000000000200000000030000
0000000000000000000400000000000000000005010800020B0D1D1D0E2C66A5DBE3E9EA
DCBB570B120E150B0B0507000306040200000000000000000000000000
00000000000000000000000000040004080B07091312161B1D2C2B333B525C6A727A8483
8016000000000200000000000000000000000000000000000000000000
0000000000000000000004000000000104070906110D1A161423292D32404B51583B1D00
0000000000000000000000000000000000000000000000000000000000
000000000001000400070003000000010105080A07120D0B121A171B1220180D00080E04
0800000000000000000000000000000000000000000000000000000000
00000000000000000000000002000000000200000303010409171104060B0C140C030E02
0603030000000400000000000000000000000000000000000000000000
000000000000000000000000000000000105000002010407010F08080508090003080203
0001000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000003010004040601070202070805000502
07020A0100000100000000000000000000000000000000000000000000
000000000000000000000000000900000000000300030004000206000009010602050000
0000000000000000000000000000000000000000000000000000000000
000000000000000000030000000000000000000000000004000101000100040003030000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000200000000000000000100000000000400000000000005000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000002000000000000000000000000000103000000000401000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000000000000000000000000000000020200
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000007000000000000000000000000000000000000
000000000000000000000000000000000000000000000003000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000400000000000000000000
0000000000000000000000000001000000000000000000000000000000
000000000000000000000000000000000000000000000000000100000000000000000000
0000000000000000000000000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000400000000020000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000050000000000
0000000000000100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001000000010000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
   ImageSize->{288, 288},
   ImageMargins->{{43, 0}, {0, 0}},
   ImageRegion->{{0, 1}, {0, 1}},
   ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0/@000?l0/@000?l0/@000?l0/@000?l0
/@000?l0/@0001`000@VJ?l5=004o`03J000008000@VJ?l5;P06o`@000@VJ?l5;P001[jXoom]iP@0
00@VJ?l5<P02o`03J000008000@VJ?l5;P001YEXoolYiP@000@VJ?l5;P001^HYoom]iP@000@VJ?l5
8P0001/000IVlnKVZ;he0003o`0000<000IVlnKVZ;h]0003UOmV008000IX0000I_<2iP03Z;h002`0
00IX_P001O<30006I_?ViZRn<P000ol000020006I_?ViZRn;@001VQE0005:@<000IVlnKVZ;h]0006
K@D000E]0`001VKci^JX_R40000K0006:Kh00;kc=@000ol000030006:Kh00;kc;P000iGoIP050006
:Kh00;kc<P001_l0000Y_P8000>nl`00;@06o`<000HY_P00__<b0006o`0002Vn0P000kkc000/0003
J000008000Ko0000:Kh20003__<00200000K0003o`00008000?o0000<`000ol000030003o`000080
00?o0000;@000kiXIP040003o`00008000?o0000;`000`FX00020003o`00008000?o0000;0001@Fn
003o00@000?o00000P000ol0000_0003i_l0008000?o00000P000ol0000[0003onH0008000Go0000
o`040003o`0001l0000K0003o`00008000?o0000<`000ol000030003o`00008000?o0000;P000fIX
IP030003o`00008000?o0000;@001:SoobH30003o`00008000?o0000;0001NKciP3o00@000?o0000
0P000ol0000[0006J9D000F10`000ol000020003o`0002/000KoKNH01Fd30003o`00008000?o0000
7`0001/000?o00000P000ol0000c0003o`0000<000?o00000P000ol0000_0003__<0008000?o0000
0P000ol0000^0003iPGc00<000?o00000P000ol0000]0004_X40o`@000?o00000P000ol0000[0005
ojSooh4010000ol000020003o`0002/000JX1OooKNH30003o`00008000?o00007`0001/000HY_P00
_RTe0003o`0000<000HY_P00_RTb0006o`0002Vn0P000khY000a0006o`0002Vn0P000khY000_0003
:FKo00@000HY_P00_RT]0003o`0000H000HY_P00_RT]0003EH4000H000HY_P00_RTQ00006`001VKc
i^KcIS<000?o:Ol01@001VKci^KcIRd000KoENH01O<30006I_?Vi_=V;@001ZQE0021l`<000IVlnKV
lfH`0003YRWo00@000IVlnKVlfH]0003o`0000H000IVlnKVlfH^0003lh6V00D000IVlnKVlfHQ0000
700012IXJ6Hd0003IVgo00H000@VJ6QV;P001[kcoom]iP@000@VJ6QV;P001RHYoolYiP@000@VJ6QV
<P000`EX000400049VQXIRh01Ol500049VQXIS0000@5J?nX100012IXJ6HR0000o`2a0000o`2a0000
o`2a0000o`2a0000o`2a0000o`2a00005`3ooiWo0@0001L000?o000010000ol0000:0003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000X0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00002P02o`40000G0003o`0000@000?o00002P000ol000090003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol0000:0003o`0000T000?o00002@000ol0
00090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000T0
00?o00002@000ol000090003o`0000T000?o00002@000ol000090003o`0000X00_l100005`000ol0
00040003o`0003X000?o0000>@000ol0000i0003o`0003X000?o0000>@000ol0000i0003o`0002<0
0Ol100005`000ol0003o09D00Ol100005`000ol0003o09D00Ol100002`0012IXo`D80003o`000?l0
U@01o`40000:0006I_?ViZRn1`000ol0003o09D00Ol100002P001RVn002nl`L00ooo09<00ol10000
2P000ol000020003o`0000D000?o0000103ooh[o1`01o`40000:0003o`00008000?o00001@000ol0
00040?ooR_l7007o0@0000X000?o00000P000ol000050003o`0000@0oon:o`L00Ol100002P001RVn
002n:@L000?o0000103ooh[o1`01o`40000:0006I_?Vi_=V1`000ol000040?ooR_l7007o0@0000/0
00@VJ6QV20000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0
oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003
o`0000@0oon:o`L00Ol100005`02o`D0oon:o`H00_l100005`000ol000040?ooR_l7007o0@0001L0
00?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o
0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol100005`000ol000040?oo
R_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol100005`000ol0
00040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G00;o1@3ooh[o1P02o`40000G0003
o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40
000G0003o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o
1`01o`40000G0003o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000
103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L0
0_l50?ooR_l600;o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol10000
5`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L0
0Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000102fo`HccOl7007o0@0001L000?o0000
102fo`HccOl7007o0@0001L000?o0000102fo`HccOl7007o0@0001L000?o0000102fo`HccOl7007o
0@0001L000?o0000102fo`HccOl7007o0@0001L000?o0000102fo`HccOl7007o0@0001L00_l50?oo
R_l600;o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol100005`000ol0
00040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol10000
5`000ol000040?ko1S<Io`HcI_l7007o0@0001L000?o0000103no`Hc6Ol6<fKo1`01o`40000G0003
o`0000@0o_l6<aWo1S=Vo`L00Ol100000P04o`03J000008000@VJ?l520000ol000040?ko1S<Io`Hc
I_l7007o0@0000@000?o00000`001VKci^JX_PL000?o0000103no`Hc6Ol6<fKo1`01o`4000040003
o`0000<000HY_P00__<70003o`0000@0o_l6<aWo1S=Vo`L00Ol1000010000ol000030003o`000080
00?o00001@03o`@0oon:o`D00ol1000010000ol000030003o`00008000?o00001@000ol000040?oo
R_l7007o0@0000@000?o00000`000ol000020003o`0000D000?o0000103ooh[o1`01o`4000040003
o`0000<000HY_P00_RT70003o`0000@0oon:o`L00Ol100000P000olYo`050006I_?Vi_=V1`000ol0
00040?ooR_l7007o0@00008000=VKOl01P0012IXJ6H80003o`0000@0oon:o`L00Ol100005`000ol0
000409So1S?[o`L00Ol100005`000ol0000409So1S?[o`L00Ol100005`000ol0000409So1S?[o`L0
0Ol100005`000ol0000409So1S?[o`L00Ol100005`000ol0000409So1S?[o`L00Ol100005`000ol0
000409So1S?[o`L00Ol100005`02o`D0Rol7<oOo1P02o`40000G0003o`0000@0Rol7<oOo1`01o`40
000G0003o`0000@0Rol7<oOo1`01o`40000G0003o`0000@0Rol7<oOo1`01o`40000G0003o`0000@0
Rol7<oOo1`01o`40000G0003o`0000@0Rol7<oOo1`01o`40000G0003o`0000@0Rol7<oOo1`01o`40
000G0003o`0000@0oolHo`I3K?l7007o0@0001L000?o0000103ooaSo1T=/o`L00Ol100005`000ol0
00040?oo6?l6@fco1`01o`40000G0003o`0000@0oolHo`I3K?l7007o0@0001L000?o0000103ooaSo
1T=/o`L00Ol100005`02o`D0oolHo`I3K?l600;o0@0001L000?o00001038o``c]Ol7007o0@0001L0
00?o00001038o``c]Ol7007o0@0001L000?o00001038o``c]Ol7007o0@0001L000?o00001038o``c
]Ol7007o0@0001L000?o00001038o``c]Ol7007o0@0001L000?o00001038o``c]Ol7007o0@0001L0
00?o00001013o`HcEOl6<aSo1S?7o`L00Ol100005`000ol0000404?o1S=Eo`Hc6?l6<lOo1`01o`40
000G0003o`0000@0@ol6<eGo1S<Ho`Hcaol7007o0@0001L000?o00001013o`HcEOl6<aSo1S?7o`L0
0Ol100005`000ol0000404?o1S=Eo`Hc6?l6<lOo1`01o`40000G00;o1@13o`HcEOl6<aSo1S?7o`H0
0_l100005`000ol0000403go1S=Eo`Hc9?l6<l7o1`01o`40000G0003o`0000@0?Ol6<eGo1S<To`Hc
`Ol7007o0@0001L000?o0000100mo`HcEOl6<bCo1S?1o`L00Ol100005`000ol0000403go1S=Eo`Hc
9?l6<l7o1`01o`40000G0003o`0000@0?Ol6<eGo1S<To`Hc`Ol7007o0@0001L000?o0000100mo`Hc
EOl6<bCo1S?1o`L00Ol100005`000ol0000403Oo1S=>o`Lc9?l6<`Ko33>ko`L00Ol100005`000ol0
000403Oo1S=>o`Lc9?l6<`Ko33>ko`L00Ol100005`000ol0000403Oo1S=>o`Lc9?l6<`Ko33>ko`L0
0Ol100005`000ol0000403Oo1S=>o`Lc9?l6<`Ko33>ko`L00Ol100005`000ol0000403Oo1S=>o`Lc
9?l6<`Ko33>ko`L00Ol100005`02o`D0=ol6<dko1c<To`Hc1_l<<k_o1P02o`40000G0003o`0000@0
Col6@ako1S<6o`Hc1_l7<`Ko1S<6@`co1T<6o`I31S<6@k_o1`01o`40000G0003o`0000@0Col6@ako
1S<6o`Hc1_l7<`Ko1S<6@`co1T<6o`I31S<6@k_o1`01o`40000G0003o`0000@0Col6@ako1S<6o`Hc
1_l7<`Ko1S<6@`co1T<6o`I31S<6@k_o1`01o`40000G0003o`0000@0Col6@ako1S<6o`Hc1_l7<`Ko
1S<6@`co1T<6o`I31S<6@k_o1`01o`40000G0003o`0000@0Col6@ako1S<6o`Hc1_l7<`Ko1S<6@`co
1T<6o`I31S<6@k_o1`01o`40000G0003o`0000@0Col6@ako1S<6o`Hc1_l7<`Ko1S<6@`co1T<6o`I3
1S<6@k_o1`01o`40000G0003o`0000@0NOl6<`co3C<6@`Hc1T<<<`a31S<6o``c1T<6<`ICWOl7007o
0@0001L000?o0000101io`Hc3?l=<`I31S<6@``c34<6<`Ko33<6@`Hc1U>Mo`L00Ol1000000<0ool0
1?l400049VSo1@P000?o0000101io`Hc3?l=<`I31S<6@``c34<6<`Ko33<6@`Hc1U>Mo`L00Ol10000
00@0UOmV0P001VP0001Vl`;V00>X_P001P000ol0000407Wo1S<<o`dc1T<6<`I333<<@`Hc1_l<<`I3
1S<6Digo1`01o`4000020003UOmV00D000HY_P00__<70003o`0000@0NOl6<`co3C<6@`Hc1T<<<`a3
1S<6o``c1T<6<`ICWOl7007o0@0000<000>nJ6H010000ol000020003o`0000D00ol407Wo1S<<o`dc
1T<6<`I333<<@`Hc1_l<<`I31S<6Digo1@03o`4000040003IVQV00<000?o00000P000ol000050003
o`0000@0Iol6<`co4S<7@`Ko1V<N@`Ko1S<6@``c1_l6<j?o1`01o`4000050003__<0008000?o0000
0P000ol000050003o`0000@0Iol6<`co4S<7@`Ko1V<N@`Ko1S<6@``c1_l6<j?o1`01o`4000060006
o`0002Vn0P000khY00060003o`0000@0Iol6<`co4S<7@`Ko1V<N@`Ko1S<6@``c1_l6<j?o1`01o`40
00001`3oENH01O<00`001VKci^KcIPL000?o0000101Wo`Hc3?lB<`M31_l6Hai31_l6<`I333<6o`Hc
Xol7007o0@0000030;kc00;o00=]iP000`0012IXJ6H80003o`0000@0Iol6<`co4S<7@`Ko1V<N@`Ko
1S<6@``c1_l6<j?o1`01o`40000G0003o`0000@0Iol6<`co4S<7@`Ko1V<N@`Ko1S<6@``c1_l6<j?o
1`01o`40000G0003o`0000@0BOl6<aSo1S<<oaTc1U<6P`IX1S<6@`aC1VP6D`Hc1V<6<`I333<Bo`Hc
QOl7007o0@0001L000?o00001019o`Hc6?l6<`co6C<6D`J31VP6<`I335<6J0IC1S<6H`Hc1T<<<a;o
1S>5o`L00Ol100005`000ol0000404Wo1S<Ho`Hc3?lI<`IC1X<6J0Hc1T<<D`IX1U<6<`IS1S<6@``c
4_l6<hGo1`01o`40000G0003o`0000@0BOl6<aSo1S<<oaTc1U<6P`IX1S<6@`aC1VP6D`Hc1V<6<`I3
33<Bo`HcQOl7007o0@0001L000?o00001019o`Hc6?l6<`co6C<6D`J31VP6<`I335<6J0IC1S<6H`Hc
1T<<<a;o1S>5o`L00Ol100005`02o`D0BOl6<aSo1S<<oaTc1U<6P`IX1S<6@`aC1VP6D`Hc1V<6<`I3
33<Bo`HcQOl600;o0@0001L000?o0000100[o`Hc1_l6@`Ko1S<Boa8c1T<6D`I31VP6H`MC1VP6T`J3
1Y<6J0JX1X<6H`Ko1T<6H`Hc1T>Yo`L00Ol100005`000ol0000402_o1S<6o`I31_l6<a;o4S<6@`IC
1T<6J0IS1e<6J0JC1X<6T`IX1ZP6P`IS1_l6@`IS1S<6@jWo1`01o`40000G0003o`0000@0:ol6<`Ko
1T<6o`Hc4_lB<`I31U<6@`IX1V<7D`IX1Y<6P`JC1VP6Z0J31V<6o`I31V<6<`I3ZOl7007o0@0001L0
00?o0000100[o`Hc1_l6@`Ko1S<Boa8c1T<6D`I31VP6H`MC1VP6T`J31Y<6J0JX1X<6H`Ko1T<6H`Hc
1T>Yo`L00Ol100005`000ol0000402_o1S<6o`I31_l6<a;o4S<6@`IC1T<6J0IS1e<6J0JC1X<6T`IX
1ZP6P`IS1_l6@`IS1S<6@jWo1`01o`40000G0003o`0000@0:ol6<`Ko1T<6o`Hc4_lB<`I31U<6@`IX
1V<7D`IX1Y<6P`JC1VP6Z0J31V<6o`I31V<6<`I3ZOl7007o0@0001L000?o0000100Uo`Hc4_l6@a;o
1S<<@`IC1V<6D`J31VP6Z0NC1X<6``KS1_<610I41VT6Q0JT1RT6Z;Go1`01o`40000G0003o`0000@0
9Ol6<a;o1T<Bo`Hc34<6D`IS1U<6P`IX1ZP7T`J31/<6h`Kc1P@6A0IY1X@6Y0HY1ZReo`L00Ol10000
5`000ol0000402Go1S<Bo`I34_l6<`a31U<6H`IC1X<6J0JX1i<6P`K31^<6l`H41T@6J@J41Z@6:@JX
]Ol7007o0@0001L000?o0000100Uo`Hc4_l6@a;o1S<<@`IC1V<6D`J31VP6Z0NC1X<6``KS1_<610I4
1VT6Q0JT1RT6Z;Go1`01o`40000G0003o`0000@09Ol6<a;o1T<Bo`Hc34<6D`IS1U<6P`IX1ZP7T`J3
1/<6h`Kc1P@6A0IY1X@6Y0HY1ZReo`L00Ol100005`02o`D09Ol6<a;o1T<Bo`Hc34<6D`IS1U<6P`IX
1ZP7T`J31/<6h`Kc1P@6A0IY1X@6Y0HY1ZReo`H00_l100005`000ol0000406Oo1S<<o`IC1T<6D`eX
3:P6d`Kc1U@6J@Jd1]@6m18E1V>So`L00Ol100005`000ol0000406Oo1S<<o`IC1T<6D`eX3:P6d`Kc
1U@6J@Jd1]@6m18E1V>So`L00Ol100005`000ol0000406Oo1S<<o`IC1T<6D`eX3:P6d`Kc1U@6J@Jd
1]@6m18E1V>So`L00Ol100005`000ol0000406Oo1S<<o`IC1T<6D`eX3:P6d`Kc1U@6J@Jd1]@6m18E
1V>So`L00Ol100005`000ol0000406Oo1S<<o`IC1T<6D`eX3:P6d`Kc1U@6J@Jd1]@6m18E1V>So`L0
0Ol100005`000ol0000406Oo1S<<o`IC1T<6D`eX3:P6d`Kc1U@6J@Jd1]@6m18E1V>So`L00Ol10000
5`000ol0000407?o1S<6o`Hc3Ol6@`IC39<6D`K31[@6ZPJF1Z/<ePJF1QH6K@I31V<6D`IX3D<<<`co
1S=Jo`L00Ol100005`000ol0000407?o1S<6o`Hc3Ol6@`IC39<6D`K31[@6ZPJF1Z/<ePJF1QH6K@I3
1V<6D`IX3D<<<`co1S=Jo`L00Ol100005`000ol0000407?o1S<6o`Hc3Ol6@`IC39<6D`K31[@6ZPJF
1Z/<ePJF1QH6K@I31V<6D`IX3D<<<`co1S=Jo`L00Ol100005`000ol0000407?o1S<6o`Hc3Ol6@`IC
39<6D`K31[@6ZPJF1Z/<ePJF1QH6K@I31V<6D`IX3D<<<`co1S=Jo`L00Ol100005`000ol0000407?o
1S<6o`Hc3Ol6@`IC39<6D`K31[@6ZPJF1Z/<ePJF1QH6K@I31V<6D`IX3D<<<`co1S=Jo`L00Ol10000
5`02o`D0Lol6<`Ko1S<=o`I31U<<T`IC1/<6]0JZ1YH6Z`cF1YH65PI]1T<6H`IC1VP=@``c3?l6<e[o
1P02o`40000G0003o`0000@0QOl=<`Ko1V<6<`Ko1[@6APJF1^HN00HW1VH6]0Ko36P6P`eX1V<6@`Ko
1S<6@``c=_l6<`co1`01o`40000G0003o`0000@0QOl=<`Ko1V<6<`Ko1[@6APJF1^HN00HW1VH6]0Ko
36P6P`eX1V<6@`Ko1S<6@``c=_l6<`co1`01o`40000G0003o`0000@0QOl=<`Ko1V<6<`Ko1[@6APJF
1^HN00HW1VH6]0Ko36P6P`eX1V<6@`Ko1S<6@``c=_l6<`co1`01o`40000G0003o`0000@0QOl=<`Ko
1V<6<`Ko1[@6APJF1^HN00HW1VH6]0Ko36P6P`eX1V<6@`Ko1S<6@``c=_l6<`co1`01o`40000G0003
o`0000@0QOl=<`Ko1V<6<`Ko1[@6APJF1^HN00HW1VH6]0Ko36P6P`eX1V<6@`Ko1S<6@``c=_l6<`co
1`01o`40000G0003o`0000@0QOl=<`Ko1V<6<`Ko1[@6APJF1^HN00HW1VH6]0Ko36P6P`eX1V<6@`Ko
1S<6@``c=_l6<`co1`01o`40000G0003o`0000@0V?l6D`Ko1TD6ISH01RL6EPI41Y<6P`eX1T<6D`Hc
34<<o`I3B?l7007o0@0001L000?o0000102Ho`IC1_l6A@IV=P069`IF1T@6T`J33FP6@`IC1S<<@`co
1T=8o`L00Ol100005`000ol0000409So1U<6o`I51VHf00HW1UH6A0JC1X<=J0I31U<6<`a33?l6@dSo
1`01o`40000G0003o`0000@0V?l6D`Ko1TD6ISH01RL6EPI41Y<6P`eX1T<6D`Hc34<<o`I3B?l7007o
0@0001L000?o0000102Ho`IC1_l6A@IV=P069`IF1T@6T`J33FP6@`IC1S<<@`co1T=8o`L00Ol10000
5`02o`D0V?l6D`Ko1TD6ISH01RL6EPI41Y<6P`eX1T<6D`Hc34<<o`I3B?l600;o0@0001L000?o0000
102No`JT1UI200KV1RH6@`JC1VP=H`aC33<6o`a34_l6@`Ko1S<To`L00Ol100005`000ol0000409ko
1Z@6ET801^H69PI31Y<6J0eS35<<<`Ko34<Bo`I31_l6<bCo1`01o`40000G0003o`0000@0W_l6Y0IF
@P06iPHV1T<6T`IX3F<<D``c1_l<@a;o1T<6o`Hc9?l7007o0@0001L000?o0000102No`JT1UI200KV
1RH6@`JC1VP=H`aC33<6o`a34_l6@`Ko1S<To`L00Ol100005`000ol0000409ko1Z@6ET801^H69PI3
1Y<6J0eS35<<<`Ko34<Bo`I31_l6<bCo1`01o`40000G0003o`0000@0W_l6Y0IF@P06iPHV1T<6T`IX
3F<<D``c1_l<@a;o1T<6o`Hc9?l7007o0@0001L000?o0000102;o`Lc1_l6J0HV1RM800IV1_<6Z0J3
3FP6H`I31U<6o`Hc34<Ho`Hc6?l6<`co1`01o`40000G0003o`0000@0Rol7<`Ko1VP69PHWB006IPKc
1ZP6P`eX1V<6@`IC1_l6<`a36?l6<aSo1S<<o`L00Ol100005`000ol0000408_o1c<6o`IX1RH69dP0
1VH6l`JX1X<=J0IS1T<6D`Ko1S<<@aSo1S<Ho`Hc3?l7007o0@0000030;jX00;o00=]iP000`0012IX
o`D80003o`0000@0Rol7<`Ko1VP69PHWB006IPKc1ZP6P`eX1V<6@`IC1_l6<`a36?l6<aSo1S<<o`L0
0Ol1000000<0J;h00P000`Gc00020006I_?ViZRn1`000ol0000408_o1c<6o`IX1RH69dP01VH6l`JX
1X<=J0IS1T<6D`Ko1S<<@aSo1S<Ho`Hc3?l7007o0@0000H000Ko0000:Kh20003__<000H00ol408_o
1c<6o`IX1RH69dP01VH6l`JX1X<=J0IS1T<6D`Ko1S<<@aSo1S<Ho`Hc3?l500?o0@0000D000<5Z000
0P000ol000020003o`0000D000?o0000102;o`M31_l6E0I[CP06YPJ11]<6T`MX1X<6H`IC1T<6o`Hc
1_l6@aSo1S<<o`I36?l7007o0@0000<000BXoolV0`000ol000020003o`0000D000?o0000102;o`M3
1_l6E0I[CP06YPJ11]<6T`MX1X<6H`IC1T<6o`Hc1_l6@aSo1S<<o`I36?l7007o0@0000@000?V1O<0
0`000ol000020003o`0000D000?o0000102;o`M31_l6E0I[CP06YPJ11]<6T`MX1X<6H`IC1T<6o`Hc
1_l6@aSo1S<<o`I36?l7007o0@0000H000Ko0000:Kh20003_RT000H000?o0000102;o`M31_l6E0I[
CP06YPJ11]<6T`MX1X<6H`IC1T<6o`Hc1_l6@aSo1S<<o`I36?l7007o0@0000030:QE008000>1l`00
0P001VKci^KcIPL000?o0000102;o`M31_l6E0I[CP06YPJ11]<6T`MX1X<6H`IC1T<6o`Hc1_l6@aSo
1S<<o`I36?l7007o0@00000302HY00;o00<YiP000`0012IXJ6H80003o`0000@0Rol7@`Ko1U@6Jdh0
1ZH6P@KC1Y<7J0J31V<6D`I31_l6<`Ko1T<Ho`Hc3?l6@aSo1`01o`40000G0003o`0000@0Rol7<`Ko
1RX6eTh01^H6I@J31Z<=J0IC34<6H`Hc1_l6@`co1S<fo`L00Ol100005`000ol0000408_o1c<6o`HZ
1]I>00KV1VD6P`JS3FP6D`a31V<6<`Ko1T<<o`Hc=_l7007o0@0001L000?o0000102;o`Lc1_l6:PKF
CP06iPIU1X<6X`eX1U<<@`IS1S<6o`I33?l6<cKo1`01o`40000G0003o`0000@0Rol7<`Ko1RX6eTh0
1^H6I@J31Z<=J0IC34<6H`Hc1_l6@`co1S<fo`L00Ol100005`000ol0000408_o1c<6o`HZ1]I>00KV
1VD6P`JS3FP6D`a31V<6<`Ko1T<<o`Hc=_l7007o0@0001L00_l508_o1c<6o`HZ1]I>00KV1VD6P`JS
3FP6D`a31V<6<`Ko1T<<o`Hc=_l600;o0@0001L000?o0000102Ho`KU1RM>00HW1PH6<`J31fP6P`IX
1X<6J0aC34<6<`Ko1S<To``c1_l7007o0@0001L000?o0000102Ho`KU1RM>00HW1PH6<`J31fP6P`IX
1X<6J0aC34<6<`Ko1S<To``c1_l7007o0@0001L000?o0000102Ho`KU1RM>00HW1PH6<`J31fP6P`IX
1X<6J0aC34<6<`Ko1S<To``c1_l7007o0@0001L000?o0000102Ho`KU1RM>00HW1PH6<`J31fP6P`IX
1X<6J0aC34<6<`Ko1S<To``c1_l7007o0@0001L000?o0000102Ho`KU1RM>00HW1PH6<`J31fP6P`IX
1X<6J0aC34<6<`Ko1S<To``c1_l7007o0@0001L000?o0000102Ho`KU1RM>00HW1PH6<`J31fP6P`IX
1X<6J0aC34<6<`Ko1S<To``c1_l7007o0@0001L000?o0000102;o`Lc1_l6:PKFCP06iPIU1X<6X`eX
35<6@`IS1S<6o`I33?l6<cKo1`01o`40000G0003o`0000@0Rol7<`Ko1RX6eTh01^H6I@J31Z<=J0aC
1T<6H`Hc1_l6@`co1S<fo`L00Ol100005`000ol0000408_o1c<6o`HZ1]I>00KV1VD6P`JS3FP<D`I3
1V<6<`Ko1T<<o`Hc=_l7007o0@0001L000?o0000102;o`Lc1_l6:PKFCP06iPIU1X<6X`eX35<6@`IS
1S<6o`I33?l6<cKo1`01o`40000G0003o`0000@0Rol7<`Ko1RX6eTh01^H6I@J31Z<=J0aC1T<6H`Hc
1_l6@`co1S<fo`L00Ol100005`02o`D0Rol7<`Ko1RX6eTh01^H6I@J31Z<=J0aC1T<6H`Hc1_l6@`co
1S<fo`H00_l100005`000ol0000408_o1d<6o`ID1V]>00JV1X46d`JC1fP6P`IS1U<6@`Ko1S<6o`I3
6?l6<`co1T<Ho`L00Ol100005`000ol0000408_o1d<6o`ID1V]>00JV1X46d`JC1fP6P`IS1U<6@`Ko
1S<6o`I36?l6<`co1T<Ho`L00Ol100005`000ol0000408_o1d<6o`ID1V]>00JV1X46d`JC1fP6P`IS
1U<6@`Ko1S<6o`I36?l6<`co1T<Ho`L00Ol100005`000ol0000408_o1d<6o`ID1V]>00JV1X46d`JC
1fP6P`IS1U<6@`Ko1S<6o`I36?l6<`co1T<Ho`L00Ol100005`000ol0000408_o1d<6o`ID1V]>00JV
1X46d`JC1fP6P`IS1U<6@`Ko1S<6o`I36?l6<`co1T<Ho`L00Ol100005`000ol0000408_o1d<6o`ID
1V]>00JV1X46d`JC1fP6P`IS1U<6@`Ko1S<6o`I36?l6<`co1T<Ho`L00Ol100005`000ol0000408_o
3C<6J0HV1RM800IV1_<6Z0J33FP6H`I31U<6o`Hc34<Ho`Hc6?l6<`co1`01o`40000G0003o`0000@0
Rol=<`IX1RH69dP01VH6l`JX1X<=J0IS1T<6D`Ko1S<<@aSo1S<Ho`Hc3?l7007o0@0001L000?o0000
102;o`dc1VP69PHWB006IPKc1ZP6P`eX1V<6@`IC1_l6<`a36?l6<aSo1S<<o`L00Ol100005`000ol0
000408_o3C<6J0HV1RM800IV1_<6Z0J33FP6H`I31U<6o`Hc34<Ho`Hc6?l6<`co1`01o`40000G0003
o`0000@0Rol=<`IX1RH69dP01VH6l`JX1X<=J0IS1T<6D`Ko1S<<@aSo1S<Ho`Hc3?l7007o0@0001L0
0_l508_o3C<6J0HV1RM800IV1_<6Z0J33FP6H`I31U<6o`Hc34<Ho`Hc6?l6<`co1P02o`40000G0003
o`0000@0W_l6Y0IF@P06iPHV1T<6T`IX1f<BD``c1_l<@a;o1S<6o`Hc9?l7007o0@0001L000?o0000
102No`JT1UI200KV1RH6@`JC1VP7Ha9C33<6o`a34_l6<`Ko1S<To`L00Ol100005`000ol0000409ko
1Z@6ET801^H69PI31Y<6J0MS4U<<<`Ko34<Bo`Hc1_l6<bCo1`01o`40000G0003o`0000@0W_l6Y0IF
@P06iPHV1T<6T`IX1f<BD``c1_l<@a;o1S<6o`Hc9?l7007o0@0001L000?o0000102No`JT1UI200KV
1RH6@`JC1VP7Ha9C33<6o`a34_l6<`Ko1S<To`L00Ol100005`000ol0000409ko1Z@6ET801^H69PI3
1Y<6J0MS4U<<<`Ko34<Bo`Hc1_l6<bCo1`01o`40000G0003o`0000@0V?l6H`Ko1TD6ISH01RL6EPI4
39<=J0I31U<6<`a33?l6@dSo1`01o`40000G0003o`0000@0V?l6H`Ko1TD6ISH01RL6EPI439<=J0I3
1U<6<`a33?l6@dSo1`01o`40000G0003o`0000@0V?l6H`Ko1TD6ISH01RL6EPI439<=J0I31U<6<`a3
3?l6@dSo1`01o`40000G0003o`0000@0V?l6H`Ko1TD6ISH01RL6EPI439<=J0I31U<6<`a33?l6@dSo
1`01o`40000G0003o`0000@0V?l6H`Ko1TD6ISH01RL6EPI439<=J0I31U<6<`a33?l6@dSo1`01o`40
000G00;o1@2Ho`IS1_l6A@IV=P069`IF1T@<T`eX1T<6D`Hc34<<o`I3B?l600;o0@0001L000?o0000
1025o`dc1_l6J0Hc1_l6]0I61YH6iQh01RL6IPJd1_l<J0J33FP6H`I31_l6<`I333<Ho`Hc6?l6<`co
1`01o`40000G0003o`0000@0QOl=<`Ko1VP6<`Ko1[@6APJF1^HN00HW1VH6]0Ko36P6P`eX1V<6@`Ko
1S<6@``c6?l6<aSo1S<<o`L00Ol100005`000ol0000408Go3C<6o`IX1S<6o`Jd1TH6UPKV7P069`IV
1[@6o`aX1X<=J0IS1T<6o`Hc1T<<<aSo1S<Ho`Hc3?l7007o0@0001L000?o00001025o`dc1_l6J0Hc
1_l6]0I61YH6iQh01RL6IPJd1_l<J0J33FP6H`I31_l6<`I333<Ho`Hc6?l6<`co1`01o`40000G0003
o`0000@0QOl=<`Ko1VP6<`Ko1[@6APJF1^HN00HW1VH6]0Ko36P6P`eX1V<6@`Ko1S<6@``c6?l6<aSo
1S<<o`L00Ol100005`000ol0000408Go3C<6o`IX1S<6o`Jd1TH6UPKV7P069`IV1[@6o`aX1X<=J0IS
1T<6o`Hc1T<<<aSo1S<Ho`Hc3?l7007o0@0001L000?o0000100go`Hc=_l6<`Ko1T<6o`Lc35<<T`IS
1]<6P@K51ZH6aPKF1^H6YPHV1X@6D`IX1V<6J0eC1S<6@`Ko1S<6@``cC_l7007o0@0001L000?o0000
100go`Hc=_l6<`Ko1T<6o`Lc35<<T`IS1]<6P@K51ZH6aPKF1^H6YPHV1X@6D`IX1V<6J0eC1S<6@`Ko
1S<6@``cC_l7007o0@0001L000?o0000100go`Hc=_l6<`Ko1T<6o`Lc35<<T`IS1]<6P@K51ZH6aPKF
1^H6YPHV1X@6D`IX1V<6J0eC1S<6@`Ko1S<6@``cC_l7007o0@0000@00_l00fP0000200049VSo1@P0
00?o0000100go`Hc=_l6<`Ko1T<6o`Lc35<<T`IS1]<6P@K51ZH6aPKF1^H6YPHV1X@6D`IX1V<6J0eC
1S<6@`Ko1S<6@``cC_l7007o0@0000D000?o00000P001VKci^JX_PL000?o0000100go`Hc=_l6<`Ko
1T<6o`Lc35<<T`IS1]<6P@K51ZH6aPKF1^H6YPHV1X@6D`IX1V<6J0eC1S<6@`Ko1S<6@``cC_l7007o
0@0000030?oo00Co0`001RVn002nl`L000?o0000100go`Hc=_l6<`Ko1T<6o`Lc35<<T`IS1]<6P@K5
1ZH6aPKF1^H6YPHV1X@6D`IX1V<6J0eC1S<6@`Ko1S<6@``cC_l7007o0@00000300Fn008000?o0000
0P000ol000020003o`0000D00ol404oo1S<6o`Hc1T<6D`a336P6P`fC3=<6l`HD1VT6U0KD1_@65@I5
32X6PaSo1S>5o`D00ol1000000H0i_?V0?l40003o`00008000?o00001@000ol0000404oo1S<6o`Hc
1T<6D`a336P6P`fC3=<6l`HD1VT6U0KD1_@65@I532X6PaSo1S>5o`L00Ol100000P001;j10?l40003
o`00008000?o00001@000ol0000404oo1S<6o`Hc1T<6D`a336P6P`fC3=<6l`HD1VT6U0KD1_@65@I5
32X6PaSo1S>5o`L00Ol100000`000bUVo`040006:Kh00;hY1`000ol0000404oo1S<6o`Hc1T<6D`a3
36P6P`fC3=<6l`HD1VT6U0KD1_@65@I532X6PaSo1S>5o`L00Ol100000`000jHYo`040006I_?Vi_=V
1`000ol0000404oo1S<6o`Hc1T<6D`a336P6P`fC3=<6l`HD1VT6U0KD1_@65@I532X6PaSo1S>5o`L0
0Ol1000010000`EX000400049VQXIPP000?o0000101?o`Hc1_l6<`I31U<<@`aX1X<=T`cC1_<650IY
1Y@6e0Kd1QD6A@`Z1X<Ho`HcQOl7007o0@0001L000?o0000100mo`Hc7_l6<a931VP6D`JC1h<6J0JX
1/<6d`Kc1RT6E0IY1X@650JC]Ol7007o0@0001L000?o0000100mo`Hc7_l6<a931VP6D`JC1h<6J0JX
1/<6d`Kc1RT6E0IY1X@650JC]Ol7007o0@0001L000?o0000100mo`Hc7_l6<a931VP6D`JC1h<6J0JX
1/<6d`Kc1RT6E0IY1X@650JC]Ol7007o0@0001L000?o0000100mo`Hc7_l6<a931VP6D`JC1h<6J0JX
1/<6d`Kc1RT6E0IY1X@650JC]Ol7007o0@0001L000?o0000100mo`Hc7_l6<a931VP6D`JC1h<6J0JX
1/<6d`Kc1RT6E0IY1X@650JC]Ol7007o0@0001L000?o0000100mo`Hc7_l6<a931VP6D`JC1h<6J0JX
1/<6d`Kc1RT6E0IY1X@650JC]Ol7007o0@0001L00_l502_o1S<6o`I31_l6<ako1S<6@`IC1T<6J0eC
1VP6T`J31Y<6J0JX1X<6D`Ko1T<6H`Hc1T>Yo`H00_l100005`000ol0000402_o1S<6o`I31_l6<ako
1S<6@`IC1T<6J0eC1VP6T`J31Y<6J0JX1X<6D`Ko1T<6H`Hc1T>Yo`L00Ol100005`000ol0000402_o
1S<6o`I31_l6<ako1S<6@`IC1T<6J0eC1VP6T`J31Y<6J0JX1X<6D`Ko1T<6H`Hc1T>Yo`L00Ol10000
5`000ol0000402_o1S<6o`I31_l6<ako1S<6@`IC1T<6J0eC1VP6T`J31Y<6J0JX1X<6D`Ko1T<6H`Hc
1T>Yo`L00Ol100005`000ol0000402_o1S<6o`I31_l6<ako1S<6@`IC1T<6J0eC1VP6T`J31Y<6J0JX
1X<6D`Ko1T<6H`Hc1T>Yo`L00Ol100005`000ol0000402_o1S<6o`I31_l6<ako1S<6@`IC1T<6J0eC
1VP6T`J31Y<6J0JX1X<6D`Ko1T<6H`Hc1T>Yo`L00Ol100005`000ol0000404Wo1S<Ho`Hc3?l<<`Ko
1c<6@`J31VP6<`I335<6J0IC1S<6H`Hc1T<<<a;o1S>5o`L00Ol100005`000ol0000404Wo1S<Ho`Hc
3?l<<`Ko1c<6@`J31VP6<`I335<6J0IC1S<6H`Hc1T<<<a;o1S>5o`L00Ol100005`000ol0000404Wo
1S<Ho`Hc3?l<<`Ko1c<6@`J31VP6<`I335<6J0IC1S<6H`Hc1T<<<a;o1S>5o`L00Ol100005`000ol0
000404Wo1S<Ho`Hc3?l<<`Ko1c<6@`J31VP6<`I335<6J0IC1S<6H`Hc1T<<<a;o1S>5o`L00Ol10000
5`000ol0000404Wo1S<Ho`Hc3?l<<`Ko1c<6@`J31VP6<`I335<6J0IC1S<6H`Hc1T<<<a;o1S>5o`L0
0Ol100005`000ol0000404Wo1S<Ho`Hc3?l<<`Ko1c<6@`J31VP6<`I335<6J0IC1S<6H`Hc1T<<<a;o
1S>5o`L00Ol100005`02o`D0Iol6<`co1S<6o`Hc1d<6o`IS34<6<`a31_l6<`I333>_o`H00_l10000
5`000ol0000406Oo1S<<o`Hc1_l6<`M31_l6H`a31S<<@`Ko1S<6@``c[ol7007o0@0001L000?o0000
101Wo`Hc3?l6<`Ko1S<7@`Ko1V<<@`Hc34<6o`Hc1T<<<joo1`01o`40000G0003o`0000@0Iol6<`co
1S<6o`Hc1d<6o`IS34<6<`a31_l6<`I333>_o`L00Ol100005`000ol0000406Oo1S<<o`Hc1_l6<`M3
1_l6H`a31S<<@`Ko1S<6@``c[ol7007o0@0001L000?o0000101Wo`Hc3?l6<`Ko1S<7@`Ko1V<<@`Hc
34<6o`Hc1T<<<joo1`01o`40000G0003o`0000@0NOl6<`co3C<6@`Ko1T<<<`a31S<6o``c1T<6<`IC
WOl7007o0@0001L000?o0000101io`Hc3?l=<`I31_l6@``c34<6<`Ko33<6@`Hc1U>Mo`L00Ol10000
5`000ol0000407Wo1S<<o`dc1T<6o`I333<<@`Hc1_l<<`I31S<6Digo1`01o`40000G0003o`0000@0
NOl6<`co3C<6@`Ko1T<<<`a31S<6o``c1T<6<`ICWOl7007o0@0001L000?o0000101io`Hc3?l=<`I3
1_l6@``c34<6<`Ko33<6@`Hc1U>Mo`L00Ol100005`000ol0000407Wo1S<<o`dc1T<6o`I333<<@`Hc
1_l<<`I31S<6Digo1`01o`40000G00;o1@1?o`I37_l6<`Ko1S<6o`Lc1_l6<`I33?l6@`Ko1T<<<k_o
1P02o`40000G0003o`0000@0Col6@ako1S<6o`Hc1_l7<`Ko1S<6@`co1T<6o`I333>ko`L00Ol10000
5`000ol0000404oo1T<No`Hc1_l6<`Ko1c<6o`Hc1T<<o`I31_l6@``c^ol7007o0@0001L000?o0000
101?o`I37_l6<`Ko1S<6o`Lc1_l6<`I33?l6@`Ko1T<<<k_o1`01o`40000G0003o`0000@0Col6@ako
1S<6o`Hc1_l7<`Ko1S<6@`co1T<6o`I333>ko`L00Ol100005`000ol0000404oo1T<No`Hc1_l6<`Ko
1c<6o`Hc1T<<o`I31_l6@``c^ol7007o0@0001L000?o0000100go`HcC_l7<bCo1S<6o``c^ol7007o
0@0001L000?o0000100go`HcC_l7<bCo1S<6o``c^ol7007o0@0001L000?o0000100go`HcC_l7<bCo
1S<6o``c^ol7007o0@0001L000?o0000100go`HcC_l7<bCo1S<6o``c^ol7007o0@0001L000?o0000
100go`HcC_l7<bCo1S<6o``c^ol7007o0@0001L000?o0000100go`HcC_l7<bCo1S<6o``c^ol7007o
0@0001L00_l503go1S=Eo`Hc9?l6<l7o1P02o`40000G0003o`0000@0?Ol6<eGo1S<To`Hc`Ol7007o
0@0001L000?o0000100mo`HcEOl6<bCo1S?1o`L00Ol100005`000ol0000403go1S=Eo`Hc9?l6<l7o
1`01o`40000G0003o`0000@0?Ol6<eGo1S<To`Hc`Ol7007o0@0001L000?o0000100mo`HcEOl6<bCo
1S?1o`L00Ol100005`000ol0000404?o1S=Eo`Hc6?l6<lOo1`01o`40000G0003o`0000@0@ol6<eGo
1S<Ho`Hcaol7007o0@0001L000?o00001013o`HcEOl6<aSo1S?7o`L00Ol1000000<0UFP00_l00bWV
000300049VSo1@P000?o00001013o`HcEOl6<aSo1S?7o`L00Ol1000000<0J5D00P000`DY00020006
I_?ViZRn1`000ol0000404?o1S=Eo`Hc6?l6<lOo1`01o`4000060006o`0002Vn0P000kkc00060003
o`0000@0@ol6<eGo1S<Ho`Hcaol7007o0@0000D000?Vo`000P000ol000020003o`0000D00ol40<So
33>eo`D00ol1000000<0J9D00P000`F100020003o`00008000?o00001@000ol000040<So33>eo`L0
0Ol1000000<0ojP00_l00h4000020003o`00008000?o00001@000ol000040<So33>eo`L00Ol10000
00<0o`001`001RVn002n:@L000?o00001038o``c]Ol7007o0@0000030?l000L000IVlnKVlfH70003
o`0000@0b?l<<kGo1`01o`4000000`3oo`03o`D000@VJ6QV20000ol000040<So33>eo`L00Ol10000
5`000ol000040?oo6?l6@fco1`01o`40000G0003o`0000@0oolHo`I3K?l7007o0@0001L000?o0000
103ooaSo1T=/o`L00Ol100005`000ol000040?oo6?l6@fco1`01o`40000G0003o`0000@0oolHo`I3
K?l7007o0@0001L000?o0000103ooaSo1T=/o`L00Ol100005`02o`D0Rol7<oOo1P02o`40000G0003
o`0000@0Rol7<oOo1`01o`40000G0003o`0000@0Rol7<oOo1`01o`40000G0003o`0000@0Rol7<oOo
1`01o`40000G0003o`0000@0Rol7<oOo1`01o`40000G0003o`0000@0Rol7<oOo1`01o`40000G0003
o`0000@0V?l6<n_o1`01o`40000G0003o`0000@0V?l6<n_o1`01o`40000G0003o`0000@0V?l6<n_o
1`01o`40000G0003o`0000@0V?l6<n_o1`01o`40000G0003o`0000@0V?l6<n_o1`01o`40000G0003
o`0000@0V?l6<n_o1`01o`40000G00;o1@3ooh[o1P02o`40000G0003o`0000@0oon:o`L00Ol10000
5`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L0
0Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103no`Hc6Ol6<fKo1`01o`40000G0003
o`0000@0o_l6<aWo1S=Vo`L00Ol100005`000ol000040?ko1S<Io`HcI_l7007o0@0001L000?o0000
103no`Hc6Ol6<fKo1`01o`40000G0003o`0000@0o_l6<aWo1S=Vo`L00Ol100005`000ol000040?ko
1S<Io`HcI_l7007o0@0001L00_l50?ooR_l600;o0@0001L000?o0000103ooh[o1`01o`40000G0003
o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40
000G0003o`0000@0oon:o`L00Ol100005`000ol000040;Ko1S?=o`L00Ol100005`000ol000040;Ko
1S?=o`L00Ol100005`000ol000040;Ko1S?=o`L00Ol100005`000ol000040;Ko1S?=o`L00Ol10000
5`000ol000040;Ko1S?=o`L00Ol100005`000ol000040;Ko1S?=o`L00Ol100005`02o`D0oon:o`H0
0_l100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0
oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003
o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40
000G0003o`0000@0oon:o`L00Ol1000000<0iRT00_l00fgV000300049VSo1@P000?o0000103ooh[o
1`01o`4000000`1]1@0200031Fd0008000IVlnKVZ;h70003o`0000@0oon:o`L00Ol1000000<0J000
0`001_l0000Y_P8000>nl`001P03o`@0oon:o`D00ol1000000<0onH00`001Ol0003o00@000?o0000
1@000ol000040?ooR_l7007o0@0000070?m]iP05K@030003o`00008000?o00001@000ol000040?oo
R_l7007o0@0000030:P500;o00=]iP000P000ol000020003o`0000D000?o0000103ooh[o1`01o`40
00000`1EP@070006:Kh00;hY1`000ol000040?ooR_l7007o0@00008000?cPJH01@001VKci^KcIPL0
00?o0000103ooh[o1`01o`40000300041FSoZ0@000@VJ6QV20000ol000040?ooR_l7007o0@0001L0
00?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o
0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol100005`02o`D0oon:o`H0
0_l100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0
oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003
o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o1`01o`40
000G0003o`0000@0oon:o`L00Ol100005`000ol000040?ooR_l7007o0@0001L000?o0000103ooh[o
1`01o`40000G00;o1@3ooh[o1P02o`40000G0003o`0000@0oon:o`L00Ol100005`000ol000040?oo
R_l7007o0@0001L000?o0000103ooh[o1`01o`40000G0003o`0000@0oon:o`L00Ol100005`000ol0
00040?ooR_l7007o0@0001L000?o0000o`2E007o0@0001L000?o0000o`2E007o0@0001L000?o0000
o`2E007o0@0001L000?o0000o`2E007o0@0001L000?o0000o`2E007o0@0001L000?o0000o`2E007o
0@0001L00_l50003o`0003X000?o0000>@000ol0000i0003o`0003X000?o0000>@000ol0000i0003
o`0002800_l100005`000ol000040003o`0000X000?o00002@000ol000090003o`0000T000?o0000
2@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003
o`0000T000?o00002@000ol000090003o`0000T000?o00002P000ol000090003o`0000T000?o0000
2@000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol000090003
o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0000:00;o0@0001L0oonIo`40
003o0;40003o0;400000\
\>"],
   ImageRangeCache->{{{54.0625, 283.438}, {287.812, 58.4375}} -> {-21.9811, \
13.4296, 0.249262, 0.249262}}],

Cell[BoxData[
     TagBox[\(\[SkeletonIndicator]  DensityGraphics  \[SkeletonIndicator]\),
       False,
       Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{906, 658},
WindowMargins->{{1, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->True,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
Magnification->1.5,
MacintoshSystemPageSetup->"\<\
0@00D04P0B0000003T8:b?mUofX>g@]ND005:0?l0040D04P0B0000003T8:b000
0000D0000000000000000BL?00400@IM;W0000000000000B0002I0000aP00000
8W800@0100<00P0000400000oS`10000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of
the file.  The cache data will then be recreated when you save this file
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 68, 0, 202, "Title"],

Cell[CellGroupData[{
Cell[1824, 55, 38, 0, 75, "Section"],
Cell[1865, 57, 121, 3, 43, "Text"],
Cell[1989, 62, 433, 8, 131, "Input"],
Cell[2425, 72, 164, 4, 65, "Text"],
Cell[2592, 78, 269, 5, 108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2898, 88, 46, 0, 75, "Section"],
Cell[2947, 90, 117, 2, 39, "Input"],

Cell[CellGroupData[{
Cell[3089, 96, 160, 3, 62, "Input"],
Cell[3252, 101, 623381, 12003, 612, 322606, 8285, "GraphicsData",
"PostScript", "Graphics"],
Cell[626636, 12106, 137, 3, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[626810, 12114, 171, 3, 62, "Input"],
Cell[626984, 12119, 323, 5, 102, "Message"],
Cell[627310, 12126, 323, 5, 102, "Message"],
Cell[627636, 12133, 203, 3, 56, "Message"],
Cell[627842, 12138, 323, 5, 102, "Message"],
Cell[628168, 12145, 164, 3, 56, "Message"],
Cell[628335, 12150, 203, 3, 56, "Message"],
Cell[628541, 12155, 203, 3, 56, "Message"],
Cell[628747, 12160, 162, 3, 56, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[628946, 12168, 53, 1, 39, "Input"],
Cell[629002, 12171, 472244, 10076, 363, 320495, 8198, "GraphicsData",
"PostScript", "Graphics"],
Cell[1101249, 22249, 137, 3, 39, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1101435, 22258, 43, 0, 75, "Section"],
Cell[1101481, 22260, 64, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[1101570, 22265, 79, 1, 39, "Input"],
Cell[1101652, 22268, 441438, 9779, 363, 318374, 8255, "GraphicsData",
"PostScript", "Graphics"],
Cell[1543093, 32049, 137, 3, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1543267, 32057, 520, 10, 154, "Input"],
Cell[1543790, 32069, 178, 3, 56, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1544005, 32077, 49, 1, 39, "Input"],
Cell[1544057, 32080, 451332, 9893, 363, 321436, 8285, "GraphicsData",
"PostScript", "Graphics"],
Cell[1995392, 41975, 137, 3, 39, "Output"]
}, Open  ]],
Cell[1995544, 41981, 61, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[1995630, 41986, 83, 1, 39, "Input"],
Cell[1995716, 41989, 448174, 9816, 363, 321971, 8253, "GraphicsData",
"PostScript", "Graphics"],
Cell[2443893, 51807, 137, 3, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2444067, 51815, 68, 1, 39, "Input"],
Cell[2444138, 51818, 184, 3, 56, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2444359, 51826, 82, 1, 39, "Input"],
Cell[2444444, 51829, 457762, 9855, 363, 318567, 8132, "GraphicsData",
"PostScript", "Graphics"],
Cell[2902209, 61686, 137, 3, 39, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2902395, 61695, 46, 0, 75, "Section"],
Cell[2902444, 61697, 306, 6, 85, "Input"],

Cell[CellGroupData[{
Cell[2902775, 61707, 165, 3, 62, "Input"],
Cell[2902943, 61712, 411490, 9355, 363, 318364, 8201, "GraphicsData",
"PostScript", "Graphics"],
Cell[3314436, 71069, 137, 3, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3314610, 71077, 199, 4, 62, "Input"],
Cell[3314812, 71083, 60561, 1220, 444, 14224, 643, "GraphicsData",
"PostScript", "Graphics"],
Cell[3375376, 72305, 137, 3, 39, "Output"]
}, Open  ]],
Cell[3375528, 72311, 130, 3, 39, "Input"],

Cell[CellGroupData[{
Cell[3375683, 72318, 75, 1, 39, "Input"],
Cell[3375761, 72321, 415802, 9505, 363, 329537, 8436, "GraphicsData",
"PostScript", "Graphics"],
Cell[3791566, 81828, 137, 3, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3791740, 81836, 112, 2, 39, "Input"],
Cell[3791855, 81840, 42688, 1008, 444, 14634, 657, "GraphicsData",
"PostScript", "Graphics"],
Cell[3834546, 82850, 137, 3, 39, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
